;;; phps-mode-parser.el --- Exported Emacs Parser Generator -*- lexical-binding: t -*-

;; Copyright (C) 2018-2024  Free Software Foundation, Inc.

;; This file is not part of GNU Emacs.


;;; Commentary:


;;; Code:


(require 'phps-mode-lexer)

(define-error
 'phps-parser-error
 "PHPs Parser Error")


;;; Variables:


(defvar
  phps-mode-parser--action-tables
  #s(hash-table size 42072 test equal rehash-size 1.5 rehash-threshold 0.8125 data (0 0 1 1 2 2 3 3 4 4 5 2 6 2 7 2 8 8 9 2 10 10 11 11 12 2 13 13 14 2 15 15 16 16 17 17 18 2 19 16 20 20 21 15 22 22 23 11 24 24 25 25 26 26 27 2 28 2 29 11 30 16 31 11 32 32 33 33 34 34 35 35 36 11 37 11 38 38 39 39 40 40 41 16 42 11 43 11 44 22 45 2 46 2 47 47 48 16 49 2 50 11 51 51 52 11 53 53 54 11 55 55 56 56 57 57 58 58 59 59 60 60 61 61 62 2 63 2 64 64 65 2 66 2 67 15 68 68 69 69 70 70 71 2 72 11 73 2 74 16 75 75 76 76 77 11 78 2 79 79 80 80 81 11 82 82 83 2 84 84 85 85 86 86 87 87 88 88 89 89 90 90 91 91 92 11 93 93 94 94 95 95 96 96 97 97 98 98 99 99 100 100 101 101 102 102 103 103 104 104 105 105 106 106 107 107 108 108 109 109 110 110 111 111 112 112 113 113 114 114 115 115 116 116 117 117 118 118 119 119 120 120 121 121 122 122 123 98 124 124 125 2 126 13 127 127 128 11 129 129 130 130 131 131 132 132 133 133 134 103 135 135 136 136 137 137 138 138 139 11 140 140 141 141 142 13 143 143 144 144 145 145 146 146 147 147 148 148 149 149 150 150 151 151 152 152 153 153 154 154 155 155 156 156 157 157 158 158 159 11 160 160 161 161 162 162 163 76 164 124 165 165 166 166 167 15 168 16 169 15 170 11 171 26 172 2 173 16 174 11 175 11 176 40 177 16 178 11 179 11 180 180 181 16 182 15 183 69 184 70 185 11 186 16 187 76 188 11 189 11 190 190 191 87 192 192 193 91 194 194 195 97 196 196 197 102 198 105 199 199 200 200 201 201 202 202 203 203 204 204 205 205 206 124 207 207 208 208 209 165 210 210 211 26 212 11 213 2 214 2 215 3 216 4 217 2 218 2 219 2 220 2 221 11 222 2 223 2 224 224 225 2 226 226 227 22 228 228 229 229 230 2 231 11 232 11 233 233 234 234 235 235 236 22 237 2 238 2 239 2 240 11 241 241 242 11 243 243 244 11 245 245 246 246 247 247 248 248 249 60 250 250 251 2 252 2 253 11 254 2 255 2 256 68 257 129 258 258 259 2 260 2 261 261 262 2 263 263 264 264 265 2 266 84 267 85 268 88 269 132 270 11 271 271 272 272 273 98 274 274 275 275 276 276 277 103 278 103 279 279 280 280 281 281 282 282 283 283 284 284 285 285 286 286 287 287 288 288 289 98 290 2 291 291 292 2 293 2 294 2 295 2 296 2 297 2 298 2 299 2 300 300 301 2 302 2 303 2 304 2 305 2 306 306 307 2 308 2 309 2 310 2 311 2 312 2 313 2 314 2 315 2 316 2 317 2 318 2 319 2 320 2 321 2 322 322 323 323 324 324 325 325 326 326 327 327 328 328 329 329 330 330 331 331 332 332 333 333 334 334 335 335 336 336 337 4 338 2 339 339 340 340 341 341 342 342 343 343 344 344 345 345 346 346 347 347 348 348 349 349 350 350 351 350 352 40 353 353 354 2 355 2 356 3 357 4 358 2 359 2 360 2 361 2 362 11 363 2 364 2 365 365 366 2 367 367 368 22 369 369 370 370 371 2 372 11 373 11 374 374 375 375 376 376 377 22 378 2 379 2 380 2 381 11 382 382 383 11 384 384 385 11 386 386 387 387 388 388 389 389 390 60 391 391 392 2 393 2 394 11 395 2 396 2 397 68 398 129 399 399 400 2 401 2 402 402 403 2 404 404 405 405 406 2 407 84 408 85 409 88 410 132 411 11 412 412 413 413 414 98 415 415 416 416 417 417 418 103 419 103 420 420 421 421 422 422 423 423 424 424 425 425 426 426 427 427 428 428 429 429 430 98 431 2 432 432 433 2 434 2 435 2 436 2 437 2 438 2 439 2 440 2 441 300 442 2 443 2 444 2 445 2 446 2 447 306 448 2 449 2 450 2 451 2 452 2 453 2 454 2 455 2 456 2 457 2 458 2 459 2 460 2 461 2 462 2 463 463 464 464 465 465 466 466 467 467 468 468 469 469 470 470 471 471 472 472 473 473 474 474 475 475 476 476 477 477 478 4 479 2 480 480 481 481 482 482 483 483 484 484 485 485 486 486 487 487 488 488 489 489 490 490 491 350 492 350 493 40 494 353 495 2 496 417 497 497 498 2 499 3 500 4 501 2 502 2 503 2 504 2 505 11 506 2 507 2 508 508 509 2 510 510 511 22 512 512 513 513 514 2 515 11 516 11 517 517 518 518 519 519 520 22 521 2 522 2 523 2 524 11 525 525 526 11 527 527 528 11 529 529 530 530 531 531 532 532 533 60 534 534 535 2 536 2 537 11 538 2 539 2 540 68 541 129 542 542 543 2 544 2 545 545 546 2 547 547 548 548 549 2 550 84 551 85 552 88 553 132 554 11 555 555 556 556 557 98 558 558 559 559 560 560 561 103 562 103 563 563 564 564 565 565 566 566 567 567 568 568 569 569 570 570 571 571 572 572 573 573 574 98 575 2 576 576 577 2 578 2 579 2 580 2 581 2 582 2 583 2 584 2 585 300 586 2 587 2 588 2 589 2 590 2 591 306 592 2 593 2 594 2 595 2 596 2 597 2 598 2 599 2 600 2 601 2 602 2 603 2 604 2 605 2 606 2 607 607 608 608 609 609 610 610 611 611 612 612 613 613 614 614 615 615 616 616 617 617 618 618 619 619 620 620 621 621 622 4 623 2 624 624 625 625 626 626 627 627 628 628 629 629 630 630 631 631 632 632 633 633 634 634 635 350 636 350 637 40 638 353 639 2 640 417 641 641 642 569 643 643 644 644 645 645 646 646 647 647 648 2 649 417 650 650 651 651 652 40 653 653 654 276 655 655 656 656 657 2 658 417 659 659 660 660 661 661 662 662 663 663 664 664 665 2 666 3 667 4 668 2 669 2 670 2 671 2 672 2 673 11 674 2 675 2 676 676 677 2 678 678 679 22 680 680 681 681 682 2 683 11 684 11 685 685 686 686 687 687 688 22 689 2 690 2 691 2 692 11 693 693 694 11 695 695 696 11 697 697 698 698 699 699 700 700 701 60 702 702 703 2 704 2 705 11 706 2 707 2 708 68 709 129 710 710 711 2 712 2 713 713 714 2 715 715 716 716 717 2 718 84 719 85 720 88 721 132 722 11 723 723 724 724 725 98 726 726 727 727 728 728 729 103 730 103 731 731 732 732 733 733 734 734 735 735 736 736 737 737 738 738 739 739 740 740 741 98 742 2 743 743 744 2 745 2 746 2 747 2 748 2 749 2 750 2 751 2 752 300 753 2 754 2 755 2 756 2 757 2 758 306 759 2 760 2 761 2 762 2 763 2 764 2 765 2 766 2 767 2 768 2 769 2 770 2 771 2 772 2 773 2 774 774 775 775 776 776 777 777 778 778 779 779 780 780 781 781 782 782 783 783 784 784 785 785 786 786 787 787 788 788 789 4 790 2 791 791 792 792 793 793 794 794 795 795 796 796 797 797 798 798 799 799 800 800 801 801 802 350 803 350 804 40 805 353 806 2 807 417 808 808 809 569 810 810 811 811 812 812 813 813 814 814 815 2 816 417 817 817 818 818 819 40 820 820 821 276 822 822 823 823 824 2 825 417 826 826 827 827 828 828 829 829 830 830 831 831 832 2 833 728 834 2 835 835 836 836 837 837 838 838 839 839 840 840 841 841 842 842 843 843 844 844 845 845 846 846 847 847 848 848 849 849 850 850 851 851 852 852 853 853 854 854 855 855 856 856 857 857 858 858 859 859 860 860 861 861 862 862 863 863 864 864 865 865 866 866 867 867 868 868 869 869 870 870 871 871 872 872 873 873 874 874 875 875 876 876 877 877 878 878 879 879 880 880 881 881 882 882 883 883 884 884 885 885 886 886 887 887 888 888 889 889 890 890 891 891 892 892 893 893 894 894 895 895 896 896 897 897 898 898 899 899 900 900 901 901 902 902 903 903 904 904 905 905 906 906 907 907 908 908 909 909 910 910 911 911 912 912 913 913 914 914 915 915 916 916 917 917 918 918 919 919 920 920 921 921 922 922 923 923 924 924 925 11 926 926 927 927 928 928 929 2 930 417 931 931 932 932 933 933 934 2 935 3 936 4 937 2 938 938 939 2 940 2 941 2 942 942 943 943 944 2 945 945 946 2 947 947 948 948 949 949 950 950 951 951 952 952 953 953 954 954 955 955 956 956 957 22 958 958 959 959 960 960 961 961 962 962 963 2 964 964 965 965 966 966 967 967 968 968 969 969 970 970 971 971 972 972 973 973 974 974 975 975 976 976 977 977 978 978 979 979 980 980 981 981 982 982 983 983 984 984 985 985 986 986 987 987 988 988 989 989 990 990 991 22 992 992 993 993 994 994 995 995 996 996 997 2 998 998 999 999 1000 1000 1001 1001 1002 1002 1003 1003 1004 1004 1005 1005 1006 1006 1007 1007 1008 1008 1009 1009 1010 1010 1011 1011 1012 1012 1013 2 1014 1014 1015 1015 1016 1016 1017 1017 1018 1018 1019 1019 1020 1020 1021 1021 1022 68 1023 1023 1024 1024 1025 2 1026 1026 1027 1027 1028 1028 1029 1029 1030 1030 1031 1031 1032 2 1033 1033 1034 1034 1035 1035 1036 1036 1037 1037 1038 2 1039 84 1040 85 1041 1041 1042 88 1043 132 1044 11 1045 1045 1046 1046 1047 98 1048 1048 1049 1049 1050 1050 1051 103 1052 103 1053 1053 1054 1054 1055 1055 1056 1056 1057 1057 1058 1058 1059 1059 1060 154 1061 1061 1062 1062 1063 1063 1064 1064 1065 1065 1066 1066 1067 98 1068 2 1069 11 1070 1070 1071 2 1072 1072 1073 11 1074 11 1075 1075 1076 1076 1077 1077 1078 2 1079 2 1080 11 1081 1081 1082 11 1083 11 1084 1084 1085 60 1086 1086 1087 2 1088 11 1089 2 1090 2 1091 129 1092 1092 1093 2 1094 1094 1095 1095 1096 1096 1097 2 1098 2 1099 2 1100 2 1101 2 1102 2 1103 2 1104 2 1105 300 1106 2 1107 2 1108 2 1109 2 1110 2 1111 306 1112 2 1113 2 1114 2 1115 2 1116 2 1117 2 1118 2 1119 2 1120 2 1121 2 1122 2 1123 2 1124 2 1125 2 1126 2 1127 1127 1128 1128 1129 1129 1130 1130 1131 1131 1132 1132 1133 1133 1134 1134 1135 1135 1136 1136 1137 1137 1138 1138 1139 1139 1140 1140 1141 1141 1142 4 1143 2 1144 1144 1145 1145 1146 1146 1147 1147 1148 1148 1149 1149 1150 1150 1151 1151 1152 1152 1153 1153 1154 1154 1155 350 1156 350 1157 40 1158 353 1159 2 1160 417 1161 1161 1162 569 1163 1163 1164 1164 1165 1165 1166 1166 1167 1167 1168 2 1169 417 1170 1170 1171 1171 1172 40 1173 1173 1174 276 1175 1175 1176 1176 1177 2 1178 417 1179 1179 1180 1180 1181 1181 1182 1182 1183 1183 1184 1184 1185 2 1186 728 1187 2 1188 1188 1189 1189 1190 1190 1191 1191 1192 1192 1193 1193 1194 1194 1195 1195 1196 1196 1197 1197 1198 2 1199 3 1200 4 1201 2 1202 2 1203 2 1204 2 1205 11 1206 2 1207 2 1208 1208 1209 2 1210 1210 1211 22 1212 1212 1213 1213 1214 2 1215 11 1216 11 1217 1217 1218 1218 1219 1219 1220 22 1221 2 1222 2 1223 2 1224 11 1225 1225 1226 11 1227 1227 1228 11 1229 1229 1230 1230 1231 1231 1232 1232 1233 60 1234 1234 1235 2 1236 2 1237 11 1238 2 1239 2 1240 68 1241 129 1242 1242 1243 2 1244 2 1245 1245 1246 2 1247 1247 1248 1248 1249 2 1250 84 1251 85 1252 88 1253 132 1254 11 1255 1255 1256 1256 1257 98 1258 1258 1259 1259 1260 1260 1261 103 1262 103 1263 1263 1264 1264 1265 1265 1266 1266 1267 1267 1268 1268 1269 1269 1270 1270 1271 1271 1272 1272 1273 98 1274 2 1275 1275 1276 2 1277 2 1278 2 1279 2 1280 2 1281 2 1282 2 1283 2 1284 300 1285 2 1286 2 1287 2 1288 2 1289 2 1290 306 1291 2 1292 2 1293 2 1294 2 1295 2 1296 2 1297 2 1298 2 1299 2 1300 2 1301 2 1302 2 1303 2 1304 2 1305 2 1306 1306 1307 1307 1308 1308 1309 1309 1310 1310 1311 1311 1312 1312 1313 1313 1314 1314 1315 1315 1316 1316 1317 1317 1318 1318 1319 1319 1320 1320 1321 4 1322 2 1323 1323 1324 1324 1325 1325 1326 1326 1327 1327 1328 1328 1329 1329 1330 1330 1331 1331 1332 1332 1333 1333 1334 350 1335 350 1336 40 1337 353 1338 2 1339 417 1340 1340 1341 569 1342 1342 1343 1343 1344 1344 1345 1345 1346 1346 1347 2 1348 417 1349 1349 1350 1350 1351 40 1352 1352 1353 276 1354 1354 1355 1355 1356 2 1357 417 1358 1358 1359 1359 1360 1360 1361 1361 1362 1362 1363 1363 1364 2 1365 728 1366 2 1367 1367 1368 1368 1369 1369 1370 1370 1371 1371 1372 1372 1373 1373 1374 1374 1375 1375 1376 1376 1377 845 1378 1378 1379 1379 1380 1380 1381 1381 1382 1382 1383 1383 1384 1384 1385 1385 1386 1386 1387 1387 1388 1388 1389 1389 1390 1390 1391 1391 1392 1392 1393 1393 1394 1394 1395 1395 1396 1396 1397 1397 1398 1398 1399 1399 1400 1400 1401 1401 1402 1402 1403 1403 1404 1404 1405 1405 1406 1406 1407 1407 1408 1408 1409 1409 1410 1410 1411 1411 1412 1412 1413 1413 1414 1414 1415 1415 1416 1416 1417 1417 1418 1418 1419 1419 1420 1420 1421 1421 1422 1422 1423 1423 1424 1424 1425 1425 1426 1426 1427 1427 1428 1428 1429 1429 1430 1430 1431 1431 1432 1432 1433 1433 1434 1434 1435 1435 1436 1436 1437 1437 1438 1438 1439 1439 1440 1440 1441 1441 1442 1442 1443 1443 1444 1444 1445 1445 1446 1446 1447 1447 1448 1448 1449 1449 1450 1450 1451 1451 1452 1452 1453 1453 1454 1454 1455 1455 1456 1456 1457 11 1458 1458 1459 1459 1460 1460 1461 2 1462 417 1463 1463 1464 932 1465 1465 1466 1466 1467 965 1468 154 1469 1469 1470 157 1471 1471 1472 2 1473 1473 1474 1474 1475 1475 1476 1476 1477 2 1478 2 1479 2 1480 1480 1481 2 1482 1482 1483 2 1484 2 1485 2 1486 2 1487 2 1488 2 1489 2 1490 2 1491 2 1492 1492 1493 1493 1494 1494 1495 1495 1496 1496 1497 1497 1498 1498 1499 1499 1500 1500 1501 1501 1502 1502 1503 1503 1504 1504 1505 1505 1506 1506 1507 22 1508 1508 1509 3 1510 4 1511 2 1512 11 1513 1513 1514 1514 1515 1515 1516 1516 1517 1517 1518 1518 1519 1519 1520 1520 1521 1521 1522 1522 1523 1523 1524 11 1525 1525 1526 1526 1527 1527 1528 1528 1529 84 1530 88 1531 11 1532 1532 1533 1533 1534 98 1535 1535 1536 1536 1537 1537 1538 1538 1539 1539 1540 1540 1541 1541 1542 98 1543 845 1544 1544 1545 1545 1546 1546 1547 1547 1548 1548 1549 1549 1550 1550 1551 1551 1552 1552 1553 1553 1554 1554 1555 1555 1556 1556 1557 1557 1558 1558 1559 1559 1560 1560 1561 1561 1562 1562 1563 1563 1564 1564 1565 1565 1566 1566 1567 1567 1568 1568 1569 1569 1570 1570 1571 1571 1572 1572 1573 1573 1574 1574 1575 1575 1576 1576 1577 1577 1578 1578 1579 1579 1580 1580 1581 1581 1582 1582 1583 1583 1584 1584 1585 1585 1586 1586 1587 1587 1588 1588 1589 1589 1590 1590 1591 1591 1592 1592 1593 1593 1594 1594 1595 1595 1596 1596 1597 1597 1598 1598 1599 1599 1600 1600 1601 1601 1602 1602 1603 1603 1604 1604 1605 1605 1606 1606 1607 1607 1608 1608 1609 1609 1610 1610 1611 1611 1612 1612 1613 1613 1614 1614 1615 1615 1616 1616 1617 1617 1618 1618 1619 1619 1620 1620 1621 1621 1622 1622 1623 11 1624 1624 1625 1625 1626 1626 1627 2 1628 417 1629 1629 1630 932 1631 1631 1632 1632 1633 965 1634 154 1635 157 1636 1636 1637 1637 1638 1638 1639 845 1640 1640 1641 11 1642 1642 1643 2 1644 417 1645 1645 1646 1646 1647 1647 1648 350 1649 350 1650 353 1651 2 1652 417 1653 1653 1654 569 1655 1655 1656 1656 1657 1657 1658 1658 1659 2 1660 417 1661 1661 1662 1662 1663 1663 1664 1664 1665 2 1666 3 1667 4 1668 2 1669 2 1670 2 1671 2 1672 11 1673 2 1674 2 1675 1675 1676 2 1677 1677 1678 22 1679 1679 1680 1680 1681 2 1682 2 1683 11 1684 11 1685 1685 1686 1686 1687 1687 1688 22 1689 2 1690 2 1691 2 1692 11 1693 1693 1694 11 1695 1695 1696 11 1697 1697 1698 1698 1699 1699 1700 1700 1701 60 1702 1702 1703 2 1704 2 1705 11 1706 2 1707 2 1708 68 1709 129 1710 1710 1711 2 1712 2 1713 1713 1714 2 1715 1715 1716 1716 1717 2 1718 84 1719 85 1720 22 1721 88 1722 1722 1723 569 1724 132 1725 11 1726 1726 1727 1727 1728 98 1729 1729 1730 1730 1731 1731 1732 103 1733 103 1734 1734 1735 1735 1736 1736 1737 1737 1738 1738 1739 1739 1740 1740 1741 1741 1742 1742 1743 1743 1744 1744 1745 1745 1746 98 1747 2 1748 11 1749 1749 1750 2 1751 2 1752 2 1753 2 1754 2 1755 2 1756 2 1757 2 1758 300 1759 2 1760 2 1761 2 1762 2 1763 2 1764 306 1765 2 1766 2 1767 2 1768 2 1769 2 1770 2 1771 2 1772 2 1773 2 1774 2 1775 2 1776 2 1777 2 1778 2 1779 2 1780 1780 1781 1781 1782 1782 1783 1783 1784 1784 1785 1785 1786 1786 1787 1787 1788 1788 1789 1789 1790 1790 1791 1791 1792 1792 1793 1793 1794 1794 1795 4 1796 2 1797 1797 1798 1798 1799 1799 1800 1800 1801 1801 1802 1802 1803 1803 1804 1804 1805 1805 1806 1806 1807 1807 1808 350 1809 350 1810 40 1811 353 1812 2 1813 417 1814 1814 1815 569 1816 1816 1817 1817 1818 1818 1819 1819 1820 1820 1821 2 1822 417 1823 1823 1824 1824 1825 40 1826 1826 1827 276 1828 1828 1829 1829 1830 2 1831 417 1832 1832 1833 1833 1834 1834 1835 1835 1836 1836 1837 1837 1838 2 1839 728 1840 2 1841 1841 1842 1842 1843 1843 1844 1844 1845 1845 1846 1846 1847 1847 1848 1848 1849 1849 1850 1850 1851 1851 1852 2 1853 3 1854 4 1855 2 1856 2 1857 2 1858 2 1859 11 1860 2 1861 2 1862 1208 1863 2 1864 1210 1865 22 1866 1212 1867 1213 1868 2 1869 2 1870 11 1871 11 1872 1217 1873 1218 1874 1219 1875 22 1876 2 1877 2 1878 2 1879 11 1880 1225 1881 11 1882 1227 1883 11 1884 1229 1885 1230 1886 1231 1887 1232 1888 60 1889 1234 1890 2 1891 2 1892 11 1893 2 1894 2 1895 68 1896 129 1897 1242 1898 2 1899 2 1900 1245 1901 2 1902 1247 1903 1248 1904 2 1905 84 1906 85 1907 22 1908 88 1909 1909 1910 157 1911 132 1912 11 1913 1255 1914 1256 1915 98 1916 1258 1917 1259 1918 1918 1919 103 1920 103 1921 1263 1922 1264 1923 1265 1924 1266 1925 1267 1926 1268 1927 1927 1928 1928 1929 1269 1930 1270 1931 1271 1932 1272 1933 98 1934 2 1935 11 1936 1275 1937 2 1938 2 1939 2 1940 2 1941 2 1942 2 1943 2 1944 2 1945 300 1946 2 1947 2 1948 2 1949 2 1950 2 1951 306 1952 2 1953 2 1954 2 1955 2 1956 2 1957 2 1958 2 1959 2 1960 2 1961 2 1962 2 1963 2 1964 2 1965 2 1966 2 1967 1306 1968 1307 1969 1308 1970 1309 1971 1310 1972 1311 1973 1312 1974 1313 1975 1314 1976 1315 1977 1316 1978 1317 1979 1318 1980 1319 1981 1320 1982 4 1983 2 1984 1323 1985 1324 1986 1325 1987 1326 1988 1327 1989 1328 1990 1329 1991 1330 1992 1331 1993 1332 1994 1333 1995 350 1996 350 1997 40 1998 353 1999 2 2000 417 2001 1340 2002 569 2003 1342 2004 1343 2005 1344 2006 1345 2007 1346 2008 2 2009 417 2010 1349 2011 1350 2012 40 2013 1352 2014 276 2015 1354 2016 1355 2017 2 2018 417 2019 1358 2020 1359 2021 1360 2022 1361 2023 1362 2024 1363 2025 2 2026 728 2027 2 2028 1367 2029 1368 2030 1369 2031 1370 2032 1371 2033 1372 2034 1373 2035 1374 2036 1375 2037 1376 2038 1851 2039 157 2040 2040 2041 2 2042 2042 2043 845 2044 1378 2045 1379 2046 1380 2047 1381 2048 1382 2049 1383 2050 1384 2051 1385 2052 1386 2053 1387 2054 1388 2055 1389 2056 1390 2057 1391 2058 1392 2059 1393 2060 1394 2061 1395 2062 1396 2063 1397 2064 1398 2065 1399 2066 1400 2067 1401 2068 1402 2069 1403 2070 1404 2071 1405 2072 1406 2073 1407 2074 1408 2075 1409 2076 1410 2077 1411 2078 1412 2079 1413 2080 1414 2081 1415 2082 1416 2083 1417 2084 1418 2085 1419 2086 1420 2087 1421 2088 1422 2089 1423 2090 1424 2091 1425 2092 1426 2093 1427 2094 1428 2095 1429 2096 1430 2097 1431 2098 1432 2099 1433 2100 1434 2101 1435 2102 1436 2103 1437 2104 1438 2105 1439 2106 1440 2107 1441 2108 1442 2109 1443 2110 1444 2111 1445 2112 1446 2113 1447 2114 1448 2115 1449 2116 1450 2117 1451 2118 1452 2119 1453 2120 1454 2121 1455 2122 1456 2123 11 2124 1458 2125 1459 2126 1460 2127 2 2128 417 2129 1463 2130 932 2131 1465 2132 1466 2133 965 2134 154 2135 157 2136 1471 2137 1475 2138 1476 2139 2 2140 2 2141 2 2142 1480 2143 2 2144 1482 2145 2 2146 2 2147 2 2148 2 2149 2 2150 2 2151 2 2152 2 2153 2 2154 1492 2155 1493 2156 1494 2157 1495 2158 1496 2159 1497 2160 1498 2161 1499 2162 1500 2163 1501 2164 1502 2165 1503 2166 1504 2167 22 2168 1508 2169 4 2170 11 2171 1528 2172 88 2173 11 2174 1532 2175 98 2176 1537 2177 1538 2178 1539 2179 1540 2180 1541 2181 98 2182 845 2183 11 2184 1626 2185 932 2186 1631 2187 1632 2188 965 2189 154 2190 157 2191 1636 2192 1637 2193 1638 2194 845 2195 11 2196 1642 2197 1646 2198 1647 2199 350 2200 350 2201 353 2202 2 2203 417 2204 1653 2205 569 2206 1655 2207 1656 2208 1657 2209 1658 2210 2 2211 417 2212 1661 2213 1662 2214 1663 2215 1664 2216 2216 2217 2217 2218 2 2219 417 2220 2220 2221 1851 2222 2222 2223 2223 2224 138 2225 11 2226 140 2227 157 2228 158 2229 160 2230 162 2231 76 2232 124 2233 165 2234 2234 2235 2235 2236 138 2237 11 2238 140 2239 157 2240 2240 2241 161 2242 2242 2243 2243 2244 2244 2245 2 2246 2246 2247 2247 2248 2248 2249 2248 2250 2250 2251 2251 2252 2252 2253 2253 2254 2254 2255 2255 2256 2256 2257 2257 2258 2258 2259 2259 2260 2260 2261 2261 2262 2262 2263 2263 2264 2264 2265 2248 2266 2266 2267 2267 2268 2268 2269 2269 2270 2270 2271 2271 2272 2272 2273 2273 2274 2274 2275 2275 2276 2276 2277 2277 2278 2278 2279 2279 2280 2280 2281 2281 2282 2282 2283 2283 2284 2284 2285 2285 2286 2286 2287 2287 2288 2248 2289 2289 2290 2290 2291 2291 2292 2292 2293 2293 2294 2294 2295 2295 2296 2296 2297 2297 2298 2298 2299 2299 2300 2248 2301 2301 2302 2264 2303 2303 2304 2248 2305 2305 2306 2306 2307 2307 2308 2308 2309 2309 2310 2310 2311 2311 2312 2312 2313 2313 2314 2314 2315 2248 2316 2316 2317 2317 2318 2318 2319 2319 2320 2320 2321 2321 2322 2322 2323 2323 2324 2324 2325 2325 2326 2326 2327 2284 2328 2328 2329 1476 2330 2 2331 3 2332 4 2333 2 2334 2 2335 2 2336 2 2337 11 2338 2 2339 2 2340 1070 2341 2 2342 955 2343 22 2344 1072 2345 961 2346 2 2347 11 2348 11 2349 1075 2350 1076 2351 1077 2352 22 2353 2 2354 2 2355 2 2356 11 2357 1081 2358 11 2359 1001 2360 11 2361 1084 2362 1008 2363 1009 2364 1010 2365 60 2366 1086 2367 2 2368 2 2369 11 2370 2 2371 2 2372 68 2373 129 2374 1092 2375 2 2376 2 2377 1094 2378 2 2379 1035 2380 1095 2381 2 2382 84 2383 85 2384 22 2385 88 2386 132 2387 11 2388 1045 2389 1046 2390 98 2391 1048 2392 1049 2393 2393 2394 103 2395 103 2396 1053 2397 1055 2398 1056 2399 1057 2400 1058 2401 1059 2402 1062 2403 1064 2404 1065 2405 1066 2406 98 2407 2 2408 11 2409 1096 2410 2 2411 2 2412 2 2413 2 2414 2 2415 2 2416 2 2417 2 2418 300 2419 2 2420 2 2421 2 2422 2 2423 2 2424 306 2425 2 2426 2 2427 2 2428 2 2429 2 2430 2 2431 2 2432 2 2433 2 2434 2 2435 2 2436 2 2437 2 2438 2 2439 2 2440 1127 2441 1128 2442 1129 2443 1130 2444 1131 2445 1132 2446 1133 2447 1134 2448 1135 2449 1136 2450 1137 2451 1138 2452 1139 2453 1140 2454 1141 2455 4 2456 2 2457 1144 2458 1145 2459 1146 2460 1147 2461 1148 2462 1149 2463 1150 2464 1151 2465 1152 2466 1153 2467 1154 2468 350 2469 350 2470 40 2471 353 2472 2 2473 417 2474 1161 2475 569 2476 1163 2477 1164 2478 1165 2479 1166 2480 1167 2481 2 2482 417 2483 1170 2484 1171 2485 40 2486 1173 2487 276 2488 1175 2489 1176 2490 2 2491 417 2492 1179 2493 1180 2494 1181 2495 1182 2496 1183 2497 1184 2498 2 2499 728 2500 2 2501 1188 2502 1189 2503 1190 2504 1191 2505 1192 2506 1193 2507 1194 2508 1195 2509 1196 2510 1197 2511 1851 2512 157 2513 2040 2514 2 2515 2515 2516 845 2517 2517 2518 2518 2519 2519 2520 2520 2521 2521 2522 2522 2523 2523 2524 2524 2525 2525 2526 2526 2527 2527 2528 2528 2529 2529 2530 2530 2531 2531 2532 2532 2533 2533 2534 2534 2535 2535 2536 2536 2537 2537 2538 2538 2539 2539 2540 2540 2541 2541 2542 2542 2543 2543 2544 2544 2545 2545 2546 2546 2547 2547 2548 2548 2549 2549 2550 2550 2551 2551 2552 2552 2553 2553 2554 2554 2555 2555 2556 2556 2557 2557 2558 2558 2559 2559 2560 2560 2561 2561 2562 2562 2563 2563 2564 2564 2565 2565 2566 2566 2567 2567 2568 2568 2569 2569 2570 2570 2571 2571 2572 2572 2573 2573 2574 2574 2575 2575 2576 2576 2577 2577 2578 2578 2579 2579 2580 2580 2581 2581 2582 2582 2583 2583 2584 2584 2585 2585 2586 2586 2587 2587 2588 2588 2589 2589 2590 2590 2591 2591 2592 2592 2593 2593 2594 2594 2595 2595 2596 11 2597 2597 2598 2598 2599 2599 2600 2 2601 417 2602 2602 2603 932 2604 2604 2605 2605 2606 965 2607 154 2608 157 2609 2609 2610 2610 2611 1476 2612 2 2613 2 2614 2 2615 2615 2616 2 2617 2617 2618 2 2619 2 2620 2 2621 2 2622 2 2623 2 2624 2 2625 2 2626 2 2627 2627 2628 2628 2629 2629 2630 2630 2631 2631 2632 2632 2633 2633 2634 2634 2635 2635 2636 2636 2637 2637 2638 2638 2639 2639 2640 22 2641 2641 2642 4 2643 11 2644 2644 2645 88 2646 11 2647 2647 2648 98 2649 2649 2650 1538 2651 2651 2652 2652 2653 2653 2654 98 2655 845 2656 11 2657 2657 2658 932 2659 2659 2660 2660 2661 965 2662 154 2663 157 2664 2664 2665 2665 2666 2666 2667 845 2668 11 2669 2669 2670 2670 2671 2671 2672 350 2673 350 2674 353 2675 2 2676 417 2677 2677 2678 569 2679 2679 2680 2680 2681 2681 2682 2682 2683 2 2684 417 2685 2685 2686 2686 2687 2687 2688 2688 2689 2689 2690 2690 2691 2 2692 417 2693 2693 2694 2694 2695 138 2696 11 2697 140 2698 157 2699 158 2700 160 2701 162 2702 76 2703 124 2704 165 2705 2705 2706 2706 2707 138 2708 11 2709 140 2710 157 2711 2240 2712 2242 2713 2243 2714 2244 2715 2 2716 2716 2717 2717 2718 845 2719 2719 2720 11 2721 2721 2722 2 2723 417 2724 2724 2725 2725 2726 2726 2727 2727 2728 2728 2729 2729 2730 2730 2731 350 2732 350 2733 353 2734 2 2735 417 2736 2736 2737 569 2738 2738 2739 2739 2740 2740 2741 2741 2742 2 2743 417 2744 2744 2745 2745 2746 2746 2747 2747 2748 4 2749 11 2750 2750 2751 88 2752 11 2753 2753 2754 98 2755 2755 2756 1538 2757 2757 2758 2758 2759 2759 2760 98 2761 845 2762 11 2763 2763 2764 932 2765 2765 2766 2766 2767 965 2768 154 2769 157 2770 2770 2771 2771 2772 2772 2773 845 2774 11 2775 2775 2776 2776 2777 2777 2778 350 2779 350 2780 353 2781 2 2782 417 2783 2783 2784 569 2785 2785 2786 2786 2787 2787 2788 2788 2789 2 2790 417 2791 2791 2792 2792 2793 2793 2794 2794 2795 2795 2796 2796 2797 2 2798 417 2799 2799 2800 22 2801 2801 2802 2802 2803 2803 2804 2804 2805 2805 2806 2806 2807 2807 2808 2808 2809 2809 2810 16 2811 16 2812 2812 2813 2813 2814 2814 2815 2815 2816 2816 2817 569 2818 2818 2819 2819 2820 2820 2821 2821 2822 2822 2823 2823 2824 417 2825 2825 2826 2 2827 2827 2828 2828 2829 2829 2830 2830 2831 4 2832 11 2833 2833 2834 88 2835 11 2836 2836 2837 98 2838 2838 2839 1538 2840 2840 2841 2841 2842 2842 2843 98 2844 845 2845 11 2846 2846 2847 932 2848 2848 2849 2849 2850 965 2851 154 2852 157 2853 2853 2854 2854 2855 2855 2856 2856 2857 845 2858 11 2859 2859 2860 2860 2861 2861 2862 350 2863 350 2864 353 2865 2 2866 417 2867 2867 2868 569 2869 2869 2870 2870 2871 2871 2872 2872 2873 2 2874 417 2875 2875 2876 2876 2877 2877 2878 2878 2879 2879 2880 2880 2881 2 2882 417 2883 2883 2884 569 2885 2885 2886 2 2887 2887 2888 2888 2889 1260 2890 2 2891 2891 2892 2892 2893 2893 2894 2894 2895 2895 2896 22 2897 2801 2898 2898 2899 2899 2900 2900 2901 68 2902 2902 2903 2903 2904 2904 2905 2905 2906 16 2907 16 2908 2812 2909 569 2910 2910 2911 2911 2912 2912 2913 2913 2914 2914 2915 2823 2916 417 2917 2917 2918 2 2919 2919 2920 2828 2921 2829 2922 2922 2923 2842 2924 2924 2925 2925 2926 2926 2927 2927 2928 2928 2929 2929 2930 4 2931 2 2932 13 2933 2933 2934 2934 2935 2935 2936 2936 2937 2937 2938 2938 2939 2644 2940 2940 2941 2941 2942 2942 2943 2943 2944 2944 2945 2945 2946 2946 2947 2947 2948 2948 2949 2949 2950 2950 2951 350 2952 350 2953 40 2954 353 2955 2 2956 417 2957 2957 2958 569 2959 2959 2960 2960 2961 2680 2962 2962 2963 2682 2964 2 2965 417 2966 2685 2967 2967 2968 932 2969 2969 2970 2970 2971 2971 2972 965 2973 154 2974 157 2975 2975 2976 2976 2977 40 2978 2978 2979 2979 2980 2980 2981 2981 2982 932 2983 2983 2984 2984 2985 13 2986 2986 2987 13 2988 2988 2989 76 2990 2990 2991 2991 2992 2992 2993 13 2994 2994 2995 2995 2996 2996 2997 2997 2998 2998 2999 2999 3000 3000 3001 13 3002 3002 3003 3003 3004 3004 3005 3005 3006 3006 3007 3007 3008 3008 3009 3009 3010 3010 3011 3011 3012 3012 3013 3013 3014 3014 3015 3014 3016 3016 3017 3017 3018 3018 3019 3019 3020 3020 3021 3021 3022 3022 3023 3023 3024 3024 3025 3025 3026 3026 3027 3027 3028 2263 3029 3029 3030 3014 3031 3031 3032 3032 3033 3033 3034 3034 3035 3035 3036 3036 3037 3037 3038 3038 3039 3039 3040 2284 3041 2286 3042 3014 3043 3043 3044 3044 3045 3014 3046 3046 3047 3029 3048 3048 3049 3014 3050 3050 3051 3051 3052 3052 3053 3053 3054 3054 3055 3055 3056 3056 3057 3057 3058 3058 3059 3059 3060 3060 3061 3024 3062 3062 3063 3063 3064 2 3065 3065 3066 2 3067 3 3068 4 3069 2 3070 2 3071 2 3072 2 3073 11 3074 2 3075 2 3076 3076 3077 2 3078 3078 3079 22 3080 3080 3081 3081 3082 2 3083 11 3084 11 3085 3085 3086 3086 3087 3087 3088 22 3089 2 3090 2 3091 2 3092 11 3093 3093 3094 11 3095 3095 3096 11 3097 3097 3098 3098 3099 3099 3100 3100 3101 60 3102 3102 3103 2 3104 2 3105 11 3106 2 3107 2 3108 68 3109 129 3110 3110 3111 2 3112 2 3113 3113 3114 2 3115 3115 3116 3116 3117 2 3118 84 3119 85 3120 88 3121 132 3122 11 3123 3123 3124 3124 3125 98 3126 3126 3127 3127 3128 3128 3129 103 3130 103 3131 3131 3132 3132 3133 3133 3134 3134 3135 3135 3136 3136 3137 3137 3138 3138 3139 3139 3140 3140 3141 98 3142 2 3143 3143 3144 2 3145 2 3146 2 3147 2 3148 2 3149 2 3150 2 3151 2 3152 300 3153 2 3154 2 3155 2 3156 2 3157 2 3158 306 3159 2 3160 2 3161 2 3162 2 3163 2 3164 2 3165 2 3166 2 3167 2 3168 2 3169 2 3170 2 3171 2 3172 2 3173 2 3174 3174 3175 3175 3176 3176 3177 3177 3178 3178 3179 3179 3180 3180 3181 3181 3182 3182 3183 3183 3184 3184 3185 3185 3186 3186 3187 3187 3188 3188 3189 4 3190 2 3191 3191 3192 3192 3193 3193 3194 3194 3195 3195 3196 3196 3197 3197 3198 3198 3199 3199 3200 3200 3201 3201 3202 350 3203 350 3204 40 3205 353 3206 2 3207 417 3208 3208 3209 569 3210 3210 3211 3211 3212 3212 3213 3213 3214 3214 3215 2 3216 417 3217 3217 3218 3218 3219 40 3220 3220 3221 276 3222 3222 3223 3223 3224 2 3225 417 3226 3226 3227 3227 3228 3228 3229 3229 3230 3230 3231 3231 3232 2 3233 728 3234 2 3235 3235 3236 3236 3237 3237 3238 3238 3239 3239 3240 3240 3241 3241 3242 3242 3243 3243 3244 3244 3245 845 3246 3246 3247 3247 3248 3248 3249 3249 3250 3250 3251 3251 3252 3252 3253 3253 3254 3254 3255 3255 3256 3256 3257 3257 3258 3258 3259 3259 3260 3260 3261 3261 3262 3262 3263 3263 3264 3264 3265 3265 3266 3266 3267 3267 3268 3268 3269 3269 3270 3270 3271 3271 3272 3272 3273 3273 3274 3274 3275 3275 3276 3276 3277 3277 3278 3278 3279 3279 3280 3280 3281 3281 3282 3282 3283 3283 3284 3284 3285 3285 3286 3286 3287 3287 3288 3288 3289 3289 3290 3290 3291 3291 3292 3292 3293 3293 3294 3294 3295 3295 3296 3296 3297 3297 3298 3298 3299 3299 3300 3300 3301 3301 3302 3302 3303 3303 3304 3304 3305 3305 3306 3306 3307 3307 3308 3308 3309 3309 3310 3310 3311 3311 3312 3312 3313 3313 3314 3314 3315 3315 3316 3316 3317 3317 3318 3318 3319 3319 3320 3320 3321 3321 3322 3322 3323 3323 3324 3324 3325 11 3326 3326 3327 3327 3328 3328 3329 2 3330 417 3331 3331 3332 932 3333 3333 3334 3334 3335 965 3336 154 3337 157 3338 3338 3339 3339 3340 1476 3341 2 3342 2 3343 2 3344 3344 3345 2 3346 3346 3347 2 3348 2 3349 2 3350 2 3351 2 3352 2 3353 2 3354 2 3355 2 3356 3356 3357 3357 3358 3358 3359 3359 3360 3360 3361 3361 3362 3362 3363 3363 3364 3364 3365 3365 3366 3366 3367 3367 3368 3368 3369 22 3370 3370 3371 4 3372 11 3373 3373 3374 88 3375 11 3376 3376 3377 98 3378 3378 3379 1538 3380 3380 3381 3381 3382 3382 3383 98 3384 845 3385 11 3386 3386 3387 932 3388 3388 3389 3389 3390 965 3391 154 3392 157 3393 3393 3394 3394 3395 3395 3396 845 3397 11 3398 3398 3399 3399 3400 3400 3401 350 3402 350 3403 353 3404 2 3405 417 3406 3406 3407 569 3408 3408 3409 3409 3410 3410 3411 3411 3412 2 3413 417 3414 3414 3415 3415 3416 3416 3417 3417 3418 3418 3419 3419 3420 2 3421 417 3422 3422 3423 3423 3424 138 3425 11 3426 140 3427 157 3428 158 3429 160 3430 162 3431 76 3432 124 3433 165 3434 3434 3435 3435 3436 138 3437 11 3438 140 3439 157 3440 2240 3441 2242 3442 2243 3443 2244 3444 2 3445 3445 3446 3446 3447 3447 3448 845 3449 3449 3450 11 3451 3451 3452 2 3453 417 3454 3454 3455 3455 3456 3456 3457 2727 3458 3458 3459 3459 3460 350 3461 350 3462 353 3463 2 3464 417 3465 3465 3466 569 3467 3467 3468 3468 3469 3469 3470 3470 3471 2 3472 417 3473 3473 3474 3474 3475 3475 3476 3476 3477 2804 3478 3478 3479 569 3480 3480 3481 2 3482 3482 3483 3483 3484 2 3485 3 3486 4 3487 2 3488 2 3489 2 3490 2 3491 11 3492 2 3493 2 3494 3494 3495 2 3496 3496 3497 22 3498 3498 3499 3499 3500 2 3501 11 3502 11 3503 3503 3504 3504 3505 3505 3506 22 3507 2 3508 2 3509 2 3510 11 3511 3511 3512 11 3513 3513 3514 11 3515 3515 3516 3516 3517 3517 3518 3518 3519 60 3520 3520 3521 2 3522 2 3523 11 3524 2 3525 2 3526 68 3527 129 3528 3528 3529 2 3530 2 3531 3531 3532 2 3533 3533 3534 3534 3535 2 3536 84 3537 85 3538 88 3539 132 3540 11 3541 3541 3542 3542 3543 98 3544 3544 3545 3545 3546 3546 3547 103 3548 103 3549 3549 3550 3550 3551 3551 3552 3552 3553 3553 3554 3554 3555 3555 3556 3556 3557 3557 3558 3558 3559 98 3560 2 3561 3561 3562 2 3563 2 3564 2 3565 2 3566 2 3567 2 3568 2 3569 2 3570 300 3571 2 3572 2 3573 2 3574 2 3575 2 3576 306 3577 2 3578 2 3579 2 3580 2 3581 2 3582 2 3583 2 3584 2 3585 2 3586 2 3587 2 3588 2 3589 2 3590 2 3591 2 3592 3592 3593 3593 3594 3594 3595 3595 3596 3596 3597 3597 3598 3598 3599 3599 3600 3600 3601 3601 3602 3602 3603 3603 3604 3604 3605 3605 3606 3606 3607 4 3608 2 3609 3609 3610 3610 3611 3611 3612 3612 3613 3613 3614 3614 3615 3615 3616 3616 3617 3617 3618 3618 3619 3619 3620 350 3621 350 3622 40 3623 353 3624 2 3625 417 3626 3626 3627 569 3628 3628 3629 3629 3630 3630 3631 3631 3632 3632 3633 2 3634 417 3635 3635 3636 3636 3637 40 3638 3638 3639 276 3640 3640 3641 3641 3642 2 3643 417 3644 3644 3645 3645 3646 3646 3647 3647 3648 3648 3649 3649 3650 2 3651 728 3652 2 3653 3653 3654 3654 3655 3655 3656 3656 3657 3657 3658 3658 3659 3659 3660 3660 3661 3661 3662 3662 3663 845 3664 3664 3665 3665 3666 3666 3667 3667 3668 3668 3669 3669 3670 3670 3671 3671 3672 3672 3673 3673 3674 3674 3675 3675 3676 3676 3677 3677 3678 3678 3679 3679 3680 3680 3681 3681 3682 3682 3683 3683 3684 3684 3685 3685 3686 3686 3687 3687 3688 3688 3689 3689 3690 3690 3691 3691 3692 3692 3693 3693 3694 3694 3695 3695 3696 3696 3697 3697 3698 3698 3699 3699 3700 3700 3701 3701 3702 3702 3703 3703 3704 3704 3705 3705 3706 3706 3707 3707 3708 3708 3709 3709 3710 3710 3711 3711 3712 3712 3713 3713 3714 3714 3715 3715 3716 3716 3717 3717 3718 3718 3719 3719 3720 3720 3721 3721 3722 3722 3723 3723 3724 3724 3725 3725 3726 3726 3727 3727 3728 3728 3729 3729 3730 3730 3731 3731 3732 3732 3733 3733 3734 3734 3735 3735 3736 3736 3737 3737 3738 3738 3739 3739 3740 3740 3741 3741 3742 3742 3743 11 3744 3744 3745 3745 3746 3746 3747 2 3748 417 3749 3749 3750 932 3751 3751 3752 3752 3753 965 3754 154 3755 157 3756 3756 3757 3757 3758 1476 3759 2 3760 2 3761 2 3762 3762 3763 2 3764 3764 3765 2 3766 2 3767 2 3768 2 3769 2 3770 2 3771 2 3772 2 3773 2 3774 3774 3775 3775 3776 3776 3777 3777 3778 3778 3779 3779 3780 3780 3781 3781 3782 3782 3783 3783 3784 3784 3785 3785 3786 3786 3787 22 3788 3788 3789 4 3790 11 3791 3791 3792 88 3793 11 3794 3794 3795 98 3796 3796 3797 1538 3798 3798 3799 3799 3800 3800 3801 98 3802 845 3803 11 3804 3804 3805 932 3806 3806 3807 3807 3808 965 3809 154 3810 157 3811 3811 3812 3812 3813 3813 3814 845 3815 11 3816 3816 3817 3817 3818 3818 3819 350 3820 350 3821 353 3822 2 3823 417 3824 3824 3825 569 3826 3826 3827 3827 3828 3828 3829 3829 3830 2 3831 417 3832 3832 3833 3833 3834 3834 3835 3835 3836 3836 3837 3837 3838 2 3839 417 3840 3840 3841 3841 3842 138 3843 11 3844 140 3845 157 3846 158 3847 160 3848 162 3849 76 3850 124 3851 165 3852 3852 3853 3853 3854 138 3855 11 3856 140 3857 157 3858 2240 3859 2242 3860 2243 3861 2244 3862 2 3863 3863 3864 3864 3865 2 3866 3866 3867 845 3868 3868 3869 11 3870 3870 3871 2 3872 417 3873 3873 3874 3874 3875 3875 3876 2727 3877 3877 3878 3878 3879 350 3880 350 3881 353 3882 2 3883 417 3884 3884 3885 569 3886 3886 3887 3887 3888 3888 3889 3889 3890 2 3891 417 3892 3892 3893 3893 3894 3894 3895 3895 3896 2804 3897 3897 3898 569 3899 3899 3900 2 3901 3901 3902 3902 3903 3546 3904 2 3905 3905 3906 3906 3907 3907 3908 3908 3909 3909 3910 2898 3911 3911 3912 68 3913 3913 3914 3914 3915 3915 3916 3916 3917 3917 3918 3918 3919 3919 3920 2 3921 3921 3922 3922 3923 3923 3924 3924 3925 3925 3926 3926 3927 2942 3928 2944 3929 3929 3930 3930 3931 3931 3932 3932 3933 3933 3934 350 3935 350 3936 40 3937 353 3938 2 3939 417 3940 3940 3941 569 3942 3942 3943 3943 3944 3944 3945 3945 3946 932 3947 3947 3948 3948 3949 3949 3950 965 3951 154 3952 157 3953 3953 3954 3954 3955 40 3956 3956 3957 3957 3958 2981 3959 2984 3960 2986 3961 2988 3962 76 3963 2990 3964 2991 3965 3965 3966 276 3967 3967 3968 2 3969 276 3970 76 3971 3971 3972 2 3973 3 3974 4 3975 2 3976 2 3977 2 3978 2 3979 11 3980 2 3981 2 3982 3982 3983 2 3984 3984 3985 22 3986 3986 3987 3987 3988 3988 3989 2 3990 11 3991 11 3992 3992 3993 3993 3994 3994 3995 22 3996 2 3997 2 3998 2 3999 11 4000 4000 4001 11 4002 4002 4003 11 4004 4004 4005 4005 4006 4006 4007 4007 4008 60 4009 4009 4010 2 4011 2 4012 11 4013 2 4014 2 4015 68 4016 129 4017 4017 4018 2 4019 2 4020 4020 4021 2 4022 4022 4023 4023 4024 2 4025 84 4026 85 4027 88 4028 132 4029 11 4030 4030 4031 4031 4032 98 4033 4033 4034 4034 4035 4035 4036 103 4037 103 4038 4038 4039 4039 4040 4040 4041 4041 4042 4042 4043 3986 4044 2829 4045 4045 4046 4046 4047 4047 4048 4048 4049 4049 4050 4050 4051 4051 4052 98 4053 2 4054 4054 4055 2 4056 2 4057 2 4058 2 4059 2 4060 2 4061 2 4062 2 4063 300 4064 2 4065 2 4066 2 4067 2 4068 2 4069 306 4070 2 4071 2 4072 2 4073 2 4074 2 4075 2 4076 2 4077 2 4078 2 4079 2 4080 2 4081 2 4082 2 4083 2 4084 2 4085 4085 4086 4086 4087 4087 4088 4088 4089 4089 4090 4090 4091 4091 4092 4092 4093 4093 4094 4094 4095 4095 4096 4096 4097 4097 4098 4098 4099 4099 4100 4 4101 2 4102 4102 4103 4103 4104 4104 4105 4105 4106 4106 4107 4107 4108 4108 4109 4109 4110 4110 4111 4111 4112 4112 4113 350 4114 350 4115 40 4116 353 4117 2 4118 417 4119 4119 4120 569 4121 4121 4122 4122 4123 4123 4124 4124 4125 4125 4126 2 4127 417 4128 4128 4129 4129 4130 40 4131 4131 4132 276 4133 4133 4134 4134 4135 2 4136 417 4137 4137 4138 4138 4139 4139 4140 4140 4141 4141 4142 4142 4143 2 4144 728 4145 2 4146 4146 4147 4147 4148 4148 4149 4149 4150 4150 4151 4151 4152 4152 4153 4153 4154 4154 4155 4155 4156 845 4157 4157 4158 4158 4159 4159 4160 4160 4161 4161 4162 4162 4163 4163 4164 4164 4165 4165 4166 4166 4167 4167 4168 4168 4169 4169 4170 4170 4171 4171 4172 4172 4173 4173 4174 4174 4175 4175 4176 4176 4177 4177 4178 4178 4179 4179 4180 4180 4181 4181 4182 4182 4183 4183 4184 4184 4185 4185 4186 4186 4187 4187 4188 4188 4189 4189 4190 4190 4191 4191 4192 4192 4193 4193 4194 4194 4195 4195 4196 4196 4197 4197 4198 4198 4199 4199 4200 4200 4201 4201 4202 4202 4203 4203 4204 4204 4205 4205 4206 4206 4207 4207 4208 4208 4209 4209 4210 4210 4211 4211 4212 4212 4213 4213 4214 4214 4215 4215 4216 4216 4217 4217 4218 4218 4219 4219 4220 4220 4221 4221 4222 4222 4223 4223 4224 4224 4225 4225 4226 4226 4227 4227 4228 4228 4229 4229 4230 4230 4231 4231 4232 4232 4233 4233 4234 4234 4235 4235 4236 11 4237 4237 4238 4238 4239 4239 4240 2 4241 417 4242 4242 4243 932 4244 4244 4245 4245 4246 965 4247 154 4248 157 4249 4249 4250 4250 4251 1476 4252 2 4253 2 4254 2 4255 4255 4256 2 4257 4257 4258 2 4259 2 4260 2 4261 2 4262 2 4263 2 4264 2 4265 2 4266 2 4267 4267 4268 4268 4269 4269 4270 4270 4271 4271 4272 4272 4273 4273 4274 4274 4275 4275 4276 4276 4277 4277 4278 4278 4279 4279 4280 22 4281 4281 4282 4 4283 11 4284 4284 4285 88 4286 11 4287 4287 4288 98 4289 4289 4290 1538 4291 4291 4292 4292 4293 4293 4294 98 4295 845 4296 11 4297 4297 4298 932 4299 4299 4300 4300 4301 965 4302 154 4303 157 4304 4304 4305 4305 4306 4306 4307 845 4308 11 4309 4309 4310 4310 4311 4311 4312 350 4313 350 4314 353 4315 2 4316 417 4317 4317 4318 569 4319 4319 4320 4320 4321 4321 4322 4322 4323 2 4324 417 4325 4325 4326 4326 4327 4327 4328 4328 4329 4329 4330 4330 4331 2 4332 417 4333 4333 4334 4334 4335 4335 4336 4336 4337 4337 4338 4338 4339 4339 4340 2242 4341 2 4342 2 4343 3 4344 4 4345 2 4346 2 4347 2 4348 2 4349 11 4350 2 4351 2 4352 4352 4353 2 4354 4354 4355 22 4356 4356 4357 4357 4358 2 4359 11 4360 11 4361 4361 4362 4362 4363 4363 4364 22 4365 2 4366 2 4367 2 4368 11 4369 4369 4370 11 4371 4371 4372 11 4373 4373 4374 4374 4375 4375 4376 4376 4377 60 4378 4378 4379 2 4380 2 4381 11 4382 2 4383 2 4384 68 4385 129 4386 4386 4387 2 4388 2 4389 4389 4390 2 4391 4391 4392 4392 4393 2 4394 84 4395 85 4396 88 4397 132 4398 11 4399 4399 4400 4400 4401 98 4402 4402 4403 4403 4404 4404 4405 103 4406 103 4407 4407 4408 4408 4409 4409 4410 4410 4411 4411 4412 4412 4413 4413 4414 4414 4415 4415 4416 4416 4417 98 4418 2 4419 4419 4420 2 4421 2 4422 2 4423 2 4424 2 4425 2 4426 2 4427 2 4428 300 4429 2 4430 2 4431 2 4432 2 4433 2 4434 306 4435 2 4436 2 4437 2 4438 2 4439 2 4440 2 4441 2 4442 2 4443 2 4444 2 4445 2 4446 2 4447 2 4448 2 4449 2 4450 4450 4451 4451 4452 4452 4453 4453 4454 4454 4455 4455 4456 4456 4457 4457 4458 4458 4459 4459 4460 4460 4461 4461 4462 4462 4463 4463 4464 4464 4465 4 4466 2 4467 4467 4468 4468 4469 4469 4470 4470 4471 4471 4472 4472 4473 4473 4474 4474 4475 4475 4476 4476 4477 4477 4478 350 4479 350 4480 40 4481 353 4482 2 4483 417 4484 4484 4485 569 4486 4486 4487 4487 4488 4488 4489 4489 4490 4490 4491 2 4492 417 4493 4493 4494 4494 4495 40 4496 4496 4497 276 4498 4498 4499 4499 4500 2 4501 417 4502 4502 4503 4503 4504 4504 4505 4505 4506 4506 4507 4507 4508 2 4509 728 4510 2 4511 4511 4512 4512 4513 4513 4514 4514 4515 4515 4516 4516 4517 4517 4518 4518 4519 4519 4520 4520 4521 845 4522 4522 4523 4523 4524 4524 4525 4525 4526 4526 4527 4527 4528 4528 4529 4529 4530 4530 4531 4531 4532 4532 4533 4533 4534 4534 4535 4535 4536 4536 4537 4537 4538 4538 4539 4539 4540 4540 4541 4541 4542 4542 4543 4543 4544 4544 4545 4545 4546 4546 4547 4547 4548 4548 4549 4549 4550 4550 4551 4551 4552 4552 4553 4553 4554 4554 4555 4555 4556 4556 4557 4557 4558 4558 4559 4559 4560 4560 4561 4561 4562 4562 4563 4563 4564 4564 4565 4565 4566 4566 4567 4567 4568 4568 4569 4569 4570 4570 4571 4571 4572 4572 4573 4573 4574 4574 4575 4575 4576 4576 4577 4577 4578 4578 4579 4579 4580 4580 4581 4581 4582 4582 4583 4583 4584 4584 4585 4585 4586 4586 4587 4587 4588 4588 4589 4589 4590 4590 4591 4591 4592 4592 4593 4593 4594 4594 4595 4595 4596 4596 4597 4597 4598 4598 4599 4599 4600 4600 4601 11 4602 4602 4603 4603 4604 4604 4605 2 4606 417 4607 4607 4608 932 4609 4609 4610 4610 4611 965 4612 154 4613 157 4614 4614 4615 4615 4616 1476 4617 2 4618 2 4619 2 4620 4620 4621 2 4622 4622 4623 2 4624 2 4625 2 4626 2 4627 2 4628 2 4629 2 4630 2 4631 2 4632 4632 4633 4633 4634 4634 4635 4635 4636 4636 4637 4637 4638 4638 4639 4639 4640 4640 4641 4641 4642 4642 4643 4643 4644 4644 4645 22 4646 4646 4647 4 4648 11 4649 4649 4650 88 4651 11 4652 4652 4653 98 4654 4654 4655 1538 4656 4656 4657 4657 4658 4658 4659 98 4660 845 4661 11 4662 4662 4663 932 4664 4664 4665 4665 4666 965 4667 154 4668 157 4669 4669 4670 4670 4671 4671 4672 845 4673 11 4674 4674 4675 4675 4676 4676 4677 350 4678 350 4679 353 4680 2 4681 417 4682 4682 4683 569 4684 4684 4685 4685 4686 4686 4687 4687 4688 2 4689 417 4690 4690 4691 4691 4692 4692 4693 4693 4694 4694 4695 4695 4696 2 4697 417 4698 4698 4699 4699 4700 138 4701 11 4702 140 4703 157 4704 158 4705 160 4706 162 4707 76 4708 124 4709 165 4710 4710 4711 4711 4712 138 4713 11 4714 140 4715 157 4716 2240 4717 2242 4718 2243 4719 2244 4720 2 4721 4721 4722 4722 4723 845 4724 4724 4725 11 4726 4726 4727 2 4728 417 4729 4729 4730 4730 4731 4731 4732 2727 4733 4733 4734 4734 4735 350 4736 350 4737 353 4738 2 4739 417 4740 4740 4741 569 4742 4742 4743 4743 4744 4744 4745 4745 4746 2 4747 417 4748 4748 4749 4749 4750 4750 4751 4751 4752 2804 4753 4753 4754 569 4755 4755 4756 2 4757 4757 4758 4758 4759 2 4760 3 4761 4 4762 2 4763 2 4764 2 4765 2 4766 11 4767 2 4768 2 4769 4769 4770 2 4771 4771 4772 22 4773 4773 4774 4774 4775 2 4776 11 4777 11 4778 4778 4779 4779 4780 4780 4781 22 4782 2 4783 2 4784 2 4785 11 4786 4786 4787 11 4788 4788 4789 11 4790 4790 4791 4791 4792 4792 4793 4793 4794 60 4795 4795 4796 2 4797 2 4798 11 4799 2 4800 2 4801 68 4802 129 4803 4803 4804 2 4805 2 4806 4806 4807 2 4808 4808 4809 4809 4810 2 4811 84 4812 85 4813 88 4814 132 4815 11 4816 4816 4817 4817 4818 98 4819 4819 4820 4820 4821 4821 4822 103 4823 103 4824 4824 4825 4825 4826 4826 4827 4827 4828 4828 4829 4829 4830 4830 4831 4831 4832 4832 4833 4833 4834 98 4835 2 4836 4836 4837 2 4838 2 4839 2 4840 2 4841 2 4842 2 4843 2 4844 2 4845 300 4846 2 4847 2 4848 2 4849 2 4850 2 4851 306 4852 2 4853 2 4854 2 4855 2 4856 2 4857 2 4858 2 4859 2 4860 2 4861 2 4862 2 4863 2 4864 2 4865 2 4866 2 4867 4867 4868 4868 4869 4869 4870 4870 4871 4871 4872 4872 4873 4873 4874 4874 4875 4875 4876 4876 4877 4877 4878 4878 4879 4879 4880 4880 4881 4881 4882 4 4883 2 4884 4884 4885 4885 4886 4886 4887 4887 4888 4888 4889 4889 4890 4890 4891 4891 4892 4892 4893 4893 4894 4894 4895 350 4896 350 4897 40 4898 353 4899 2 4900 417 4901 4901 4902 569 4903 4903 4904 4904 4905 4905 4906 4906 4907 4907 4908 2 4909 417 4910 4910 4911 4911 4912 40 4913 4913 4914 276 4915 4915 4916 4916 4917 2 4918 417 4919 4919 4920 4920 4921 4921 4922 4922 4923 4923 4924 4924 4925 2 4926 728 4927 2 4928 4928 4929 4929 4930 4930 4931 4931 4932 4932 4933 4933 4934 4934 4935 4935 4936 4936 4937 4937 4938 845 4939 4939 4940 4940 4941 4941 4942 4942 4943 4943 4944 4944 4945 4945 4946 4946 4947 4947 4948 4948 4949 4949 4950 4950 4951 4951 4952 4952 4953 4953 4954 4954 4955 4955 4956 4956 4957 4957 4958 4958 4959 4959 4960 4960 4961 4961 4962 4962 4963 4963 4964 4964 4965 4965 4966 4966 4967 4967 4968 4968 4969 4969 4970 4970 4971 4971 4972 4972 4973 4973 4974 4974 4975 4975 4976 4976 4977 4977 4978 4978 4979 4979 4980 4980 4981 4981 4982 4982 4983 4983 4984 4984 4985 4985 4986 4986 4987 4987 4988 4988 4989 4989 4990 4990 4991 4991 4992 4992 4993 4993 4994 4994 4995 4995 4996 4996 4997 4997 4998 4998 4999 4999 5000 5000 5001 5001 5002 5002 5003 5003 5004 5004 5005 5005 5006 5006 5007 5007 5008 5008 5009 5009 5010 5010 5011 5011 5012 5012 5013 5013 5014 5014 5015 5015 5016 5016 5017 5017 5018 11 5019 5019 5020 5020 5021 5021 5022 2 5023 417 5024 5024 5025 932 5026 5026 5027 5027 5028 965 5029 154 5030 157 5031 5031 5032 5032 5033 1476 5034 2 5035 2 5036 2 5037 5037 5038 2 5039 5039 5040 2 5041 2 5042 2 5043 2 5044 2 5045 2 5046 2 5047 2 5048 2 5049 5049 5050 5050 5051 5051 5052 5052 5053 5053 5054 5054 5055 5055 5056 5056 5057 5057 5058 5058 5059 5059 5060 5060 5061 5061 5062 22 5063 5063 5064 4 5065 11 5066 5066 5067 88 5068 11 5069 5069 5070 98 5071 5071 5072 1538 5073 5073 5074 5074 5075 5075 5076 98 5077 845 5078 11 5079 5079 5080 932 5081 5081 5082 5082 5083 965 5084 154 5085 157 5086 5086 5087 5087 5088 5088 5089 845 5090 11 5091 5091 5092 5092 5093 5093 5094 350 5095 350 5096 353 5097 2 5098 417 5099 5099 5100 569 5101 5101 5102 5102 5103 5103 5104 5104 5105 2 5106 417 5107 5107 5108 5108 5109 5109 5110 5110 5111 5111 5112 5112 5113 2 5114 417 5115 5115 5116 5116 5117 138 5118 11 5119 140 5120 157 5121 158 5122 160 5123 162 5124 76 5125 124 5126 165 5127 5127 5128 5128 5129 138 5130 11 5131 140 5132 157 5133 2240 5134 2242 5135 2243 5136 2244 5137 2 5138 5138 5139 5139 5140 2 5141 5141 5142 845 5143 5143 5144 11 5145 5145 5146 2 5147 417 5148 5148 5149 5149 5150 5150 5151 2727 5152 5152 5153 5153 5154 350 5155 350 5156 353 5157 2 5158 417 5159 5159 5160 569 5161 5161 5162 5162 5163 5163 5164 5164 5165 2 5166 417 5167 5167 5168 5168 5169 5169 5170 5170 5171 2804 5172 5172 5173 569 5174 5174 5175 2 5176 5176 5177 5177 5178 4821 5179 2 5180 5180 5181 5181 5182 5182 5183 5183 5184 5184 5185 2898 5186 5186 5187 68 5188 5188 5189 5189 5190 5190 5191 5191 5192 5192 5193 5193 5194 5194 5195 2 5196 5196 5197 5197 5198 5198 5199 5199 5200 5200 5201 5201 5202 2942 5203 2944 5204 5204 5205 5205 5206 5206 5207 5207 5208 5208 5209 350 5210 350 5211 40 5212 353 5213 2 5214 417 5215 5215 5216 569 5217 5217 5218 5218 5219 5219 5220 5220 5221 932 5222 5222 5223 5223 5224 5224 5225 965 5226 154 5227 157 5228 5228 5229 5229 5230 40 5231 5231 5232 5232 5233 2981 5234 2984 5235 2986 5236 2988 5237 76 5238 2990 5239 2991 5240 5240 5241 276 5242 5242 5243 2 5244 276 5245 76 5246 3971 5247 2829 5248 5248 5249 1851 5250 157 5251 2040 5252 2 5253 5253 5254 2 5255 5255 5256 5256 5257 154 5258 5258 5259 157 5260 5260 5261 5261 5262 5262 5263 5263 5264 5264 5265 5265 5266 5266 5267 5267 5268 5268 5269 157 5270 5270 5271 2 5272 276 5273 5273 5274 2 5275 276 5276 5276 5277 5277 5278 5278 5279 5279 5280 5280 5281 5281 5282 1851 5283 157 5284 5284 5285 5285 5286 5286 5287 5287 5288 276 5289 5289 5290 5290 5291 2 5292 417 5293 5293 5294 22 5295 2801 5296 5296 5297 5297 5298 5298 5299 5299 5300 5300 5301 5301 5302 5302 5303 16 5304 16 5305 2812 5306 569 5307 5307 5308 5308 5309 5309 5310 5310 5311 2823 5312 417 5313 5313 5314 2 5315 5315 5316 2828 5317 2829 5318 5318 5319 2842 5320 5320 5321 5321 5322 5322 5323 5323 5324 5324 5325 5325 5326 2898 5327 5327 5328 68 5329 5329 5330 5330 5331 5331 5332 5332 5333 5333 5334 5334 5335 5335 5336 2 5337 5337 5338 5338 5339 5339 5340 5340 5341 5341 5342 5342 5343 2942 5344 2944 5345 5345 5346 5346 5347 5347 5348 5348 5349 5349 5350 350 5351 350 5352 40 5353 353 5354 2 5355 417 5356 5356 5357 569 5358 5358 5359 5359 5360 5360 5361 5361 5362 932 5363 5363 5364 5364 5365 5365 5366 965 5367 154 5368 157 5369 5369 5370 5370 5371 40 5372 5372 5373 5373 5374 2981 5375 2984 5376 2986 5377 2988 5378 76 5379 2990 5380 2991 5381 5381 5382 276 5383 5383 5384 2 5385 276 5386 76 5387 3971 5388 2829 5389 5389 5390 1851 5391 157 5392 2040 5393 2 5394 5394 5395 2 5396 154 5397 157 5398 5398 5399 5399 5400 5400 5401 5401 5402 5402 5403 5266 5404 5404 5405 157 5406 5406 5407 2 5408 276 5409 5409 5410 2 5411 276 5412 5412 5413 5413 5414 5414 5415 5415 5416 5416 5417 5417 5418 1851 5419 157 5420 5420 5421 5421 5422 5422 5423 5423 5424 276 5425 5425 5426 5426 5427 2 5428 417 5429 5429 5430 5298 5431 5431 5432 5432 5433 5433 5434 138 5435 11 5436 140 5437 157 5438 158 5439 160 5440 162 5441 76 5442 124 5443 165 5444 5444 5445 5445 5446 138 5447 11 5448 140 5449 157 5450 2240 5451 2242 5452 2243 5453 2244 5454 2 5455 5455 5456 5456 5457 845 5458 5458 5459 11 5460 5460 5461 2 5462 417 5463 5463 5464 5464 5465 5465 5466 2727 5467 5467 5468 5468 5469 350 5470 350 5471 353 5472 2 5473 417 5474 5474 5475 569 5476 5476 5477 5477 5478 5478 5479 5479 5480 2 5481 417 5482 5482 5483 5483 5484 5484 5485 5485 5486 2804 5487 5487 5488 569 5489 5489 5490 2 5491 5491 5492 5492 5493 5493 5494 2 5495 5495 5496 5496 5497 5497 5498 5498 5499 5499 5500 2898 5501 5501 5502 68 5503 5503 5504 5504 5505 5505 5506 5506 5507 5507 5508 5508 5509 5509 5510 2 5511 5511 5512 5512 5513 5513 5514 5514 5515 5515 5516 5516 5517 2942 5518 2944 5519 5519 5520 5520 5521 5521 5522 5522 5523 5523 5524 350 5525 350 5526 40 5527 353 5528 2 5529 417 5530 5530 5531 569 5532 5532 5533 5533 5534 5534 5535 5535 5536 932 5537 5537 5538 5538 5539 5539 5540 965 5541 154 5542 157 5543 5543 5544 5544 5545 40 5546 5546 5547 5547 5548 2981 5549 2984 5550 2986 5551 2988 5552 76 5553 2990 5554 2991 5555 5555 5556 276 5557 5557 5558 2 5559 276 5560 76 5561 3971 5562 2829 5563 5563 5564 1851 5565 157 5566 2040 5567 2 5568 5568 5569 2 5570 154 5571 157 5572 5572 5573 5573 5574 5574 5575 5575 5576 5576 5577 5266 5578 5578 5579 157 5580 5580 5581 2 5582 276 5583 5583 5584 2 5585 276 5586 5586 5587 5587 5588 5588 5589 2242 5590 2 5591 5591 5592 5592 5593 5593 5594 5594 5595 5595 5596 1851 5597 157 5598 5598 5599 5599 5600 5600 5601 5601 5602 276 5603 5603 5604 5604 5605 2 5606 417 5607 5607 5608 5298 5609 5609 5610 5610 5611 1851 5612 157 5613 2040 5614 2 5615 5615 5616 2 5617 154 5618 157 5619 5619 5620 5620 5621 5621 5622 5622 5623 5623 5624 5266 5625 5625 5626 157 5627 5627 5628 2 5629 276 5630 5630 5631 2 5632 276 5633 5633 5634 5634 5635 5635 5636 5636 5637 5637 5638 5638 5639 1851 5640 157 5641 5641 5642 5642 5643 5643 5644 5644 5645 276 5646 5646 5647 5647 5648 2 5649 417 5650 5650 5651 5298 5652 5652 5653 5653 5654 5654 5655 5655 5656 5656 5657 5657 5658 2898 5659 5659 5660 68 5661 5661 5662 5662 5663 5663 5664 5664 5665 5665 5666 5666 5667 5667 5668 2 5669 5669 5670 5670 5671 5671 5672 5672 5673 5673 5674 5674 5675 2942 5676 2944 5677 5677 5678 5678 5679 5679 5680 5680 5681 5681 5682 350 5683 350 5684 40 5685 353 5686 2 5687 417 5688 5688 5689 569 5690 5690 5691 5691 5692 5692 5693 5693 5694 932 5695 5695 5696 5696 5697 5697 5698 965 5699 154 5700 157 5701 5701 5702 5702 5703 40 5704 5704 5705 5705 5706 2981 5707 2984 5708 2986 5709 2988 5710 76 5711 2990 5712 2991 5713 5713 5714 276 5715 5715 5716 2 5717 276 5718 76 5719 3971 5720 2829 5721 5721 5722 1851 5723 157 5724 2040 5725 2 5726 5726 5727 2 5728 154 5729 157 5730 5730 5731 5731 5732 5732 5733 5733 5734 5734 5735 5266 5736 5736 5737 157 5738 5738 5739 2 5740 276 5741 5741 5742 2 5743 276 5744 5744 5745 5745 5746 5746 5747 5747 5748 5748 5749 5749 5750 1851 5751 157 5752 5752 5753 5753 5754 5754 5755 5755 5756 276 5757 5757 5758 5758 5759 2 5760 417 5761 5761 5762 5298 5763 5763 5764 5764 5765 3014 5766 5766 5767 5767 5768 5768 5769 5769 5770 5770 5771 5771 5772 5772 5773 5773 5774 5774 5775 2284 5776 5776 5777 5777 5778 5778 5779 5779 5780 5780 5781 5781 5782 5782 5783 5783 5784 5784 5785 5785 5786 5786 5787 5787 5788 5788 5789 5789 5790 5790 5791 5791 5792 5792 5793 5793 5794 5794 5795 5795 5796 5796 5797 5797 5798 5798 5799 5799 5800 5800 5801 5801 5802 5802 5803 5803 5804 5804 5805 5805 5806 5806 5807 5807 5808 5808 5809 5809 5810 5810 5811 5811 5812 5812 5813 5813 5814 5814 5815 5815 5816 5816 5817 5817 5818 5818 5819 5819 5820 5820 5821 5821 5822 5822 5823 5823 5824 5824 5825 5825 5826 5826 5827 5827 5828 5828 5829 5829 5830 5830 5831 5831 5832 5832 5833 5833 5834 5834 5835 5835 5836 5836 5837 5837 5838 5838 5839 5839 5840 5840 5841 5841 5842 5842 5843 5843 5844 5844 5845 5845 5846 5846 5847 5847 5848 5848 5849 5849 5850 5850 5851 5851 5852 5852 5853 5853 5854 5854 5855 5855 5856 5856 5857 5857 5858 5858 5859 5859 5860 5860 5861 5861 5862 138 5863 5863 5864 5864 5865 11 5866 140 5867 157 5868 5868 5869 161 5870 5870 5871 5871 5872 5872 5873 5873 5874 124 5875 165 5876 5876 5877 5877 5878 2248 5879 5879 5880 5880 5881 5881 5882 5882 5883 5883 5884 5884 5885 5885 5886 5886 5887 5887 5888 5888 5889 5889 5890 5890 5891 5891 5892 2263 5893 2264 5894 2248 5895 5895 5896 5896 5897 5897 5898 5898 5899 5899 5900 5900 5901 5901 5902 5902 5903 5903 5904 5904 5905 5905 5906 2284 5907 5907 5908 2264 5909 5909 5910 2248 5911 5911 5912 5912 5913 5913 5914 5914 5915 5915 5916 5916 5917 5917 5918 5918 5919 5919 5920 5920 5921 2248 5922 5922 5923 5923 5924 5924 5925 5925 5926 5926 5927 5927 5928 5928 5929 5929 5930 5930 5931 5931 5932 5932 5933 5933 5934 2248 5935 5935 5936 5936 5937 5937 5938 5938 5939 5939 5940 5940 5941 5941 5942 5942 5943 5943 5944 5944 5945 5945 5946 5946 5947 5947 5948 5948 5949 5949 5950 5950 5951 5951 5952 5952 5953 5953 5954 5954 5955 5955 5956 5956 5957 5957 5958 5958 5959 5959 5960 5960 5961 5961 5962 5962 5963 5963 5964 5964 5965 5965 5966 5966 5967 5967 5968 5968 5969 5969 5970 5970 5971 5971 5972 5972 5973 5973 5974 5974 5975 5975 5976 5976 5977 5977 5978 5978 5979 5979 5980 5980 5981 5981 5982 5982 5983 5983 5984 5984 5985 5985 5986 5986 5987 5987 5988 5988 5989 5989 5990 5990 5991 5991 5992 5992 5993 5993 5994 5994 5995 5995 5996 5996 5997 5997 5998 5998 5999 5999 6000 6000 6001 6001 6002 6002 6003 6003 6004 6004 6005 6005 6006 6006 6007 6007 6008 6008 6009 6009 6010 6010 6011 6011 6012 6012 6013 6013 6014 6014 6015 6015 6016 6016 6017 3060 6018 6018 6019 6019 6020 6020 6021 2040 6022 6022 6023 5783 6024 6024 6025 6025 6026 2263 6027 2264 6028 2248 6029 6029 6030 6030 6031 6031 6032 6032 6033 6033 6034 6034 6035 6035 6036 6036 6037 6037 6038 6038 6039 6039 6040 2284 6041 6041 6042 2264 6043 6043 6044 6044 6045 6045 6046 6046 6047 2040 6048 3060 6049 5783 6050 6050 6051 6051 6052 2 6053 3128 6054 6054 6055 2248 6056 6056 6057 6057 6058 6058 6059 6059 6060 6060 6061 6061 6062 6062 6063 6063 6064 6064 6065 6065 6066 2 6067 3128 6068 6068 6069 2248 6070 6070 6071 6071 6072 6072 6073 6073 6074 6074 6075 6075 6076 6076 6077 6077 6078 6078 6079 6079 6080 6080 6081 6081 6082 6082 6083 6083 6084 6084 6085 6085 6086 6086 6087 6087 6088 6088 6089 6089 6090 6090 6091 6091 6092 13 6093 6093 6094 6094 6095 6095 6096 6096 6097 6097 6098 6098 6099 6099 6100 6100 6101 6101 6102 6102 6103 6103 6104 6104 6105 6105 6106 6106 6107 6107 6108 6108 6109 6109 6110 6110 6111 6111 6112 6112 6113 6113 6114 6114 6115 6115 6116 6116 6117 6117 6118 6118 6119 6119 6120 6120 6121 6121 6122 6122 6123 6123 6124 6124 6125 6125 6126 6126 6127 6127 6128 6128 6129 6129 6130 6130 6131 6131 6132 6132 6133 6133 6134 6134 6135 6135 6136 6136 6137 6137 6138 6138 6139 6139 6140 6140 6141 6141 6142 6142 6143 6143 6144 6144 6145 6145 6146 6146 6147 6147 6148 6148 6149 6149 6150 6150 6151 6151 6152 6152 6153 6153 6154 6154 6155 6155 6156 6156 6157 6157 6158 6158 6159 6159 6160 6160 6161 6161 6162 6162 6163 6163 6164 6164 6165 6165 6166 6166 6167 6167 6168 6168 6169 6169 6170 6170 6171 6171 6172 6172 6173 6173 6174 6174 6175 6175 6176 6176 6177 6177 6178 98 6179 6179 6180 6180 6181 6181 6182 6182 6183 6183 6184 6095 6185 6185 6186 6186 6187 6185 6188 6188 6189 6189 6190 5783 6191 6191 6192 6192 6193 6193 6194 6194 6195 6195 6196 6196 6197 6197 6198 6198 6199 6199 6200 6200 6201 6201 6202 6202 6203 6203 6204 6204 6205 6205 6206 6206 6207 6207 6208 6208 6209 6209 6210 6210 6211 6211 6212 6212 6213 6213 6214 6214 6215 6215 6216 6216 6217 6217 6218 6218 6219 6219 6220 6220 6221 6221 6222 6222 6223 6223 6224 6224 6225 6225 6226 6226 6227 6227 6228 6228 6229 6229 6230 6230 6231 6231 6232 6232 6233 6233 6234 6234 6235 6235 6236 6236 6237 6237 6238 6238 6239 6239 6240 6240 6241 6241 6242 6242 6243 6243 6244 6244 6245 6245 6246 6246 6247 6247 6248 6248 6249 6249 6250 6250 6251 6251 6252 6252 6253 6253 6254 6254 6255 6255 6256 6256 6257 6257 6258 6258 6259 6259 6260 6260 6261 6261 6262 6262 6263 6263 6264 6264 6265 6265 6266 6266 6267 6267 6268 6268 6269 6269 6270 6270 6271 6271 6272 6272 6273 6273 6274 6274 6275 6275 6276 6276 6277 6277 6278 6278 6279 6279 6280 6280 6281 6281 6282 6282 6283 6283 6284 6284 6285 5783 6286 6286 6287 6287 6288 6288 6289 6289 6290 6290 6291 6291 6292 6292 6293 6293 6294 6294 6295 6295 6296 6296 6297 6297 6298 6298 6299 6299 6300 6300 6301 6301 6302 6302 6303 6303 6304 6304 6305 6305 6306 6306 6307 6307 6308 6308 6309 6309 6310 6310 6311 6311 6312 6312 6313 6313 6314 6314 6315 6315 6316 6316 6317 6317 6318 6318 6319 6319 6320 6320 6321 6321 6322 6322 6323 6323 6324 6324 6325 6325 6326 6326 6327 6327 6328 6328 6329 6329 6330 6330 6331 6331 6332 6332 6333 6333 6334 6334 6335 6335 6336 6336 6337 6337 6338 6338 6339 6339 6340 6340 6341 6341 6342 6342 6343 6343 6344 6344 6345 6345 6346 6346 6347 6347 6348 6348 6349 6349 6350 6350 6351 6351 6352 6352 6353 6353 6354 6354 6355 6355 6356 6356 6357 6357 6358 6358 6359 6359 6360 6360 6361 6361 6362 6362 6363 6363 6364 6364 6365 6365 6366 6366 6367 13 6368 6368 6369 6369 6370 6370 6371 6371 6372 6372 6373 6373 6374 6374 6375 6375 6376 13 6377 6377 6378 6378 6379 5783 6380 6380 6381 6381 6382 6382 6383 6383 6384 6384 6385 6385 6386 6386 6387 6387 6388 6388 6389 6389 6390 6390 6391 6391 6392 6392 6393 6393 6394 6394 6395 6395 6396 6396 6397 6397 6398 6398 6399 6399 6400 6400 6401 6401 6402 6402 6403 6403 6404 6404 6405 6405 6406 6406 6407 6407 6408 6408 6409 6409 6410 6410 6411 6411 6412 6412 6413 6413 6414 6414 6415 6415 6416 6416 6417 6417 6418 6418 6419 6419 6420 6420 6421 6421 6422 6422 6423 6423 6424 6424 6425 6425 6426 6426 6427 6427 6428 6428 6429 6429 6430 6430 6431 6431 6432 6432 6433 6433 6434 6434 6435 6435 6436 6436 6437 6437 6438 6438 6439 6439 6440 6440 6441 6441 6442 6442 6443 6443 6444 6444 6445 6445 6446 6446 6447 6447 6448 6448 6449 6449 6450 6450 6451 6451 6452 6452 6453 6453 6454 6454 6455 6455 6456 6456 6457 6457 6458 6458 6459 6459 6460 6460 6461 2 6462 6185 6463 6463 6464 6464 6465 2 6466 2 6467 2 6468 2 6469 2 6470 2 6471 2 6472 2 6473 300 6474 2 6475 2 6476 2 6477 2 6478 2 6479 306 6480 2 6481 2 6482 2 6483 2 6484 2 6485 2 6486 2 6487 2 6488 2 6489 2 6490 2 6491 2 6492 2 6493 2 6494 2 6495 6495 6496 6496 6497 6497 6498 6498 6499 6499 6500 6500 6501 6501 6502 6502 6503 6503 6504 6504 6505 6505 6506 6506 6507 6507 6508 6508 6509 6509 6510 4 6511 2 6512 6512 6513 6513 6514 6514 6515 6515 6516 6516 6517 6517 6518 6518 6519 6519 6520 6520 6521 6521 6522 6522 6523 350 6524 350 6525 40 6526 353 6527 2 6528 417 6529 6529 6530 569 6531 6531 6532 6532 6533 6533 6534 6534 6535 6535 6536 2 6537 417 6538 6538 6539 6539 6540 40 6541 6541 6542 276 6543 6543 6544 6544 6545 2 6546 417 6547 6547 6548 6548 6549 6549 6550 6550 6551 6551 6552 6552 6553 2 6554 728 6555 2 6556 6556 6557 6557 6558 6558 6559 6559 6560 6560 6561 6561 6562 6562 6563 6563 6564 6564 6565 6565 6566 6566 6567 6567 6568 6568 6569 6569 6570 6570 6571 6571 6572 6572 6573 6573 6574 6574 6575 932 6576 6576 6577 6577 6578 965 6579 154 6580 157 6581 6581 6582 6582 6583 6583 6584 569 6585 6585 6586 6586 6587 6587 6588 6588 6589 6589 6590 6590 6591 6591 6592 6592 6593 6593 6594 6594 6595 13 6596 6596 6597 6597 6598 6598 6599 6599 6600 6600 6601 6601 6602 6602 6603 6603 6604 6604 6605 965 6606 154 6607 157 6608 6608 6609 6609 6610 6610 6611 6572 6612 569 6613 6613 6614 276 6615 6615 6616 2690 6617 2 6618 417 6619 2693 6620 2 6621 276 6622 76 6623 3971 6624 2829 6625 6625 6626 1851 6627 157 6628 6628 6629 2 6630 154 6631 157 6632 6632 6633 6633 6634 6634 6635 6635 6636 6636 6637 5266 6638 6638 6639 157 6640 6640 6641 2 6642 276 6643 6643 6644 2 6645 276 6646 6646 6647 6647 6648 6648 6649 6649 6650 6650 6651 6651 6652 1851 6653 157 6654 6654 6655 6655 6656 6656 6657 6657 6658 276 6659 6659 6660 6660 6661 2 6662 417 6663 6663 6664 5298 6665 6665 6666 6666 6667 845 6668 6668 6669 11 6670 6670 6671 2 6672 417 6673 6673 6674 6674 6675 6675 6676 2727 6677 6677 6678 6678 6679 2040 6680 2 6681 6681 6682 350 6683 350 6684 353 6685 2 6686 417 6687 6687 6688 569 6689 6689 6690 6690 6691 6691 6692 6692 6693 2 6694 417 6695 6695 6696 6696 6697 6697 6698 6698 6699 6699 6700 2804 6701 6701 6702 569 6703 6703 6704 2 6705 6705 6706 6706 6707 1260 6708 2 6709 6709 6710 6710 6711 6711 6712 6712 6713 6713 6714 2898 6715 6715 6716 68 6717 6717 6718 6718 6719 6719 6720 6720 6721 6721 6722 6722 6723 6723 6724 2 6725 6725 6726 6726 6727 6727 6728 6728 6729 6729 6730 6730 6731 2942 6732 2944 6733 6733 6734 6734 6735 6735 6736 6736 6737 6737 6738 350 6739 350 6740 40 6741 353 6742 2 6743 417 6744 6744 6745 569 6746 6746 6747 6747 6748 6748 6749 6749 6750 932 6751 6751 6752 6752 6753 6753 6754 965 6755 154 6756 157 6757 6757 6758 6758 6759 40 6760 6760 6761 6761 6762 2981 6763 2984 6764 2986 6765 2988 6766 76 6767 2990 6768 2991 6769 6769 6770 276 6771 6771 6772 2 6773 276 6774 76 6775 3971 6776 2829 6777 6777 6778 1851 6779 157 6780 6780 6781 2 6782 154 6783 157 6784 6784 6785 6785 6786 6786 6787 6787 6788 6788 6789 5266 6790 6790 6791 157 6792 6792 6793 2 6794 276 6795 6795 6796 2 6797 276 6798 6798 6799 6799 6800 6800 6801 6801 6802 6802 6803 6803 6804 6804 6805 1851 6806 157 6807 6807 6808 6808 6809 6809 6810 6810 6811 276 6812 6812 6813 6813 6814 2 6815 417 6816 6816 6817 5298 6818 6818 6819 6819 6820 845 6821 6821 6822 6822 6823 6823 6824 6824 6825 6825 6826 6826 6827 6827 6828 6828 6829 6829 6830 6830 6831 6831 6832 6832 6833 6833 6834 6834 6835 6835 6836 6836 6837 6837 6838 6838 6839 6839 6840 6840 6841 6841 6842 6842 6843 6843 6844 6844 6845 6845 6846 6846 6847 6847 6848 6848 6849 6849 6850 6850 6851 6851 6852 6852 6853 6853 6854 6854 6855 6855 6856 6856 6857 6857 6858 6858 6859 6859 6860 6860 6861 6861 6862 6862 6863 6863 6864 6864 6865 6865 6866 6866 6867 6867 6868 6868 6869 6869 6870 6870 6871 6871 6872 6872 6873 6873 6874 6874 6875 6875 6876 6876 6877 6877 6878 6878 6879 6879 6880 6880 6881 6881 6882 6882 6883 6883 6884 6884 6885 6885 6886 6886 6887 6887 6888 6888 6889 6889 6890 6890 6891 6891 6892 6892 6893 6893 6894 6894 6895 6895 6896 6896 6897 6897 6898 6898 6899 6899 6900 11 6901 6901 6902 6902 6903 6903 6904 2 6905 417 6906 6906 6907 932 6908 6908 6909 6909 6910 965 6911 154 6912 157 6913 6913 6914 6914 6915 1476 6916 2 6917 2 6918 2 6919 6919 6920 2 6921 6921 6922 2 6923 2 6924 2 6925 2 6926 2 6927 2 6928 2 6929 2 6930 2 6931 6931 6932 6932 6933 6933 6934 6934 6935 6935 6936 6936 6937 6937 6938 6938 6939 6939 6940 6940 6941 6941 6942 6942 6943 6943 6944 22 6945 6945 6946 4 6947 11 6948 6948 6949 88 6950 11 6951 6951 6952 98 6953 6953 6954 1538 6955 6955 6956 6956 6957 6957 6958 98 6959 845 6960 11 6961 6961 6962 932 6963 6963 6964 6964 6965 965 6966 154 6967 157 6968 6968 6969 6969 6970 6970 6971 845 6972 11 6973 6973 6974 6974 6975 6975 6976 350 6977 350 6978 353 6979 2 6980 417 6981 6981 6982 569 6983 6983 6984 6984 6985 6985 6986 6986 6987 2 6988 417 6989 6989 6990 6990 6991 6991 6992 6992 6993 6993 6994 6994 6995 2 6996 417 6997 6997 6998 84 6999 6999 7000 7000 7001 138 7002 11 7003 140 7004 157 7005 158 7006 160 7007 162 7008 76 7009 124 7010 165 7011 7011 7012 7012 7013 138 7014 11 7015 140 7016 157 7017 2240 7018 2242 7019 2243 7020 2244 7021 2 7022 2 7023 3 7024 4 7025 2 7026 2 7027 2 7028 2 7029 11 7030 2 7031 2 7032 1675 7033 2 7034 1677 7035 22 7036 1679 7037 1680 7038 2 7039 11 7040 11 7041 1685 7042 1686 7043 1687 7044 22 7045 2 7046 2 7047 2 7048 11 7049 1693 7050 11 7051 1695 7052 11 7053 1697 7054 1698 7055 1699 7056 1700 7057 60 7058 1702 7059 2 7060 2 7061 11 7062 2 7063 2 7064 68 7065 129 7066 1710 7067 2 7068 2 7069 1713 7070 2 7071 1715 7072 1716 7073 2 7074 84 7075 85 7076 88 7077 132 7078 11 7079 1726 7080 1727 7081 98 7082 1729 7083 1730 7084 7084 7085 103 7086 103 7087 1734 7088 1735 7089 1736 7090 1737 7091 1738 7092 1739 7093 1742 7094 1743 7095 1744 7096 1745 7097 98 7098 2 7099 1749 7100 2 7101 2 7102 2 7103 2 7104 2 7105 2 7106 2 7107 2 7108 300 7109 2 7110 2 7111 2 7112 2 7113 2 7114 306 7115 2 7116 2 7117 2 7118 2 7119 2 7120 2 7121 2 7122 2 7123 2 7124 2 7125 2 7126 2 7127 2 7128 2 7129 2 7130 1780 7131 1781 7132 1782 7133 1783 7134 1784 7135 1785 7136 1786 7137 1787 7138 1788 7139 1789 7140 1790 7141 1791 7142 1792 7143 1793 7144 1794 7145 4 7146 2 7147 1797 7148 1798 7149 1799 7150 1800 7151 1801 7152 1802 7153 1803 7154 1804 7155 1805 7156 1806 7157 1807 7158 350 7159 350 7160 40 7161 353 7162 2 7163 417 7164 1814 7165 569 7166 1816 7167 1817 7168 1818 7169 1819 7170 1820 7171 2 7172 417 7173 1823 7174 1824 7175 40 7176 1826 7177 276 7178 1828 7179 1829 7180 2 7181 417 7182 1832 7183 1833 7184 1834 7185 1835 7186 1836 7187 1837 7188 2 7189 728 7190 2 7191 1841 7192 1842 7193 1843 7194 1844 7195 1845 7196 1846 7197 1847 7198 1848 7199 1849 7200 1850 7201 845 7202 6821 7203 6822 7204 6823 7205 6824 7206 6825 7207 6826 7208 6827 7209 6828 7210 6829 7211 6830 7212 6831 7213 6832 7214 6833 7215 6834 7216 6835 7217 6836 7218 6837 7219 6838 7220 6839 7221 6840 7222 6841 7223 6842 7224 6843 7225 6844 7226 6845 7227 6846 7228 6847 7229 6848 7230 6849 7231 6850 7232 6851 7233 6852 7234 6853 7235 6854 7236 6855 7237 6856 7238 6857 7239 6858 7240 6859 7241 6860 7242 6861 7243 6862 7244 6863 7245 6864 7246 6865 7247 6866 7248 6867 7249 6868 7250 6869 7251 6870 7252 6871 7253 6872 7254 6873 7255 6874 7256 6875 7257 6876 7258 6877 7259 6878 7260 6879 7261 6880 7262 6881 7263 6882 7264 6883 7265 6884 7266 6885 7267 6886 7268 6887 7269 6888 7270 6889 7271 6890 7272 6891 7273 6892 7274 6893 7275 6894 7276 6895 7277 6896 7278 6897 7279 6898 7280 6899 7281 11 7282 6901 7283 6902 7284 6903 7285 2 7286 417 7287 6906 7288 932 7289 6908 7290 6909 7291 965 7292 154 7293 157 7294 6913 7295 6914 7296 1476 7297 2 7298 2 7299 2 7300 6919 7301 2 7302 6921 7303 2 7304 2 7305 2 7306 2 7307 2 7308 2 7309 2 7310 2 7311 2 7312 6931 7313 6932 7314 6933 7315 6934 7316 6935 7317 6936 7318 6937 7319 6938 7320 6939 7321 6940 7322 6941 7323 6942 7324 6943 7325 22 7326 6945 7327 4 7328 11 7329 6948 7330 88 7331 11 7332 6951 7333 98 7334 6953 7335 1538 7336 6955 7337 6956 7338 6957 7339 98 7340 845 7341 11 7342 6961 7343 932 7344 6963 7345 6964 7346 965 7347 154 7348 157 7349 6968 7350 6969 7351 6970 7352 845 7353 11 7354 6973 7355 6974 7356 6975 7357 350 7358 350 7359 353 7360 2 7361 417 7362 6981 7363 569 7364 6983 7365 6984 7366 6985 7367 6986 7368 2 7369 417 7370 6989 7371 6990 7372 6991 7373 6992 7374 6993 7375 6994 7376 2 7377 417 7378 6997 7379 7000 7380 138 7381 11 7382 140 7383 157 7384 158 7385 160 7386 162 7387 76 7388 124 7389 165 7390 7011 7391 7012 7392 138 7393 11 7394 140 7395 157 7396 2240 7397 2242 7398 2243 7399 2244 7400 2 7401 7084 7402 7402 7403 7402 7404 845 7405 7405 7406 11 7407 7407 7408 2 7409 417 7410 7410 7411 7411 7412 7412 7413 2727 7414 7414 7415 7415 7416 350 7417 350 7418 353 7419 2 7420 417 7421 7421 7422 569 7423 7423 7424 7424 7425 7425 7426 7426 7427 2 7428 417 7429 7429 7430 7430 7431 7431 7432 7432 7433 2804 7434 7434 7435 569 7436 7436 7437 2 7438 7438 7439 7439 7440 7440 7441 2 7442 7442 7443 7443 7444 7444 7445 7445 7446 7446 7447 2898 7448 7448 7449 68 7450 7450 7451 7451 7452 7452 7453 7453 7454 7454 7455 7455 7456 7456 7457 2 7458 7458 7459 7459 7460 7460 7461 7461 7462 7462 7463 7463 7464 2942 7465 2944 7466 7466 7467 7467 7468 7468 7469 7469 7470 7470 7471 350 7472 350 7473 40 7474 353 7475 2 7476 417 7477 7477 7478 569 7479 7479 7480 7480 7481 7481 7482 7482 7483 932 7484 7484 7485 7485 7486 7486 7487 965 7488 154 7489 157 7490 7490 7491 7491 7492 40 7493 7493 7494 7494 7495 2981 7496 2984 7497 2986 7498 2988 7499 76 7500 2990 7501 2991 7502 7502 7503 276 7504 7504 7505 2 7506 276 7507 76 7508 3971 7509 2829 7510 7510 7511 1851 7512 157 7513 2040 7514 2 7515 6681 7516 2 7517 154 7518 157 7519 7519 7520 7520 7521 7521 7522 7522 7523 7523 7524 5266 7525 7525 7526 157 7527 7527 7528 2 7529 276 7530 7530 7531 2 7532 276 7533 7533 7534 7534 7535 7535 7536 7536 7537 7537 7538 7538 7539 1851 7540 157 7541 7541 7542 7542 7543 7543 7544 7544 7545 276 7546 7546 7547 7547 7548 2 7549 417 7550 7550 7551 5298 7552 7552 7553 7553 7554 1476 7555 2 7556 3 7557 4 7558 2 7559 2 7560 2 7561 2 7562 11 7563 2 7564 2 7565 7565 7566 2 7567 7567 7568 22 7569 7569 7570 7570 7571 2 7572 11 7573 11 7574 7574 7575 7575 7576 7576 7577 22 7578 2 7579 2 7580 2 7581 11 7582 7582 7583 11 7584 7584 7585 11 7586 7586 7587 7587 7588 7588 7589 7589 7590 60 7591 7591 7592 2 7593 2 7594 11 7595 2 7596 2 7597 68 7598 129 7599 7599 7600 2 7601 2 7602 7602 7603 2 7604 7604 7605 7605 7606 2 7607 84 7608 85 7609 22 7610 88 7611 132 7612 11 7613 7613 7614 7614 7615 98 7616 7616 7617 7617 7618 7618 7619 103 7620 103 7621 7621 7622 7622 7623 7623 7624 7624 7625 7625 7626 7626 7627 7627 7628 7628 7629 7629 7630 7630 7631 98 7632 2 7633 11 7634 7634 7635 2 7636 2 7637 2 7638 2 7639 2 7640 2 7641 2 7642 2 7643 300 7644 2 7645 2 7646 2 7647 2 7648 2 7649 306 7650 2 7651 2 7652 2 7653 2 7654 2 7655 2 7656 2 7657 2 7658 2 7659 2 7660 2 7661 2 7662 2 7663 2 7664 2 7665 7665 7666 7666 7667 7667 7668 7668 7669 7669 7670 7670 7671 7671 7672 7672 7673 7673 7674 7674 7675 7675 7676 7676 7677 7677 7678 7678 7679 7679 7680 4 7681 2 7682 7682 7683 7683 7684 7684 7685 7685 7686 7686 7687 7687 7688 7688 7689 7689 7690 7690 7691 7691 7692 7692 7693 350 7694 350 7695 40 7696 353 7697 2 7698 417 7699 7699 7700 569 7701 7701 7702 7702 7703 7703 7704 7704 7705 7705 7706 2 7707 417 7708 7708 7709 7709 7710 40 7711 7711 7712 276 7713 7713 7714 7714 7715 2 7716 417 7717 7717 7718 7718 7719 7719 7720 7720 7721 7721 7722 7722 7723 2 7724 728 7725 2 7726 7726 7727 7727 7728 7728 7729 7729 7730 7730 7731 7731 7732 7732 7733 7733 7734 7734 7735 7735 7736 1851 7737 157 7738 2040 7739 2 7740 7740 7741 845 7742 7742 7743 7743 7744 7744 7745 7745 7746 7746 7747 7747 7748 7748 7749 7749 7750 7750 7751 7751 7752 7752 7753 7753 7754 7754 7755 7755 7756 7756 7757 7757 7758 7758 7759 7759 7760 7760 7761 7761 7762 7762 7763 7763 7764 7764 7765 7765 7766 7766 7767 7767 7768 7768 7769 7769 7770 7770 7771 7771 7772 7772 7773 7773 7774 7774 7775 7775 7776 7776 7777 7777 7778 7778 7779 7779 7780 7780 7781 7781 7782 7782 7783 7783 7784 7784 7785 7785 7786 7786 7787 7787 7788 7788 7789 7789 7790 7790 7791 7791 7792 7792 7793 7793 7794 7794 7795 7795 7796 7796 7797 7797 7798 7798 7799 7799 7800 7800 7801 7801 7802 7802 7803 7803 7804 7804 7805 7805 7806 7806 7807 7807 7808 7808 7809 7809 7810 7810 7811 7811 7812 7812 7813 7813 7814 7814 7815 7815 7816 7816 7817 7817 7818 7818 7819 7819 7820 7820 7821 11 7822 7822 7823 7823 7824 7824 7825 2 7826 417 7827 7827 7828 932 7829 7829 7830 7830 7831 965 7832 154 7833 157 7834 7834 7835 7835 7836 1476 7837 2 7838 2 7839 2 7840 7840 7841 2 7842 7842 7843 2 7844 2 7845 2 7846 2 7847 2 7848 2 7849 2 7850 2 7851 2 7852 7852 7853 7853 7854 7854 7855 7855 7856 7856 7857 7857 7858 7858 7859 7859 7860 7860 7861 7861 7862 7862 7863 7863 7864 7864 7865 22 7866 7866 7867 4 7868 11 7869 7869 7870 88 7871 11 7872 7872 7873 98 7874 7874 7875 1538 7876 7876 7877 7877 7878 7878 7879 98 7880 845 7881 11 7882 7882 7883 932 7884 7884 7885 7885 7886 965 7887 154 7888 157 7889 7889 7890 7890 7891 7891 7892 845 7893 11 7894 7894 7895 7895 7896 7896 7897 350 7898 350 7899 353 7900 2 7901 417 7902 7902 7903 569 7904 7904 7905 7905 7906 7906 7907 7907 7908 2 7909 417 7910 7910 7911 7911 7912 7912 7913 7913 7914 7914 7915 7915 7916 2 7917 417 7918 7918 7919 7919 7920 138 7921 11 7922 140 7923 157 7924 158 7925 160 7926 162 7927 76 7928 124 7929 165 7930 7930 7931 7931 7932 138 7933 11 7934 140 7935 157 7936 2240 7937 2242 7938 2243 7939 2244 7940 2 7941 2 7942 3 7943 4 7944 2 7945 2 7946 2 7947 2 7948 11 7949 2 7950 2 7951 7565 7952 2 7953 7567 7954 22 7955 7569 7956 7570 7957 2 7958 11 7959 11 7960 7574 7961 7575 7962 7576 7963 22 7964 2 7965 2 7966 2 7967 11 7968 7582 7969 11 7970 7584 7971 11 7972 7586 7973 7587 7974 7588 7975 7589 7976 60 7977 7591 7978 2 7979 2 7980 11 7981 2 7982 2 7983 68 7984 129 7985 7599 7986 2 7987 2 7988 7602 7989 2 7990 7604 7991 7605 7992 2 7993 84 7994 85 7995 88 7996 132 7997 11 7998 7613 7999 7614 8000 98 8001 7616 8002 7617 8003 8003 8004 103 8005 103 8006 7621 8007 7622 8008 7623 8009 7624 8010 7625 8011 7626 8012 7627 8013 7628 8014 7629 8015 7630 8016 98 8017 2 8018 7634 8019 2 8020 2 8021 2 8022 2 8023 2 8024 2 8025 2 8026 2 8027 300 8028 2 8029 2 8030 2 8031 2 8032 2 8033 306 8034 2 8035 2 8036 2 8037 2 8038 2 8039 2 8040 2 8041 2 8042 2 8043 2 8044 2 8045 2 8046 2 8047 2 8048 2 8049 7665 8050 7666 8051 7667 8052 7668 8053 7669 8054 7670 8055 7671 8056 7672 8057 7673 8058 7674 8059 7675 8060 7676 8061 7677 8062 7678 8063 7679 8064 4 8065 2 8066 7682 8067 7683 8068 7684 8069 7685 8070 7686 8071 7687 8072 7688 8073 7689 8074 7690 8075 7691 8076 7692 8077 350 8078 350 8079 40 8080 353 8081 2 8082 417 8083 7699 8084 569 8085 7701 8086 7702 8087 7703 8088 7704 8089 7705 8090 2 8091 417 8092 7708 8093 7709 8094 40 8095 7711 8096 276 8097 7713 8098 7714 8099 2 8100 417 8101 7717 8102 7718 8103 7719 8104 7720 8105 7721 8106 7722 8107 2 8108 728 8109 2 8110 7726 8111 7727 8112 7728 8113 7729 8114 7730 8115 7731 8116 7732 8117 7733 8118 7734 8119 7735 8120 845 8121 7742 8122 7743 8123 7744 8124 7745 8125 7746 8126 7747 8127 7748 8128 7749 8129 7750 8130 7751 8131 7752 8132 7753 8133 7754 8134 7755 8135 7756 8136 7757 8137 7758 8138 7759 8139 7760 8140 7761 8141 7762 8142 7763 8143 7764 8144 7765 8145 7766 8146 7767 8147 7768 8148 7769 8149 7770 8150 7771 8151 7772 8152 7773 8153 7774 8154 7775 8155 7776 8156 7777 8157 7778 8158 7779 8159 7780 8160 7781 8161 7782 8162 7783 8163 7784 8164 7785 8165 7786 8166 7787 8167 7788 8168 7789 8169 7790 8170 7791 8171 7792 8172 7793 8173 7794 8174 7795 8175 7796 8176 7797 8177 7798 8178 7799 8179 7800 8180 7801 8181 7802 8182 7803 8183 7804 8184 7805 8185 7806 8186 7807 8187 7808 8188 7809 8189 7810 8190 7811 8191 7812 8192 7813 8193 7814 8194 7815 8195 7816 8196 7817 8197 7818 8198 7819 8199 7820 8200 11 8201 7822 8202 7823 8203 7824 8204 2 8205 417 8206 7827 8207 932 8208 7829 8209 7830 8210 965 8211 154 8212 157 8213 7834 8214 7835 8215 1476 8216 2 8217 2 8218 2 8219 7840 8220 2 8221 7842 8222 2 8223 2 8224 2 8225 2 8226 2 8227 2 8228 2 8229 2 8230 2 8231 7852 8232 7853 8233 7854 8234 7855 8235 7856 8236 7857 8237 7858 8238 7859 8239 7860 8240 7861 8241 7862 8242 7863 8243 7864 8244 22 8245 7866 8246 4 8247 11 8248 7869 8249 88 8250 11 8251 7872 8252 98 8253 7874 8254 1538 8255 7876 8256 7877 8257 7878 8258 98 8259 845 8260 11 8261 7882 8262 932 8263 7884 8264 7885 8265 965 8266 154 8267 157 8268 7889 8269 7890 8270 7891 8271 845 8272 11 8273 7894 8274 7895 8275 7896 8276 350 8277 350 8278 353 8279 2 8280 417 8281 7902 8282 569 8283 7904 8284 7905 8285 7906 8286 7907 8287 2 8288 417 8289 7910 8290 7911 8291 7912 8292 7913 8293 7914 8294 7915 8295 2 8296 417 8297 7918 8298 7919 8299 138 8300 11 8301 140 8302 157 8303 158 8304 160 8305 162 8306 76 8307 124 8308 165 8309 7930 8310 7931 8311 138 8312 11 8313 140 8314 157 8315 2240 8316 2242 8317 2243 8318 2244 8319 2 8320 8003 8321 8321 8322 8321 8323 845 8324 8324 8325 11 8326 8326 8327 2 8328 417 8329 8329 8330 8330 8331 8331 8332 2727 8333 8333 8334 8334 8335 350 8336 350 8337 353 8338 2 8339 417 8340 8340 8341 569 8342 8342 8343 8343 8344 8344 8345 8345 8346 2 8347 417 8348 8348 8349 8349 8350 8350 8351 8351 8352 2804 8353 8353 8354 569 8355 8355 8356 2 8357 8357 8358 8358 8359 7440 8360 2 8361 8361 8362 8362 8363 8363 8364 8364 8365 8365 8366 2898 8367 8367 8368 68 8369 8369 8370 8370 8371 8371 8372 8372 8373 8373 8374 8374 8375 8375 8376 2 8377 8377 8378 8378 8379 8379 8380 8380 8381 8381 8382 8382 8383 2942 8384 2944 8385 8385 8386 8386 8387 8387 8388 8388 8389 8389 8390 350 8391 350 8392 40 8393 353 8394 2 8395 417 8396 8396 8397 569 8398 8398 8399 8399 8400 8400 8401 8401 8402 932 8403 8403 8404 8404 8405 8405 8406 965 8407 154 8408 157 8409 8409 8410 8410 8411 40 8412 8412 8413 8413 8414 2981 8415 2984 8416 2986 8417 2988 8418 76 8419 2990 8420 2991 8421 8421 8422 276 8423 8423 8424 2 8425 276 8426 76 8427 3971 8428 2829 8429 8429 8430 1851 8431 157 8432 2040 8433 2 8434 7740 8435 2 8436 154 8437 157 8438 8438 8439 8439 8440 8440 8441 8441 8442 8442 8443 5266 8444 8444 8445 157 8446 8446 8447 2 8448 276 8449 8449 8450 2 8451 276 8452 8452 8453 8453 8454 8454 8455 8455 8456 8456 8457 8457 8458 1851 8459 157 8460 8460 8461 8461 8462 8462 8463 8463 8464 276 8465 8465 8466 8466 8467 2 8468 417 8469 8469 8470 5298 8471 8471 8472 8472 8473 845 8474 8324 8475 11 8476 8326 8477 2 8478 417 8479 8329 8480 8330 8481 8331 8482 2727 8483 8333 8484 8334 8485 350 8486 350 8487 353 8488 2 8489 417 8490 8340 8491 569 8492 8342 8493 8343 8494 8344 8495 8345 8496 2 8497 417 8498 8348 8499 8349 8500 8350 8501 8351 8502 4 8503 11 8504 8504 8505 88 8506 11 8507 8507 8508 98 8509 8509 8510 1538 8511 8511 8512 8512 8513 8513 8514 98 8515 845 8516 11 8517 8517 8518 932 8519 8519 8520 8520 8521 965 8522 154 8523 157 8524 8524 8525 8525 8526 8526 8527 845 8528 11 8529 8529 8530 8530 8531 8531 8532 350 8533 350 8534 353 8535 2 8536 417 8537 8537 8538 569 8539 8539 8540 8540 8541 8541 8542 8542 8543 2 8544 417 8545 8545 8546 8546 8547 8547 8548 8548 8549 8549 8550 8550 8551 2 8552 417 8553 8553 8554 2804 8555 8353 8556 569 8557 8355 8558 2 8559 8357 8560 8358 8561 7440 8562 2 8563 8361 8564 8362 8565 8363 8566 8364 8567 8365 8568 2898 8569 8367 8570 68 8571 8369 8572 8370 8573 8371 8574 8372 8575 8373 8576 8374 8577 8375 8578 8382 8579 2942 8580 2944 8581 8386 8582 932 8583 8403 8584 8404 8585 8405 8586 965 8587 154 8588 157 8589 8409 8590 8410 8591 8413 8592 2981 8593 2984 8594 2986 8595 2988 8596 76 8597 2990 8598 2991 8599 8421 8600 2 8601 276 8602 76 8603 3971 8604 2829 8605 8429 8606 1851 8607 157 8608 8608 8609 2 8610 154 8611 157 8612 8438 8613 8439 8614 8440 8615 8441 8616 8442 8617 5266 8618 8444 8619 157 8620 8446 8621 2 8622 276 8623 8449 8624 2 8625 276 8626 8452 8627 8453 8628 8454 8629 8455 8630 8456 8631 8457 8632 1851 8633 157 8634 8460 8635 8461 8636 8462 8637 8463 8638 276 8639 8465 8640 8466 8641 2 8642 417 8643 8469 8644 5298 8645 8471 8646 8472 8647 845 8648 7405 8649 11 8650 7407 8651 2 8652 417 8653 7410 8654 7411 8655 7412 8656 2727 8657 7414 8658 7415 8659 8659 8660 350 8661 350 8662 353 8663 2 8664 417 8665 7421 8666 569 8667 7423 8668 7424 8669 7425 8670 7426 8671 2 8672 417 8673 7429 8674 7430 8675 7431 8676 7432 8677 8677 8678 2804 8679 7434 8680 569 8681 7436 8682 2 8683 7438 8684 7439 8685 7440 8686 2 8687 7442 8688 7443 8689 7444 8690 7445 8691 7446 8692 2898 8693 7448 8694 68 8695 7450 8696 7451 8697 7452 8698 7453 8699 7454 8700 7455 8701 7456 8702 7463 8703 2942 8704 2944 8705 7467 8706 932 8707 7484 8708 7485 8709 7486 8710 965 8711 154 8712 157 8713 7490 8714 7491 8715 7494 8716 2981 8717 2984 8718 2986 8719 2988 8720 76 8721 2990 8722 2991 8723 7502 8724 2 8725 276 8726 76 8727 3971 8728 2829 8729 7510 8730 1851 8731 157 8732 8732 8733 2 8734 154 8735 157 8736 7519 8737 7520 8738 7521 8739 7522 8740 7523 8741 5266 8742 7525 8743 157 8744 7527 8745 2 8746 276 8747 7530 8748 2 8749 276 8750 7533 8751 8751 8752 7534 8753 7535 8754 7536 8755 7537 8756 7538 8757 1851 8758 157 8759 7541 8760 7542 8761 7543 8762 7544 8763 276 8764 7546 8765 7547 8766 2 8767 417 8768 7550 8769 5298 8770 7552 8771 7553 8772 2216 8773 1851 8774 157 8775 8775 8776 276 8777 8777 8778 2217 8779 2 8780 417 8781 2220 8782 5298 8783 8783 8784 2223 8785 138 8786 11 8787 140 8788 157 8789 158 8790 160 8791 162 8792 76 8793 124 8794 165 8795 2234 8796 2235 8797 138 8798 11 8799 140 8800 157 8801 2240 8802 2242 8803 2243 8804 2244 8805 2 8806 2246 8807 2247 8808 2 8809 2891 8810 845 8811 6668 8812 11 8813 6670 8814 2 8815 417 8816 6673 8817 6674 8818 6675 8819 2727 8820 6677 8821 6678 8822 350 8823 350 8824 353 8825 2 8826 417 8827 6687 8828 569 8829 6689 8830 6690 8831 6691 8832 6692 8833 2 8834 417 8835 6695 8836 6696 8837 6697 8838 6698 8839 2804 8840 6701 8841 569 8842 6703 8843 2 8844 6705 8845 6706 8846 1260 8847 2 8848 6709 8849 6710 8850 6711 8851 6712 8852 6713 8853 2898 8854 6715 8855 68 8856 6717 8857 6718 8858 6719 8859 6720 8860 6721 8861 6722 8862 6723 8863 6730 8864 2942 8865 2944 8866 6734 8867 932 8868 6751 8869 6752 8870 6753 8871 965 8872 154 8873 157 8874 6757 8875 6758 8876 6761 8877 2981 8878 2984 8879 2986 8880 2988 8881 76 8882 2990 8883 2991 8884 6769 8885 2 8886 276 8887 76 8888 3971 8889 2829 8890 6777 8891 1851 8892 157 8893 2040 8894 2 8895 2042 8896 2 8897 154 8898 157 8899 6784 8900 6785 8901 6786 8902 6787 8903 6788 8904 5266 8905 6790 8906 157 8907 6792 8908 2 8909 276 8910 6795 8911 2 8912 276 8913 6798 8914 6800 8915 6801 8916 6802 8917 6803 8918 6804 8919 1851 8920 157 8921 6807 8922 6808 8923 6809 8924 6810 8925 276 8926 6812 8927 6813 8928 2 8929 417 8930 6816 8931 5298 8932 6818 8933 6819 8934 2893 8935 2895 8936 2925 8937 2926 8938 932 8939 2927 8940 2605 8941 965 8942 154 8943 157 8944 2609 8945 2610 8946 2928 8947 2940 8948 2942 8949 2944 8950 2947 8951 932 8952 2969 8953 2970 8954 2971 8955 965 8956 154 8957 157 8958 2975 8959 2976 8960 2979 8961 2981 8962 2984 8963 2986 8964 2988 8965 76 8966 2990 8967 2991 8968 3013 8969 2 8970 276 8971 76 8972 3971 8973 2829 8974 6625 8975 1851 8976 157 8977 2040 8978 2 8979 2515 8980 2 8981 154 8982 157 8983 6632 8984 6634 8985 6635 8986 5266 8987 6638 8988 157 8989 6640 8990 2 8991 276 8992 6643 8993 2 8994 276 8995 6646 8996 6649 8997 1851 8998 157 8999 6654 9000 845 9001 2517 9002 2518 9003 2519 9004 2520 9005 2521 9006 2522 9007 2523 9008 2524 9009 2525 9010 2526 9011 2527 9012 2528 9013 2529 9014 2530 9015 2531 9016 2532 9017 2533 9018 2534 9019 2535 9020 2536 9021 2537 9022 2538 9023 2539 9024 2540 9025 2541 9026 2542 9027 2543 9028 2544 9029 2545 9030 2546 9031 2547 9032 2548 9033 2549 9034 2550 9035 2551 9036 2552 9037 2553 9038 2554 9039 2555 9040 2556 9041 2557 9042 2558 9043 2559 9044 2560 9045 2561 9046 2562 9047 2563 9048 2564 9049 2565 9050 2566 9051 2567 9052 2568 9053 2569 9054 2570 9055 2571 9056 2572 9057 2573 9058 2574 9059 2575 9060 2576 9061 2577 9062 2578 9063 2579 9064 2580 9065 2581 9066 2582 9067 2583 9068 2584 9069 2585 9070 2586 9071 2587 9072 2588 9073 2589 9074 2590 9075 2591 9076 2592 9077 2593 9078 2594 9079 2595 9080 11 9081 2597 9082 2598 9083 2599 9084 2 9085 417 9086 2602 9087 2604 9088 1476 9089 2 9090 2 9091 2 9092 2615 9093 2 9094 2617 9095 2 9096 2 9097 2 9098 2 9099 2 9100 2 9101 2 9102 2 9103 2 9104 2627 9105 2628 9106 2629 9107 2630 9108 2631 9109 2632 9110 2633 9111 2634 9112 2635 9113 2636 9114 2637 9115 2638 9116 2639 9117 22 9118 2641 9119 11 9120 88 9121 11 9122 2647 9123 98 9124 2649 9125 1538 9126 2651 9127 2652 9128 2653 9129 98 9130 845 9131 11 9132 2657 9133 932 9134 2659 9135 2660 9136 965 9137 154 9138 157 9139 2664 9140 2665 9141 2666 9142 845 9143 11 9144 2669 9145 2670 9146 2671 9147 350 9148 350 9149 353 9150 2 9151 417 9152 2677 9153 569 9154 2679 9155 2681 9156 2686 9157 2687 9158 2688 9159 2689 9160 157 9161 9161 9162 2694 9163 2 9164 9164 9165 138 9166 11 9167 140 9168 157 9169 158 9170 160 9171 162 9172 76 9173 124 9174 165 9175 2705 9176 2706 9177 138 9178 11 9179 140 9180 157 9181 2240 9182 2242 9183 2243 9184 2244 9185 2 9186 2716 9187 2717 9188 845 9189 2719 9190 11 9191 2721 9192 2 9193 417 9194 2724 9195 2725 9196 2726 9197 2727 9198 2729 9199 2730 9200 350 9201 350 9202 353 9203 2 9204 417 9205 2736 9206 569 9207 2738 9208 2739 9209 2740 9210 2741 9211 2 9212 417 9213 2744 9214 2745 9215 2746 9216 2747 9217 2804 9218 2809 9219 569 9220 2885 9221 2 9222 2887 9223 2888 9224 2892 9225 2894 9226 2898 9227 2899 9228 68 9229 2904 9230 2913 9231 2929 9232 6633 9233 6636 9234 9234 9235 6647 9236 6648 9237 6650 9238 6651 9239 6655 9240 6656 9241 6657 9242 276 9243 6659 9244 6660 9245 2 9246 417 9247 6663 9248 5298 9249 6665 9250 6666 9251 1476 9252 2 9253 2 9254 2 9255 9255 9256 2 9257 9257 9258 2 9259 2 9260 2 9261 2 9262 2 9263 2 9264 2 9265 2 9266 2 9267 9267 9268 9268 9269 9269 9270 9270 9271 9271 9272 9272 9273 9273 9274 9274 9275 9275 9276 9276 9277 9277 9278 9278 9279 9279 9280 22 9281 9281 9282 4 9283 11 9284 9284 9285 88 9286 11 9287 9287 9288 98 9289 9289 9290 1538 9291 9291 9292 9292 9293 9293 9294 98 9295 845 9296 11 9297 9297 9298 932 9299 9299 9300 9300 9301 965 9302 154 9303 157 9304 9304 9305 9305 9306 9306 9307 845 9308 11 9309 9309 9310 9310 9311 9311 9312 350 9313 350 9314 353 9315 2 9316 417 9317 9317 9318 569 9319 9319 9320 9320 9321 9321 9322 9322 9323 2 9324 417 9325 9325 9326 9326 9327 9327 9328 9328 9329 9329 9330 9330 9331 2 9332 417 9333 9333 9334 9334 9335 138 9336 11 9337 140 9338 157 9339 158 9340 160 9341 162 9342 76 9343 124 9344 165 9345 9345 9346 9346 9347 138 9348 11 9349 140 9350 157 9351 2240 9352 2242 9353 2243 9354 2244 9355 2 9356 2 9357 3 9358 4 9359 2 9360 2 9361 2 9362 2 9363 11 9364 2 9365 2 9366 676 9367 2 9368 678 9369 22 9370 680 9371 681 9372 2 9373 11 9374 11 9375 685 9376 686 9377 687 9378 22 9379 2 9380 2 9381 2 9382 11 9383 693 9384 11 9385 695 9386 11 9387 697 9388 698 9389 699 9390 700 9391 60 9392 702 9393 2 9394 2 9395 11 9396 2 9397 2 9398 68 9399 129 9400 710 9401 2 9402 2 9403 713 9404 2 9405 715 9406 716 9407 2 9408 84 9409 85 9410 88 9411 132 9412 11 9413 723 9414 724 9415 98 9416 726 9417 727 9418 9418 9419 103 9420 103 9421 731 9422 732 9423 733 9424 734 9425 735 9426 736 9427 737 9428 738 9429 739 9430 740 9431 98 9432 2 9433 743 9434 2 9435 2 9436 2 9437 2 9438 2 9439 2 9440 2 9441 2 9442 300 9443 2 9444 2 9445 2 9446 2 9447 2 9448 306 9449 2 9450 2 9451 2 9452 2 9453 2 9454 2 9455 2 9456 2 9457 2 9458 2 9459 2 9460 2 9461 2 9462 2 9463 2 9464 774 9465 775 9466 776 9467 777 9468 778 9469 779 9470 780 9471 781 9472 782 9473 783 9474 784 9475 785 9476 786 9477 787 9478 788 9479 4 9480 2 9481 791 9482 792 9483 793 9484 794 9485 795 9486 796 9487 797 9488 798 9489 799 9490 800 9491 801 9492 350 9493 350 9494 40 9495 353 9496 2 9497 417 9498 808 9499 569 9500 810 9501 811 9502 812 9503 813 9504 814 9505 2 9506 417 9507 817 9508 818 9509 40 9510 820 9511 276 9512 822 9513 823 9514 2 9515 417 9516 826 9517 827 9518 828 9519 829 9520 830 9521 831 9522 2 9523 728 9524 2 9525 835 9526 836 9527 837 9528 838 9529 839 9530 840 9531 841 9532 842 9533 843 9534 844 9535 845 9536 846 9537 847 9538 848 9539 849 9540 850 9541 851 9542 852 9543 853 9544 854 9545 855 9546 856 9547 857 9548 858 9549 859 9550 860 9551 861 9552 862 9553 863 9554 864 9555 865 9556 866 9557 867 9558 868 9559 869 9560 870 9561 871 9562 872 9563 873 9564 874 9565 875 9566 876 9567 877 9568 878 9569 879 9570 880 9571 881 9572 882 9573 883 9574 884 9575 885 9576 886 9577 887 9578 888 9579 889 9580 890 9581 891 9582 892 9583 893 9584 894 9585 895 9586 896 9587 897 9588 898 9589 899 9590 900 9591 901 9592 902 9593 903 9594 904 9595 905 9596 906 9597 907 9598 908 9599 909 9600 910 9601 911 9602 912 9603 913 9604 914 9605 915 9606 916 9607 917 9608 918 9609 919 9610 920 9611 921 9612 922 9613 923 9614 924 9615 11 9616 926 9617 927 9618 928 9619 2 9620 417 9621 931 9622 932 9623 933 9624 938 9625 965 9626 154 9627 157 9628 9161 9629 9234 9630 1476 9631 2 9632 2 9633 2 9634 9255 9635 2 9636 9257 9637 2 9638 2 9639 2 9640 2 9641 2 9642 2 9643 2 9644 2 9645 2 9646 9267 9647 9268 9648 9269 9649 9270 9650 9271 9651 9272 9652 9273 9653 9274 9654 9275 9655 9276 9656 9277 9657 9278 9658 9279 9659 22 9660 9281 9661 4 9662 11 9663 9284 9664 88 9665 11 9666 9287 9667 98 9668 9289 9669 1538 9670 9291 9671 9292 9672 9293 9673 98 9674 845 9675 11 9676 9297 9677 932 9678 9299 9679 9300 9680 965 9681 154 9682 157 9683 9304 9684 9305 9685 9306 9686 845 9687 11 9688 9309 9689 9310 9690 9311 9691 350 9692 350 9693 353 9694 2 9695 417 9696 9317 9697 569 9698 9319 9699 9320 9700 9321 9701 9322 9702 2 9703 417 9704 9325 9705 9326 9706 9327 9707 9328 9708 9329 9709 9330 9710 2 9711 417 9712 9333 9713 9334 9714 138 9715 11 9716 140 9717 157 9718 158 9719 160 9720 162 9721 76 9722 124 9723 165 9724 9345 9725 9346 9726 138 9727 11 9728 140 9729 157 9730 2240 9731 2242 9732 2243 9733 2244 9734 2 9735 9418 9736 9736 9737 9736 9738 845 9739 9739 9740 11 9741 9741 9742 2 9743 417 9744 9744 9745 9745 9746 9746 9747 2727 9748 9748 9749 9749 9750 350 9751 350 9752 353 9753 2 9754 417 9755 9755 9756 569 9757 9757 9758 9758 9759 9759 9760 9760 9761 2 9762 417 9763 9763 9764 9764 9765 9765 9766 9766 9767 2804 9768 9768 9769 569 9770 9770 9771 2 9772 9772 9773 9773 9774 2 9775 3 9776 4 9777 2 9778 2 9779 2 9780 2 9781 11 9782 2 9783 2 9784 9784 9785 2 9786 9786 9787 22 9788 9788 9789 9789 9790 2 9791 11 9792 11 9793 9793 9794 9794 9795 9795 9796 22 9797 2 9798 2 9799 2 9800 11 9801 9801 9802 11 9803 9803 9804 11 9805 9805 9806 9806 9807 9807 9808 9808 9809 60 9810 9810 9811 2 9812 2 9813 11 9814 2 9815 2 9816 68 9817 129 9818 9818 9819 2 9820 2 9821 9821 9822 2 9823 9823 9824 9824 9825 2 9826 84 9827 85 9828 88 9829 132 9830 11 9831 9831 9832 9832 9833 98 9834 9834 9835 9835 9836 9836 9837 103 9838 103 9839 9839 9840 9840 9841 9841 9842 9842 9843 9843 9844 9844 9845 9845 9846 9846 9847 9847 9848 9848 9849 98 9850 2 9851 9851 9852 2 9853 2 9854 2 9855 2 9856 2 9857 2 9858 2 9859 2 9860 300 9861 2 9862 2 9863 2 9864 2 9865 2 9866 306 9867 2 9868 2 9869 2 9870 2 9871 2 9872 2 9873 2 9874 2 9875 2 9876 2 9877 2 9878 2 9879 2 9880 2 9881 2 9882 9882 9883 9883 9884 9884 9885 9885 9886 9886 9887 9887 9888 9888 9889 9889 9890 9890 9891 9891 9892 9892 9893 9893 9894 9894 9895 9895 9896 9896 9897 4 9898 2 9899 9899 9900 9900 9901 9901 9902 9902 9903 9903 9904 9904 9905 9905 9906 9906 9907 9907 9908 9908 9909 9909 9910 350 9911 350 9912 40 9913 353 9914 2 9915 417 9916 9916 9917 569 9918 9918 9919 9919 9920 9920 9921 9921 9922 9922 9923 2 9924 417 9925 9925 9926 9926 9927 40 9928 9928 9929 276 9930 9930 9931 9931 9932 2 9933 417 9934 9934 9935 9935 9936 9936 9937 9937 9938 9938 9939 9939 9940 2 9941 728 9942 2 9943 9943 9944 9944 9945 9945 9946 9946 9947 9947 9948 9948 9949 9949 9950 9950 9951 9951 9952 9952 9953 845 9954 9954 9955 9955 9956 9956 9957 9957 9958 9958 9959 9959 9960 9960 9961 9961 9962 9962 9963 9963 9964 9964 9965 9965 9966 9966 9967 9967 9968 9968 9969 9969 9970 9970 9971 9971 9972 9972 9973 9973 9974 9974 9975 9975 9976 9976 9977 9977 9978 9978 9979 9979 9980 9980 9981 9981 9982 9982 9983 9983 9984 9984 9985 9985 9986 9986 9987 9987 9988 9988 9989 9989 9990 9990 9991 9991 9992 9992 9993 9993 9994 9994 9995 9995 9996 9996 9997 9997 9998 9998 9999 9999 10000 10000 10001 10001 10002 10002 10003 10003 10004 10004 10005 10005 10006 10006 10007 10007 10008 10008 10009 10009 10010 10010 10011 10011 10012 10012 10013 10013 10014 10014 10015 10015 10016 10016 10017 10017 10018 10018 10019 10019 10020 10020 10021 10021 10022 10022 10023 10023 10024 10024 10025 10025 10026 10026 10027 10027 10028 10028 10029 10029 10030 10030 10031 10031 10032 10032 10033 11 10034 10034 10035 10035 10036 10036 10037 2 10038 417 10039 10039 10040 932 10041 10041 10042 10042 10043 965 10044 154 10045 157 10046 10046 10047 10047 10048 1476 10049 2 10050 2 10051 2 10052 10052 10053 2 10054 10054 10055 2 10056 2 10057 2 10058 2 10059 2 10060 2 10061 2 10062 2 10063 2 10064 10064 10065 10065 10066 10066 10067 10067 10068 10068 10069 10069 10070 10070 10071 10071 10072 10072 10073 10073 10074 10074 10075 10075 10076 10076 10077 22 10078 10078 10079 4 10080 11 10081 10081 10082 88 10083 11 10084 10084 10085 98 10086 10086 10087 1538 10088 10088 10089 10089 10090 10090 10091 98 10092 845 10093 11 10094 10094 10095 932 10096 10096 10097 10097 10098 965 10099 154 10100 157 10101 10101 10102 10102 10103 10103 10104 845 10105 11 10106 10106 10107 10107 10108 10108 10109 350 10110 350 10111 353 10112 2 10113 417 10114 10114 10115 569 10116 10116 10117 10117 10118 10118 10119 10119 10120 2 10121 417 10122 10122 10123 10123 10124 10124 10125 10125 10126 10126 10127 10127 10128 2 10129 417 10130 10130 10131 10131 10132 138 10133 11 10134 140 10135 157 10136 158 10137 160 10138 162 10139 76 10140 124 10141 165 10142 10142 10143 10143 10144 138 10145 11 10146 140 10147 157 10148 2240 10149 2242 10150 2243 10151 2244 10152 2 10153 10153 10154 10154 10155 2 10156 10156 10157 845 10158 10158 10159 11 10160 10160 10161 2 10162 417 10163 10163 10164 10164 10165 10165 10166 2727 10167 10167 10168 10168 10169 350 10170 350 10171 353 10172 2 10173 417 10174 10174 10175 569 10176 10176 10177 10177 10178 10178 10179 10179 10180 2 10181 417 10182 10182 10183 10183 10184 10184 10185 10185 10186 2804 10187 10187 10188 569 10189 10189 10190 2 10191 10191 10192 10192 10193 9836 10194 2 10195 10195 10196 10196 10197 10197 10198 10198 10199 10199 10200 2898 10201 10201 10202 68 10203 10203 10204 10204 10205 10205 10206 10206 10207 10207 10208 10208 10209 10209 10210 2 10211 10211 10212 10212 10213 10213 10214 10214 10215 10215 10216 10216 10217 2942 10218 2944 10219 10219 10220 10220 10221 10221 10222 10222 10223 10223 10224 350 10225 350 10226 40 10227 353 10228 2 10229 417 10230 10230 10231 569 10232 10232 10233 10233 10234 10234 10235 10235 10236 932 10237 10237 10238 10238 10239 10239 10240 965 10241 154 10242 157 10243 10243 10244 10244 10245 40 10246 10246 10247 10247 10248 2981 10249 2984 10250 2986 10251 2988 10252 76 10253 2990 10254 2991 10255 10255 10256 276 10257 10257 10258 2 10259 276 10260 76 10261 3971 10262 2829 10263 10263 10264 1851 10265 157 10266 2040 10267 2 10268 10268 10269 2 10270 154 10271 157 10272 10272 10273 10273 10274 10274 10275 10275 10276 10276 10277 5266 10278 10278 10279 157 10280 10280 10281 2 10282 276 10283 10283 10284 2 10285 276 10286 10286 10287 10287 10288 10288 10289 10289 10290 10290 10291 10291 10292 1851 10293 157 10294 10294 10295 10295 10296 10296 10297 10297 10298 276 10299 10299 10300 10300 10301 2 10302 417 10303 10303 10304 5298 10305 10305 10306 10306 10307 10307 10308 10308 10309 10309 10310 10310 10311 2898 10312 10312 10313 68 10314 10314 10315 10315 10316 10316 10317 10317 10318 10318 10319 10319 10320 10320 10321 2 10322 10322 10323 10323 10324 10324 10325 10325 10326 10326 10327 10327 10328 2942 10329 2944 10330 10330 10331 10331 10332 10332 10333 10333 10334 10334 10335 350 10336 350 10337 40 10338 353 10339 2 10340 417 10341 10341 10342 569 10343 10343 10344 10344 10345 10345 10346 10346 10347 932 10348 10348 10349 10349 10350 10350 10351 965 10352 154 10353 157 10354 10354 10355 10355 10356 40 10357 10357 10358 10358 10359 2981 10360 2984 10361 2986 10362 2988 10363 76 10364 2990 10365 2991 10366 10366 10367 276 10368 10368 10369 2 10370 276 10371 76 10372 3971 10373 2829 10374 10374 10375 1851 10376 157 10377 2040 10378 2 10379 10379 10380 2 10381 154 10382 157 10383 10383 10384 10384 10385 10385 10386 10386 10387 10387 10388 5266 10389 10389 10390 157 10391 10391 10392 2 10393 276 10394 10394 10395 2 10396 276 10397 10397 10398 10398 10399 10399 10400 10400 10401 10401 10402 10402 10403 1851 10404 157 10405 10405 10406 10406 10407 10407 10408 10408 10409 276 10410 10410 10411 10411 10412 2 10413 417 10414 10414 10415 5298 10416 10416 10417 10417 10418 2 10419 10419 10420 845 10421 9739 10422 11 10423 9741 10424 2 10425 417 10426 9744 10427 9745 10428 9746 10429 2727 10430 9748 10431 9749 10432 350 10433 350 10434 353 10435 2 10436 417 10437 9755 10438 569 10439 9757 10440 9758 10441 9759 10442 9760 10443 2 10444 417 10445 9763 10446 9764 10447 9765 10448 9766 10449 2804 10450 9768 10451 569 10452 9770 10453 2 10454 9772 10455 9773 10456 2 10457 3 10458 4 10459 2 10460 2 10461 2 10462 2 10463 11 10464 2 10465 2 10466 9784 10467 2 10468 9786 10469 22 10470 9788 10471 9789 10472 2 10473 11 10474 11 10475 9793 10476 9794 10477 9795 10478 22 10479 2 10480 2 10481 2 10482 11 10483 9801 10484 11 10485 9803 10486 11 10487 9805 10488 9806 10489 9807 10490 9808 10491 60 10492 9810 10493 2 10494 2 10495 11 10496 2 10497 2 10498 68 10499 129 10500 9818 10501 2 10502 2 10503 9821 10504 2 10505 9823 10506 9824 10507 2 10508 84 10509 85 10510 88 10511 132 10512 11 10513 9831 10514 9832 10515 98 10516 9834 10517 9835 10518 9836 10519 103 10520 103 10521 9839 10522 9840 10523 9841 10524 9842 10525 9843 10526 9844 10527 9845 10528 9846 10529 9847 10530 9848 10531 98 10532 2 10533 9851 10534 2 10535 2 10536 2 10537 2 10538 2 10539 2 10540 2 10541 2 10542 300 10543 2 10544 2 10545 2 10546 2 10547 2 10548 306 10549 2 10550 2 10551 2 10552 2 10553 2 10554 2 10555 2 10556 2 10557 2 10558 2 10559 2 10560 2 10561 2 10562 2 10563 2 10564 9882 10565 9883 10566 9884 10567 9885 10568 9886 10569 9887 10570 9888 10571 9889 10572 9890 10573 9891 10574 9892 10575 9893 10576 9894 10577 9895 10578 9896 10579 4 10580 2 10581 9899 10582 9900 10583 9901 10584 9902 10585 9903 10586 9904 10587 9905 10588 9906 10589 9907 10590 9908 10591 9909 10592 350 10593 350 10594 40 10595 353 10596 2 10597 417 10598 9916 10599 569 10600 9918 10601 9919 10602 9920 10603 9921 10604 9922 10605 2 10606 417 10607 9925 10608 9926 10609 40 10610 9928 10611 276 10612 9930 10613 9931 10614 2 10615 417 10616 9934 10617 9935 10618 9936 10619 9937 10620 9938 10621 9939 10622 2 10623 728 10624 2 10625 9943 10626 9944 10627 9945 10628 9946 10629 9947 10630 9948 10631 9949 10632 9950 10633 9951 10634 9952 10635 845 10636 9954 10637 9955 10638 9956 10639 9957 10640 9958 10641 9959 10642 9960 10643 9961 10644 9962 10645 9963 10646 9964 10647 9965 10648 9966 10649 9967 10650 9968 10651 9969 10652 9970 10653 9971 10654 9972 10655 9973 10656 9974 10657 9975 10658 9976 10659 9977 10660 9978 10661 9979 10662 9980 10663 9981 10664 9982 10665 9983 10666 9984 10667 9985 10668 9986 10669 9987 10670 9988 10671 9989 10672 9990 10673 9991 10674 9992 10675 9993 10676 9994 10677 9995 10678 9996 10679 9997 10680 9998 10681 9999 10682 10000 10683 10001 10684 10002 10685 10003 10686 10004 10687 10005 10688 10006 10689 10007 10690 10008 10691 10009 10692 10010 10693 10011 10694 10012 10695 10013 10696 10014 10697 10015 10698 10016 10699 10017 10700 10018 10701 10019 10702 10020 10703 10021 10704 10022 10705 10023 10706 10024 10707 10025 10708 10026 10709 10027 10710 10028 10711 10029 10712 10030 10713 10031 10714 10032 10715 11 10716 10034 10717 10035 10718 10036 10719 2 10720 417 10721 10039 10722 932 10723 10041 10724 10042 10725 965 10726 154 10727 157 10728 10046 10729 10047 10730 1476 10731 2 10732 2 10733 2 10734 10052 10735 2 10736 10054 10737 2 10738 2 10739 2 10740 2 10741 2 10742 2 10743 2 10744 2 10745 2 10746 10064 10747 10065 10748 10066 10749 10067 10750 10068 10751 10069 10752 10070 10753 10071 10754 10072 10755 10073 10756 10074 10757 10075 10758 10076 10759 22 10760 10078 10761 4 10762 11 10763 10081 10764 88 10765 11 10766 10084 10767 98 10768 10086 10769 1538 10770 10088 10771 10089 10772 10090 10773 98 10774 845 10775 11 10776 10094 10777 932 10778 10096 10779 10097 10780 965 10781 154 10782 157 10783 10101 10784 10102 10785 10103 10786 845 10787 11 10788 10106 10789 10107 10790 10108 10791 350 10792 350 10793 353 10794 2 10795 417 10796 10114 10797 569 10798 10116 10799 10117 10800 10118 10801 10119 10802 2 10803 417 10804 10122 10805 10123 10806 10124 10807 10125 10808 10126 10809 10127 10810 2 10811 417 10812 10130 10813 10131 10814 138 10815 11 10816 140 10817 157 10818 158 10819 160 10820 162 10821 76 10822 124 10823 165 10824 10142 10825 10143 10826 138 10827 11 10828 140 10829 157 10830 2240 10831 2242 10832 2243 10833 2244 10834 2 10835 10153 10836 10154 10837 2 10838 10156 10839 845 10840 10158 10841 11 10842 10160 10843 2 10844 417 10845 10163 10846 10164 10847 10165 10848 2727 10849 10167 10850 10168 10851 350 10852 350 10853 353 10854 2 10855 417 10856 10174 10857 569 10858 10176 10859 10177 10860 10178 10861 10179 10862 2 10863 417 10864 10182 10865 10183 10866 10184 10867 10185 10868 2804 10869 10187 10870 569 10871 10189 10872 2 10873 10191 10874 10192 10875 9836 10876 2 10877 10195 10878 10196 10879 10197 10880 10198 10881 10199 10882 2898 10883 10201 10884 68 10885 10203 10886 10204 10887 10205 10888 10206 10889 10207 10890 10208 10891 10209 10892 10216 10893 2942 10894 2944 10895 10220 10896 932 10897 10237 10898 10238 10899 10239 10900 965 10901 154 10902 157 10903 10243 10904 10244 10905 10247 10906 2981 10907 2984 10908 2986 10909 2988 10910 76 10911 2990 10912 2991 10913 10255 10914 2 10915 276 10916 76 10917 3971 10918 2829 10919 10263 10920 1851 10921 157 10922 2040 10923 2 10924 10268 10925 2 10926 154 10927 157 10928 10272 10929 10273 10930 10274 10931 10275 10932 10276 10933 5266 10934 10278 10935 157 10936 10280 10937 2 10938 276 10939 10283 10940 2 10941 276 10942 10286 10943 10287 10944 10288 10945 10289 10946 10290 10947 10291 10948 1851 10949 157 10950 10294 10951 10295 10952 10296 10953 10297 10954 276 10955 10299 10956 10300 10957 2 10958 417 10959 10303 10960 5298 10961 10305 10962 10306 10963 10307 10964 10308 10965 10309 10966 10310 10967 2898 10968 10312 10969 68 10970 10314 10971 10315 10972 10316 10973 10317 10974 10318 10975 10319 10976 10320 10977 10327 10978 2942 10979 2944 10980 10331 10981 932 10982 10348 10983 10349 10984 10350 10985 965 10986 154 10987 157 10988 10354 10989 10355 10990 10358 10991 2981 10992 2984 10993 2986 10994 2988 10995 76 10996 2990 10997 2991 10998 10366 10999 2 11000 276 11001 76 11002 3971 11003 2829 11004 10374 11005 1851 11006 157 11007 2040 11008 2 11009 10379 11010 2 11011 154 11012 157 11013 10383 11014 10384 11015 10385 11016 10386 11017 10387 11018 5266 11019 10389 11020 157 11021 10391 11022 2 11023 276 11024 10394 11025 2 11026 276 11027 10397 11028 10398 11029 10399 11030 10400 11031 10401 11032 10402 11033 1851 11034 157 11035 10405 11036 10406 11037 11037 11038 10407 11039 10408 11040 276 11041 10410 11042 10411 11043 2 11044 417 11045 10414 11046 5298 11047 10416 11048 10417 11049 11049 11050 11050 11051 11051 11052 11052 11053 11053 11054 11054 11055 11055 11056 11056 11057 845 11058 11058 11059 11059 11060 11060 11061 11061 11062 11062 11063 11063 11064 11064 11065 11065 11066 11066 11067 11067 11068 11068 11069 11069 11070 11070 11071 11071 11072 11072 11073 11073 11074 11074 11075 11075 11076 11076 11077 11077 11078 11078 11079 11079 11080 11080 11081 11081 11082 11082 11083 11083 11084 11084 11085 11085 11086 11086 11087 11087 11088 11088 11089 11089 11090 11090 11091 11091 11092 11092 11093 11093 11094 11094 11095 11095 11096 11096 11097 11097 11098 11098 11099 11099 11100 11100 11101 11101 11102 11102 11103 11103 11104 11104 11105 11105 11106 11106 11107 11107 11108 11108 11109 11109 11110 11110 11111 11111 11112 11112 11113 11113 11114 11114 11115 11115 11116 11116 11117 11117 11118 11118 11119 11119 11120 11120 11121 11121 11122 11122 11123 11123 11124 11124 11125 11125 11126 11126 11127 11127 11128 11128 11129 11129 11130 11130 11131 11131 11132 11132 11133 11133 11134 11134 11135 11135 11136 11136 11137 11 11138 11138 11139 11139 11140 11140 11141 2 11142 417 11143 11143 11144 932 11145 11145 11146 11146 11147 965 11148 154 11149 157 11150 11150 11151 11151 11152 1476 11153 2 11154 2 11155 2 11156 11156 11157 2 11158 11158 11159 2 11160 2 11161 2 11162 2 11163 2 11164 2 11165 2 11166 2 11167 2 11168 11168 11169 11169 11170 11170 11171 11171 11172 11172 11173 11173 11174 11174 11175 11175 11176 11176 11177 11177 11178 11178 11179 11179 11180 11180 11181 22 11182 11182 11183 4 11184 11 11185 11185 11186 88 11187 11 11188 11188 11189 98 11190 11190 11191 1538 11192 11192 11193 11193 11194 11194 11195 98 11196 845 11197 11 11198 11198 11199 932 11200 11200 11201 11201 11202 965 11203 154 11204 157 11205 11205 11206 11206 11207 11207 11208 845 11209 11 11210 11210 11211 11211 11212 11212 11213 350 11214 350 11215 353 11216 2 11217 417 11218 11218 11219 569 11220 11220 11221 11221 11222 11222 11223 11223 11224 2 11225 417 11226 11226 11227 11227 11228 11228 11229 11229 11230 11230 11231 11231 11232 2 11233 417 11234 11234 11235 11235 11236 11236 11237 138 11238 11 11239 140 11240 157 11241 158 11242 160 11243 162 11244 76 11245 124 11246 165 11247 11247 11248 11248 11249 138 11250 11 11251 140 11252 157 11253 2240 11254 2242 11255 2243 11256 2244 11257 2 11258 2 11259 3 11260 4 11261 2 11262 2 11263 2 11264 2 11265 11 11266 2 11267 2 11268 508 11269 2 11270 510 11271 22 11272 512 11273 513 11274 2 11275 11 11276 11 11277 517 11278 518 11279 519 11280 22 11281 2 11282 2 11283 2 11284 11 11285 525 11286 11 11287 527 11288 11 11289 529 11290 530 11291 531 11292 532 11293 60 11294 534 11295 2 11296 2 11297 11 11298 2 11299 2 11300 68 11301 129 11302 542 11303 2 11304 2 11305 545 11306 2 11307 547 11308 548 11309 2 11310 84 11311 85 11312 88 11313 132 11314 11 11315 555 11316 556 11317 98 11318 558 11319 559 11320 11320 11321 103 11322 103 11323 563 11324 564 11325 565 11326 566 11327 567 11328 568 11329 570 11330 571 11331 572 11332 573 11333 98 11334 2 11335 576 11336 2 11337 2 11338 2 11339 2 11340 2 11341 2 11342 2 11343 2 11344 300 11345 2 11346 2 11347 2 11348 2 11349 2 11350 306 11351 2 11352 2 11353 2 11354 2 11355 2 11356 2 11357 2 11358 2 11359 2 11360 2 11361 2 11362 2 11363 2 11364 2 11365 2 11366 607 11367 608 11368 609 11369 610 11370 611 11371 612 11372 613 11373 614 11374 615 11375 616 11376 617 11377 618 11378 619 11379 620 11380 621 11381 4 11382 2 11383 624 11384 625 11385 626 11386 627 11387 628 11388 629 11389 630 11390 631 11391 632 11392 633 11393 634 11394 350 11395 350 11396 40 11397 353 11398 2 11399 417 11400 641 11401 569 11402 643 11403 644 11404 645 11405 646 11406 647 11407 2 11408 417 11409 650 11410 651 11411 40 11412 653 11413 276 11414 655 11415 656 11416 2 11417 417 11418 659 11419 660 11420 661 11421 662 11422 663 11423 664 11424 2 11425 728 11426 2 11427 10419 11428 11037 11429 11049 11430 11050 11431 11051 11432 11052 11433 11053 11434 11054 11435 11055 11436 11056 11437 845 11438 11058 11439 11059 11440 11060 11441 11061 11442 11062 11443 11063 11444 11064 11445 11065 11446 11066 11447 11067 11448 11068 11449 11069 11450 11070 11451 11071 11452 11072 11453 11073 11454 11074 11455 11075 11456 11076 11457 11077 11458 11078 11459 11079 11460 11080 11461 11081 11462 11082 11463 11083 11464 11084 11465 11085 11466 11086 11467 11087 11468 11088 11469 11089 11470 11090 11471 11091 11472 11092 11473 11093 11474 11094 11475 11095 11476 11096 11477 11097 11478 11098 11479 11099 11480 11100 11481 11101 11482 11102 11483 11103 11484 11104 11485 11105 11486 11106 11487 11107 11488 11108 11489 11109 11490 11110 11491 11111 11492 11112 11493 11113 11494 11114 11495 11115 11496 11116 11497 11117 11498 11118 11499 11119 11500 11120 11501 11121 11502 11122 11503 11123 11504 11124 11505 11125 11506 11126 11507 11127 11508 11128 11509 11129 11510 11130 11511 11131 11512 11132 11513 11133 11514 11134 11515 11135 11516 11136 11517 11 11518 11138 11519 11139 11520 11140 11521 2 11522 417 11523 11143 11524 932 11525 11145 11526 11146 11527 965 11528 154 11529 157 11530 11150 11531 11151 11532 1476 11533 2 11534 2 11535 2 11536 11156 11537 2 11538 11158 11539 2 11540 2 11541 2 11542 2 11543 2 11544 2 11545 2 11546 2 11547 2 11548 11168 11549 11169 11550 11170 11551 11171 11552 11172 11553 11173 11554 11174 11555 11175 11556 11176 11557 11177 11558 11178 11559 11179 11560 11180 11561 22 11562 11182 11563 4 11564 11 11565 11185 11566 88 11567 11 11568 11188 11569 98 11570 11190 11571 1538 11572 11192 11573 11193 11574 11194 11575 98 11576 845 11577 11 11578 11198 11579 932 11580 11200 11581 11201 11582 965 11583 154 11584 157 11585 11205 11586 11206 11587 11207 11588 845 11589 11 11590 11210 11591 11211 11592 11212 11593 350 11594 350 11595 353 11596 2 11597 417 11598 11218 11599 569 11600 11220 11601 11221 11602 11222 11603 11223 11604 2 11605 417 11606 11226 11607 11227 11608 11228 11609 11229 11610 11230 11611 11231 11612 2 11613 417 11614 11234 11615 11236 11616 138 11617 11 11618 140 11619 157 11620 158 11621 160 11622 162 11623 76 11624 124 11625 165 11626 11247 11627 11248 11628 138 11629 11 11630 140 11631 157 11632 2240 11633 2242 11634 2243 11635 2244 11636 2 11637 11320 11638 11638 11639 11638 11640 845 11641 11641 11642 11 11643 11643 11644 2 11645 417 11646 11646 11647 11647 11648 11648 11649 2727 11650 11650 11651 11651 11652 350 11653 350 11654 353 11655 2 11656 417 11657 11657 11658 569 11659 11659 11660 11660 11661 11661 11662 11662 11663 2 11664 417 11665 11665 11666 11666 11667 11667 11668 11668 11669 2804 11670 11670 11671 569 11672 11672 11673 2 11674 11674 11675 11675 11676 2 11677 3 11678 4 11679 2 11680 2 11681 2 11682 2 11683 11 11684 2 11685 2 11686 11686 11687 2 11688 11688 11689 22 11690 11690 11691 11691 11692 2 11693 11 11694 11 11695 11695 11696 11696 11697 11697 11698 22 11699 2 11700 2 11701 2 11702 11 11703 11703 11704 11 11705 11705 11706 11 11707 11707 11708 11708 11709 11709 11710 11710 11711 60 11712 11712 11713 2 11714 2 11715 11 11716 2 11717 2 11718 68 11719 129 11720 11720 11721 2 11722 2 11723 11723 11724 2 11725 11725 11726 11726 11727 2 11728 84 11729 85 11730 88 11731 132 11732 11 11733 11733 11734 11734 11735 98 11736 11736 11737 11737 11738 11738 11739 103 11740 103 11741 11741 11742 11742 11743 11743 11744 11744 11745 11745 11746 11746 11747 11747 11748 11748 11749 11749 11750 11750 11751 98 11752 2 11753 11753 11754 2 11755 2 11756 2 11757 2 11758 2 11759 2 11760 2 11761 2 11762 300 11763 2 11764 2 11765 2 11766 2 11767 2 11768 306 11769 2 11770 2 11771 2 11772 2 11773 2 11774 2 11775 2 11776 2 11777 2 11778 2 11779 2 11780 2 11781 2 11782 2 11783 2 11784 11784 11785 11785 11786 11786 11787 11787 11788 11788 11789 11789 11790 11790 11791 11791 11792 11792 11793 11793 11794 11794 11795 11795 11796 11796 11797 11797 11798 11798 11799 4 11800 2 11801 11801 11802 11802 11803 11803 11804 11804 11805 11805 11806 11806 11807 11807 11808 11808 11809 11809 11810 11810 11811 11811 11812 350 11813 350 11814 40 11815 353 11816 2 11817 417 11818 11818 11819 569 11820 11820 11821 11821 11822 11822 11823 11823 11824 11824 11825 2 11826 417 11827 11827 11828 11828 11829 40 11830 11830 11831 276 11832 11832 11833 11833 11834 2 11835 417 11836 11836 11837 11837 11838 11838 11839 11839 11840 11840 11841 11841 11842 2 11843 728 11844 2 11845 11845 11846 11846 11847 11847 11848 11848 11849 11849 11850 11850 11851 11851 11852 11852 11853 11853 11854 11854 11855 845 11856 11856 11857 11857 11858 11858 11859 11859 11860 11860 11861 11861 11862 11862 11863 11863 11864 11864 11865 11865 11866 11866 11867 11867 11868 11868 11869 11869 11870 11870 11871 11871 11872 11872 11873 11873 11874 11874 11875 11875 11876 11876 11877 11877 11878 11878 11879 11879 11880 11880 11881 11881 11882 11882 11883 11883 11884 11884 11885 11885 11886 11886 11887 11887 11888 11888 11889 11889 11890 11890 11891 11891 11892 11892 11893 11893 11894 11894 11895 11895 11896 11896 11897 11897 11898 11898 11899 11899 11900 11900 11901 11901 11902 11902 11903 11903 11904 11904 11905 11905 11906 11906 11907 11907 11908 11908 11909 11909 11910 11910 11911 11911 11912 11912 11913 11913 11914 11914 11915 11915 11916 11916 11917 11917 11918 11918 11919 11919 11920 11920 11921 11921 11922 11922 11923 11923 11924 11924 11925 11925 11926 11926 11927 11927 11928 11928 11929 11929 11930 11930 11931 11931 11932 11932 11933 11933 11934 11934 11935 11 11936 11936 11937 11937 11938 11938 11939 2 11940 417 11941 11941 11942 932 11943 11943 11944 11944 11945 965 11946 154 11947 157 11948 11948 11949 11949 11950 1476 11951 2 11952 2 11953 2 11954 11954 11955 2 11956 11956 11957 2 11958 2 11959 2 11960 2 11961 2 11962 2 11963 2 11964 2 11965 2 11966 11966 11967 11967 11968 11968 11969 11969 11970 11970 11971 11971 11972 11972 11973 11973 11974 11974 11975 11975 11976 11976 11977 11977 11978 11978 11979 22 11980 11980 11981 4 11982 11 11983 11983 11984 88 11985 11 11986 11986 11987 98 11988 11988 11989 1538 11990 11990 11991 11991 11992 11992 11993 98 11994 845 11995 11 11996 11996 11997 932 11998 11998 11999 11999 12000 965 12001 154 12002 157 12003 12003 12004 12004 12005 12005 12006 845 12007 11 12008 12008 12009 12009 12010 12010 12011 350 12012 350 12013 353 12014 2 12015 417 12016 12016 12017 569 12018 12018 12019 12019 12020 12020 12021 12021 12022 2 12023 417 12024 12024 12025 12025 12026 12026 12027 12027 12028 12028 12029 12029 12030 2 12031 417 12032 12032 12033 12033 12034 138 12035 11 12036 140 12037 157 12038 158 12039 160 12040 162 12041 76 12042 124 12043 165 12044 12044 12045 12045 12046 138 12047 11 12048 140 12049 157 12050 2240 12051 2242 12052 2243 12053 2244 12054 2 12055 12055 12056 12056 12057 2 12058 12058 12059 845 12060 12060 12061 11 12062 12062 12063 2 12064 417 12065 12065 12066 12066 12067 12067 12068 2727 12069 12069 12070 12070 12071 350 12072 350 12073 353 12074 2 12075 417 12076 12076 12077 569 12078 12078 12079 12079 12080 12080 12081 12081 12082 2 12083 417 12084 12084 12085 12085 12086 12086 12087 12087 12088 2804 12089 12089 12090 569 12091 12091 12092 2 12093 12093 12094 12094 12095 11738 12096 2 12097 12097 12098 12098 12099 12099 12100 12100 12101 12101 12102 2898 12103 12103 12104 68 12105 12105 12106 12106 12107 12107 12108 12108 12109 12109 12110 12110 12111 12111 12112 2 12113 12113 12114 12114 12115 12115 12116 12116 12117 12117 12118 12118 12119 2942 12120 2944 12121 12121 12122 12122 12123 12123 12124 12124 12125 12125 12126 350 12127 350 12128 40 12129 353 12130 2 12131 417 12132 12132 12133 569 12134 12134 12135 12135 12136 12136 12137 12137 12138 932 12139 12139 12140 12140 12141 12141 12142 965 12143 154 12144 157 12145 12145 12146 12146 12147 40 12148 12148 12149 12149 12150 2981 12151 2984 12152 2986 12153 2988 12154 76 12155 2990 12156 2991 12157 12157 12158 276 12159 12159 12160 2 12161 276 12162 76 12163 3971 12164 2829 12165 12165 12166 1851 12167 157 12168 2040 12169 2 12170 12170 12171 2 12172 154 12173 157 12174 12174 12175 12175 12176 12176 12177 12177 12178 12178 12179 5266 12180 12180 12181 157 12182 12182 12183 2 12184 276 12185 12185 12186 2 12187 276 12188 12188 12189 12189 12190 12190 12191 12191 12192 12192 12193 12193 12194 1851 12195 157 12196 12196 12197 12197 12198 12198 12199 12199 12200 276 12201 12201 12202 12202 12203 2 12204 417 12205 12205 12206 5298 12207 12207 12208 12208 12209 12209 12210 12210 12211 12211 12212 12212 12213 2898 12214 12214 12215 68 12216 12216 12217 12217 12218 12218 12219 12219 12220 12220 12221 12221 12222 12222 12223 2 12224 12224 12225 12225 12226 12226 12227 12227 12228 12228 12229 12229 12230 2942 12231 2944 12232 12232 12233 12233 12234 12234 12235 12235 12236 12236 12237 350 12238 350 12239 40 12240 353 12241 2 12242 417 12243 12243 12244 569 12245 12245 12246 12246 12247 12247 12248 12248 12249 932 12250 12250 12251 12251 12252 12252 12253 965 12254 154 12255 157 12256 12256 12257 12257 12258 40 12259 12259 12260 12260 12261 2981 12262 2984 12263 2986 12264 2988 12265 76 12266 2990 12267 2991 12268 12268 12269 276 12270 12270 12271 2 12272 276 12273 76 12274 3971 12275 2829 12276 12276 12277 1851 12278 157 12279 2040 12280 2 12281 12281 12282 2 12283 154 12284 157 12285 12285 12286 12286 12287 12287 12288 12288 12289 12289 12290 5266 12291 12291 12292 157 12293 12293 12294 2 12295 276 12296 12296 12297 2 12298 276 12299 12299 12300 12300 12301 12301 12302 12302 12303 12303 12304 12304 12305 1851 12306 157 12307 12307 12308 12308 12309 12309 12310 12310 12311 276 12312 12312 12313 12313 12314 2 12315 417 12316 12316 12317 5298 12318 12318 12319 12319 12320 845 12321 11641 12322 11 12323 11643 12324 2 12325 417 12326 11646 12327 11647 12328 11648 12329 2727 12330 11650 12331 11651 12332 350 12333 350 12334 353 12335 2 12336 417 12337 11657 12338 569 12339 11659 12340 11660 12341 11661 12342 11662 12343 2 12344 417 12345 11665 12346 11666 12347 11667 12348 11668 12349 2804 12350 11670 12351 569 12352 11672 12353 2 12354 11674 12355 11675 12356 2 12357 3 12358 4 12359 2 12360 2 12361 2 12362 2 12363 11 12364 2 12365 2 12366 11686 12367 2 12368 11688 12369 22 12370 11690 12371 11691 12372 2 12373 11 12374 11 12375 11695 12376 11696 12377 11697 12378 22 12379 2 12380 2 12381 2 12382 11 12383 11703 12384 11 12385 11705 12386 11 12387 11707 12388 11708 12389 11709 12390 11710 12391 60 12392 11712 12393 2 12394 2 12395 11 12396 2 12397 2 12398 68 12399 129 12400 11720 12401 2 12402 2 12403 11723 12404 2 12405 11725 12406 11726 12407 2 12408 84 12409 85 12410 88 12411 132 12412 11 12413 11733 12414 11734 12415 98 12416 11736 12417 11737 12418 11738 12419 103 12420 103 12421 11741 12422 11742 12423 11743 12424 11744 12425 11745 12426 11746 12427 11747 12428 11748 12429 11749 12430 11750 12431 98 12432 2 12433 11753 12434 2 12435 2 12436 2 12437 2 12438 2 12439 2 12440 2 12441 2 12442 300 12443 2 12444 2 12445 2 12446 2 12447 2 12448 306 12449 2 12450 2 12451 2 12452 2 12453 2 12454 2 12455 2 12456 2 12457 2 12458 2 12459 2 12460 2 12461 2 12462 2 12463 2 12464 11784 12465 11785 12466 11786 12467 11787 12468 11788 12469 11789 12470 11790 12471 11791 12472 11792 12473 11793 12474 11794 12475 11795 12476 11796 12477 11797 12478 11798 12479 4 12480 2 12481 11801 12482 11802 12483 11803 12484 11804 12485 11805 12486 11806 12487 11807 12488 11808 12489 11809 12490 11810 12491 11811 12492 350 12493 350 12494 40 12495 353 12496 2 12497 417 12498 11818 12499 569 12500 11820 12501 11821 12502 11822 12503 11823 12504 11824 12505 2 12506 417 12507 11827 12508 11828 12509 40 12510 11830 12511 276 12512 11832 12513 11833 12514 2 12515 417 12516 11836 12517 11837 12518 11838 12519 11839 12520 11840 12521 11841 12522 2 12523 728 12524 2 12525 11845 12526 11846 12527 11847 12528 11848 12529 11849 12530 11850 12531 11851 12532 11852 12533 11853 12534 11854 12535 845 12536 11856 12537 11857 12538 11858 12539 11859 12540 11860 12541 11861 12542 11862 12543 11863 12544 11864 12545 11865 12546 11866 12547 11867 12548 11868 12549 11869 12550 11870 12551 11871 12552 11872 12553 11873 12554 11874 12555 11875 12556 11876 12557 11877 12558 11878 12559 11879 12560 11880 12561 11881 12562 11882 12563 11883 12564 11884 12565 11885 12566 11886 12567 11887 12568 11888 12569 11889 12570 11890 12571 11891 12572 11892 12573 11893 12574 11894 12575 11895 12576 11896 12577 11897 12578 11898 12579 11899 12580 11900 12581 11901 12582 11902 12583 11903 12584 11904 12585 11905 12586 11906 12587 11907 12588 11908 12589 11909 12590 11910 12591 11911 12592 11912 12593 11913 12594 11914 12595 11915 12596 11916 12597 11917 12598 11918 12599 11919 12600 11920 12601 11921 12602 11922 12603 11923 12604 11924 12605 11925 12606 11926 12607 11927 12608 11928 12609 11929 12610 11930 12611 11931 12612 11932 12613 11933 12614 11934 12615 11 12616 11936 12617 11937 12618 11938 12619 2 12620 417 12621 11941 12622 932 12623 11943 12624 11944 12625 965 12626 154 12627 157 12628 11948 12629 11949 12630 1476 12631 2 12632 2 12633 2 12634 11954 12635 2 12636 11956 12637 2 12638 2 12639 2 12640 2 12641 2 12642 2 12643 2 12644 2 12645 2 12646 11966 12647 11967 12648 11968 12649 11969 12650 11970 12651 11971 12652 11972 12653 11973 12654 11974 12655 11975 12656 11976 12657 11977 12658 11978 12659 22 12660 11980 12661 4 12662 11 12663 11983 12664 88 12665 11 12666 11986 12667 98 12668 11988 12669 1538 12670 11990 12671 11991 12672 11992 12673 98 12674 845 12675 11 12676 11996 12677 932 12678 11998 12679 11999 12680 965 12681 154 12682 157 12683 12003 12684 12004 12685 12005 12686 845 12687 11 12688 12008 12689 12009 12690 12010 12691 350 12692 350 12693 353 12694 2 12695 417 12696 12016 12697 569 12698 12018 12699 12019 12700 12020 12701 12021 12702 2 12703 417 12704 12024 12705 12025 12706 12026 12707 12027 12708 12028 12709 12029 12710 2 12711 417 12712 12032 12713 12033 12714 138 12715 11 12716 140 12717 157 12718 158 12719 160 12720 162 12721 76 12722 124 12723 165 12724 12044 12725 12045 12726 138 12727 11 12728 140 12729 157 12730 2240 12731 2242 12732 2243 12733 2244 12734 2 12735 12055 12736 12056 12737 2 12738 12058 12739 845 12740 12060 12741 11 12742 12062 12743 2 12744 417 12745 12065 12746 12066 12747 12067 12748 2727 12749 12069 12750 12070 12751 350 12752 350 12753 353 12754 2 12755 417 12756 12076 12757 569 12758 12078 12759 12079 12760 12080 12761 12081 12762 2 12763 417 12764 12084 12765 12085 12766 12086 12767 12087 12768 2804 12769 12089 12770 569 12771 12091 12772 2 12773 12093 12774 12094 12775 11738 12776 2 12777 12097 12778 12098 12779 12099 12780 12100 12781 12101 12782 2898 12783 12103 12784 68 12785 12105 12786 12106 12787 12107 12788 12108 12789 12109 12790 12110 12791 12111 12792 12118 12793 2942 12794 2944 12795 12122 12796 932 12797 12139 12798 12140 12799 12141 12800 965 12801 154 12802 157 12803 12145 12804 12146 12805 12149 12806 2981 12807 2984 12808 2986 12809 2988 12810 76 12811 2990 12812 2991 12813 12157 12814 2 12815 276 12816 76 12817 3971 12818 2829 12819 12165 12820 1851 12821 157 12822 2040 12823 2 12824 12170 12825 2 12826 154 12827 157 12828 12174 12829 12175 12830 12176 12831 12177 12832 12178 12833 5266 12834 12180 12835 157 12836 12182 12837 2 12838 276 12839 12185 12840 2 12841 276 12842 12188 12843 12189 12844 12190 12845 12191 12846 12192 12847 12193 12848 1851 12849 157 12850 12196 12851 12197 12852 12198 12853 12199 12854 276 12855 12201 12856 12202 12857 2 12858 417 12859 12205 12860 5298 12861 12207 12862 12208 12863 12209 12864 12210 12865 12211 12866 12212 12867 2898 12868 12214 12869 68 12870 12216 12871 12217 12872 12218 12873 12219 12874 12220 12875 12221 12876 12222 12877 12229 12878 2942 12879 2944 12880 12233 12881 932 12882 12250 12883 12251 12884 12252 12885 965 12886 154 12887 157 12888 12256 12889 12257 12890 12260 12891 2981 12892 2984 12893 2986 12894 2988 12895 76 12896 2990 12897 2991 12898 12268 12899 2 12900 276 12901 76 12902 3971 12903 2829 12904 12276 12905 1851 12906 157 12907 2040 12908 2 12909 12281 12910 2 12911 154 12912 157 12913 12285 12914 12286 12915 12287 12916 12288 12917 12289 12918 5266 12919 12291 12920 157 12921 12293 12922 2 12923 276 12924 12296 12925 2 12926 276 12927 12299 12928 12300 12929 12301 12930 12302 12931 12303 12932 12304 12933 1851 12934 157 12935 12307 12936 12308 12937 12309 12938 12310 12939 276 12940 12312 12941 12313 12942 2 12943 417 12944 12316 12945 5298 12946 12318 12947 12319 12948 12948 12949 12949 12950 12950 12951 12951 12952 2 12953 417 12954 12954 12955 12955 12956 40 12957 12957 12958 276 12959 12959 12960 12960 12961 2 12962 417 12963 12963 12964 12964 12965 12965 12966 12966 12967 12967 12968 12968 12969 2 12970 728 12971 2 12972 12972 12973 12973 12974 12974 12975 12975 12976 12976 12977 12977 12978 12978 12979 12979 12980 12980 12981 12981 12982 845 12983 12983 12984 12984 12985 12985 12986 12986 12987 12987 12988 12988 12989 12989 12990 12990 12991 12991 12992 12992 12993 12993 12994 12994 12995 12995 12996 12996 12997 12997 12998 12998 12999 12999 13000 13000 13001 13001 13002 13002 13003 13003 13004 13004 13005 13005 13006 13006 13007 13007 13008 13008 13009 13009 13010 13010 13011 13011 13012 13012 13013 13013 13014 13014 13015 13015 13016 13016 13017 13017 13018 13018 13019 13019 13020 13020 13021 13021 13022 13022 13023 13023 13024 13024 13025 13025 13026 13026 13027 13027 13028 13028 13029 13029 13030 13030 13031 13031 13032 13032 13033 13033 13034 13034 13035 13035 13036 13036 13037 13037 13038 13038 13039 13039 13040 13040 13041 13041 13042 13042 13043 13043 13044 13044 13045 13045 13046 13046 13047 13047 13048 13048 13049 13049 13050 13050 13051 13051 13052 13052 13053 13053 13054 13054 13055 13055 13056 13056 13057 13057 13058 13058 13059 13059 13060 13060 13061 13061 13062 11 13063 13063 13064 13064 13065 13065 13066 2 13067 417 13068 13068 13069 932 13070 13070 13071 13071 13072 965 13073 154 13074 157 13075 13075 13076 13076 13077 1476 13078 2 13079 2 13080 2 13081 13081 13082 2 13083 13083 13084 2 13085 2 13086 2 13087 2 13088 2 13089 2 13090 2 13091 2 13092 2 13093 13093 13094 13094 13095 13095 13096 13096 13097 13097 13098 13098 13099 13099 13100 13100 13101 13101 13102 13102 13103 13103 13104 13104 13105 13105 13106 22 13107 13107 13108 4 13109 11 13110 13110 13111 88 13112 11 13113 13113 13114 98 13115 13115 13116 1538 13117 13117 13118 13118 13119 13119 13120 98 13121 845 13122 11 13123 13123 13124 932 13125 13125 13126 13126 13127 965 13128 154 13129 157 13130 13130 13131 13131 13132 13132 13133 845 13134 11 13135 13135 13136 13136 13137 13137 13138 350 13139 350 13140 353 13141 2 13142 417 13143 13143 13144 569 13145 13145 13146 13146 13147 13147 13148 13148 13149 2 13150 417 13151 13151 13152 13152 13153 13153 13154 13154 13155 13155 13156 13156 13157 2 13158 417 13159 13159 13160 13160 13161 138 13162 11 13163 140 13164 157 13165 158 13166 160 13167 162 13168 76 13169 124 13170 165 13171 13171 13172 13172 13173 138 13174 11 13175 140 13176 157 13177 2240 13178 2242 13179 2243 13180 2244 13181 2 13182 2 13183 3 13184 4 13185 2 13186 2 13187 2 13188 2 13189 11 13190 2 13191 2 13192 365 13193 2 13194 367 13195 22 13196 369 13197 370 13198 2 13199 11 13200 11 13201 374 13202 375 13203 376 13204 22 13205 2 13206 2 13207 2 13208 11 13209 382 13210 11 13211 384 13212 11 13213 386 13214 387 13215 388 13216 389 13217 60 13218 391 13219 2 13220 2 13221 11 13222 2 13223 2 13224 68 13225 129 13226 399 13227 2 13228 2 13229 402 13230 2 13231 404 13232 405 13233 2 13234 84 13235 85 13236 88 13237 132 13238 11 13239 412 13240 413 13241 98 13242 415 13243 416 13244 13244 13245 103 13246 103 13247 420 13248 421 13249 422 13250 423 13251 424 13252 425 13253 426 13254 427 13255 428 13256 429 13257 98 13258 2 13259 432 13260 2 13261 2 13262 2 13263 2 13264 2 13265 2 13266 2 13267 2 13268 300 13269 2 13270 2 13271 2 13272 2 13273 2 13274 306 13275 2 13276 2 13277 2 13278 2 13279 2 13280 2 13281 2 13282 2 13283 2 13284 2 13285 2 13286 2 13287 2 13288 2 13289 2 13290 463 13291 464 13292 465 13293 466 13294 467 13295 468 13296 469 13297 470 13298 471 13299 472 13300 473 13301 474 13302 475 13303 476 13304 477 13305 4 13306 2 13307 480 13308 481 13309 482 13310 483 13311 484 13312 485 13313 486 13314 487 13315 488 13316 489 13317 490 13318 350 13319 350 13320 40 13321 353 13322 2 13323 417 13324 497 13325 569 13326 11235 13327 12948 13328 12949 13329 12950 13330 12951 13331 2 13332 417 13333 12954 13334 12955 13335 40 13336 12957 13337 276 13338 12959 13339 12960 13340 2 13341 417 13342 12963 13343 12964 13344 12965 13345 12966 13346 12967 13347 12968 13348 2 13349 728 13350 2 13351 12972 13352 12973 13353 12974 13354 12975 13355 12976 13356 12977 13357 12978 13358 12979 13359 12980 13360 12981 13361 845 13362 12983 13363 12984 13364 12985 13365 12986 13366 12987 13367 12988 13368 12989 13369 12990 13370 12991 13371 12992 13372 12993 13373 12994 13374 12995 13375 12996 13376 12997 13377 12998 13378 12999 13379 13000 13380 13001 13381 13002 13382 13003 13383 13004 13384 13005 13385 13006 13386 13007 13387 13008 13388 13009 13389 13010 13390 13011 13391 13012 13392 13013 13393 13014 13394 13015 13395 13016 13396 13017 13397 13018 13398 13019 13399 13020 13400 13021 13401 13022 13402 13023 13403 13024 13404 13025 13405 13026 13406 13027 13407 13028 13408 13029 13409 13030 13410 13031 13411 13032 13412 13033 13413 13034 13414 13035 13415 13036 13416 13037 13417 13038 13418 13039 13419 13040 13420 13041 13421 13042 13422 13043 13423 13044 13424 13045 13425 13046 13426 13047 13427 13048 13428 13049 13429 13050 13430 13051 13431 13052 13432 13053 13433 13054 13434 13055 13435 13056 13436 13057 13437 13058 13438 13059 13439 13060 13440 13061 13441 11 13442 13063 13443 13064 13444 13065 13445 2 13446 417 13447 13068 13448 932 13449 13070 13450 13071 13451 965 13452 154 13453 157 13454 13075 13455 13076 13456 1476 13457 2 13458 2 13459 2 13460 13081 13461 2 13462 13083 13463 2 13464 2 13465 2 13466 2 13467 2 13468 2 13469 2 13470 2 13471 2 13472 13093 13473 13094 13474 13095 13475 13096 13476 13097 13477 13098 13478 13099 13479 13100 13480 13101 13481 13102 13482 13103 13483 13104 13484 13105 13485 22 13486 13107 13487 4 13488 11 13489 13110 13490 88 13491 11 13492 13113 13493 98 13494 13115 13495 1538 13496 13117 13497 13118 13498 13119 13499 98 13500 845 13501 11 13502 13123 13503 932 13504 13125 13505 13126 13506 965 13507 154 13508 157 13509 13130 13510 13131 13511 13132 13512 845 13513 11 13514 13135 13515 13136 13516 13137 13517 350 13518 350 13519 353 13520 2 13521 417 13522 13143 13523 569 13524 13145 13525 13146 13526 13147 13527 13148 13528 2 13529 417 13530 13151 13531 13152 13532 13153 13533 13154 13534 13155 13535 13156 13536 2 13537 417 13538 13159 13539 13160 13540 138 13541 11 13542 140 13543 157 13544 158 13545 160 13546 162 13547 76 13548 124 13549 165 13550 13171 13551 13172 13552 138 13553 11 13554 140 13555 157 13556 2240 13557 2242 13558 2243 13559 2244 13560 2 13561 13244 13562 13562 13563 13562 13564 845 13565 13565 13566 11 13567 13567 13568 2 13569 417 13570 13570 13571 13571 13572 13572 13573 2727 13574 13574 13575 13575 13576 350 13577 350 13578 353 13579 2 13580 417 13581 13581 13582 569 13583 13583 13584 13584 13585 13585 13586 13586 13587 2 13588 417 13589 13589 13590 13590 13591 13591 13592 13592 13593 2804 13594 13594 13595 569 13596 13596 13597 2 13598 13598 13599 13599 13600 2 13601 3 13602 4 13603 2 13604 2 13605 2 13606 2 13607 11 13608 2 13609 2 13610 13610 13611 2 13612 13612 13613 22 13614 13614 13615 13615 13616 2 13617 11 13618 11 13619 13619 13620 13620 13621 13621 13622 22 13623 2 13624 2 13625 2 13626 11 13627 13627 13628 11 13629 13629 13630 11 13631 13631 13632 13632 13633 13633 13634 13634 13635 60 13636 13636 13637 2 13638 2 13639 11 13640 2 13641 2 13642 68 13643 129 13644 13644 13645 2 13646 2 13647 13647 13648 2 13649 13649 13650 13650 13651 2 13652 84 13653 85 13654 88 13655 132 13656 11 13657 13657 13658 13658 13659 98 13660 13660 13661 13661 13662 13662 13663 103 13664 103 13665 13665 13666 13666 13667 13667 13668 13668 13669 13669 13670 13670 13671 13671 13672 13672 13673 13673 13674 13674 13675 98 13676 2 13677 13677 13678 2 13679 2 13680 2 13681 2 13682 2 13683 2 13684 2 13685 2 13686 300 13687 2 13688 2 13689 2 13690 2 13691 2 13692 306 13693 2 13694 2 13695 2 13696 2 13697 2 13698 2 13699 2 13700 2 13701 2 13702 2 13703 2 13704 2 13705 2 13706 2 13707 2 13708 13708 13709 13709 13710 13710 13711 13711 13712 13712 13713 13713 13714 13714 13715 13715 13716 13716 13717 13717 13718 13718 13719 13719 13720 13720 13721 13721 13722 13722 13723 4 13724 2 13725 13725 13726 13726 13727 13727 13728 13728 13729 13729 13730 13730 13731 13731 13732 13732 13733 13733 13734 13734 13735 13735 13736 350 13737 350 13738 40 13739 353 13740 2 13741 417 13742 13742 13743 569 13744 13744 13745 13745 13746 13746 13747 13747 13748 13748 13749 2 13750 417 13751 13751 13752 13752 13753 40 13754 13754 13755 276 13756 13756 13757 13757 13758 2 13759 417 13760 13760 13761 13761 13762 13762 13763 13763 13764 13764 13765 13765 13766 2 13767 728 13768 2 13769 13769 13770 13770 13771 13771 13772 13772 13773 13773 13774 13774 13775 13775 13776 13776 13777 13777 13778 13778 13779 845 13780 13780 13781 13781 13782 13782 13783 13783 13784 13784 13785 13785 13786 13786 13787 13787 13788 13788 13789 13789 13790 13790 13791 13791 13792 13792 13793 13793 13794 13794 13795 13795 13796 13796 13797 13797 13798 13798 13799 13799 13800 13800 13801 13801 13802 13802 13803 13803 13804 13804 13805 13805 13806 13806 13807 13807 13808 13808 13809 13809 13810 13810 13811 13811 13812 13812 13813 13813 13814 13814 13815 13815 13816 13816 13817 13817 13818 13818 13819 13819 13820 13820 13821 13821 13822 13822 13823 13823 13824 13824 13825 13825 13826 13826 13827 13827 13828 13828 13829 13829 13830 13830 13831 13831 13832 13832 13833 13833 13834 13834 13835 13835 13836 13836 13837 13837 13838 13838 13839 13839 13840 13840 13841 13841 13842 13842 13843 13843 13844 13844 13845 13845 13846 13846 13847 13847 13848 13848 13849 13849 13850 13850 13851 13851 13852 13852 13853 13853 13854 13854 13855 13855 13856 13856 13857 13857 13858 13858 13859 11 13860 13860 13861 13861 13862 13862 13863 2 13864 417 13865 13865 13866 932 13867 13867 13868 13868 13869 965 13870 154 13871 157 13872 13872 13873 13873 13874 1476 13875 2 13876 2 13877 2 13878 13878 13879 2 13880 13880 13881 2 13882 2 13883 2 13884 2 13885 2 13886 2 13887 2 13888 2 13889 2 13890 13890 13891 13891 13892 13892 13893 13893 13894 13894 13895 13895 13896 13896 13897 13897 13898 13898 13899 13899 13900 13900 13901 13901 13902 13902 13903 22 13904 13904 13905 4 13906 11 13907 13907 13908 88 13909 11 13910 13910 13911 98 13912 13912 13913 1538 13914 13914 13915 13915 13916 13916 13917 98 13918 845 13919 11 13920 13920 13921 932 13922 13922 13923 13923 13924 965 13925 154 13926 157 13927 13927 13928 13928 13929 13929 13930 845 13931 11 13932 13932 13933 13933 13934 13934 13935 350 13936 350 13937 353 13938 2 13939 417 13940 13940 13941 569 13942 13942 13943 13943 13944 13944 13945 13945 13946 2 13947 417 13948 13948 13949 13949 13950 13950 13951 13951 13952 13952 13953 13953 13954 2 13955 417 13956 13956 13957 13957 13958 138 13959 11 13960 140 13961 157 13962 158 13963 160 13964 162 13965 76 13966 124 13967 165 13968 13968 13969 13969 13970 138 13971 11 13972 140 13973 157 13974 2240 13975 2242 13976 2243 13977 2244 13978 2 13979 13979 13980 13980 13981 2 13982 13982 13983 845 13984 13984 13985 11 13986 13986 13987 2 13988 417 13989 13989 13990 13990 13991 13991 13992 2727 13993 13993 13994 13994 13995 350 13996 350 13997 353 13998 2 13999 417 14000 14000 14001 569 14002 14002 14003 14003 14004 14004 14005 14005 14006 2 14007 417 14008 14008 14009 14009 14010 14010 14011 14011 14012 2804 14013 14013 14014 569 14015 14015 14016 2 14017 14017 14018 14018 14019 13662 14020 2 14021 14021 14022 14022 14023 14023 14024 14024 14025 14025 14026 2898 14027 14027 14028 68 14029 14029 14030 14030 14031 14031 14032 14032 14033 14033 14034 14034 14035 14035 14036 2 14037 14037 14038 14038 14039 14039 14040 14040 14041 14041 14042 14042 14043 2942 14044 2944 14045 14045 14046 14046 14047 14047 14048 14048 14049 14049 14050 350 14051 350 14052 40 14053 353 14054 2 14055 417 14056 14056 14057 569 14058 14058 14059 14059 14060 14060 14061 14061 14062 932 14063 14063 14064 14064 14065 14065 14066 965 14067 154 14068 157 14069 14069 14070 14070 14071 40 14072 14072 14073 14073 14074 2981 14075 2984 14076 2986 14077 2988 14078 76 14079 2990 14080 2991 14081 14081 14082 276 14083 14083 14084 2 14085 276 14086 76 14087 3971 14088 2829 14089 14089 14090 1851 14091 157 14092 2040 14093 2 14094 14094 14095 2 14096 154 14097 157 14098 14098 14099 14099 14100 14100 14101 14101 14102 14102 14103 5266 14104 14104 14105 157 14106 14106 14107 2 14108 276 14109 14109 14110 2 14111 276 14112 14112 14113 14113 14114 14114 14115 14115 14116 14116 14117 14117 14118 1851 14119 157 14120 14120 14121 14121 14122 14122 14123 14123 14124 276 14125 14125 14126 14126 14127 2 14128 417 14129 14129 14130 5298 14131 14131 14132 14132 14133 14133 14134 14134 14135 14135 14136 14136 14137 2898 14138 14138 14139 68 14140 14140 14141 14141 14142 14142 14143 14143 14144 14144 14145 14145 14146 14146 14147 2 14148 14148 14149 14149 14150 14150 14151 14151 14152 14152 14153 14153 14154 2942 14155 2944 14156 14156 14157 14157 14158 14158 14159 14159 14160 14160 14161 350 14162 350 14163 40 14164 353 14165 2 14166 417 14167 14167 14168 569 14169 14169 14170 14170 14171 14171 14172 14172 14173 932 14174 14174 14175 14175 14176 14176 14177 965 14178 154 14179 157 14180 14180 14181 14181 14182 40 14183 14183 14184 14184 14185 2981 14186 2984 14187 2986 14188 2988 14189 76 14190 2990 14191 2991 14192 14192 14193 276 14194 14194 14195 2 14196 276 14197 76 14198 3971 14199 2829 14200 14200 14201 1851 14202 157 14203 2040 14204 2 14205 14205 14206 2 14207 154 14208 157 14209 14209 14210 14210 14211 14211 14212 14212 14213 14213 14214 5266 14215 14215 14216 157 14217 14217 14218 2 14219 276 14220 14220 14221 2 14222 276 14223 14223 14224 14224 14225 14225 14226 14226 14227 14227 14228 14228 14229 1851 14230 157 14231 14231 14232 14232 14233 14233 14234 14234 14235 276 14236 14236 14237 14237 14238 2 14239 417 14240 14240 14241 5298 14242 14242 14243 14243 14244 14244 14245 845 14246 13565 14247 11 14248 13567 14249 2 14250 417 14251 13570 14252 13571 14253 13572 14254 2727 14255 13574 14256 13575 14257 350 14258 350 14259 353 14260 2 14261 417 14262 13581 14263 569 14264 13583 14265 13584 14266 13585 14267 13586 14268 2 14269 417 14270 13589 14271 13590 14272 13591 14273 13592 14274 2804 14275 13594 14276 569 14277 13596 14278 2 14279 13598 14280 13599 14281 2 14282 3 14283 4 14284 2 14285 2 14286 2 14287 2 14288 11 14289 2 14290 2 14291 13610 14292 2 14293 13612 14294 22 14295 13614 14296 13615 14297 2 14298 11 14299 11 14300 13619 14301 13620 14302 13621 14303 22 14304 2 14305 2 14306 2 14307 11 14308 13627 14309 11 14310 13629 14311 11 14312 13631 14313 13632 14314 13633 14315 13634 14316 60 14317 13636 14318 2 14319 2 14320 11 14321 2 14322 2 14323 68 14324 129 14325 13644 14326 2 14327 2 14328 13647 14329 2 14330 13649 14331 13650 14332 2 14333 84 14334 85 14335 88 14336 132 14337 11 14338 13657 14339 13658 14340 98 14341 13660 14342 13661 14343 13662 14344 103 14345 103 14346 13665 14347 13666 14348 13667 14349 13668 14350 13669 14351 13670 14352 13671 14353 13672 14354 13673 14355 13674 14356 98 14357 2 14358 13677 14359 2 14360 2 14361 2 14362 2 14363 2 14364 2 14365 2 14366 2 14367 300 14368 2 14369 2 14370 2 14371 2 14372 2 14373 306 14374 2 14375 2 14376 2 14377 2 14378 2 14379 2 14380 2 14381 2 14382 2 14383 2 14384 2 14385 2 14386 2 14387 2 14388 2 14389 13708 14390 13709 14391 13710 14392 13711 14393 13712 14394 13713 14395 13714 14396 13715 14397 13716 14398 13717 14399 13718 14400 13719 14401 13720 14402 13721 14403 13722 14404 4 14405 2 14406 13725 14407 13726 14408 13727 14409 13728 14410 13729 14411 13730 14412 13731 14413 13732 14414 13733 14415 13734 14416 13735 14417 350 14418 350 14419 40 14420 353 14421 2 14422 417 14423 13742 14424 569 14425 13744 14426 13745 14427 13746 14428 13747 14429 13748 14430 2 14431 417 14432 13751 14433 13752 14434 40 14435 13754 14436 276 14437 13756 14438 13757 14439 2 14440 417 14441 13760 14442 13761 14443 13762 14444 13763 14445 13764 14446 13765 14447 2 14448 728 14449 2 14450 13769 14451 13770 14452 13771 14453 13772 14454 13773 14455 13774 14456 13775 14457 13776 14458 13777 14459 13778 14460 845 14461 13780 14462 13781 14463 13782 14464 13783 14465 13784 14466 13785 14467 13786 14468 13787 14469 13788 14470 13789 14471 13790 14472 13791 14473 13792 14474 13793 14475 13794 14476 13795 14477 13796 14478 13797 14479 13798 14480 13799 14481 13800 14482 13801 14483 13802 14484 13803 14485 13804 14486 13805 14487 13806 14488 13807 14489 13808 14490 13809 14491 13810 14492 13811 14493 13812 14494 13813 14495 13814 14496 13815 14497 13816 14498 13817 14499 13818 14500 13819 14501 13820 14502 13821 14503 13822 14504 13823 14505 13824 14506 13825 14507 13826 14508 13827 14509 13828 14510 13829 14511 13830 14512 13831 14513 13832 14514 13833 14515 13834 14516 13835 14517 13836 14518 13837 14519 13838 14520 13839 14521 13840 14522 13841 14523 13842 14524 13843 14525 13844 14526 13845 14527 13846 14528 13847 14529 13848 14530 13849 14531 13850 14532 13851 14533 13852 14534 13853 14535 13854 14536 13855 14537 13856 14538 13857 14539 13858 14540 11 14541 13860 14542 13861 14543 13862 14544 2 14545 417 14546 13865 14547 932 14548 13867 14549 13868 14550 965 14551 154 14552 157 14553 13872 14554 13873 14555 1476 14556 2 14557 2 14558 2 14559 13878 14560 2 14561 13880 14562 2 14563 2 14564 2 14565 2 14566 2 14567 2 14568 2 14569 2 14570 2 14571 13890 14572 13891 14573 13892 14574 13893 14575 13894 14576 13895 14577 13896 14578 13897 14579 13898 14580 13899 14581 13900 14582 13901 14583 13902 14584 22 14585 13904 14586 4 14587 11 14588 13907 14589 88 14590 11 14591 13910 14592 98 14593 13912 14594 1538 14595 13914 14596 13915 14597 13916 14598 98 14599 845 14600 11 14601 13920 14602 932 14603 13922 14604 13923 14605 965 14606 154 14607 157 14608 13927 14609 13928 14610 13929 14611 845 14612 11 14613 13932 14614 13933 14615 13934 14616 350 14617 350 14618 353 14619 2 14620 417 14621 13940 14622 569 14623 13942 14624 13943 14625 13944 14626 13945 14627 2 14628 417 14629 13948 14630 13949 14631 13950 14632 13951 14633 13952 14634 13953 14635 2 14636 417 14637 13956 14638 13957 14639 138 14640 11 14641 140 14642 157 14643 158 14644 160 14645 162 14646 76 14647 124 14648 165 14649 13968 14650 13969 14651 138 14652 11 14653 140 14654 157 14655 2240 14656 2242 14657 2243 14658 2244 14659 2 14660 13979 14661 13980 14662 2 14663 13982 14664 845 14665 13984 14666 11 14667 13986 14668 2 14669 417 14670 13989 14671 13990 14672 13991 14673 2727 14674 13993 14675 13994 14676 350 14677 350 14678 353 14679 2 14680 417 14681 14000 14682 569 14683 14002 14684 14003 14685 14004 14686 14005 14687 2 14688 417 14689 14008 14690 14009 14691 14010 14692 14011 14693 2804 14694 14013 14695 569 14696 14015 14697 2 14698 14017 14699 14018 14700 13662 14701 2 14702 14021 14703 14022 14704 14023 14705 14024 14706 14025 14707 2898 14708 14027 14709 68 14710 14029 14711 14030 14712 14031 14713 14032 14714 14033 14715 14034 14716 14035 14717 14042 14718 2942 14719 2944 14720 14046 14721 932 14722 14063 14723 14064 14724 14065 14725 965 14726 154 14727 157 14728 14069 14729 14070 14730 14073 14731 2981 14732 2984 14733 2986 14734 2988 14735 76 14736 2990 14737 2991 14738 14081 14739 2 14740 276 14741 76 14742 3971 14743 2829 14744 14089 14745 1851 14746 157 14747 2040 14748 2 14749 14094 14750 2 14751 154 14752 157 14753 14098 14754 14099 14755 14100 14756 14101 14757 14102 14758 5266 14759 14104 14760 157 14761 14106 14762 2 14763 276 14764 14109 14765 2 14766 276 14767 14112 14768 14113 14769 14114 14770 14115 14771 14116 14772 14117 14773 1851 14774 157 14775 14120 14776 14121 14777 14122 14778 14123 14779 276 14780 14125 14781 14126 14782 2 14783 417 14784 14129 14785 5298 14786 14131 14787 14132 14788 14133 14789 14134 14790 14135 14791 14136 14792 2898 14793 14138 14794 68 14795 14140 14796 14141 14797 14142 14798 14143 14799 14144 14800 14145 14801 14146 14802 14153 14803 2942 14804 2944 14805 14157 14806 932 14807 14174 14808 14175 14809 14176 14810 965 14811 154 14812 157 14813 14180 14814 14181 14815 14184 14816 2981 14817 2984 14818 2986 14819 2988 14820 76 14821 2990 14822 2991 14823 14192 14824 2 14825 276 14826 76 14827 3971 14828 2829 14829 14200 14830 1851 14831 157 14832 2040 14833 2 14834 14205 14835 2 14836 154 14837 157 14838 14209 14839 14210 14840 14211 14841 14212 14842 14213 14843 5266 14844 14215 14845 157 14846 14217 14847 2 14848 276 14849 14220 14850 2 14851 276 14852 14223 14853 14224 14854 14225 14855 14226 14856 14227 14857 14228 14858 1851 14859 157 14860 14231 14861 14232 14862 14233 14863 14234 14864 276 14865 14236 14866 14237 14867 2 14868 417 14869 14240 14870 5298 14871 14242 14872 14243 14873 569 14874 14874 14875 14875 14876 14876 14877 14877 14878 14878 14879 2 14880 417 14881 14881 14882 14882 14883 40 14884 14884 14885 276 14886 14886 14887 14887 14888 2 14889 417 14890 14890 14891 14891 14892 14892 14893 14893 14894 14894 14895 14895 14896 2 14897 728 14898 2 14899 14899 14900 14900 14901 14901 14902 14902 14903 14903 14904 14904 14905 14905 14906 14906 14907 14907 14908 14908 14909 845 14910 14910 14911 14911 14912 14912 14913 14913 14914 14914 14915 14915 14916 14916 14917 14917 14918 14918 14919 14919 14920 14920 14921 14921 14922 14922 14923 14923 14924 14924 14925 14925 14926 14926 14927 14927 14928 14928 14929 14929 14930 14930 14931 14931 14932 14932 14933 14933 14934 14934 14935 14935 14936 14936 14937 14937 14938 14938 14939 14939 14940 14940 14941 14941 14942 14942 14943 14943 14944 14944 14945 14945 14946 14946 14947 14947 14948 14948 14949 14949 14950 14950 14951 14951 14952 14952 14953 14953 14954 14954 14955 14955 14956 14956 14957 14957 14958 14958 14959 14959 14960 14960 14961 14961 14962 14962 14963 14963 14964 14964 14965 14965 14966 14966 14967 14967 14968 14968 14969 14969 14970 14970 14971 14971 14972 14972 14973 14973 14974 14974 14975 14975 14976 14976 14977 14977 14978 14978 14979 14979 14980 14980 14981 14981 14982 14982 14983 14983 14984 14984 14985 14985 14986 14986 14987 14987 14988 14988 14989 11 14990 14990 14991 14991 14992 14992 14993 2 14994 417 14995 14995 14996 932 14997 14997 14998 14998 14999 965 15000 154 15001 157 15002 15002 15003 15003 15004 1476 15005 2 15006 2 15007 2 15008 15008 15009 2 15010 15010 15011 2 15012 2 15013 2 15014 2 15015 2 15016 2 15017 2 15018 2 15019 2 15020 15020 15021 15021 15022 15022 15023 15023 15024 15024 15025 15025 15026 15026 15027 15027 15028 15028 15029 15029 15030 15030 15031 15031 15032 15032 15033 22 15034 15034 15035 4 15036 11 15037 15037 15038 88 15039 11 15040 15040 15041 98 15042 15042 15043 1538 15044 15044 15045 15045 15046 15046 15047 98 15048 845 15049 11 15050 15050 15051 932 15052 15052 15053 15053 15054 965 15055 154 15056 157 15057 15057 15058 15058 15059 15059 15060 845 15061 11 15062 15062 15063 15063 15064 15064 15065 350 15066 350 15067 353 15068 2 15069 417 15070 15070 15071 569 15072 15072 15073 15073 15074 15074 15075 15075 15076 2 15077 417 15078 15078 15079 15079 15080 15080 15081 15081 15082 15082 15083 15083 15084 2 15085 417 15086 15086 15087 15087 15088 138 15089 11 15090 140 15091 157 15092 158 15093 160 15094 162 15095 76 15096 124 15097 165 15098 15098 15099 15099 15100 138 15101 11 15102 140 15103 157 15104 2240 15105 2242 15106 2243 15107 2244 15108 2 15109 2 15110 3 15111 4 15112 2 15113 2 15114 2 15115 2 15116 11 15117 2 15118 2 15119 224 15120 2 15121 226 15122 22 15123 228 15124 229 15125 2 15126 11 15127 11 15128 233 15129 234 15130 235 15131 22 15132 2 15133 2 15134 2 15135 11 15136 241 15137 11 15138 243 15139 11 15140 245 15141 246 15142 247 15143 248 15144 60 15145 250 15146 2 15147 2 15148 11 15149 2 15150 2 15151 68 15152 129 15153 258 15154 2 15155 2 15156 261 15157 2 15158 263 15159 264 15160 2 15161 84 15162 85 15163 88 15164 132 15165 11 15166 271 15167 272 15168 98 15169 274 15170 275 15171 15171 15172 103 15173 103 15174 279 15175 280 15176 281 15177 282 15178 283 15179 284 15180 285 15181 286 15182 287 15183 288 15184 98 15185 2 15186 291 15187 2 15188 2 15189 2 15190 2 15191 2 15192 2 15193 2 15194 2 15195 300 15196 2 15197 2 15198 2 15199 2 15200 2 15201 306 15202 2 15203 2 15204 2 15205 2 15206 2 15207 2 15208 2 15209 2 15210 2 15211 2 15212 2 15213 2 15214 2 15215 2 15216 2 15217 322 15218 323 15219 324 15220 325 15221 326 15222 327 15223 328 15224 329 15225 330 15226 331 15227 332 15228 333 15229 334 15230 335 15231 336 15232 4 15233 2 15234 339 15235 340 15236 341 15237 342 15238 343 15239 344 15240 345 15241 346 15242 347 15243 348 15244 349 15245 350 15246 350 15247 40 15248 353 15249 2 15250 417 15251 14244 15252 569 15253 14874 15254 14875 15255 14876 15256 14877 15257 14878 15258 2 15259 417 15260 14881 15261 14882 15262 40 15263 14884 15264 276 15265 14886 15266 14887 15267 2 15268 417 15269 14890 15270 14891 15271 14892 15272 14893 15273 14894 15274 14895 15275 2 15276 728 15277 2 15278 14899 15279 14900 15280 14901 15281 14902 15282 14903 15283 14904 15284 14905 15285 14906 15286 14907 15287 14908 15288 845 15289 14910 15290 14911 15291 14912 15292 14913 15293 14914 15294 14915 15295 14916 15296 14917 15297 14918 15298 14919 15299 14920 15300 14921 15301 14922 15302 14923 15303 14924 15304 14925 15305 14926 15306 14927 15307 14928 15308 14929 15309 14930 15310 14931 15311 14932 15312 14933 15313 14934 15314 14935 15315 14936 15316 14937 15317 14938 15318 14939 15319 14940 15320 14941 15321 14942 15322 14943 15323 14944 15324 14945 15325 14946 15326 14947 15327 14948 15328 14949 15329 14950 15330 14951 15331 14952 15332 14953 15333 14954 15334 14955 15335 14956 15336 14957 15337 14958 15338 14959 15339 14960 15340 14961 15341 14962 15342 14963 15343 14964 15344 14965 15345 14966 15346 14967 15347 14968 15348 14969 15349 14970 15350 14971 15351 14972 15352 14973 15353 14974 15354 14975 15355 14976 15356 14977 15357 14978 15358 14979 15359 14980 15360 14981 15361 14982 15362 14983 15363 14984 15364 14985 15365 14986 15366 14987 15367 14988 15368 11 15369 14990 15370 14991 15371 14992 15372 2 15373 417 15374 14995 15375 932 15376 14997 15377 14998 15378 965 15379 154 15380 157 15381 15002 15382 15003 15383 1476 15384 2 15385 2 15386 2 15387 15008 15388 2 15389 15010 15390 2 15391 2 15392 2 15393 2 15394 2 15395 2 15396 2 15397 2 15398 2 15399 15020 15400 15021 15401 15022 15402 15023 15403 15024 15404 15025 15405 15026 15406 15027 15407 15028 15408 15029 15409 15030 15410 15031 15411 15032 15412 22 15413 15034 15414 4 15415 11 15416 15037 15417 88 15418 11 15419 15040 15420 98 15421 15042 15422 1538 15423 15044 15424 15045 15425 15046 15426 98 15427 845 15428 11 15429 15050 15430 932 15431 15052 15432 15053 15433 965 15434 154 15435 157 15436 15057 15437 15058 15438 15059 15439 845 15440 11 15441 15062 15442 15063 15443 15064 15444 350 15445 350 15446 353 15447 2 15448 417 15449 15070 15450 569 15451 15072 15452 15073 15453 15074 15454 15075 15455 2 15456 417 15457 15078 15458 15079 15459 15080 15460 15081 15461 15082 15462 15083 15463 2 15464 417 15465 15086 15466 15087 15467 138 15468 11 15469 140 15470 157 15471 158 15472 160 15473 162 15474 76 15475 124 15476 165 15477 15098 15478 15099 15479 138 15480 11 15481 140 15482 157 15483 2240 15484 2242 15485 2243 15486 2244 15487 2 15488 15171 15489 15489 15490 15489 15491 845 15492 15492 15493 11 15494 15494 15495 2 15496 417 15497 15497 15498 15498 15499 15499 15500 2727 15501 15501 15502 15502 15503 350 15504 350 15505 353 15506 2 15507 417 15508 15508 15509 569 15510 15510 15511 15511 15512 15512 15513 15513 15514 2 15515 417 15516 15516 15517 15517 15518 15518 15519 15519 15520 2804 15521 15521 15522 569 15523 15523 15524 2 15525 15525 15526 15526 15527 2 15528 3 15529 4 15530 2 15531 2 15532 2 15533 2 15534 11 15535 2 15536 2 15537 15537 15538 2 15539 15539 15540 22 15541 15541 15542 15542 15543 2 15544 11 15545 11 15546 15546 15547 15547 15548 15548 15549 22 15550 2 15551 2 15552 2 15553 11 15554 15554 15555 11 15556 15556 15557 11 15558 15558 15559 15559 15560 15560 15561 15561 15562 60 15563 15563 15564 2 15565 2 15566 11 15567 2 15568 2 15569 68 15570 129 15571 15571 15572 2 15573 2 15574 15574 15575 2 15576 15576 15577 15577 15578 2 15579 84 15580 85 15581 88 15582 132 15583 11 15584 15584 15585 15585 15586 98 15587 15587 15588 15588 15589 15589 15590 103 15591 103 15592 15592 15593 15593 15594 15594 15595 15595 15596 15596 15597 15597 15598 15598 15599 15599 15600 15600 15601 15601 15602 98 15603 2 15604 15604 15605 2 15606 2 15607 2 15608 2 15609 2 15610 2 15611 2 15612 2 15613 300 15614 2 15615 2 15616 2 15617 2 15618 2 15619 306 15620 2 15621 2 15622 2 15623 2 15624 2 15625 2 15626 2 15627 2 15628 2 15629 2 15630 2 15631 2 15632 2 15633 2 15634 2 15635 15635 15636 15636 15637 15637 15638 15638 15639 15639 15640 15640 15641 15641 15642 15642 15643 15643 15644 15644 15645 15645 15646 15646 15647 15647 15648 15648 15649 15649 15650 4 15651 2 15652 15652 15653 15653 15654 15654 15655 15655 15656 15656 15657 15657 15658 15658 15659 15659 15660 15660 15661 15661 15662 15662 15663 350 15664 350 15665 40 15666 353 15667 2 15668 417 15669 15669 15670 569 15671 15671 15672 15672 15673 15673 15674 15674 15675 15675 15676 2 15677 417 15678 15678 15679 15679 15680 40 15681 15681 15682 276 15683 15683 15684 15684 15685 2 15686 417 15687 15687 15688 15688 15689 15689 15690 15690 15691 15691 15692 15692 15693 2 15694 728 15695 2 15696 15696 15697 15697 15698 15698 15699 15699 15700 15700 15701 15701 15702 15702 15703 15703 15704 15704 15705 15705 15706 845 15707 15707 15708 15708 15709 15709 15710 15710 15711 15711 15712 15712 15713 15713 15714 15714 15715 15715 15716 15716 15717 15717 15718 15718 15719 15719 15720 15720 15721 15721 15722 15722 15723 15723 15724 15724 15725 15725 15726 15726 15727 15727 15728 15728 15729 15729 15730 15730 15731 15731 15732 15732 15733 15733 15734 15734 15735 15735 15736 15736 15737 15737 15738 15738 15739 15739 15740 15740 15741 15741 15742 15742 15743 15743 15744 15744 15745 15745 15746 15746 15747 15747 15748 15748 15749 15749 15750 15750 15751 15751 15752 15752 15753 15753 15754 15754 15755 15755 15756 15756 15757 15757 15758 15758 15759 15759 15760 15760 15761 15761 15762 15762 15763 15763 15764 15764 15765 15765 15766 15766 15767 15767 15768 15768 15769 15769 15770 15770 15771 15771 15772 15772 15773 15773 15774 15774 15775 15775 15776 15776 15777 15777 15778 15778 15779 15779 15780 15780 15781 15781 15782 15782 15783 15783 15784 15784 15785 15785 15786 11 15787 15787 15788 15788 15789 15789 15790 2 15791 417 15792 15792 15793 932 15794 15794 15795 15795 15796 965 15797 154 15798 157 15799 15799 15800 15800 15801 1476 15802 2 15803 2 15804 2 15805 15805 15806 2 15807 15807 15808 2 15809 2 15810 2 15811 2 15812 2 15813 2 15814 2 15815 2 15816 2 15817 15817 15818 15818 15819 15819 15820 15820 15821 15821 15822 15822 15823 15823 15824 15824 15825 15825 15826 15826 15827 15827 15828 15828 15829 15829 15830 22 15831 15831 15832 4 15833 11 15834 15834 15835 88 15836 11 15837 15837 15838 98 15839 15839 15840 1538 15841 15841 15842 15842 15843 15843 15844 98 15845 845 15846 11 15847 15847 15848 932 15849 15849 15850 15850 15851 965 15852 154 15853 157 15854 15854 15855 15855 15856 15856 15857 845 15858 11 15859 15859 15860 15860 15861 15861 15862 350 15863 350 15864 353 15865 2 15866 417 15867 15867 15868 569 15869 15869 15870 15870 15871 15871 15872 15872 15873 2 15874 417 15875 15875 15876 15876 15877 15877 15878 15878 15879 15879 15880 15880 15881 2 15882 417 15883 15883 15884 15884 15885 138 15886 11 15887 140 15888 157 15889 158 15890 160 15891 162 15892 76 15893 124 15894 165 15895 15895 15896 15896 15897 138 15898 11 15899 140 15900 157 15901 2240 15902 2242 15903 2243 15904 2244 15905 2 15906 15906 15907 15907 15908 2 15909 15909 15910 845 15911 15911 15912 11 15913 15913 15914 2 15915 417 15916 15916 15917 15917 15918 15918 15919 2727 15920 15920 15921 15921 15922 350 15923 350 15924 353 15925 2 15926 417 15927 15927 15928 569 15929 15929 15930 15930 15931 15931 15932 15932 15933 2 15934 417 15935 15935 15936 15936 15937 15937 15938 15938 15939 2804 15940 15940 15941 569 15942 15942 15943 2 15944 15944 15945 15945 15946 15589 15947 2 15948 15948 15949 15949 15950 15950 15951 15951 15952 15952 15953 2898 15954 15954 15955 68 15956 15956 15957 15957 15958 15958 15959 15959 15960 15960 15961 15961 15962 15962 15963 2 15964 15964 15965 15965 15966 15966 15967 15967 15968 15968 15969 15969 15970 2942 15971 2944 15972 15972 15973 15973 15974 15974 15975 15975 15976 15976 15977 350 15978 350 15979 40 15980 353 15981 2 15982 417 15983 15983 15984 569 15985 15985 15986 15986 15987 15987 15988 15988 15989 932 15990 15990 15991 15991 15992 15992 15993 965 15994 154 15995 157 15996 15996 15997 15997 15998 40 15999 15999 16000 16000 16001 2981 16002 2984 16003 2986 16004 2988 16005 76 16006 2990 16007 2991 16008 16008 16009 276 16010 16010 16011 2 16012 276 16013 76 16014 3971 16015 2829 16016 16016 16017 1851 16018 157 16019 2040 16020 2 16021 16021 16022 2 16023 154 16024 157 16025 16025 16026 16026 16027 16027 16028 16028 16029 16029 16030 5266 16031 16031 16032 157 16033 16033 16034 2 16035 276 16036 16036 16037 2 16038 276 16039 16039 16040 16040 16041 16041 16042 16042 16043 16043 16044 16044 16045 1851 16046 157 16047 16047 16048 16048 16049 16049 16050 16050 16051 276 16052 16052 16053 16053 16054 2 16055 417 16056 16056 16057 5298 16058 16058 16059 16059 16060 16060 16061 16061 16062 16062 16063 16063 16064 2898 16065 16065 16066 68 16067 16067 16068 16068 16069 16069 16070 16070 16071 16071 16072 16072 16073 16073 16074 2 16075 16075 16076 16076 16077 16077 16078 16078 16079 16079 16080 16080 16081 2942 16082 2944 16083 16083 16084 16084 16085 16085 16086 16086 16087 16087 16088 350 16089 350 16090 40 16091 353 16092 2 16093 417 16094 16094 16095 569 16096 16096 16097 16097 16098 16098 16099 16099 16100 932 16101 16101 16102 16102 16103 16103 16104 965 16105 154 16106 157 16107 16107 16108 16108 16109 40 16110 16110 16111 16111 16112 2981 16113 2984 16114 2986 16115 2988 16116 76 16117 2990 16118 2991 16119 16119 16120 276 16121 16121 16122 2 16123 276 16124 76 16125 3971 16126 2829 16127 16127 16128 1851 16129 157 16130 2040 16131 2 16132 16132 16133 2 16134 154 16135 157 16136 16136 16137 16137 16138 16138 16139 16139 16140 16140 16141 5266 16142 16142 16143 157 16144 16144 16145 2 16146 276 16147 16147 16148 2 16149 276 16150 16150 16151 16151 16152 16152 16153 16153 16154 16154 16155 16155 16156 1851 16157 157 16158 16158 16159 16159 16160 16160 16161 16161 16162 276 16163 16163 16164 16164 16165 2 16166 417 16167 16167 16168 5298 16169 16169 16170 16170 16171 26 16172 16172 16173 15 16174 15 16175 11 16176 26 16177 2 16178 11 16179 11 16180 40 16181 16 16182 16182 16183 15 16184 69 16185 70 16186 11 16187 76 16188 11 16189 11 16190 16190 16191 87 16192 102 16193 16193 16194 201 16195 16195 16196 124 16197 165 16198 16198 16199 26 16200 16200 16201 16201 16202 1054 16203 11 16204 6185 16205 16205 16206 2 16207 276 16208 1054 16209 16209 16210 16210 16211 16211 16212 15 16213 16 16214 15 16215 11 16216 26 16217 2 16218 16 16219 11 16220 11 16221 40 16222 16 16223 11 16224 11 16225 16225 16226 16 16227 15 16228 69 16229 70 16230 11 16231 16 16232 76 16233 11 16234 11 16235 16235 16236 87 16237 16237 16238 91 16239 16239 16240 97 16241 16241 16242 102 16243 105 16244 16244 16245 16245 16246 16246 16247 16247 16248 16248 16249 16249 16250 16250 16251 124 16252 165 16253 16253 16254 26 16255 11 16256 2 16257 276 16258 26 16259 16259 16260 16260 16261 16261 16262 16262 16263 16263 16264 16264 16265 16265 16266 16266 16267 138 16268 11 16269 140 16270 157 16271 160 16272 162 16273 76 16274 124 16275 165 16276 16276 16277 16277 16278 16278 16279 16 16280 16280 16281 2984 16282 2986 16283 2988 16284 76 16285 2990 16286 2991 16287 16287 16288 2727 16289 16289 16290 16290 16291 16291 16292 16292 16293 1054 16294 6185 16295 16295 16296 16296 16297 16297 16298 16298 16299 15 16300 16 16301 15 16302 11 16303 26 16304 2 16305 6185 16306 16 16307 11 16308 11 16309 40 16310 16 16311 11 16312 16312 16313 16 16314 15 16315 69 16316 70 16317 11 16318 16 16319 76 16320 11 16321 11 16322 16322 16323 87 16324 16324 16325 91 16326 16326 16327 97 16328 16328 16329 102 16330 105 16331 16331 16332 16332 16333 16246 16334 16334 16335 16335 16336 16336 16337 16337 16338 124 16339 165 16340 16340 16341 26 16342 16342 16343 16264 16344 138 16345 11 16346 140 16347 157 16348 160 16349 162 16350 76 16351 124 16352 165 16353 16353 16354 16354 16355 16355 16356 16 16357 2984 16358 2986 16359 2988 16360 76 16361 2990 16362 2991 16363 16363 16364 16364 16365 1054 16366 6185 16367 16367 16368 16296 16369 16297 16370 6185 16371 16371 16372 2 16373 276 16374 16374 16375 16375 16376 16376 16377 16377 16378 16378 16379 16379 16380 15 16381 16 16382 15 16383 11 16384 26 16385 2 16386 6185 16387 16 16388 11 16389 11 16390 40 16391 16 16392 11 16393 11 16394 16394 16395 16 16396 15 16397 69 16398 70 16399 11 16400 16 16401 76 16402 11 16403 11 16404 16404 16405 87 16406 16406 16407 91 16408 16408 16409 97 16410 16410 16411 102 16412 105 16413 16413 16414 16414 16415 16415 16416 16416 16417 16417 16418 16418 16419 16419 16420 124 16421 165 16422 16422 16423 26 16424 11 16425 2 16426 276 16427 26 16428 16428 16429 15 16430 15 16431 11 16432 26 16433 2 16434 11 16435 11 16436 40 16437 16 16438 16438 16439 15 16440 69 16441 70 16442 11 16443 76 16444 11 16445 11 16446 16446 16447 87 16448 102 16449 16449 16450 16415 16451 16451 16452 124 16453 165 16454 16454 16455 26 16456 16456 16457 16457 16458 1054 16459 6185 16460 16460 16461 16296 16462 16297 16463 6185 16464 16464 16465 2 16466 276 16467 16374 16468 16375 16469 16469 16470 16470 16471 16378 16472 6185 16473 16473 16474 22 16475 4 16476 11 16477 2750 16478 88 16479 11 16480 2753 16481 98 16482 2755 16483 1538 16484 2757 16485 2758 16486 16486 16487 154 16488 16488 16489 98 16490 845 16491 11 16492 2763 16493 932 16494 2765 16495 2766 16496 965 16497 154 16498 157 16499 2770 16500 2771 16501 16501 16502 157 16503 6185 16504 16504 16505 16505 16506 2772 16507 845 16508 11 16509 2775 16510 2776 16511 2777 16512 350 16513 350 16514 353 16515 2 16516 417 16517 2783 16518 569 16519 2785 16520 2786 16521 2787 16522 2788 16523 2 16524 417 16525 2791 16526 2792 16527 2793 16528 2794 16529 2795 16530 2796 16531 2 16532 417 16533 2799 16534 124 16535 165 16536 16536 16537 16537 16538 11 16539 76 16540 16540 16541 124 16542 165 16543 16543 16544 13 16545 16545 16546 16546 16547 16547 16548 16548 16549 16549 16550 16550 16551 16551 16552 16552 16553 16553 16554 157 16555 13 16556 16556 16557 76 16558 124 16559 165 16560 16560 16561 2 16562 276 16563 16563 16564 16564 16565 16565 16566 16566 16567 16567 16568 16568 16569 2 16570 16570 16571 16571 16572 16572 16573 16573 16574 16574 16575 16575 16576 16576 16577 15 16578 16 16579 15 16580 11 16581 26 16582 2 16583 16 16584 11 16585 11 16586 40 16587 16 16588 11 16589 11 16590 16590 16591 16 16592 15 16593 69 16594 70 16595 11 16596 16 16597 76 16598 11 16599 11 16600 16600 16601 87 16602 16602 16603 91 16604 16604 16605 97 16606 16606 16607 102 16608 105 16609 16609 16610 16610 16611 16611 16612 16612 16613 16613 16614 16614 16615 16615 16616 124 16617 165 16618 16618 16619 26 16620 11 16621 2 16622 276 16623 26 16624 16624 16625 15 16626 15 16627 11 16628 26 16629 2 16630 11 16631 11 16632 40 16633 16 16634 16634 16635 15 16636 69 16637 70 16638 11 16639 76 16640 11 16641 11 16642 16642 16643 87 16644 102 16645 16645 16646 16611 16647 16647 16648 124 16649 165 16650 16650 16651 26 16652 16652 16653 16653 16654 1054 16655 6185 16656 16656 16657 16296 16658 16297 16659 6185 16660 16660 16661 2 16662 276 16663 16374 16664 16375 16665 16665 16666 16666 16667 16378 16668 6185 16669 16669 16670 22 16671 154 16672 157 16673 6185 16674 16674 16675 124 16676 165 16677 16677 16678 16678 16679 11 16680 76 16681 16681 16682 124 16683 165 16684 16684 16685 13 16686 16550 16687 157 16688 76 16689 124 16690 165 16691 16691 16692 2 16693 276 16694 16563 16695 16564 16696 16696 16697 16566 16698 16567 16699 16568 16700 16700 16701 16568 16702 16702 16703 16703 16704 16704 16705 2 16706 16570 16707 6185 16708 16708 16709 16709 16710 16710 16711 16711 16712 16712 16713 16713 16714 15 16715 16 16716 15 16717 11 16718 26 16719 2 16720 16 16721 11 16722 11 16723 40 16724 16 16725 11 16726 11 16727 16727 16728 16 16729 15 16730 69 16731 70 16732 11 16733 16 16734 76 16735 11 16736 11 16737 16737 16738 87 16739 16739 16740 91 16741 16741 16742 97 16743 16743 16744 102 16745 105 16746 16746 16747 16747 16748 16748 16749 16749 16750 16750 16751 16751 16752 16752 16753 124 16754 165 16755 16755 16756 26 16757 11 16758 2 16759 276 16760 26 16761 16761 16762 15 16763 15 16764 11 16765 26 16766 2 16767 11 16768 11 16769 40 16770 16 16771 16771 16772 15 16773 69 16774 70 16775 11 16776 76 16777 11 16778 11 16779 16779 16780 87 16781 102 16782 16782 16783 16748 16784 16784 16785 124 16786 165 16787 16787 16788 26 16789 16789 16790 16790 16791 1054 16792 6185 16793 16793 16794 16296 16795 16297 16796 6185 16797 16797 16798 2 16799 276 16800 16374 16801 16375 16802 16802 16803 16803 16804 16378 16805 6185 16806 16806 16807 22 16808 154 16809 157 16810 6185 16811 16811 16812 124 16813 165 16814 16814 16815 16815 16816 11 16817 76 16818 16818 16819 124 16820 165 16821 16821 16822 13 16823 16550 16824 157 16825 76 16826 124 16827 165 16828 16828 16829 2 16830 276 16831 16563 16832 16564 16833 16833 16834 16566 16835 16567 16836 16568 16837 16837 16838 16568 16839 16839 16840 16703 16841 16704 16842 6185 16843 16843 16844 16704 16845 6185 16846 16846 16847 16847 16848 16848 16849 16849 16850 16850 16851 3060 16852 3024 16853 16853 16854 16854 16855 2 16856 2 16857 3 16858 4 16859 2 16860 2 16861 2 16862 2 16863 11 16864 2 16865 2 16866 3076 16867 2 16868 3078 16869 22 16870 3080 16871 3081 16872 2 16873 11 16874 11 16875 3085 16876 3086 16877 3087 16878 22 16879 2 16880 2 16881 2 16882 11 16883 3093 16884 11 16885 3095 16886 11 16887 3097 16888 3098 16889 3099 16890 3100 16891 60 16892 3102 16893 2 16894 2 16895 11 16896 2 16897 2 16898 68 16899 129 16900 3110 16901 2 16902 2 16903 3113 16904 2 16905 3115 16906 3116 16907 2 16908 84 16909 85 16910 88 16911 132 16912 11 16913 3123 16914 3124 16915 98 16916 3126 16917 3127 16918 16918 16919 103 16920 103 16921 3131 16922 3132 16923 3133 16924 3134 16925 3135 16926 3136 16927 3137 16928 3138 16929 3139 16930 3140 16931 98 16932 2 16933 3143 16934 2 16935 2 16936 2 16937 2 16938 2 16939 2 16940 2 16941 2 16942 300 16943 2 16944 2 16945 2 16946 2 16947 2 16948 306 16949 2 16950 2 16951 2 16952 2 16953 2 16954 2 16955 2 16956 2 16957 2 16958 2 16959 2 16960 2 16961 2 16962 2 16963 2 16964 3174 16965 3175 16966 3176 16967 3177 16968 3178 16969 3179 16970 3180 16971 3181 16972 3182 16973 3183 16974 3184 16975 3185 16976 3186 16977 3187 16978 3188 16979 4 16980 2 16981 3191 16982 3192 16983 3193 16984 3194 16985 3195 16986 3196 16987 3197 16988 3198 16989 3199 16990 3200 16991 3201 16992 350 16993 350 16994 40 16995 353 16996 2 16997 417 16998 3208 16999 569 17000 3210 17001 3211 17002 3212 17003 3213 17004 3214 17005 2 17006 417 17007 3217 17008 3218 17009 40 17010 3220 17011 276 17012 3222 17013 3223 17014 2 17015 417 17016 3226 17017 3227 17018 3228 17019 3229 17020 3230 17021 3231 17022 2 17023 728 17024 2 17025 3235 17026 3236 17027 3237 17028 3238 17029 3239 17030 3240 17031 3241 17032 3242 17033 3243 17034 3244 17035 845 17036 3246 17037 3247 17038 3248 17039 3249 17040 3250 17041 3251 17042 3252 17043 3253 17044 3254 17045 3255 17046 3256 17047 3257 17048 3258 17049 3259 17050 3260 17051 3261 17052 3262 17053 3263 17054 3264 17055 3265 17056 3266 17057 3267 17058 3268 17059 3269 17060 3270 17061 3271 17062 3272 17063 3273 17064 3274 17065 3275 17066 3276 17067 3277 17068 3278 17069 3279 17070 3280 17071 3281 17072 3282 17073 3283 17074 3284 17075 3285 17076 3286 17077 3287 17078 3288 17079 3289 17080 3290 17081 3291 17082 3292 17083 3293 17084 3294 17085 3295 17086 3296 17087 3297 17088 3298 17089 3299 17090 3300 17091 3301 17092 3302 17093 3303 17094 3304 17095 3305 17096 3306 17097 3307 17098 3308 17099 3309 17100 3310 17101 3311 17102 3312 17103 3313 17104 3314 17105 3315 17106 3316 17107 3317 17108 3318 17109 3319 17110 3320 17111 3321 17112 3322 17113 3323 17114 3324 17115 11 17116 3326 17117 3327 17118 3328 17119 2 17120 417 17121 3331 17122 932 17123 3333 17124 3334 17125 965 17126 154 17127 157 17128 3338 17129 3339 17130 1476 17131 2 17132 2 17133 2 17134 3344 17135 2 17136 3346 17137 2 17138 2 17139 2 17140 2 17141 2 17142 2 17143 2 17144 2 17145 2 17146 3356 17147 3357 17148 3358 17149 3359 17150 3360 17151 3361 17152 3362 17153 3363 17154 3364 17155 3365 17156 3366 17157 3367 17158 3368 17159 22 17160 3370 17161 4 17162 11 17163 3373 17164 88 17165 11 17166 3376 17167 98 17168 3378 17169 1538 17170 3380 17171 3381 17172 3382 17173 98 17174 845 17175 11 17176 3386 17177 932 17178 3388 17179 3389 17180 965 17181 154 17182 157 17183 3393 17184 3394 17185 3395 17186 845 17187 11 17188 3398 17189 3399 17190 3400 17191 350 17192 350 17193 353 17194 2 17195 417 17196 3406 17197 569 17198 3408 17199 3409 17200 3410 17201 3411 17202 2 17203 417 17204 3414 17205 3415 17206 3416 17207 3417 17208 3418 17209 3419 17210 2 17211 417 17212 3422 17213 3423 17214 138 17215 11 17216 140 17217 157 17218 158 17219 160 17220 162 17221 76 17222 124 17223 165 17224 3434 17225 3435 17226 138 17227 11 17228 140 17229 157 17230 2240 17231 2242 17232 2243 17233 2244 17234 2 17235 3445 17236 3446 17237 845 17238 3449 17239 11 17240 3451 17241 2 17242 417 17243 3454 17244 3455 17245 3456 17246 2727 17247 3458 17248 3459 17249 350 17250 350 17251 353 17252 2 17253 417 17254 3465 17255 569 17256 3467 17257 3468 17258 3469 17259 3470 17260 2 17261 417 17262 3473 17263 3474 17264 3475 17265 3476 17266 2804 17267 3478 17268 569 17269 3480 17270 2 17271 3482 17272 3483 17273 2 17274 3 17275 4 17276 2 17277 2 17278 2 17279 2 17280 11 17281 2 17282 2 17283 3494 17284 2 17285 3496 17286 22 17287 3498 17288 3499 17289 2 17290 11 17291 11 17292 3503 17293 3504 17294 3505 17295 22 17296 2 17297 2 17298 2 17299 11 17300 3511 17301 11 17302 3513 17303 11 17304 3515 17305 3516 17306 3517 17307 3518 17308 60 17309 3520 17310 2 17311 2 17312 11 17313 2 17314 2 17315 68 17316 129 17317 3528 17318 2 17319 2 17320 3531 17321 2 17322 3533 17323 3534 17324 2 17325 84 17326 85 17327 88 17328 132 17329 11 17330 3541 17331 3542 17332 98 17333 3544 17334 3545 17335 3546 17336 103 17337 103 17338 3549 17339 3550 17340 3551 17341 3552 17342 3553 17343 3554 17344 3555 17345 3556 17346 3557 17347 3558 17348 98 17349 2 17350 3561 17351 2 17352 2 17353 2 17354 2 17355 2 17356 2 17357 2 17358 2 17359 300 17360 2 17361 2 17362 2 17363 2 17364 2 17365 306 17366 2 17367 2 17368 2 17369 2 17370 2 17371 2 17372 2 17373 2 17374 2 17375 2 17376 2 17377 2 17378 2 17379 2 17380 2 17381 3592 17382 3593 17383 3594 17384 3595 17385 3596 17386 3597 17387 3598 17388 3599 17389 3600 17390 3601 17391 3602 17392 3603 17393 3604 17394 3605 17395 3606 17396 4 17397 2 17398 3609 17399 3610 17400 3611 17401 3612 17402 3613 17403 3614 17404 3615 17405 3616 17406 3617 17407 3618 17408 3619 17409 350 17410 350 17411 40 17412 353 17413 2 17414 417 17415 3626 17416 569 17417 3628 17418 3629 17419 3630 17420 3631 17421 3632 17422 2 17423 417 17424 3635 17425 3636 17426 40 17427 3638 17428 276 17429 3640 17430 3641 17431 2 17432 417 17433 3644 17434 3645 17435 3646 17436 3647 17437 3648 17438 3649 17439 2 17440 728 17441 2 17442 3653 17443 3654 17444 3655 17445 3656 17446 3657 17447 3658 17448 3659 17449 3660 17450 3661 17451 3662 17452 845 17453 3664 17454 3665 17455 3666 17456 3667 17457 3668 17458 3669 17459 3670 17460 3671 17461 3672 17462 3673 17463 3674 17464 3675 17465 3676 17466 3677 17467 3678 17468 3679 17469 3680 17470 3681 17471 3682 17472 3683 17473 3684 17474 3685 17475 3686 17476 3687 17477 3688 17478 3689 17479 3690 17480 3691 17481 3692 17482 3693 17483 3694 17484 3695 17485 3696 17486 3697 17487 3698 17488 3699 17489 3700 17490 3701 17491 3702 17492 3703 17493 3704 17494 3705 17495 3706 17496 3707 17497 3708 17498 3709 17499 3710 17500 3711 17501 3712 17502 3713 17503 3714 17504 3715 17505 3716 17506 3717 17507 3718 17508 3719 17509 3720 17510 3721 17511 3722 17512 3723 17513 3724 17514 3725 17515 3726 17516 3727 17517 3728 17518 3729 17519 3730 17520 3731 17521 3732 17522 3733 17523 3734 17524 3735 17525 3736 17526 3737 17527 3738 17528 3739 17529 3740 17530 3741 17531 3742 17532 11 17533 3744 17534 3745 17535 3746 17536 2 17537 417 17538 3749 17539 932 17540 3751 17541 3752 17542 965 17543 154 17544 157 17545 3756 17546 3757 17547 1476 17548 2 17549 2 17550 2 17551 3762 17552 2 17553 3764 17554 2 17555 2 17556 2 17557 2 17558 2 17559 2 17560 2 17561 2 17562 2 17563 3774 17564 3775 17565 3776 17566 3777 17567 3778 17568 3779 17569 3780 17570 3781 17571 3782 17572 3783 17573 3784 17574 3785 17575 3786 17576 22 17577 3788 17578 4 17579 11 17580 3791 17581 88 17582 11 17583 3794 17584 98 17585 3796 17586 1538 17587 3798 17588 3799 17589 3800 17590 98 17591 845 17592 11 17593 3804 17594 932 17595 3806 17596 3807 17597 965 17598 154 17599 157 17600 3811 17601 3812 17602 3813 17603 845 17604 11 17605 3816 17606 3817 17607 3818 17608 350 17609 350 17610 353 17611 2 17612 417 17613 3824 17614 569 17615 3826 17616 3827 17617 3828 17618 3829 17619 2 17620 417 17621 3832 17622 3833 17623 3834 17624 3835 17625 3836 17626 3837 17627 2 17628 417 17629 3840 17630 3841 17631 138 17632 11 17633 140 17634 157 17635 158 17636 160 17637 162 17638 76 17639 124 17640 165 17641 3852 17642 3853 17643 138 17644 11 17645 140 17646 157 17647 2240 17648 2242 17649 2243 17650 2244 17651 2 17652 3863 17653 3864 17654 2 17655 3866 17656 845 17657 3868 17658 11 17659 3870 17660 2 17661 417 17662 3873 17663 3874 17664 3875 17665 2727 17666 3877 17667 3878 17668 350 17669 350 17670 353 17671 2 17672 417 17673 3884 17674 569 17675 3886 17676 3887 17677 3888 17678 3889 17679 2 17680 417 17681 3892 17682 3893 17683 3894 17684 3895 17685 2804 17686 3897 17687 569 17688 3899 17689 2 17690 3901 17691 3902 17692 3546 17693 2 17694 3905 17695 3906 17696 3907 17697 3908 17698 3909 17699 2898 17700 3911 17701 68 17702 3913 17703 3914 17704 3915 17705 3916 17706 3917 17707 3918 17708 3919 17709 3926 17710 2942 17711 2944 17712 3930 17713 932 17714 3947 17715 3948 17716 3949 17717 965 17718 154 17719 157 17720 3953 17721 3954 17722 3957 17723 2981 17724 2984 17725 2986 17726 2988 17727 76 17728 2990 17729 2991 17730 3965 17731 2 17732 276 17733 76 17734 3971 17735 2829 17736 4338 17737 1851 17738 157 17739 2040 17740 2 17741 5615 17742 2 17743 154 17744 157 17745 5619 17746 5620 17747 5621 17748 5622 17749 5623 17750 5266 17751 5625 17752 157 17753 5627 17754 2 17755 276 17756 5630 17757 2 17758 276 17759 5633 17760 5634 17761 5635 17762 5636 17763 5637 17764 5638 17765 1851 17766 157 17767 5641 17768 5642 17769 5643 17770 5644 17771 276 17772 5646 17773 5647 17774 2 17775 417 17776 5650 17777 5298 17778 5652 17779 5653 17780 5654 17781 5655 17782 5656 17783 5657 17784 2898 17785 5659 17786 68 17787 5661 17788 5662 17789 5663 17790 5664 17791 5665 17792 5666 17793 5667 17794 5674 17795 2942 17796 2944 17797 5678 17798 932 17799 5695 17800 5696 17801 5697 17802 965 17803 154 17804 157 17805 5701 17806 5702 17807 5705 17808 2981 17809 2984 17810 2986 17811 2988 17812 76 17813 2990 17814 2991 17815 5713 17816 2 17817 276 17818 76 17819 3971 17820 2829 17821 5721 17822 1851 17823 157 17824 2040 17825 2 17826 5726 17827 2 17828 154 17829 157 17830 5730 17831 5731 17832 5732 17833 5733 17834 5734 17835 5266 17836 5736 17837 157 17838 5738 17839 2 17840 276 17841 5741 17842 2 17843 276 17844 5744 17845 5745 17846 5746 17847 5747 17848 5748 17849 5749 17850 1851 17851 157 17852 5752 17853 5753 17854 5754 17855 5755 17856 276 17857 5757 17858 5758 17859 2 17860 417 17861 5761 17862 5298 17863 5763 17864 5764 17865 17865 17866 6185 17867 17867 17868 6185 17869 17869 17870 4 17871 17871 17872 17872 17873 3060 17874 17874 17875 40 17876 17876 17877 17877 17878 17878 17879 2 17880 417 17881 17881 17882 2 17883 2 17884 3 17885 4 17886 2 17887 2 17888 2 17889 2 17890 11 17891 2 17892 2 17893 17893 17894 2 17895 17895 17896 22 17897 17897 17898 17898 17899 2 17900 11 17901 11 17902 17902 17903 17903 17904 17904 17905 22 17906 2 17907 2 17908 2 17909 11 17910 17910 17911 11 17912 17912 17913 11 17914 17914 17915 17915 17916 17916 17917 17917 17918 60 17919 17919 17920 2 17921 2 17922 11 17923 2 17924 2 17925 68 17926 129 17927 17927 17928 2 17929 2 17930 17930 17931 2 17932 17932 17933 17933 17934 2 17935 84 17936 85 17937 88 17938 132 17939 11 17940 17940 17941 17941 17942 98 17943 17943 17944 17944 17945 17945 17946 103 17947 103 17948 17948 17949 17949 17950 17950 17951 17951 17952 17952 17953 17953 17954 17954 17955 17955 17956 17956 17957 17957 17958 98 17959 2 17960 17960 17961 2 17962 2 17963 2 17964 2 17965 2 17966 2 17967 2 17968 2 17969 300 17970 2 17971 2 17972 2 17973 2 17974 2 17975 306 17976 2 17977 2 17978 2 17979 2 17980 2 17981 2 17982 2 17983 2 17984 2 17985 2 17986 2 17987 2 17988 2 17989 2 17990 2 17991 17991 17992 17992 17993 17993 17994 17994 17995 17995 17996 17996 17997 17997 17998 17998 17999 17999 18000 18000 18001 18001 18002 18002 18003 18003 18004 18004 18005 18005 18006 4 18007 2 18008 18008 18009 18009 18010 18010 18011 18011 18012 18012 18013 18013 18014 18014 18015 18015 18016 18016 18017 18017 18018 18018 18019 350 18020 350 18021 40 18022 353 18023 2 18024 417 18025 18025 18026 569 18027 18027 18028 18028 18029 18029 18030 18030 18031 18031 18032 2 18033 417 18034 18034 18035 18035 18036 40 18037 18037 18038 276 18039 18039 18040 18040 18041 2 18042 417 18043 18043 18044 18044 18045 18045 18046 18046 18047 18047 18048 18048 18049 2 18050 728 18051 2 18052 18052 18053 18053 18054 18054 18055 18055 18056 18056 18057 18057 18058 18058 18059 18059 18060 18060 18061 18061 18062 845 18063 18063 18064 18064 18065 18065 18066 18066 18067 18067 18068 18068 18069 18069 18070 18070 18071 18071 18072 18072 18073 18073 18074 18074 18075 18075 18076 18076 18077 18077 18078 18078 18079 18079 18080 18080 18081 18081 18082 18082 18083 18083 18084 18084 18085 18085 18086 18086 18087 18087 18088 18088 18089 18089 18090 18090 18091 18091 18092 18092 18093 18093 18094 18094 18095 18095 18096 18096 18097 18097 18098 18098 18099 18099 18100 18100 18101 18101 18102 18102 18103 18103 18104 18104 18105 18105 18106 18106 18107 18107 18108 18108 18109 18109 18110 18110 18111 18111 18112 18112 18113 18113 18114 18114 18115 18115 18116 18116 18117 18117 18118 18118 18119 18119 18120 18120 18121 18121 18122 18122 18123 18123 18124 18124 18125 18125 18126 18126 18127 18127 18128 18128 18129 18129 18130 18130 18131 18131 18132 18132 18133 18133 18134 18134 18135 18135 18136 18136 18137 18137 18138 18138 18139 18139 18140 18140 18141 18141 18142 11 18143 18143 18144 18144 18145 18145 18146 2 18147 417 18148 18148 18149 932 18150 18150 18151 18151 18152 965 18153 154 18154 157 18155 18155 18156 18156 18157 1476 18158 2 18159 2 18160 2 18161 18161 18162 2 18163 18163 18164 2 18165 2 18166 2 18167 2 18168 2 18169 2 18170 2 18171 2 18172 2 18173 18173 18174 18174 18175 18175 18176 18176 18177 18177 18178 18178 18179 18179 18180 18180 18181 18181 18182 18182 18183 18183 18184 18184 18185 18185 18186 22 18187 18187 18188 4 18189 11 18190 18190 18191 88 18192 11 18193 18193 18194 98 18195 18195 18196 1538 18197 18197 18198 18198 18199 18199 18200 98 18201 845 18202 11 18203 18203 18204 932 18205 18205 18206 18206 18207 965 18208 154 18209 157 18210 18210 18211 18211 18212 18212 18213 845 18214 11 18215 18215 18216 18216 18217 18217 18218 350 18219 350 18220 353 18221 2 18222 417 18223 18223 18224 569 18225 18225 18226 18226 18227 18227 18228 18228 18229 2 18230 417 18231 18231 18232 18232 18233 18233 18234 18234 18235 18235 18236 18236 18237 2 18238 417 18239 18239 18240 18240 18241 138 18242 11 18243 140 18244 157 18245 158 18246 160 18247 162 18248 76 18249 124 18250 165 18251 18251 18252 18252 18253 138 18254 11 18255 140 18256 157 18257 2240 18258 2242 18259 2243 18260 2244 18261 2 18262 2 18263 3 18264 4 18265 2 18266 2 18267 2 18268 2 18269 11 18270 2 18271 2 18272 17893 18273 2 18274 17895 18275 22 18276 17897 18277 17898 18278 2 18279 11 18280 11 18281 17902 18282 17903 18283 17904 18284 22 18285 2 18286 2 18287 2 18288 11 18289 17910 18290 11 18291 17912 18292 11 18293 17914 18294 17915 18295 17916 18296 17917 18297 60 18298 17919 18299 2 18300 2 18301 11 18302 2 18303 2 18304 68 18305 129 18306 17927 18307 2 18308 2 18309 17930 18310 2 18311 17932 18312 17933 18313 2 18314 84 18315 85 18316 88 18317 132 18318 11 18319 17940 18320 17941 18321 98 18322 17943 18323 17944 18324 18324 18325 103 18326 103 18327 17948 18328 17949 18329 17950 18330 17951 18331 17952 18332 17953 18333 17954 18334 17955 18335 17956 18336 17957 18337 98 18338 2 18339 17960 18340 2 18341 2 18342 2 18343 2 18344 2 18345 2 18346 2 18347 2 18348 300 18349 2 18350 2 18351 2 18352 2 18353 2 18354 306 18355 2 18356 2 18357 2 18358 2 18359 2 18360 2 18361 2 18362 2 18363 2 18364 2 18365 2 18366 2 18367 2 18368 2 18369 2 18370 17991 18371 17992 18372 17993 18373 17994 18374 17995 18375 17996 18376 17997 18377 17998 18378 17999 18379 18000 18380 18001 18381 18002 18382 18003 18383 18004 18384 18005 18385 4 18386 2 18387 18008 18388 18009 18389 18010 18390 18011 18391 18012 18392 18013 18393 18014 18394 18015 18395 18016 18396 18017 18397 18018 18398 350 18399 350 18400 40 18401 353 18402 2 18403 417 18404 18025 18405 569 18406 18027 18407 18028 18408 18029 18409 18030 18410 18031 18411 2 18412 417 18413 18034 18414 18035 18415 40 18416 18037 18417 276 18418 18039 18419 18040 18420 2 18421 417 18422 18043 18423 18044 18424 18045 18425 18046 18426 18047 18427 18048 18428 2 18429 728 18430 2 18431 18052 18432 18053 18433 18054 18434 18055 18435 18056 18436 18057 18437 18058 18438 18059 18439 18060 18440 18061 18441 845 18442 18063 18443 18064 18444 18065 18445 18066 18446 18067 18447 18068 18448 18069 18449 18070 18450 18071 18451 18072 18452 18073 18453 18074 18454 18075 18455 18076 18456 18077 18457 18078 18458 18079 18459 18080 18460 18081 18461 18082 18462 18083 18463 18084 18464 18085 18465 18086 18466 18087 18467 18088 18468 18089 18469 18090 18470 18091 18471 18092 18472 18093 18473 18094 18474 18095 18475 18096 18476 18097 18477 18098 18478 18099 18479 18100 18480 18101 18481 18102 18482 18103 18483 18104 18484 18105 18485 18106 18486 18107 18487 18108 18488 18109 18489 18110 18490 18111 18491 18112 18492 18113 18493 18114 18494 18115 18495 18116 18496 18117 18497 18118 18498 18119 18499 18120 18500 18121 18501 18122 18502 18123 18503 18124 18504 18125 18505 18126 18506 18127 18507 18128 18508 18129 18509 18130 18510 18131 18511 18132 18512 18133 18513 18134 18514 18135 18515 18136 18516 18137 18517 18138 18518 18139 18519 18140 18520 18141 18521 11 18522 18143 18523 18144 18524 18145 18525 2 18526 417 18527 18148 18528 932 18529 18150 18530 18151 18531 965 18532 154 18533 157 18534 18155 18535 18156 18536 1476 18537 2 18538 2 18539 2 18540 18161 18541 2 18542 18163 18543 2 18544 2 18545 2 18546 2 18547 2 18548 2 18549 2 18550 2 18551 2 18552 18173 18553 18174 18554 18175 18555 18176 18556 18177 18557 18178 18558 18179 18559 18180 18560 18181 18561 18182 18562 18183 18563 18184 18564 18185 18565 22 18566 18187 18567 4 18568 11 18569 18190 18570 88 18571 11 18572 18193 18573 98 18574 18195 18575 1538 18576 18197 18577 18198 18578 18199 18579 98 18580 845 18581 11 18582 18203 18583 932 18584 18205 18585 18206 18586 965 18587 154 18588 157 18589 18210 18590 18211 18591 18212 18592 845 18593 11 18594 18215 18595 18216 18596 18217 18597 350 18598 350 18599 353 18600 2 18601 417 18602 18223 18603 569 18604 18225 18605 18226 18606 18227 18607 18228 18608 2 18609 417 18610 18231 18611 18232 18612 18233 18613 18234 18614 18235 18615 18236 18616 2 18617 417 18618 18239 18619 18240 18620 138 18621 11 18622 140 18623 157 18624 158 18625 160 18626 162 18627 76 18628 124 18629 165 18630 18251 18631 18252 18632 138 18633 11 18634 140 18635 157 18636 2240 18637 2242 18638 2243 18639 2244 18640 2 18641 18324 18642 18642 18643 18642 18644 845 18645 18645 18646 11 18647 18647 18648 2 18649 417 18650 18650 18651 18651 18652 18652 18653 2727 18654 18654 18655 18655 18656 350 18657 350 18658 353 18659 2 18660 417 18661 18661 18662 569 18663 18663 18664 18664 18665 18665 18666 18666 18667 2 18668 417 18669 18669 18670 18670 18671 18671 18672 18672 18673 2804 18674 18674 18675 569 18676 18676 18677 2 18678 18678 18679 18679 18680 2 18681 3 18682 4 18683 2 18684 2 18685 2 18686 2 18687 11 18688 2 18689 2 18690 18690 18691 2 18692 18692 18693 22 18694 18694 18695 18695 18696 2 18697 11 18698 11 18699 18699 18700 18700 18701 18701 18702 22 18703 2 18704 2 18705 2 18706 11 18707 18707 18708 11 18709 18709 18710 11 18711 18711 18712 18712 18713 18713 18714 18714 18715 60 18716 18716 18717 2 18718 2 18719 11 18720 2 18721 2 18722 68 18723 129 18724 18724 18725 2 18726 2 18727 18727 18728 2 18729 18729 18730 18730 18731 2 18732 84 18733 85 18734 88 18735 132 18736 11 18737 18737 18738 18738 18739 98 18740 18740 18741 18741 18742 18742 18743 103 18744 103 18745 18745 18746 18746 18747 18747 18748 18748 18749 18749 18750 18750 18751 18751 18752 18752 18753 18753 18754 18754 18755 98 18756 2 18757 18757 18758 2 18759 2 18760 2 18761 2 18762 2 18763 2 18764 2 18765 2 18766 300 18767 2 18768 2 18769 2 18770 2 18771 2 18772 306 18773 2 18774 2 18775 2 18776 2 18777 2 18778 2 18779 2 18780 2 18781 2 18782 2 18783 2 18784 2 18785 2 18786 2 18787 2 18788 18788 18789 18789 18790 18790 18791 18791 18792 18792 18793 18793 18794 18794 18795 18795 18796 18796 18797 18797 18798 18798 18799 18799 18800 18800 18801 18801 18802 18802 18803 4 18804 2 18805 18805 18806 18806 18807 18807 18808 18808 18809 18809 18810 18810 18811 18811 18812 18812 18813 18813 18814 18814 18815 18815 18816 350 18817 350 18818 40 18819 353 18820 2 18821 417 18822 18822 18823 569 18824 18824 18825 18825 18826 18826 18827 18827 18828 18828 18829 2 18830 417 18831 18831 18832 18832 18833 40 18834 18834 18835 276 18836 18836 18837 18837 18838 2 18839 417 18840 18840 18841 18841 18842 18842 18843 18843 18844 18844 18845 18845 18846 2 18847 728 18848 2 18849 18849 18850 18850 18851 18851 18852 18852 18853 18853 18854 18854 18855 18855 18856 18856 18857 18857 18858 18858 18859 845 18860 18860 18861 18861 18862 18862 18863 18863 18864 18864 18865 18865 18866 18866 18867 18867 18868 18868 18869 18869 18870 18870 18871 18871 18872 18872 18873 18873 18874 18874 18875 18875 18876 18876 18877 18877 18878 18878 18879 18879 18880 18880 18881 18881 18882 18882 18883 18883 18884 18884 18885 18885 18886 18886 18887 18887 18888 18888 18889 18889 18890 18890 18891 18891 18892 18892 18893 18893 18894 18894 18895 18895 18896 18896 18897 18897 18898 18898 18899 18899 18900 18900 18901 18901 18902 18902 18903 18903 18904 18904 18905 18905 18906 18906 18907 18907 18908 18908 18909 18909 18910 18910 18911 18911 18912 18912 18913 18913 18914 18914 18915 18915 18916 18916 18917 18917 18918 18918 18919 18919 18920 18920 18921 18921 18922 18922 18923 18923 18924 18924 18925 18925 18926 18926 18927 18927 18928 18928 18929 18929 18930 18930 18931 18931 18932 18932 18933 18933 18934 18934 18935 18935 18936 18936 18937 18937 18938 18938 18939 11 18940 18940 18941 18941 18942 18942 18943 2 18944 417 18945 18945 18946 932 18947 18947 18948 18948 18949 965 18950 154 18951 157 18952 18952 18953 18953 18954 1476 18955 2 18956 2 18957 2 18958 18958 18959 2 18960 18960 18961 2 18962 2 18963 2 18964 2 18965 2 18966 2 18967 2 18968 2 18969 2 18970 18970 18971 18971 18972 18972 18973 18973 18974 18974 18975 18975 18976 18976 18977 18977 18978 18978 18979 18979 18980 18980 18981 18981 18982 18982 18983 22 18984 18984 18985 4 18986 11 18987 18987 18988 88 18989 11 18990 18990 18991 98 18992 18992 18993 1538 18994 18994 18995 18995 18996 18996 18997 98 18998 845 18999 11 19000 19000 19001 932 19002 19002 19003 19003 19004 965 19005 154 19006 157 19007 19007 19008 19008 19009 19009 19010 845 19011 11 19012 19012 19013 19013 19014 19014 19015 350 19016 350 19017 353 19018 2 19019 417 19020 19020 19021 569 19022 19022 19023 19023 19024 19024 19025 19025 19026 2 19027 417 19028 19028 19029 19029 19030 19030 19031 19031 19032 19032 19033 19033 19034 2 19035 417 19036 19036 19037 19037 19038 138 19039 11 19040 140 19041 157 19042 158 19043 160 19044 162 19045 76 19046 124 19047 165 19048 19048 19049 19049 19050 138 19051 11 19052 140 19053 157 19054 2240 19055 2242 19056 2243 19057 2244 19058 2 19059 19059 19060 19060 19061 2 19062 19062 19063 845 19064 19064 19065 11 19066 19066 19067 2 19068 417 19069 19069 19070 19070 19071 19071 19072 2727 19073 19073 19074 19074 19075 350 19076 350 19077 353 19078 2 19079 417 19080 19080 19081 569 19082 19082 19083 19083 19084 19084 19085 19085 19086 2 19087 417 19088 19088 19089 19089 19090 19090 19091 19091 19092 2804 19093 19093 19094 569 19095 19095 19096 2 19097 19097 19098 19098 19099 18742 19100 2 19101 19101 19102 19102 19103 19103 19104 19104 19105 19105 19106 2898 19107 19107 19108 68 19109 19109 19110 19110 19111 19111 19112 19112 19113 19113 19114 19114 19115 19115 19116 2 19117 19117 19118 19118 19119 19119 19120 19120 19121 19121 19122 19122 19123 2942 19124 2944 19125 19125 19126 19126 19127 19127 19128 19128 19129 19129 19130 350 19131 350 19132 40 19133 353 19134 2 19135 417 19136 19136 19137 569 19138 19138 19139 19139 19140 19140 19141 19141 19142 932 19143 19143 19144 19144 19145 19145 19146 965 19147 154 19148 157 19149 19149 19150 19150 19151 40 19152 19152 19153 19153 19154 2981 19155 2984 19156 2986 19157 2988 19158 76 19159 2990 19160 2991 19161 19161 19162 276 19163 19163 19164 2 19165 276 19166 76 19167 3971 19168 2829 19169 19169 19170 1851 19171 157 19172 2040 19173 2 19174 19174 19175 2 19176 154 19177 157 19178 19178 19179 19179 19180 19180 19181 19181 19182 19182 19183 5266 19184 19184 19185 157 19186 19186 19187 2 19188 276 19189 19189 19190 2 19191 276 19192 19192 19193 19193 19194 19194 19195 19195 19196 19196 19197 19197 19198 1851 19199 157 19200 19200 19201 19201 19202 19202 19203 19203 19204 276 19205 19205 19206 19206 19207 2 19208 417 19209 19209 19210 5298 19211 19211 19212 19212 19213 19213 19214 19214 19215 19215 19216 19216 19217 2898 19218 19218 19219 68 19220 19220 19221 19221 19222 19222 19223 19223 19224 19224 19225 19225 19226 19226 19227 2 19228 19228 19229 19229 19230 19230 19231 19231 19232 19232 19233 19233 19234 2942 19235 2944 19236 19236 19237 19237 19238 19238 19239 19239 19240 19240 19241 350 19242 350 19243 40 19244 353 19245 2 19246 417 19247 19247 19248 569 19249 19249 19250 19250 19251 19251 19252 19252 19253 932 19254 19254 19255 19255 19256 19256 19257 965 19258 154 19259 157 19260 19260 19261 19261 19262 40 19263 19263 19264 19264 19265 2981 19266 2984 19267 2986 19268 2988 19269 76 19270 2990 19271 2991 19272 19272 19273 276 19274 19274 19275 2 19276 276 19277 76 19278 3971 19279 2829 19280 19280 19281 1851 19282 157 19283 2040 19284 2 19285 19285 19286 2 19287 154 19288 157 19289 19289 19290 19290 19291 19291 19292 19292 19293 19293 19294 5266 19295 19295 19296 157 19297 19297 19298 2 19299 276 19300 19300 19301 2 19302 276 19303 19303 19304 19304 19305 19305 19306 19306 19307 19307 19308 19308 19309 1851 19310 157 19311 19311 19312 19312 19313 19313 19314 19314 19315 276 19316 19316 19317 19317 19318 2 19319 417 19320 19320 19321 5298 19322 19322 19323 19323 19324 19324 19325 4 19326 11 19327 11 19328 19328 19329 84 19330 22 19331 88 19332 11 19333 19333 19334 98 19335 19335 19336 19336 19337 1538 19338 19338 19339 19339 19340 19340 19341 98 19342 845 19343 11 19344 19344 19345 932 19346 19346 19347 19347 19348 965 19349 154 19350 157 19351 19351 19352 19352 19353 19353 19354 16374 19355 19324 19356 4 19357 11 19358 11 19359 19359 19360 84 19361 22 19362 88 19363 11 19364 19364 19365 98 19366 157 19367 19367 19368 1538 19369 19369 19370 19370 19371 19371 19372 98 19373 845 19374 11 19375 19375 19376 932 19377 19377 19378 19378 19379 965 19380 154 19381 157 19382 19382 19383 19383 19384 19384 19385 16374 19386 19386 19387 19387 19388 19388 19389 19389 19390 19390 19391 15 19392 16 19393 15 19394 11 19395 26 19396 2 19397 6185 19398 16 19399 11 19400 11 19401 40 19402 16 19403 11 19404 11 19405 19405 19406 16 19407 15 19408 69 19409 70 19410 11 19411 16 19412 76 19413 11 19414 11 19415 19415 19416 87 19417 19417 19418 91 19419 19419 19420 97 19421 19421 19422 102 19423 105 19424 19424 19425 19425 19426 19426 19427 19427 19428 19428 19429 19429 19430 19430 19431 124 19432 165 19433 19433 19434 26 19435 11 19436 2 19437 276 19438 26 19439 19439 19440 15 19441 15 19442 11 19443 26 19444 2 19445 11 19446 11 19447 40 19448 16 19449 19449 19450 15 19451 69 19452 70 19453 11 19454 76 19455 11 19456 11 19457 19457 19458 87 19459 102 19460 19460 19461 19426 19462 19462 19463 124 19464 165 19465 19465 19466 26 19467 19467 19468 19468 19469 1054 19470 6185 19471 19471 19472 16296 19473 16297 19474 6185 19475 19475 19476 2 19477 276 19478 16374 19479 16375 19480 19480 19481 19481 19482 16378 19483 6185 19484 19484 19485 22 19486 154 19487 157 19488 6185 19489 19489 19490 124 19491 165 19492 19492 19493 19493 19494 11 19495 76 19496 19496 19497 124 19498 165 19499 19499 19500 13 19501 16550 19502 157 19503 76 19504 124 19505 165 19506 19506 19507 2 19508 276 19509 16563 19510 16564 19511 19511 19512 16566 19513 16567 19514 16568 19515 19515 19516 16568 19517 19517 19518 16703 19519 16704 19520 6185 19521 19521 19522 16704 19523 6185 19524 19524 19525 19525 19526 3060 19527 19527 19528 6185 19529 19529 19530 6185 19531 19531 19532 3060 19533 19533 19534 2 19535 17945 19536 19324 19537 19335 19538 16374 19539 19324 19540 157 19541 16374 19542 19386 19543 19543 19544 19544 19545 19389 19546 6185 19547 19547 19548 19548 19549 19549 19550 19550 19551 6185 19552 19552 19553 2 19554 19554 19555 19549 19556 6185 19557 19557 19558 19558 19559 157 19560 19560 19561 2 19562 19562 19563 16374 19564 19564 19565 19565 19566 19566 19567 19567 19568 19568 19569 15 19570 16 19571 15 19572 11 19573 26 19574 2 19575 6185 19576 16 19577 11 19578 11 19579 40 19580 16 19581 11 19582 11 19583 19583 19584 16 19585 15 19586 69 19587 70 19588 11 19589 16 19590 76 19591 11 19592 11 19593 19593 19594 87 19595 19595 19596 91 19597 19597 19598 97 19599 19599 19600 102 19601 105 19602 19602 19603 19603 19604 19604 19605 19605 19606 19606 19607 19607 19608 19608 19609 124 19610 165 19611 19611 19612 26 19613 11 19614 2 19615 276 19616 26 19617 19617 19618 15 19619 15 19620 11 19621 26 19622 2 19623 11 19624 11 19625 40 19626 16 19627 19627 19628 15 19629 69 19630 70 19631 11 19632 76 19633 11 19634 11 19635 19635 19636 87 19637 102 19638 19638 19639 19604 19640 19640 19641 124 19642 165 19643 19643 19644 26 19645 19645 19646 19646 19647 1054 19648 6185 19649 19649 19650 16296 19651 16297 19652 6185 19653 19653 19654 2 19655 276 19656 16374 19657 16375 19658 19658 19659 19659 19660 16378 19661 6185 19662 19662 19663 22 19664 154 19665 157 19666 6185 19667 19667 19668 124 19669 165 19670 19670 19671 19671 19672 11 19673 76 19674 19674 19675 124 19676 165 19677 19677 19678 13 19679 16550 19680 157 19681 76 19682 124 19683 165 19684 19684 19685 2 19686 276 19687 16563 19688 16564 19689 19689 19690 16566 19691 16567 19692 16568 19693 19693 19694 16568 19695 19695 19696 16703 19697 16704 19698 6185 19699 19699 19700 16704 19701 6185 19702 19702 19703 19703 19704 3060 19705 19705 19706 6185 19707 19707 19708 6185 19709 19709 19710 3060 19711 19711 19712 2 19713 17945 19714 19324 19715 19335 19716 16374 19717 19324 19718 157 19719 16374 19720 19386 19721 19721 19722 19722 19723 19389 19724 6185 19725 19725 19726 19726 19727 19549 19728 6185 19729 19549 19730 6185 19731 19557 19732 157 19733 16374 19734 19564 19735 19735 19736 19736 19737 19567 19738 6185 19739 19739 19740 19740 19741 3060 19742 19742 19743 2 19744 19744 19745 19745 19746 19746 19747 15 19748 15 19749 11 19750 26 19751 2 19752 11 19753 11 19754 40 19755 16 19756 11 19757 19757 19758 15 19759 69 19760 70 19761 11 19762 76 19763 11 19764 11 19765 19765 19766 87 19767 102 19768 19768 19769 19769 19770 19770 19771 124 19772 165 19773 19773 19774 11 19775 2 19776 276 19777 6185 19778 19778 19779 26 19780 11 19781 2 19782 276 19783 26 19784 19784 19785 15 19786 15 19787 11 19788 26 19789 2 19790 11 19791 11 19792 40 19793 16 19794 19794 19795 15 19796 69 19797 70 19798 11 19799 76 19800 11 19801 11 19802 19802 19803 87 19804 102 19805 19805 19806 19769 19807 19807 19808 124 19809 165 19810 19810 19811 26 19812 19812 19813 19813 19814 1054 19815 6185 19816 19816 19817 16296 19818 16297 19819 6185 19820 19820 19821 2 19822 276 19823 16374 19824 16375 19825 19825 19826 19826 19827 16378 19828 6185 19829 19829 19830 22 19831 154 19832 157 19833 6185 19834 19834 19835 124 19836 165 19837 19837 19838 19838 19839 11 19840 76 19841 19841 19842 124 19843 165 19844 19844 19845 13 19846 16550 19847 157 19848 76 19849 124 19850 165 19851 19851 19852 2 19853 276 19854 16563 19855 16564 19856 19856 19857 16566 19858 16567 19859 16568 19860 19860 19861 16568 19862 19862 19863 16703 19864 16704 19865 6185 19866 19866 19867 16704 19868 6185 19869 19869 19870 19870 19871 3060 19872 19872 19873 6185 19874 19874 19875 6185 19876 19876 19877 3060 19878 19878 19879 2 19880 17945 19881 19324 19882 19335 19883 16374 19884 19324 19885 157 19886 16374 19887 19386 19888 19888 19889 19889 19890 19389 19891 6185 19892 19892 19893 19893 19894 19549 19895 6185 19896 19549 19897 6185 19898 19557 19899 157 19900 16374 19901 19564 19902 19902 19903 19903 19904 19567 19905 6185 19906 19906 19907 3060 19908 19908 19909 19770 19910 11 19911 2 19912 276 19913 6185 19914 19914 19915 16 19916 2040 19917 19917 19918 19918 19919 16374 19920 16 19921 19921 19922 19922 19923 19923 19924 19924 19925 19925 19926 19926 19927 15 19928 16 19929 15 19930 11 19931 26 19932 2 19933 6185 19934 16 19935 11 19936 11 19937 40 19938 16 19939 11 19940 11 19941 19941 19942 16 19943 15 19944 69 19945 70 19946 11 19947 16 19948 76 19949 11 19950 11 19951 19951 19952 87 19953 19953 19954 91 19955 19955 19956 97 19957 19957 19958 102 19959 105 19960 19960 19961 19961 19962 19962 19963 19963 19964 19964 19965 19965 19966 19966 19967 124 19968 165 19969 19969 19970 26 19971 11 19972 2 19973 276 19974 26 19975 19975 19976 15 19977 15 19978 11 19979 26 19980 2 19981 11 19982 11 19983 40 19984 16 19985 19985 19986 15 19987 69 19988 70 19989 11 19990 76 19991 11 19992 11 19993 19993 19994 87 19995 102 19996 19996 19997 19962 19998 19998 19999 124 20000 165 20001 20001 20002 26 20003 20003 20004 20004 20005 1054 20006 6185 20007 20007 20008 16296 20009 16297 20010 6185 20011 20011 20012 2 20013 276 20014 16374 20015 16375 20016 20016 20017 20017 20018 16378 20019 6185 20020 20020 20021 22 20022 154 20023 157 20024 6185 20025 20025 20026 124 20027 165 20028 20028 20029 20029 20030 11 20031 76 20032 20032 20033 124 20034 165 20035 20035 20036 13 20037 16550 20038 157 20039 76 20040 124 20041 165 20042 20042 20043 2 20044 276 20045 16563 20046 16564 20047 20047 20048 16566 20049 16567 20050 16568 20051 20051 20052 16568 20053 20053 20054 16703 20055 16704 20056 6185 20057 20057 20058 16704 20059 6185 20060 20060 20061 20061 20062 3060 20063 20063 20064 6185 20065 20065 20066 6185 20067 20067 20068 3060 20069 20069 20070 2 20071 17945 20072 19324 20073 19335 20074 16374 20075 19324 20076 157 20077 16374 20078 19386 20079 20079 20080 20080 20081 19389 20082 6185 20083 20083 20084 20084 20085 19549 20086 6185 20087 19549 20088 6185 20089 19557 20090 157 20091 16374 20092 19564 20093 20093 20094 20094 20095 19567 20096 6185 20097 20097 20098 3060 20099 20099 20100 19770 20101 11 20102 2 20103 276 20104 6185 20105 20105 20106 16 20107 19918 20108 16374 20109 19922 20110 20110 20111 20111 20112 19925 20113 6185 20114 20114 20115 6185 20116 20116 20117 6185 20118 20118 20119 20119 20120 16264 20121 138 20122 11 20123 140 20124 157 20125 160 20126 162 20127 76 20128 124 20129 165 20130 20130 20131 20131 20132 20132 20133 16 20134 2984 20135 2986 20136 2988 20137 76 20138 2990 20139 2991 20140 20140 20141 20141 20142 1054 20143 6185 20144 20144 20145 16296 20146 16297 20147 6185 20148 20148 20149 2 20150 276 20151 16374 20152 16375 20153 20153 20154 20154 20155 16378 20156 6185 20157 20157 20158 22 20159 154 20160 157 20161 6185 20162 20162 20163 124 20164 165 20165 20165 20166 20166 20167 11 20168 76 20169 20169 20170 124 20171 165 20172 20172 20173 13 20174 16550 20175 157 20176 76 20177 124 20178 165 20179 20179 20180 2988 20181 76 20182 2990 20183 2991 20184 20184 20185 2 20186 276 20187 16563 20188 16564 20189 20189 20190 16566 20191 16567 20192 16568 20193 20193 20194 16568 20195 20195 20196 16703 20197 16704 20198 6185 20199 20199 20200 16704 20201 6185 20202 20202 20203 20203 20204 3060 20205 20205 20206 6185 20207 20207 20208 20208 20209 13 20210 2988 20211 76 20212 2990 20213 2991 20214 20214 20215 20215 20216 2 20217 276 20218 16374 20219 16209 20220 20220 20221 20221 20222 157 20223 6185 20224 20224 20225 6185 20226 20226 20227 3060 20228 20228 20229 2 20230 17945 20231 19324 20232 19335 20233 16374 20234 19324 20235 157 20236 16374 20237 19386 20238 20238 20239 20239 20240 19389 20241 6185 20242 20242 20243 20243 20244 19549 20245 6185 20246 19549 20247 6185 20248 19557 20249 157 20250 16374 20251 19564 20252 20252 20253 20253 20254 19567 20255 6185 20256 20256 20257 20257 20258 161 20259 2986 20260 2988 20261 76 20262 2990 20263 2991 20264 20264 20265 2248 20266 20266 20267 20267 20268 20268 20269 20269 20270 20270 20271 20271 20272 20272 20273 20273 20274 20274 20275 20275 20276 20276 20277 20277 20278 20278 20279 2263 20280 2264 20281 2248 20282 20282 20283 20283 20284 20284 20285 20285 20286 20286 20287 20287 20288 20288 20289 20289 20290 20290 20291 20291 20292 20292 20293 2284 20294 20294 20295 2264 20296 20296 20297 2248 20298 20298 20299 20299 20300 20300 20301 20301 20302 20302 20303 20303 20304 20304 20305 20305 20306 20306 20307 20307 20308 2248 20309 20309 20310 20310 20311 20311 20312 20312 20313 20313 20314 20314 20315 20315 20316 20316 20317 3060 20318 20318 20319 19770 20320 11 20321 2 20322 276 20323 6185 20324 20324 20325 16 20326 19918 20327 16374 20328 19922 20329 20329 20330 20330 20331 19925 20332 6185 20333 20333 20334 6185 20335 20335 20336 2984 20337 2986 20338 2988 20339 76 20340 2990 20341 2991 20342 20342 20343 6185 20344 20344 20345 2 20346 20346 20347 20347 20348 6185 20349 20349 20350 6185 20351 20351 20352 20352 20353 20353 20354 1054 20355 6185 20356 20356 20357 16296 20358 16297 20359 6185 20360 20360 20361 2 20362 276 20363 16374 20364 16375 20365 20365 20366 20366 20367 16378 20368 6185 20369 20369 20370 22 20371 154 20372 157 20373 6185 20374 20374 20375 124 20376 165 20377 20377 20378 20378 20379 11 20380 76 20381 20381 20382 124 20383 165 20384 20384 20385 13 20386 16550 20387 157 20388 76 20389 124 20390 165 20391 20391 20392 2 20393 276 20394 16563 20395 16564 20396 20396 20397 16566 20398 16567 20399 16568 20400 20400 20401 16568 20402 20402 20403 16703 20404 16704 20405 6185 20406 20406 20407 16704 20408 6185 20409 20409 20410 20410 20411 3060 20412 20412 20413 6185 20414 20414 20415 2 20416 276 20417 16374 20418 20418 20419 6185 20420 20420 20421 3060 20422 20422 20423 2 20424 17945 20425 19324 20426 19335 20427 16374 20428 19324 20429 157 20430 16374 20431 19386 20432 20432 20433 20433 20434 19389 20435 6185 20436 20436 20437 20437 20438 19549 20439 6185 20440 19549 20441 6185 20442 19557 20443 157 20444 16374 20445 19564 20446 20446 20447 20447 20448 19567 20449 6185 20450 20450 20451 3060 20452 20452 20453 19770 20454 11 20455 2 20456 276 20457 6185 20458 20458 20459 16 20460 19918 20461 16374 20462 19922 20463 20463 20464 20464 20465 19925 20466 6185 20467 20467 20468 6185 20469 20469 20470 6185 20471 20471 20472 16 20473 19918 20474 16374 20475 19922 20476 20476 20477 20477 20478 19925 20479 6185 20480 20480 20481 6185 20482 20482 20483 6185 20484 20484 20485 20485 20486 16264 20487 138 20488 11 20489 140 20490 157 20491 160 20492 162 20493 76 20494 124 20495 165 20496 20496 20497 20497 20498 20498 20499 16 20500 2984 20501 2986 20502 2988 20503 76 20504 2990 20505 2991 20506 20506 20507 20507 20508 1054 20509 6185 20510 20510 20511 16296 20512 16297 20513 6185 20514 20514 20515 2 20516 276 20517 16374 20518 16375 20519 20519 20520 20520 20521 16378 20522 6185 20523 20523 20524 22 20525 154 20526 157 20527 6185 20528 20528 20529 124 20530 165 20531 20531 20532 20532 20533 11 20534 76 20535 20535 20536 124 20537 165 20538 20538 20539 13 20540 16550 20541 157 20542 76 20543 124 20544 165 20545 20545 20546 2988 20547 76 20548 2990 20549 2991 20550 20550 20551 2 20552 276 20553 16563 20554 16564 20555 20555 20556 16566 20557 16567 20558 16568 20559 20559 20560 16568 20561 20561 20562 16703 20563 16704 20564 6185 20565 20565 20566 16704 20567 6185 20568 20568 20569 20569 20570 3060 20571 20571 20572 6185 20573 20573 20574 20208 20575 2988 20576 76 20577 2990 20578 2991 20579 20579 20580 2 20581 276 20582 16374 20583 20583 20584 157 20585 6185 20586 20586 20587 6185 20588 20588 20589 3060 20590 20590 20591 2 20592 17945 20593 19324 20594 19335 20595 16374 20596 19324 20597 157 20598 16374 20599 19386 20600 20600 20601 20601 20602 19389 20603 6185 20604 20604 20605 20605 20606 19549 20607 6185 20608 19549 20609 6185 20610 19557 20611 157 20612 16374 20613 19564 20614 20614 20615 20615 20616 19567 20617 6185 20618 20618 20619 20257 20620 2986 20621 2988 20622 76 20623 2990 20624 2991 20625 20625 20626 20626 20627 3060 20628 20628 20629 19770 20630 11 20631 2 20632 276 20633 6185 20634 20634 20635 16 20636 19918 20637 16374 20638 19922 20639 20639 20640 20640 20641 19925 20642 6185 20643 20643 20644 6185 20645 20645 20646 2984 20647 2986 20648 2988 20649 76 20650 2990 20651 2991 20652 20652 20653 6185 20654 20654 20655 3060 20656 20656 20657 19770 20658 11 20659 2 20660 276 20661 6185 20662 20662 20663 16 20664 19918 20665 16374 20666 19922 20667 20667 20668 20668 20669 19925 20670 6185 20671 20671 20672 6185 20673 20673 20674 6185 20675 20675 20676 20676 20677 16264 20678 138 20679 11 20680 140 20681 157 20682 160 20683 162 20684 76 20685 124 20686 165 20687 20687 20688 20688 20689 20689 20690 16 20691 2984 20692 2986 20693 2988 20694 76 20695 2990 20696 2991 20697 20697 20698 20698 20699 1054 20700 6185 20701 20701 20702 16296 20703 16297 20704 6185 20705 20705 20706 2 20707 276 20708 16374 20709 16375 20710 20710 20711 20711 20712 16378 20713 6185 20714 20714 20715 22 20716 154 20717 157 20718 6185 20719 20719 20720 124 20721 165 20722 20722 20723 20723 20724 11 20725 76 20726 20726 20727 124 20728 165 20729 20729 20730 13 20731 16550 20732 157 20733 76 20734 124 20735 165 20736 20736 20737 2988 20738 76 20739 2990 20740 2991 20741 20741 20742 2 20743 276 20744 16563 20745 16564 20746 20746 20747 16566 20748 16567 20749 16568 20750 20750 20751 16568 20752 20752 20753 16703 20754 16704 20755 6185 20756 20756 20757 16704 20758 6185 20759 20759 20760 20760 20761 3060 20762 20762 20763 6185 20764 20764 20765 20208 20766 2988 20767 76 20768 2990 20769 2991 20770 20770 20771 2 20772 276 20773 16374 20774 20774 20775 157 20776 6185 20777 20777 20778 6185 20779 20779 20780 3060 20781 20781 20782 2 20783 17945 20784 19324 20785 19335 20786 16374 20787 19324 20788 157 20789 16374 20790 19386 20791 20791 20792 20792 20793 19389 20794 6185 20795 20795 20796 20796 20797 19549 20798 6185 20799 19549 20800 6185 20801 19557 20802 157 20803 16374 20804 19564 20805 20805 20806 20806 20807 19567 20808 6185 20809 20809 20810 20257 20811 2986 20812 2988 20813 76 20814 2990 20815 2991 20816 20816 20817 20817 20818 3060 20819 20819 20820 19770 20821 11 20822 2 20823 276 20824 6185 20825 20825 20826 16 20827 19918 20828 16374 20829 19922 20830 20830 20831 20831 20832 19925 20833 6185 20834 20834 20835 6185 20836 20836 20837 2984 20838 2986 20839 2988 20840 76 20841 2990 20842 2991 20843 20843 20844 6185 20845 20845 20846 845 20847 11 20848 20848 20849 20849 20850 20850 20851 350 20852 350 20853 353 20854 2 20855 417 20856 20856 20857 569 20858 20858 20859 20859 20860 20860 20861 20861 20862 2 20863 417 20864 20864 20865 20865 20866 20866 20867 20867 20868 20868 20869 569 20870 20870 20871 20871 20872 1851 20873 157 20874 20874 20875 20875 20876 2 20877 417 20878 20878 20879 20879 20880 845 20881 11 20882 20882 20883 20883 20884 20884 20885 350 20886 350 20887 353 20888 2 20889 417 20890 20890 20891 569 20892 20892 20893 20893 20894 20894 20895 20895 20896 2 20897 417 20898 20898 20899 20899 20900 20900 20901 20901 20902 20902 20903 569 20904 20904 20905 20905 20906 1851 20907 157 20908 20908 20909 20909 20910 2 20911 417 20912 20912 20913 845 20914 18645 20915 11 20916 18647 20917 2 20918 417 20919 18650 20920 18651 20921 18652 20922 2727 20923 18654 20924 18655 20925 350 20926 350 20927 353 20928 2 20929 417 20930 18661 20931 569 20932 18663 20933 18664 20934 18665 20935 18666 20936 2 20937 417 20938 18669 20939 18670 20940 18671 20941 18672 20942 2804 20943 18674 20944 569 20945 18676 20946 2 20947 18678 20948 18679 20949 2 20950 3 20951 4 20952 2 20953 2 20954 2 20955 2 20956 11 20957 2 20958 2 20959 18690 20960 2 20961 18692 20962 22 20963 18694 20964 18695 20965 2 20966 11 20967 11 20968 18699 20969 18700 20970 18701 20971 22 20972 2 20973 2 20974 2 20975 11 20976 18707 20977 11 20978 18709 20979 11 20980 18711 20981 18712 20982 18713 20983 18714 20984 60 20985 18716 20986 2 20987 2 20988 11 20989 2 20990 2 20991 68 20992 129 20993 18724 20994 2 20995 2 20996 18727 20997 2 20998 18729 20999 18730 21000 2 21001 84 21002 85 21003 88 21004 132 21005 11 21006 18737 21007 18738 21008 98 21009 18740 21010 18741 21011 18742 21012 103 21013 103 21014 18745 21015 18746 21016 18747 21017 18748 21018 18749 21019 18750 21020 18751 21021 18752 21022 18753 21023 18754 21024 98 21025 2 21026 18757 21027 2 21028 2 21029 2 21030 2 21031 2 21032 2 21033 2 21034 2 21035 300 21036 2 21037 2 21038 2 21039 2 21040 2 21041 306 21042 2 21043 2 21044 2 21045 2 21046 2 21047 2 21048 2 21049 2 21050 2 21051 2 21052 2 21053 2 21054 2 21055 2 21056 2 21057 18788 21058 18789 21059 18790 21060 18791 21061 18792 21062 18793 21063 18794 21064 18795 21065 18796 21066 18797 21067 18798 21068 18799 21069 18800 21070 18801 21071 18802 21072 4 21073 2 21074 18805 21075 18806 21076 18807 21077 18808 21078 18809 21079 18810 21080 18811 21081 18812 21082 18813 21083 18814 21084 18815 21085 350 21086 350 21087 40 21088 353 21089 2 21090 417 21091 18822 21092 569 21093 18824 21094 18825 21095 18826 21096 18827 21097 18828 21098 2 21099 417 21100 18831 21101 18832 21102 40 21103 18834 21104 276 21105 18836 21106 18837 21107 2 21108 417 21109 18840 21110 18841 21111 18842 21112 18843 21113 18844 21114 18845 21115 2 21116 728 21117 2 21118 18849 21119 18850 21120 18851 21121 18852 21122 18853 21123 18854 21124 18855 21125 18856 21126 18857 21127 18858 21128 845 21129 18860 21130 18861 21131 18862 21132 18863 21133 18864 21134 18865 21135 18866 21136 18867 21137 18868 21138 18869 21139 18870 21140 18871 21141 18872 21142 18873 21143 18874 21144 18875 21145 18876 21146 18877 21147 18878 21148 18879 21149 18880 21150 18881 21151 18882 21152 18883 21153 18884 21154 18885 21155 18886 21156 18887 21157 18888 21158 18889 21159 18890 21160 18891 21161 18892 21162 18893 21163 18894 21164 18895 21165 18896 21166 18897 21167 18898 21168 18899 21169 18900 21170 18901 21171 18902 21172 18903 21173 18904 21174 18905 21175 18906 21176 18907 21177 18908 21178 18909 21179 18910 21180 18911 21181 18912 21182 18913 21183 18914 21184 18915 21185 18916 21186 18917 21187 18918 21188 18919 21189 18920 21190 18921 21191 18922 21192 18923 21193 18924 21194 18925 21195 18926 21196 18927 21197 18928 21198 18929 21199 18930 21200 18931 21201 18932 21202 18933 21203 18934 21204 18935 21205 18936 21206 18937 21207 18938 21208 11 21209 18940 21210 18941 21211 18942 21212 2 21213 417 21214 18945 21215 932 21216 18947 21217 18948 21218 965 21219 154 21220 157 21221 18952 21222 18953 21223 1476 21224 2 21225 2 21226 2 21227 18958 21228 2 21229 18960 21230 2 21231 2 21232 2 21233 2 21234 2 21235 2 21236 2 21237 2 21238 2 21239 18970 21240 18971 21241 18972 21242 18973 21243 18974 21244 18975 21245 18976 21246 18977 21247 18978 21248 18979 21249 18980 21250 18981 21251 18982 21252 22 21253 18984 21254 4 21255 11 21256 18987 21257 88 21258 11 21259 18990 21260 98 21261 18992 21262 1538 21263 18994 21264 18995 21265 18996 21266 98 21267 845 21268 11 21269 19000 21270 932 21271 19002 21272 19003 21273 965 21274 154 21275 157 21276 19007 21277 19008 21278 19009 21279 845 21280 11 21281 19012 21282 19013 21283 19014 21284 350 21285 350 21286 353 21287 2 21288 417 21289 19020 21290 569 21291 19022 21292 19023 21293 19024 21294 19025 21295 2 21296 417 21297 19028 21298 19029 21299 19030 21300 19031 21301 19032 21302 19033 21303 2 21304 417 21305 19036 21306 19037 21307 138 21308 11 21309 140 21310 157 21311 158 21312 160 21313 162 21314 76 21315 124 21316 165 21317 19048 21318 19049 21319 138 21320 11 21321 140 21322 157 21323 2240 21324 2242 21325 2243 21326 2244 21327 2 21328 19059 21329 19060 21330 2 21331 19062 21332 845 21333 19064 21334 11 21335 19066 21336 2 21337 417 21338 19069 21339 19070 21340 19071 21341 2727 21342 19073 21343 19074 21344 350 21345 350 21346 353 21347 2 21348 417 21349 19080 21350 569 21351 19082 21352 19083 21353 19084 21354 19085 21355 2 21356 417 21357 19088 21358 19089 21359 19090 21360 19091 21361 2804 21362 19093 21363 569 21364 19095 21365 2 21366 19097 21367 19098 21368 18742 21369 2 21370 19101 21371 19102 21372 19103 21373 19104 21374 19105 21375 2898 21376 19107 21377 68 21378 19109 21379 19110 21380 19111 21381 19112 21382 19113 21383 19114 21384 19115 21385 19122 21386 2942 21387 2944 21388 19126 21389 932 21390 19143 21391 19144 21392 19145 21393 965 21394 154 21395 157 21396 19149 21397 19150 21398 19153 21399 2981 21400 2984 21401 2986 21402 2988 21403 76 21404 2990 21405 2991 21406 19161 21407 2 21408 276 21409 76 21410 3971 21411 2829 21412 19169 21413 1851 21414 157 21415 2040 21416 2 21417 19174 21418 2 21419 154 21420 157 21421 19178 21422 19179 21423 19180 21424 19181 21425 19182 21426 5266 21427 19184 21428 157 21429 19186 21430 2 21431 276 21432 19189 21433 2 21434 276 21435 19192 21436 19193 21437 19194 21438 19195 21439 19196 21440 19197 21441 1851 21442 157 21443 19200 21444 19201 21445 19202 21446 19203 21447 276 21448 19205 21449 19206 21450 2 21451 417 21452 19209 21453 5298 21454 19211 21455 19212 21456 19213 21457 19214 21458 19215 21459 19216 21460 2898 21461 19218 21462 68 21463 19220 21464 19221 21465 19222 21466 19223 21467 19224 21468 19225 21469 19226 21470 19233 21471 2942 21472 2944 21473 19237 21474 932 21475 19254 21476 19255 21477 19256 21478 965 21479 154 21480 157 21481 19260 21482 19261 21483 19264 21484 2981 21485 2984 21486 2986 21487 2988 21488 76 21489 2990 21490 2991 21491 19272 21492 2 21493 276 21494 76 21495 3971 21496 2829 21497 19280 21498 1851 21499 157 21500 2040 21501 2 21502 19285 21503 2 21504 154 21505 157 21506 19289 21507 19290 21508 19291 21509 19292 21510 19293 21511 5266 21512 19295 21513 157 21514 19297 21515 2 21516 276 21517 19300 21518 2 21519 276 21520 19303 21521 19304 21522 19305 21523 19306 21524 19307 21525 19308 21526 1851 21527 157 21528 19311 21529 19312 21530 19313 21531 19314 21532 276 21533 19316 21534 19317 21535 2 21536 417 21537 19320 21538 5298 21539 19322 21540 19323 21541 19549 21542 6185 21543 19549 21544 6185 21545 19557 21546 157 21547 16374 21548 19564 21549 21549 21550 21550 21551 19567 21552 6185 21553 21553 21554 3060 21555 21555 21556 19770 21557 11 21558 2 21559 276 21560 6185 21561 21561 21562 16 21563 19918 21564 16374 21565 19922 21566 21566 21567 21567 21568 19925 21569 6185 21570 21570 21571 6185 21572 21572 21573 6185 21574 21574 21575 21575 21576 16264 21577 138 21578 11 21579 140 21580 157 21581 160 21582 162 21583 76 21584 124 21585 165 21586 21586 21587 21587 21588 21588 21589 16 21590 2984 21591 2986 21592 2988 21593 76 21594 2990 21595 2991 21596 21596 21597 21597 21598 1054 21599 6185 21600 21600 21601 16296 21602 16297 21603 6185 21604 21604 21605 2 21606 276 21607 16374 21608 16375 21609 21609 21610 21610 21611 16378 21612 6185 21613 21613 21614 22 21615 154 21616 157 21617 6185 21618 21618 21619 124 21620 165 21621 21621 21622 21622 21623 11 21624 76 21625 21625 21626 124 21627 165 21628 21628 21629 13 21630 16550 21631 157 21632 76 21633 124 21634 165 21635 21635 21636 2988 21637 76 21638 2990 21639 2991 21640 21640 21641 2 21642 276 21643 16563 21644 16564 21645 21645 21646 16566 21647 16567 21648 16568 21649 21649 21650 16568 21651 21651 21652 16703 21653 16704 21654 6185 21655 21655 21656 16704 21657 6185 21658 21658 21659 21659 21660 3060 21661 21661 21662 6185 21663 21663 21664 20208 21665 2988 21666 76 21667 2990 21668 2991 21669 21669 21670 2 21671 276 21672 16374 21673 21673 21674 157 21675 6185 21676 21676 21677 6185 21678 21678 21679 3060 21680 21680 21681 2 21682 17945 21683 19324 21684 19335 21685 16374 21686 19324 21687 157 21688 16374 21689 19386 21690 21690 21691 21691 21692 19389 21693 6185 21694 21694 21695 21695 21696 19549 21697 6185 21698 19549 21699 6185 21700 19557 21701 157 21702 16374 21703 19564 21704 21704 21705 21705 21706 19567 21707 6185 21708 21708 21709 20257 21710 2986 21711 2988 21712 76 21713 2990 21714 2991 21715 21715 21716 3060 21717 21717 21718 19770 21719 11 21720 2 21721 276 21722 6185 21723 21723 21724 16 21725 19918 21726 16374 21727 19922 21728 21728 21729 21729 21730 19925 21731 6185 21732 21732 21733 6185 21734 21734 21735 2984 21736 2986 21737 2988 21738 76 21739 2990 21740 2991 21741 21741 21742 6185 21743 21743 21744 2 21745 3 21746 4 21747 2 21748 2 21749 2 21750 2 21751 11 21752 2 21753 2 21754 21754 21755 2 21756 21756 21757 22 21758 21758 21759 21759 21760 2 21761 11 21762 11 21763 21763 21764 21764 21765 21765 21766 22 21767 2 21768 2 21769 2 21770 11 21771 21771 21772 11 21773 21773 21774 11 21775 21775 21776 21776 21777 21777 21778 21778 21779 60 21780 21780 21781 2 21782 2 21783 11 21784 2 21785 2 21786 68 21787 129 21788 21788 21789 2 21790 2 21791 21791 21792 2 21793 21793 21794 21794 21795 2 21796 84 21797 85 21798 88 21799 132 21800 11 21801 21801 21802 21802 21803 98 21804 21804 21805 21805 21806 21806 21807 103 21808 103 21809 21809 21810 21810 21811 21811 21812 21812 21813 21813 21814 21814 21815 21815 21816 21816 21817 21817 21818 21818 21819 98 21820 2 21821 21821 21822 2 21823 2 21824 2 21825 2 21826 2 21827 2 21828 2 21829 2 21830 300 21831 2 21832 2 21833 2 21834 2 21835 2 21836 306 21837 2 21838 2 21839 2 21840 2 21841 2 21842 2 21843 2 21844 2 21845 2 21846 2 21847 2 21848 2 21849 2 21850 2 21851 2 21852 21852 21853 21853 21854 21854 21855 21855 21856 21856 21857 21857 21858 21858 21859 21859 21860 21860 21861 21861 21862 21862 21863 21863 21864 21864 21865 21865 21866 21866 21867 4 21868 2 21869 21869 21870 21870 21871 21871 21872 21872 21873 21873 21874 21874 21875 21875 21876 21876 21877 21877 21878 21878 21879 21879 21880 350 21881 350 21882 40 21883 353 21884 2 21885 417 21886 21886 21887 569 21888 21888 21889 21889 21890 21890 21891 21891 21892 21892 21893 2 21894 417 21895 21895 21896 21896 21897 40 21898 21898 21899 276 21900 21900 21901 21901 21902 2 21903 417 21904 21904 21905 21905 21906 21906 21907 21907 21908 21908 21909 21909 21910 2 21911 728 21912 2 21913 21913 21914 21914 21915 21915 21916 21916 21917 21917 21918 21918 21919 21919 21920 21920 21921 21921 21922 21922 21923 845 21924 21924 21925 21925 21926 21926 21927 21927 21928 21928 21929 21929 21930 21930 21931 21931 21932 21932 21933 21933 21934 21934 21935 21935 21936 21936 21937 21937 21938 21938 21939 21939 21940 21940 21941 21941 21942 21942 21943 21943 21944 21944 21945 21945 21946 21946 21947 21947 21948 21948 21949 21949 21950 21950 21951 21951 21952 21952 21953 21953 21954 21954 21955 21955 21956 21956 21957 21957 21958 21958 21959 21959 21960 21960 21961 21961 21962 21962 21963 21963 21964 21964 21965 21965 21966 21966 21967 21967 21968 21968 21969 21969 21970 21970 21971 21971 21972 21972 21973 21973 21974 21974 21975 21975 21976 21976 21977 21977 21978 21978 21979 21979 21980 21980 21981 21981 21982 21982 21983 21983 21984 21984 21985 21985 21986 21986 21987 21987 21988 21988 21989 21989 21990 21990 21991 21991 21992 21992 21993 21993 21994 21994 21995 21995 21996 21996 21997 21997 21998 21998 21999 21999 22000 22000 22001 22001 22002 22002 22003 11 22004 22004 22005 22005 22006 22006 22007 2 22008 417 22009 22009 22010 932 22011 22011 22012 22012 22013 965 22014 154 22015 157 22016 22016 22017 22017 22018 1476 22019 2 22020 2 22021 2 22022 22022 22023 2 22024 22024 22025 2 22026 2 22027 2 22028 2 22029 2 22030 2 22031 2 22032 2 22033 2 22034 22034 22035 22035 22036 22036 22037 22037 22038 22038 22039 22039 22040 22040 22041 22041 22042 22042 22043 22043 22044 22044 22045 22045 22046 22046 22047 22 22048 22048 22049 4 22050 11 22051 22051 22052 88 22053 11 22054 22054 22055 98 22056 22056 22057 1538 22058 22058 22059 22059 22060 22060 22061 98 22062 845 22063 11 22064 22064 22065 932 22066 22066 22067 22067 22068 965 22069 154 22070 157 22071 22071 22072 22072 22073 22073 22074 845 22075 11 22076 22076 22077 22077 22078 22078 22079 350 22080 350 22081 353 22082 2 22083 417 22084 22084 22085 569 22086 22086 22087 22087 22088 22088 22089 22089 22090 2 22091 417 22092 22092 22093 22093 22094 22094 22095 22095 22096 22096 22097 22097 22098 2 22099 417 22100 22100 22101 22101 22102 138 22103 11 22104 140 22105 157 22106 158 22107 160 22108 162 22109 76 22110 124 22111 165 22112 22112 22113 22113 22114 138 22115 11 22116 140 22117 157 22118 2240 22119 2242 22120 2243 22121 2244 22122 2 22123 2 22124 3 22125 4 22126 2 22127 2 22128 2 22129 2 22130 11 22131 2 22132 2 22133 21754 22134 2 22135 21756 22136 22 22137 21758 22138 21759 22139 2 22140 11 22141 11 22142 21763 22143 21764 22144 21765 22145 22 22146 2 22147 2 22148 2 22149 11 22150 21771 22151 11 22152 21773 22153 11 22154 21775 22155 21776 22156 21777 22157 21778 22158 60 22159 21780 22160 2 22161 2 22162 11 22163 2 22164 2 22165 68 22166 129 22167 21788 22168 2 22169 2 22170 21791 22171 2 22172 21793 22173 21794 22174 2 22175 84 22176 85 22177 88 22178 132 22179 11 22180 21801 22181 21802 22182 98 22183 21804 22184 21805 22185 22185 22186 103 22187 103 22188 21809 22189 21810 22190 21811 22191 21812 22192 21813 22193 21814 22194 21815 22195 21816 22196 21817 22197 21818 22198 98 22199 2 22200 21821 22201 2 22202 2 22203 2 22204 2 22205 2 22206 2 22207 2 22208 2 22209 300 22210 2 22211 2 22212 2 22213 2 22214 2 22215 306 22216 2 22217 2 22218 2 22219 2 22220 2 22221 2 22222 2 22223 2 22224 2 22225 2 22226 2 22227 2 22228 2 22229 2 22230 2 22231 21852 22232 21853 22233 21854 22234 21855 22235 21856 22236 21857 22237 21858 22238 21859 22239 21860 22240 21861 22241 21862 22242 21863 22243 21864 22244 21865 22245 21866 22246 4 22247 2 22248 21869 22249 21870 22250 21871 22251 21872 22252 21873 22253 21874 22254 21875 22255 21876 22256 21877 22257 21878 22258 21879 22259 350 22260 350 22261 40 22262 353 22263 2 22264 417 22265 21886 22266 569 22267 21888 22268 21889 22269 21890 22270 21891 22271 21892 22272 2 22273 417 22274 21895 22275 21896 22276 40 22277 21898 22278 276 22279 21900 22280 21901 22281 2 22282 417 22283 21904 22284 21905 22285 21906 22286 21907 22287 21908 22288 21909 22289 2 22290 728 22291 2 22292 21913 22293 21914 22294 21915 22295 21916 22296 21917 22297 21918 22298 21919 22299 21920 22300 21921 22301 21922 22302 845 22303 21924 22304 21925 22305 21926 22306 21927 22307 21928 22308 21929 22309 21930 22310 21931 22311 21932 22312 21933 22313 21934 22314 21935 22315 21936 22316 21937 22317 21938 22318 21939 22319 21940 22320 21941 22321 21942 22322 21943 22323 21944 22324 21945 22325 21946 22326 21947 22327 21948 22328 21949 22329 21950 22330 21951 22331 21952 22332 21953 22333 21954 22334 21955 22335 21956 22336 21957 22337 21958 22338 21959 22339 21960 22340 21961 22341 21962 22342 21963 22343 21964 22344 21965 22345 21966 22346 21967 22347 21968 22348 21969 22349 21970 22350 21971 22351 21972 22352 21973 22353 21974 22354 21975 22355 21976 22356 21977 22357 21978 22358 21979 22359 21980 22360 21981 22361 21982 22362 21983 22363 21984 22364 21985 22365 21986 22366 21987 22367 21988 22368 21989 22369 21990 22370 21991 22371 21992 22372 21993 22373 21994 22374 21995 22375 21996 22376 21997 22377 21998 22378 21999 22379 22000 22380 22001 22381 22002 22382 11 22383 22004 22384 22005 22385 22006 22386 2 22387 417 22388 22009 22389 932 22390 22011 22391 22012 22392 965 22393 154 22394 157 22395 22016 22396 22017 22397 1476 22398 2 22399 2 22400 2 22401 22022 22402 2 22403 22024 22404 2 22405 2 22406 2 22407 2 22408 2 22409 2 22410 2 22411 2 22412 2 22413 22034 22414 22035 22415 22036 22416 22037 22417 22038 22418 22039 22419 22040 22420 22041 22421 22042 22422 22043 22423 22044 22424 22045 22425 22046 22426 22 22427 22048 22428 4 22429 11 22430 22051 22431 88 22432 11 22433 22054 22434 98 22435 22056 22436 1538 22437 22058 22438 22059 22439 22060 22440 98 22441 845 22442 11 22443 22064 22444 932 22445 22066 22446 22067 22447 965 22448 154 22449 157 22450 22071 22451 22072 22452 22073 22453 845 22454 11 22455 22076 22456 22077 22457 22078 22458 350 22459 350 22460 353 22461 2 22462 417 22463 22084 22464 569 22465 22086 22466 22087 22467 22088 22468 22089 22469 2 22470 417 22471 22092 22472 22093 22473 22094 22474 22095 22475 22096 22476 22097 22477 2 22478 417 22479 22100 22480 22101 22481 138 22482 11 22483 140 22484 157 22485 158 22486 160 22487 162 22488 76 22489 124 22490 165 22491 22112 22492 22113 22493 138 22494 11 22495 140 22496 157 22497 2240 22498 2242 22499 2243 22500 2244 22501 2 22502 22185 22503 22503 22504 22503 22505 845 22506 22506 22507 11 22508 22508 22509 2 22510 417 22511 22511 22512 22512 22513 22513 22514 2727 22515 22515 22516 22516 22517 350 22518 350 22519 353 22520 2 22521 417 22522 22522 22523 569 22524 22524 22525 22525 22526 22526 22527 22527 22528 2 22529 417 22530 22530 22531 22531 22532 22532 22533 22533 22534 2804 22535 22535 22536 569 22537 22537 22538 2 22539 22539 22540 22540 22541 2 22542 3 22543 4 22544 2 22545 2 22546 2 22547 2 22548 11 22549 2 22550 2 22551 22551 22552 2 22553 22553 22554 22 22555 22555 22556 22556 22557 2 22558 11 22559 11 22560 22560 22561 22561 22562 22562 22563 22 22564 2 22565 2 22566 2 22567 11 22568 22568 22569 11 22570 22570 22571 11 22572 22572 22573 22573 22574 22574 22575 22575 22576 60 22577 22577 22578 2 22579 2 22580 11 22581 2 22582 2 22583 68 22584 129 22585 22585 22586 2 22587 2 22588 22588 22589 2 22590 22590 22591 22591 22592 2 22593 84 22594 85 22595 88 22596 132 22597 11 22598 22598 22599 22599 22600 98 22601 22601 22602 22602 22603 22603 22604 103 22605 103 22606 22606 22607 22607 22608 22608 22609 22609 22610 22610 22611 22611 22612 22612 22613 22613 22614 22614 22615 22615 22616 98 22617 2 22618 22618 22619 2 22620 2 22621 2 22622 2 22623 2 22624 2 22625 2 22626 2 22627 300 22628 2 22629 2 22630 2 22631 2 22632 2 22633 306 22634 2 22635 2 22636 2 22637 2 22638 2 22639 2 22640 2 22641 2 22642 2 22643 2 22644 2 22645 2 22646 2 22647 2 22648 2 22649 22649 22650 22650 22651 22651 22652 22652 22653 22653 22654 22654 22655 22655 22656 22656 22657 22657 22658 22658 22659 22659 22660 22660 22661 22661 22662 22662 22663 22663 22664 4 22665 2 22666 22666 22667 22667 22668 22668 22669 22669 22670 22670 22671 22671 22672 22672 22673 22673 22674 22674 22675 22675 22676 22676 22677 350 22678 350 22679 40 22680 353 22681 2 22682 417 22683 22683 22684 569 22685 22685 22686 22686 22687 22687 22688 22688 22689 22689 22690 2 22691 417 22692 22692 22693 22693 22694 40 22695 22695 22696 276 22697 22697 22698 22698 22699 2 22700 417 22701 22701 22702 22702 22703 22703 22704 22704 22705 22705 22706 22706 22707 2 22708 728 22709 2 22710 22710 22711 22711 22712 22712 22713 22713 22714 22714 22715 22715 22716 22716 22717 22717 22718 22718 22719 22719 22720 845 22721 22721 22722 22722 22723 22723 22724 22724 22725 22725 22726 22726 22727 22727 22728 22728 22729 22729 22730 22730 22731 22731 22732 22732 22733 22733 22734 22734 22735 22735 22736 22736 22737 22737 22738 22738 22739 22739 22740 22740 22741 22741 22742 22742 22743 22743 22744 22744 22745 22745 22746 22746 22747 22747 22748 22748 22749 22749 22750 22750 22751 22751 22752 22752 22753 22753 22754 22754 22755 22755 22756 22756 22757 22757 22758 22758 22759 22759 22760 22760 22761 22761 22762 22762 22763 22763 22764 22764 22765 22765 22766 22766 22767 22767 22768 22768 22769 22769 22770 22770 22771 22771 22772 22772 22773 22773 22774 22774 22775 22775 22776 22776 22777 22777 22778 22778 22779 22779 22780 22780 22781 22781 22782 22782 22783 22783 22784 22784 22785 22785 22786 22786 22787 22787 22788 22788 22789 22789 22790 22790 22791 22791 22792 22792 22793 22793 22794 22794 22795 22795 22796 22796 22797 22797 22798 22798 22799 22799 22800 11 22801 22801 22802 22802 22803 22803 22804 2 22805 417 22806 22806 22807 932 22808 22808 22809 22809 22810 965 22811 154 22812 157 22813 22813 22814 22814 22815 1476 22816 2 22817 2 22818 2 22819 22819 22820 2 22821 22821 22822 2 22823 2 22824 2 22825 2 22826 2 22827 2 22828 2 22829 2 22830 2 22831 22831 22832 22832 22833 22833 22834 22834 22835 22835 22836 22836 22837 22837 22838 22838 22839 22839 22840 22840 22841 22841 22842 22842 22843 22843 22844 22 22845 22845 22846 4 22847 11 22848 22848 22849 88 22850 11 22851 22851 22852 98 22853 22853 22854 1538 22855 22855 22856 22856 22857 22857 22858 98 22859 845 22860 11 22861 22861 22862 932 22863 22863 22864 22864 22865 965 22866 154 22867 157 22868 22868 22869 22869 22870 22870 22871 845 22872 11 22873 22873 22874 22874 22875 22875 22876 350 22877 350 22878 353 22879 2 22880 417 22881 22881 22882 569 22883 22883 22884 22884 22885 22885 22886 22886 22887 2 22888 417 22889 22889 22890 22890 22891 22891 22892 22892 22893 22893 22894 22894 22895 2 22896 417 22897 22897 22898 22898 22899 138 22900 11 22901 140 22902 157 22903 158 22904 160 22905 162 22906 76 22907 124 22908 165 22909 22909 22910 22910 22911 138 22912 11 22913 140 22914 157 22915 2240 22916 2242 22917 2243 22918 2244 22919 2 22920 22920 22921 22921 22922 2 22923 22923 22924 845 22925 22925 22926 11 22927 22927 22928 2 22929 417 22930 22930 22931 22931 22932 22932 22933 2727 22934 22934 22935 22935 22936 350 22937 350 22938 353 22939 2 22940 417 22941 22941 22942 569 22943 22943 22944 22944 22945 22945 22946 22946 22947 2 22948 417 22949 22949 22950 22950 22951 22951 22952 22952 22953 2804 22954 22954 22955 569 22956 22956 22957 2 22958 22958 22959 22959 22960 22603 22961 2 22962 22962 22963 22963 22964 22964 22965 22965 22966 22966 22967 2898 22968 22968 22969 68 22970 22970 22971 22971 22972 22972 22973 22973 22974 22974 22975 22975 22976 22976 22977 2 22978 22978 22979 22979 22980 22980 22981 22981 22982 22982 22983 22983 22984 2942 22985 2944 22986 22986 22987 22987 22988 22988 22989 22989 22990 22990 22991 350 22992 350 22993 40 22994 353 22995 2 22996 417 22997 22997 22998 569 22999 22999 23000 23000 23001 23001 23002 23002 23003 932 23004 23004 23005 23005 23006 23006 23007 965 23008 154 23009 157 23010 23010 23011 23011 23012 40 23013 23013 23014 23014 23015 2981 23016 2984 23017 2986 23018 2988 23019 76 23020 2990 23021 2991 23022 23022 23023 276 23024 23024 23025 2 23026 276 23027 76 23028 3971 23029 2829 23030 23030 23031 1851 23032 157 23033 2040 23034 2 23035 23035 23036 2 23037 154 23038 157 23039 23039 23040 23040 23041 23041 23042 23042 23043 23043 23044 5266 23045 23045 23046 157 23047 23047 23048 2 23049 276 23050 23050 23051 2 23052 276 23053 23053 23054 23054 23055 23055 23056 23056 23057 23057 23058 23058 23059 1851 23060 157 23061 23061 23062 23062 23063 23063 23064 23064 23065 276 23066 23066 23067 23067 23068 2 23069 417 23070 23070 23071 5298 23072 23072 23073 23073 23074 23074 23075 23075 23076 23076 23077 23077 23078 2898 23079 23079 23080 68 23081 23081 23082 23082 23083 23083 23084 23084 23085 23085 23086 23086 23087 23087 23088 2 23089 23089 23090 23090 23091 23091 23092 23092 23093 23093 23094 23094 23095 2942 23096 2944 23097 23097 23098 23098 23099 23099 23100 23100 23101 23101 23102 350 23103 350 23104 40 23105 353 23106 2 23107 417 23108 23108 23109 569 23110 23110 23111 23111 23112 23112 23113 23113 23114 932 23115 23115 23116 23116 23117 23117 23118 965 23119 154 23120 157 23121 23121 23122 23122 23123 40 23124 23124 23125 23125 23126 2981 23127 2984 23128 2986 23129 2988 23130 76 23131 2990 23132 2991 23133 23133 23134 276 23135 23135 23136 2 23137 276 23138 76 23139 3971 23140 2829 23141 23141 23142 1851 23143 157 23144 2040 23145 2 23146 23146 23147 2 23148 154 23149 157 23150 23150 23151 23151 23152 23152 23153 23153 23154 23154 23155 5266 23156 23156 23157 157 23158 23158 23159 2 23160 276 23161 23161 23162 2 23163 276 23164 23164 23165 23165 23166 23166 23167 23167 23168 23168 23169 23169 23170 1851 23171 157 23172 23172 23173 23173 23174 23174 23175 23175 23176 276 23177 23177 23178 23178 23179 2 23180 417 23181 23181 23182 5298 23183 23183 23184 23184 23185 16711 23186 23186 23187 845 23188 22506 23189 11 23190 22508 23191 2 23192 417 23193 22511 23194 22512 23195 22513 23196 2727 23197 22515 23198 22516 23199 350 23200 350 23201 353 23202 2 23203 417 23204 22522 23205 569 23206 22524 23207 22525 23208 22526 23209 22527 23210 2 23211 417 23212 22530 23213 22531 23214 22532 23215 22533 23216 2804 23217 22535 23218 569 23219 22537 23220 2 23221 22539 23222 22540 23223 2 23224 3 23225 4 23226 2 23227 2 23228 2 23229 2 23230 11 23231 2 23232 2 23233 22551 23234 2 23235 22553 23236 22 23237 22555 23238 22556 23239 2 23240 11 23241 11 23242 22560 23243 22561 23244 22562 23245 22 23246 2 23247 2 23248 2 23249 11 23250 22568 23251 11 23252 22570 23253 11 23254 22572 23255 22573 23256 22574 23257 22575 23258 60 23259 22577 23260 2 23261 2 23262 11 23263 2 23264 2 23265 68 23266 129 23267 22585 23268 2 23269 2 23270 22588 23271 2 23272 22590 23273 22591 23274 2 23275 84 23276 85 23277 88 23278 132 23279 11 23280 22598 23281 22599 23282 98 23283 22601 23284 22602 23285 22603 23286 103 23287 103 23288 22606 23289 22607 23290 22608 23291 22609 23292 22610 23293 22611 23294 22612 23295 22613 23296 22614 23297 22615 23298 98 23299 2 23300 22618 23301 2 23302 2 23303 2 23304 2 23305 2 23306 2 23307 2 23308 2 23309 300 23310 2 23311 2 23312 2 23313 2 23314 2 23315 306 23316 2 23317 2 23318 2 23319 2 23320 2 23321 2 23322 2 23323 2 23324 2 23325 2 23326 2 23327 2 23328 2 23329 2 23330 2 23331 22649 23332 22650 23333 22651 23334 22652 23335 22653 23336 22654 23337 22655 23338 22656 23339 22657 23340 22658 23341 22659 23342 22660 23343 22661 23344 22662 23345 22663 23346 4 23347 2 23348 22666 23349 22667 23350 22668 23351 22669 23352 22670 23353 22671 23354 22672 23355 22673 23356 22674 23357 22675 23358 22676 23359 350 23360 350 23361 40 23362 353 23363 2 23364 417 23365 22683 23366 569 23367 22685 23368 22686 23369 22687 23370 22688 23371 22689 23372 2 23373 417 23374 22692 23375 22693 23376 40 23377 22695 23378 276 23379 22697 23380 22698 23381 2 23382 417 23383 22701 23384 22702 23385 22703 23386 22704 23387 22705 23388 22706 23389 2 23390 728 23391 2 23392 22710 23393 22711 23394 22712 23395 22713 23396 22714 23397 22715 23398 22716 23399 22717 23400 22718 23401 22719 23402 845 23403 22721 23404 22722 23405 22723 23406 22724 23407 22725 23408 22726 23409 22727 23410 22728 23411 22729 23412 22730 23413 22731 23414 22732 23415 22733 23416 22734 23417 22735 23418 22736 23419 22737 23420 22738 23421 22739 23422 22740 23423 22741 23424 22742 23425 22743 23426 22744 23427 22745 23428 22746 23429 22747 23430 22748 23431 22749 23432 22750 23433 22751 23434 22752 23435 22753 23436 22754 23437 22755 23438 22756 23439 22757 23440 22758 23441 22759 23442 22760 23443 22761 23444 22762 23445 22763 23446 22764 23447 22765 23448 22766 23449 22767 23450 22768 23451 22769 23452 22770 23453 22771 23454 22772 23455 22773 23456 22774 23457 22775 23458 22776 23459 22777 23460 22778 23461 22779 23462 22780 23463 22781 23464 22782 23465 22783 23466 22784 23467 22785 23468 22786 23469 22787 23470 22788 23471 22789 23472 22790 23473 22791 23474 22792 23475 22793 23476 22794 23477 22795 23478 22796 23479 22797 23480 22798 23481 22799 23482 11 23483 22801 23484 22802 23485 22803 23486 2 23487 417 23488 22806 23489 932 23490 22808 23491 22809 23492 965 23493 154 23494 157 23495 22813 23496 22814 23497 1476 23498 2 23499 2 23500 2 23501 22819 23502 2 23503 22821 23504 2 23505 2 23506 2 23507 2 23508 2 23509 2 23510 2 23511 2 23512 2 23513 22831 23514 22832 23515 22833 23516 22834 23517 22835 23518 22836 23519 22837 23520 22838 23521 22839 23522 22840 23523 22841 23524 22842 23525 22843 23526 22 23527 22845 23528 4 23529 11 23530 22848 23531 88 23532 11 23533 22851 23534 98 23535 22853 23536 1538 23537 22855 23538 22856 23539 22857 23540 98 23541 845 23542 11 23543 22861 23544 932 23545 22863 23546 22864 23547 965 23548 154 23549 157 23550 22868 23551 22869 23552 22870 23553 845 23554 11 23555 22873 23556 22874 23557 22875 23558 350 23559 350 23560 353 23561 2 23562 417 23563 22881 23564 569 23565 22883 23566 22884 23567 22885 23568 22886 23569 2 23570 417 23571 22889 23572 22890 23573 22891 23574 22892 23575 22893 23576 22894 23577 2 23578 417 23579 22897 23580 22898 23581 138 23582 11 23583 140 23584 157 23585 158 23586 160 23587 162 23588 76 23589 124 23590 165 23591 22909 23592 22910 23593 138 23594 11 23595 140 23596 157 23597 2240 23598 2242 23599 2243 23600 2244 23601 2 23602 22920 23603 22921 23604 2 23605 22923 23606 845 23607 22925 23608 11 23609 22927 23610 2 23611 417 23612 22930 23613 22931 23614 22932 23615 2727 23616 22934 23617 22935 23618 350 23619 350 23620 353 23621 2 23622 417 23623 22941 23624 569 23625 22943 23626 22944 23627 22945 23628 22946 23629 2 23630 417 23631 22949 23632 22950 23633 22951 23634 22952 23635 2804 23636 22954 23637 569 23638 22956 23639 2 23640 22958 23641 22959 23642 22603 23643 2 23644 22962 23645 22963 23646 22964 23647 22965 23648 22966 23649 2898 23650 22968 23651 68 23652 22970 23653 22971 23654 22972 23655 22973 23656 22974 23657 22975 23658 22976 23659 22983 23660 2942 23661 2944 23662 22987 23663 932 23664 23004 23665 23005 23666 23006 23667 965 23668 154 23669 157 23670 23010 23671 23011 23672 23014 23673 2981 23674 2984 23675 2986 23676 2988 23677 76 23678 2990 23679 2991 23680 23022 23681 2 23682 276 23683 76 23684 3971 23685 2829 23686 23030 23687 1851 23688 157 23689 2040 23690 2 23691 23035 23692 2 23693 154 23694 157 23695 23039 23696 23040 23697 23041 23698 23042 23699 23043 23700 5266 23701 23045 23702 157 23703 23047 23704 2 23705 276 23706 23050 23707 2 23708 276 23709 23053 23710 23054 23711 23055 23712 23056 23713 23057 23714 23058 23715 1851 23716 157 23717 23061 23718 23062 23719 23063 23720 23064 23721 276 23722 23066 23723 23067 23724 2 23725 417 23726 23070 23727 5298 23728 23072 23729 23073 23730 23074 23731 23075 23732 23076 23733 23077 23734 2898 23735 23079 23736 68 23737 23081 23738 23082 23739 23083 23740 23084 23741 23085 23742 23086 23743 23087 23744 23094 23745 2942 23746 2944 23747 23098 23748 932 23749 23115 23750 23116 23751 23117 23752 965 23753 154 23754 157 23755 23121 23756 23122 23757 23125 23758 2981 23759 2984 23760 2986 23761 2988 23762 76 23763 2990 23764 2991 23765 23133 23766 2 23767 276 23768 76 23769 3971 23770 2829 23771 23141 23772 1851 23773 157 23774 2040 23775 2 23776 23146 23777 2 23778 154 23779 157 23780 23150 23781 23151 23782 23152 23783 23153 23784 23154 23785 5266 23786 23156 23787 157 23788 23158 23789 2 23790 276 23791 23161 23792 2 23793 276 23794 23164 23795 23165 23796 23166 23797 23167 23798 23168 23799 23169 23800 1851 23801 157 23802 23172 23803 23173 23804 23174 23805 23175 23806 276 23807 23177 23808 23178 23809 2 23810 417 23811 23181 23812 5298 23813 23183 23814 23184 23815 16704 23816 6185 23817 23817 23818 23818 23819 3060 23820 23820 23821 6185 23822 23822 23823 6185 23824 23824 23825 3060 23826 23826 23827 2 23828 17945 23829 19324 23830 19335 23831 16374 23832 19324 23833 157 23834 16374 23835 19386 23836 23836 23837 23837 23838 19389 23839 6185 23840 23840 23841 23841 23842 19549 23843 6185 23844 19549 23845 6185 23846 19557 23847 157 23848 16374 23849 19564 23850 23850 23851 23851 23852 19567 23853 6185 23854 23854 23855 3060 23856 23856 23857 19770 23858 11 23859 2 23860 276 23861 6185 23862 23862 23863 16 23864 19918 23865 16374 23866 19922 23867 23867 23868 23868 23869 19925 23870 6185 23871 23871 23872 6185 23873 23873 23874 6185 23875 23875 23876 23876 23877 16264 23878 138 23879 11 23880 140 23881 157 23882 160 23883 162 23884 76 23885 124 23886 165 23887 23887 23888 23888 23889 23889 23890 16 23891 2984 23892 2986 23893 2988 23894 76 23895 2990 23896 2991 23897 23897 23898 23898 23899 1054 23900 6185 23901 23901 23902 16296 23903 16297 23904 6185 23905 23905 23906 2 23907 276 23908 16374 23909 16375 23910 23910 23911 23911 23912 16378 23913 6185 23914 23914 23915 22 23916 154 23917 157 23918 6185 23919 23919 23920 124 23921 165 23922 23922 23923 23923 23924 11 23925 76 23926 23926 23927 124 23928 165 23929 23929 23930 13 23931 16550 23932 157 23933 76 23934 124 23935 165 23936 23936 23937 2988 23938 76 23939 2990 23940 2991 23941 23941 23942 2 23943 276 23944 16563 23945 16564 23946 23946 23947 16566 23948 16567 23949 16568 23950 23950 23951 16568 23952 23952 23953 16703 23954 16704 23955 6185 23956 23956 23957 16704 23958 6185 23959 23959 23960 23960 23961 3060 23962 23962 23963 6185 23964 23964 23965 20208 23966 2988 23967 76 23968 2990 23969 2991 23970 23970 23971 2 23972 276 23973 16374 23974 23974 23975 157 23976 6185 23977 23977 23978 6185 23979 23979 23980 3060 23981 23981 23982 2 23983 17945 23984 19324 23985 19335 23986 16374 23987 19324 23988 157 23989 16374 23990 19386 23991 23991 23992 23992 23993 19389 23994 6185 23995 23995 23996 23996 23997 19549 23998 6185 23999 19549 24000 6185 24001 19557 24002 157 24003 16374 24004 19564 24005 24005 24006 24006 24007 19567 24008 6185 24009 24009 24010 20257 24011 2986 24012 2988 24013 76 24014 2990 24015 2991 24016 24016 24017 3060 24018 24018 24019 19770 24020 11 24021 2 24022 276 24023 6185 24024 24024 24025 16 24026 19918 24027 16374 24028 19922 24029 24029 24030 24030 24031 19925 24032 6185 24033 24033 24034 6185 24035 24035 24036 2984 24037 2986 24038 2988 24039 76 24040 2990 24041 2991 24042 24042 24043 6185 24044 24044 24045 21806 24046 16574 24047 24047 24048 16568 24049 24049 24050 16703 24051 16704 24052 6185 24053 24053 24054 16704 24055 6185 24056 24056 24057 24057 24058 3060 24059 24059 24060 6185 24061 24061 24062 6185 24063 24063 24064 3060 24065 24065 24066 2 24067 17945 24068 19324 24069 19335 24070 16374 24071 19324 24072 157 24073 16374 24074 19386 24075 24075 24076 24076 24077 19389 24078 6185 24079 24079 24080 24080 24081 19549 24082 6185 24083 19549 24084 6185 24085 19557 24086 157 24087 16374 24088 19564 24089 24089 24090 24090 24091 19567 24092 6185 24093 24093 24094 3060 24095 24095 24096 19770 24097 11 24098 2 24099 276 24100 6185 24101 24101 24102 16 24103 19918 24104 16374 24105 19922 24106 24106 24107 24107 24108 19925 24109 6185 24110 24110 24111 6185 24112 24112 24113 6185 24114 24114 24115 24115 24116 16264 24117 138 24118 11 24119 140 24120 157 24121 160 24122 162 24123 76 24124 124 24125 165 24126 24126 24127 24127 24128 24128 24129 16 24130 2984 24131 2986 24132 2988 24133 76 24134 2990 24135 2991 24136 24136 24137 24137 24138 1054 24139 6185 24140 24140 24141 16296 24142 16297 24143 6185 24144 24144 24145 2 24146 276 24147 16374 24148 16375 24149 24149 24150 24150 24151 16378 24152 6185 24153 24153 24154 22 24155 154 24156 157 24157 6185 24158 24158 24159 124 24160 165 24161 24161 24162 24162 24163 11 24164 76 24165 24165 24166 124 24167 165 24168 24168 24169 13 24170 16550 24171 157 24172 76 24173 124 24174 165 24175 24175 24176 2988 24177 76 24178 2990 24179 2991 24180 24180 24181 2 24182 276 24183 16563 24184 16564 24185 24185 24186 16566 24187 16567 24188 16568 24189 24189 24190 16568 24191 24191 24192 16703 24193 16704 24194 6185 24195 24195 24196 16704 24197 6185 24198 24198 24199 24199 24200 3060 24201 24201 24202 6185 24203 24203 24204 20208 24205 2988 24206 76 24207 2990 24208 2991 24209 24209 24210 2 24211 276 24212 16374 24213 24213 24214 157 24215 6185 24216 24216 24217 6185 24218 24218 24219 3060 24220 24220 24221 2 24222 17945 24223 19324 24224 19335 24225 16374 24226 19324 24227 157 24228 16374 24229 19386 24230 24230 24231 24231 24232 19389 24233 6185 24234 24234 24235 24235 24236 19549 24237 6185 24238 19549 24239 6185 24240 19557 24241 157 24242 16374 24243 19564 24244 24244 24245 24245 24246 19567 24247 6185 24248 24248 24249 20257 24250 2986 24251 2988 24252 76 24253 2990 24254 2991 24255 24255 24256 24256 24257 3060 24258 24258 24259 19770 24260 11 24261 2 24262 276 24263 6185 24264 24264 24265 16 24266 19918 24267 16374 24268 19922 24269 24269 24270 24270 24271 19925 24272 6185 24273 24273 24274 6185 24275 24275 24276 2984 24277 2986 24278 2988 24279 76 24280 2990 24281 2991 24282 24282 24283 6185 24284 24284 24285 22 24286 154 24287 157 24288 6185 24289 24289 24290 124 24291 165 24292 24292 24293 24293 24294 11 24295 76 24296 24296 24297 124 24298 165 24299 24299 24300 13 24301 16550 24302 157 24303 76 24304 124 24305 165 24306 24306 24307 2988 24308 76 24309 2990 24310 2991 24311 24311 24312 2 24313 276 24314 16563 24315 16564 24316 24316 24317 16566 24318 16567 24319 16568 24320 24320 24321 16568 24322 24322 24323 16703 24324 16704 24325 6185 24326 24326 24327 16704 24328 6185 24329 24329 24330 24330 24331 3060 24332 24332 24333 6185 24334 24334 24335 20208 24336 2988 24337 76 24338 2990 24339 2991 24340 24340 24341 157 24342 6185 24343 24343 24344 6185 24345 24345 24346 3060 24347 24347 24348 2 24349 17945 24350 19324 24351 19335 24352 16374 24353 19324 24354 157 24355 16374 24356 19386 24357 24357 24358 24358 24359 19389 24360 6185 24361 24361 24362 24362 24363 19549 24364 6185 24365 19549 24366 6185 24367 19557 24368 157 24369 16374 24370 19564 24371 24371 24372 24372 24373 19567 24374 6185 24375 24375 24376 20257 24377 2986 24378 2988 24379 76 24380 2990 24381 2991 24382 24382 24383 24383 24384 3060 24385 24385 24386 19770 24387 11 24388 2 24389 276 24390 6185 24391 24391 24392 16 24393 19918 24394 16374 24395 19922 24396 24396 24397 24397 24398 19925 24399 6185 24400 24400 24401 6185 24402 24402 24403 2984 24404 2986 24405 2988 24406 76 24407 2990 24408 2991 24409 24409 24410 6185 24411 24411 24412 2 24413 276 24414 16374 24415 16375 24416 24416 24417 24417 24418 16378 24419 6185 24420 24420 24421 22 24422 154 24423 157 24424 6185 24425 24425 24426 124 24427 165 24428 24428 24429 24429 24430 11 24431 76 24432 24432 24433 124 24434 165 24435 24435 24436 13 24437 16550 24438 157 24439 76 24440 124 24441 165 24442 24442 24443 2988 24444 76 24445 2990 24446 2991 24447 24447 24448 2 24449 276 24450 16563 24451 16564 24452 24452 24453 16566 24454 16567 24455 16568 24456 24456 24457 16568 24458 24458 24459 16703 24460 16704 24461 6185 24462 24462 24463 16704 24464 6185 24465 24465 24466 24466 24467 3060 24468 24468 24469 6185 24470 24470 24471 20208 24472 2988 24473 76 24474 2990 24475 2991 24476 24476 24477 2 24478 276 24479 16374 24480 24480 24481 157 24482 6185 24483 24483 24484 6185 24485 24485 24486 3060 24487 24487 24488 2 24489 17945 24490 19324 24491 19335 24492 16374 24493 19324 24494 157 24495 16374 24496 19386 24497 24497 24498 24498 24499 19389 24500 6185 24501 24501 24502 24502 24503 19549 24504 6185 24505 19549 24506 6185 24507 19557 24508 157 24509 16374 24510 19564 24511 24511 24512 24512 24513 19567 24514 6185 24515 24515 24516 20257 24517 2986 24518 2988 24519 76 24520 2990 24521 2991 24522 24522 24523 3060 24524 24524 24525 19770 24526 11 24527 2 24528 276 24529 6185 24530 24530 24531 16 24532 19918 24533 16374 24534 19922 24535 24535 24536 24536 24537 19925 24538 6185 24539 24539 24540 6185 24541 24541 24542 2984 24543 2986 24544 2988 24545 76 24546 2990 24547 2991 24548 24548 24549 6185 24550 24550 24551 16296 24552 16297 24553 6185 24554 24554 24555 2 24556 276 24557 16374 24558 16375 24559 24559 24560 24560 24561 16378 24562 6185 24563 24563 24564 22 24565 154 24566 157 24567 6185 24568 24568 24569 124 24570 165 24571 24571 24572 24572 24573 11 24574 76 24575 24575 24576 124 24577 165 24578 24578 24579 13 24580 16550 24581 157 24582 76 24583 124 24584 165 24585 24585 24586 2 24587 276 24588 16563 24589 16564 24590 24590 24591 16566 24592 16567 24593 16568 24594 24594 24595 16568 24596 24596 24597 16703 24598 16704 24599 6185 24600 24600 24601 16704 24602 6185 24603 24603 24604 24604 24605 3060 24606 24606 24607 6185 24608 24608 24609 6185 24610 24610 24611 3060 24612 24612 24613 2 24614 17945 24615 19324 24616 19335 24617 16374 24618 19324 24619 157 24620 16374 24621 19386 24622 24622 24623 24623 24624 19389 24625 6185 24626 24626 24627 24627 24628 19549 24629 6185 24630 19549 24631 6185 24632 19557 24633 157 24634 16374 24635 19564 24636 24636 24637 24637 24638 19567 24639 6185 24640 24640 24641 3060 24642 24642 24643 19770 24644 11 24645 2 24646 276 24647 6185 24648 24648 24649 16 24650 19918 24651 16374 24652 19922 24653 24653 24654 24654 24655 19925 24656 6185 24657 24657 24658 6185 24659 24659 24660 6185 24661 24661 24662 845 24663 15492 24664 11 24665 15494 24666 2 24667 417 24668 15497 24669 15498 24670 15499 24671 2727 24672 15501 24673 15502 24674 350 24675 350 24676 353 24677 2 24678 417 24679 15508 24680 569 24681 15510 24682 15511 24683 15512 24684 15513 24685 2 24686 417 24687 15516 24688 15517 24689 15518 24690 15519 24691 2804 24692 15521 24693 569 24694 15523 24695 2 24696 15525 24697 15526 24698 2 24699 3 24700 4 24701 2 24702 2 24703 2 24704 2 24705 11 24706 2 24707 2 24708 15537 24709 2 24710 15539 24711 22 24712 15541 24713 15542 24714 2 24715 11 24716 11 24717 15546 24718 15547 24719 15548 24720 22 24721 2 24722 2 24723 2 24724 11 24725 15554 24726 11 24727 15556 24728 11 24729 15558 24730 15559 24731 15560 24732 15561 24733 60 24734 15563 24735 2 24736 2 24737 11 24738 2 24739 2 24740 68 24741 129 24742 15571 24743 2 24744 2 24745 15574 24746 2 24747 15576 24748 15577 24749 2 24750 84 24751 85 24752 88 24753 132 24754 11 24755 15584 24756 15585 24757 98 24758 15587 24759 15588 24760 15589 24761 103 24762 103 24763 15592 24764 15593 24765 15594 24766 15595 24767 15596 24768 15597 24769 15598 24770 15599 24771 15600 24772 15601 24773 98 24774 2 24775 15604 24776 2 24777 2 24778 2 24779 2 24780 2 24781 2 24782 2 24783 2 24784 300 24785 2 24786 2 24787 2 24788 2 24789 2 24790 306 24791 2 24792 2 24793 2 24794 2 24795 2 24796 2 24797 2 24798 2 24799 2 24800 2 24801 2 24802 2 24803 2 24804 2 24805 2 24806 15635 24807 15636 24808 15637 24809 15638 24810 15639 24811 15640 24812 15641 24813 15642 24814 15643 24815 15644 24816 15645 24817 15646 24818 15647 24819 15648 24820 15649 24821 4 24822 2 24823 15652 24824 15653 24825 15654 24826 15655 24827 15656 24828 15657 24829 15658 24830 15659 24831 15660 24832 15661 24833 15662 24834 350 24835 350 24836 40 24837 353 24838 2 24839 417 24840 15669 24841 569 24842 15671 24843 15672 24844 15673 24845 15674 24846 15675 24847 2 24848 417 24849 15678 24850 15679 24851 40 24852 15681 24853 276 24854 15683 24855 15684 24856 2 24857 417 24858 15687 24859 15688 24860 15689 24861 15690 24862 15691 24863 15692 24864 2 24865 728 24866 2 24867 15696 24868 15697 24869 15698 24870 15699 24871 15700 24872 15701 24873 15702 24874 15703 24875 15704 24876 15705 24877 845 24878 15707 24879 15708 24880 15709 24881 15710 24882 15711 24883 15712 24884 15713 24885 15714 24886 15715 24887 15716 24888 15717 24889 15718 24890 15719 24891 15720 24892 15721 24893 15722 24894 15723 24895 15724 24896 15725 24897 15726 24898 15727 24899 15728 24900 15729 24901 15730 24902 15731 24903 15732 24904 15733 24905 15734 24906 15735 24907 15736 24908 15737 24909 15738 24910 15739 24911 15740 24912 15741 24913 15742 24914 15743 24915 15744 24916 15745 24917 15746 24918 15747 24919 15748 24920 15749 24921 15750 24922 15751 24923 15752 24924 15753 24925 15754 24926 15755 24927 15756 24928 15757 24929 15758 24930 15759 24931 15760 24932 15761 24933 15762 24934 15763 24935 15764 24936 15765 24937 15766 24938 15767 24939 15768 24940 15769 24941 15770 24942 15771 24943 15772 24944 15773 24945 15774 24946 15775 24947 15776 24948 15777 24949 15778 24950 15779 24951 15780 24952 15781 24953 15782 24954 15783 24955 15784 24956 15785 24957 11 24958 15787 24959 15788 24960 15789 24961 2 24962 417 24963 15792 24964 932 24965 15794 24966 15795 24967 965 24968 154 24969 157 24970 15799 24971 15800 24972 1476 24973 2 24974 2 24975 2 24976 15805 24977 2 24978 15807 24979 2 24980 2 24981 2 24982 2 24983 2 24984 2 24985 2 24986 2 24987 2 24988 15817 24989 15818 24990 15819 24991 15820 24992 15821 24993 15822 24994 15823 24995 15824 24996 15825 24997 15826 24998 15827 24999 15828 25000 15829 25001 22 25002 15831 25003 4 25004 11 25005 15834 25006 88 25007 11 25008 15837 25009 98 25010 15839 25011 1538 25012 15841 25013 15842 25014 15843 25015 98 25016 845 25017 11 25018 15847 25019 932 25020 15849 25021 15850 25022 965 25023 154 25024 157 25025 15854 25026 15855 25027 15856 25028 845 25029 11 25030 15859 25031 15860 25032 15861 25033 350 25034 350 25035 353 25036 2 25037 417 25038 15867 25039 569 25040 15869 25041 15870 25042 15871 25043 15872 25044 2 25045 417 25046 15875 25047 15876 25048 15877 25049 15878 25050 15879 25051 15880 25052 2 25053 417 25054 15883 25055 15884 25056 138 25057 11 25058 140 25059 157 25060 158 25061 160 25062 162 25063 76 25064 124 25065 165 25066 15895 25067 15896 25068 138 25069 11 25070 140 25071 157 25072 2240 25073 2242 25074 2243 25075 2244 25076 2 25077 15906 25078 15907 25079 2 25080 15909 25081 845 25082 15911 25083 11 25084 15913 25085 2 25086 417 25087 15916 25088 15917 25089 15918 25090 2727 25091 15920 25092 15921 25093 350 25094 350 25095 353 25096 2 25097 417 25098 15927 25099 569 25100 15929 25101 15930 25102 15931 25103 15932 25104 2 25105 417 25106 15935 25107 15936 25108 15937 25109 15938 25110 2804 25111 15940 25112 569 25113 15942 25114 2 25115 15944 25116 15945 25117 15589 25118 2 25119 15948 25120 15949 25121 15950 25122 15951 25123 15952 25124 2898 25125 15954 25126 68 25127 15956 25128 15957 25129 15958 25130 15959 25131 15960 25132 15961 25133 15962 25134 15969 25135 2942 25136 2944 25137 15973 25138 932 25139 15990 25140 15991 25141 15992 25142 965 25143 154 25144 157 25145 15996 25146 15997 25147 16000 25148 2981 25149 2984 25150 2986 25151 2988 25152 76 25153 2990 25154 2991 25155 16008 25156 2 25157 276 25158 76 25159 3971 25160 2829 25161 16016 25162 1851 25163 157 25164 2040 25165 2 25166 16021 25167 2 25168 154 25169 157 25170 16025 25171 16026 25172 16027 25173 16028 25174 16029 25175 5266 25176 16031 25177 157 25178 16033 25179 2 25180 276 25181 16036 25182 2 25183 276 25184 16039 25185 16040 25186 16041 25187 16042 25188 16043 25189 16044 25190 1851 25191 157 25192 16047 25193 16048 25194 16049 25195 16050 25196 276 25197 16052 25198 16053 25199 2 25200 417 25201 16056 25202 5298 25203 16058 25204 16059 25205 16060 25206 16061 25207 16062 25208 16063 25209 2898 25210 16065 25211 68 25212 16067 25213 16068 25214 16069 25215 16070 25216 16071 25217 16072 25218 16073 25219 16080 25220 2942 25221 2944 25222 16084 25223 932 25224 16101 25225 16102 25226 16103 25227 965 25228 154 25229 157 25230 16107 25231 16108 25232 16111 25233 2981 25234 2984 25235 2986 25236 2988 25237 76 25238 2990 25239 2991 25240 16119 25241 2 25242 276 25243 76 25244 3971 25245 2829 25246 16127 25247 1851 25248 157 25249 2040 25250 2 25251 16132 25252 2 25253 154 25254 157 25255 16136 25256 16137 25257 16138 25258 16139 25259 16140 25260 5266 25261 16142 25262 157 25263 16144 25264 2 25265 276 25266 16147 25267 2 25268 276 25269 16150 25270 16151 25271 16152 25272 16153 25273 16154 25274 16155 25275 1851 25276 157 25277 16158 25278 16159 25279 16160 25280 16161 25281 276 25282 16163 25283 16164 25284 2 25285 417 25286 16167 25287 5298 25288 16169 25289 16170 25290 25290 25291 16264 25292 138 25293 11 25294 140 25295 157 25296 160 25297 162 25298 76 25299 124 25300 165 25301 25301 25302 25302 25303 25303 25304 16 25305 2984 25306 2986 25307 2988 25308 76 25309 2990 25310 2991 25311 25311 25312 25312 25313 1054 25314 6185 25315 25315 25316 16296 25317 16297 25318 6185 25319 25319 25320 2 25321 276 25322 16374 25323 16375 25324 25324 25325 25325 25326 16378 25327 6185 25328 25328 25329 22 25330 154 25331 157 25332 6185 25333 25333 25334 124 25335 165 25336 25336 25337 25337 25338 11 25339 76 25340 25340 25341 124 25342 165 25343 25343 25344 13 25345 16550 25346 157 25347 76 25348 124 25349 165 25350 25350 25351 2988 25352 76 25353 2990 25354 2991 25355 25355 25356 2 25357 276 25358 16563 25359 16564 25360 25360 25361 16566 25362 16567 25363 16568 25364 25364 25365 16568 25366 25366 25367 16703 25368 16704 25369 6185 25370 25370 25371 16704 25372 6185 25373 25373 25374 25374 25375 3060 25376 25376 25377 6185 25378 25378 25379 20208 25380 2988 25381 76 25382 2990 25383 2991 25384 25384 25385 2 25386 276 25387 16374 25388 25388 25389 157 25390 6185 25391 25391 25392 6185 25393 25393 25394 3060 25395 25395 25396 2 25397 17945 25398 19324 25399 19335 25400 16374 25401 19324 25402 157 25403 16374 25404 19386 25405 25405 25406 25406 25407 19389 25408 6185 25409 25409 25410 25410 25411 19549 25412 6185 25413 19549 25414 6185 25415 19557 25416 157 25417 16374 25418 19564 25419 25419 25420 25420 25421 19567 25422 6185 25423 25423 25424 20257 25425 2986 25426 2988 25427 76 25428 2990 25429 2991 25430 25430 25431 3060 25432 25432 25433 19770 25434 11 25435 2 25436 276 25437 6185 25438 25438 25439 16 25440 19918 25441 16374 25442 19922 25443 25443 25444 25444 25445 19925 25446 6185 25447 25447 25448 6185 25449 25449 25450 2984 25451 2986 25452 2988 25453 76 25454 2990 25455 2991 25456 25456 25457 6185 25458 25458 25459 2248 25460 25460 25461 25461 25462 25462 25463 25463 25464 25464 25465 25465 25466 25466 25467 25467 25468 25468 25469 25469 25470 25470 25471 25471 25472 25472 25473 2263 25474 2264 25475 2248 25476 25476 25477 25477 25478 25478 25479 25479 25480 25480 25481 25481 25482 25482 25483 25483 25484 25484 25485 25485 25486 25486 25487 2284 25488 25488 25489 2264 25490 25490 25491 2248 25492 25492 25493 25493 25494 25494 25495 25495 25496 25496 25497 25497 25498 25498 25499 25499 25500 25500 25501 25501 25502 2248 25503 25503 25504 25504 25505 25505 25506 25506 25507 25507 25508 25508 25509 25509 25510 25510 25511 25511 25512 25512 25513 25513 25514 25514 25515 25515 25516 25516 25517 25517 25518 3024 25519 25519 25520 154 25521 25521 25522 157 25523 25523 25524 25524 25525 25525 25526 3014 25527 25527 25528 25528 25529 25529 25530 25530 25531 25531 25532 25532 25533 25533 25534 25534 25535 25535 25536 25536 25537 25537 25538 25538 25539 2263 25540 3029 25541 3014 25542 25542 25543 25543 25544 25544 25545 25545 25546 25546 25547 25547 25548 25548 25549 25549 25550 25550 25551 2284 25552 25552 25553 3029 25554 25554 25555 3014 25556 25556 25557 25557 25558 25558 25559 25559 25560 25560 25561 25561 25562 25562 25563 25563 25564 25564 25565 25565 25566 25566 25567 3024 25568 25568 25569 25569 25570 2 25571 25571 25572 3014 25573 25573 25574 25574 25575 25575 25576 25576 25577 25577 25578 25578 25579 25579 25580 25580 25581 25581 25582 25582 25583 25583 25584 25584 25585 25585 25586 25586 25587 25587 25588 6572 25589 569 25590 25590 25591 932 25592 25592 25593 25593 25594 965 25595 154 25596 157 25597 25597 25598 25598 25599 6572 25600 569 25601 25601 25602 165 25603 25603 25604 845 25605 25605 25606 25606 25607 25607 25608 25608 25609 25609 25610 25610 25611 25611 25612 25612 25613 25613 25614 25614 25615 25615 25616 25616 25617 25617 25618 25618 25619 25619 25620 25620 25621 25621 25622 25622 25623 25623 25624 25624 25625 25625 25626 25626 25627 25627 25628 25628 25629 25629 25630 25630 25631 25631 25632 25632 25633 25633 25634 25634 25635 25635 25636 25636 25637 25637 25638 25638 25639 25639 25640 25640 25641 25641 25642 25642 25643 25643 25644 25644 25645 25645 25646 25646 25647 25647 25648 25648 25649 25649 25650 25650 25651 25651 25652 25652 25653 25653 25654 25654 25655 25655 25656 25656 25657 25657 25658 25658 25659 25659 25660 25660 25661 25661 25662 25662 25663 25663 25664 25664 25665 25665 25666 25666 25667 25667 25668 25668 25669 25669 25670 25670 25671 25671 25672 25672 25673 25673 25674 25674 25675 25675 25676 25676 25677 25677 25678 25678 25679 25679 25680 25680 25681 25681 25682 25682 25683 25683 25684 11 25685 25685 25686 25686 25687 25687 25688 2 25689 417 25690 25690 25691 25691 25692 1476 25693 2 25694 2 25695 2 25696 25696 25697 2 25698 25698 25699 2 25700 2 25701 2 25702 2 25703 2 25704 2 25705 2 25706 2 25707 2 25708 25708 25709 25709 25710 25710 25711 25711 25712 25712 25713 25713 25714 25714 25715 25715 25716 25716 25717 25717 25718 25718 25719 25719 25720 25720 25721 22 25722 25722 25723 4 25724 11 25725 25725 25726 88 25727 11 25728 25728 25729 98 25730 25730 25731 1538 25732 25732 25733 25733 25734 25734 25735 98 25736 845 25737 11 25738 25738 25739 932 25740 25740 25741 25741 25742 965 25743 154 25744 157 25745 25745 25746 25746 25747 25747 25748 845 25749 11 25750 25750 25751 25751 25752 25752 25753 350 25754 350 25755 353 25756 2 25757 417 25758 25758 25759 569 25760 25760 25761 25761 25762 25762 25763 25763 25764 2 25765 417 25766 25766 25767 25767 25768 25768 25769 25769 25770 25770 25771 25771 25772 2 25773 417 25774 25774 25775 25775 25776 26 25777 11 25778 2 25779 276 25780 26 25781 25781 25782 15 25783 15 25784 11 25785 26 25786 2 25787 11 25788 11 25789 40 25790 16 25791 25791 25792 15 25793 69 25794 70 25795 11 25796 76 25797 11 25798 11 25799 25799 25800 87 25801 102 25802 25802 25803 109 25804 25804 25805 124 25806 165 25807 25807 25808 26 25809 25809 25810 25810 25811 1054 25812 6185 25813 25813 25814 16296 25815 16297 25816 6185 25817 25817 25818 2 25819 276 25820 16374 25821 16375 25822 25822 25823 25823 25824 16378 25825 6185 25826 25826 25827 22 25828 154 25829 157 25830 6185 25831 25831 25832 124 25833 165 25834 25834 25835 25835 25836 11 25837 76 25838 25838 25839 124 25840 165 25841 25841 25842 13 25843 16550 25844 157 25845 76 25846 124 25847 165 25848 25848 25849 2 25850 276 25851 16563 25852 16564 25853 25853 25854 16566 25855 16567 25856 16568 25857 25857 25858 16568 25859 25859 25860 16703 25861 16704 25862 6185 25863 25863 25864 16704 25865 6185 25866 25866 25867 25867 25868 3060 25869 25869 25870 6185 25871 25871 25872 6185 25873 25873 25874 3060 25875 25875 25876 2 25877 17945 25878 19324 25879 19335 25880 16374 25881 19324 25882 157 25883 16374 25884 19386 25885 25885 25886 25886 25887 19389 25888 6185 25889 25889 25890 25890 25891 19549 25892 6185 25893 19549 25894 6185 25895 19557 25896 157 25897 16374 25898 19564 25899 25899 25900 25900 25901 19567 25902 6185 25903 25903 25904 3060 25905 25905 25906 19770 25907 11 25908 2 25909 276 25910 6185 25911 25911 25912 16 25913 19918 25914 16374 25915 19922 25916 25916 25917 25917 25918 19925 25919 6185 25920 25920 25921 6185 25922 25922 25923 6185 25924 25924 25925 25925 25926 16264 25927 138 25928 11 25929 140 25930 157 25931 160 25932 162 25933 76 25934 124 25935 165 25936 25936 25937 25937 25938 138 25939 11 25940 140 25941 157 25942 2240 25943 2242 25944 2243 25945 2244 25946 2 25947 2 25948 3 25949 4 25950 2 25951 2 25952 2 25953 2 25954 11 25955 2 25956 2 25957 17 25958 2 25959 20 25960 22 25961 24 25962 25 25963 2 25964 11 25965 11 25966 32 25967 33 25968 39 25969 22 25970 2 25971 2 25972 2 25973 11 25974 51 25975 11 25976 53 25977 11 25978 55 25979 57 25980 58 25981 59 25982 60 25983 61 25984 2 25985 2 25986 11 25987 2 25988 2 25989 68 25990 129 25991 130 25992 2 25993 2 25994 75 25995 2 25996 80 25997 82 25998 2 25999 84 26000 85 26001 88 26002 132 26003 11 26004 93 26005 94 26006 98 26007 99 26008 100 26009 26009 26010 103 26011 103 26012 106 26013 110 26014 112 26015 113 26016 114 26017 115 26018 116 26019 117 26020 119 26021 122 26022 98 26023 2 26024 133 26025 2 26026 2 26027 2 26028 2 26029 2 26030 2 26031 2 26032 2 26033 300 26034 2 26035 2 26036 2 26037 2 26038 2 26039 306 26040 2 26041 2 26042 2 26043 2 26044 2 26045 2 26046 2 26047 2 26048 2 26049 2 26050 2 26051 2 26052 2 26053 2 26054 2 26055 6495 26056 6496 26057 6497 26058 6498 26059 6499 26060 6500 26061 6501 26062 6502 26063 6503 26064 6504 26065 6505 26066 6506 26067 6507 26068 6508 26069 6509 26070 4 26071 2 26072 6512 26073 6513 26074 6514 26075 6515 26076 6516 26077 6517 26078 6518 26079 6519 26080 6520 26081 6521 26082 6522 26083 350 26084 350 26085 40 26086 353 26087 2 26088 417 26089 6529 26090 569 26091 6531 26092 6532 26093 6533 26094 6534 26095 6535 26096 2 26097 417 26098 6538 26099 6539 26100 40 26101 6541 26102 276 26103 6543 26104 6544 26105 2 26106 417 26107 6547 26108 6548 26109 6549 26110 6550 26111 6551 26112 6552 26113 2 26114 728 26115 2 26116 6556 26117 6557 26118 6558 26119 6559 26120 6560 26121 6561 26122 6562 26123 6563 26124 6564 26125 6565 26126 845 26127 25605 26128 25606 26129 25607 26130 25608 26131 25609 26132 25610 26133 25611 26134 25612 26135 25613 26136 25614 26137 25615 26138 25616 26139 25617 26140 25618 26141 25619 26142 25620 26143 25621 26144 25622 26145 25623 26146 25624 26147 25625 26148 25626 26149 25627 26150 25628 26151 25629 26152 25630 26153 25631 26154 25632 26155 25633 26156 25634 26157 25635 26158 25636 26159 25637 26160 25638 26161 25639 26162 25640 26163 25641 26164 25642 26165 25643 26166 25644 26167 25645 26168 25646 26169 25647 26170 25648 26171 25649 26172 25650 26173 25651 26174 25652 26175 25653 26176 25654 26177 25655 26178 25656 26179 25657 26180 25658 26181 25659 26182 25660 26183 25661 26184 25662 26185 25663 26186 25664 26187 25665 26188 25666 26189 25667 26190 25668 26191 25669 26192 25670 26193 25671 26194 25672 26195 25673 26196 25674 26197 25675 26198 25676 26199 25677 26200 25678 26201 25679 26202 25680 26203 25681 26204 25682 26205 25683 26206 11 26207 25685 26208 25686 26209 25687 26210 2 26211 417 26212 25690 26213 932 26214 25691 26215 25593 26216 965 26217 154 26218 157 26219 25597 26220 25598 26221 1476 26222 2 26223 2 26224 2 26225 25696 26226 2 26227 25698 26228 2 26229 2 26230 2 26231 2 26232 2 26233 2 26234 2 26235 2 26236 2 26237 25708 26238 25709 26239 25710 26240 25711 26241 25712 26242 25713 26243 25714 26244 25715 26245 25716 26246 25717 26247 25718 26248 25719 26249 25720 26250 22 26251 25722 26252 4 26253 11 26254 25725 26255 88 26256 11 26257 25728 26258 98 26259 25730 26260 1538 26261 25732 26262 25733 26263 25734 26264 98 26265 845 26266 11 26267 25738 26268 932 26269 25740 26270 25741 26271 965 26272 154 26273 157 26274 25745 26275 25746 26276 25747 26277 845 26278 11 26279 25750 26280 25751 26281 25752 26282 350 26283 350 26284 353 26285 2 26286 417 26287 25758 26288 569 26289 25760 26290 25761 26291 25762 26292 25763 26293 2 26294 417 26295 25766 26296 25767 26297 25768 26298 25769 26299 25770 26300 25771 26301 2 26302 417 26303 25774 26304 25775 26305 138 26306 11 26307 140 26308 157 26309 158 26310 160 26311 162 26312 76 26313 124 26314 165 26315 207 26316 208 26317 138 26318 11 26319 140 26320 157 26321 2240 26322 2242 26323 2243 26324 2244 26325 2 26326 26009 26327 26327 26328 26327 26329 845 26330 26330 26331 11 26332 26332 26333 2 26334 417 26335 26335 26336 26336 26337 26337 26338 2727 26339 16291 26340 16292 26341 350 26342 350 26343 353 26344 2 26345 417 26346 26346 26347 569 26348 26348 26349 26349 26350 26350 26351 26351 26352 2 26353 417 26354 26354 26355 26355 26356 26356 26357 26357 26358 2804 26359 26359 26360 569 26361 26361 26362 2 26363 26363 26364 26364 26365 2 26366 3 26367 4 26368 2 26369 2 26370 2 26371 2 26372 11 26373 2 26374 2 26375 26375 26376 2 26377 26377 26378 22 26379 26379 26380 26380 26381 2 26382 11 26383 11 26384 26384 26385 26385 26386 26386 26387 22 26388 2 26389 2 26390 2 26391 11 26392 26392 26393 11 26394 26394 26395 11 26396 26396 26397 26397 26398 26398 26399 26399 26400 60 26401 26401 26402 2 26403 2 26404 11 26405 2 26406 2 26407 68 26408 129 26409 26409 26410 2 26411 2 26412 26412 26413 2 26414 26414 26415 26415 26416 2 26417 84 26418 85 26419 88 26420 132 26421 11 26422 26422 26423 26423 26424 98 26425 26425 26426 26426 26427 26427 26428 103 26429 103 26430 26430 26431 26431 26432 26432 26433 26433 26434 26434 26435 26435 26436 26436 26437 26437 26438 26438 26439 26439 26440 98 26441 2 26442 26442 26443 2 26444 2 26445 2 26446 2 26447 2 26448 2 26449 2 26450 2 26451 300 26452 2 26453 2 26454 2 26455 2 26456 2 26457 306 26458 2 26459 2 26460 2 26461 2 26462 2 26463 2 26464 2 26465 2 26466 2 26467 2 26468 2 26469 2 26470 2 26471 2 26472 2 26473 26473 26474 26474 26475 26475 26476 26476 26477 26477 26478 26478 26479 26479 26480 26480 26481 26481 26482 26482 26483 26483 26484 26484 26485 26485 26486 26486 26487 26487 26488 4 26489 2 26490 26490 26491 26491 26492 26492 26493 26493 26494 26494 26495 26495 26496 26496 26497 26497 26498 26498 26499 26499 26500 26500 26501 350 26502 350 26503 40 26504 353 26505 2 26506 417 26507 26507 26508 569 26509 26509 26510 26510 26511 26511 26512 26512 26513 26513 26514 2 26515 417 26516 26516 26517 26517 26518 40 26519 26519 26520 276 26521 26521 26522 26522 26523 2 26524 417 26525 26525 26526 26526 26527 26527 26528 26528 26529 26529 26530 26530 26531 2 26532 728 26533 2 26534 26534 26535 26535 26536 26536 26537 26537 26538 26538 26539 26539 26540 26540 26541 26541 26542 26542 26543 26543 26544 845 26545 26545 26546 26546 26547 26547 26548 26548 26549 26549 26550 26550 26551 26551 26552 26552 26553 26553 26554 26554 26555 26555 26556 26556 26557 26557 26558 26558 26559 26559 26560 26560 26561 26561 26562 26562 26563 26563 26564 26564 26565 26565 26566 26566 26567 26567 26568 26568 26569 26569 26570 26570 26571 26571 26572 26572 26573 26573 26574 26574 26575 26575 26576 26576 26577 26577 26578 26578 26579 26579 26580 26580 26581 26581 26582 26582 26583 26583 26584 26584 26585 26585 26586 26586 26587 26587 26588 26588 26589 26589 26590 26590 26591 26591 26592 26592 26593 26593 26594 26594 26595 26595 26596 26596 26597 26597 26598 26598 26599 26599 26600 26600 26601 26601 26602 26602 26603 26603 26604 26604 26605 26605 26606 26606 26607 26607 26608 26608 26609 26609 26610 26610 26611 26611 26612 26612 26613 26613 26614 26614 26615 26615 26616 26616 26617 26617 26618 26618 26619 26619 26620 26620 26621 26621 26622 26622 26623 26623 26624 11 26625 26625 26626 26626 26627 26627 26628 2 26629 417 26630 26630 26631 932 26632 26632 26633 26633 26634 965 26635 154 26636 157 26637 26637 26638 26638 26639 1476 26640 2 26641 2 26642 2 26643 26643 26644 2 26645 26645 26646 2 26647 2 26648 2 26649 2 26650 2 26651 2 26652 2 26653 2 26654 2 26655 26655 26656 26656 26657 26657 26658 26658 26659 26659 26660 26660 26661 26661 26662 26662 26663 26663 26664 26664 26665 26665 26666 26666 26667 26667 26668 22 26669 26669 26670 4 26671 11 26672 26672 26673 88 26674 11 26675 26675 26676 98 26677 26677 26678 1538 26679 26679 26680 26680 26681 26681 26682 98 26683 845 26684 11 26685 26685 26686 932 26687 26687 26688 26688 26689 965 26690 154 26691 157 26692 26692 26693 26693 26694 26694 26695 845 26696 11 26697 26697 26698 26698 26699 26699 26700 350 26701 350 26702 353 26703 2 26704 417 26705 26705 26706 569 26707 26707 26708 26708 26709 26709 26710 26710 26711 2 26712 417 26713 26713 26714 26714 26715 26715 26716 26716 26717 26717 26718 26718 26719 2 26720 417 26721 26721 26722 26722 26723 138 26724 11 26725 140 26726 157 26727 158 26728 160 26729 162 26730 76 26731 124 26732 165 26733 26733 26734 26734 26735 138 26736 11 26737 140 26738 157 26739 2240 26740 2242 26741 2243 26742 2244 26743 2 26744 26744 26745 26745 26746 2 26747 26747 26748 845 26749 26749 26750 11 26751 26751 26752 2 26753 417 26754 26754 26755 26755 26756 26756 26757 2727 26758 26758 26759 26759 26760 350 26761 350 26762 353 26763 2 26764 417 26765 26765 26766 569 26767 26767 26768 26768 26769 26769 26770 26770 26771 2 26772 417 26773 26773 26774 26774 26775 26775 26776 26776 26777 2804 26778 26778 26779 569 26780 26780 26781 2 26782 26782 26783 26783 26784 26427 26785 2 26786 26786 26787 26787 26788 26788 26789 26789 26790 26790 26791 2898 26792 26792 26793 68 26794 26794 26795 26795 26796 26796 26797 26797 26798 26798 26799 26799 26800 26800 26801 2 26802 26802 26803 26803 26804 26804 26805 26805 26806 26806 26807 26807 26808 2942 26809 2944 26810 26810 26811 26811 26812 26812 26813 26813 26814 26814 26815 350 26816 350 26817 40 26818 353 26819 2 26820 417 26821 26821 26822 569 26823 26823 26824 26824 26825 26825 26826 26826 26827 932 26828 26828 26829 26829 26830 26830 26831 965 26832 154 26833 157 26834 26834 26835 26835 26836 40 26837 26837 26838 26838 26839 2981 26840 2984 26841 2986 26842 2988 26843 76 26844 2990 26845 2991 26846 26846 26847 276 26848 26848 26849 2 26850 276 26851 76 26852 3971 26853 2829 26854 26854 26855 1851 26856 157 26857 2040 26858 2 26859 26859 26860 2 26861 154 26862 157 26863 26863 26864 26864 26865 26865 26866 26866 26867 26867 26868 5266 26869 26869 26870 157 26871 26871 26872 2 26873 276 26874 26874 26875 2 26876 276 26877 26877 26878 26878 26879 26879 26880 26880 26881 26881 26882 26882 26883 1851 26884 157 26885 26885 26886 26886 26887 26887 26888 26888 26889 276 26890 26890 26891 26891 26892 2 26893 417 26894 26894 26895 5298 26896 26896 26897 26897 26898 26898 26899 26899 26900 26900 26901 16849 26902 2898 26903 26903 26904 68 26905 26905 26906 26906 26907 26907 26908 26908 26909 25592 26910 26910 26911 26911 26912 2 26913 26913 26914 26914 26915 26915 26916 26916 26917 26917 26918 26918 26919 2942 26920 2944 26921 26921 26922 26922 26923 26923 26924 26924 26925 26925 26926 350 26927 350 26928 40 26929 353 26930 2 26931 417 26932 26932 26933 569 26934 26934 26935 26935 26936 26936 26937 26937 26938 932 26939 26939 26940 26940 26941 26941 26942 965 26943 154 26944 157 26945 26945 26946 26946 26947 40 26948 26948 26949 26949 26950 2981 26951 2984 26952 2986 26953 2988 26954 76 26955 2990 26956 2991 26957 26957 26958 276 26959 26959 26960 2 26961 276 26962 76 26963 3971 26964 2829 26965 26965 26966 1851 26967 157 26968 2040 26969 2 26970 26970 26971 2 26972 154 26973 157 26974 26974 26975 26975 26976 26976 26977 26977 26978 26978 26979 5266 26980 26980 26981 157 26982 26982 26983 2 26984 276 26985 26985 26986 2 26987 276 26988 26988 26989 26989 26990 26990 26991 26991 26992 26992 26993 26993 26994 1851 26995 157 26996 26996 26997 26997 26998 26998 26999 26999 27000 276 27001 27001 27002 27002 27003 2 27004 417 27005 27005 27006 5298 27007 27007 27008 27008 27009 27009 27010 845 27011 26330 27012 11 27013 26332 27014 2 27015 417 27016 26335 27017 26336 27018 16 27019 2984 27020 2986 27021 2988 27022 76 27023 2990 27024 2991 27025 27025 27026 26337 27027 16 27028 16 27029 16 27030 16 27031 27031 27032 27032 27033 97 27034 27034 27035 105 27036 27036 27037 27037 27038 27038 27039 16264 27040 138 27041 11 27042 140 27043 157 27044 160 27045 162 27046 76 27047 124 27048 165 27049 27049 27050 27050 27051 16 27052 2984 27053 2986 27054 2988 27055 76 27056 2990 27057 2991 27058 27058 27059 2988 27060 76 27061 2990 27062 2991 27063 27063 27064 20208 27065 2988 27066 76 27067 2990 27068 2991 27069 27069 27070 20257 27071 2986 27072 2988 27073 76 27074 2990 27075 2991 27076 27076 27077 2984 27078 2986 27079 2988 27080 76 27081 2990 27082 2991 27083 27083 27084 350 27085 350 27086 353 27087 2 27088 417 27089 26346 27090 569 27091 26348 27092 26349 27093 26350 27094 26351 27095 2 27096 417 27097 26354 27098 26355 27099 26356 27100 26357 27101 1054 27102 6185 27103 27103 27104 16296 27105 16297 27106 6185 27107 27107 27108 2804 27109 26359 27110 569 27111 26361 27112 2 27113 26363 27114 26364 27115 2 27116 3 27117 4 27118 2 27119 2 27120 2 27121 2 27122 11 27123 2 27124 2 27125 26375 27126 2 27127 26377 27128 22 27129 26379 27130 26380 27131 2 27132 11 27133 11 27134 26384 27135 26385 27136 26386 27137 22 27138 2 27139 2 27140 2 27141 11 27142 26392 27143 11 27144 26394 27145 11 27146 26396 27147 26397 27148 26398 27149 26399 27150 60 27151 26401 27152 2 27153 2 27154 11 27155 2 27156 2 27157 68 27158 129 27159 26409 27160 2 27161 2 27162 26412 27163 2 27164 26414 27165 26415 27166 2 27167 84 27168 85 27169 88 27170 132 27171 11 27172 26422 27173 26423 27174 98 27175 26425 27176 26426 27177 26427 27178 103 27179 103 27180 26430 27181 26431 27182 26432 27183 26433 27184 26434 27185 26435 27186 26436 27187 26437 27188 26438 27189 26439 27190 98 27191 2 27192 26442 27193 2 27194 2 27195 2 27196 2 27197 2 27198 2 27199 2 27200 2 27201 300 27202 2 27203 2 27204 2 27205 2 27206 2 27207 306 27208 2 27209 2 27210 2 27211 2 27212 2 27213 2 27214 2 27215 2 27216 2 27217 2 27218 2 27219 2 27220 2 27221 2 27222 2 27223 26473 27224 26474 27225 26475 27226 26476 27227 26477 27228 26478 27229 26479 27230 26480 27231 26481 27232 26482 27233 26483 27234 26484 27235 26485 27236 26486 27237 26487 27238 4 27239 2 27240 26490 27241 26491 27242 26492 27243 26493 27244 26494 27245 26495 27246 26496 27247 26497 27248 26498 27249 26499 27250 26500 27251 350 27252 350 27253 40 27254 353 27255 2 27256 417 27257 26507 27258 569 27259 26509 27260 26510 27261 26511 27262 26512 27263 26513 27264 2 27265 417 27266 26516 27267 26517 27268 40 27269 26519 27270 276 27271 26521 27272 26522 27273 2 27274 417 27275 26525 27276 26526 27277 26527 27278 26528 27279 26529 27280 26530 27281 2 27282 728 27283 2 27284 26534 27285 26535 27286 26536 27287 26537 27288 26538 27289 26539 27290 26540 27291 26541 27292 26542 27293 26543 27294 845 27295 26545 27296 26546 27297 26547 27298 26548 27299 26549 27300 26550 27301 26551 27302 26552 27303 26553 27304 26554 27305 26555 27306 26556 27307 26557 27308 26558 27309 26559 27310 26560 27311 26561 27312 26562 27313 26563 27314 26564 27315 26565 27316 26566 27317 26567 27318 26568 27319 26569 27320 26570 27321 26571 27322 26572 27323 26573 27324 26574 27325 26575 27326 26576 27327 26577 27328 26578 27329 26579 27330 26580 27331 26581 27332 26582 27333 26583 27334 26584 27335 26585 27336 26586 27337 26587 27338 26588 27339 26589 27340 26590 27341 26591 27342 26592 27343 26593 27344 26594 27345 26595 27346 26596 27347 26597 27348 26598 27349 26599 27350 26600 27351 26601 27352 26602 27353 26603 27354 26604 27355 26605 27356 26606 27357 26607 27358 26608 27359 26609 27360 26610 27361 26611 27362 26612 27363 26613 27364 26614 27365 26615 27366 26616 27367 26617 27368 26618 27369 26619 27370 26620 27371 26621 27372 26622 27373 26623 27374 11 27375 26625 27376 26626 27377 26627 27378 2 27379 417 27380 26630 27381 932 27382 26632 27383 26633 27384 965 27385 154 27386 157 27387 26637 27388 26638 27389 1476 27390 2 27391 2 27392 2 27393 26643 27394 2 27395 26645 27396 2 27397 2 27398 2 27399 2 27400 2 27401 2 27402 2 27403 2 27404 2 27405 26655 27406 26656 27407 26657 27408 26658 27409 26659 27410 26660 27411 26661 27412 26662 27413 26663 27414 26664 27415 26665 27416 26666 27417 26667 27418 22 27419 26669 27420 4 27421 11 27422 26672 27423 88 27424 11 27425 26675 27426 98 27427 26677 27428 1538 27429 26679 27430 26680 27431 26681 27432 98 27433 845 27434 11 27435 26685 27436 932 27437 26687 27438 26688 27439 965 27440 154 27441 157 27442 26692 27443 26693 27444 26694 27445 845 27446 11 27447 26697 27448 26698 27449 26699 27450 350 27451 350 27452 353 27453 2 27454 417 27455 26705 27456 569 27457 26707 27458 26708 27459 26709 27460 26710 27461 2 27462 417 27463 26713 27464 26714 27465 26715 27466 26716 27467 26717 27468 26718 27469 2 27470 417 27471 26721 27472 26722 27473 138 27474 11 27475 140 27476 157 27477 158 27478 160 27479 162 27480 76 27481 124 27482 165 27483 26733 27484 26734 27485 138 27486 11 27487 140 27488 157 27489 2240 27490 2242 27491 2243 27492 2244 27493 2 27494 26744 27495 26745 27496 2 27497 26747 27498 845 27499 26749 27500 11 27501 26751 27502 2 27503 417 27504 26754 27505 26755 27506 26756 27507 2727 27508 26758 27509 26759 27510 350 27511 350 27512 353 27513 2 27514 417 27515 26765 27516 569 27517 26767 27518 26768 27519 26769 27520 26770 27521 2 27522 417 27523 26773 27524 26774 27525 26775 27526 26776 27527 2804 27528 26778 27529 569 27530 26780 27531 2 27532 26782 27533 26783 27534 26427 27535 2 27536 26786 27537 26787 27538 26788 27539 26789 27540 26790 27541 2898 27542 26792 27543 68 27544 26794 27545 26795 27546 26796 27547 26797 27548 26798 27549 26799 27550 26800 27551 26807 27552 2942 27553 2944 27554 26811 27555 932 27556 26828 27557 26829 27558 26830 27559 965 27560 154 27561 157 27562 26834 27563 26835 27564 26838 27565 2981 27566 2984 27567 2986 27568 2988 27569 76 27570 2990 27571 2991 27572 26846 27573 2 27574 276 27575 76 27576 3971 27577 2829 27578 26854 27579 1851 27580 157 27581 2040 27582 2 27583 26859 27584 2 27585 154 27586 157 27587 26863 27588 26864 27589 26865 27590 26866 27591 26867 27592 5266 27593 26869 27594 157 27595 26871 27596 2 27597 276 27598 26874 27599 2 27600 276 27601 26877 27602 26878 27603 26879 27604 26880 27605 26881 27606 26882 27607 1851 27608 157 27609 26885 27610 26886 27611 26887 27612 26888 27613 276 27614 26890 27615 26891 27616 2 27617 417 27618 26894 27619 5298 27620 26896 27621 26897 27622 2 27623 276 27624 16374 27625 16375 27626 27626 27627 27627 27628 16378 27629 6185 27630 27630 27631 27631 27632 27632 27633 27633 27634 27634 27635 27635 27636 27636 27637 6185 27638 27638 27639 27639 27640 3060 27641 27641 27642 6185 27643 27636 27644 3060 27645 27641 27646 27646 27647 27647 27648 27648 27649 27649 27650 27650 27651 27651 27652 27652 27653 16 27654 27654 27655 76 27656 27656 27657 27657 27658 27658 27659 27659 27660 27660 27661 4047 27662 27662 27663 2829 27664 27664 27665 27665 27666 16 27667 27667 27668 27668 27669 27669 27670 27670 27671 76 27672 27672 27673 27673 27674 27674 27675 27675 27676 4047 27677 27677 27678 27656 27679 27679 27680 27680 27681 2829 27682 27682 27683 27683 27684 26898 27685 22 27686 154 27687 157 27688 6185 27689 27689 27690 124 27691 165 27692 27692 27693 27693 27694 11 27695 76 27696 27696 27697 124 27698 165 27699 27699 27700 13 27701 16550 27702 157 27703 76 27704 124 27705 165 27706 27706 27707 2988 27708 76 27709 2990 27710 2991 27711 27711 27712 26899 27713 2 27714 276 27715 16563 27716 16564 27717 27717 27718 16566 27719 16567 27720 16568 27721 27721 27722 16568 27723 27723 27724 16703 27725 16704 27726 6185 27727 27727 27728 16704 27729 6185 27730 27730 27731 26900 27732 27732 27733 3060 27734 27734 27735 2898 27736 26903 27737 68 27738 26905 27739 26906 27740 6185 27741 27741 27742 26907 27743 26908 27744 26910 27745 26911 27746 26918 27747 2942 27748 2944 27749 26922 27750 932 27751 26939 27752 26940 27753 26941 27754 965 27755 154 27756 157 27757 26945 27758 26946 27759 26949 27760 2981 27761 2984 27762 2986 27763 2988 27764 76 27765 2990 27766 2991 27767 26957 27768 27768 27769 27769 27770 27770 27771 27771 27772 27772 27773 27773 27774 27774 27775 27775 27776 27776 27777 27777 27778 27778 27779 27779 27780 27780 27781 27781 27782 27782 27783 27783 27784 27784 27785 27785 27786 27786 27787 27787 27788 27788 27789 27789 27790 27790 27791 27791 27792 27792 27793 27793 27794 27794 27795 27795 27796 27796 27797 27797 27798 27798 27799 27799 27800 27800 27801 27801 27802 27802 27803 27803 27804 27804 27805 27805 27806 27806 27807 27807 27808 27808 27809 27809 27810 27810 27811 27811 27812 27812 27813 27813 27814 27814 27815 27815 27816 27816 27817 27817 27818 27818 27819 27819 27820 27820 27821 27821 27822 27822 27823 27823 27824 27824 27825 27825 27826 27826 27827 27827 27828 27828 27829 27829 27830 27830 27831 27831 27832 27832 27833 27833 27834 27834 27835 27835 27836 27836 27837 27837 27838 27838 27839 27839 27840 27840 27841 27841 27842 27842 27843 27843 27844 27844 27845 27845 27846 27846 27847 27847 27848 5871 27849 27849 27850 27850 27851 27851 27852 27852 27853 27853 27854 15 27855 16 27856 16 27857 15 27858 11 27859 26 27860 2 27861 16 27862 11 27863 11 27864 40 27865 16 27866 11 27867 11 27868 27868 27869 16 27870 56 27871 15 27872 69 27873 70 27874 11 27875 16 27876 76 27877 11 27878 79 27879 11 27880 27880 27881 87 27882 27882 27883 91 27884 27884 27885 97 27886 27886 27887 102 27888 105 27889 27889 27890 27890 27891 27891 27892 27892 27893 27893 27894 27894 27895 27895 27896 124 27897 27897 27898 165 27899 27899 27900 26 27901 11 27902 2 27903 276 27904 26 27905 27905 27906 15 27907 15 27908 11 27909 26 27910 2 27911 11 27912 11 27913 40 27914 16 27915 27915 27916 15 27917 69 27918 70 27919 11 27920 76 27921 11 27922 11 27923 27923 27924 87 27925 102 27926 27926 27927 27891 27928 27928 27929 124 27930 165 27931 27931 27932 26 27933 27933 27934 27934 27935 1054 27936 6185 27937 27937 27938 16296 27939 16297 27940 6185 27941 27941 27942 2 27943 276 27944 16374 27945 16375 27946 27946 27947 27947 27948 16378 27949 6185 27950 27950 27951 22 27952 154 27953 157 27954 6185 27955 27955 27956 124 27957 165 27958 27958 27959 27959 27960 11 27961 76 27962 27962 27963 124 27964 165 27965 27965 27966 13 27967 16550 27968 157 27969 76 27970 124 27971 165 27972 27972 27973 2 27974 276 27975 16563 27976 16564 27977 27977 27978 16566 27979 16567 27980 16568 27981 27981 27982 16568 27983 27983 27984 16703 27985 16704 27986 6185 27987 27987 27988 16704 27989 6185 27990 27990 27991 27991 27992 3060 27993 27993 27994 6185 27995 27995 27996 6185 27997 27997 27998 3060 27999 27999 28000 2 28001 17945 28002 19324 28003 19335 28004 16374 28005 19324 28006 157 28007 16374 28008 19386 28009 28009 28010 28010 28011 19389 28012 6185 28013 28013 28014 28014 28015 19549 28016 6185 28017 19549 28018 6185 28019 19557 28020 157 28021 16374 28022 19564 28023 28023 28024 28024 28025 19567 28026 6185 28027 28027 28028 3060 28029 28029 28030 19770 28031 11 28032 2 28033 276 28034 6185 28035 28035 28036 16 28037 19918 28038 16374 28039 19922 28040 28040 28041 28041 28042 19925 28043 6185 28044 28044 28045 6185 28046 28046 28047 6185 28048 28048 28049 28049 28050 16264 28051 138 28052 11 28053 140 28054 157 28055 160 28056 162 28057 76 28058 124 28059 165 28060 28060 28061 28061 28062 28062 28063 16 28064 2984 28065 2986 28066 2988 28067 76 28068 2990 28069 2991 28070 28070 28071 28071 28072 1054 28073 6185 28074 28074 28075 16296 28076 16297 28077 6185 28078 28078 28079 2 28080 276 28081 16374 28082 16375 28083 28083 28084 28084 28085 16378 28086 6185 28087 28087 28088 6185 28089 3060 28090 27641 28091 6185 28092 3060 28093 28093 28094 28094 28095 28095 28096 28096 28097 22 28098 154 28099 157 28100 6185 28101 28101 28102 124 28103 165 28104 28104 28105 28105 28106 11 28107 76 28108 28108 28109 124 28110 165 28111 28111 28112 13 28113 16550 28114 157 28115 76 28116 124 28117 165 28118 28118 28119 2988 28120 76 28121 2990 28122 2991 28123 28123 28124 2 28125 276 28126 16563 28127 16564 28128 28128 28129 16566 28130 16567 28131 16568 28132 28132 28133 16568 28134 28134 28135 16703 28136 16704 28137 6185 28138 28138 28139 16704 28140 6185 28141 28141 28142 28142 28143 3060 28144 28144 28145 6185 28146 28146 28147 5871 28148 27851 28149 27852 28150 28150 28151 28151 28152 27851 28153 27852 28154 28154 28155 20208 28156 2988 28157 76 28158 2990 28159 2991 28160 28160 28161 2 28162 276 28163 16374 28164 28164 28165 157 28166 6185 28167 28167 28168 6185 28169 28169 28170 3060 28171 28171 28172 2 28173 17945 28174 19324 28175 19335 28176 16374 28177 19324 28178 157 28179 16374 28180 19386 28181 28181 28182 28182 28183 19389 28184 6185 28185 28185 28186 28186 28187 19549 28188 6185 28189 19549 28190 6185 28191 19557 28192 157 28193 16374 28194 19564 28195 28195 28196 28196 28197 19567 28198 6185 28199 28199 28200 20257 28201 2986 28202 2988 28203 76 28204 2990 28205 2991 28206 28206 28207 3060 28208 28208 28209 19770 28210 11 28211 2 28212 276 28213 6185 28214 28214 28215 16 28216 19918 28217 16374 28218 19922 28219 28219 28220 28220 28221 19925 28222 6185 28223 28223 28224 6185 28225 28225 28226 2040 28227 28227 28228 3060 28229 16 28230 28230 28231 28231 28232 2 28233 3128 28234 28234 28235 2984 28236 2986 28237 2988 28238 76 28239 2990 28240 2991 28241 28241 28242 6185 28243 28243 28244 28244 28245 27851 28246 27852 28247 28247 28248 2 28249 276 28250 76 28251 3971 28252 2829 28253 26965 28254 1851 28255 157 28256 2040 28257 2 28258 26970 28259 2 28260 154 28261 157 28262 26974 28263 26975 28264 20208 28265 2988 28266 76 28267 2990 28268 2991 28269 28269 28270 26976 28271 26977 28272 26978 28273 2 28274 276 28275 16374 28276 28276 28277 15 28278 15 28279 11 28280 26 28281 2 28282 11 28283 11 28284 40 28285 16 28286 11 28287 28287 28288 15 28289 69 28290 70 28291 11 28292 76 28293 11 28294 11 28295 28295 28296 87 28297 102 28298 28298 28299 28299 28300 28300 28301 124 28302 165 28303 28303 28304 26 28305 11 28306 2 28307 276 28308 26 28309 28309 28310 28310 28311 28311 28312 1054 28313 6185 28314 28314 28315 16296 28316 16297 28317 6185 28318 28318 28319 2 28320 276 28321 16374 28322 16375 28323 28323 28324 28324 28325 16378 28326 6185 28327 28327 28328 22 28329 154 28330 157 28331 6185 28332 28332 28333 124 28334 165 28335 28335 28336 28336 28337 11 28338 76 28339 28339 28340 124 28341 165 28342 28342 28343 13 28344 16550 28345 157 28346 76 28347 124 28348 165 28349 28349 28350 2 28351 276 28352 16563 28353 16564 28354 28354 28355 16566 28356 16567 28357 16568 28358 28358 28359 16568 28360 28360 28361 16703 28362 16704 28363 6185 28364 28364 28365 16704 28366 6185 28367 28367 28368 28368 28369 3060 28370 28370 28371 6185 28372 28372 28373 2 28374 276 28375 16374 28376 28376 28377 6185 28378 28378 28379 3060 28380 28380 28381 2 28382 17945 28383 19324 28384 19335 28385 16374 28386 19324 28387 157 28388 16374 28389 19386 28390 28390 28391 28391 28392 19389 28393 6185 28394 28394 28395 28395 28396 19549 28397 6185 28398 19549 28399 6185 28400 19557 28401 157 28402 16374 28403 19564 28404 28404 28405 28405 28406 19567 28407 6185 28408 28408 28409 3060 28410 28410 28411 19770 28412 11 28413 2 28414 276 28415 6185 28416 28416 28417 16 28418 19918 28419 16374 28420 19922 28421 28421 28422 28422 28423 19925 28424 6185 28425 28425 28426 6185 28427 28427 28428 6185 28429 28429 28430 157 28431 6185 28432 28432 28433 6185 28434 28434 28435 3060 28436 28436 28437 2 28438 17945 28439 19324 28440 19335 28441 16374 28442 19324 28443 157 28444 16374 28445 19386 28446 28446 28447 28447 28448 19389 28449 6185 28450 28450 28451 28451 28452 19549 28453 6185 28454 19549 28455 6185 28456 19557 28457 157 28458 16374 28459 19564 28460 28460 28461 28461 28462 19567 28463 6185 28464 28464 28465 5266 28466 26980 28467 157 28468 26982 28469 2 28470 276 28471 26985 28472 20257 28473 2986 28474 2988 28475 76 28476 2990 28477 2991 28478 28478 28479 2 28480 276 28481 26988 28482 3060 28483 28483 28484 26989 28485 19770 28486 11 28487 2 28488 276 28489 6185 28490 28490 28491 16 28492 19918 28493 16374 28494 19922 28495 28495 28496 28496 28497 19925 28498 6185 28499 28499 28500 26990 28501 6185 28502 28502 28503 3060 28504 28504 28505 26991 28506 2984 28507 2986 28508 2988 28509 76 28510 2990 28511 2991 28512 28512 28513 6185 28514 28514 28515 26992 28516 6572 28517 569 28518 28518 28519 26993 28520 1851 28521 157 28522 26996 28523 26997 28524 26998 28525 26999 28526 276 28527 27001 28528 27002 28529 2 28530 417 28531 27005 28532 5298 28533 27007 28534 27008))
  "The generated action-tables.")

(defvar
  phps-mode-parser--distinct-action-tables
  #s(hash-table size 12466 test equal rehash-size 1.5 rehash-threshold 0.8125 data (0 ((("!") reduce 84) (("\"") reduce 84) (($) reduce 84) (("$") reduce 84) (("(") reduce 84) (("+") reduce 84) (("-") reduce 84) ((";") reduce 84) (("@") reduce 84) ((T_ABSTRACT) reduce 84) ((T_ARRAY) reduce 84) ((T_ARRAY_CAST) reduce 84) ((T_ATTRIBUTE) reduce 84) ((T_BOOL_CAST) reduce 84) ((T_BREAK) reduce 84) ((T_CLASS) reduce 84) ((T_CLASS_C) reduce 84) ((T_CLONE) reduce 84) ((T_CONST) reduce 84) ((T_CONSTANT_ENCAPSED_STRING) reduce 84) ((T_CONTINUE) reduce 84) ((T_DEC) reduce 84) ((T_DECLARE) reduce 84) ((T_DIR) reduce 84) ((T_DNUMBER) reduce 84) ((T_DO) reduce 84) ((T_DOUBLE_CAST) reduce 84) ((T_ECHO) reduce 84) ((T_EMPTY) reduce 84) ((T_ENUM) reduce 84) ((T_EVAL) reduce 84) ((T_EXIT) reduce 84) ((T_FILE) reduce 84) ((T_FINAL) reduce 84) ((T_FN) reduce 84) ((T_FOR) reduce 84) ((T_FOREACH) reduce 84) ((T_FUNCTION) reduce 84) ((T_FUNC_C) reduce 84) ((T_GLOBAL) reduce 84) ((T_GOTO) reduce 84) ((T_HALT_COMPILER) reduce 84) ((T_IF) reduce 84) ((T_INC) reduce 84) ((T_INCLUDE) reduce 84) ((T_INCLUDE_ONCE) reduce 84) ((T_INLINE_HTML) reduce 84) ((T_INTERFACE) reduce 84) ((T_INT_CAST) reduce 84) ((T_ISSET) reduce 84) ((T_LINE) reduce 84) ((T_LIST) reduce 84) ((T_LNUMBER) reduce 84) ((T_MATCH) reduce 84) ((T_METHOD_C) reduce 84) ((T_NAMESPACE) reduce 84) ((T_NAME_FULLY_QUALIFIED) reduce 84) ((T_NAME_QUALIFIED) reduce 84) ((T_NAME_RELATIVE) reduce 84) ((T_NEW) reduce 84) ((T_NS_C) reduce 84) ((T_OBJECT_CAST) reduce 84) ((T_PRINT) reduce 84) ((T_READONLY) reduce 84) ((T_REQUIRE) reduce 84) ((T_REQUIRE_ONCE) reduce 84) ((T_RETURN) reduce 84) ((T_START_HEREDOC) reduce 84) ((T_STATIC) reduce 84) ((T_STRING) reduce 84) ((T_STRING_CAST) reduce 84) ((T_SWITCH) reduce 84) ((T_THROW) reduce 84) ((T_TRAIT) reduce 84) ((T_TRAIT_C) reduce 84) ((T_TRY) reduce 84) ((T_UNSET) reduce 84) ((T_UNSET_CAST) reduce 84) ((T_USE) reduce 84) ((T_VARIABLE) reduce 84) ((T_WHILE) reduce 84) ((T_YIELD) reduce 84) ((T_YIELD_FROM) reduce 84) (("[") reduce 84) (("`") reduce 84) (("{") reduce 84) (("~") reduce 84)) 1 ((("!") shift) (("\"") shift) (($) accept) (("$") shift) (("(") shift) (("+") shift) (("-") shift) ((";") shift) (("@") shift) ((T_ABSTRACT) shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_BREAK) shift) ((T_CLASS) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONST) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_CONTINUE) shift) ((T_DEC) shift) ((T_DECLARE) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DO) shift) ((T_DOUBLE_CAST) shift) ((T_ECHO) shift) ((T_EMPTY) shift) ((T_ENUM) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FINAL) shift) ((T_FN) shift) ((T_FOR) shift) ((T_FOREACH) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_GLOBAL) shift) ((T_GOTO) shift) ((T_HALT_COMPILER) shift) ((T_IF) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INLINE_HTML) shift) ((T_INTERFACE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAMESPACE) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_RETURN) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_SWITCH) shift) ((T_THROW) shift) ((T_TRAIT) shift) ((T_TRAIT_C) shift) ((T_TRY) shift) ((T_UNSET) shift) ((T_UNSET_CAST) shift) ((T_USE) shift) ((T_VARIABLE) shift) ((T_WHILE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("{") shift) (("~") shift)) 2 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) (("+") shift) (("-") shift) (("@") shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("~") shift)) 3 (((T_CURLY_OPEN) shift) ((T_DOLLAR_OPEN_CURLY_BRACES) shift) ((T_ENCAPSED_AND_WHITESPACE) shift) ((T_VARIABLE) shift)) 4 ((("$") shift) ((T_VARIABLE) shift) (("{") shift)) 8 ((("!") reduce 164) (("\"") reduce 164) (($) reduce 164) (("$") reduce 164) (("(") reduce 164) (("+") reduce 164) (("-") reduce 164) ((";") reduce 164) (("@") reduce 164) ((T_ABSTRACT) reduce 164) ((T_ARRAY) reduce 164) ((T_ARRAY_CAST) reduce 164) ((T_ATTRIBUTE) reduce 164) ((T_BOOL_CAST) reduce 164) ((T_BREAK) reduce 164) ((T_CLASS) reduce 164) ((T_CLASS_C) reduce 164) ((T_CLONE) reduce 164) ((T_CONST) reduce 164) ((T_CONSTANT_ENCAPSED_STRING) reduce 164) ((T_CONTINUE) reduce 164) ((T_DEC) reduce 164) ((T_DECLARE) reduce 164) ((T_DIR) reduce 164) ((T_DNUMBER) reduce 164) ((T_DO) reduce 164) ((T_DOUBLE_CAST) reduce 164) ((T_ECHO) reduce 164) ((T_EMPTY) reduce 164) ((T_ENUM) reduce 164) ((T_EVAL) reduce 164) ((T_EXIT) reduce 164) ((T_FILE) reduce 164) ((T_FINAL) reduce 164) ((T_FN) reduce 164) ((T_FOR) reduce 164) ((T_FOREACH) reduce 164) ((T_FUNCTION) reduce 164) ((T_FUNC_C) reduce 164) ((T_GLOBAL) reduce 164) ((T_GOTO) reduce 164) ((T_HALT_COMPILER) reduce 164) ((T_IF) reduce 164) ((T_INC) reduce 164) ((T_INCLUDE) reduce 164) ((T_INCLUDE_ONCE) reduce 164) ((T_INLINE_HTML) reduce 164) ((T_INTERFACE) reduce 164) ((T_INT_CAST) reduce 164) ((T_ISSET) reduce 164) ((T_LINE) reduce 164) ((T_LIST) reduce 164) ((T_LNUMBER) reduce 164) ((T_MATCH) reduce 164) ((T_METHOD_C) reduce 164) ((T_NAMESPACE) reduce 164) ((T_NAME_FULLY_QUALIFIED) reduce 164) ((T_NAME_QUALIFIED) reduce 164) ((T_NAME_RELATIVE) reduce 164) ((T_NEW) reduce 164) ((T_NS_C) reduce 164) ((T_OBJECT_CAST) reduce 164) ((T_PRINT) reduce 164) ((T_READONLY) reduce 164) ((T_REQUIRE) reduce 164) ((T_REQUIRE_ONCE) reduce 164) ((T_RETURN) reduce 164) ((T_START_HEREDOC) reduce 164) ((T_STATIC) reduce 164) ((T_STRING) reduce 164) ((T_STRING_CAST) reduce 164) ((T_SWITCH) reduce 164) ((T_THROW) reduce 164) ((T_TRAIT) reduce 164) ((T_TRAIT_C) reduce 164) ((T_TRY) reduce 164) ((T_UNSET) reduce 164) ((T_UNSET_CAST) reduce 164) ((T_USE) reduce 164) ((T_VARIABLE) reduce 164) ((T_WHILE) reduce 164) ((T_YIELD) reduce 164) ((T_YIELD_FROM) reduce 164) (("[") reduce 164) (("`") reduce 164) (("{") reduce 164) (("~") reduce 164)) 10 (((T_ABSTRACT) reduce 194) ((T_CLASS) reduce 194) ((T_FINAL) reduce 194) ((T_READONLY) reduce 194)) 11 ((("(") shift)) 13 (((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_STATIC) shift) ((T_STRING) shift)) 15 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) (("+") shift) (("-") shift) ((";") reduce 507) (("@") shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("~") shift)) 16 (((T_STRING) shift)) 17 ((("%") reduce 502) (("*") reduce 502) (("+") reduce 502) (("-") reduce 502) ((".") reduce 502) (("/") reduce 502) ((";") reduce 502) (("<") reduce 502) ((">") reduce 502) (("?") reduce 502) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_BOOLEAN_AND) reduce 502) ((T_BOOLEAN_OR) reduce 502) ((T_COALESCE) reduce 502) ((T_INSTANCEOF) reduce 502) ((T_IS_EQUAL) reduce 502) ((T_IS_GREATER_OR_EQUAL) reduce 502) ((T_IS_IDENTICAL) reduce 502) ((T_IS_NOT_EQUAL) reduce 502) ((T_IS_NOT_IDENTICAL) reduce 502) ((T_IS_SMALLER_OR_EQUAL) reduce 502) ((T_LOGICAL_AND) reduce 502) ((T_LOGICAL_OR) reduce 502) ((T_LOGICAL_XOR) reduce 502) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 502) ((T_OBJECT_OPERATOR) reduce 502) ((T_POW) reduce 502) ((T_SL) reduce 502) ((T_SPACESHIP) reduce 502) ((T_SR) reduce 502) (("[") reduce 502) (("^") reduce 502) (("{") reduce 502) (("|") reduce 502)) 20 ((("%") reduce 484) (("(") reduce 484) (("*") reduce 484) (("+") reduce 484) (("-") reduce 484) ((".") reduce 484) (("/") reduce 484) ((";") reduce 484) (("<") reduce 484) ((">") reduce 484) (("?") reduce 484) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_BOOLEAN_AND) reduce 484) ((T_BOOLEAN_OR) reduce 484) ((T_COALESCE) reduce 484) ((T_INSTANCEOF) reduce 484) ((T_IS_EQUAL) reduce 484) ((T_IS_GREATER_OR_EQUAL) reduce 484) ((T_IS_IDENTICAL) reduce 484) ((T_IS_NOT_EQUAL) reduce 484) ((T_IS_NOT_IDENTICAL) reduce 484) ((T_IS_SMALLER_OR_EQUAL) reduce 484) ((T_LOGICAL_AND) reduce 484) ((T_LOGICAL_OR) reduce 484) ((T_LOGICAL_XOR) reduce 484) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 484) ((T_OBJECT_OPERATOR) reduce 484) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 484) ((T_POW) reduce 484) ((T_SL) reduce 484) ((T_SPACESHIP) reduce 484) ((T_SR) reduce 484) (("[") reduce 484) (("^") reduce 484) (("{") reduce 484) (("|") reduce 484)) 22 ((("\"") shift) (("$") shift) (("(") shift) ((T_ARRAY) shift) ((T_CLASS_C) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DIR) shift) ((T_FILE) shift) ((T_FUNC_C) shift) ((T_LINE) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NS_C) shift) ((T_READONLY) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_TRAIT_C) shift) ((T_VARIABLE) shift) (("[") shift)) 24 ((("%") reduce 497) (("*") reduce 497) (("+") reduce 497) (("-") reduce 497) ((".") reduce 497) (("/") reduce 497) ((";") reduce 497) (("<") reduce 497) ((">") reduce 497) (("?") reduce 497) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_BOOLEAN_AND) reduce 497) ((T_BOOLEAN_OR) reduce 497) ((T_COALESCE) reduce 497) ((T_INSTANCEOF) reduce 497) ((T_IS_EQUAL) reduce 497) ((T_IS_GREATER_OR_EQUAL) reduce 497) ((T_IS_IDENTICAL) reduce 497) ((T_IS_NOT_EQUAL) reduce 497) ((T_IS_NOT_IDENTICAL) reduce 497) ((T_IS_SMALLER_OR_EQUAL) reduce 497) ((T_LOGICAL_AND) reduce 497) ((T_LOGICAL_OR) reduce 497) ((T_LOGICAL_XOR) reduce 497) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 497) ((T_OBJECT_OPERATOR) reduce 497) ((T_POW) reduce 497) ((T_SL) reduce 497) ((T_SPACESHIP) reduce 497) ((T_SR) reduce 497) (("[") reduce 497) (("^") reduce 497) (("{") reduce 497) (("|") reduce 497)) 25 ((("%") reduce 487) (("*") reduce 487) (("+") reduce 487) (("-") reduce 487) ((".") reduce 487) (("/") reduce 487) ((";") reduce 487) (("<") reduce 487) ((">") reduce 487) (("?") reduce 487) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_BOOLEAN_AND) reduce 487) ((T_BOOLEAN_OR) reduce 487) ((T_COALESCE) reduce 487) ((T_INSTANCEOF) reduce 487) ((T_IS_EQUAL) reduce 487) ((T_IS_GREATER_OR_EQUAL) reduce 487) ((T_IS_IDENTICAL) reduce 487) ((T_IS_NOT_EQUAL) reduce 487) ((T_IS_NOT_IDENTICAL) reduce 487) ((T_IS_SMALLER_OR_EQUAL) reduce 487) ((T_LOGICAL_AND) reduce 487) ((T_LOGICAL_OR) reduce 487) ((T_LOGICAL_XOR) reduce 487) ((T_POW) reduce 487) ((T_SL) reduce 487) ((T_SPACESHIP) reduce 487) ((T_SR) reduce 487) (("^") reduce 487) (("|") reduce 487)) 26 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) (("+") shift) (("-") shift) ((";") shift) (("@") shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_BREAK) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_CONTINUE) shift) ((T_DEC) shift) ((T_DECLARE) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DO) shift) ((T_DOUBLE_CAST) shift) ((T_ECHO) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FOR) shift) ((T_FOREACH) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_GLOBAL) shift) ((T_GOTO) shift) ((T_IF) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INLINE_HTML) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_RETURN) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_SWITCH) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_TRY) shift) ((T_UNSET) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_WHILE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("{") shift) (("~") shift)) 32 ((("%") reduce 475) (("(") shift) (("*") reduce 475) (("+") reduce 475) (("-") reduce 475) ((".") reduce 475) (("/") reduce 475) ((";") reduce 475) (("<") reduce 475) ((">") reduce 475) (("?") reduce 475) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_BOOLEAN_AND) reduce 475) ((T_BOOLEAN_OR) reduce 475) ((T_COALESCE) reduce 475) ((T_INSTANCEOF) reduce 475) ((T_IS_EQUAL) reduce 475) ((T_IS_GREATER_OR_EQUAL) reduce 475) ((T_IS_IDENTICAL) reduce 475) ((T_IS_NOT_EQUAL) reduce 475) ((T_IS_NOT_IDENTICAL) reduce 475) ((T_IS_SMALLER_OR_EQUAL) reduce 475) ((T_LOGICAL_AND) reduce 475) ((T_LOGICAL_OR) reduce 475) ((T_LOGICAL_XOR) reduce 475) ((T_POW) reduce 475) ((T_SL) reduce 475) ((T_SPACESHIP) reduce 475) ((T_SR) reduce 475) (("^") reduce 475) (("|") reduce 475)) 33 ((("%") reduce 496) (("*") reduce 496) (("+") reduce 496) (("-") reduce 496) ((".") reduce 496) (("/") reduce 496) ((";") reduce 496) (("<") reduce 496) ((">") reduce 496) (("?") reduce 496) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_BOOLEAN_AND) reduce 496) ((T_BOOLEAN_OR) reduce 496) ((T_COALESCE) reduce 496) ((T_INSTANCEOF) reduce 496) ((T_IS_EQUAL) reduce 496) ((T_IS_GREATER_OR_EQUAL) reduce 496) ((T_IS_IDENTICAL) reduce 496) ((T_IS_NOT_EQUAL) reduce 496) ((T_IS_NOT_IDENTICAL) reduce 496) ((T_IS_SMALLER_OR_EQUAL) reduce 496) ((T_LOGICAL_AND) reduce 496) ((T_LOGICAL_OR) reduce 496) ((T_LOGICAL_XOR) reduce 496) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 496) ((T_OBJECT_OPERATOR) reduce 496) ((T_POW) reduce 496) ((T_SL) reduce 496) ((T_SPACESHIP) reduce 496) ((T_SR) reduce 496) (("[") reduce 496) (("^") reduce 496) (("{") reduce 496) (("|") reduce 496)) 34 (((T_ABSTRACT) reduce 195) ((T_CLASS) reduce 195) ((T_FINAL) reduce 195) ((T_READONLY) reduce 195)) 35 ((("(") reduce 452) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 452) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 452)) 38 ((("(") reduce 453) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 453) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 453) ((T_READONLY) reduce 453) ((T_STRING) reduce 453)) 39 ((("%") reduce 500) (("*") reduce 500) (("+") reduce 500) (("-") reduce 500) ((".") reduce 500) (("/") reduce 500) ((";") reduce 500) (("<") reduce 500) ((">") reduce 500) (("?") reduce 500) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_BOOLEAN_AND) reduce 500) ((T_BOOLEAN_OR) reduce 500) ((T_COALESCE) reduce 500) ((T_INSTANCEOF) reduce 500) ((T_IS_EQUAL) reduce 500) ((T_IS_GREATER_OR_EQUAL) reduce 500) ((T_IS_IDENTICAL) reduce 500) ((T_IS_NOT_EQUAL) reduce 500) ((T_IS_NOT_IDENTICAL) reduce 500) ((T_IS_SMALLER_OR_EQUAL) reduce 500) ((T_LOGICAL_AND) reduce 500) ((T_LOGICAL_OR) reduce 500) ((T_LOGICAL_XOR) reduce 500) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 500) ((T_OBJECT_OPERATOR) reduce 500) ((T_POW) reduce 500) ((T_SL) reduce 500) ((T_SPACESHIP) reduce 500) ((T_SR) reduce 500) (("[") reduce 500) (("^") reduce 500) (("{") reduce 500) (("|") reduce 500)) 40 ((("$") shift) ((T_VARIABLE) shift)) 47 ((("!") reduce 158) (("\"") reduce 158) (($) reduce 158) (("$") reduce 158) (("(") reduce 158) (("+") reduce 158) (("-") reduce 158) ((";") reduce 158) (("@") reduce 158) ((T_ABSTRACT) reduce 158) ((T_ARRAY) reduce 158) ((T_ARRAY_CAST) reduce 158) ((T_ATTRIBUTE) reduce 158) ((T_BOOL_CAST) reduce 158) ((T_BREAK) reduce 158) ((T_CLASS) reduce 158) ((T_CLASS_C) reduce 158) ((T_CLONE) reduce 158) ((T_CONST) reduce 158) ((T_CONSTANT_ENCAPSED_STRING) reduce 158) ((T_CONTINUE) reduce 158) ((T_DEC) reduce 158) ((T_DECLARE) reduce 158) ((T_DIR) reduce 158) ((T_DNUMBER) reduce 158) ((T_DO) reduce 158) ((T_DOUBLE_CAST) reduce 158) ((T_ECHO) reduce 158) ((T_EMPTY) reduce 158) ((T_ENUM) reduce 158) ((T_EVAL) reduce 158) ((T_EXIT) reduce 158) ((T_FILE) reduce 158) ((T_FINAL) reduce 158) ((T_FN) reduce 158) ((T_FOR) reduce 158) ((T_FOREACH) reduce 158) ((T_FUNCTION) reduce 158) ((T_FUNC_C) reduce 158) ((T_GLOBAL) reduce 158) ((T_GOTO) reduce 158) ((T_HALT_COMPILER) reduce 158) ((T_IF) reduce 158) ((T_INC) reduce 158) ((T_INCLUDE) reduce 158) ((T_INCLUDE_ONCE) reduce 158) ((T_INLINE_HTML) reduce 158) ((T_INTERFACE) reduce 158) ((T_INT_CAST) reduce 158) ((T_ISSET) reduce 158) ((T_LINE) reduce 158) ((T_LIST) reduce 158) ((T_LNUMBER) reduce 158) ((T_MATCH) reduce 158) ((T_METHOD_C) reduce 158) ((T_NAMESPACE) reduce 158) ((T_NAME_FULLY_QUALIFIED) reduce 158) ((T_NAME_QUALIFIED) reduce 158) ((T_NAME_RELATIVE) reduce 158) ((T_NEW) reduce 158) ((T_NS_C) reduce 158) ((T_OBJECT_CAST) reduce 158) ((T_PRINT) reduce 158) ((T_READONLY) reduce 158) ((T_REQUIRE) reduce 158) ((T_REQUIRE_ONCE) reduce 158) ((T_RETURN) reduce 158) ((T_START_HEREDOC) reduce 158) ((T_STATIC) reduce 158) ((T_STRING) reduce 158) ((T_STRING_CAST) reduce 158) ((T_SWITCH) reduce 158) ((T_THROW) reduce 158) ((T_TRAIT) reduce 158) ((T_TRAIT_C) reduce 158) ((T_TRY) reduce 158) ((T_UNSET) reduce 158) ((T_UNSET_CAST) reduce 158) ((T_USE) reduce 158) ((T_VARIABLE) reduce 158) ((T_WHILE) reduce 158) ((T_YIELD) reduce 158) ((T_YIELD_FROM) reduce 158) (("[") reduce 158) (("`") reduce 158) (("{") reduce 158) (("~") reduce 158)) 51 ((("%") reduce 495) (("*") reduce 495) (("+") reduce 495) (("-") reduce 495) ((".") reduce 495) (("/") reduce 495) ((";") reduce 495) (("<") reduce 495) ((">") reduce 495) (("?") reduce 495) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_BOOLEAN_AND) reduce 495) ((T_BOOLEAN_OR) reduce 495) ((T_COALESCE) reduce 495) ((T_INSTANCEOF) reduce 495) ((T_IS_EQUAL) reduce 495) ((T_IS_GREATER_OR_EQUAL) reduce 495) ((T_IS_IDENTICAL) reduce 495) ((T_IS_NOT_EQUAL) reduce 495) ((T_IS_NOT_IDENTICAL) reduce 495) ((T_IS_SMALLER_OR_EQUAL) reduce 495) ((T_LOGICAL_AND) reduce 495) ((T_LOGICAL_OR) reduce 495) ((T_LOGICAL_XOR) reduce 495) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 495) ((T_OBJECT_OPERATOR) reduce 495) ((T_POW) reduce 495) ((T_SL) reduce 495) ((T_SPACESHIP) reduce 495) ((T_SR) reduce 495) (("[") reduce 495) (("^") reduce 495) (("{") reduce 495) (("|") reduce 495)) 53 ((("%") reduce 486) (("*") reduce 486) (("+") reduce 486) (("-") reduce 486) ((".") reduce 486) (("/") reduce 486) ((";") reduce 486) (("<") reduce 486) ((">") reduce 486) (("?") reduce 486) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_BOOLEAN_AND) reduce 486) ((T_BOOLEAN_OR) reduce 486) ((T_COALESCE) reduce 486) ((T_INSTANCEOF) reduce 486) ((T_IS_EQUAL) reduce 486) ((T_IS_GREATER_OR_EQUAL) reduce 486) ((T_IS_IDENTICAL) reduce 486) ((T_IS_NOT_EQUAL) reduce 486) ((T_IS_NOT_IDENTICAL) reduce 486) ((T_IS_SMALLER_OR_EQUAL) reduce 486) ((T_LOGICAL_AND) reduce 486) ((T_LOGICAL_OR) reduce 486) ((T_LOGICAL_XOR) reduce 486) ((T_POW) reduce 486) ((T_SL) reduce 486) ((T_SPACESHIP) reduce 486) ((T_SR) reduce 486) (("^") reduce 486) (("|") reduce 486)) 55 ((("%") reduce 499) (("*") reduce 499) (("+") reduce 499) (("-") reduce 499) ((".") reduce 499) (("/") reduce 499) ((";") reduce 499) (("<") reduce 499) ((">") reduce 499) (("?") reduce 499) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_BOOLEAN_AND) reduce 499) ((T_BOOLEAN_OR) reduce 499) ((T_COALESCE) reduce 499) ((T_INSTANCEOF) reduce 499) ((T_IS_EQUAL) reduce 499) ((T_IS_GREATER_OR_EQUAL) reduce 499) ((T_IS_IDENTICAL) reduce 499) ((T_IS_NOT_EQUAL) reduce 499) ((T_IS_NOT_IDENTICAL) reduce 499) ((T_IS_SMALLER_OR_EQUAL) reduce 499) ((T_LOGICAL_AND) reduce 499) ((T_LOGICAL_OR) reduce 499) ((T_LOGICAL_XOR) reduce 499) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 499) ((T_OBJECT_OPERATOR) reduce 499) ((T_POW) reduce 499) ((T_SL) reduce 499) ((T_SPACESHIP) reduce 499) ((T_SR) reduce 499) (("[") reduce 499) (("^") reduce 499) (("{") reduce 499) (("|") reduce 499)) 56 (((T_ABSTRACT) shift) ((T_ARRAY) shift) ((T_AS) shift) ((T_BREAK) shift) ((T_CALLABLE) shift) ((T_CASE) shift) ((T_CATCH) shift) ((T_CLASS) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONST) shift) ((T_CONTINUE) shift) ((T_DECLARE) shift) ((T_DEFAULT) shift) ((T_DIR) shift) ((T_DO) shift) ((T_ECHO) shift) ((T_ELSE) shift) ((T_ELSEIF) shift) ((T_EMPTY) shift) ((T_ENDDECLARE) shift) ((T_ENDFOR) shift) ((T_ENDFOREACH) shift) ((T_ENDIF) shift) ((T_ENDSWITCH) shift) ((T_ENDWHILE) shift) ((T_ENUM) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_EXTENDS) shift) ((T_FILE) shift) ((T_FINAL) shift) ((T_FINALLY) shift) ((T_FN) shift) ((T_FOR) shift) ((T_FOREACH) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_GLOBAL) shift) ((T_GOTO) shift) ((T_IF) shift) ((T_IMPLEMENTS) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INSTANCEOF) shift) ((T_INSTEADOF) shift) ((T_INTERFACE) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAMESPACE) shift) ((T_NAME_QUALIFIED) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_PRINT) shift) ((T_PRIVATE) shift) ((T_PROTECTED) shift) ((T_PUBLIC) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_RETURN) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_SWITCH) shift) ((T_THROW) shift) ((T_TRAIT) shift) ((T_TRAIT_C) shift) ((T_TRY) shift) ((T_UNSET) shift) ((T_USE) shift) ((T_VAR) shift) ((T_WHILE) shift) ((T_YIELD) shift) (("{") shift)) 57 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) ((";") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 93) ((T_OBJECT_OPERATOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("[") reduce 93) (("^") reduce 93) (("{") reduce 93) (("|") reduce 93)) 58 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) ((";") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 92) ((T_OBJECT_OPERATOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("[") reduce 92) (("^") reduce 92) (("{") reduce 92) (("|") reduce 92)) 59 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) ((";") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 94) ((T_OBJECT_OPERATOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("[") reduce 94) (("^") reduce 94) (("{") reduce 94) (("|") reduce 94)) 60 ((("$") shift) (("(") shift) ((T_ABSTRACT) shift) ((T_ATTRIBUTE) shift) ((T_CLASS) reduce 192) ((T_FINAL) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_READONLY) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_VARIABLE) shift)) 61 ((("%") reduce 501) (("*") reduce 501) (("+") reduce 501) (("-") reduce 501) ((".") reduce 501) (("/") reduce 501) ((";") reduce 501) (("<") reduce 501) ((">") reduce 501) (("?") reduce 501) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_BOOLEAN_AND) reduce 501) ((T_BOOLEAN_OR) reduce 501) ((T_COALESCE) reduce 501) ((T_INSTANCEOF) reduce 501) ((T_IS_EQUAL) reduce 501) ((T_IS_GREATER_OR_EQUAL) reduce 501) ((T_IS_IDENTICAL) reduce 501) ((T_IS_NOT_EQUAL) reduce 501) ((T_IS_NOT_IDENTICAL) reduce 501) ((T_IS_SMALLER_OR_EQUAL) reduce 501) ((T_LOGICAL_AND) reduce 501) ((T_LOGICAL_OR) reduce 501) ((T_LOGICAL_XOR) reduce 501) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 501) ((T_OBJECT_OPERATOR) reduce 501) ((T_POW) reduce 501) ((T_SL) reduce 501) ((T_SPACESHIP) reduce 501) ((T_SR) reduce 501) (("[") reduce 501) (("^") reduce 501) (("{") reduce 501) (("|") reduce 501)) 64 ((("(") shift) ((T_ABSTRACT) reduce 196) ((T_CLASS) reduce 196) ((T_FINAL) reduce 196) ((T_READONLY) reduce 196)) 68 (((T_CURLY_OPEN) shift) ((T_DOLLAR_OPEN_CURLY_BRACES) shift) ((T_ENCAPSED_AND_WHITESPACE) shift) ((T_END_HEREDOC) shift) ((T_VARIABLE) shift)) 69 (((T_FN) shift) ((T_FUNCTION) shift) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_VARIABLE) shift)) 70 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) ((":") shift) ((";") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 91) ((T_OBJECT_OPERATOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("[") reduce 91) (("^") reduce 91) (("{") reduce 91) (("|") reduce 91)) 75 ((("%") reduce 498) (("*") reduce 498) (("+") reduce 498) (("-") reduce 498) ((".") reduce 498) (("/") reduce 498) ((";") reduce 498) (("<") reduce 498) ((">") reduce 498) (("?") reduce 498) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_BOOLEAN_AND) reduce 498) ((T_BOOLEAN_OR) reduce 498) ((T_COALESCE) reduce 498) ((T_INSTANCEOF) reduce 498) ((T_IS_EQUAL) reduce 498) ((T_IS_GREATER_OR_EQUAL) reduce 498) ((T_IS_IDENTICAL) reduce 498) ((T_IS_NOT_EQUAL) reduce 498) ((T_IS_NOT_IDENTICAL) reduce 498) ((T_IS_SMALLER_OR_EQUAL) reduce 498) ((T_LOGICAL_AND) reduce 498) ((T_LOGICAL_OR) reduce 498) ((T_LOGICAL_XOR) reduce 498) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 498) ((T_OBJECT_OPERATOR) reduce 498) ((T_POW) reduce 498) ((T_SL) reduce 498) ((T_SPACESHIP) reduce 498) ((T_SR) reduce 498) (("[") reduce 498) (("^") reduce 498) (("{") reduce 498) (("|") reduce 498)) 76 ((("{") shift)) 79 (((T_CONST) shift) ((T_FUNCTION) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_STRING) shift)) 80 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) ((";") reduce 529) (("<") reduce 529) (("=") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AND_EQUAL) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_COALESCE_EQUAL) reduce 529) ((T_CONCAT_EQUAL) reduce 529) ((T_DEC) reduce 529) ((T_DIV_EQUAL) reduce 529) ((T_INC) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_MINUS_EQUAL) reduce 529) ((T_MOD_EQUAL) reduce 529) ((T_MUL_EQUAL) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_OR_EQUAL) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_PLUS_EQUAL) reduce 529) ((T_POW) reduce 529) ((T_POW_EQUAL) reduce 529) ((T_SL) reduce 529) ((T_SL_EQUAL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) ((T_SR_EQUAL) reduce 529) ((T_XOR_EQUAL) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 82 ((("!") shift) (("\"") shift) (("$") shift) (("%") reduce 440) (("(") shift) (("*") reduce 440) (("+") shift) (("-") shift) ((".") reduce 440) (("/") reduce 440) ((";") reduce 440) (("<") reduce 440) ((">") reduce 440) (("?") reduce 440) (("@") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOLEAN_AND) reduce 440) ((T_BOOLEAN_OR) reduce 440) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_COALESCE) reduce 440) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INSTANCEOF) reduce 440) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_IS_EQUAL) reduce 440) ((T_IS_GREATER_OR_EQUAL) reduce 440) ((T_IS_IDENTICAL) reduce 440) ((T_IS_NOT_EQUAL) reduce 440) ((T_IS_NOT_IDENTICAL) reduce 440) ((T_IS_SMALLER_OR_EQUAL) reduce 440) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_LOGICAL_AND) reduce 440) ((T_LOGICAL_OR) reduce 440) ((T_LOGICAL_XOR) reduce 440) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_POW) reduce 440) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_SL) reduce 440) ((T_SPACESHIP) reduce 440) ((T_SR) reduce 440) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("^") reduce 440) (("`") shift) (("|") reduce 440) (("~") shift)) 84 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) (("+") shift) ((",") reduce 548) (("-") shift) (("@") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_CAST) shift) ((T_ELLIPSIS) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("]") reduce 548) (("`") shift) (("~") shift)) 85 (((T_CURLY_OPEN) shift) ((T_DOLLAR_OPEN_CURLY_BRACES) shift) ((T_ENCAPSED_AND_WHITESPACE) shift) ((T_VARIABLE) shift) (("`") reduce 477)) 86 ((("!") reduce 147) (("\"") reduce 147) (($) reduce 147) (("$") reduce 147) (("(") reduce 147) (("+") reduce 147) (("-") reduce 147) ((";") reduce 147) (("@") reduce 147) ((T_ABSTRACT) reduce 147) ((T_ARRAY) reduce 147) ((T_ARRAY_CAST) reduce 147) ((T_ATTRIBUTE) reduce 147) ((T_BOOL_CAST) reduce 147) ((T_BREAK) reduce 147) ((T_CLASS) reduce 147) ((T_CLASS_C) reduce 147) ((T_CLONE) reduce 147) ((T_CONST) reduce 147) ((T_CONSTANT_ENCAPSED_STRING) reduce 147) ((T_CONTINUE) reduce 147) ((T_DEC) reduce 147) ((T_DECLARE) reduce 147) ((T_DIR) reduce 147) ((T_DNUMBER) reduce 147) ((T_DO) reduce 147) ((T_DOUBLE_CAST) reduce 147) ((T_ECHO) reduce 147) ((T_EMPTY) reduce 147) ((T_ENUM) reduce 147) ((T_EVAL) reduce 147) ((T_EXIT) reduce 147) ((T_FILE) reduce 147) ((T_FINAL) reduce 147) ((T_FN) reduce 147) ((T_FOR) reduce 147) ((T_FOREACH) reduce 147) ((T_FUNCTION) reduce 147) ((T_FUNC_C) reduce 147) ((T_GLOBAL) reduce 147) ((T_GOTO) reduce 147) ((T_HALT_COMPILER) reduce 147) ((T_IF) reduce 147) ((T_INC) reduce 147) ((T_INCLUDE) reduce 147) ((T_INCLUDE_ONCE) reduce 147) ((T_INLINE_HTML) reduce 147) ((T_INTERFACE) reduce 147) ((T_INT_CAST) reduce 147) ((T_ISSET) reduce 147) ((T_LINE) reduce 147) ((T_LIST) reduce 147) ((T_LNUMBER) reduce 147) ((T_MATCH) reduce 147) ((T_METHOD_C) reduce 147) ((T_NAMESPACE) reduce 147) ((T_NAME_FULLY_QUALIFIED) reduce 147) ((T_NAME_QUALIFIED) reduce 147) ((T_NAME_RELATIVE) reduce 147) ((T_NEW) reduce 147) ((T_NS_C) reduce 147) ((T_OBJECT_CAST) reduce 147) ((T_PRINT) reduce 147) ((T_READONLY) reduce 147) ((T_REQUIRE) reduce 147) ((T_REQUIRE_ONCE) reduce 147) ((T_RETURN) reduce 147) ((T_START_HEREDOC) reduce 147) ((T_STATIC) reduce 147) ((T_STRING) reduce 147) ((T_STRING_CAST) reduce 147) ((T_SWITCH) reduce 147) ((T_THROW) reduce 147) ((T_TRAIT) reduce 147) ((T_TRAIT_C) reduce 147) ((T_TRY) reduce 147) ((T_UNSET) reduce 147) ((T_UNSET_CAST) reduce 147) ((T_USE) reduce 147) ((T_VARIABLE) reduce 147) ((T_WHILE) reduce 147) ((T_YIELD) reduce 147) ((T_YIELD_FROM) reduce 147) (("[") reduce 147) (("`") reduce 147) (("{") reduce 147) (("~") reduce 147)) 87 (((T_ELSE) shift) ((T_ELSEIF) shift) ((T_ENDIF) shift)) 88 (((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) (("[") shift) (("{") shift)) 89 (((T_ABSTRACT) reduce 100) ((T_ATTRIBUTE) reduce 100) ((T_CLASS) reduce 100) ((T_ENUM) reduce 100) ((T_FINAL) reduce 100) ((T_FN) reduce 100) ((T_FUNCTION) reduce 100) ((T_INTERFACE) reduce 100) ((T_READONLY) reduce 100) ((T_STATIC) reduce 100) ((T_TRAIT) reduce 100)) 90 ((("!") reduce 108) (("\"") reduce 108) (("$") reduce 108) (($) reduce 108) (("(") reduce 108) (("+") reduce 108) (("-") reduce 108) ((";") reduce 108) (("@") reduce 108) ((T_ABSTRACT) reduce 108) ((T_ARRAY) reduce 108) ((T_ARRAY_CAST) reduce 108) ((T_ATTRIBUTE) reduce 108) ((T_BOOL_CAST) reduce 108) ((T_BREAK) reduce 108) ((T_CLASS) reduce 108) ((T_CLASS_C) reduce 108) ((T_CLONE) reduce 108) ((T_CONST) reduce 108) ((T_CONSTANT_ENCAPSED_STRING) reduce 108) ((T_CONTINUE) reduce 108) ((T_DEC) reduce 108) ((T_DECLARE) reduce 108) ((T_DIR) reduce 108) ((T_DNUMBER) reduce 108) ((T_DO) reduce 108) ((T_DOUBLE_CAST) reduce 108) ((T_ECHO) reduce 108) ((T_EMPTY) reduce 108) ((T_ENUM) reduce 108) ((T_EVAL) reduce 108) ((T_EXIT) reduce 108) ((T_FILE) reduce 108) ((T_FINAL) reduce 108) ((T_FN) reduce 108) ((T_FOR) reduce 108) ((T_FOREACH) reduce 108) ((T_FUNCTION) reduce 108) ((T_FUNC_C) reduce 108) ((T_GLOBAL) reduce 108) ((T_GOTO) reduce 108) ((T_HALT_COMPILER) reduce 108) ((T_IF) reduce 108) ((T_INC) reduce 108) ((T_INCLUDE) reduce 108) ((T_INCLUDE_ONCE) reduce 108) ((T_INLINE_HTML) reduce 108) ((T_INTERFACE) reduce 108) ((T_INT_CAST) reduce 108) ((T_ISSET) reduce 108) ((T_LINE) reduce 108) ((T_LIST) reduce 108) ((T_LNUMBER) reduce 108) ((T_MATCH) reduce 108) ((T_METHOD_C) reduce 108) ((T_NAMESPACE) reduce 108) ((T_NAME_FULLY_QUALIFIED) reduce 108) ((T_NAME_QUALIFIED) reduce 108) ((T_NAME_RELATIVE) reduce 108) ((T_NEW) reduce 108) ((T_NS_C) reduce 108) ((T_OBJECT_CAST) reduce 108) ((T_PRINT) reduce 108) ((T_READONLY) reduce 108) ((T_REQUIRE) reduce 108) ((T_REQUIRE_ONCE) reduce 108) ((T_RETURN) reduce 108) ((T_START_HEREDOC) reduce 108) ((T_STATIC) reduce 108) ((T_STRING) reduce 108) ((T_STRING_CAST) reduce 108) ((T_SWITCH) reduce 108) ((T_THROW) reduce 108) ((T_TRAIT) reduce 108) ((T_TRAIT_C) reduce 108) ((T_TRY) reduce 108) ((T_UNSET) reduce 108) ((T_UNSET_CAST) reduce 108) ((T_USE) reduce 108) ((T_VARIABLE) reduce 108) ((T_WHILE) reduce 108) ((T_YIELD) reduce 108) ((T_YIELD_FROM) reduce 108) (("[") reduce 108) (("`") reduce 108) (("{") reduce 108) (("~") reduce 108)) 91 (((T_ABSTRACT) shift) ((T_ATTRIBUTE) shift) ((T_CLASS) shift) ((T_ENUM) shift) ((T_FINAL) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_INTERFACE) shift) ((T_READONLY) shift) ((T_STATIC) shift) ((T_TRAIT) shift)) 93 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) ((";") reduce 525) (("<") reduce 525) (("=") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AND_EQUAL) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_COALESCE_EQUAL) reduce 525) ((T_CONCAT_EQUAL) reduce 525) ((T_DEC) reduce 525) ((T_DIV_EQUAL) reduce 525) ((T_INC) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_MINUS_EQUAL) reduce 525) ((T_MOD_EQUAL) reduce 525) ((T_MUL_EQUAL) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_OR_EQUAL) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_PLUS_EQUAL) reduce 525) ((T_POW) reduce 525) ((T_POW_EQUAL) reduce 525) ((T_SL) reduce 525) ((T_SL_EQUAL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) ((T_SR_EQUAL) reduce 525) ((T_XOR_EQUAL) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 94 ((("%") reduce 493) (("*") reduce 493) (("+") reduce 493) (("-") reduce 493) ((".") reduce 493) (("/") reduce 493) ((";") reduce 493) (("<") reduce 493) ((">") reduce 493) (("?") reduce 493) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_BOOLEAN_AND) reduce 493) ((T_BOOLEAN_OR) reduce 493) ((T_COALESCE) reduce 493) ((T_INSTANCEOF) reduce 493) ((T_IS_EQUAL) reduce 493) ((T_IS_GREATER_OR_EQUAL) reduce 493) ((T_IS_IDENTICAL) reduce 493) ((T_IS_NOT_EQUAL) reduce 493) ((T_IS_NOT_IDENTICAL) reduce 493) ((T_IS_SMALLER_OR_EQUAL) reduce 493) ((T_LOGICAL_AND) reduce 493) ((T_LOGICAL_OR) reduce 493) ((T_LOGICAL_XOR) reduce 493) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 513) ((T_OBJECT_OPERATOR) reduce 513) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 513) ((T_POW) reduce 493) ((T_SL) reduce 493) ((T_SPACESHIP) reduce 493) ((T_SR) reduce 493) (("[") reduce 513) (("^") reduce 493) (("{") reduce 513) (("|") reduce 493)) 95 ((("!") reduce 103) (("\"") reduce 103) (($) reduce 103) (("$") reduce 103) (("(") reduce 103) (("+") reduce 103) (("-") reduce 103) ((";") reduce 103) (("@") reduce 103) ((T_ABSTRACT) reduce 103) ((T_ARRAY) reduce 103) ((T_ARRAY_CAST) reduce 103) ((T_ATTRIBUTE) reduce 103) ((T_BOOL_CAST) reduce 103) ((T_BREAK) reduce 103) ((T_CLASS) reduce 103) ((T_CLASS_C) reduce 103) ((T_CLONE) reduce 103) ((T_CONST) reduce 103) ((T_CONSTANT_ENCAPSED_STRING) reduce 103) ((T_CONTINUE) reduce 103) ((T_DEC) reduce 103) ((T_DECLARE) reduce 103) ((T_DIR) reduce 103) ((T_DNUMBER) reduce 103) ((T_DO) reduce 103) ((T_DOUBLE_CAST) reduce 103) ((T_ECHO) reduce 103) ((T_EMPTY) reduce 103) ((T_ENUM) reduce 103) ((T_EVAL) reduce 103) ((T_EXIT) reduce 103) ((T_FILE) reduce 103) ((T_FINAL) reduce 103) ((T_FN) reduce 103) ((T_FOR) reduce 103) ((T_FOREACH) reduce 103) ((T_FUNCTION) reduce 103) ((T_FUNC_C) reduce 103) ((T_GLOBAL) reduce 103) ((T_GOTO) reduce 103) ((T_HALT_COMPILER) reduce 103) ((T_IF) reduce 103) ((T_INC) reduce 103) ((T_INCLUDE) reduce 103) ((T_INCLUDE_ONCE) reduce 103) ((T_INLINE_HTML) reduce 103) ((T_INTERFACE) reduce 103) ((T_INT_CAST) reduce 103) ((T_ISSET) reduce 103) ((T_LINE) reduce 103) ((T_LIST) reduce 103) ((T_LNUMBER) reduce 103) ((T_MATCH) reduce 103) ((T_METHOD_C) reduce 103) ((T_NAMESPACE) reduce 103) ((T_NAME_FULLY_QUALIFIED) reduce 103) ((T_NAME_QUALIFIED) reduce 103) ((T_NAME_RELATIVE) reduce 103) ((T_NEW) reduce 103) ((T_NS_C) reduce 103) ((T_OBJECT_CAST) reduce 103) ((T_PRINT) reduce 103) ((T_READONLY) reduce 103) ((T_REQUIRE) reduce 103) ((T_REQUIRE_ONCE) reduce 103) ((T_RETURN) reduce 103) ((T_START_HEREDOC) reduce 103) ((T_STATIC) reduce 103) ((T_STRING) reduce 103) ((T_STRING_CAST) reduce 103) ((T_SWITCH) reduce 103) ((T_THROW) reduce 103) ((T_TRAIT) reduce 103) ((T_TRAIT_C) reduce 103) ((T_TRY) reduce 103) ((T_UNSET) reduce 103) ((T_UNSET_CAST) reduce 103) ((T_USE) reduce 103) ((T_VARIABLE) reduce 103) ((T_WHILE) reduce 103) ((T_YIELD) reduce 103) ((T_YIELD_FROM) reduce 103) (("[") reduce 103) (("`") reduce 103) (("{") reduce 103) (("~") reduce 103)) 96 (((T_ABSTRACT) reduce 188) ((T_CLASS) reduce 188) ((T_FINAL) reduce 188) ((T_READONLY) reduce 188)) 97 (((T_ABSTRACT) shift) ((T_CLASS) shift) ((T_FINAL) shift) ((T_READONLY) shift)) 98 (((T_PAAMAYIM_NEKUDOTAYIM) shift)) 99 ((("%") reduce 492) (("*") reduce 492) (("+") reduce 492) (("-") reduce 492) ((".") reduce 492) (("/") reduce 492) ((";") reduce 492) (("<") reduce 492) ((">") reduce 492) (("?") reduce 492) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_BOOLEAN_AND) reduce 492) ((T_BOOLEAN_OR) reduce 492) ((T_COALESCE) reduce 492) ((T_INSTANCEOF) reduce 492) ((T_IS_EQUAL) reduce 492) ((T_IS_GREATER_OR_EQUAL) reduce 492) ((T_IS_IDENTICAL) reduce 492) ((T_IS_NOT_EQUAL) reduce 492) ((T_IS_NOT_IDENTICAL) reduce 492) ((T_IS_SMALLER_OR_EQUAL) reduce 492) ((T_LOGICAL_AND) reduce 492) ((T_LOGICAL_OR) reduce 492) ((T_LOGICAL_XOR) reduce 492) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 515) ((T_OBJECT_OPERATOR) reduce 515) ((T_POW) reduce 492) ((T_SL) reduce 492) ((T_SPACESHIP) reduce 492) ((T_SR) reduce 492) (("[") reduce 515) (("^") reduce 492) (("{") reduce 515) (("|") reduce 492)) 100 ((("%") reduce 491) (("(") reduce 518) (("*") reduce 491) (("+") reduce 491) (("-") reduce 491) ((".") reduce 491) (("/") reduce 491) ((";") reduce 491) (("<") reduce 491) ((">") reduce 491) (("?") reduce 491) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_BOOLEAN_AND) reduce 491) ((T_BOOLEAN_OR) reduce 491) ((T_COALESCE) reduce 491) ((T_INSTANCEOF) reduce 491) ((T_IS_EQUAL) reduce 491) ((T_IS_GREATER_OR_EQUAL) reduce 491) ((T_IS_IDENTICAL) reduce 491) ((T_IS_NOT_EQUAL) reduce 491) ((T_IS_NOT_IDENTICAL) reduce 491) ((T_IS_SMALLER_OR_EQUAL) reduce 491) ((T_LOGICAL_AND) reduce 491) ((T_LOGICAL_OR) reduce 491) ((T_LOGICAL_XOR) reduce 491) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 512) ((T_OBJECT_OPERATOR) reduce 512) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 512) ((T_POW) reduce 491) ((T_SL) reduce 491) ((T_SPACESHIP) reduce 491) ((T_SR) reduce 491) (("[") reduce 512) (("^") reduce 491) (("{") reduce 512) (("|") reduce 491)) 101 ((("!") reduce 106) (("\"") reduce 106) (($) reduce 106) (("$") reduce 106) (("(") reduce 106) (("+") reduce 106) (("-") reduce 106) ((";") reduce 106) (("@") reduce 106) ((T_ABSTRACT) reduce 106) ((T_ARRAY) reduce 106) ((T_ARRAY_CAST) reduce 106) ((T_ATTRIBUTE) reduce 106) ((T_BOOL_CAST) reduce 106) ((T_BREAK) reduce 106) ((T_CLASS) reduce 106) ((T_CLASS_C) reduce 106) ((T_CLONE) reduce 106) ((T_CONST) reduce 106) ((T_CONSTANT_ENCAPSED_STRING) reduce 106) ((T_CONTINUE) reduce 106) ((T_DEC) reduce 106) ((T_DECLARE) reduce 106) ((T_DIR) reduce 106) ((T_DNUMBER) reduce 106) ((T_DO) reduce 106) ((T_DOUBLE_CAST) reduce 106) ((T_ECHO) reduce 106) ((T_EMPTY) reduce 106) ((T_ENUM) reduce 106) ((T_EVAL) reduce 106) ((T_EXIT) reduce 106) ((T_FILE) reduce 106) ((T_FINAL) reduce 106) ((T_FN) reduce 106) ((T_FOR) reduce 106) ((T_FOREACH) reduce 106) ((T_FUNCTION) reduce 106) ((T_FUNC_C) reduce 106) ((T_GLOBAL) reduce 106) ((T_GOTO) reduce 106) ((T_HALT_COMPILER) reduce 106) ((T_IF) reduce 106) ((T_INC) reduce 106) ((T_INCLUDE) reduce 106) ((T_INCLUDE_ONCE) reduce 106) ((T_INLINE_HTML) reduce 106) ((T_INTERFACE) reduce 106) ((T_INT_CAST) reduce 106) ((T_ISSET) reduce 106) ((T_LINE) reduce 106) ((T_LIST) reduce 106) ((T_LNUMBER) reduce 106) ((T_MATCH) reduce 106) ((T_METHOD_C) reduce 106) ((T_NAMESPACE) reduce 106) ((T_NAME_FULLY_QUALIFIED) reduce 106) ((T_NAME_QUALIFIED) reduce 106) ((T_NAME_RELATIVE) reduce 106) ((T_NEW) reduce 106) ((T_NS_C) reduce 106) ((T_OBJECT_CAST) reduce 106) ((T_PRINT) reduce 106) ((T_READONLY) reduce 106) ((T_REQUIRE) reduce 106) ((T_REQUIRE_ONCE) reduce 106) ((T_RETURN) reduce 106) ((T_START_HEREDOC) reduce 106) ((T_STATIC) reduce 106) ((T_STRING) reduce 106) ((T_STRING_CAST) reduce 106) ((T_SWITCH) reduce 106) ((T_THROW) reduce 106) ((T_TRAIT) reduce 106) ((T_TRAIT_C) reduce 106) ((T_TRY) reduce 106) ((T_UNSET) reduce 106) ((T_UNSET_CAST) reduce 106) ((T_USE) reduce 106) ((T_VARIABLE) reduce 106) ((T_WHILE) reduce 106) ((T_YIELD) reduce 106) ((T_YIELD_FROM) reduce 106) (("[") reduce 106) (("`") reduce 106) (("{") reduce 106) (("~") reduce 106)) 102 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 103 ((("(") reduce 457) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift)) 104 (((T_NULLSAFE_OBJECT_OPERATOR) reduce 514) ((T_OBJECT_OPERATOR) reduce 514) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 509) (("[") reduce 514) (("{") reduce 514)) 105 ((("(") reduce 457) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_READONLY) reduce 457) ((T_STRING) reduce 457)) 106 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) ((";") reduce 524) (("<") reduce 524) (("=") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AND_EQUAL) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_COALESCE_EQUAL) reduce 524) ((T_CONCAT_EQUAL) reduce 524) ((T_DEC) reduce 524) ((T_DIV_EQUAL) reduce 524) ((T_INC) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_MINUS_EQUAL) reduce 524) ((T_MOD_EQUAL) reduce 524) ((T_MUL_EQUAL) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_OR_EQUAL) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_PLUS_EQUAL) reduce 524) ((T_POW) reduce 524) ((T_POW_EQUAL) reduce 524) ((T_SL) reduce 524) ((T_SL_EQUAL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) ((T_SR_EQUAL) reduce 524) ((T_XOR_EQUAL) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 107 ((("!") reduce 102) (("\"") reduce 102) (($) reduce 102) (("$") reduce 102) (("(") reduce 102) (("+") reduce 102) (("-") reduce 102) ((";") reduce 102) (("@") reduce 102) ((T_ABSTRACT) reduce 102) ((T_ARRAY) reduce 102) ((T_ARRAY_CAST) reduce 102) ((T_ATTRIBUTE) reduce 102) ((T_BOOL_CAST) reduce 102) ((T_BREAK) reduce 102) ((T_CLASS) reduce 102) ((T_CLASS_C) reduce 102) ((T_CLONE) reduce 102) ((T_CONST) reduce 102) ((T_CONSTANT_ENCAPSED_STRING) reduce 102) ((T_CONTINUE) reduce 102) ((T_DEC) reduce 102) ((T_DECLARE) reduce 102) ((T_DIR) reduce 102) ((T_DNUMBER) reduce 102) ((T_DO) reduce 102) ((T_DOUBLE_CAST) reduce 102) ((T_ECHO) reduce 102) ((T_EMPTY) reduce 102) ((T_ENUM) reduce 102) ((T_EVAL) reduce 102) ((T_EXIT) reduce 102) ((T_FILE) reduce 102) ((T_FINAL) reduce 102) ((T_FN) reduce 102) ((T_FOR) reduce 102) ((T_FOREACH) reduce 102) ((T_FUNCTION) reduce 102) ((T_FUNC_C) reduce 102) ((T_GLOBAL) reduce 102) ((T_GOTO) reduce 102) ((T_HALT_COMPILER) reduce 102) ((T_IF) reduce 102) ((T_INC) reduce 102) ((T_INCLUDE) reduce 102) ((T_INCLUDE_ONCE) reduce 102) ((T_INLINE_HTML) reduce 102) ((T_INTERFACE) reduce 102) ((T_INT_CAST) reduce 102) ((T_ISSET) reduce 102) ((T_LINE) reduce 102) ((T_LIST) reduce 102) ((T_LNUMBER) reduce 102) ((T_MATCH) reduce 102) ((T_METHOD_C) reduce 102) ((T_NAMESPACE) reduce 102) ((T_NAME_FULLY_QUALIFIED) reduce 102) ((T_NAME_QUALIFIED) reduce 102) ((T_NAME_RELATIVE) reduce 102) ((T_NEW) reduce 102) ((T_NS_C) reduce 102) ((T_OBJECT_CAST) reduce 102) ((T_PRINT) reduce 102) ((T_READONLY) reduce 102) ((T_REQUIRE) reduce 102) ((T_REQUIRE_ONCE) reduce 102) ((T_RETURN) reduce 102) ((T_START_HEREDOC) reduce 102) ((T_STATIC) reduce 102) ((T_STRING) reduce 102) ((T_STRING_CAST) reduce 102) ((T_SWITCH) reduce 102) ((T_THROW) reduce 102) ((T_TRAIT) reduce 102) ((T_TRAIT_C) reduce 102) ((T_TRY) reduce 102) ((T_UNSET) reduce 102) ((T_UNSET_CAST) reduce 102) ((T_USE) reduce 102) ((T_VARIABLE) reduce 102) ((T_WHILE) reduce 102) ((T_YIELD) reduce 102) ((T_YIELD_FROM) reduce 102) (("[") reduce 102) (("`") reduce 102) (("{") reduce 102) (("~") reduce 102)) 108 ((("!") reduce 146) (("\"") reduce 146) (($) reduce 146) (("$") reduce 146) (("(") reduce 146) (("+") reduce 146) (("-") reduce 146) ((";") reduce 146) (("@") reduce 146) ((T_ABSTRACT) reduce 146) ((T_ARRAY) reduce 146) ((T_ARRAY_CAST) reduce 146) ((T_ATTRIBUTE) reduce 146) ((T_BOOL_CAST) reduce 146) ((T_BREAK) reduce 146) ((T_CLASS) reduce 146) ((T_CLASS_C) reduce 146) ((T_CLONE) reduce 146) ((T_CONST) reduce 146) ((T_CONSTANT_ENCAPSED_STRING) reduce 146) ((T_CONTINUE) reduce 146) ((T_DEC) reduce 146) ((T_DECLARE) reduce 146) ((T_DIR) reduce 146) ((T_DNUMBER) reduce 146) ((T_DO) reduce 146) ((T_DOUBLE_CAST) reduce 146) ((T_ECHO) reduce 146) ((T_EMPTY) reduce 146) ((T_ENUM) reduce 146) ((T_EVAL) reduce 146) ((T_EXIT) reduce 146) ((T_FILE) reduce 146) ((T_FINAL) reduce 146) ((T_FN) reduce 146) ((T_FOR) reduce 146) ((T_FOREACH) reduce 146) ((T_FUNCTION) reduce 146) ((T_FUNC_C) reduce 146) ((T_GLOBAL) reduce 146) ((T_GOTO) reduce 146) ((T_HALT_COMPILER) reduce 146) ((T_IF) reduce 146) ((T_INC) reduce 146) ((T_INCLUDE) reduce 146) ((T_INCLUDE_ONCE) reduce 146) ((T_INLINE_HTML) reduce 146) ((T_INTERFACE) reduce 146) ((T_INT_CAST) reduce 146) ((T_ISSET) reduce 146) ((T_LINE) reduce 146) ((T_LIST) reduce 146) ((T_LNUMBER) reduce 146) ((T_MATCH) reduce 146) ((T_METHOD_C) reduce 146) ((T_NAMESPACE) reduce 146) ((T_NAME_FULLY_QUALIFIED) reduce 146) ((T_NAME_QUALIFIED) reduce 146) ((T_NAME_RELATIVE) reduce 146) ((T_NEW) reduce 146) ((T_NS_C) reduce 146) ((T_OBJECT_CAST) reduce 146) ((T_PRINT) reduce 146) ((T_READONLY) reduce 146) ((T_REQUIRE) reduce 146) ((T_REQUIRE_ONCE) reduce 146) ((T_RETURN) reduce 146) ((T_START_HEREDOC) reduce 146) ((T_STATIC) reduce 146) ((T_STRING) reduce 146) ((T_STRING_CAST) reduce 146) ((T_SWITCH) reduce 146) ((T_THROW) reduce 146) ((T_TRAIT) reduce 146) ((T_TRAIT_C) reduce 146) ((T_TRY) reduce 146) ((T_UNSET) reduce 146) ((T_UNSET_CAST) reduce 146) ((T_USE) reduce 146) ((T_VARIABLE) reduce 146) ((T_WHILE) reduce 146) ((T_YIELD) reduce 146) ((T_YIELD_FROM) reduce 146) (("[") reduce 146) (("`") reduce 146) (("{") reduce 146) (("~") reduce 146)) 109 ((("!") reduce 243) (("\"") reduce 243) (("$") reduce 243) (($) reduce 243) (("(") reduce 243) (("+") reduce 243) (("-") reduce 243) ((";") reduce 243) (("@") reduce 243) ((T_ABSTRACT) reduce 243) ((T_ARRAY) reduce 243) ((T_ARRAY_CAST) reduce 243) ((T_ATTRIBUTE) reduce 243) ((T_BOOL_CAST) reduce 243) ((T_BREAK) reduce 243) ((T_CLASS) reduce 243) ((T_CLASS_C) reduce 243) ((T_CLONE) reduce 243) ((T_CONST) reduce 243) ((T_CONSTANT_ENCAPSED_STRING) reduce 243) ((T_CONTINUE) reduce 243) ((T_DEC) reduce 243) ((T_DECLARE) reduce 243) ((T_DIR) reduce 243) ((T_DNUMBER) reduce 243) ((T_DO) reduce 243) ((T_DOUBLE_CAST) reduce 243) ((T_ECHO) reduce 243) ((T_ELSE) shift) ((T_ELSEIF) shift) ((T_EMPTY) reduce 243) ((T_ENUM) reduce 243) ((T_EVAL) reduce 243) ((T_EXIT) reduce 243) ((T_FILE) reduce 243) ((T_FINAL) reduce 243) ((T_FN) reduce 243) ((T_FOR) reduce 243) ((T_FOREACH) reduce 243) ((T_FUNCTION) reduce 243) ((T_FUNC_C) reduce 243) ((T_GLOBAL) reduce 243) ((T_GOTO) reduce 243) ((T_HALT_COMPILER) reduce 243) ((T_IF) reduce 243) ((T_INC) reduce 243) ((T_INCLUDE) reduce 243) ((T_INCLUDE_ONCE) reduce 243) ((T_INLINE_HTML) reduce 243) ((T_INTERFACE) reduce 243) ((T_INT_CAST) reduce 243) ((T_ISSET) reduce 243) ((T_LINE) reduce 243) ((T_LIST) reduce 243) ((T_LNUMBER) reduce 243) ((T_MATCH) reduce 243) ((T_METHOD_C) reduce 243) ((T_NAMESPACE) reduce 243) ((T_NAME_FULLY_QUALIFIED) reduce 243) ((T_NAME_QUALIFIED) reduce 243) ((T_NAME_RELATIVE) reduce 243) ((T_NEW) reduce 243) ((T_NS_C) reduce 243) ((T_OBJECT_CAST) reduce 243) ((T_PRINT) reduce 243) ((T_READONLY) reduce 243) ((T_REQUIRE) reduce 243) ((T_REQUIRE_ONCE) reduce 243) ((T_RETURN) reduce 243) ((T_START_HEREDOC) reduce 243) ((T_STATIC) reduce 243) ((T_STRING) reduce 243) ((T_STRING_CAST) reduce 243) ((T_SWITCH) reduce 243) ((T_THROW) reduce 243) ((T_TRAIT) reduce 243) ((T_TRAIT_C) reduce 243) ((T_TRY) reduce 243) ((T_UNSET) reduce 243) ((T_UNSET_CAST) reduce 243) ((T_USE) reduce 243) ((T_VARIABLE) reduce 243) ((T_WHILE) reduce 243) ((T_YIELD) reduce 243) ((T_YIELD_FROM) reduce 243) (("[") reduce 243) (("`") reduce 243) (("{") reduce 243) (("~") reduce 243)) 110 ((("%") reduce 445) (("*") reduce 445) (("+") reduce 445) (("-") reduce 445) ((".") reduce 445) (("/") reduce 445) ((";") reduce 445) (("<") reduce 445) ((">") reduce 445) (("?") reduce 445) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_BOOLEAN_AND) reduce 445) ((T_BOOLEAN_OR) reduce 445) ((T_COALESCE) reduce 445) ((T_INSTANCEOF) reduce 445) ((T_IS_EQUAL) reduce 445) ((T_IS_GREATER_OR_EQUAL) reduce 445) ((T_IS_IDENTICAL) reduce 445) ((T_IS_NOT_EQUAL) reduce 445) ((T_IS_NOT_IDENTICAL) reduce 445) ((T_IS_SMALLER_OR_EQUAL) reduce 445) ((T_LOGICAL_AND) reduce 445) ((T_LOGICAL_OR) reduce 445) ((T_LOGICAL_XOR) reduce 445) ((T_POW) reduce 445) ((T_SL) reduce 445) ((T_SPACESHIP) reduce 445) ((T_SR) reduce 445) (("^") reduce 445) (("|") reduce 445)) 111 ((("!") reduce 105) (("\"") reduce 105) (($) reduce 105) (("$") reduce 105) (("(") reduce 105) (("+") reduce 105) (("-") reduce 105) ((";") reduce 105) (("@") reduce 105) ((T_ABSTRACT) reduce 105) ((T_ARRAY) reduce 105) ((T_ARRAY_CAST) reduce 105) ((T_ATTRIBUTE) reduce 105) ((T_BOOL_CAST) reduce 105) ((T_BREAK) reduce 105) ((T_CLASS) reduce 105) ((T_CLASS_C) reduce 105) ((T_CLONE) reduce 105) ((T_CONST) reduce 105) ((T_CONSTANT_ENCAPSED_STRING) reduce 105) ((T_CONTINUE) reduce 105) ((T_DEC) reduce 105) ((T_DECLARE) reduce 105) ((T_DIR) reduce 105) ((T_DNUMBER) reduce 105) ((T_DO) reduce 105) ((T_DOUBLE_CAST) reduce 105) ((T_ECHO) reduce 105) ((T_EMPTY) reduce 105) ((T_ENUM) reduce 105) ((T_EVAL) reduce 105) ((T_EXIT) reduce 105) ((T_FILE) reduce 105) ((T_FINAL) reduce 105) ((T_FN) reduce 105) ((T_FOR) reduce 105) ((T_FOREACH) reduce 105) ((T_FUNCTION) reduce 105) ((T_FUNC_C) reduce 105) ((T_GLOBAL) reduce 105) ((T_GOTO) reduce 105) ((T_HALT_COMPILER) reduce 105) ((T_IF) reduce 105) ((T_INC) reduce 105) ((T_INCLUDE) reduce 105) ((T_INCLUDE_ONCE) reduce 105) ((T_INLINE_HTML) reduce 105) ((T_INTERFACE) reduce 105) ((T_INT_CAST) reduce 105) ((T_ISSET) reduce 105) ((T_LINE) reduce 105) ((T_LIST) reduce 105) ((T_LNUMBER) reduce 105) ((T_MATCH) reduce 105) ((T_METHOD_C) reduce 105) ((T_NAMESPACE) reduce 105) ((T_NAME_FULLY_QUALIFIED) reduce 105) ((T_NAME_QUALIFIED) reduce 105) ((T_NAME_RELATIVE) reduce 105) ((T_NEW) reduce 105) ((T_NS_C) reduce 105) ((T_OBJECT_CAST) reduce 105) ((T_PRINT) reduce 105) ((T_READONLY) reduce 105) ((T_REQUIRE) reduce 105) ((T_REQUIRE_ONCE) reduce 105) ((T_RETURN) reduce 105) ((T_START_HEREDOC) reduce 105) ((T_STATIC) reduce 105) ((T_STRING) reduce 105) ((T_STRING_CAST) reduce 105) ((T_SWITCH) reduce 105) ((T_THROW) reduce 105) ((T_TRAIT) reduce 105) ((T_TRAIT_C) reduce 105) ((T_TRY) reduce 105) ((T_UNSET) reduce 105) ((T_UNSET_CAST) reduce 105) ((T_USE) reduce 105) ((T_VARIABLE) reduce 105) ((T_WHILE) reduce 105) ((T_YIELD) reduce 105) ((T_YIELD_FROM) reduce 105) (("[") reduce 105) (("`") reduce 105) (("{") reduce 105) (("~") reduce 105)) 112 ((("%") reduce 427) (("*") reduce 427) (("+") reduce 427) (("-") reduce 427) ((".") reduce 427) (("/") reduce 427) ((";") reduce 427) (("<") reduce 427) ((">") reduce 427) (("?") reduce 427) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_BOOLEAN_AND) reduce 427) ((T_BOOLEAN_OR) reduce 427) ((T_COALESCE) reduce 427) ((T_INSTANCEOF) reduce 427) ((T_IS_EQUAL) reduce 427) ((T_IS_GREATER_OR_EQUAL) reduce 427) ((T_IS_IDENTICAL) reduce 427) ((T_IS_NOT_EQUAL) reduce 427) ((T_IS_NOT_IDENTICAL) reduce 427) ((T_IS_SMALLER_OR_EQUAL) reduce 427) ((T_LOGICAL_AND) reduce 427) ((T_LOGICAL_OR) reduce 427) ((T_LOGICAL_XOR) reduce 427) ((T_POW) reduce 427) ((T_SL) reduce 427) ((T_SPACESHIP) reduce 427) ((T_SR) reduce 427) (("^") reduce 427) (("|") reduce 427)) 113 ((("%") reduce 449) (("*") reduce 449) (("+") reduce 449) (("-") reduce 449) ((".") reduce 449) (("/") reduce 449) ((";") reduce 449) (("<") reduce 449) ((">") reduce 449) (("?") reduce 449) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_BOOLEAN_AND) reduce 449) ((T_BOOLEAN_OR) reduce 449) ((T_COALESCE) reduce 449) ((T_INSTANCEOF) reduce 449) ((T_IS_EQUAL) reduce 449) ((T_IS_GREATER_OR_EQUAL) reduce 449) ((T_IS_IDENTICAL) reduce 449) ((T_IS_NOT_EQUAL) reduce 449) ((T_IS_NOT_IDENTICAL) reduce 449) ((T_IS_SMALLER_OR_EQUAL) reduce 449) ((T_LOGICAL_AND) reduce 449) ((T_LOGICAL_OR) reduce 449) ((T_LOGICAL_XOR) reduce 449) ((T_POW) reduce 449) ((T_SL) reduce 449) ((T_SPACESHIP) reduce 449) ((T_SR) reduce 449) (("^") reduce 449) (("|") reduce 449)) 114 ((("%") reduce 494) (("(") shift) (("*") reduce 494) (("+") reduce 494) (("-") reduce 494) ((".") reduce 494) (("/") reduce 494) ((";") reduce 494) (("<") reduce 494) ((">") reduce 494) (("?") reduce 494) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_BOOLEAN_AND) reduce 494) ((T_BOOLEAN_OR) reduce 494) ((T_COALESCE) reduce 494) ((T_INSTANCEOF) reduce 494) ((T_IS_EQUAL) reduce 494) ((T_IS_GREATER_OR_EQUAL) reduce 494) ((T_IS_IDENTICAL) reduce 494) ((T_IS_NOT_EQUAL) reduce 494) ((T_IS_NOT_IDENTICAL) reduce 494) ((T_IS_SMALLER_OR_EQUAL) reduce 494) ((T_LOGICAL_AND) reduce 494) ((T_LOGICAL_OR) reduce 494) ((T_LOGICAL_XOR) reduce 494) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 494) ((T_OBJECT_OPERATOR) reduce 494) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 494) ((T_SL) reduce 494) ((T_SPACESHIP) reduce 494) ((T_SR) reduce 494) (("[") reduce 494) (("^") reduce 494) (("{") reduce 494) (("|") reduce 494)) 115 ((("%") reduce 423) (("*") reduce 423) (("+") reduce 423) (("-") reduce 423) ((".") reduce 423) (("/") reduce 423) ((";") reduce 423) (("<") reduce 423) ((">") reduce 423) (("?") reduce 423) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_BOOLEAN_AND) reduce 423) ((T_BOOLEAN_OR) reduce 423) ((T_COALESCE) reduce 423) ((T_INSTANCEOF) reduce 423) ((T_IS_EQUAL) reduce 423) ((T_IS_GREATER_OR_EQUAL) reduce 423) ((T_IS_IDENTICAL) reduce 423) ((T_IS_NOT_EQUAL) reduce 423) ((T_IS_NOT_IDENTICAL) reduce 423) ((T_IS_SMALLER_OR_EQUAL) reduce 423) ((T_LOGICAL_AND) reduce 423) ((T_LOGICAL_OR) reduce 423) ((T_LOGICAL_XOR) reduce 423) ((T_POW) reduce 423) ((T_SL) reduce 423) ((T_SPACESHIP) reduce 423) ((T_SR) reduce 423) (("^") reduce 423) (("|") reduce 423)) 116 ((("%") reduce 437) (("*") reduce 437) (("+") reduce 437) (("-") reduce 437) ((".") reduce 437) (("/") reduce 437) ((";") reduce 437) (("<") reduce 437) ((">") reduce 437) (("?") reduce 437) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_BOOLEAN_AND) reduce 437) ((T_BOOLEAN_OR) reduce 437) ((T_COALESCE) reduce 437) ((T_INSTANCEOF) reduce 437) ((T_IS_EQUAL) reduce 437) ((T_IS_GREATER_OR_EQUAL) reduce 437) ((T_IS_IDENTICAL) reduce 437) ((T_IS_NOT_EQUAL) reduce 437) ((T_IS_NOT_IDENTICAL) reduce 437) ((T_IS_SMALLER_OR_EQUAL) reduce 437) ((T_LOGICAL_AND) reduce 437) ((T_LOGICAL_OR) reduce 437) ((T_LOGICAL_XOR) reduce 437) ((T_POW) reduce 437) ((T_SL) reduce 437) ((T_SPACESHIP) reduce 437) ((T_SR) reduce 437) (("^") reduce 437) (("|") reduce 437)) 117 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) ((";") reduce 519) (("<") reduce 519) (("=") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AND_EQUAL) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_COALESCE_EQUAL) reduce 519) ((T_CONCAT_EQUAL) reduce 519) ((T_DEC) reduce 519) ((T_DIV_EQUAL) reduce 519) ((T_INC) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_MINUS_EQUAL) reduce 519) ((T_MOD_EQUAL) reduce 519) ((T_MUL_EQUAL) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_OR_EQUAL) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_PLUS_EQUAL) reduce 519) ((T_POW) reduce 519) ((T_POW_EQUAL) reduce 519) ((T_SL) reduce 519) ((T_SL_EQUAL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) ((T_SR_EQUAL) reduce 519) ((T_XOR_EQUAL) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 118 ((("!") reduce 107) (("\"") reduce 107) (("$") reduce 107) (($) reduce 107) (("(") reduce 107) (("+") reduce 107) (("-") reduce 107) ((";") reduce 107) (("@") reduce 107) ((T_ABSTRACT) reduce 107) ((T_ARRAY) reduce 107) ((T_ARRAY_CAST) reduce 107) ((T_ATTRIBUTE) reduce 107) ((T_BOOL_CAST) reduce 107) ((T_BREAK) reduce 107) ((T_CLASS) reduce 107) ((T_CLASS_C) reduce 107) ((T_CLONE) reduce 107) ((T_CONST) reduce 107) ((T_CONSTANT_ENCAPSED_STRING) reduce 107) ((T_CONTINUE) reduce 107) ((T_DEC) reduce 107) ((T_DECLARE) reduce 107) ((T_DIR) reduce 107) ((T_DNUMBER) reduce 107) ((T_DO) reduce 107) ((T_DOUBLE_CAST) reduce 107) ((T_ECHO) reduce 107) ((T_EMPTY) reduce 107) ((T_ENUM) reduce 107) ((T_EVAL) reduce 107) ((T_EXIT) reduce 107) ((T_FILE) reduce 107) ((T_FINAL) reduce 107) ((T_FN) reduce 107) ((T_FOR) reduce 107) ((T_FOREACH) reduce 107) ((T_FUNCTION) reduce 107) ((T_FUNC_C) reduce 107) ((T_GLOBAL) reduce 107) ((T_GOTO) reduce 107) ((T_HALT_COMPILER) reduce 107) ((T_IF) reduce 107) ((T_INC) reduce 107) ((T_INCLUDE) reduce 107) ((T_INCLUDE_ONCE) reduce 107) ((T_INLINE_HTML) reduce 107) ((T_INTERFACE) reduce 107) ((T_INT_CAST) reduce 107) ((T_ISSET) reduce 107) ((T_LINE) reduce 107) ((T_LIST) reduce 107) ((T_LNUMBER) reduce 107) ((T_MATCH) reduce 107) ((T_METHOD_C) reduce 107) ((T_NAMESPACE) reduce 107) ((T_NAME_FULLY_QUALIFIED) reduce 107) ((T_NAME_QUALIFIED) reduce 107) ((T_NAME_RELATIVE) reduce 107) ((T_NEW) reduce 107) ((T_NS_C) reduce 107) ((T_OBJECT_CAST) reduce 107) ((T_PRINT) reduce 107) ((T_READONLY) reduce 107) ((T_REQUIRE) reduce 107) ((T_REQUIRE_ONCE) reduce 107) ((T_RETURN) reduce 107) ((T_START_HEREDOC) reduce 107) ((T_STATIC) reduce 107) ((T_STRING) reduce 107) ((T_STRING_CAST) reduce 107) ((T_SWITCH) reduce 107) ((T_THROW) reduce 107) ((T_TRAIT) reduce 107) ((T_TRAIT_C) reduce 107) ((T_TRY) reduce 107) ((T_UNSET) reduce 107) ((T_UNSET_CAST) reduce 107) ((T_USE) reduce 107) ((T_VARIABLE) reduce 107) ((T_WHILE) reduce 107) ((T_YIELD) reduce 107) ((T_YIELD_FROM) reduce 107) (("[") reduce 107) (("`") reduce 107) (("{") reduce 107) (("~") reduce 107)) 119 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) ((";") reduce 526) (("<") reduce 526) (("=") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AND_EQUAL) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_COALESCE_EQUAL) reduce 526) ((T_CONCAT_EQUAL) reduce 526) ((T_DEC) reduce 526) ((T_DIV_EQUAL) reduce 526) ((T_INC) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_MINUS_EQUAL) reduce 526) ((T_MOD_EQUAL) reduce 526) ((T_MUL_EQUAL) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_OR_EQUAL) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_PLUS_EQUAL) reduce 526) ((T_POW) reduce 526) ((T_POW_EQUAL) reduce 526) ((T_SL) reduce 526) ((T_SL_EQUAL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) ((T_SR_EQUAL) reduce 526) ((T_XOR_EQUAL) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 120 ((("!") reduce 83) (("\"") reduce 83) (($) reduce 83) (("$") reduce 83) (("(") reduce 83) (("+") reduce 83) (("-") reduce 83) ((";") reduce 83) (("@") reduce 83) ((T_ABSTRACT) reduce 83) ((T_ARRAY) reduce 83) ((T_ARRAY_CAST) reduce 83) ((T_ATTRIBUTE) reduce 83) ((T_BOOL_CAST) reduce 83) ((T_BREAK) reduce 83) ((T_CLASS) reduce 83) ((T_CLASS_C) reduce 83) ((T_CLONE) reduce 83) ((T_CONST) reduce 83) ((T_CONSTANT_ENCAPSED_STRING) reduce 83) ((T_CONTINUE) reduce 83) ((T_DEC) reduce 83) ((T_DECLARE) reduce 83) ((T_DIR) reduce 83) ((T_DNUMBER) reduce 83) ((T_DO) reduce 83) ((T_DOUBLE_CAST) reduce 83) ((T_ECHO) reduce 83) ((T_EMPTY) reduce 83) ((T_ENUM) reduce 83) ((T_EVAL) reduce 83) ((T_EXIT) reduce 83) ((T_FILE) reduce 83) ((T_FINAL) reduce 83) ((T_FN) reduce 83) ((T_FOR) reduce 83) ((T_FOREACH) reduce 83) ((T_FUNCTION) reduce 83) ((T_FUNC_C) reduce 83) ((T_GLOBAL) reduce 83) ((T_GOTO) reduce 83) ((T_HALT_COMPILER) reduce 83) ((T_IF) reduce 83) ((T_INC) reduce 83) ((T_INCLUDE) reduce 83) ((T_INCLUDE_ONCE) reduce 83) ((T_INLINE_HTML) reduce 83) ((T_INTERFACE) reduce 83) ((T_INT_CAST) reduce 83) ((T_ISSET) reduce 83) ((T_LINE) reduce 83) ((T_LIST) reduce 83) ((T_LNUMBER) reduce 83) ((T_MATCH) reduce 83) ((T_METHOD_C) reduce 83) ((T_NAMESPACE) reduce 83) ((T_NAME_FULLY_QUALIFIED) reduce 83) ((T_NAME_QUALIFIED) reduce 83) ((T_NAME_RELATIVE) reduce 83) ((T_NEW) reduce 83) ((T_NS_C) reduce 83) ((T_OBJECT_CAST) reduce 83) ((T_PRINT) reduce 83) ((T_READONLY) reduce 83) ((T_REQUIRE) reduce 83) ((T_REQUIRE_ONCE) reduce 83) ((T_RETURN) reduce 83) ((T_START_HEREDOC) reduce 83) ((T_STATIC) reduce 83) ((T_STRING) reduce 83) ((T_STRING_CAST) reduce 83) ((T_SWITCH) reduce 83) ((T_THROW) reduce 83) ((T_TRAIT) reduce 83) ((T_TRAIT_C) reduce 83) ((T_TRY) reduce 83) ((T_UNSET) reduce 83) ((T_UNSET_CAST) reduce 83) ((T_USE) reduce 83) ((T_VARIABLE) reduce 83) ((T_WHILE) reduce 83) ((T_YIELD) reduce 83) ((T_YIELD_FROM) reduce 83) (("[") reduce 83) (("`") reduce 83) (("{") reduce 83) (("~") reduce 83)) 121 ((("!") reduce 104) (("\"") reduce 104) (($) reduce 104) (("$") reduce 104) (("(") reduce 104) (("+") reduce 104) (("-") reduce 104) ((";") reduce 104) (("@") reduce 104) ((T_ABSTRACT) reduce 104) ((T_ARRAY) reduce 104) ((T_ARRAY_CAST) reduce 104) ((T_ATTRIBUTE) reduce 104) ((T_BOOL_CAST) reduce 104) ((T_BREAK) reduce 104) ((T_CLASS) reduce 104) ((T_CLASS_C) reduce 104) ((T_CLONE) reduce 104) ((T_CONST) reduce 104) ((T_CONSTANT_ENCAPSED_STRING) reduce 104) ((T_CONTINUE) reduce 104) ((T_DEC) reduce 104) ((T_DECLARE) reduce 104) ((T_DIR) reduce 104) ((T_DNUMBER) reduce 104) ((T_DO) reduce 104) ((T_DOUBLE_CAST) reduce 104) ((T_ECHO) reduce 104) ((T_EMPTY) reduce 104) ((T_ENUM) reduce 104) ((T_EVAL) reduce 104) ((T_EXIT) reduce 104) ((T_FILE) reduce 104) ((T_FINAL) reduce 104) ((T_FN) reduce 104) ((T_FOR) reduce 104) ((T_FOREACH) reduce 104) ((T_FUNCTION) reduce 104) ((T_FUNC_C) reduce 104) ((T_GLOBAL) reduce 104) ((T_GOTO) reduce 104) ((T_HALT_COMPILER) reduce 104) ((T_IF) reduce 104) ((T_INC) reduce 104) ((T_INCLUDE) reduce 104) ((T_INCLUDE_ONCE) reduce 104) ((T_INLINE_HTML) reduce 104) ((T_INTERFACE) reduce 104) ((T_INT_CAST) reduce 104) ((T_ISSET) reduce 104) ((T_LINE) reduce 104) ((T_LIST) reduce 104) ((T_LNUMBER) reduce 104) ((T_MATCH) reduce 104) ((T_METHOD_C) reduce 104) ((T_NAMESPACE) reduce 104) ((T_NAME_FULLY_QUALIFIED) reduce 104) ((T_NAME_QUALIFIED) reduce 104) ((T_NAME_RELATIVE) reduce 104) ((T_NEW) reduce 104) ((T_NS_C) reduce 104) ((T_OBJECT_CAST) reduce 104) ((T_PRINT) reduce 104) ((T_READONLY) reduce 104) ((T_REQUIRE) reduce 104) ((T_REQUIRE_ONCE) reduce 104) ((T_RETURN) reduce 104) ((T_START_HEREDOC) reduce 104) ((T_STATIC) reduce 104) ((T_STRING) reduce 104) ((T_STRING_CAST) reduce 104) ((T_SWITCH) reduce 104) ((T_THROW) reduce 104) ((T_TRAIT) reduce 104) ((T_TRAIT_C) reduce 104) ((T_TRY) reduce 104) ((T_UNSET) reduce 104) ((T_UNSET_CAST) reduce 104) ((T_USE) reduce 104) ((T_VARIABLE) reduce 104) ((T_WHILE) reduce 104) ((T_YIELD) reduce 104) ((T_YIELD_FROM) reduce 104) (("[") reduce 104) (("`") reduce 104) (("{") reduce 104) (("~") reduce 104)) 122 ((("%") reduce 367) (("*") reduce 367) (("+") reduce 367) (("-") reduce 367) ((".") reduce 367) (("/") reduce 367) ((";") reduce 367) (("<") reduce 367) (("=") shift) ((">") reduce 367) (("?") reduce 367) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AND_EQUAL) shift) ((T_BOOLEAN_AND) reduce 367) ((T_BOOLEAN_OR) reduce 367) ((T_COALESCE) reduce 367) ((T_COALESCE_EQUAL) shift) ((T_CONCAT_EQUAL) shift) ((T_DEC) shift) ((T_DIV_EQUAL) shift) ((T_INC) shift) ((T_INSTANCEOF) reduce 367) ((T_IS_EQUAL) reduce 367) ((T_IS_GREATER_OR_EQUAL) reduce 367) ((T_IS_IDENTICAL) reduce 367) ((T_IS_NOT_EQUAL) reduce 367) ((T_IS_NOT_IDENTICAL) reduce 367) ((T_IS_SMALLER_OR_EQUAL) reduce 367) ((T_LOGICAL_AND) reduce 367) ((T_LOGICAL_OR) reduce 367) ((T_LOGICAL_XOR) reduce 367) ((T_MINUS_EQUAL) shift) ((T_MOD_EQUAL) shift) ((T_MUL_EQUAL) shift) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_OR_EQUAL) shift) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_PLUS_EQUAL) shift) ((T_POW) reduce 367) ((T_POW_EQUAL) shift) ((T_SL) reduce 367) ((T_SL_EQUAL) shift) ((T_SPACESHIP) reduce 367) ((T_SR) reduce 367) ((T_SR_EQUAL) shift) ((T_XOR_EQUAL) shift) (("[") reduce 510) (("^") reduce 367) (("{") reduce 510) (("|") reduce 367)) 124 ((("!") reduce 140) (("\"") reduce 140) (("$") reduce 140) (("(") reduce 140) (("+") reduce 140) (("-") reduce 140) ((";") reduce 140) (("@") reduce 140) ((T_ABSTRACT) reduce 140) ((T_ARRAY) reduce 140) ((T_ARRAY_CAST) reduce 140) ((T_ATTRIBUTE) reduce 140) ((T_BOOL_CAST) reduce 140) ((T_BREAK) reduce 140) ((T_CLASS) reduce 140) ((T_CLASS_C) reduce 140) ((T_CLONE) reduce 140) ((T_CONSTANT_ENCAPSED_STRING) reduce 140) ((T_CONTINUE) reduce 140) ((T_DEC) reduce 140) ((T_DECLARE) reduce 140) ((T_DIR) reduce 140) ((T_DNUMBER) reduce 140) ((T_DO) reduce 140) ((T_DOUBLE_CAST) reduce 140) ((T_ECHO) reduce 140) ((T_EMPTY) reduce 140) ((T_ENUM) reduce 140) ((T_EVAL) reduce 140) ((T_EXIT) reduce 140) ((T_FILE) reduce 140) ((T_FINAL) reduce 140) ((T_FN) reduce 140) ((T_FOR) reduce 140) ((T_FOREACH) reduce 140) ((T_FUNCTION) reduce 140) ((T_FUNC_C) reduce 140) ((T_GLOBAL) reduce 140) ((T_GOTO) reduce 140) ((T_HALT_COMPILER) reduce 140) ((T_IF) reduce 140) ((T_INC) reduce 140) ((T_INCLUDE) reduce 140) ((T_INCLUDE_ONCE) reduce 140) ((T_INLINE_HTML) reduce 140) ((T_INTERFACE) reduce 140) ((T_INT_CAST) reduce 140) ((T_ISSET) reduce 140) ((T_LINE) reduce 140) ((T_LIST) reduce 140) ((T_LNUMBER) reduce 140) ((T_MATCH) reduce 140) ((T_METHOD_C) reduce 140) ((T_NAME_FULLY_QUALIFIED) reduce 140) ((T_NAME_QUALIFIED) reduce 140) ((T_NAME_RELATIVE) reduce 140) ((T_NEW) reduce 140) ((T_NS_C) reduce 140) ((T_OBJECT_CAST) reduce 140) ((T_PRINT) reduce 140) ((T_READONLY) reduce 140) ((T_REQUIRE) reduce 140) ((T_REQUIRE_ONCE) reduce 140) ((T_RETURN) reduce 140) ((T_START_HEREDOC) reduce 140) ((T_STATIC) reduce 140) ((T_STRING) reduce 140) ((T_STRING_CAST) reduce 140) ((T_SWITCH) reduce 140) ((T_THROW) reduce 140) ((T_TRAIT) reduce 140) ((T_TRAIT_C) reduce 140) ((T_TRY) reduce 140) ((T_UNSET) reduce 140) ((T_UNSET_CAST) reduce 140) ((T_VARIABLE) reduce 140) ((T_WHILE) reduce 140) ((T_YIELD) reduce 140) ((T_YIELD_FROM) reduce 140) (("[") reduce 140) (("`") reduce 140) (("{") reduce 140) (("}") reduce 140) (("~") reduce 140)) 127 ((("(") reduce 453) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 453) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 453)) 129 (((T_FN) shift) ((T_FUNCTION) shift) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470)) 130 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) ((";") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 91) ((T_OBJECT_OPERATOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("[") reduce 91) (("^") reduce 91) (("{") reduce 91) (("|") reduce 91)) 131 (((T_ATTRIBUTE) reduce 100) ((T_FN) reduce 100) ((T_FUNCTION) reduce 100) ((T_STATIC) reduce 100)) 132 (((T_ATTRIBUTE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_STATIC) shift)) 133 ((("%") reduce 411) (("*") reduce 411) (("+") reduce 411) (("-") reduce 411) ((".") reduce 411) (("/") reduce 411) ((";") reduce 411) (("<") reduce 411) ((">") reduce 411) (("?") reduce 411) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_BOOLEAN_AND) reduce 411) ((T_BOOLEAN_OR) reduce 411) ((T_COALESCE) reduce 411) ((T_INSTANCEOF) reduce 411) ((T_IS_EQUAL) reduce 411) ((T_IS_GREATER_OR_EQUAL) reduce 411) ((T_IS_IDENTICAL) reduce 411) ((T_IS_NOT_EQUAL) reduce 411) ((T_IS_NOT_IDENTICAL) reduce 411) ((T_IS_SMALLER_OR_EQUAL) reduce 411) ((T_LOGICAL_AND) reduce 411) ((T_LOGICAL_OR) reduce 411) ((T_LOGICAL_XOR) reduce 411) ((T_POW) shift) ((T_SL) reduce 411) ((T_SPACESHIP) reduce 411) ((T_SR) reduce 411) (("^") reduce 411) (("|") reduce 411)) 135 ((("(") reduce 79)) 136 ((("(") reduce 80)) 137 ((("(") reduce 458)) 138 ((("(") reduce 454)) 140 ((("(") reduce 255) ((")") reduce 250) (("?") reduce 255) ((T_ABSTRACT) shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 255) ((T_ARRAY) reduce 255) ((T_ATTRIBUTE) shift) ((T_CALLABLE) reduce 255) ((T_ELLIPSIS) reduce 255) ((T_FINAL) shift) ((T_NAME_FULLY_QUALIFIED) reduce 255) ((T_NAME_QUALIFIED) reduce 255) ((T_NAME_RELATIVE) reduce 255) ((T_PRIVATE) shift) ((T_PROTECTED) shift) ((T_PUBLIC) shift) ((T_READONLY) shift) ((T_STATIC) shift) ((T_STRING) reduce 255) ((T_VARIABLE) reduce 255)) 141 ((("(") reduce 344) (("?") reduce 344) ((T_ABSTRACT) reduce 344) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 344) ((T_ARRAY) reduce 344) ((T_CALLABLE) reduce 344) ((T_ELLIPSIS) reduce 344) ((T_FINAL) reduce 344) ((T_NAME_FULLY_QUALIFIED) reduce 344) ((T_NAME_QUALIFIED) reduce 344) ((T_NAME_RELATIVE) reduce 344) ((T_PRIVATE) reduce 344) ((T_PROTECTED) reduce 344) ((T_PUBLIC) reduce 344) ((T_READONLY) reduce 344) ((T_STATIC) reduce 344) ((T_STRING) reduce 344) ((T_VARIABLE) reduce 344)) 143 ((("(") reduce 345) (("?") reduce 345) ((T_ABSTRACT) reduce 345) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 345) ((T_ARRAY) reduce 345) ((T_CALLABLE) reduce 345) ((T_ELLIPSIS) reduce 345) ((T_FINAL) reduce 345) ((T_NAME_FULLY_QUALIFIED) reduce 345) ((T_NAME_QUALIFIED) reduce 345) ((T_NAME_RELATIVE) reduce 345) ((T_PRIVATE) reduce 345) ((T_PROTECTED) reduce 345) ((T_PUBLIC) reduce 345) ((T_READONLY) reduce 345) ((T_STATIC) reduce 345) ((T_STRING) reduce 345) ((T_VARIABLE) reduce 345)) 144 ((("(") reduce 342) (("?") reduce 342) ((T_ABSTRACT) reduce 342) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 342) ((T_ARRAY) reduce 342) ((T_CALLABLE) reduce 342) ((T_ELLIPSIS) reduce 342) ((T_FINAL) reduce 342) ((T_NAME_FULLY_QUALIFIED) reduce 342) ((T_NAME_QUALIFIED) reduce 342) ((T_NAME_RELATIVE) reduce 342) ((T_PRIVATE) reduce 342) ((T_PROTECTED) reduce 342) ((T_PUBLIC) reduce 342) ((T_READONLY) reduce 342) ((T_STATIC) reduce 342) ((T_STRING) reduce 342) ((T_VARIABLE) reduce 342)) 145 ((("(") reduce 341) (("?") reduce 341) ((T_ABSTRACT) reduce 341) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 341) ((T_ARRAY) reduce 341) ((T_CALLABLE) reduce 341) ((T_ELLIPSIS) reduce 341) ((T_FINAL) reduce 341) ((T_NAME_FULLY_QUALIFIED) reduce 341) ((T_NAME_QUALIFIED) reduce 341) ((T_NAME_RELATIVE) reduce 341) ((T_PRIVATE) reduce 341) ((T_PROTECTED) reduce 341) ((T_PUBLIC) reduce 341) ((T_READONLY) reduce 341) ((T_STATIC) reduce 341) ((T_STRING) reduce 341) ((T_VARIABLE) reduce 341)) 146 ((("(") reduce 340) (("?") reduce 340) ((T_ABSTRACT) reduce 340) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 340) ((T_ARRAY) reduce 340) ((T_CALLABLE) reduce 340) ((T_ELLIPSIS) reduce 340) ((T_FINAL) reduce 340) ((T_NAME_FULLY_QUALIFIED) reduce 340) ((T_NAME_QUALIFIED) reduce 340) ((T_NAME_RELATIVE) reduce 340) ((T_PRIVATE) reduce 340) ((T_PROTECTED) reduce 340) ((T_PUBLIC) reduce 340) ((T_READONLY) reduce 340) ((T_STATIC) reduce 340) ((T_STRING) reduce 340) ((T_VARIABLE) reduce 340)) 147 ((("(") reduce 346) (("?") reduce 346) ((T_ABSTRACT) reduce 346) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 346) ((T_ARRAY) reduce 346) ((T_CALLABLE) reduce 346) ((T_ELLIPSIS) reduce 346) ((T_FINAL) reduce 346) ((T_NAME_FULLY_QUALIFIED) reduce 346) ((T_NAME_QUALIFIED) reduce 346) ((T_NAME_RELATIVE) reduce 346) ((T_PRIVATE) reduce 346) ((T_PROTECTED) reduce 346) ((T_PUBLIC) reduce 346) ((T_READONLY) reduce 346) ((T_STATIC) reduce 346) ((T_STRING) reduce 346) ((T_VARIABLE) reduce 346)) 148 ((("(") reduce 343) (("?") reduce 343) ((T_ABSTRACT) reduce 343) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 343) ((T_ARRAY) reduce 343) ((T_CALLABLE) reduce 343) ((T_ELLIPSIS) reduce 343) ((T_FINAL) reduce 343) ((T_NAME_FULLY_QUALIFIED) reduce 343) ((T_NAME_QUALIFIED) reduce 343) ((T_NAME_RELATIVE) reduce 343) ((T_PRIVATE) reduce 343) ((T_PROTECTED) reduce 343) ((T_PUBLIC) reduce 343) ((T_READONLY) reduce 343) ((T_STATIC) reduce 343) ((T_STRING) reduce 343) ((T_VARIABLE) reduce 343)) 149 ((("(") reduce 100) (("?") reduce 100) ((T_ABSTRACT) reduce 100) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 100) ((T_ARRAY) reduce 100) ((T_ATTRIBUTE) reduce 100) ((T_CALLABLE) reduce 100) ((T_ELLIPSIS) reduce 100) ((T_FINAL) reduce 100) ((T_NAME_FULLY_QUALIFIED) reduce 100) ((T_NAME_QUALIFIED) reduce 100) ((T_NAME_RELATIVE) reduce 100) ((T_PRIVATE) reduce 100) ((T_PROTECTED) reduce 100) ((T_PUBLIC) reduce 100) ((T_READONLY) reduce 100) ((T_STATIC) reduce 100) ((T_STRING) reduce 100) ((T_VARIABLE) reduce 100)) 150 (((")") reduce 251) ((",") reduce 251)) 151 ((("(") reduce 255) (("?") reduce 255) ((T_ABSTRACT) shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 255) ((T_ARRAY) reduce 255) ((T_ATTRIBUTE) shift) ((T_CALLABLE) reduce 255) ((T_ELLIPSIS) reduce 255) ((T_FINAL) shift) ((T_NAME_FULLY_QUALIFIED) reduce 255) ((T_NAME_QUALIFIED) reduce 255) ((T_NAME_RELATIVE) reduce 255) ((T_PRIVATE) shift) ((T_PROTECTED) shift) ((T_PUBLIC) shift) ((T_READONLY) shift) ((T_STATIC) shift) ((T_STRING) reduce 255) ((T_VARIABLE) reduce 255)) 152 ((("(") reduce 338) (("?") reduce 338) ((T_ABSTRACT) reduce 338) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 338) ((T_ARRAY) reduce 338) ((T_CALLABLE) reduce 338) ((T_ELLIPSIS) reduce 338) ((T_FINAL) reduce 338) ((T_NAME_FULLY_QUALIFIED) reduce 338) ((T_NAME_QUALIFIED) reduce 338) ((T_NAME_RELATIVE) reduce 338) ((T_PRIVATE) reduce 338) ((T_PROTECTED) reduce 338) ((T_PUBLIC) reduce 338) ((T_READONLY) reduce 338) ((T_STATIC) reduce 338) ((T_STRING) reduce 338) ((T_VARIABLE) reduce 338)) 153 ((("(") reduce 256) (("?") reduce 256) ((T_ABSTRACT) shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 256) ((T_ARRAY) reduce 256) ((T_CALLABLE) reduce 256) ((T_ELLIPSIS) reduce 256) ((T_FINAL) shift) ((T_NAME_FULLY_QUALIFIED) reduce 256) ((T_NAME_QUALIFIED) reduce 256) ((T_NAME_RELATIVE) reduce 256) ((T_PRIVATE) shift) ((T_PROTECTED) shift) ((T_PUBLIC) shift) ((T_READONLY) shift) ((T_STATIC) shift) ((T_STRING) reduce 256) ((T_VARIABLE) reduce 256)) 154 (((")") reduce 123) ((",") shift)) 155 ((("(") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 259) ((T_ARRAY) shift) ((T_CALLABLE) shift) ((T_ELLIPSIS) reduce 259) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_STRING) shift) ((T_VARIABLE) reduce 259)) 156 (((")") reduce 254) ((",") reduce 254)) 157 (((")") shift)) 158 (((":") reduce 459) ((T_USE) shift) (("{") reduce 459)) 160 (((":") shift) (("{") reduce 286)) 161 ((("(") shift) (("?") shift) ((T_ARRAY) shift) ((T_CALLABLE) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_STATIC) shift) ((T_STRING) shift)) 162 ((("{") reduce 455)) 165 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) (("+") shift) (("-") shift) ((";") shift) (("@") shift) ((T_ABSTRACT) shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_BREAK) shift) ((T_CLASS) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_CONTINUE) shift) ((T_DEC) shift) ((T_DECLARE) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DO) shift) ((T_DOUBLE_CAST) shift) ((T_ECHO) shift) ((T_EMPTY) shift) ((T_ENUM) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FINAL) shift) ((T_FN) shift) ((T_FOR) shift) ((T_FOREACH) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_GLOBAL) shift) ((T_GOTO) shift) ((T_HALT_COMPILER) shift) ((T_IF) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INLINE_HTML) shift) ((T_INTERFACE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_RETURN) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_SWITCH) shift) ((T_THROW) shift) ((T_TRAIT) shift) ((T_TRAIT_C) shift) ((T_TRY) shift) ((T_UNSET) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_WHILE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("{") shift) (("}") shift) (("~") shift)) 166 ((("!") reduce 164) (("\"") reduce 164) (("$") reduce 164) (("(") reduce 164) (("+") reduce 164) (("-") reduce 164) ((";") reduce 164) (("@") reduce 164) ((T_ABSTRACT) reduce 164) ((T_ARRAY) reduce 164) ((T_ARRAY_CAST) reduce 164) ((T_ATTRIBUTE) reduce 164) ((T_BOOL_CAST) reduce 164) ((T_BREAK) reduce 164) ((T_CLASS) reduce 164) ((T_CLASS_C) reduce 164) ((T_CLONE) reduce 164) ((T_CONSTANT_ENCAPSED_STRING) reduce 164) ((T_CONTINUE) reduce 164) ((T_DEC) reduce 164) ((T_DECLARE) reduce 164) ((T_DIR) reduce 164) ((T_DNUMBER) reduce 164) ((T_DO) reduce 164) ((T_DOUBLE_CAST) reduce 164) ((T_ECHO) reduce 164) ((T_EMPTY) reduce 164) ((T_ENUM) reduce 164) ((T_EVAL) reduce 164) ((T_EXIT) reduce 164) ((T_FILE) reduce 164) ((T_FINAL) reduce 164) ((T_FN) reduce 164) ((T_FOR) reduce 164) ((T_FOREACH) reduce 164) ((T_FUNCTION) reduce 164) ((T_FUNC_C) reduce 164) ((T_GLOBAL) reduce 164) ((T_GOTO) reduce 164) ((T_HALT_COMPILER) reduce 164) ((T_IF) reduce 164) ((T_INC) reduce 164) ((T_INCLUDE) reduce 164) ((T_INCLUDE_ONCE) reduce 164) ((T_INLINE_HTML) reduce 164) ((T_INTERFACE) reduce 164) ((T_INT_CAST) reduce 164) ((T_ISSET) reduce 164) ((T_LINE) reduce 164) ((T_LIST) reduce 164) ((T_LNUMBER) reduce 164) ((T_MATCH) reduce 164) ((T_METHOD_C) reduce 164) ((T_NAME_FULLY_QUALIFIED) reduce 164) ((T_NAME_QUALIFIED) reduce 164) ((T_NAME_RELATIVE) reduce 164) ((T_NEW) reduce 164) ((T_NS_C) reduce 164) ((T_OBJECT_CAST) reduce 164) ((T_PRINT) reduce 164) ((T_READONLY) reduce 164) ((T_REQUIRE) reduce 164) ((T_REQUIRE_ONCE) reduce 164) ((T_RETURN) reduce 164) ((T_START_HEREDOC) reduce 164) ((T_STATIC) reduce 164) ((T_STRING) reduce 164) ((T_STRING_CAST) reduce 164) ((T_SWITCH) reduce 164) ((T_THROW) reduce 164) ((T_TRAIT) reduce 164) ((T_TRAIT_C) reduce 164) ((T_TRY) reduce 164) ((T_UNSET) reduce 164) ((T_UNSET_CAST) reduce 164) ((T_VARIABLE) reduce 164) ((T_WHILE) reduce 164) ((T_YIELD) reduce 164) ((T_YIELD_FROM) reduce 164) (("[") reduce 164) (("`") reduce 164) (("{") reduce 164) (("}") reduce 164) (("~") reduce 164)) 180 ((("!") reduce 158) (("\"") reduce 158) (("$") reduce 158) (("(") reduce 158) (("+") reduce 158) (("-") reduce 158) ((";") reduce 158) (("@") reduce 158) ((T_ABSTRACT) reduce 158) ((T_ARRAY) reduce 158) ((T_ARRAY_CAST) reduce 158) ((T_ATTRIBUTE) reduce 158) ((T_BOOL_CAST) reduce 158) ((T_BREAK) reduce 158) ((T_CLASS) reduce 158) ((T_CLASS_C) reduce 158) ((T_CLONE) reduce 158) ((T_CONSTANT_ENCAPSED_STRING) reduce 158) ((T_CONTINUE) reduce 158) ((T_DEC) reduce 158) ((T_DECLARE) reduce 158) ((T_DIR) reduce 158) ((T_DNUMBER) reduce 158) ((T_DO) reduce 158) ((T_DOUBLE_CAST) reduce 158) ((T_ECHO) reduce 158) ((T_EMPTY) reduce 158) ((T_ENUM) reduce 158) ((T_EVAL) reduce 158) ((T_EXIT) reduce 158) ((T_FILE) reduce 158) ((T_FINAL) reduce 158) ((T_FN) reduce 158) ((T_FOR) reduce 158) ((T_FOREACH) reduce 158) ((T_FUNCTION) reduce 158) ((T_FUNC_C) reduce 158) ((T_GLOBAL) reduce 158) ((T_GOTO) reduce 158) ((T_HALT_COMPILER) reduce 158) ((T_IF) reduce 158) ((T_INC) reduce 158) ((T_INCLUDE) reduce 158) ((T_INCLUDE_ONCE) reduce 158) ((T_INLINE_HTML) reduce 158) ((T_INTERFACE) reduce 158) ((T_INT_CAST) reduce 158) ((T_ISSET) reduce 158) ((T_LINE) reduce 158) ((T_LIST) reduce 158) ((T_LNUMBER) reduce 158) ((T_MATCH) reduce 158) ((T_METHOD_C) reduce 158) ((T_NAME_FULLY_QUALIFIED) reduce 158) ((T_NAME_QUALIFIED) reduce 158) ((T_NAME_RELATIVE) reduce 158) ((T_NEW) reduce 158) ((T_NS_C) reduce 158) ((T_OBJECT_CAST) reduce 158) ((T_PRINT) reduce 158) ((T_READONLY) reduce 158) ((T_REQUIRE) reduce 158) ((T_REQUIRE_ONCE) reduce 158) ((T_RETURN) reduce 158) ((T_START_HEREDOC) reduce 158) ((T_STATIC) reduce 158) ((T_STRING) reduce 158) ((T_STRING_CAST) reduce 158) ((T_SWITCH) reduce 158) ((T_THROW) reduce 158) ((T_TRAIT) reduce 158) ((T_TRAIT_C) reduce 158) ((T_TRY) reduce 158) ((T_UNSET) reduce 158) ((T_UNSET_CAST) reduce 158) ((T_VARIABLE) reduce 158) ((T_WHILE) reduce 158) ((T_YIELD) reduce 158) ((T_YIELD_FROM) reduce 158) (("[") reduce 158) (("`") reduce 158) (("{") reduce 158) (("}") reduce 158) (("~") reduce 158)) 190 ((("!") reduce 147) (("\"") reduce 147) (("$") reduce 147) (("(") reduce 147) (("+") reduce 147) (("-") reduce 147) ((";") reduce 147) (("@") reduce 147) ((T_ABSTRACT) reduce 147) ((T_ARRAY) reduce 147) ((T_ARRAY_CAST) reduce 147) ((T_ATTRIBUTE) reduce 147) ((T_BOOL_CAST) reduce 147) ((T_BREAK) reduce 147) ((T_CLASS) reduce 147) ((T_CLASS_C) reduce 147) ((T_CLONE) reduce 147) ((T_CONSTANT_ENCAPSED_STRING) reduce 147) ((T_CONTINUE) reduce 147) ((T_DEC) reduce 147) ((T_DECLARE) reduce 147) ((T_DIR) reduce 147) ((T_DNUMBER) reduce 147) ((T_DO) reduce 147) ((T_DOUBLE_CAST) reduce 147) ((T_ECHO) reduce 147) ((T_EMPTY) reduce 147) ((T_ENUM) reduce 147) ((T_EVAL) reduce 147) ((T_EXIT) reduce 147) ((T_FILE) reduce 147) ((T_FINAL) reduce 147) ((T_FN) reduce 147) ((T_FOR) reduce 147) ((T_FOREACH) reduce 147) ((T_FUNCTION) reduce 147) ((T_FUNC_C) reduce 147) ((T_GLOBAL) reduce 147) ((T_GOTO) reduce 147) ((T_HALT_COMPILER) reduce 147) ((T_IF) reduce 147) ((T_INC) reduce 147) ((T_INCLUDE) reduce 147) ((T_INCLUDE_ONCE) reduce 147) ((T_INLINE_HTML) reduce 147) ((T_INTERFACE) reduce 147) ((T_INT_CAST) reduce 147) ((T_ISSET) reduce 147) ((T_LINE) reduce 147) ((T_LIST) reduce 147) ((T_LNUMBER) reduce 147) ((T_MATCH) reduce 147) ((T_METHOD_C) reduce 147) ((T_NAME_FULLY_QUALIFIED) reduce 147) ((T_NAME_QUALIFIED) reduce 147) ((T_NAME_RELATIVE) reduce 147) ((T_NEW) reduce 147) ((T_NS_C) reduce 147) ((T_OBJECT_CAST) reduce 147) ((T_PRINT) reduce 147) ((T_READONLY) reduce 147) ((T_REQUIRE) reduce 147) ((T_REQUIRE_ONCE) reduce 147) ((T_RETURN) reduce 147) ((T_START_HEREDOC) reduce 147) ((T_STATIC) reduce 147) ((T_STRING) reduce 147) ((T_STRING_CAST) reduce 147) ((T_SWITCH) reduce 147) ((T_THROW) reduce 147) ((T_TRAIT) reduce 147) ((T_TRAIT_C) reduce 147) ((T_TRY) reduce 147) ((T_UNSET) reduce 147) ((T_UNSET_CAST) reduce 147) ((T_VARIABLE) reduce 147) ((T_WHILE) reduce 147) ((T_YIELD) reduce 147) ((T_YIELD_FROM) reduce 147) (("[") reduce 147) (("`") reduce 147) (("{") reduce 147) (("}") reduce 147) (("~") reduce 147)) 192 ((("!") reduce 142) (("\"") reduce 142) (("$") reduce 142) (("(") reduce 142) (("+") reduce 142) (("-") reduce 142) ((";") reduce 142) (("@") reduce 142) ((T_ABSTRACT) reduce 142) ((T_ARRAY) reduce 142) ((T_ARRAY_CAST) reduce 142) ((T_ATTRIBUTE) reduce 142) ((T_BOOL_CAST) reduce 142) ((T_BREAK) reduce 142) ((T_CLASS) reduce 142) ((T_CLASS_C) reduce 142) ((T_CLONE) reduce 142) ((T_CONSTANT_ENCAPSED_STRING) reduce 142) ((T_CONTINUE) reduce 142) ((T_DEC) reduce 142) ((T_DECLARE) reduce 142) ((T_DIR) reduce 142) ((T_DNUMBER) reduce 142) ((T_DO) reduce 142) ((T_DOUBLE_CAST) reduce 142) ((T_ECHO) reduce 142) ((T_EMPTY) reduce 142) ((T_ENUM) reduce 142) ((T_EVAL) reduce 142) ((T_EXIT) reduce 142) ((T_FILE) reduce 142) ((T_FINAL) reduce 142) ((T_FN) reduce 142) ((T_FOR) reduce 142) ((T_FOREACH) reduce 142) ((T_FUNCTION) reduce 142) ((T_FUNC_C) reduce 142) ((T_GLOBAL) reduce 142) ((T_GOTO) reduce 142) ((T_HALT_COMPILER) reduce 142) ((T_IF) reduce 142) ((T_INC) reduce 142) ((T_INCLUDE) reduce 142) ((T_INCLUDE_ONCE) reduce 142) ((T_INLINE_HTML) reduce 142) ((T_INTERFACE) reduce 142) ((T_INT_CAST) reduce 142) ((T_ISSET) reduce 142) ((T_LINE) reduce 142) ((T_LIST) reduce 142) ((T_LNUMBER) reduce 142) ((T_MATCH) reduce 142) ((T_METHOD_C) reduce 142) ((T_NAME_FULLY_QUALIFIED) reduce 142) ((T_NAME_QUALIFIED) reduce 142) ((T_NAME_RELATIVE) reduce 142) ((T_NEW) reduce 142) ((T_NS_C) reduce 142) ((T_OBJECT_CAST) reduce 142) ((T_PRINT) reduce 142) ((T_READONLY) reduce 142) ((T_REQUIRE) reduce 142) ((T_REQUIRE_ONCE) reduce 142) ((T_RETURN) reduce 142) ((T_START_HEREDOC) reduce 142) ((T_STATIC) reduce 142) ((T_STRING) reduce 142) ((T_STRING_CAST) reduce 142) ((T_SWITCH) reduce 142) ((T_THROW) reduce 142) ((T_TRAIT) reduce 142) ((T_TRAIT_C) reduce 142) ((T_TRY) reduce 142) ((T_UNSET) reduce 142) ((T_UNSET_CAST) reduce 142) ((T_VARIABLE) reduce 142) ((T_WHILE) reduce 142) ((T_YIELD) reduce 142) ((T_YIELD_FROM) reduce 142) (("[") reduce 142) (("`") reduce 142) (("{") reduce 142) (("}") reduce 142) (("~") reduce 142)) 194 ((("!") reduce 103) (("\"") reduce 103) (("$") reduce 103) (("(") reduce 103) (("+") reduce 103) (("-") reduce 103) ((";") reduce 103) (("@") reduce 103) ((T_ABSTRACT) reduce 103) ((T_ARRAY) reduce 103) ((T_ARRAY_CAST) reduce 103) ((T_ATTRIBUTE) reduce 103) ((T_BOOL_CAST) reduce 103) ((T_BREAK) reduce 103) ((T_CLASS) reduce 103) ((T_CLASS_C) reduce 103) ((T_CLONE) reduce 103) ((T_CONSTANT_ENCAPSED_STRING) reduce 103) ((T_CONTINUE) reduce 103) ((T_DEC) reduce 103) ((T_DECLARE) reduce 103) ((T_DIR) reduce 103) ((T_DNUMBER) reduce 103) ((T_DO) reduce 103) ((T_DOUBLE_CAST) reduce 103) ((T_ECHO) reduce 103) ((T_EMPTY) reduce 103) ((T_ENUM) reduce 103) ((T_EVAL) reduce 103) ((T_EXIT) reduce 103) ((T_FILE) reduce 103) ((T_FINAL) reduce 103) ((T_FN) reduce 103) ((T_FOR) reduce 103) ((T_FOREACH) reduce 103) ((T_FUNCTION) reduce 103) ((T_FUNC_C) reduce 103) ((T_GLOBAL) reduce 103) ((T_GOTO) reduce 103) ((T_HALT_COMPILER) reduce 103) ((T_IF) reduce 103) ((T_INC) reduce 103) ((T_INCLUDE) reduce 103) ((T_INCLUDE_ONCE) reduce 103) ((T_INLINE_HTML) reduce 103) ((T_INTERFACE) reduce 103) ((T_INT_CAST) reduce 103) ((T_ISSET) reduce 103) ((T_LINE) reduce 103) ((T_LIST) reduce 103) ((T_LNUMBER) reduce 103) ((T_MATCH) reduce 103) ((T_METHOD_C) reduce 103) ((T_NAME_FULLY_QUALIFIED) reduce 103) ((T_NAME_QUALIFIED) reduce 103) ((T_NAME_RELATIVE) reduce 103) ((T_NEW) reduce 103) ((T_NS_C) reduce 103) ((T_OBJECT_CAST) reduce 103) ((T_PRINT) reduce 103) ((T_READONLY) reduce 103) ((T_REQUIRE) reduce 103) ((T_REQUIRE_ONCE) reduce 103) ((T_RETURN) reduce 103) ((T_START_HEREDOC) reduce 103) ((T_STATIC) reduce 103) ((T_STRING) reduce 103) ((T_STRING_CAST) reduce 103) ((T_SWITCH) reduce 103) ((T_THROW) reduce 103) ((T_TRAIT) reduce 103) ((T_TRAIT_C) reduce 103) ((T_TRY) reduce 103) ((T_UNSET) reduce 103) ((T_UNSET_CAST) reduce 103) ((T_VARIABLE) reduce 103) ((T_WHILE) reduce 103) ((T_YIELD) reduce 103) ((T_YIELD_FROM) reduce 103) (("[") reduce 103) (("`") reduce 103) (("{") reduce 103) (("}") reduce 103) (("~") reduce 103)) 196 ((("!") reduce 106) (("\"") reduce 106) (("$") reduce 106) (("(") reduce 106) (("+") reduce 106) (("-") reduce 106) ((";") reduce 106) (("@") reduce 106) ((T_ABSTRACT) reduce 106) ((T_ARRAY) reduce 106) ((T_ARRAY_CAST) reduce 106) ((T_ATTRIBUTE) reduce 106) ((T_BOOL_CAST) reduce 106) ((T_BREAK) reduce 106) ((T_CLASS) reduce 106) ((T_CLASS_C) reduce 106) ((T_CLONE) reduce 106) ((T_CONSTANT_ENCAPSED_STRING) reduce 106) ((T_CONTINUE) reduce 106) ((T_DEC) reduce 106) ((T_DECLARE) reduce 106) ((T_DIR) reduce 106) ((T_DNUMBER) reduce 106) ((T_DO) reduce 106) ((T_DOUBLE_CAST) reduce 106) ((T_ECHO) reduce 106) ((T_EMPTY) reduce 106) ((T_ENUM) reduce 106) ((T_EVAL) reduce 106) ((T_EXIT) reduce 106) ((T_FILE) reduce 106) ((T_FINAL) reduce 106) ((T_FN) reduce 106) ((T_FOR) reduce 106) ((T_FOREACH) reduce 106) ((T_FUNCTION) reduce 106) ((T_FUNC_C) reduce 106) ((T_GLOBAL) reduce 106) ((T_GOTO) reduce 106) ((T_HALT_COMPILER) reduce 106) ((T_IF) reduce 106) ((T_INC) reduce 106) ((T_INCLUDE) reduce 106) ((T_INCLUDE_ONCE) reduce 106) ((T_INLINE_HTML) reduce 106) ((T_INTERFACE) reduce 106) ((T_INT_CAST) reduce 106) ((T_ISSET) reduce 106) ((T_LINE) reduce 106) ((T_LIST) reduce 106) ((T_LNUMBER) reduce 106) ((T_MATCH) reduce 106) ((T_METHOD_C) reduce 106) ((T_NAME_FULLY_QUALIFIED) reduce 106) ((T_NAME_QUALIFIED) reduce 106) ((T_NAME_RELATIVE) reduce 106) ((T_NEW) reduce 106) ((T_NS_C) reduce 106) ((T_OBJECT_CAST) reduce 106) ((T_PRINT) reduce 106) ((T_READONLY) reduce 106) ((T_REQUIRE) reduce 106) ((T_REQUIRE_ONCE) reduce 106) ((T_RETURN) reduce 106) ((T_START_HEREDOC) reduce 106) ((T_STATIC) reduce 106) ((T_STRING) reduce 106) ((T_STRING_CAST) reduce 106) ((T_SWITCH) reduce 106) ((T_THROW) reduce 106) ((T_TRAIT) reduce 106) ((T_TRAIT_C) reduce 106) ((T_TRY) reduce 106) ((T_UNSET) reduce 106) ((T_UNSET_CAST) reduce 106) ((T_VARIABLE) reduce 106) ((T_WHILE) reduce 106) ((T_YIELD) reduce 106) ((T_YIELD_FROM) reduce 106) (("[") reduce 106) (("`") reduce 106) (("{") reduce 106) (("}") reduce 106) (("~") reduce 106)) 199 ((("!") reduce 102) (("\"") reduce 102) (("$") reduce 102) (("(") reduce 102) (("+") reduce 102) (("-") reduce 102) ((";") reduce 102) (("@") reduce 102) ((T_ABSTRACT) reduce 102) ((T_ARRAY) reduce 102) ((T_ARRAY_CAST) reduce 102) ((T_ATTRIBUTE) reduce 102) ((T_BOOL_CAST) reduce 102) ((T_BREAK) reduce 102) ((T_CLASS) reduce 102) ((T_CLASS_C) reduce 102) ((T_CLONE) reduce 102) ((T_CONSTANT_ENCAPSED_STRING) reduce 102) ((T_CONTINUE) reduce 102) ((T_DEC) reduce 102) ((T_DECLARE) reduce 102) ((T_DIR) reduce 102) ((T_DNUMBER) reduce 102) ((T_DO) reduce 102) ((T_DOUBLE_CAST) reduce 102) ((T_ECHO) reduce 102) ((T_EMPTY) reduce 102) ((T_ENUM) reduce 102) ((T_EVAL) reduce 102) ((T_EXIT) reduce 102) ((T_FILE) reduce 102) ((T_FINAL) reduce 102) ((T_FN) reduce 102) ((T_FOR) reduce 102) ((T_FOREACH) reduce 102) ((T_FUNCTION) reduce 102) ((T_FUNC_C) reduce 102) ((T_GLOBAL) reduce 102) ((T_GOTO) reduce 102) ((T_HALT_COMPILER) reduce 102) ((T_IF) reduce 102) ((T_INC) reduce 102) ((T_INCLUDE) reduce 102) ((T_INCLUDE_ONCE) reduce 102) ((T_INLINE_HTML) reduce 102) ((T_INTERFACE) reduce 102) ((T_INT_CAST) reduce 102) ((T_ISSET) reduce 102) ((T_LINE) reduce 102) ((T_LIST) reduce 102) ((T_LNUMBER) reduce 102) ((T_MATCH) reduce 102) ((T_METHOD_C) reduce 102) ((T_NAME_FULLY_QUALIFIED) reduce 102) ((T_NAME_QUALIFIED) reduce 102) ((T_NAME_RELATIVE) reduce 102) ((T_NEW) reduce 102) ((T_NS_C) reduce 102) ((T_OBJECT_CAST) reduce 102) ((T_PRINT) reduce 102) ((T_READONLY) reduce 102) ((T_REQUIRE) reduce 102) ((T_REQUIRE_ONCE) reduce 102) ((T_RETURN) reduce 102) ((T_START_HEREDOC) reduce 102) ((T_STATIC) reduce 102) ((T_STRING) reduce 102) ((T_STRING_CAST) reduce 102) ((T_SWITCH) reduce 102) ((T_THROW) reduce 102) ((T_TRAIT) reduce 102) ((T_TRAIT_C) reduce 102) ((T_TRY) reduce 102) ((T_UNSET) reduce 102) ((T_UNSET_CAST) reduce 102) ((T_VARIABLE) reduce 102) ((T_WHILE) reduce 102) ((T_YIELD) reduce 102) ((T_YIELD_FROM) reduce 102) (("[") reduce 102) (("`") reduce 102) (("{") reduce 102) (("}") reduce 102) (("~") reduce 102)) 200 ((("!") reduce 146) (("\"") reduce 146) (("$") reduce 146) (("(") reduce 146) (("+") reduce 146) (("-") reduce 146) ((";") reduce 146) (("@") reduce 146) ((T_ABSTRACT) reduce 146) ((T_ARRAY) reduce 146) ((T_ARRAY_CAST) reduce 146) ((T_ATTRIBUTE) reduce 146) ((T_BOOL_CAST) reduce 146) ((T_BREAK) reduce 146) ((T_CLASS) reduce 146) ((T_CLASS_C) reduce 146) ((T_CLONE) reduce 146) ((T_CONSTANT_ENCAPSED_STRING) reduce 146) ((T_CONTINUE) reduce 146) ((T_DEC) reduce 146) ((T_DECLARE) reduce 146) ((T_DIR) reduce 146) ((T_DNUMBER) reduce 146) ((T_DO) reduce 146) ((T_DOUBLE_CAST) reduce 146) ((T_ECHO) reduce 146) ((T_EMPTY) reduce 146) ((T_ENUM) reduce 146) ((T_EVAL) reduce 146) ((T_EXIT) reduce 146) ((T_FILE) reduce 146) ((T_FINAL) reduce 146) ((T_FN) reduce 146) ((T_FOR) reduce 146) ((T_FOREACH) reduce 146) ((T_FUNCTION) reduce 146) ((T_FUNC_C) reduce 146) ((T_GLOBAL) reduce 146) ((T_GOTO) reduce 146) ((T_HALT_COMPILER) reduce 146) ((T_IF) reduce 146) ((T_INC) reduce 146) ((T_INCLUDE) reduce 146) ((T_INCLUDE_ONCE) reduce 146) ((T_INLINE_HTML) reduce 146) ((T_INTERFACE) reduce 146) ((T_INT_CAST) reduce 146) ((T_ISSET) reduce 146) ((T_LINE) reduce 146) ((T_LIST) reduce 146) ((T_LNUMBER) reduce 146) ((T_MATCH) reduce 146) ((T_METHOD_C) reduce 146) ((T_NAME_FULLY_QUALIFIED) reduce 146) ((T_NAME_QUALIFIED) reduce 146) ((T_NAME_RELATIVE) reduce 146) ((T_NEW) reduce 146) ((T_NS_C) reduce 146) ((T_OBJECT_CAST) reduce 146) ((T_PRINT) reduce 146) ((T_READONLY) reduce 146) ((T_REQUIRE) reduce 146) ((T_REQUIRE_ONCE) reduce 146) ((T_RETURN) reduce 146) ((T_START_HEREDOC) reduce 146) ((T_STATIC) reduce 146) ((T_STRING) reduce 146) ((T_STRING_CAST) reduce 146) ((T_SWITCH) reduce 146) ((T_THROW) reduce 146) ((T_TRAIT) reduce 146) ((T_TRAIT_C) reduce 146) ((T_TRY) reduce 146) ((T_UNSET) reduce 146) ((T_UNSET_CAST) reduce 146) ((T_VARIABLE) reduce 146) ((T_WHILE) reduce 146) ((T_YIELD) reduce 146) ((T_YIELD_FROM) reduce 146) (("[") reduce 146) (("`") reduce 146) (("{") reduce 146) (("}") reduce 146) (("~") reduce 146)) 201 ((("!") reduce 243) (("\"") reduce 243) (("$") reduce 243) (("(") reduce 243) (("+") reduce 243) (("-") reduce 243) ((";") reduce 243) (("@") reduce 243) ((T_ABSTRACT) reduce 243) ((T_ARRAY) reduce 243) ((T_ARRAY_CAST) reduce 243) ((T_ATTRIBUTE) reduce 243) ((T_BOOL_CAST) reduce 243) ((T_BREAK) reduce 243) ((T_CLASS) reduce 243) ((T_CLASS_C) reduce 243) ((T_CLONE) reduce 243) ((T_CONSTANT_ENCAPSED_STRING) reduce 243) ((T_CONTINUE) reduce 243) ((T_DEC) reduce 243) ((T_DECLARE) reduce 243) ((T_DIR) reduce 243) ((T_DNUMBER) reduce 243) ((T_DO) reduce 243) ((T_DOUBLE_CAST) reduce 243) ((T_ECHO) reduce 243) ((T_ELSE) shift) ((T_ELSEIF) shift) ((T_EMPTY) reduce 243) ((T_ENUM) reduce 243) ((T_EVAL) reduce 243) ((T_EXIT) reduce 243) ((T_FILE) reduce 243) ((T_FINAL) reduce 243) ((T_FN) reduce 243) ((T_FOR) reduce 243) ((T_FOREACH) reduce 243) ((T_FUNCTION) reduce 243) ((T_FUNC_C) reduce 243) ((T_GLOBAL) reduce 243) ((T_GOTO) reduce 243) ((T_HALT_COMPILER) reduce 243) ((T_IF) reduce 243) ((T_INC) reduce 243) ((T_INCLUDE) reduce 243) ((T_INCLUDE_ONCE) reduce 243) ((T_INLINE_HTML) reduce 243) ((T_INTERFACE) reduce 243) ((T_INT_CAST) reduce 243) ((T_ISSET) reduce 243) ((T_LINE) reduce 243) ((T_LIST) reduce 243) ((T_LNUMBER) reduce 243) ((T_MATCH) reduce 243) ((T_METHOD_C) reduce 243) ((T_NAME_FULLY_QUALIFIED) reduce 243) ((T_NAME_QUALIFIED) reduce 243) ((T_NAME_RELATIVE) reduce 243) ((T_NEW) reduce 243) ((T_NS_C) reduce 243) ((T_OBJECT_CAST) reduce 243) ((T_PRINT) reduce 243) ((T_READONLY) reduce 243) ((T_REQUIRE) reduce 243) ((T_REQUIRE_ONCE) reduce 243) ((T_RETURN) reduce 243) ((T_START_HEREDOC) reduce 243) ((T_STATIC) reduce 243) ((T_STRING) reduce 243) ((T_STRING_CAST) reduce 243) ((T_SWITCH) reduce 243) ((T_THROW) reduce 243) ((T_TRAIT) reduce 243) ((T_TRAIT_C) reduce 243) ((T_TRY) reduce 243) ((T_UNSET) reduce 243) ((T_UNSET_CAST) reduce 243) ((T_VARIABLE) reduce 243) ((T_WHILE) reduce 243) ((T_YIELD) reduce 243) ((T_YIELD_FROM) reduce 243) (("[") reduce 243) (("`") reduce 243) (("{") reduce 243) (("}") reduce 243) (("~") reduce 243)) 202 ((("!") reduce 139) (("\"") reduce 139) (("$") reduce 139) (("(") reduce 139) (("+") reduce 139) (("-") reduce 139) ((";") reduce 139) (("@") reduce 139) ((T_ABSTRACT) reduce 139) ((T_ARRAY) reduce 139) ((T_ARRAY_CAST) reduce 139) ((T_ATTRIBUTE) reduce 139) ((T_BOOL_CAST) reduce 139) ((T_BREAK) reduce 139) ((T_CLASS) reduce 139) ((T_CLASS_C) reduce 139) ((T_CLONE) reduce 139) ((T_CONSTANT_ENCAPSED_STRING) reduce 139) ((T_CONTINUE) reduce 139) ((T_DEC) reduce 139) ((T_DECLARE) reduce 139) ((T_DIR) reduce 139) ((T_DNUMBER) reduce 139) ((T_DO) reduce 139) ((T_DOUBLE_CAST) reduce 139) ((T_ECHO) reduce 139) ((T_EMPTY) reduce 139) ((T_ENUM) reduce 139) ((T_EVAL) reduce 139) ((T_EXIT) reduce 139) ((T_FILE) reduce 139) ((T_FINAL) reduce 139) ((T_FN) reduce 139) ((T_FOR) reduce 139) ((T_FOREACH) reduce 139) ((T_FUNCTION) reduce 139) ((T_FUNC_C) reduce 139) ((T_GLOBAL) reduce 139) ((T_GOTO) reduce 139) ((T_HALT_COMPILER) reduce 139) ((T_IF) reduce 139) ((T_INC) reduce 139) ((T_INCLUDE) reduce 139) ((T_INCLUDE_ONCE) reduce 139) ((T_INLINE_HTML) reduce 139) ((T_INTERFACE) reduce 139) ((T_INT_CAST) reduce 139) ((T_ISSET) reduce 139) ((T_LINE) reduce 139) ((T_LIST) reduce 139) ((T_LNUMBER) reduce 139) ((T_MATCH) reduce 139) ((T_METHOD_C) reduce 139) ((T_NAME_FULLY_QUALIFIED) reduce 139) ((T_NAME_QUALIFIED) reduce 139) ((T_NAME_RELATIVE) reduce 139) ((T_NEW) reduce 139) ((T_NS_C) reduce 139) ((T_OBJECT_CAST) reduce 139) ((T_PRINT) reduce 139) ((T_READONLY) reduce 139) ((T_REQUIRE) reduce 139) ((T_REQUIRE_ONCE) reduce 139) ((T_RETURN) reduce 139) ((T_START_HEREDOC) reduce 139) ((T_STATIC) reduce 139) ((T_STRING) reduce 139) ((T_STRING_CAST) reduce 139) ((T_SWITCH) reduce 139) ((T_THROW) reduce 139) ((T_TRAIT) reduce 139) ((T_TRAIT_C) reduce 139) ((T_TRY) reduce 139) ((T_UNSET) reduce 139) ((T_UNSET_CAST) reduce 139) ((T_VARIABLE) reduce 139) ((T_WHILE) reduce 139) ((T_YIELD) reduce 139) ((T_YIELD_FROM) reduce 139) (("[") reduce 139) (("`") reduce 139) (("{") reduce 139) (("}") reduce 139) (("~") reduce 139)) 203 ((("!") reduce 105) (("\"") reduce 105) (("$") reduce 105) (("(") reduce 105) (("+") reduce 105) (("-") reduce 105) ((";") reduce 105) (("@") reduce 105) ((T_ABSTRACT) reduce 105) ((T_ARRAY) reduce 105) ((T_ARRAY_CAST) reduce 105) ((T_ATTRIBUTE) reduce 105) ((T_BOOL_CAST) reduce 105) ((T_BREAK) reduce 105) ((T_CLASS) reduce 105) ((T_CLASS_C) reduce 105) ((T_CLONE) reduce 105) ((T_CONSTANT_ENCAPSED_STRING) reduce 105) ((T_CONTINUE) reduce 105) ((T_DEC) reduce 105) ((T_DECLARE) reduce 105) ((T_DIR) reduce 105) ((T_DNUMBER) reduce 105) ((T_DO) reduce 105) ((T_DOUBLE_CAST) reduce 105) ((T_ECHO) reduce 105) ((T_EMPTY) reduce 105) ((T_ENUM) reduce 105) ((T_EVAL) reduce 105) ((T_EXIT) reduce 105) ((T_FILE) reduce 105) ((T_FINAL) reduce 105) ((T_FN) reduce 105) ((T_FOR) reduce 105) ((T_FOREACH) reduce 105) ((T_FUNCTION) reduce 105) ((T_FUNC_C) reduce 105) ((T_GLOBAL) reduce 105) ((T_GOTO) reduce 105) ((T_HALT_COMPILER) reduce 105) ((T_IF) reduce 105) ((T_INC) reduce 105) ((T_INCLUDE) reduce 105) ((T_INCLUDE_ONCE) reduce 105) ((T_INLINE_HTML) reduce 105) ((T_INTERFACE) reduce 105) ((T_INT_CAST) reduce 105) ((T_ISSET) reduce 105) ((T_LINE) reduce 105) ((T_LIST) reduce 105) ((T_LNUMBER) reduce 105) ((T_MATCH) reduce 105) ((T_METHOD_C) reduce 105) ((T_NAME_FULLY_QUALIFIED) reduce 105) ((T_NAME_QUALIFIED) reduce 105) ((T_NAME_RELATIVE) reduce 105) ((T_NEW) reduce 105) ((T_NS_C) reduce 105) ((T_OBJECT_CAST) reduce 105) ((T_PRINT) reduce 105) ((T_READONLY) reduce 105) ((T_REQUIRE) reduce 105) ((T_REQUIRE_ONCE) reduce 105) ((T_RETURN) reduce 105) ((T_START_HEREDOC) reduce 105) ((T_STATIC) reduce 105) ((T_STRING) reduce 105) ((T_STRING_CAST) reduce 105) ((T_SWITCH) reduce 105) ((T_THROW) reduce 105) ((T_TRAIT) reduce 105) ((T_TRAIT_C) reduce 105) ((T_TRY) reduce 105) ((T_UNSET) reduce 105) ((T_UNSET_CAST) reduce 105) ((T_VARIABLE) reduce 105) ((T_WHILE) reduce 105) ((T_YIELD) reduce 105) ((T_YIELD_FROM) reduce 105) (("[") reduce 105) (("`") reduce 105) (("{") reduce 105) (("}") reduce 105) (("~") reduce 105)) 204 ((("!") reduce 141) (("\"") reduce 141) (("$") reduce 141) (("(") reduce 141) (("+") reduce 141) (("-") reduce 141) ((";") reduce 141) (("@") reduce 141) ((T_ABSTRACT) reduce 141) ((T_ARRAY) reduce 141) ((T_ARRAY_CAST) reduce 141) ((T_ATTRIBUTE) reduce 141) ((T_BOOL_CAST) reduce 141) ((T_BREAK) reduce 141) ((T_CLASS) reduce 141) ((T_CLASS_C) reduce 141) ((T_CLONE) reduce 141) ((T_CONSTANT_ENCAPSED_STRING) reduce 141) ((T_CONTINUE) reduce 141) ((T_DEC) reduce 141) ((T_DECLARE) reduce 141) ((T_DIR) reduce 141) ((T_DNUMBER) reduce 141) ((T_DO) reduce 141) ((T_DOUBLE_CAST) reduce 141) ((T_ECHO) reduce 141) ((T_EMPTY) reduce 141) ((T_ENUM) reduce 141) ((T_EVAL) reduce 141) ((T_EXIT) reduce 141) ((T_FILE) reduce 141) ((T_FINAL) reduce 141) ((T_FN) reduce 141) ((T_FOR) reduce 141) ((T_FOREACH) reduce 141) ((T_FUNCTION) reduce 141) ((T_FUNC_C) reduce 141) ((T_GLOBAL) reduce 141) ((T_GOTO) reduce 141) ((T_HALT_COMPILER) reduce 141) ((T_IF) reduce 141) ((T_INC) reduce 141) ((T_INCLUDE) reduce 141) ((T_INCLUDE_ONCE) reduce 141) ((T_INLINE_HTML) reduce 141) ((T_INTERFACE) reduce 141) ((T_INT_CAST) reduce 141) ((T_ISSET) reduce 141) ((T_LINE) reduce 141) ((T_LIST) reduce 141) ((T_LNUMBER) reduce 141) ((T_MATCH) reduce 141) ((T_METHOD_C) reduce 141) ((T_NAME_FULLY_QUALIFIED) reduce 141) ((T_NAME_QUALIFIED) reduce 141) ((T_NAME_RELATIVE) reduce 141) ((T_NEW) reduce 141) ((T_NS_C) reduce 141) ((T_OBJECT_CAST) reduce 141) ((T_PRINT) reduce 141) ((T_READONLY) reduce 141) ((T_REQUIRE) reduce 141) ((T_REQUIRE_ONCE) reduce 141) ((T_RETURN) reduce 141) ((T_START_HEREDOC) reduce 141) ((T_STATIC) reduce 141) ((T_STRING) reduce 141) ((T_STRING_CAST) reduce 141) ((T_SWITCH) reduce 141) ((T_THROW) reduce 141) ((T_TRAIT) reduce 141) ((T_TRAIT_C) reduce 141) ((T_TRY) reduce 141) ((T_UNSET) reduce 141) ((T_UNSET_CAST) reduce 141) ((T_VARIABLE) reduce 141) ((T_WHILE) reduce 141) ((T_YIELD) reduce 141) ((T_YIELD_FROM) reduce 141) (("[") reduce 141) (("`") reduce 141) (("{") reduce 141) (("}") reduce 141) (("~") reduce 141)) 205 ((("!") reduce 104) (("\"") reduce 104) (("$") reduce 104) (("(") reduce 104) (("+") reduce 104) (("-") reduce 104) ((";") reduce 104) (("@") reduce 104) ((T_ABSTRACT) reduce 104) ((T_ARRAY) reduce 104) ((T_ARRAY_CAST) reduce 104) ((T_ATTRIBUTE) reduce 104) ((T_BOOL_CAST) reduce 104) ((T_BREAK) reduce 104) ((T_CLASS) reduce 104) ((T_CLASS_C) reduce 104) ((T_CLONE) reduce 104) ((T_CONSTANT_ENCAPSED_STRING) reduce 104) ((T_CONTINUE) reduce 104) ((T_DEC) reduce 104) ((T_DECLARE) reduce 104) ((T_DIR) reduce 104) ((T_DNUMBER) reduce 104) ((T_DO) reduce 104) ((T_DOUBLE_CAST) reduce 104) ((T_ECHO) reduce 104) ((T_EMPTY) reduce 104) ((T_ENUM) reduce 104) ((T_EVAL) reduce 104) ((T_EXIT) reduce 104) ((T_FILE) reduce 104) ((T_FINAL) reduce 104) ((T_FN) reduce 104) ((T_FOR) reduce 104) ((T_FOREACH) reduce 104) ((T_FUNCTION) reduce 104) ((T_FUNC_C) reduce 104) ((T_GLOBAL) reduce 104) ((T_GOTO) reduce 104) ((T_HALT_COMPILER) reduce 104) ((T_IF) reduce 104) ((T_INC) reduce 104) ((T_INCLUDE) reduce 104) ((T_INCLUDE_ONCE) reduce 104) ((T_INLINE_HTML) reduce 104) ((T_INTERFACE) reduce 104) ((T_INT_CAST) reduce 104) ((T_ISSET) reduce 104) ((T_LINE) reduce 104) ((T_LIST) reduce 104) ((T_LNUMBER) reduce 104) ((T_MATCH) reduce 104) ((T_METHOD_C) reduce 104) ((T_NAME_FULLY_QUALIFIED) reduce 104) ((T_NAME_QUALIFIED) reduce 104) ((T_NAME_RELATIVE) reduce 104) ((T_NEW) reduce 104) ((T_NS_C) reduce 104) ((T_OBJECT_CAST) reduce 104) ((T_PRINT) reduce 104) ((T_READONLY) reduce 104) ((T_REQUIRE) reduce 104) ((T_REQUIRE_ONCE) reduce 104) ((T_RETURN) reduce 104) ((T_START_HEREDOC) reduce 104) ((T_STATIC) reduce 104) ((T_STRING) reduce 104) ((T_STRING_CAST) reduce 104) ((T_SWITCH) reduce 104) ((T_THROW) reduce 104) ((T_TRAIT) reduce 104) ((T_TRAIT_C) reduce 104) ((T_TRY) reduce 104) ((T_UNSET) reduce 104) ((T_UNSET_CAST) reduce 104) ((T_VARIABLE) reduce 104) ((T_WHILE) reduce 104) ((T_YIELD) reduce 104) ((T_YIELD_FROM) reduce 104) (("[") reduce 104) (("`") reduce 104) (("{") reduce 104) (("}") reduce 104) (("~") reduce 104)) 207 ((("%") reduce 455) (("*") reduce 455) (("+") reduce 455) (("-") reduce 455) ((".") reduce 455) (("/") reduce 455) ((";") reduce 455) (("<") reduce 455) ((">") reduce 455) (("?") reduce 455) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_BOOLEAN_AND) reduce 455) ((T_BOOLEAN_OR) reduce 455) ((T_COALESCE) reduce 455) ((T_INSTANCEOF) reduce 455) ((T_IS_EQUAL) reduce 455) ((T_IS_GREATER_OR_EQUAL) reduce 455) ((T_IS_IDENTICAL) reduce 455) ((T_IS_NOT_EQUAL) reduce 455) ((T_IS_NOT_IDENTICAL) reduce 455) ((T_IS_SMALLER_OR_EQUAL) reduce 455) ((T_LOGICAL_AND) reduce 455) ((T_LOGICAL_OR) reduce 455) ((T_LOGICAL_XOR) reduce 455) ((T_POW) reduce 455) ((T_SL) reduce 455) ((T_SPACESHIP) reduce 455) ((T_SR) reduce 455) (("^") reduce 455) (("|") reduce 455)) 208 ((("%") reduce 450) (("*") reduce 450) (("+") reduce 450) (("-") reduce 450) ((".") reduce 450) (("/") reduce 450) ((";") reduce 450) (("<") reduce 450) ((">") reduce 450) (("?") reduce 450) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_BOOLEAN_AND) reduce 450) ((T_BOOLEAN_OR) reduce 450) ((T_COALESCE) reduce 450) ((T_INSTANCEOF) reduce 450) ((T_IS_EQUAL) reduce 450) ((T_IS_GREATER_OR_EQUAL) reduce 450) ((T_IS_IDENTICAL) reduce 450) ((T_IS_NOT_EQUAL) reduce 450) ((T_IS_NOT_IDENTICAL) reduce 450) ((T_IS_SMALLER_OR_EQUAL) reduce 450) ((T_LOGICAL_AND) reduce 450) ((T_LOGICAL_OR) reduce 450) ((T_LOGICAL_XOR) reduce 450) ((T_POW) reduce 450) ((T_SL) reduce 450) ((T_SPACESHIP) reduce 450) ((T_SR) reduce 450) (("^") reduce 450) (("|") reduce 450)) 210 ((("!") reduce 145) (("\"") reduce 145) (("$") reduce 145) (("(") reduce 145) (("+") reduce 145) (("-") reduce 145) ((";") reduce 145) (("@") reduce 145) ((T_ABSTRACT) reduce 145) ((T_ARRAY) reduce 145) ((T_ARRAY_CAST) reduce 145) ((T_ATTRIBUTE) reduce 145) ((T_BOOL_CAST) reduce 145) ((T_BREAK) reduce 145) ((T_CLASS) reduce 145) ((T_CLASS_C) reduce 145) ((T_CLONE) reduce 145) ((T_CONSTANT_ENCAPSED_STRING) reduce 145) ((T_CONTINUE) reduce 145) ((T_DEC) reduce 145) ((T_DECLARE) reduce 145) ((T_DIR) reduce 145) ((T_DNUMBER) reduce 145) ((T_DO) reduce 145) ((T_DOUBLE_CAST) reduce 145) ((T_ECHO) reduce 145) ((T_EMPTY) reduce 145) ((T_ENUM) reduce 145) ((T_EVAL) reduce 145) ((T_EXIT) reduce 145) ((T_FILE) reduce 145) ((T_FINAL) reduce 145) ((T_FN) reduce 145) ((T_FOR) reduce 145) ((T_FOREACH) reduce 145) ((T_FUNCTION) reduce 145) ((T_FUNC_C) reduce 145) ((T_GLOBAL) reduce 145) ((T_GOTO) reduce 145) ((T_HALT_COMPILER) reduce 145) ((T_IF) reduce 145) ((T_INC) reduce 145) ((T_INCLUDE) reduce 145) ((T_INCLUDE_ONCE) reduce 145) ((T_INLINE_HTML) reduce 145) ((T_INTERFACE) reduce 145) ((T_INT_CAST) reduce 145) ((T_ISSET) reduce 145) ((T_LINE) reduce 145) ((T_LIST) reduce 145) ((T_LNUMBER) reduce 145) ((T_MATCH) reduce 145) ((T_METHOD_C) reduce 145) ((T_NAME_FULLY_QUALIFIED) reduce 145) ((T_NAME_QUALIFIED) reduce 145) ((T_NAME_RELATIVE) reduce 145) ((T_NEW) reduce 145) ((T_NS_C) reduce 145) ((T_OBJECT_CAST) reduce 145) ((T_PRINT) reduce 145) ((T_READONLY) reduce 145) ((T_REQUIRE) reduce 145) ((T_REQUIRE_ONCE) reduce 145) ((T_RETURN) reduce 145) ((T_START_HEREDOC) reduce 145) ((T_STATIC) reduce 145) ((T_STRING) reduce 145) ((T_STRING_CAST) reduce 145) ((T_SWITCH) reduce 145) ((T_THROW) reduce 145) ((T_TRAIT) reduce 145) ((T_TRAIT_C) reduce 145) ((T_TRY) reduce 145) ((T_UNSET) reduce 145) ((T_UNSET_CAST) reduce 145) ((T_VARIABLE) reduce 145) ((T_WHILE) reduce 145) ((T_YIELD) reduce 145) ((T_YIELD_FROM) reduce 145) (("[") reduce 145) (("`") reduce 145) (("{") reduce 145) (("}") reduce 145) (("~") reduce 145)) 224 ((("%") reduce 502) ((")") reduce 502) (("*") reduce 502) (("+") reduce 502) (("-") reduce 502) ((".") reduce 502) (("/") reduce 502) (("<") reduce 502) ((">") reduce 502) (("?") reduce 502) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_BOOLEAN_AND) reduce 502) ((T_BOOLEAN_OR) reduce 502) ((T_COALESCE) reduce 502) ((T_INSTANCEOF) reduce 502) ((T_IS_EQUAL) reduce 502) ((T_IS_GREATER_OR_EQUAL) reduce 502) ((T_IS_IDENTICAL) reduce 502) ((T_IS_NOT_EQUAL) reduce 502) ((T_IS_NOT_IDENTICAL) reduce 502) ((T_IS_SMALLER_OR_EQUAL) reduce 502) ((T_LOGICAL_AND) reduce 502) ((T_LOGICAL_OR) reduce 502) ((T_LOGICAL_XOR) reduce 502) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 502) ((T_OBJECT_OPERATOR) reduce 502) ((T_POW) reduce 502) ((T_SL) reduce 502) ((T_SPACESHIP) reduce 502) ((T_SR) reduce 502) (("[") reduce 502) (("^") reduce 502) (("{") reduce 502) (("|") reduce 502)) 226 ((("%") reduce 484) (("(") reduce 484) ((")") reduce 484) (("*") reduce 484) (("+") reduce 484) (("-") reduce 484) ((".") reduce 484) (("/") reduce 484) (("<") reduce 484) ((">") reduce 484) (("?") reduce 484) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_BOOLEAN_AND) reduce 484) ((T_BOOLEAN_OR) reduce 484) ((T_COALESCE) reduce 484) ((T_INSTANCEOF) reduce 484) ((T_IS_EQUAL) reduce 484) ((T_IS_GREATER_OR_EQUAL) reduce 484) ((T_IS_IDENTICAL) reduce 484) ((T_IS_NOT_EQUAL) reduce 484) ((T_IS_NOT_IDENTICAL) reduce 484) ((T_IS_SMALLER_OR_EQUAL) reduce 484) ((T_LOGICAL_AND) reduce 484) ((T_LOGICAL_OR) reduce 484) ((T_LOGICAL_XOR) reduce 484) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 484) ((T_OBJECT_OPERATOR) reduce 484) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 484) ((T_POW) reduce 484) ((T_SL) reduce 484) ((T_SPACESHIP) reduce 484) ((T_SR) reduce 484) (("[") reduce 484) (("^") reduce 484) (("{") reduce 484) (("|") reduce 484)) 228 ((("%") reduce 497) ((")") reduce 497) (("*") reduce 497) (("+") reduce 497) (("-") reduce 497) ((".") reduce 497) (("/") reduce 497) (("<") reduce 497) ((">") reduce 497) (("?") reduce 497) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_BOOLEAN_AND) reduce 497) ((T_BOOLEAN_OR) reduce 497) ((T_COALESCE) reduce 497) ((T_INSTANCEOF) reduce 497) ((T_IS_EQUAL) reduce 497) ((T_IS_GREATER_OR_EQUAL) reduce 497) ((T_IS_IDENTICAL) reduce 497) ((T_IS_NOT_EQUAL) reduce 497) ((T_IS_NOT_IDENTICAL) reduce 497) ((T_IS_SMALLER_OR_EQUAL) reduce 497) ((T_LOGICAL_AND) reduce 497) ((T_LOGICAL_OR) reduce 497) ((T_LOGICAL_XOR) reduce 497) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 497) ((T_OBJECT_OPERATOR) reduce 497) ((T_POW) reduce 497) ((T_SL) reduce 497) ((T_SPACESHIP) reduce 497) ((T_SR) reduce 497) (("[") reduce 497) (("^") reduce 497) (("{") reduce 497) (("|") reduce 497)) 229 ((("%") reduce 487) ((")") reduce 487) (("*") reduce 487) (("+") reduce 487) (("-") reduce 487) ((".") reduce 487) (("/") reduce 487) (("<") reduce 487) ((">") reduce 487) (("?") reduce 487) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_BOOLEAN_AND) reduce 487) ((T_BOOLEAN_OR) reduce 487) ((T_COALESCE) reduce 487) ((T_INSTANCEOF) reduce 487) ((T_IS_EQUAL) reduce 487) ((T_IS_GREATER_OR_EQUAL) reduce 487) ((T_IS_IDENTICAL) reduce 487) ((T_IS_NOT_EQUAL) reduce 487) ((T_IS_NOT_IDENTICAL) reduce 487) ((T_IS_SMALLER_OR_EQUAL) reduce 487) ((T_LOGICAL_AND) reduce 487) ((T_LOGICAL_OR) reduce 487) ((T_LOGICAL_XOR) reduce 487) ((T_POW) reduce 487) ((T_SL) reduce 487) ((T_SPACESHIP) reduce 487) ((T_SR) reduce 487) (("^") reduce 487) (("|") reduce 487)) 233 ((("%") reduce 475) (("(") shift) ((")") reduce 475) (("*") reduce 475) (("+") reduce 475) (("-") reduce 475) ((".") reduce 475) (("/") reduce 475) (("<") reduce 475) ((">") reduce 475) (("?") reduce 475) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_BOOLEAN_AND) reduce 475) ((T_BOOLEAN_OR) reduce 475) ((T_COALESCE) reduce 475) ((T_INSTANCEOF) reduce 475) ((T_IS_EQUAL) reduce 475) ((T_IS_GREATER_OR_EQUAL) reduce 475) ((T_IS_IDENTICAL) reduce 475) ((T_IS_NOT_EQUAL) reduce 475) ((T_IS_NOT_IDENTICAL) reduce 475) ((T_IS_SMALLER_OR_EQUAL) reduce 475) ((T_LOGICAL_AND) reduce 475) ((T_LOGICAL_OR) reduce 475) ((T_LOGICAL_XOR) reduce 475) ((T_POW) reduce 475) ((T_SL) reduce 475) ((T_SPACESHIP) reduce 475) ((T_SR) reduce 475) (("^") reduce 475) (("|") reduce 475)) 234 ((("%") reduce 496) ((")") reduce 496) (("*") reduce 496) (("+") reduce 496) (("-") reduce 496) ((".") reduce 496) (("/") reduce 496) (("<") reduce 496) ((">") reduce 496) (("?") reduce 496) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_BOOLEAN_AND) reduce 496) ((T_BOOLEAN_OR) reduce 496) ((T_COALESCE) reduce 496) ((T_INSTANCEOF) reduce 496) ((T_IS_EQUAL) reduce 496) ((T_IS_GREATER_OR_EQUAL) reduce 496) ((T_IS_IDENTICAL) reduce 496) ((T_IS_NOT_EQUAL) reduce 496) ((T_IS_NOT_IDENTICAL) reduce 496) ((T_IS_SMALLER_OR_EQUAL) reduce 496) ((T_LOGICAL_AND) reduce 496) ((T_LOGICAL_OR) reduce 496) ((T_LOGICAL_XOR) reduce 496) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 496) ((T_OBJECT_OPERATOR) reduce 496) ((T_POW) reduce 496) ((T_SL) reduce 496) ((T_SPACESHIP) reduce 496) ((T_SR) reduce 496) (("[") reduce 496) (("^") reduce 496) (("{") reduce 496) (("|") reduce 496)) 235 ((("%") reduce 500) ((")") reduce 500) (("*") reduce 500) (("+") reduce 500) (("-") reduce 500) ((".") reduce 500) (("/") reduce 500) (("<") reduce 500) ((">") reduce 500) (("?") reduce 500) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_BOOLEAN_AND) reduce 500) ((T_BOOLEAN_OR) reduce 500) ((T_COALESCE) reduce 500) ((T_INSTANCEOF) reduce 500) ((T_IS_EQUAL) reduce 500) ((T_IS_GREATER_OR_EQUAL) reduce 500) ((T_IS_IDENTICAL) reduce 500) ((T_IS_NOT_EQUAL) reduce 500) ((T_IS_NOT_IDENTICAL) reduce 500) ((T_IS_SMALLER_OR_EQUAL) reduce 500) ((T_LOGICAL_AND) reduce 500) ((T_LOGICAL_OR) reduce 500) ((T_LOGICAL_XOR) reduce 500) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 500) ((T_OBJECT_OPERATOR) reduce 500) ((T_POW) reduce 500) ((T_SL) reduce 500) ((T_SPACESHIP) reduce 500) ((T_SR) reduce 500) (("[") reduce 500) (("^") reduce 500) (("{") reduce 500) (("|") reduce 500)) 241 ((("%") reduce 495) ((")") reduce 495) (("*") reduce 495) (("+") reduce 495) (("-") reduce 495) ((".") reduce 495) (("/") reduce 495) (("<") reduce 495) ((">") reduce 495) (("?") reduce 495) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_BOOLEAN_AND) reduce 495) ((T_BOOLEAN_OR) reduce 495) ((T_COALESCE) reduce 495) ((T_INSTANCEOF) reduce 495) ((T_IS_EQUAL) reduce 495) ((T_IS_GREATER_OR_EQUAL) reduce 495) ((T_IS_IDENTICAL) reduce 495) ((T_IS_NOT_EQUAL) reduce 495) ((T_IS_NOT_IDENTICAL) reduce 495) ((T_IS_SMALLER_OR_EQUAL) reduce 495) ((T_LOGICAL_AND) reduce 495) ((T_LOGICAL_OR) reduce 495) ((T_LOGICAL_XOR) reduce 495) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 495) ((T_OBJECT_OPERATOR) reduce 495) ((T_POW) reduce 495) ((T_SL) reduce 495) ((T_SPACESHIP) reduce 495) ((T_SR) reduce 495) (("[") reduce 495) (("^") reduce 495) (("{") reduce 495) (("|") reduce 495)) 243 ((("%") reduce 486) ((")") reduce 486) (("*") reduce 486) (("+") reduce 486) (("-") reduce 486) ((".") reduce 486) (("/") reduce 486) (("<") reduce 486) ((">") reduce 486) (("?") reduce 486) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_BOOLEAN_AND) reduce 486) ((T_BOOLEAN_OR) reduce 486) ((T_COALESCE) reduce 486) ((T_INSTANCEOF) reduce 486) ((T_IS_EQUAL) reduce 486) ((T_IS_GREATER_OR_EQUAL) reduce 486) ((T_IS_IDENTICAL) reduce 486) ((T_IS_NOT_EQUAL) reduce 486) ((T_IS_NOT_IDENTICAL) reduce 486) ((T_IS_SMALLER_OR_EQUAL) reduce 486) ((T_LOGICAL_AND) reduce 486) ((T_LOGICAL_OR) reduce 486) ((T_LOGICAL_XOR) reduce 486) ((T_POW) reduce 486) ((T_SL) reduce 486) ((T_SPACESHIP) reduce 486) ((T_SR) reduce 486) (("^") reduce 486) (("|") reduce 486)) 245 ((("%") reduce 499) ((")") reduce 499) (("*") reduce 499) (("+") reduce 499) (("-") reduce 499) ((".") reduce 499) (("/") reduce 499) (("<") reduce 499) ((">") reduce 499) (("?") reduce 499) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_BOOLEAN_AND) reduce 499) ((T_BOOLEAN_OR) reduce 499) ((T_COALESCE) reduce 499) ((T_INSTANCEOF) reduce 499) ((T_IS_EQUAL) reduce 499) ((T_IS_GREATER_OR_EQUAL) reduce 499) ((T_IS_IDENTICAL) reduce 499) ((T_IS_NOT_EQUAL) reduce 499) ((T_IS_NOT_IDENTICAL) reduce 499) ((T_IS_SMALLER_OR_EQUAL) reduce 499) ((T_LOGICAL_AND) reduce 499) ((T_LOGICAL_OR) reduce 499) ((T_LOGICAL_XOR) reduce 499) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 499) ((T_OBJECT_OPERATOR) reduce 499) ((T_POW) reduce 499) ((T_SL) reduce 499) ((T_SPACESHIP) reduce 499) ((T_SR) reduce 499) (("[") reduce 499) (("^") reduce 499) (("{") reduce 499) (("|") reduce 499)) 246 ((("%") reduce 93) (("(") reduce 93) ((")") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 93) ((T_OBJECT_OPERATOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("[") reduce 93) (("^") reduce 93) (("{") reduce 93) (("|") reduce 93)) 247 ((("%") reduce 92) (("(") reduce 92) ((")") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 92) ((T_OBJECT_OPERATOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("[") reduce 92) (("^") reduce 92) (("{") reduce 92) (("|") reduce 92)) 248 ((("%") reduce 94) (("(") reduce 94) ((")") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 94) ((T_OBJECT_OPERATOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("[") reduce 94) (("^") reduce 94) (("{") reduce 94) (("|") reduce 94)) 250 ((("%") reduce 501) ((")") reduce 501) (("*") reduce 501) (("+") reduce 501) (("-") reduce 501) ((".") reduce 501) (("/") reduce 501) (("<") reduce 501) ((">") reduce 501) (("?") reduce 501) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_BOOLEAN_AND) reduce 501) ((T_BOOLEAN_OR) reduce 501) ((T_COALESCE) reduce 501) ((T_INSTANCEOF) reduce 501) ((T_IS_EQUAL) reduce 501) ((T_IS_GREATER_OR_EQUAL) reduce 501) ((T_IS_IDENTICAL) reduce 501) ((T_IS_NOT_EQUAL) reduce 501) ((T_IS_NOT_IDENTICAL) reduce 501) ((T_IS_SMALLER_OR_EQUAL) reduce 501) ((T_LOGICAL_AND) reduce 501) ((T_LOGICAL_OR) reduce 501) ((T_LOGICAL_XOR) reduce 501) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 501) ((T_OBJECT_OPERATOR) reduce 501) ((T_POW) reduce 501) ((T_SL) reduce 501) ((T_SPACESHIP) reduce 501) ((T_SR) reduce 501) (("[") reduce 501) (("^") reduce 501) (("{") reduce 501) (("|") reduce 501)) 258 ((("%") reduce 91) (("(") reduce 91) ((")") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 91) ((T_OBJECT_OPERATOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("[") reduce 91) (("^") reduce 91) (("{") reduce 91) (("|") reduce 91)) 261 ((("%") reduce 498) ((")") reduce 498) (("*") reduce 498) (("+") reduce 498) (("-") reduce 498) ((".") reduce 498) (("/") reduce 498) (("<") reduce 498) ((">") reduce 498) (("?") reduce 498) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_BOOLEAN_AND) reduce 498) ((T_BOOLEAN_OR) reduce 498) ((T_COALESCE) reduce 498) ((T_INSTANCEOF) reduce 498) ((T_IS_EQUAL) reduce 498) ((T_IS_GREATER_OR_EQUAL) reduce 498) ((T_IS_IDENTICAL) reduce 498) ((T_IS_NOT_EQUAL) reduce 498) ((T_IS_NOT_IDENTICAL) reduce 498) ((T_IS_SMALLER_OR_EQUAL) reduce 498) ((T_LOGICAL_AND) reduce 498) ((T_LOGICAL_OR) reduce 498) ((T_LOGICAL_XOR) reduce 498) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 498) ((T_OBJECT_OPERATOR) reduce 498) ((T_POW) reduce 498) ((T_SL) reduce 498) ((T_SPACESHIP) reduce 498) ((T_SR) reduce 498) (("[") reduce 498) (("^") reduce 498) (("{") reduce 498) (("|") reduce 498)) 263 ((("%") reduce 529) (("(") reduce 529) ((")") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) (("=") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AND_EQUAL) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_COALESCE_EQUAL) reduce 529) ((T_CONCAT_EQUAL) reduce 529) ((T_DEC) reduce 529) ((T_DIV_EQUAL) reduce 529) ((T_INC) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_MINUS_EQUAL) reduce 529) ((T_MOD_EQUAL) reduce 529) ((T_MUL_EQUAL) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_OR_EQUAL) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_PLUS_EQUAL) reduce 529) ((T_POW) reduce 529) ((T_POW_EQUAL) reduce 529) ((T_SL) reduce 529) ((T_SL_EQUAL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) ((T_SR_EQUAL) reduce 529) ((T_XOR_EQUAL) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 264 ((("!") shift) (("\"") shift) (("$") shift) (("%") reduce 440) (("(") shift) ((")") reduce 440) (("*") reduce 440) (("+") shift) (("-") shift) ((".") reduce 440) (("/") reduce 440) (("<") reduce 440) ((">") reduce 440) (("?") reduce 440) (("@") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOLEAN_AND) reduce 440) ((T_BOOLEAN_OR) reduce 440) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_COALESCE) reduce 440) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INSTANCEOF) reduce 440) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_IS_EQUAL) reduce 440) ((T_IS_GREATER_OR_EQUAL) reduce 440) ((T_IS_IDENTICAL) reduce 440) ((T_IS_NOT_EQUAL) reduce 440) ((T_IS_NOT_IDENTICAL) reduce 440) ((T_IS_SMALLER_OR_EQUAL) reduce 440) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_LOGICAL_AND) reduce 440) ((T_LOGICAL_OR) reduce 440) ((T_LOGICAL_XOR) reduce 440) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_POW) reduce 440) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_SL) reduce 440) ((T_SPACESHIP) reduce 440) ((T_SR) reduce 440) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("^") reduce 440) (("`") shift) (("|") reduce 440) (("~") shift)) 271 ((("%") reduce 525) (("(") reduce 516) ((")") reduce 525) (("*") reduce 525) (("+") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) (("<") reduce 525) (("=") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AND_EQUAL) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_COALESCE_EQUAL) reduce 525) ((T_CONCAT_EQUAL) reduce 525) ((T_DEC) reduce 525) ((T_DIV_EQUAL) reduce 525) ((T_INC) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_MINUS_EQUAL) reduce 525) ((T_MOD_EQUAL) reduce 525) ((T_MUL_EQUAL) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_OR_EQUAL) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_PLUS_EQUAL) reduce 525) ((T_POW) reduce 525) ((T_POW_EQUAL) reduce 525) ((T_SL) reduce 525) ((T_SL_EQUAL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) ((T_SR_EQUAL) reduce 525) ((T_XOR_EQUAL) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 272 ((("%") reduce 493) ((")") reduce 493) (("*") reduce 493) (("+") reduce 493) (("-") reduce 493) ((".") reduce 493) (("/") reduce 493) (("<") reduce 493) ((">") reduce 493) (("?") reduce 493) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_BOOLEAN_AND) reduce 493) ((T_BOOLEAN_OR) reduce 493) ((T_COALESCE) reduce 493) ((T_INSTANCEOF) reduce 493) ((T_IS_EQUAL) reduce 493) ((T_IS_GREATER_OR_EQUAL) reduce 493) ((T_IS_IDENTICAL) reduce 493) ((T_IS_NOT_EQUAL) reduce 493) ((T_IS_NOT_IDENTICAL) reduce 493) ((T_IS_SMALLER_OR_EQUAL) reduce 493) ((T_LOGICAL_AND) reduce 493) ((T_LOGICAL_OR) reduce 493) ((T_LOGICAL_XOR) reduce 493) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 513) ((T_OBJECT_OPERATOR) reduce 513) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 513) ((T_POW) reduce 493) ((T_SL) reduce 493) ((T_SPACESHIP) reduce 493) ((T_SR) reduce 493) (("[") reduce 513) (("^") reduce 493) (("{") reduce 513) (("|") reduce 493)) 274 ((("%") reduce 492) ((")") reduce 492) (("*") reduce 492) (("+") reduce 492) (("-") reduce 492) ((".") reduce 492) (("/") reduce 492) (("<") reduce 492) ((">") reduce 492) (("?") reduce 492) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_BOOLEAN_AND) reduce 492) ((T_BOOLEAN_OR) reduce 492) ((T_COALESCE) reduce 492) ((T_INSTANCEOF) reduce 492) ((T_IS_EQUAL) reduce 492) ((T_IS_GREATER_OR_EQUAL) reduce 492) ((T_IS_IDENTICAL) reduce 492) ((T_IS_NOT_EQUAL) reduce 492) ((T_IS_NOT_IDENTICAL) reduce 492) ((T_IS_SMALLER_OR_EQUAL) reduce 492) ((T_LOGICAL_AND) reduce 492) ((T_LOGICAL_OR) reduce 492) ((T_LOGICAL_XOR) reduce 492) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 515) ((T_OBJECT_OPERATOR) reduce 515) ((T_POW) reduce 492) ((T_SL) reduce 492) ((T_SPACESHIP) reduce 492) ((T_SR) reduce 492) (("[") reduce 515) (("^") reduce 492) (("{") reduce 515) (("|") reduce 492)) 275 ((("%") reduce 491) (("(") reduce 518) ((")") reduce 491) (("*") reduce 491) (("+") reduce 491) (("-") reduce 491) ((".") reduce 491) (("/") reduce 491) (("<") reduce 491) ((">") reduce 491) (("?") reduce 491) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_BOOLEAN_AND) reduce 491) ((T_BOOLEAN_OR) reduce 491) ((T_COALESCE) reduce 491) ((T_INSTANCEOF) reduce 491) ((T_IS_EQUAL) reduce 491) ((T_IS_GREATER_OR_EQUAL) reduce 491) ((T_IS_IDENTICAL) reduce 491) ((T_IS_NOT_EQUAL) reduce 491) ((T_IS_NOT_IDENTICAL) reduce 491) ((T_IS_SMALLER_OR_EQUAL) reduce 491) ((T_LOGICAL_AND) reduce 491) ((T_LOGICAL_OR) reduce 491) ((T_LOGICAL_XOR) reduce 491) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 512) ((T_OBJECT_OPERATOR) reduce 512) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 512) ((T_POW) reduce 491) ((T_SL) reduce 491) ((T_SPACESHIP) reduce 491) ((T_SR) reduce 491) (("[") reduce 512) (("^") reduce 491) (("{") reduce 512) (("|") reduce 491)) 276 ((("%") shift) ((")") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 279 ((("%") reduce 524) (("(") reduce 524) ((")") reduce 524) (("*") reduce 524) (("+") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) (("<") reduce 524) (("=") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AND_EQUAL) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_COALESCE_EQUAL) reduce 524) ((T_CONCAT_EQUAL) reduce 524) ((T_DEC) reduce 524) ((T_DIV_EQUAL) reduce 524) ((T_INC) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_MINUS_EQUAL) reduce 524) ((T_MOD_EQUAL) reduce 524) ((T_MUL_EQUAL) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_OR_EQUAL) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_PLUS_EQUAL) reduce 524) ((T_POW) reduce 524) ((T_POW_EQUAL) reduce 524) ((T_SL) reduce 524) ((T_SL_EQUAL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) ((T_SR_EQUAL) reduce 524) ((T_XOR_EQUAL) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 280 ((("%") reduce 445) ((")") reduce 445) (("*") reduce 445) (("+") reduce 445) (("-") reduce 445) ((".") reduce 445) (("/") reduce 445) (("<") reduce 445) ((">") reduce 445) (("?") reduce 445) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_BOOLEAN_AND) reduce 445) ((T_BOOLEAN_OR) reduce 445) ((T_COALESCE) reduce 445) ((T_INSTANCEOF) reduce 445) ((T_IS_EQUAL) reduce 445) ((T_IS_GREATER_OR_EQUAL) reduce 445) ((T_IS_IDENTICAL) reduce 445) ((T_IS_NOT_EQUAL) reduce 445) ((T_IS_NOT_IDENTICAL) reduce 445) ((T_IS_SMALLER_OR_EQUAL) reduce 445) ((T_LOGICAL_AND) reduce 445) ((T_LOGICAL_OR) reduce 445) ((T_LOGICAL_XOR) reduce 445) ((T_POW) reduce 445) ((T_SL) reduce 445) ((T_SPACESHIP) reduce 445) ((T_SR) reduce 445) (("^") reduce 445) (("|") reduce 445)) 281 ((("%") reduce 427) ((")") reduce 427) (("*") reduce 427) (("+") reduce 427) (("-") reduce 427) ((".") reduce 427) (("/") reduce 427) (("<") reduce 427) ((">") reduce 427) (("?") reduce 427) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_BOOLEAN_AND) reduce 427) ((T_BOOLEAN_OR) reduce 427) ((T_COALESCE) reduce 427) ((T_INSTANCEOF) reduce 427) ((T_IS_EQUAL) reduce 427) ((T_IS_GREATER_OR_EQUAL) reduce 427) ((T_IS_IDENTICAL) reduce 427) ((T_IS_NOT_EQUAL) reduce 427) ((T_IS_NOT_IDENTICAL) reduce 427) ((T_IS_SMALLER_OR_EQUAL) reduce 427) ((T_LOGICAL_AND) reduce 427) ((T_LOGICAL_OR) reduce 427) ((T_LOGICAL_XOR) reduce 427) ((T_POW) reduce 427) ((T_SL) reduce 427) ((T_SPACESHIP) reduce 427) ((T_SR) reduce 427) (("^") reduce 427) (("|") reduce 427)) 282 ((("%") reduce 449) ((")") reduce 449) (("*") reduce 449) (("+") reduce 449) (("-") reduce 449) ((".") reduce 449) (("/") reduce 449) (("<") reduce 449) ((">") reduce 449) (("?") reduce 449) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_BOOLEAN_AND) reduce 449) ((T_BOOLEAN_OR) reduce 449) ((T_COALESCE) reduce 449) ((T_INSTANCEOF) reduce 449) ((T_IS_EQUAL) reduce 449) ((T_IS_GREATER_OR_EQUAL) reduce 449) ((T_IS_IDENTICAL) reduce 449) ((T_IS_NOT_EQUAL) reduce 449) ((T_IS_NOT_IDENTICAL) reduce 449) ((T_IS_SMALLER_OR_EQUAL) reduce 449) ((T_LOGICAL_AND) reduce 449) ((T_LOGICAL_OR) reduce 449) ((T_LOGICAL_XOR) reduce 449) ((T_POW) reduce 449) ((T_SL) reduce 449) ((T_SPACESHIP) reduce 449) ((T_SR) reduce 449) (("^") reduce 449) (("|") reduce 449)) 283 ((("%") reduce 494) (("(") shift) ((")") reduce 494) (("*") reduce 494) (("+") reduce 494) (("-") reduce 494) ((".") reduce 494) (("/") reduce 494) (("<") reduce 494) ((">") reduce 494) (("?") reduce 494) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_BOOLEAN_AND) reduce 494) ((T_BOOLEAN_OR) reduce 494) ((T_COALESCE) reduce 494) ((T_INSTANCEOF) reduce 494) ((T_IS_EQUAL) reduce 494) ((T_IS_GREATER_OR_EQUAL) reduce 494) ((T_IS_IDENTICAL) reduce 494) ((T_IS_NOT_EQUAL) reduce 494) ((T_IS_NOT_IDENTICAL) reduce 494) ((T_IS_SMALLER_OR_EQUAL) reduce 494) ((T_LOGICAL_AND) reduce 494) ((T_LOGICAL_OR) reduce 494) ((T_LOGICAL_XOR) reduce 494) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 494) ((T_OBJECT_OPERATOR) reduce 494) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 494) ((T_SL) reduce 494) ((T_SPACESHIP) reduce 494) ((T_SR) reduce 494) (("[") reduce 494) (("^") reduce 494) (("{") reduce 494) (("|") reduce 494)) 284 ((("%") reduce 423) ((")") reduce 423) (("*") reduce 423) (("+") reduce 423) (("-") reduce 423) ((".") reduce 423) (("/") reduce 423) (("<") reduce 423) ((">") reduce 423) (("?") reduce 423) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_BOOLEAN_AND) reduce 423) ((T_BOOLEAN_OR) reduce 423) ((T_COALESCE) reduce 423) ((T_INSTANCEOF) reduce 423) ((T_IS_EQUAL) reduce 423) ((T_IS_GREATER_OR_EQUAL) reduce 423) ((T_IS_IDENTICAL) reduce 423) ((T_IS_NOT_EQUAL) reduce 423) ((T_IS_NOT_IDENTICAL) reduce 423) ((T_IS_SMALLER_OR_EQUAL) reduce 423) ((T_LOGICAL_AND) reduce 423) ((T_LOGICAL_OR) reduce 423) ((T_LOGICAL_XOR) reduce 423) ((T_POW) reduce 423) ((T_SL) reduce 423) ((T_SPACESHIP) reduce 423) ((T_SR) reduce 423) (("^") reduce 423) (("|") reduce 423)) 285 ((("%") reduce 437) ((")") reduce 437) (("*") reduce 437) (("+") reduce 437) (("-") reduce 437) ((".") reduce 437) (("/") reduce 437) (("<") reduce 437) ((">") reduce 437) (("?") reduce 437) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_BOOLEAN_AND) reduce 437) ((T_BOOLEAN_OR) reduce 437) ((T_COALESCE) reduce 437) ((T_INSTANCEOF) reduce 437) ((T_IS_EQUAL) reduce 437) ((T_IS_GREATER_OR_EQUAL) reduce 437) ((T_IS_IDENTICAL) reduce 437) ((T_IS_NOT_EQUAL) reduce 437) ((T_IS_NOT_IDENTICAL) reduce 437) ((T_IS_SMALLER_OR_EQUAL) reduce 437) ((T_LOGICAL_AND) reduce 437) ((T_LOGICAL_OR) reduce 437) ((T_LOGICAL_XOR) reduce 437) ((T_POW) reduce 437) ((T_SL) reduce 437) ((T_SPACESHIP) reduce 437) ((T_SR) reduce 437) (("^") reduce 437) (("|") reduce 437)) 286 ((("%") reduce 519) (("(") reduce 519) ((")") reduce 519) (("*") reduce 519) (("+") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) (("<") reduce 519) (("=") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AND_EQUAL) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_COALESCE_EQUAL) reduce 519) ((T_CONCAT_EQUAL) reduce 519) ((T_DEC) reduce 519) ((T_DIV_EQUAL) reduce 519) ((T_INC) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_MINUS_EQUAL) reduce 519) ((T_MOD_EQUAL) reduce 519) ((T_MUL_EQUAL) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_OR_EQUAL) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_PLUS_EQUAL) reduce 519) ((T_POW) reduce 519) ((T_POW_EQUAL) reduce 519) ((T_SL) reduce 519) ((T_SL_EQUAL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) ((T_SR_EQUAL) reduce 519) ((T_XOR_EQUAL) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 287 ((("%") reduce 526) ((")") reduce 526) (("*") reduce 526) (("+") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) (("<") reduce 526) (("=") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AND_EQUAL) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_COALESCE_EQUAL) reduce 526) ((T_CONCAT_EQUAL) reduce 526) ((T_DEC) reduce 526) ((T_DIV_EQUAL) reduce 526) ((T_INC) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_MINUS_EQUAL) reduce 526) ((T_MOD_EQUAL) reduce 526) ((T_MUL_EQUAL) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_OR_EQUAL) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_PLUS_EQUAL) reduce 526) ((T_POW) reduce 526) ((T_POW_EQUAL) reduce 526) ((T_SL) reduce 526) ((T_SL_EQUAL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) ((T_SR_EQUAL) reduce 526) ((T_XOR_EQUAL) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 288 ((("%") reduce 367) ((")") reduce 367) (("*") reduce 367) (("+") reduce 367) (("-") reduce 367) ((".") reduce 367) (("/") reduce 367) (("<") reduce 367) (("=") shift) ((">") reduce 367) (("?") reduce 367) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AND_EQUAL) shift) ((T_BOOLEAN_AND) reduce 367) ((T_BOOLEAN_OR) reduce 367) ((T_COALESCE) reduce 367) ((T_COALESCE_EQUAL) shift) ((T_CONCAT_EQUAL) shift) ((T_DEC) shift) ((T_DIV_EQUAL) shift) ((T_INC) shift) ((T_INSTANCEOF) reduce 367) ((T_IS_EQUAL) reduce 367) ((T_IS_GREATER_OR_EQUAL) reduce 367) ((T_IS_IDENTICAL) reduce 367) ((T_IS_NOT_EQUAL) reduce 367) ((T_IS_NOT_IDENTICAL) reduce 367) ((T_IS_SMALLER_OR_EQUAL) reduce 367) ((T_LOGICAL_AND) reduce 367) ((T_LOGICAL_OR) reduce 367) ((T_LOGICAL_XOR) reduce 367) ((T_MINUS_EQUAL) shift) ((T_MOD_EQUAL) shift) ((T_MUL_EQUAL) shift) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_OR_EQUAL) shift) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_PLUS_EQUAL) shift) ((T_POW) reduce 367) ((T_POW_EQUAL) shift) ((T_SL) reduce 367) ((T_SL_EQUAL) shift) ((T_SPACESHIP) reduce 367) ((T_SR) reduce 367) ((T_SR_EQUAL) shift) ((T_XOR_EQUAL) shift) (("[") reduce 510) (("^") reduce 367) (("{") reduce 510) (("|") reduce 367)) 291 ((("%") reduce 411) ((")") reduce 411) (("*") reduce 411) (("+") reduce 411) (("-") reduce 411) ((".") reduce 411) (("/") reduce 411) (("<") reduce 411) ((">") reduce 411) (("?") reduce 411) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_BOOLEAN_AND) reduce 411) ((T_BOOLEAN_OR) reduce 411) ((T_COALESCE) reduce 411) ((T_INSTANCEOF) reduce 411) ((T_IS_EQUAL) reduce 411) ((T_IS_GREATER_OR_EQUAL) reduce 411) ((T_IS_IDENTICAL) reduce 411) ((T_IS_NOT_EQUAL) reduce 411) ((T_IS_NOT_IDENTICAL) reduce 411) ((T_IS_SMALLER_OR_EQUAL) reduce 411) ((T_LOGICAL_AND) reduce 411) ((T_LOGICAL_OR) reduce 411) ((T_LOGICAL_XOR) reduce 411) ((T_POW) shift) ((T_SL) reduce 411) ((T_SPACESHIP) reduce 411) ((T_SR) reduce 411) (("^") reduce 411) (("|") reduce 411)) 300 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) (("+") shift) (("-") shift) ((":") shift) (("@") shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("~") shift)) 306 ((("$") shift) (("(") shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_VARIABLE) shift)) 322 ((("%") shift) ((")") reduce 395) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 395) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 395) ((T_BOOLEAN_OR) reduce 395) ((T_COALESCE) reduce 395) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 395) ((T_LOGICAL_OR) reduce 395) ((T_LOGICAL_XOR) reduce 395) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") reduce 395)) 323 ((("%") shift) ((")") reduce 398) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 398) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 398) ((T_BOOLEAN_OR) reduce 398) ((T_COALESCE) reduce 398) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 398) ((T_LOGICAL_OR) reduce 398) ((T_LOGICAL_XOR) reduce 398) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 398) (("|") reduce 398)) 324 ((("%") shift) ((")") reduce 407) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 407) (("/") shift) (("<") reduce 407) ((">") reduce 407) (("?") reduce 407) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_BOOLEAN_AND) reduce 407) ((T_BOOLEAN_OR) reduce 407) ((T_COALESCE) reduce 407) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 407) ((T_IS_GREATER_OR_EQUAL) reduce 407) ((T_IS_IDENTICAL) reduce 407) ((T_IS_NOT_EQUAL) reduce 407) ((T_IS_NOT_IDENTICAL) reduce 407) ((T_IS_SMALLER_OR_EQUAL) reduce 407) ((T_LOGICAL_AND) reduce 407) ((T_LOGICAL_OR) reduce 407) ((T_LOGICAL_XOR) reduce 407) ((T_POW) shift) ((T_SL) reduce 407) ((T_SPACESHIP) reduce 407) ((T_SR) reduce 407) (("^") reduce 407) (("|") reduce 407)) 325 ((("%") shift) ((")") reduce 420) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 420) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_BOOLEAN_AND) reduce 420) ((T_BOOLEAN_OR) reduce 420) ((T_COALESCE) reduce 420) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 420) ((T_LOGICAL_OR) reduce 420) ((T_LOGICAL_XOR) reduce 420) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 420) (("|") reduce 420)) 326 ((("%") shift) ((")") reduce 406) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 406) (("/") shift) (("<") reduce 406) ((">") reduce 406) (("?") reduce 406) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_BOOLEAN_AND) reduce 406) ((T_BOOLEAN_OR) reduce 406) ((T_COALESCE) reduce 406) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 406) ((T_IS_GREATER_OR_EQUAL) reduce 406) ((T_IS_IDENTICAL) reduce 406) ((T_IS_NOT_EQUAL) reduce 406) ((T_IS_NOT_IDENTICAL) reduce 406) ((T_IS_SMALLER_OR_EQUAL) reduce 406) ((T_LOGICAL_AND) reduce 406) ((T_LOGICAL_OR) reduce 406) ((T_LOGICAL_XOR) reduce 406) ((T_POW) shift) ((T_SL) reduce 406) ((T_SPACESHIP) reduce 406) ((T_SR) reduce 406) (("^") reduce 406) (("|") reduce 406)) 327 ((("%") reduce 403) ((")") reduce 403) (("*") reduce 403) (("+") reduce 403) (("-") reduce 403) ((".") reduce 403) (("/") reduce 403) (("<") reduce 403) ((">") reduce 403) (("?") reduce 403) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_BOOLEAN_AND) reduce 403) ((T_BOOLEAN_OR) reduce 403) ((T_COALESCE) reduce 403) ((T_INSTANCEOF) reduce 403) ((T_IS_EQUAL) reduce 403) ((T_IS_GREATER_OR_EQUAL) reduce 403) ((T_IS_IDENTICAL) reduce 403) ((T_IS_NOT_EQUAL) reduce 403) ((T_IS_NOT_IDENTICAL) reduce 403) ((T_IS_SMALLER_OR_EQUAL) reduce 403) ((T_LOGICAL_AND) reduce 403) ((T_LOGICAL_OR) reduce 403) ((T_LOGICAL_XOR) reduce 403) ((T_POW) shift) ((T_SL) reduce 403) ((T_SPACESHIP) reduce 403) ((T_SR) reduce 403) (("^") reduce 403) (("|") reduce 403)) 328 ((("%") shift) ((")") reduce 394) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 394) ((T_LOGICAL_XOR) reduce 394) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 329 ((("%") shift) ((")") reduce 392) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 392) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 330 ((("%") shift) ((")") reduce 393) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 393) ((T_LOGICAL_OR) reduce 393) ((T_LOGICAL_XOR) reduce 393) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 331 ((("%") shift) ((")") reduce 417) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 417) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_BOOLEAN_AND) reduce 417) ((T_BOOLEAN_OR) reduce 417) ((T_COALESCE) reduce 417) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 417) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 417) ((T_IS_NOT_EQUAL) reduce 417) ((T_IS_NOT_IDENTICAL) reduce 417) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 417) ((T_LOGICAL_OR) reduce 417) ((T_LOGICAL_XOR) reduce 417) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 417) ((T_SR) shift) (("^") reduce 417) (("|") reduce 417)) 332 ((("%") shift) ((")") reduce 413) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 413) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_BOOLEAN_AND) reduce 413) ((T_BOOLEAN_OR) reduce 413) ((T_COALESCE) reduce 413) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 413) ((T_LOGICAL_OR) reduce 413) ((T_LOGICAL_XOR) reduce 413) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 413) (("|") reduce 413)) 333 ((("%") shift) ((")") reduce 415) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 415) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_BOOLEAN_AND) reduce 415) ((T_BOOLEAN_OR) reduce 415) ((T_COALESCE) reduce 415) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 415) ((T_LOGICAL_OR) reduce 415) ((T_LOGICAL_XOR) reduce 415) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 415) (("|") reduce 415)) 334 ((("%") shift) ((")") reduce 412) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 412) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_BOOLEAN_AND) reduce 412) ((T_BOOLEAN_OR) reduce 412) ((T_COALESCE) reduce 412) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 412) ((T_LOGICAL_OR) reduce 412) ((T_LOGICAL_XOR) reduce 412) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 412) (("|") reduce 412)) 335 ((("%") shift) ((")") reduce 419) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 419) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_BOOLEAN_AND) reduce 419) ((T_BOOLEAN_OR) reduce 419) ((T_COALESCE) reduce 419) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 419) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 419) ((T_IS_NOT_EQUAL) reduce 419) ((T_IS_NOT_IDENTICAL) reduce 419) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 419) ((T_LOGICAL_OR) reduce 419) ((T_LOGICAL_XOR) reduce 419) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 419) ((T_SR) shift) (("^") reduce 419) (("|") reduce 419)) 336 ((("%") shift) ((")") reduce 414) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 414) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_BOOLEAN_AND) reduce 414) ((T_BOOLEAN_OR) reduce 414) ((T_COALESCE) reduce 414) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 414) ((T_LOGICAL_OR) reduce 414) ((T_LOGICAL_XOR) reduce 414) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 414) (("|") reduce 414)) 339 ((("%") reduce 93) ((")") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93)) 340 ((("%") reduce 92) ((")") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92)) 341 ((("%") reduce 94) ((")") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94)) 342 ((("%") reduce 470) ((")") reduce 470) (("*") reduce 470) (("+") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470)) 343 ((("%") reduce 91) ((")") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91)) 344 ((("%") reduce 529) ((")") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 345 ((("%") reduce 472) ((")") reduce 472) (("*") reduce 472) (("+") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472)) 346 ((("%") reduce 421) ((")") reduce 421) (("*") reduce 421) (("+") reduce 421) (("-") reduce 421) ((".") reduce 421) (("/") reduce 421) (("<") reduce 421) ((">") reduce 421) (("?") reduce 421) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_BOOLEAN_AND) reduce 421) ((T_BOOLEAN_OR) reduce 421) ((T_COALESCE) reduce 421) ((T_INSTANCEOF) reduce 421) ((T_IS_EQUAL) reduce 421) ((T_IS_GREATER_OR_EQUAL) reduce 421) ((T_IS_IDENTICAL) reduce 421) ((T_IS_NOT_EQUAL) reduce 421) ((T_IS_NOT_IDENTICAL) reduce 421) ((T_IS_SMALLER_OR_EQUAL) reduce 421) ((T_LOGICAL_AND) reduce 421) ((T_LOGICAL_OR) reduce 421) ((T_LOGICAL_XOR) reduce 421) ((T_POW) reduce 421) ((T_SL) reduce 421) ((T_SPACESHIP) reduce 421) ((T_SR) reduce 421) (("^") reduce 421) (("|") reduce 421)) 347 ((("%") reduce 471) ((")") reduce 471) (("*") reduce 471) (("+") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471)) 348 ((("%") reduce 473) ((")") reduce 473) (("*") reduce 473) (("+") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 349 ((("%") reduce 534) ((")") reduce 534) (("*") reduce 534) (("+") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 350 ((("$") shift) ((T_STRING) shift) ((T_VARIABLE) shift) (("{") shift)) 353 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) (("+") shift) (("-") shift) (("@") shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("]") reduce 507) (("`") shift) (("~") shift)) 365 ((("%") reduce 502) (("*") reduce 502) (("+") reduce 502) (("-") reduce 502) ((".") reduce 502) (("/") reduce 502) (("<") reduce 502) ((">") reduce 502) (("?") reduce 502) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_BOOLEAN_AND) reduce 502) ((T_BOOLEAN_OR) reduce 502) ((T_COALESCE) reduce 502) ((T_INSTANCEOF) reduce 502) ((T_IS_EQUAL) reduce 502) ((T_IS_GREATER_OR_EQUAL) reduce 502) ((T_IS_IDENTICAL) reduce 502) ((T_IS_NOT_EQUAL) reduce 502) ((T_IS_NOT_IDENTICAL) reduce 502) ((T_IS_SMALLER_OR_EQUAL) reduce 502) ((T_LOGICAL_AND) reduce 502) ((T_LOGICAL_OR) reduce 502) ((T_LOGICAL_XOR) reduce 502) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 502) ((T_OBJECT_OPERATOR) reduce 502) ((T_POW) reduce 502) ((T_SL) reduce 502) ((T_SPACESHIP) reduce 502) ((T_SR) reduce 502) (("[") reduce 502) (("^") reduce 502) (("{") reduce 502) (("|") reduce 502) (("}") reduce 502)) 367 ((("%") reduce 484) (("(") reduce 484) (("*") reduce 484) (("+") reduce 484) (("-") reduce 484) ((".") reduce 484) (("/") reduce 484) (("<") reduce 484) ((">") reduce 484) (("?") reduce 484) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_BOOLEAN_AND) reduce 484) ((T_BOOLEAN_OR) reduce 484) ((T_COALESCE) reduce 484) ((T_INSTANCEOF) reduce 484) ((T_IS_EQUAL) reduce 484) ((T_IS_GREATER_OR_EQUAL) reduce 484) ((T_IS_IDENTICAL) reduce 484) ((T_IS_NOT_EQUAL) reduce 484) ((T_IS_NOT_IDENTICAL) reduce 484) ((T_IS_SMALLER_OR_EQUAL) reduce 484) ((T_LOGICAL_AND) reduce 484) ((T_LOGICAL_OR) reduce 484) ((T_LOGICAL_XOR) reduce 484) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 484) ((T_OBJECT_OPERATOR) reduce 484) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 484) ((T_POW) reduce 484) ((T_SL) reduce 484) ((T_SPACESHIP) reduce 484) ((T_SR) reduce 484) (("[") reduce 484) (("^") reduce 484) (("{") reduce 484) (("|") reduce 484) (("}") reduce 484)) 369 ((("%") reduce 497) (("*") reduce 497) (("+") reduce 497) (("-") reduce 497) ((".") reduce 497) (("/") reduce 497) (("<") reduce 497) ((">") reduce 497) (("?") reduce 497) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_BOOLEAN_AND) reduce 497) ((T_BOOLEAN_OR) reduce 497) ((T_COALESCE) reduce 497) ((T_INSTANCEOF) reduce 497) ((T_IS_EQUAL) reduce 497) ((T_IS_GREATER_OR_EQUAL) reduce 497) ((T_IS_IDENTICAL) reduce 497) ((T_IS_NOT_EQUAL) reduce 497) ((T_IS_NOT_IDENTICAL) reduce 497) ((T_IS_SMALLER_OR_EQUAL) reduce 497) ((T_LOGICAL_AND) reduce 497) ((T_LOGICAL_OR) reduce 497) ((T_LOGICAL_XOR) reduce 497) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 497) ((T_OBJECT_OPERATOR) reduce 497) ((T_POW) reduce 497) ((T_SL) reduce 497) ((T_SPACESHIP) reduce 497) ((T_SR) reduce 497) (("[") reduce 497) (("^") reduce 497) (("{") reduce 497) (("|") reduce 497) (("}") reduce 497)) 370 ((("%") reduce 487) (("*") reduce 487) (("+") reduce 487) (("-") reduce 487) ((".") reduce 487) (("/") reduce 487) (("<") reduce 487) ((">") reduce 487) (("?") reduce 487) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_BOOLEAN_AND) reduce 487) ((T_BOOLEAN_OR) reduce 487) ((T_COALESCE) reduce 487) ((T_INSTANCEOF) reduce 487) ((T_IS_EQUAL) reduce 487) ((T_IS_GREATER_OR_EQUAL) reduce 487) ((T_IS_IDENTICAL) reduce 487) ((T_IS_NOT_EQUAL) reduce 487) ((T_IS_NOT_IDENTICAL) reduce 487) ((T_IS_SMALLER_OR_EQUAL) reduce 487) ((T_LOGICAL_AND) reduce 487) ((T_LOGICAL_OR) reduce 487) ((T_LOGICAL_XOR) reduce 487) ((T_POW) reduce 487) ((T_SL) reduce 487) ((T_SPACESHIP) reduce 487) ((T_SR) reduce 487) (("^") reduce 487) (("|") reduce 487) (("}") reduce 487)) 374 ((("%") reduce 475) (("(") shift) (("*") reduce 475) (("+") reduce 475) (("-") reduce 475) ((".") reduce 475) (("/") reduce 475) (("<") reduce 475) ((">") reduce 475) (("?") reduce 475) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_BOOLEAN_AND) reduce 475) ((T_BOOLEAN_OR) reduce 475) ((T_COALESCE) reduce 475) ((T_INSTANCEOF) reduce 475) ((T_IS_EQUAL) reduce 475) ((T_IS_GREATER_OR_EQUAL) reduce 475) ((T_IS_IDENTICAL) reduce 475) ((T_IS_NOT_EQUAL) reduce 475) ((T_IS_NOT_IDENTICAL) reduce 475) ((T_IS_SMALLER_OR_EQUAL) reduce 475) ((T_LOGICAL_AND) reduce 475) ((T_LOGICAL_OR) reduce 475) ((T_LOGICAL_XOR) reduce 475) ((T_POW) reduce 475) ((T_SL) reduce 475) ((T_SPACESHIP) reduce 475) ((T_SR) reduce 475) (("^") reduce 475) (("|") reduce 475) (("}") reduce 475)) 375 ((("%") reduce 496) (("*") reduce 496) (("+") reduce 496) (("-") reduce 496) ((".") reduce 496) (("/") reduce 496) (("<") reduce 496) ((">") reduce 496) (("?") reduce 496) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_BOOLEAN_AND) reduce 496) ((T_BOOLEAN_OR) reduce 496) ((T_COALESCE) reduce 496) ((T_INSTANCEOF) reduce 496) ((T_IS_EQUAL) reduce 496) ((T_IS_GREATER_OR_EQUAL) reduce 496) ((T_IS_IDENTICAL) reduce 496) ((T_IS_NOT_EQUAL) reduce 496) ((T_IS_NOT_IDENTICAL) reduce 496) ((T_IS_SMALLER_OR_EQUAL) reduce 496) ((T_LOGICAL_AND) reduce 496) ((T_LOGICAL_OR) reduce 496) ((T_LOGICAL_XOR) reduce 496) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 496) ((T_OBJECT_OPERATOR) reduce 496) ((T_POW) reduce 496) ((T_SL) reduce 496) ((T_SPACESHIP) reduce 496) ((T_SR) reduce 496) (("[") reduce 496) (("^") reduce 496) (("{") reduce 496) (("|") reduce 496) (("}") reduce 496)) 376 ((("%") reduce 500) (("*") reduce 500) (("+") reduce 500) (("-") reduce 500) ((".") reduce 500) (("/") reduce 500) (("<") reduce 500) ((">") reduce 500) (("?") reduce 500) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_BOOLEAN_AND) reduce 500) ((T_BOOLEAN_OR) reduce 500) ((T_COALESCE) reduce 500) ((T_INSTANCEOF) reduce 500) ((T_IS_EQUAL) reduce 500) ((T_IS_GREATER_OR_EQUAL) reduce 500) ((T_IS_IDENTICAL) reduce 500) ((T_IS_NOT_EQUAL) reduce 500) ((T_IS_NOT_IDENTICAL) reduce 500) ((T_IS_SMALLER_OR_EQUAL) reduce 500) ((T_LOGICAL_AND) reduce 500) ((T_LOGICAL_OR) reduce 500) ((T_LOGICAL_XOR) reduce 500) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 500) ((T_OBJECT_OPERATOR) reduce 500) ((T_POW) reduce 500) ((T_SL) reduce 500) ((T_SPACESHIP) reduce 500) ((T_SR) reduce 500) (("[") reduce 500) (("^") reduce 500) (("{") reduce 500) (("|") reduce 500) (("}") reduce 500)) 382 ((("%") reduce 495) (("*") reduce 495) (("+") reduce 495) (("-") reduce 495) ((".") reduce 495) (("/") reduce 495) (("<") reduce 495) ((">") reduce 495) (("?") reduce 495) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_BOOLEAN_AND) reduce 495) ((T_BOOLEAN_OR) reduce 495) ((T_COALESCE) reduce 495) ((T_INSTANCEOF) reduce 495) ((T_IS_EQUAL) reduce 495) ((T_IS_GREATER_OR_EQUAL) reduce 495) ((T_IS_IDENTICAL) reduce 495) ((T_IS_NOT_EQUAL) reduce 495) ((T_IS_NOT_IDENTICAL) reduce 495) ((T_IS_SMALLER_OR_EQUAL) reduce 495) ((T_LOGICAL_AND) reduce 495) ((T_LOGICAL_OR) reduce 495) ((T_LOGICAL_XOR) reduce 495) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 495) ((T_OBJECT_OPERATOR) reduce 495) ((T_POW) reduce 495) ((T_SL) reduce 495) ((T_SPACESHIP) reduce 495) ((T_SR) reduce 495) (("[") reduce 495) (("^") reduce 495) (("{") reduce 495) (("|") reduce 495) (("}") reduce 495)) 384 ((("%") reduce 486) (("*") reduce 486) (("+") reduce 486) (("-") reduce 486) ((".") reduce 486) (("/") reduce 486) (("<") reduce 486) ((">") reduce 486) (("?") reduce 486) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_BOOLEAN_AND) reduce 486) ((T_BOOLEAN_OR) reduce 486) ((T_COALESCE) reduce 486) ((T_INSTANCEOF) reduce 486) ((T_IS_EQUAL) reduce 486) ((T_IS_GREATER_OR_EQUAL) reduce 486) ((T_IS_IDENTICAL) reduce 486) ((T_IS_NOT_EQUAL) reduce 486) ((T_IS_NOT_IDENTICAL) reduce 486) ((T_IS_SMALLER_OR_EQUAL) reduce 486) ((T_LOGICAL_AND) reduce 486) ((T_LOGICAL_OR) reduce 486) ((T_LOGICAL_XOR) reduce 486) ((T_POW) reduce 486) ((T_SL) reduce 486) ((T_SPACESHIP) reduce 486) ((T_SR) reduce 486) (("^") reduce 486) (("|") reduce 486) (("}") reduce 486)) 386 ((("%") reduce 499) (("*") reduce 499) (("+") reduce 499) (("-") reduce 499) ((".") reduce 499) (("/") reduce 499) (("<") reduce 499) ((">") reduce 499) (("?") reduce 499) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_BOOLEAN_AND) reduce 499) ((T_BOOLEAN_OR) reduce 499) ((T_COALESCE) reduce 499) ((T_INSTANCEOF) reduce 499) ((T_IS_EQUAL) reduce 499) ((T_IS_GREATER_OR_EQUAL) reduce 499) ((T_IS_IDENTICAL) reduce 499) ((T_IS_NOT_EQUAL) reduce 499) ((T_IS_NOT_IDENTICAL) reduce 499) ((T_IS_SMALLER_OR_EQUAL) reduce 499) ((T_LOGICAL_AND) reduce 499) ((T_LOGICAL_OR) reduce 499) ((T_LOGICAL_XOR) reduce 499) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 499) ((T_OBJECT_OPERATOR) reduce 499) ((T_POW) reduce 499) ((T_SL) reduce 499) ((T_SPACESHIP) reduce 499) ((T_SR) reduce 499) (("[") reduce 499) (("^") reduce 499) (("{") reduce 499) (("|") reduce 499) (("}") reduce 499)) 387 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 93) ((T_OBJECT_OPERATOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("[") reduce 93) (("^") reduce 93) (("{") reduce 93) (("|") reduce 93) (("}") reduce 93)) 388 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 92) ((T_OBJECT_OPERATOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("[") reduce 92) (("^") reduce 92) (("{") reduce 92) (("|") reduce 92) (("}") reduce 92)) 389 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 94) ((T_OBJECT_OPERATOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("[") reduce 94) (("^") reduce 94) (("{") reduce 94) (("|") reduce 94) (("}") reduce 94)) 391 ((("%") reduce 501) (("*") reduce 501) (("+") reduce 501) (("-") reduce 501) ((".") reduce 501) (("/") reduce 501) (("<") reduce 501) ((">") reduce 501) (("?") reduce 501) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_BOOLEAN_AND) reduce 501) ((T_BOOLEAN_OR) reduce 501) ((T_COALESCE) reduce 501) ((T_INSTANCEOF) reduce 501) ((T_IS_EQUAL) reduce 501) ((T_IS_GREATER_OR_EQUAL) reduce 501) ((T_IS_IDENTICAL) reduce 501) ((T_IS_NOT_EQUAL) reduce 501) ((T_IS_NOT_IDENTICAL) reduce 501) ((T_IS_SMALLER_OR_EQUAL) reduce 501) ((T_LOGICAL_AND) reduce 501) ((T_LOGICAL_OR) reduce 501) ((T_LOGICAL_XOR) reduce 501) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 501) ((T_OBJECT_OPERATOR) reduce 501) ((T_POW) reduce 501) ((T_SL) reduce 501) ((T_SPACESHIP) reduce 501) ((T_SR) reduce 501) (("[") reduce 501) (("^") reduce 501) (("{") reduce 501) (("|") reduce 501) (("}") reduce 501)) 399 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 91) ((T_OBJECT_OPERATOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("[") reduce 91) (("^") reduce 91) (("{") reduce 91) (("|") reduce 91) (("}") reduce 91)) 402 ((("%") reduce 498) (("*") reduce 498) (("+") reduce 498) (("-") reduce 498) ((".") reduce 498) (("/") reduce 498) (("<") reduce 498) ((">") reduce 498) (("?") reduce 498) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_BOOLEAN_AND) reduce 498) ((T_BOOLEAN_OR) reduce 498) ((T_COALESCE) reduce 498) ((T_INSTANCEOF) reduce 498) ((T_IS_EQUAL) reduce 498) ((T_IS_GREATER_OR_EQUAL) reduce 498) ((T_IS_IDENTICAL) reduce 498) ((T_IS_NOT_EQUAL) reduce 498) ((T_IS_NOT_IDENTICAL) reduce 498) ((T_IS_SMALLER_OR_EQUAL) reduce 498) ((T_LOGICAL_AND) reduce 498) ((T_LOGICAL_OR) reduce 498) ((T_LOGICAL_XOR) reduce 498) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 498) ((T_OBJECT_OPERATOR) reduce 498) ((T_POW) reduce 498) ((T_SL) reduce 498) ((T_SPACESHIP) reduce 498) ((T_SR) reduce 498) (("[") reduce 498) (("^") reduce 498) (("{") reduce 498) (("|") reduce 498) (("}") reduce 498)) 404 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) (("=") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AND_EQUAL) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_COALESCE_EQUAL) reduce 529) ((T_CONCAT_EQUAL) reduce 529) ((T_DEC) reduce 529) ((T_DIV_EQUAL) reduce 529) ((T_INC) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_MINUS_EQUAL) reduce 529) ((T_MOD_EQUAL) reduce 529) ((T_MUL_EQUAL) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_OR_EQUAL) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_PLUS_EQUAL) reduce 529) ((T_POW) reduce 529) ((T_POW_EQUAL) reduce 529) ((T_SL) reduce 529) ((T_SL_EQUAL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) ((T_SR_EQUAL) reduce 529) ((T_XOR_EQUAL) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529) (("}") reduce 529)) 405 ((("!") shift) (("\"") shift) (("$") shift) (("%") reduce 440) (("(") shift) (("*") reduce 440) (("+") shift) (("-") shift) ((".") reduce 440) (("/") reduce 440) (("<") reduce 440) ((">") reduce 440) (("?") reduce 440) (("@") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOLEAN_AND) reduce 440) ((T_BOOLEAN_OR) reduce 440) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_COALESCE) reduce 440) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INSTANCEOF) reduce 440) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_IS_EQUAL) reduce 440) ((T_IS_GREATER_OR_EQUAL) reduce 440) ((T_IS_IDENTICAL) reduce 440) ((T_IS_NOT_EQUAL) reduce 440) ((T_IS_NOT_IDENTICAL) reduce 440) ((T_IS_SMALLER_OR_EQUAL) reduce 440) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_LOGICAL_AND) reduce 440) ((T_LOGICAL_OR) reduce 440) ((T_LOGICAL_XOR) reduce 440) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_POW) reduce 440) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_SL) reduce 440) ((T_SPACESHIP) reduce 440) ((T_SR) reduce 440) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("^") reduce 440) (("`") shift) (("|") reduce 440) (("}") reduce 440) (("~") shift)) 412 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) (("<") reduce 525) (("=") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AND_EQUAL) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_COALESCE_EQUAL) reduce 525) ((T_CONCAT_EQUAL) reduce 525) ((T_DEC) reduce 525) ((T_DIV_EQUAL) reduce 525) ((T_INC) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_MINUS_EQUAL) reduce 525) ((T_MOD_EQUAL) reduce 525) ((T_MUL_EQUAL) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_OR_EQUAL) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_PLUS_EQUAL) reduce 525) ((T_POW) reduce 525) ((T_POW_EQUAL) reduce 525) ((T_SL) reduce 525) ((T_SL_EQUAL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) ((T_SR_EQUAL) reduce 525) ((T_XOR_EQUAL) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525) (("}") reduce 525)) 413 ((("%") reduce 493) (("*") reduce 493) (("+") reduce 493) (("-") reduce 493) ((".") reduce 493) (("/") reduce 493) (("<") reduce 493) ((">") reduce 493) (("?") reduce 493) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_BOOLEAN_AND) reduce 493) ((T_BOOLEAN_OR) reduce 493) ((T_COALESCE) reduce 493) ((T_INSTANCEOF) reduce 493) ((T_IS_EQUAL) reduce 493) ((T_IS_GREATER_OR_EQUAL) reduce 493) ((T_IS_IDENTICAL) reduce 493) ((T_IS_NOT_EQUAL) reduce 493) ((T_IS_NOT_IDENTICAL) reduce 493) ((T_IS_SMALLER_OR_EQUAL) reduce 493) ((T_LOGICAL_AND) reduce 493) ((T_LOGICAL_OR) reduce 493) ((T_LOGICAL_XOR) reduce 493) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 513) ((T_OBJECT_OPERATOR) reduce 513) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 513) ((T_POW) reduce 493) ((T_SL) reduce 493) ((T_SPACESHIP) reduce 493) ((T_SR) reduce 493) (("[") reduce 513) (("^") reduce 493) (("{") reduce 513) (("|") reduce 493) (("}") reduce 493)) 415 ((("%") reduce 492) (("*") reduce 492) (("+") reduce 492) (("-") reduce 492) ((".") reduce 492) (("/") reduce 492) (("<") reduce 492) ((">") reduce 492) (("?") reduce 492) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_BOOLEAN_AND) reduce 492) ((T_BOOLEAN_OR) reduce 492) ((T_COALESCE) reduce 492) ((T_INSTANCEOF) reduce 492) ((T_IS_EQUAL) reduce 492) ((T_IS_GREATER_OR_EQUAL) reduce 492) ((T_IS_IDENTICAL) reduce 492) ((T_IS_NOT_EQUAL) reduce 492) ((T_IS_NOT_IDENTICAL) reduce 492) ((T_IS_SMALLER_OR_EQUAL) reduce 492) ((T_LOGICAL_AND) reduce 492) ((T_LOGICAL_OR) reduce 492) ((T_LOGICAL_XOR) reduce 492) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 515) ((T_OBJECT_OPERATOR) reduce 515) ((T_POW) reduce 492) ((T_SL) reduce 492) ((T_SPACESHIP) reduce 492) ((T_SR) reduce 492) (("[") reduce 515) (("^") reduce 492) (("{") reduce 515) (("|") reduce 492) (("}") reduce 492)) 416 ((("%") reduce 491) (("(") reduce 518) (("*") reduce 491) (("+") reduce 491) (("-") reduce 491) ((".") reduce 491) (("/") reduce 491) (("<") reduce 491) ((">") reduce 491) (("?") reduce 491) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_BOOLEAN_AND) reduce 491) ((T_BOOLEAN_OR) reduce 491) ((T_COALESCE) reduce 491) ((T_INSTANCEOF) reduce 491) ((T_IS_EQUAL) reduce 491) ((T_IS_GREATER_OR_EQUAL) reduce 491) ((T_IS_IDENTICAL) reduce 491) ((T_IS_NOT_EQUAL) reduce 491) ((T_IS_NOT_IDENTICAL) reduce 491) ((T_IS_SMALLER_OR_EQUAL) reduce 491) ((T_LOGICAL_AND) reduce 491) ((T_LOGICAL_OR) reduce 491) ((T_LOGICAL_XOR) reduce 491) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 512) ((T_OBJECT_OPERATOR) reduce 512) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 512) ((T_POW) reduce 491) ((T_SL) reduce 491) ((T_SPACESHIP) reduce 491) ((T_SR) reduce 491) (("[") reduce 512) (("^") reduce 491) (("{") reduce 512) (("|") reduce 491) (("}") reduce 491)) 417 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") shift)) 420 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) (("<") reduce 524) (("=") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AND_EQUAL) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_COALESCE_EQUAL) reduce 524) ((T_CONCAT_EQUAL) reduce 524) ((T_DEC) reduce 524) ((T_DIV_EQUAL) reduce 524) ((T_INC) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_MINUS_EQUAL) reduce 524) ((T_MOD_EQUAL) reduce 524) ((T_MUL_EQUAL) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_OR_EQUAL) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_PLUS_EQUAL) reduce 524) ((T_POW) reduce 524) ((T_POW_EQUAL) reduce 524) ((T_SL) reduce 524) ((T_SL_EQUAL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) ((T_SR_EQUAL) reduce 524) ((T_XOR_EQUAL) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524) (("}") reduce 524)) 421 ((("%") reduce 445) (("*") reduce 445) (("+") reduce 445) (("-") reduce 445) ((".") reduce 445) (("/") reduce 445) (("<") reduce 445) ((">") reduce 445) (("?") reduce 445) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_BOOLEAN_AND) reduce 445) ((T_BOOLEAN_OR) reduce 445) ((T_COALESCE) reduce 445) ((T_INSTANCEOF) reduce 445) ((T_IS_EQUAL) reduce 445) ((T_IS_GREATER_OR_EQUAL) reduce 445) ((T_IS_IDENTICAL) reduce 445) ((T_IS_NOT_EQUAL) reduce 445) ((T_IS_NOT_IDENTICAL) reduce 445) ((T_IS_SMALLER_OR_EQUAL) reduce 445) ((T_LOGICAL_AND) reduce 445) ((T_LOGICAL_OR) reduce 445) ((T_LOGICAL_XOR) reduce 445) ((T_POW) reduce 445) ((T_SL) reduce 445) ((T_SPACESHIP) reduce 445) ((T_SR) reduce 445) (("^") reduce 445) (("|") reduce 445) (("}") reduce 445)) 422 ((("%") reduce 427) (("*") reduce 427) (("+") reduce 427) (("-") reduce 427) ((".") reduce 427) (("/") reduce 427) (("<") reduce 427) ((">") reduce 427) (("?") reduce 427) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_BOOLEAN_AND) reduce 427) ((T_BOOLEAN_OR) reduce 427) ((T_COALESCE) reduce 427) ((T_INSTANCEOF) reduce 427) ((T_IS_EQUAL) reduce 427) ((T_IS_GREATER_OR_EQUAL) reduce 427) ((T_IS_IDENTICAL) reduce 427) ((T_IS_NOT_EQUAL) reduce 427) ((T_IS_NOT_IDENTICAL) reduce 427) ((T_IS_SMALLER_OR_EQUAL) reduce 427) ((T_LOGICAL_AND) reduce 427) ((T_LOGICAL_OR) reduce 427) ((T_LOGICAL_XOR) reduce 427) ((T_POW) reduce 427) ((T_SL) reduce 427) ((T_SPACESHIP) reduce 427) ((T_SR) reduce 427) (("^") reduce 427) (("|") reduce 427) (("}") reduce 427)) 423 ((("%") reduce 449) (("*") reduce 449) (("+") reduce 449) (("-") reduce 449) ((".") reduce 449) (("/") reduce 449) (("<") reduce 449) ((">") reduce 449) (("?") reduce 449) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_BOOLEAN_AND) reduce 449) ((T_BOOLEAN_OR) reduce 449) ((T_COALESCE) reduce 449) ((T_INSTANCEOF) reduce 449) ((T_IS_EQUAL) reduce 449) ((T_IS_GREATER_OR_EQUAL) reduce 449) ((T_IS_IDENTICAL) reduce 449) ((T_IS_NOT_EQUAL) reduce 449) ((T_IS_NOT_IDENTICAL) reduce 449) ((T_IS_SMALLER_OR_EQUAL) reduce 449) ((T_LOGICAL_AND) reduce 449) ((T_LOGICAL_OR) reduce 449) ((T_LOGICAL_XOR) reduce 449) ((T_POW) reduce 449) ((T_SL) reduce 449) ((T_SPACESHIP) reduce 449) ((T_SR) reduce 449) (("^") reduce 449) (("|") reduce 449) (("}") reduce 449)) 424 ((("%") reduce 494) (("(") shift) (("*") reduce 494) (("+") reduce 494) (("-") reduce 494) ((".") reduce 494) (("/") reduce 494) (("<") reduce 494) ((">") reduce 494) (("?") reduce 494) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_BOOLEAN_AND) reduce 494) ((T_BOOLEAN_OR) reduce 494) ((T_COALESCE) reduce 494) ((T_INSTANCEOF) reduce 494) ((T_IS_EQUAL) reduce 494) ((T_IS_GREATER_OR_EQUAL) reduce 494) ((T_IS_IDENTICAL) reduce 494) ((T_IS_NOT_EQUAL) reduce 494) ((T_IS_NOT_IDENTICAL) reduce 494) ((T_IS_SMALLER_OR_EQUAL) reduce 494) ((T_LOGICAL_AND) reduce 494) ((T_LOGICAL_OR) reduce 494) ((T_LOGICAL_XOR) reduce 494) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 494) ((T_OBJECT_OPERATOR) reduce 494) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 494) ((T_SL) reduce 494) ((T_SPACESHIP) reduce 494) ((T_SR) reduce 494) (("[") reduce 494) (("^") reduce 494) (("{") reduce 494) (("|") reduce 494) (("}") reduce 494)) 425 ((("%") reduce 423) (("*") reduce 423) (("+") reduce 423) (("-") reduce 423) ((".") reduce 423) (("/") reduce 423) (("<") reduce 423) ((">") reduce 423) (("?") reduce 423) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_BOOLEAN_AND) reduce 423) ((T_BOOLEAN_OR) reduce 423) ((T_COALESCE) reduce 423) ((T_INSTANCEOF) reduce 423) ((T_IS_EQUAL) reduce 423) ((T_IS_GREATER_OR_EQUAL) reduce 423) ((T_IS_IDENTICAL) reduce 423) ((T_IS_NOT_EQUAL) reduce 423) ((T_IS_NOT_IDENTICAL) reduce 423) ((T_IS_SMALLER_OR_EQUAL) reduce 423) ((T_LOGICAL_AND) reduce 423) ((T_LOGICAL_OR) reduce 423) ((T_LOGICAL_XOR) reduce 423) ((T_POW) reduce 423) ((T_SL) reduce 423) ((T_SPACESHIP) reduce 423) ((T_SR) reduce 423) (("^") reduce 423) (("|") reduce 423) (("}") reduce 423)) 426 ((("%") reduce 437) (("*") reduce 437) (("+") reduce 437) (("-") reduce 437) ((".") reduce 437) (("/") reduce 437) (("<") reduce 437) ((">") reduce 437) (("?") reduce 437) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_BOOLEAN_AND) reduce 437) ((T_BOOLEAN_OR) reduce 437) ((T_COALESCE) reduce 437) ((T_INSTANCEOF) reduce 437) ((T_IS_EQUAL) reduce 437) ((T_IS_GREATER_OR_EQUAL) reduce 437) ((T_IS_IDENTICAL) reduce 437) ((T_IS_NOT_EQUAL) reduce 437) ((T_IS_NOT_IDENTICAL) reduce 437) ((T_IS_SMALLER_OR_EQUAL) reduce 437) ((T_LOGICAL_AND) reduce 437) ((T_LOGICAL_OR) reduce 437) ((T_LOGICAL_XOR) reduce 437) ((T_POW) reduce 437) ((T_SL) reduce 437) ((T_SPACESHIP) reduce 437) ((T_SR) reduce 437) (("^") reduce 437) (("|") reduce 437) (("}") reduce 437)) 427 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) (("<") reduce 519) (("=") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AND_EQUAL) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_COALESCE_EQUAL) reduce 519) ((T_CONCAT_EQUAL) reduce 519) ((T_DEC) reduce 519) ((T_DIV_EQUAL) reduce 519) ((T_INC) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_MINUS_EQUAL) reduce 519) ((T_MOD_EQUAL) reduce 519) ((T_MUL_EQUAL) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_OR_EQUAL) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_PLUS_EQUAL) reduce 519) ((T_POW) reduce 519) ((T_POW_EQUAL) reduce 519) ((T_SL) reduce 519) ((T_SL_EQUAL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) ((T_SR_EQUAL) reduce 519) ((T_XOR_EQUAL) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519) (("}") reduce 519)) 428 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) (("<") reduce 526) (("=") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AND_EQUAL) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_COALESCE_EQUAL) reduce 526) ((T_CONCAT_EQUAL) reduce 526) ((T_DEC) reduce 526) ((T_DIV_EQUAL) reduce 526) ((T_INC) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_MINUS_EQUAL) reduce 526) ((T_MOD_EQUAL) reduce 526) ((T_MUL_EQUAL) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_OR_EQUAL) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_PLUS_EQUAL) reduce 526) ((T_POW) reduce 526) ((T_POW_EQUAL) reduce 526) ((T_SL) reduce 526) ((T_SL_EQUAL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) ((T_SR_EQUAL) reduce 526) ((T_XOR_EQUAL) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526) (("}") reduce 526)) 429 ((("%") reduce 367) (("*") reduce 367) (("+") reduce 367) (("-") reduce 367) ((".") reduce 367) (("/") reduce 367) (("<") reduce 367) (("=") shift) ((">") reduce 367) (("?") reduce 367) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AND_EQUAL) shift) ((T_BOOLEAN_AND) reduce 367) ((T_BOOLEAN_OR) reduce 367) ((T_COALESCE) reduce 367) ((T_COALESCE_EQUAL) shift) ((T_CONCAT_EQUAL) shift) ((T_DEC) shift) ((T_DIV_EQUAL) shift) ((T_INC) shift) ((T_INSTANCEOF) reduce 367) ((T_IS_EQUAL) reduce 367) ((T_IS_GREATER_OR_EQUAL) reduce 367) ((T_IS_IDENTICAL) reduce 367) ((T_IS_NOT_EQUAL) reduce 367) ((T_IS_NOT_IDENTICAL) reduce 367) ((T_IS_SMALLER_OR_EQUAL) reduce 367) ((T_LOGICAL_AND) reduce 367) ((T_LOGICAL_OR) reduce 367) ((T_LOGICAL_XOR) reduce 367) ((T_MINUS_EQUAL) shift) ((T_MOD_EQUAL) shift) ((T_MUL_EQUAL) shift) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_OR_EQUAL) shift) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_PLUS_EQUAL) shift) ((T_POW) reduce 367) ((T_POW_EQUAL) shift) ((T_SL) reduce 367) ((T_SL_EQUAL) shift) ((T_SPACESHIP) reduce 367) ((T_SR) reduce 367) ((T_SR_EQUAL) shift) ((T_XOR_EQUAL) shift) (("[") reduce 510) (("^") reduce 367) (("{") reduce 510) (("|") reduce 367) (("}") reduce 367)) 432 ((("%") reduce 411) (("*") reduce 411) (("+") reduce 411) (("-") reduce 411) ((".") reduce 411) (("/") reduce 411) (("<") reduce 411) ((">") reduce 411) (("?") reduce 411) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_BOOLEAN_AND) reduce 411) ((T_BOOLEAN_OR) reduce 411) ((T_COALESCE) reduce 411) ((T_INSTANCEOF) reduce 411) ((T_IS_EQUAL) reduce 411) ((T_IS_GREATER_OR_EQUAL) reduce 411) ((T_IS_IDENTICAL) reduce 411) ((T_IS_NOT_EQUAL) reduce 411) ((T_IS_NOT_IDENTICAL) reduce 411) ((T_IS_SMALLER_OR_EQUAL) reduce 411) ((T_LOGICAL_AND) reduce 411) ((T_LOGICAL_OR) reduce 411) ((T_LOGICAL_XOR) reduce 411) ((T_POW) shift) ((T_SL) reduce 411) ((T_SPACESHIP) reduce 411) ((T_SR) reduce 411) (("^") reduce 411) (("|") reduce 411) (("}") reduce 411)) 463 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 395) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 395) ((T_BOOLEAN_OR) reduce 395) ((T_COALESCE) reduce 395) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 395) ((T_LOGICAL_OR) reduce 395) ((T_LOGICAL_XOR) reduce 395) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") reduce 395) (("}") reduce 395)) 464 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 398) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 398) ((T_BOOLEAN_OR) reduce 398) ((T_COALESCE) reduce 398) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 398) ((T_LOGICAL_OR) reduce 398) ((T_LOGICAL_XOR) reduce 398) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 398) (("|") reduce 398) (("}") reduce 398)) 465 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 407) (("/") shift) (("<") reduce 407) ((">") reduce 407) (("?") reduce 407) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_BOOLEAN_AND) reduce 407) ((T_BOOLEAN_OR) reduce 407) ((T_COALESCE) reduce 407) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 407) ((T_IS_GREATER_OR_EQUAL) reduce 407) ((T_IS_IDENTICAL) reduce 407) ((T_IS_NOT_EQUAL) reduce 407) ((T_IS_NOT_IDENTICAL) reduce 407) ((T_IS_SMALLER_OR_EQUAL) reduce 407) ((T_LOGICAL_AND) reduce 407) ((T_LOGICAL_OR) reduce 407) ((T_LOGICAL_XOR) reduce 407) ((T_POW) shift) ((T_SL) reduce 407) ((T_SPACESHIP) reduce 407) ((T_SR) reduce 407) (("^") reduce 407) (("|") reduce 407) (("}") reduce 407)) 466 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 420) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_BOOLEAN_AND) reduce 420) ((T_BOOLEAN_OR) reduce 420) ((T_COALESCE) reduce 420) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 420) ((T_LOGICAL_OR) reduce 420) ((T_LOGICAL_XOR) reduce 420) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 420) (("|") reduce 420) (("}") reduce 420)) 467 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 406) (("/") shift) (("<") reduce 406) ((">") reduce 406) (("?") reduce 406) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_BOOLEAN_AND) reduce 406) ((T_BOOLEAN_OR) reduce 406) ((T_COALESCE) reduce 406) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 406) ((T_IS_GREATER_OR_EQUAL) reduce 406) ((T_IS_IDENTICAL) reduce 406) ((T_IS_NOT_EQUAL) reduce 406) ((T_IS_NOT_IDENTICAL) reduce 406) ((T_IS_SMALLER_OR_EQUAL) reduce 406) ((T_LOGICAL_AND) reduce 406) ((T_LOGICAL_OR) reduce 406) ((T_LOGICAL_XOR) reduce 406) ((T_POW) shift) ((T_SL) reduce 406) ((T_SPACESHIP) reduce 406) ((T_SR) reduce 406) (("^") reduce 406) (("|") reduce 406) (("}") reduce 406)) 468 ((("%") reduce 403) (("*") reduce 403) (("+") reduce 403) (("-") reduce 403) ((".") reduce 403) (("/") reduce 403) (("<") reduce 403) ((">") reduce 403) (("?") reduce 403) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_BOOLEAN_AND) reduce 403) ((T_BOOLEAN_OR) reduce 403) ((T_COALESCE) reduce 403) ((T_INSTANCEOF) reduce 403) ((T_IS_EQUAL) reduce 403) ((T_IS_GREATER_OR_EQUAL) reduce 403) ((T_IS_IDENTICAL) reduce 403) ((T_IS_NOT_EQUAL) reduce 403) ((T_IS_NOT_IDENTICAL) reduce 403) ((T_IS_SMALLER_OR_EQUAL) reduce 403) ((T_LOGICAL_AND) reduce 403) ((T_LOGICAL_OR) reduce 403) ((T_LOGICAL_XOR) reduce 403) ((T_POW) shift) ((T_SL) reduce 403) ((T_SPACESHIP) reduce 403) ((T_SR) reduce 403) (("^") reduce 403) (("|") reduce 403) (("}") reduce 403)) 469 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 394) ((T_LOGICAL_XOR) reduce 394) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 394)) 470 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 392) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 392)) 471 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 393) ((T_LOGICAL_OR) reduce 393) ((T_LOGICAL_XOR) reduce 393) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 393)) 472 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 417) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_BOOLEAN_AND) reduce 417) ((T_BOOLEAN_OR) reduce 417) ((T_COALESCE) reduce 417) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 417) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 417) ((T_IS_NOT_EQUAL) reduce 417) ((T_IS_NOT_IDENTICAL) reduce 417) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 417) ((T_LOGICAL_OR) reduce 417) ((T_LOGICAL_XOR) reduce 417) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 417) ((T_SR) shift) (("^") reduce 417) (("|") reduce 417) (("}") reduce 417)) 473 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 413) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_BOOLEAN_AND) reduce 413) ((T_BOOLEAN_OR) reduce 413) ((T_COALESCE) reduce 413) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 413) ((T_LOGICAL_OR) reduce 413) ((T_LOGICAL_XOR) reduce 413) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 413) (("|") reduce 413) (("}") reduce 413)) 474 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 415) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_BOOLEAN_AND) reduce 415) ((T_BOOLEAN_OR) reduce 415) ((T_COALESCE) reduce 415) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 415) ((T_LOGICAL_OR) reduce 415) ((T_LOGICAL_XOR) reduce 415) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 415) (("|") reduce 415) (("}") reduce 415)) 475 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 412) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_BOOLEAN_AND) reduce 412) ((T_BOOLEAN_OR) reduce 412) ((T_COALESCE) reduce 412) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 412) ((T_LOGICAL_OR) reduce 412) ((T_LOGICAL_XOR) reduce 412) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 412) (("|") reduce 412) (("}") reduce 412)) 476 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 419) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_BOOLEAN_AND) reduce 419) ((T_BOOLEAN_OR) reduce 419) ((T_COALESCE) reduce 419) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 419) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 419) ((T_IS_NOT_EQUAL) reduce 419) ((T_IS_NOT_IDENTICAL) reduce 419) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 419) ((T_LOGICAL_OR) reduce 419) ((T_LOGICAL_XOR) reduce 419) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 419) ((T_SR) shift) (("^") reduce 419) (("|") reduce 419) (("}") reduce 419)) 477 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 414) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_BOOLEAN_AND) reduce 414) ((T_BOOLEAN_OR) reduce 414) ((T_COALESCE) reduce 414) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 414) ((T_LOGICAL_OR) reduce 414) ((T_LOGICAL_XOR) reduce 414) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 414) (("|") reduce 414) (("}") reduce 414)) 480 ((("%") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93) (("}") reduce 93)) 481 ((("%") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92) (("}") reduce 92)) 482 ((("%") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94) (("}") reduce 94)) 483 ((("%") reduce 470) (("*") reduce 470) (("+") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470) (("}") reduce 470)) 484 ((("%") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91) (("}") reduce 91)) 485 ((("%") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529) (("}") reduce 529)) 486 ((("%") reduce 472) (("*") reduce 472) (("+") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472) (("}") reduce 472)) 487 ((("%") reduce 421) (("*") reduce 421) (("+") reduce 421) (("-") reduce 421) ((".") reduce 421) (("/") reduce 421) (("<") reduce 421) ((">") reduce 421) (("?") reduce 421) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_BOOLEAN_AND) reduce 421) ((T_BOOLEAN_OR) reduce 421) ((T_COALESCE) reduce 421) ((T_INSTANCEOF) reduce 421) ((T_IS_EQUAL) reduce 421) ((T_IS_GREATER_OR_EQUAL) reduce 421) ((T_IS_IDENTICAL) reduce 421) ((T_IS_NOT_EQUAL) reduce 421) ((T_IS_NOT_IDENTICAL) reduce 421) ((T_IS_SMALLER_OR_EQUAL) reduce 421) ((T_LOGICAL_AND) reduce 421) ((T_LOGICAL_OR) reduce 421) ((T_LOGICAL_XOR) reduce 421) ((T_POW) reduce 421) ((T_SL) reduce 421) ((T_SPACESHIP) reduce 421) ((T_SR) reduce 421) (("^") reduce 421) (("|") reduce 421) (("}") reduce 421)) 488 ((("%") reduce 471) (("*") reduce 471) (("+") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471) (("}") reduce 471)) 489 ((("%") reduce 473) (("*") reduce 473) (("+") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473) (("}") reduce 473)) 490 ((("%") reduce 534) (("*") reduce 534) (("+") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534) (("}") reduce 534)) 497 ((("%") reduce 536) (("*") reduce 536) (("+") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536) (("}") reduce 536)) 508 ((("%") reduce 502) (("*") reduce 502) (("+") reduce 502) (("-") reduce 502) ((".") reduce 502) (("/") reduce 502) (("<") reduce 502) ((">") reduce 502) (("?") reduce 502) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_BOOLEAN_AND) reduce 502) ((T_BOOLEAN_OR) reduce 502) ((T_COALESCE) reduce 502) ((T_INSTANCEOF) reduce 502) ((T_IS_EQUAL) reduce 502) ((T_IS_GREATER_OR_EQUAL) reduce 502) ((T_IS_IDENTICAL) reduce 502) ((T_IS_NOT_EQUAL) reduce 502) ((T_IS_NOT_IDENTICAL) reduce 502) ((T_IS_SMALLER_OR_EQUAL) reduce 502) ((T_LOGICAL_AND) reduce 502) ((T_LOGICAL_OR) reduce 502) ((T_LOGICAL_XOR) reduce 502) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 502) ((T_OBJECT_OPERATOR) reduce 502) ((T_POW) reduce 502) ((T_SL) reduce 502) ((T_SPACESHIP) reduce 502) ((T_SR) reduce 502) (("[") reduce 502) (("]") reduce 502) (("^") reduce 502) (("{") reduce 502) (("|") reduce 502)) 510 ((("%") reduce 484) (("(") reduce 484) (("*") reduce 484) (("+") reduce 484) (("-") reduce 484) ((".") reduce 484) (("/") reduce 484) (("<") reduce 484) ((">") reduce 484) (("?") reduce 484) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_BOOLEAN_AND) reduce 484) ((T_BOOLEAN_OR) reduce 484) ((T_COALESCE) reduce 484) ((T_INSTANCEOF) reduce 484) ((T_IS_EQUAL) reduce 484) ((T_IS_GREATER_OR_EQUAL) reduce 484) ((T_IS_IDENTICAL) reduce 484) ((T_IS_NOT_EQUAL) reduce 484) ((T_IS_NOT_IDENTICAL) reduce 484) ((T_IS_SMALLER_OR_EQUAL) reduce 484) ((T_LOGICAL_AND) reduce 484) ((T_LOGICAL_OR) reduce 484) ((T_LOGICAL_XOR) reduce 484) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 484) ((T_OBJECT_OPERATOR) reduce 484) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 484) ((T_POW) reduce 484) ((T_SL) reduce 484) ((T_SPACESHIP) reduce 484) ((T_SR) reduce 484) (("[") reduce 484) (("]") reduce 484) (("^") reduce 484) (("{") reduce 484) (("|") reduce 484)) 512 ((("%") reduce 497) (("*") reduce 497) (("+") reduce 497) (("-") reduce 497) ((".") reduce 497) (("/") reduce 497) (("<") reduce 497) ((">") reduce 497) (("?") reduce 497) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_BOOLEAN_AND) reduce 497) ((T_BOOLEAN_OR) reduce 497) ((T_COALESCE) reduce 497) ((T_INSTANCEOF) reduce 497) ((T_IS_EQUAL) reduce 497) ((T_IS_GREATER_OR_EQUAL) reduce 497) ((T_IS_IDENTICAL) reduce 497) ((T_IS_NOT_EQUAL) reduce 497) ((T_IS_NOT_IDENTICAL) reduce 497) ((T_IS_SMALLER_OR_EQUAL) reduce 497) ((T_LOGICAL_AND) reduce 497) ((T_LOGICAL_OR) reduce 497) ((T_LOGICAL_XOR) reduce 497) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 497) ((T_OBJECT_OPERATOR) reduce 497) ((T_POW) reduce 497) ((T_SL) reduce 497) ((T_SPACESHIP) reduce 497) ((T_SR) reduce 497) (("[") reduce 497) (("]") reduce 497) (("^") reduce 497) (("{") reduce 497) (("|") reduce 497)) 513 ((("%") reduce 487) (("*") reduce 487) (("+") reduce 487) (("-") reduce 487) ((".") reduce 487) (("/") reduce 487) (("<") reduce 487) ((">") reduce 487) (("?") reduce 487) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_BOOLEAN_AND) reduce 487) ((T_BOOLEAN_OR) reduce 487) ((T_COALESCE) reduce 487) ((T_INSTANCEOF) reduce 487) ((T_IS_EQUAL) reduce 487) ((T_IS_GREATER_OR_EQUAL) reduce 487) ((T_IS_IDENTICAL) reduce 487) ((T_IS_NOT_EQUAL) reduce 487) ((T_IS_NOT_IDENTICAL) reduce 487) ((T_IS_SMALLER_OR_EQUAL) reduce 487) ((T_LOGICAL_AND) reduce 487) ((T_LOGICAL_OR) reduce 487) ((T_LOGICAL_XOR) reduce 487) ((T_POW) reduce 487) ((T_SL) reduce 487) ((T_SPACESHIP) reduce 487) ((T_SR) reduce 487) (("]") reduce 487) (("^") reduce 487) (("|") reduce 487)) 517 ((("%") reduce 475) (("(") shift) (("*") reduce 475) (("+") reduce 475) (("-") reduce 475) ((".") reduce 475) (("/") reduce 475) (("<") reduce 475) ((">") reduce 475) (("?") reduce 475) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_BOOLEAN_AND) reduce 475) ((T_BOOLEAN_OR) reduce 475) ((T_COALESCE) reduce 475) ((T_INSTANCEOF) reduce 475) ((T_IS_EQUAL) reduce 475) ((T_IS_GREATER_OR_EQUAL) reduce 475) ((T_IS_IDENTICAL) reduce 475) ((T_IS_NOT_EQUAL) reduce 475) ((T_IS_NOT_IDENTICAL) reduce 475) ((T_IS_SMALLER_OR_EQUAL) reduce 475) ((T_LOGICAL_AND) reduce 475) ((T_LOGICAL_OR) reduce 475) ((T_LOGICAL_XOR) reduce 475) ((T_POW) reduce 475) ((T_SL) reduce 475) ((T_SPACESHIP) reduce 475) ((T_SR) reduce 475) (("]") reduce 475) (("^") reduce 475) (("|") reduce 475)) 518 ((("%") reduce 496) (("*") reduce 496) (("+") reduce 496) (("-") reduce 496) ((".") reduce 496) (("/") reduce 496) (("<") reduce 496) ((">") reduce 496) (("?") reduce 496) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_BOOLEAN_AND) reduce 496) ((T_BOOLEAN_OR) reduce 496) ((T_COALESCE) reduce 496) ((T_INSTANCEOF) reduce 496) ((T_IS_EQUAL) reduce 496) ((T_IS_GREATER_OR_EQUAL) reduce 496) ((T_IS_IDENTICAL) reduce 496) ((T_IS_NOT_EQUAL) reduce 496) ((T_IS_NOT_IDENTICAL) reduce 496) ((T_IS_SMALLER_OR_EQUAL) reduce 496) ((T_LOGICAL_AND) reduce 496) ((T_LOGICAL_OR) reduce 496) ((T_LOGICAL_XOR) reduce 496) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 496) ((T_OBJECT_OPERATOR) reduce 496) ((T_POW) reduce 496) ((T_SL) reduce 496) ((T_SPACESHIP) reduce 496) ((T_SR) reduce 496) (("[") reduce 496) (("]") reduce 496) (("^") reduce 496) (("{") reduce 496) (("|") reduce 496)) 519 ((("%") reduce 500) (("*") reduce 500) (("+") reduce 500) (("-") reduce 500) ((".") reduce 500) (("/") reduce 500) (("<") reduce 500) ((">") reduce 500) (("?") reduce 500) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_BOOLEAN_AND) reduce 500) ((T_BOOLEAN_OR) reduce 500) ((T_COALESCE) reduce 500) ((T_INSTANCEOF) reduce 500) ((T_IS_EQUAL) reduce 500) ((T_IS_GREATER_OR_EQUAL) reduce 500) ((T_IS_IDENTICAL) reduce 500) ((T_IS_NOT_EQUAL) reduce 500) ((T_IS_NOT_IDENTICAL) reduce 500) ((T_IS_SMALLER_OR_EQUAL) reduce 500) ((T_LOGICAL_AND) reduce 500) ((T_LOGICAL_OR) reduce 500) ((T_LOGICAL_XOR) reduce 500) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 500) ((T_OBJECT_OPERATOR) reduce 500) ((T_POW) reduce 500) ((T_SL) reduce 500) ((T_SPACESHIP) reduce 500) ((T_SR) reduce 500) (("[") reduce 500) (("]") reduce 500) (("^") reduce 500) (("{") reduce 500) (("|") reduce 500)) 525 ((("%") reduce 495) (("*") reduce 495) (("+") reduce 495) (("-") reduce 495) ((".") reduce 495) (("/") reduce 495) (("<") reduce 495) ((">") reduce 495) (("?") reduce 495) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_BOOLEAN_AND) reduce 495) ((T_BOOLEAN_OR) reduce 495) ((T_COALESCE) reduce 495) ((T_INSTANCEOF) reduce 495) ((T_IS_EQUAL) reduce 495) ((T_IS_GREATER_OR_EQUAL) reduce 495) ((T_IS_IDENTICAL) reduce 495) ((T_IS_NOT_EQUAL) reduce 495) ((T_IS_NOT_IDENTICAL) reduce 495) ((T_IS_SMALLER_OR_EQUAL) reduce 495) ((T_LOGICAL_AND) reduce 495) ((T_LOGICAL_OR) reduce 495) ((T_LOGICAL_XOR) reduce 495) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 495) ((T_OBJECT_OPERATOR) reduce 495) ((T_POW) reduce 495) ((T_SL) reduce 495) ((T_SPACESHIP) reduce 495) ((T_SR) reduce 495) (("[") reduce 495) (("]") reduce 495) (("^") reduce 495) (("{") reduce 495) (("|") reduce 495)) 527 ((("%") reduce 486) (("*") reduce 486) (("+") reduce 486) (("-") reduce 486) ((".") reduce 486) (("/") reduce 486) (("<") reduce 486) ((">") reduce 486) (("?") reduce 486) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_BOOLEAN_AND) reduce 486) ((T_BOOLEAN_OR) reduce 486) ((T_COALESCE) reduce 486) ((T_INSTANCEOF) reduce 486) ((T_IS_EQUAL) reduce 486) ((T_IS_GREATER_OR_EQUAL) reduce 486) ((T_IS_IDENTICAL) reduce 486) ((T_IS_NOT_EQUAL) reduce 486) ((T_IS_NOT_IDENTICAL) reduce 486) ((T_IS_SMALLER_OR_EQUAL) reduce 486) ((T_LOGICAL_AND) reduce 486) ((T_LOGICAL_OR) reduce 486) ((T_LOGICAL_XOR) reduce 486) ((T_POW) reduce 486) ((T_SL) reduce 486) ((T_SPACESHIP) reduce 486) ((T_SR) reduce 486) (("]") reduce 486) (("^") reduce 486) (("|") reduce 486)) 529 ((("%") reduce 499) (("*") reduce 499) (("+") reduce 499) (("-") reduce 499) ((".") reduce 499) (("/") reduce 499) (("<") reduce 499) ((">") reduce 499) (("?") reduce 499) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_BOOLEAN_AND) reduce 499) ((T_BOOLEAN_OR) reduce 499) ((T_COALESCE) reduce 499) ((T_INSTANCEOF) reduce 499) ((T_IS_EQUAL) reduce 499) ((T_IS_GREATER_OR_EQUAL) reduce 499) ((T_IS_IDENTICAL) reduce 499) ((T_IS_NOT_EQUAL) reduce 499) ((T_IS_NOT_IDENTICAL) reduce 499) ((T_IS_SMALLER_OR_EQUAL) reduce 499) ((T_LOGICAL_AND) reduce 499) ((T_LOGICAL_OR) reduce 499) ((T_LOGICAL_XOR) reduce 499) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 499) ((T_OBJECT_OPERATOR) reduce 499) ((T_POW) reduce 499) ((T_SL) reduce 499) ((T_SPACESHIP) reduce 499) ((T_SR) reduce 499) (("[") reduce 499) (("]") reduce 499) (("^") reduce 499) (("{") reduce 499) (("|") reduce 499)) 530 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 93) ((T_OBJECT_OPERATOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("[") reduce 93) (("]") reduce 93) (("^") reduce 93) (("{") reduce 93) (("|") reduce 93)) 531 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 92) ((T_OBJECT_OPERATOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("[") reduce 92) (("]") reduce 92) (("^") reduce 92) (("{") reduce 92) (("|") reduce 92)) 532 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 94) ((T_OBJECT_OPERATOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("[") reduce 94) (("]") reduce 94) (("^") reduce 94) (("{") reduce 94) (("|") reduce 94)) 534 ((("%") reduce 501) (("*") reduce 501) (("+") reduce 501) (("-") reduce 501) ((".") reduce 501) (("/") reduce 501) (("<") reduce 501) ((">") reduce 501) (("?") reduce 501) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_BOOLEAN_AND) reduce 501) ((T_BOOLEAN_OR) reduce 501) ((T_COALESCE) reduce 501) ((T_INSTANCEOF) reduce 501) ((T_IS_EQUAL) reduce 501) ((T_IS_GREATER_OR_EQUAL) reduce 501) ((T_IS_IDENTICAL) reduce 501) ((T_IS_NOT_EQUAL) reduce 501) ((T_IS_NOT_IDENTICAL) reduce 501) ((T_IS_SMALLER_OR_EQUAL) reduce 501) ((T_LOGICAL_AND) reduce 501) ((T_LOGICAL_OR) reduce 501) ((T_LOGICAL_XOR) reduce 501) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 501) ((T_OBJECT_OPERATOR) reduce 501) ((T_POW) reduce 501) ((T_SL) reduce 501) ((T_SPACESHIP) reduce 501) ((T_SR) reduce 501) (("[") reduce 501) (("]") reduce 501) (("^") reduce 501) (("{") reduce 501) (("|") reduce 501)) 542 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 91) ((T_OBJECT_OPERATOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("[") reduce 91) (("]") reduce 91) (("^") reduce 91) (("{") reduce 91) (("|") reduce 91)) 545 ((("%") reduce 498) (("*") reduce 498) (("+") reduce 498) (("-") reduce 498) ((".") reduce 498) (("/") reduce 498) (("<") reduce 498) ((">") reduce 498) (("?") reduce 498) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_BOOLEAN_AND) reduce 498) ((T_BOOLEAN_OR) reduce 498) ((T_COALESCE) reduce 498) ((T_INSTANCEOF) reduce 498) ((T_IS_EQUAL) reduce 498) ((T_IS_GREATER_OR_EQUAL) reduce 498) ((T_IS_IDENTICAL) reduce 498) ((T_IS_NOT_EQUAL) reduce 498) ((T_IS_NOT_IDENTICAL) reduce 498) ((T_IS_SMALLER_OR_EQUAL) reduce 498) ((T_LOGICAL_AND) reduce 498) ((T_LOGICAL_OR) reduce 498) ((T_LOGICAL_XOR) reduce 498) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 498) ((T_OBJECT_OPERATOR) reduce 498) ((T_POW) reduce 498) ((T_SL) reduce 498) ((T_SPACESHIP) reduce 498) ((T_SR) reduce 498) (("[") reduce 498) (("]") reduce 498) (("^") reduce 498) (("{") reduce 498) (("|") reduce 498)) 547 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) (("=") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AND_EQUAL) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_COALESCE_EQUAL) reduce 529) ((T_CONCAT_EQUAL) reduce 529) ((T_DEC) reduce 529) ((T_DIV_EQUAL) reduce 529) ((T_INC) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_MINUS_EQUAL) reduce 529) ((T_MOD_EQUAL) reduce 529) ((T_MUL_EQUAL) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_OR_EQUAL) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_PLUS_EQUAL) reduce 529) ((T_POW) reduce 529) ((T_POW_EQUAL) reduce 529) ((T_SL) reduce 529) ((T_SL_EQUAL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) ((T_SR_EQUAL) reduce 529) ((T_XOR_EQUAL) reduce 529) (("[") reduce 529) (("]") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 548 ((("!") shift) (("\"") shift) (("$") shift) (("%") reduce 440) (("(") shift) (("*") reduce 440) (("+") shift) (("-") shift) ((".") reduce 440) (("/") reduce 440) (("<") reduce 440) ((">") reduce 440) (("?") reduce 440) (("@") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOLEAN_AND) reduce 440) ((T_BOOLEAN_OR) reduce 440) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_COALESCE) reduce 440) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INSTANCEOF) reduce 440) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_IS_EQUAL) reduce 440) ((T_IS_GREATER_OR_EQUAL) reduce 440) ((T_IS_IDENTICAL) reduce 440) ((T_IS_NOT_EQUAL) reduce 440) ((T_IS_NOT_IDENTICAL) reduce 440) ((T_IS_SMALLER_OR_EQUAL) reduce 440) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_LOGICAL_AND) reduce 440) ((T_LOGICAL_OR) reduce 440) ((T_LOGICAL_XOR) reduce 440) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_POW) reduce 440) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_SL) reduce 440) ((T_SPACESHIP) reduce 440) ((T_SR) reduce 440) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("]") reduce 440) (("^") reduce 440) (("`") shift) (("|") reduce 440) (("~") shift)) 555 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) (("<") reduce 525) (("=") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AND_EQUAL) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_COALESCE_EQUAL) reduce 525) ((T_CONCAT_EQUAL) reduce 525) ((T_DEC) reduce 525) ((T_DIV_EQUAL) reduce 525) ((T_INC) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_MINUS_EQUAL) reduce 525) ((T_MOD_EQUAL) reduce 525) ((T_MUL_EQUAL) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_OR_EQUAL) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_PLUS_EQUAL) reduce 525) ((T_POW) reduce 525) ((T_POW_EQUAL) reduce 525) ((T_SL) reduce 525) ((T_SL_EQUAL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) ((T_SR_EQUAL) reduce 525) ((T_XOR_EQUAL) reduce 525) (("[") reduce 525) (("]") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 556 ((("%") reduce 493) (("*") reduce 493) (("+") reduce 493) (("-") reduce 493) ((".") reduce 493) (("/") reduce 493) (("<") reduce 493) ((">") reduce 493) (("?") reduce 493) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_BOOLEAN_AND) reduce 493) ((T_BOOLEAN_OR) reduce 493) ((T_COALESCE) reduce 493) ((T_INSTANCEOF) reduce 493) ((T_IS_EQUAL) reduce 493) ((T_IS_GREATER_OR_EQUAL) reduce 493) ((T_IS_IDENTICAL) reduce 493) ((T_IS_NOT_EQUAL) reduce 493) ((T_IS_NOT_IDENTICAL) reduce 493) ((T_IS_SMALLER_OR_EQUAL) reduce 493) ((T_LOGICAL_AND) reduce 493) ((T_LOGICAL_OR) reduce 493) ((T_LOGICAL_XOR) reduce 493) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 513) ((T_OBJECT_OPERATOR) reduce 513) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 513) ((T_POW) reduce 493) ((T_SL) reduce 493) ((T_SPACESHIP) reduce 493) ((T_SR) reduce 493) (("[") reduce 513) (("]") reduce 493) (("^") reduce 493) (("{") reduce 513) (("|") reduce 493)) 558 ((("%") reduce 492) (("*") reduce 492) (("+") reduce 492) (("-") reduce 492) ((".") reduce 492) (("/") reduce 492) (("<") reduce 492) ((">") reduce 492) (("?") reduce 492) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_BOOLEAN_AND) reduce 492) ((T_BOOLEAN_OR) reduce 492) ((T_COALESCE) reduce 492) ((T_INSTANCEOF) reduce 492) ((T_IS_EQUAL) reduce 492) ((T_IS_GREATER_OR_EQUAL) reduce 492) ((T_IS_IDENTICAL) reduce 492) ((T_IS_NOT_EQUAL) reduce 492) ((T_IS_NOT_IDENTICAL) reduce 492) ((T_IS_SMALLER_OR_EQUAL) reduce 492) ((T_LOGICAL_AND) reduce 492) ((T_LOGICAL_OR) reduce 492) ((T_LOGICAL_XOR) reduce 492) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 515) ((T_OBJECT_OPERATOR) reduce 515) ((T_POW) reduce 492) ((T_SL) reduce 492) ((T_SPACESHIP) reduce 492) ((T_SR) reduce 492) (("[") reduce 515) (("]") reduce 492) (("^") reduce 492) (("{") reduce 515) (("|") reduce 492)) 559 ((("%") reduce 491) (("(") reduce 518) (("*") reduce 491) (("+") reduce 491) (("-") reduce 491) ((".") reduce 491) (("/") reduce 491) (("<") reduce 491) ((">") reduce 491) (("?") reduce 491) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_BOOLEAN_AND) reduce 491) ((T_BOOLEAN_OR) reduce 491) ((T_COALESCE) reduce 491) ((T_INSTANCEOF) reduce 491) ((T_IS_EQUAL) reduce 491) ((T_IS_GREATER_OR_EQUAL) reduce 491) ((T_IS_IDENTICAL) reduce 491) ((T_IS_NOT_EQUAL) reduce 491) ((T_IS_NOT_IDENTICAL) reduce 491) ((T_IS_SMALLER_OR_EQUAL) reduce 491) ((T_LOGICAL_AND) reduce 491) ((T_LOGICAL_OR) reduce 491) ((T_LOGICAL_XOR) reduce 491) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 512) ((T_OBJECT_OPERATOR) reduce 512) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 512) ((T_POW) reduce 491) ((T_SL) reduce 491) ((T_SPACESHIP) reduce 491) ((T_SR) reduce 491) (("[") reduce 512) (("]") reduce 491) (("^") reduce 491) (("{") reduce 512) (("|") reduce 491)) 560 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 508) (("^") shift) (("|") shift)) 563 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) (("<") reduce 524) (("=") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AND_EQUAL) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_COALESCE_EQUAL) reduce 524) ((T_CONCAT_EQUAL) reduce 524) ((T_DEC) reduce 524) ((T_DIV_EQUAL) reduce 524) ((T_INC) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_MINUS_EQUAL) reduce 524) ((T_MOD_EQUAL) reduce 524) ((T_MUL_EQUAL) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_OR_EQUAL) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_PLUS_EQUAL) reduce 524) ((T_POW) reduce 524) ((T_POW_EQUAL) reduce 524) ((T_SL) reduce 524) ((T_SL_EQUAL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) ((T_SR_EQUAL) reduce 524) ((T_XOR_EQUAL) reduce 524) (("[") reduce 524) (("]") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 564 ((("%") reduce 445) (("*") reduce 445) (("+") reduce 445) (("-") reduce 445) ((".") reduce 445) (("/") reduce 445) (("<") reduce 445) ((">") reduce 445) (("?") reduce 445) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_BOOLEAN_AND) reduce 445) ((T_BOOLEAN_OR) reduce 445) ((T_COALESCE) reduce 445) ((T_INSTANCEOF) reduce 445) ((T_IS_EQUAL) reduce 445) ((T_IS_GREATER_OR_EQUAL) reduce 445) ((T_IS_IDENTICAL) reduce 445) ((T_IS_NOT_EQUAL) reduce 445) ((T_IS_NOT_IDENTICAL) reduce 445) ((T_IS_SMALLER_OR_EQUAL) reduce 445) ((T_LOGICAL_AND) reduce 445) ((T_LOGICAL_OR) reduce 445) ((T_LOGICAL_XOR) reduce 445) ((T_POW) reduce 445) ((T_SL) reduce 445) ((T_SPACESHIP) reduce 445) ((T_SR) reduce 445) (("]") reduce 445) (("^") reduce 445) (("|") reduce 445)) 565 ((("%") reduce 427) (("*") reduce 427) (("+") reduce 427) (("-") reduce 427) ((".") reduce 427) (("/") reduce 427) (("<") reduce 427) ((">") reduce 427) (("?") reduce 427) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_BOOLEAN_AND) reduce 427) ((T_BOOLEAN_OR) reduce 427) ((T_COALESCE) reduce 427) ((T_INSTANCEOF) reduce 427) ((T_IS_EQUAL) reduce 427) ((T_IS_GREATER_OR_EQUAL) reduce 427) ((T_IS_IDENTICAL) reduce 427) ((T_IS_NOT_EQUAL) reduce 427) ((T_IS_NOT_IDENTICAL) reduce 427) ((T_IS_SMALLER_OR_EQUAL) reduce 427) ((T_LOGICAL_AND) reduce 427) ((T_LOGICAL_OR) reduce 427) ((T_LOGICAL_XOR) reduce 427) ((T_POW) reduce 427) ((T_SL) reduce 427) ((T_SPACESHIP) reduce 427) ((T_SR) reduce 427) (("]") reduce 427) (("^") reduce 427) (("|") reduce 427)) 566 ((("%") reduce 449) (("*") reduce 449) (("+") reduce 449) (("-") reduce 449) ((".") reduce 449) (("/") reduce 449) (("<") reduce 449) ((">") reduce 449) (("?") reduce 449) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_BOOLEAN_AND) reduce 449) ((T_BOOLEAN_OR) reduce 449) ((T_COALESCE) reduce 449) ((T_INSTANCEOF) reduce 449) ((T_IS_EQUAL) reduce 449) ((T_IS_GREATER_OR_EQUAL) reduce 449) ((T_IS_IDENTICAL) reduce 449) ((T_IS_NOT_EQUAL) reduce 449) ((T_IS_NOT_IDENTICAL) reduce 449) ((T_IS_SMALLER_OR_EQUAL) reduce 449) ((T_LOGICAL_AND) reduce 449) ((T_LOGICAL_OR) reduce 449) ((T_LOGICAL_XOR) reduce 449) ((T_POW) reduce 449) ((T_SL) reduce 449) ((T_SPACESHIP) reduce 449) ((T_SR) reduce 449) (("]") reduce 449) (("^") reduce 449) (("|") reduce 449)) 567 ((("%") reduce 494) (("(") shift) (("*") reduce 494) (("+") reduce 494) (("-") reduce 494) ((".") reduce 494) (("/") reduce 494) (("<") reduce 494) ((">") reduce 494) (("?") reduce 494) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_BOOLEAN_AND) reduce 494) ((T_BOOLEAN_OR) reduce 494) ((T_COALESCE) reduce 494) ((T_INSTANCEOF) reduce 494) ((T_IS_EQUAL) reduce 494) ((T_IS_GREATER_OR_EQUAL) reduce 494) ((T_IS_IDENTICAL) reduce 494) ((T_IS_NOT_EQUAL) reduce 494) ((T_IS_NOT_IDENTICAL) reduce 494) ((T_IS_SMALLER_OR_EQUAL) reduce 494) ((T_LOGICAL_AND) reduce 494) ((T_LOGICAL_OR) reduce 494) ((T_LOGICAL_XOR) reduce 494) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 494) ((T_OBJECT_OPERATOR) reduce 494) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 494) ((T_SL) reduce 494) ((T_SPACESHIP) reduce 494) ((T_SR) reduce 494) (("[") reduce 494) (("]") reduce 494) (("^") reduce 494) (("{") reduce 494) (("|") reduce 494)) 568 ((("%") reduce 423) (("*") reduce 423) (("+") reduce 423) (("-") reduce 423) ((".") reduce 423) (("/") reduce 423) (("<") reduce 423) ((">") reduce 423) (("?") reduce 423) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_BOOLEAN_AND) reduce 423) ((T_BOOLEAN_OR) reduce 423) ((T_COALESCE) reduce 423) ((T_INSTANCEOF) reduce 423) ((T_IS_EQUAL) reduce 423) ((T_IS_GREATER_OR_EQUAL) reduce 423) ((T_IS_IDENTICAL) reduce 423) ((T_IS_NOT_EQUAL) reduce 423) ((T_IS_NOT_IDENTICAL) reduce 423) ((T_IS_SMALLER_OR_EQUAL) reduce 423) ((T_LOGICAL_AND) reduce 423) ((T_LOGICAL_OR) reduce 423) ((T_LOGICAL_XOR) reduce 423) ((T_POW) reduce 423) ((T_SL) reduce 423) ((T_SPACESHIP) reduce 423) ((T_SR) reduce 423) (("]") reduce 423) (("^") reduce 423) (("|") reduce 423)) 569 ((("]") shift)) 570 ((("%") reduce 437) (("*") reduce 437) (("+") reduce 437) (("-") reduce 437) ((".") reduce 437) (("/") reduce 437) (("<") reduce 437) ((">") reduce 437) (("?") reduce 437) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_BOOLEAN_AND) reduce 437) ((T_BOOLEAN_OR) reduce 437) ((T_COALESCE) reduce 437) ((T_INSTANCEOF) reduce 437) ((T_IS_EQUAL) reduce 437) ((T_IS_GREATER_OR_EQUAL) reduce 437) ((T_IS_IDENTICAL) reduce 437) ((T_IS_NOT_EQUAL) reduce 437) ((T_IS_NOT_IDENTICAL) reduce 437) ((T_IS_SMALLER_OR_EQUAL) reduce 437) ((T_LOGICAL_AND) reduce 437) ((T_LOGICAL_OR) reduce 437) ((T_LOGICAL_XOR) reduce 437) ((T_POW) reduce 437) ((T_SL) reduce 437) ((T_SPACESHIP) reduce 437) ((T_SR) reduce 437) (("]") reduce 437) (("^") reduce 437) (("|") reduce 437)) 571 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) (("<") reduce 519) (("=") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AND_EQUAL) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_COALESCE_EQUAL) reduce 519) ((T_CONCAT_EQUAL) reduce 519) ((T_DEC) reduce 519) ((T_DIV_EQUAL) reduce 519) ((T_INC) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_MINUS_EQUAL) reduce 519) ((T_MOD_EQUAL) reduce 519) ((T_MUL_EQUAL) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_OR_EQUAL) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_PLUS_EQUAL) reduce 519) ((T_POW) reduce 519) ((T_POW_EQUAL) reduce 519) ((T_SL) reduce 519) ((T_SL_EQUAL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) ((T_SR_EQUAL) reduce 519) ((T_XOR_EQUAL) reduce 519) (("[") reduce 519) (("]") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 572 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) (("<") reduce 526) (("=") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AND_EQUAL) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_COALESCE_EQUAL) reduce 526) ((T_CONCAT_EQUAL) reduce 526) ((T_DEC) reduce 526) ((T_DIV_EQUAL) reduce 526) ((T_INC) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_MINUS_EQUAL) reduce 526) ((T_MOD_EQUAL) reduce 526) ((T_MUL_EQUAL) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_OR_EQUAL) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_PLUS_EQUAL) reduce 526) ((T_POW) reduce 526) ((T_POW_EQUAL) reduce 526) ((T_SL) reduce 526) ((T_SL_EQUAL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) ((T_SR_EQUAL) reduce 526) ((T_XOR_EQUAL) reduce 526) (("[") reduce 526) (("]") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 573 ((("%") reduce 367) (("*") reduce 367) (("+") reduce 367) (("-") reduce 367) ((".") reduce 367) (("/") reduce 367) (("<") reduce 367) (("=") shift) ((">") reduce 367) (("?") reduce 367) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AND_EQUAL) shift) ((T_BOOLEAN_AND) reduce 367) ((T_BOOLEAN_OR) reduce 367) ((T_COALESCE) reduce 367) ((T_COALESCE_EQUAL) shift) ((T_CONCAT_EQUAL) shift) ((T_DEC) shift) ((T_DIV_EQUAL) shift) ((T_INC) shift) ((T_INSTANCEOF) reduce 367) ((T_IS_EQUAL) reduce 367) ((T_IS_GREATER_OR_EQUAL) reduce 367) ((T_IS_IDENTICAL) reduce 367) ((T_IS_NOT_EQUAL) reduce 367) ((T_IS_NOT_IDENTICAL) reduce 367) ((T_IS_SMALLER_OR_EQUAL) reduce 367) ((T_LOGICAL_AND) reduce 367) ((T_LOGICAL_OR) reduce 367) ((T_LOGICAL_XOR) reduce 367) ((T_MINUS_EQUAL) shift) ((T_MOD_EQUAL) shift) ((T_MUL_EQUAL) shift) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_OR_EQUAL) shift) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_PLUS_EQUAL) shift) ((T_POW) reduce 367) ((T_POW_EQUAL) shift) ((T_SL) reduce 367) ((T_SL_EQUAL) shift) ((T_SPACESHIP) reduce 367) ((T_SR) reduce 367) ((T_SR_EQUAL) shift) ((T_XOR_EQUAL) shift) (("[") reduce 510) (("]") reduce 367) (("^") reduce 367) (("{") reduce 510) (("|") reduce 367)) 576 ((("%") reduce 411) (("*") reduce 411) (("+") reduce 411) (("-") reduce 411) ((".") reduce 411) (("/") reduce 411) (("<") reduce 411) ((">") reduce 411) (("?") reduce 411) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_BOOLEAN_AND) reduce 411) ((T_BOOLEAN_OR) reduce 411) ((T_COALESCE) reduce 411) ((T_INSTANCEOF) reduce 411) ((T_IS_EQUAL) reduce 411) ((T_IS_GREATER_OR_EQUAL) reduce 411) ((T_IS_IDENTICAL) reduce 411) ((T_IS_NOT_EQUAL) reduce 411) ((T_IS_NOT_IDENTICAL) reduce 411) ((T_IS_SMALLER_OR_EQUAL) reduce 411) ((T_LOGICAL_AND) reduce 411) ((T_LOGICAL_OR) reduce 411) ((T_LOGICAL_XOR) reduce 411) ((T_POW) shift) ((T_SL) reduce 411) ((T_SPACESHIP) reduce 411) ((T_SR) reduce 411) (("]") reduce 411) (("^") reduce 411) (("|") reduce 411)) 607 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 395) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 395) ((T_BOOLEAN_OR) reduce 395) ((T_COALESCE) reduce 395) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 395) ((T_LOGICAL_OR) reduce 395) ((T_LOGICAL_XOR) reduce 395) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 395) (("^") shift) (("|") reduce 395)) 608 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 398) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 398) ((T_BOOLEAN_OR) reduce 398) ((T_COALESCE) reduce 398) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 398) ((T_LOGICAL_OR) reduce 398) ((T_LOGICAL_XOR) reduce 398) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 398) (("^") reduce 398) (("|") reduce 398)) 609 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 407) (("/") shift) (("<") reduce 407) ((">") reduce 407) (("?") reduce 407) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_BOOLEAN_AND) reduce 407) ((T_BOOLEAN_OR) reduce 407) ((T_COALESCE) reduce 407) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 407) ((T_IS_GREATER_OR_EQUAL) reduce 407) ((T_IS_IDENTICAL) reduce 407) ((T_IS_NOT_EQUAL) reduce 407) ((T_IS_NOT_IDENTICAL) reduce 407) ((T_IS_SMALLER_OR_EQUAL) reduce 407) ((T_LOGICAL_AND) reduce 407) ((T_LOGICAL_OR) reduce 407) ((T_LOGICAL_XOR) reduce 407) ((T_POW) shift) ((T_SL) reduce 407) ((T_SPACESHIP) reduce 407) ((T_SR) reduce 407) (("]") reduce 407) (("^") reduce 407) (("|") reduce 407)) 610 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 420) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_BOOLEAN_AND) reduce 420) ((T_BOOLEAN_OR) reduce 420) ((T_COALESCE) reduce 420) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 420) ((T_LOGICAL_OR) reduce 420) ((T_LOGICAL_XOR) reduce 420) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 420) (("^") reduce 420) (("|") reduce 420)) 611 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 406) (("/") shift) (("<") reduce 406) ((">") reduce 406) (("?") reduce 406) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_BOOLEAN_AND) reduce 406) ((T_BOOLEAN_OR) reduce 406) ((T_COALESCE) reduce 406) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 406) ((T_IS_GREATER_OR_EQUAL) reduce 406) ((T_IS_IDENTICAL) reduce 406) ((T_IS_NOT_EQUAL) reduce 406) ((T_IS_NOT_IDENTICAL) reduce 406) ((T_IS_SMALLER_OR_EQUAL) reduce 406) ((T_LOGICAL_AND) reduce 406) ((T_LOGICAL_OR) reduce 406) ((T_LOGICAL_XOR) reduce 406) ((T_POW) shift) ((T_SL) reduce 406) ((T_SPACESHIP) reduce 406) ((T_SR) reduce 406) (("]") reduce 406) (("^") reduce 406) (("|") reduce 406)) 612 ((("%") reduce 403) (("*") reduce 403) (("+") reduce 403) (("-") reduce 403) ((".") reduce 403) (("/") reduce 403) (("<") reduce 403) ((">") reduce 403) (("?") reduce 403) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_BOOLEAN_AND) reduce 403) ((T_BOOLEAN_OR) reduce 403) ((T_COALESCE) reduce 403) ((T_INSTANCEOF) reduce 403) ((T_IS_EQUAL) reduce 403) ((T_IS_GREATER_OR_EQUAL) reduce 403) ((T_IS_IDENTICAL) reduce 403) ((T_IS_NOT_EQUAL) reduce 403) ((T_IS_NOT_IDENTICAL) reduce 403) ((T_IS_SMALLER_OR_EQUAL) reduce 403) ((T_LOGICAL_AND) reduce 403) ((T_LOGICAL_OR) reduce 403) ((T_LOGICAL_XOR) reduce 403) ((T_POW) shift) ((T_SL) reduce 403) ((T_SPACESHIP) reduce 403) ((T_SR) reduce 403) (("]") reduce 403) (("^") reduce 403) (("|") reduce 403)) 613 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 394) ((T_LOGICAL_XOR) reduce 394) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 394) (("^") shift) (("|") shift)) 614 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 392) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 392) (("^") shift) (("|") shift)) 615 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 393) ((T_LOGICAL_OR) reduce 393) ((T_LOGICAL_XOR) reduce 393) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 393) (("^") shift) (("|") shift)) 616 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 417) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_BOOLEAN_AND) reduce 417) ((T_BOOLEAN_OR) reduce 417) ((T_COALESCE) reduce 417) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 417) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 417) ((T_IS_NOT_EQUAL) reduce 417) ((T_IS_NOT_IDENTICAL) reduce 417) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 417) ((T_LOGICAL_OR) reduce 417) ((T_LOGICAL_XOR) reduce 417) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 417) ((T_SR) shift) (("]") reduce 417) (("^") reduce 417) (("|") reduce 417)) 617 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 413) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_BOOLEAN_AND) reduce 413) ((T_BOOLEAN_OR) reduce 413) ((T_COALESCE) reduce 413) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 413) ((T_LOGICAL_OR) reduce 413) ((T_LOGICAL_XOR) reduce 413) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 413) (("^") reduce 413) (("|") reduce 413)) 618 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 415) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_BOOLEAN_AND) reduce 415) ((T_BOOLEAN_OR) reduce 415) ((T_COALESCE) reduce 415) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 415) ((T_LOGICAL_OR) reduce 415) ((T_LOGICAL_XOR) reduce 415) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 415) (("^") reduce 415) (("|") reduce 415)) 619 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 412) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_BOOLEAN_AND) reduce 412) ((T_BOOLEAN_OR) reduce 412) ((T_COALESCE) reduce 412) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 412) ((T_LOGICAL_OR) reduce 412) ((T_LOGICAL_XOR) reduce 412) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 412) (("^") reduce 412) (("|") reduce 412)) 620 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 419) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_BOOLEAN_AND) reduce 419) ((T_BOOLEAN_OR) reduce 419) ((T_COALESCE) reduce 419) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 419) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 419) ((T_IS_NOT_EQUAL) reduce 419) ((T_IS_NOT_IDENTICAL) reduce 419) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 419) ((T_LOGICAL_OR) reduce 419) ((T_LOGICAL_XOR) reduce 419) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 419) ((T_SR) shift) (("]") reduce 419) (("^") reduce 419) (("|") reduce 419)) 621 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 414) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_BOOLEAN_AND) reduce 414) ((T_BOOLEAN_OR) reduce 414) ((T_COALESCE) reduce 414) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 414) ((T_LOGICAL_OR) reduce 414) ((T_LOGICAL_XOR) reduce 414) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 414) (("^") reduce 414) (("|") reduce 414)) 624 ((("%") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("]") reduce 93) (("^") reduce 93) (("|") reduce 93)) 625 ((("%") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("]") reduce 92) (("^") reduce 92) (("|") reduce 92)) 626 ((("%") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("]") reduce 94) (("^") reduce 94) (("|") reduce 94)) 627 ((("%") reduce 470) (("*") reduce 470) (("+") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("]") reduce 470) (("^") reduce 470) (("|") reduce 470)) 628 ((("%") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("]") reduce 91) (("^") reduce 91) (("|") reduce 91)) 629 ((("%") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("]") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 630 ((("%") reduce 472) (("*") reduce 472) (("+") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("]") reduce 472) (("^") reduce 472) (("|") reduce 472)) 631 ((("%") reduce 421) (("*") reduce 421) (("+") reduce 421) (("-") reduce 421) ((".") reduce 421) (("/") reduce 421) (("<") reduce 421) ((">") reduce 421) (("?") reduce 421) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_BOOLEAN_AND) reduce 421) ((T_BOOLEAN_OR) reduce 421) ((T_COALESCE) reduce 421) ((T_INSTANCEOF) reduce 421) ((T_IS_EQUAL) reduce 421) ((T_IS_GREATER_OR_EQUAL) reduce 421) ((T_IS_IDENTICAL) reduce 421) ((T_IS_NOT_EQUAL) reduce 421) ((T_IS_NOT_IDENTICAL) reduce 421) ((T_IS_SMALLER_OR_EQUAL) reduce 421) ((T_LOGICAL_AND) reduce 421) ((T_LOGICAL_OR) reduce 421) ((T_LOGICAL_XOR) reduce 421) ((T_POW) reduce 421) ((T_SL) reduce 421) ((T_SPACESHIP) reduce 421) ((T_SR) reduce 421) (("]") reduce 421) (("^") reduce 421) (("|") reduce 421)) 632 ((("%") reduce 471) (("*") reduce 471) (("+") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("]") reduce 471) (("^") reduce 471) (("|") reduce 471)) 633 ((("%") reduce 473) (("*") reduce 473) (("+") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("]") reduce 473) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 634 ((("%") reduce 534) (("*") reduce 534) (("+") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("]") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 641 ((("%") reduce 536) (("*") reduce 536) (("+") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("]") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 643 ((("%") reduce 535) (("*") reduce 535) (("+") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("]") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 644 ((("%") reduce 540) (("*") reduce 540) (("+") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("]") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 645 ((("%") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("]") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 646 ((("%") reduce 537) (("*") reduce 537) (("+") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("]") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 647 ((("%") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("]") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 650 ((("%") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("]") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 651 ((("%") reduce 538) (("*") reduce 538) (("+") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("]") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 653 ((("%") reduce 539) (("*") reduce 539) (("+") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("]") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 655 ((("%") reduce 474) (("*") reduce 474) (("+") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("]") reduce 474) (("^") reduce 474) (("|") reduce 474)) 656 ((("%") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("]") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 659 ((("%") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("]") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 660 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 426) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 426) ((T_LOGICAL_OR) reduce 426) ((T_LOGICAL_XOR) reduce 426) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 426) (("^") shift) (("|") shift)) 661 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 390) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) reduce 390) ((T_COALESCE) reduce 390) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 390) ((T_LOGICAL_OR) reduce 390) ((T_LOGICAL_XOR) reduce 390) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 390) (("^") shift) (("|") shift)) 662 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 391) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 391) ((T_BOOLEAN_OR) reduce 391) ((T_COALESCE) reduce 391) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 391) ((T_LOGICAL_OR) reduce 391) ((T_LOGICAL_XOR) reduce 391) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 391) (("^") shift) (("|") shift)) 663 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 396) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_BOOLEAN_AND) reduce 396) ((T_BOOLEAN_OR) reduce 396) ((T_COALESCE) reduce 396) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 396) ((T_LOGICAL_OR) reduce 396) ((T_LOGICAL_XOR) reduce 396) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 396) (("^") reduce 396) (("|") reduce 396)) 664 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 397) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_BOOLEAN_AND) reduce 397) ((T_BOOLEAN_OR) reduce 397) ((T_COALESCE) reduce 397) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 397) ((T_LOGICAL_OR) reduce 397) ((T_LOGICAL_XOR) reduce 397) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 397) (("^") reduce 397) (("|") reduce 397)) 676 ((("%") reduce 502) (("*") reduce 502) (("+") reduce 502) (("-") reduce 502) ((".") reduce 502) (("/") reduce 502) ((":") reduce 502) (("<") reduce 502) ((">") reduce 502) (("?") reduce 502) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_BOOLEAN_AND) reduce 502) ((T_BOOLEAN_OR) reduce 502) ((T_COALESCE) reduce 502) ((T_INSTANCEOF) reduce 502) ((T_IS_EQUAL) reduce 502) ((T_IS_GREATER_OR_EQUAL) reduce 502) ((T_IS_IDENTICAL) reduce 502) ((T_IS_NOT_EQUAL) reduce 502) ((T_IS_NOT_IDENTICAL) reduce 502) ((T_IS_SMALLER_OR_EQUAL) reduce 502) ((T_LOGICAL_AND) reduce 502) ((T_LOGICAL_OR) reduce 502) ((T_LOGICAL_XOR) reduce 502) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 502) ((T_OBJECT_OPERATOR) reduce 502) ((T_POW) reduce 502) ((T_SL) reduce 502) ((T_SPACESHIP) reduce 502) ((T_SR) reduce 502) (("[") reduce 502) (("^") reduce 502) (("{") reduce 502) (("|") reduce 502)) 678 ((("%") reduce 484) (("(") reduce 484) (("*") reduce 484) (("+") reduce 484) (("-") reduce 484) ((".") reduce 484) (("/") reduce 484) ((":") reduce 484) (("<") reduce 484) ((">") reduce 484) (("?") reduce 484) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_BOOLEAN_AND) reduce 484) ((T_BOOLEAN_OR) reduce 484) ((T_COALESCE) reduce 484) ((T_INSTANCEOF) reduce 484) ((T_IS_EQUAL) reduce 484) ((T_IS_GREATER_OR_EQUAL) reduce 484) ((T_IS_IDENTICAL) reduce 484) ((T_IS_NOT_EQUAL) reduce 484) ((T_IS_NOT_IDENTICAL) reduce 484) ((T_IS_SMALLER_OR_EQUAL) reduce 484) ((T_LOGICAL_AND) reduce 484) ((T_LOGICAL_OR) reduce 484) ((T_LOGICAL_XOR) reduce 484) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 484) ((T_OBJECT_OPERATOR) reduce 484) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 484) ((T_POW) reduce 484) ((T_SL) reduce 484) ((T_SPACESHIP) reduce 484) ((T_SR) reduce 484) (("[") reduce 484) (("^") reduce 484) (("{") reduce 484) (("|") reduce 484)) 680 ((("%") reduce 497) (("*") reduce 497) (("+") reduce 497) (("-") reduce 497) ((".") reduce 497) (("/") reduce 497) ((":") reduce 497) (("<") reduce 497) ((">") reduce 497) (("?") reduce 497) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_BOOLEAN_AND) reduce 497) ((T_BOOLEAN_OR) reduce 497) ((T_COALESCE) reduce 497) ((T_INSTANCEOF) reduce 497) ((T_IS_EQUAL) reduce 497) ((T_IS_GREATER_OR_EQUAL) reduce 497) ((T_IS_IDENTICAL) reduce 497) ((T_IS_NOT_EQUAL) reduce 497) ((T_IS_NOT_IDENTICAL) reduce 497) ((T_IS_SMALLER_OR_EQUAL) reduce 497) ((T_LOGICAL_AND) reduce 497) ((T_LOGICAL_OR) reduce 497) ((T_LOGICAL_XOR) reduce 497) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 497) ((T_OBJECT_OPERATOR) reduce 497) ((T_POW) reduce 497) ((T_SL) reduce 497) ((T_SPACESHIP) reduce 497) ((T_SR) reduce 497) (("[") reduce 497) (("^") reduce 497) (("{") reduce 497) (("|") reduce 497)) 681 ((("%") reduce 487) (("*") reduce 487) (("+") reduce 487) (("-") reduce 487) ((".") reduce 487) (("/") reduce 487) ((":") reduce 487) (("<") reduce 487) ((">") reduce 487) (("?") reduce 487) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_BOOLEAN_AND) reduce 487) ((T_BOOLEAN_OR) reduce 487) ((T_COALESCE) reduce 487) ((T_INSTANCEOF) reduce 487) ((T_IS_EQUAL) reduce 487) ((T_IS_GREATER_OR_EQUAL) reduce 487) ((T_IS_IDENTICAL) reduce 487) ((T_IS_NOT_EQUAL) reduce 487) ((T_IS_NOT_IDENTICAL) reduce 487) ((T_IS_SMALLER_OR_EQUAL) reduce 487) ((T_LOGICAL_AND) reduce 487) ((T_LOGICAL_OR) reduce 487) ((T_LOGICAL_XOR) reduce 487) ((T_POW) reduce 487) ((T_SL) reduce 487) ((T_SPACESHIP) reduce 487) ((T_SR) reduce 487) (("^") reduce 487) (("|") reduce 487)) 685 ((("%") reduce 475) (("(") shift) (("*") reduce 475) (("+") reduce 475) (("-") reduce 475) ((".") reduce 475) (("/") reduce 475) ((":") reduce 475) (("<") reduce 475) ((">") reduce 475) (("?") reduce 475) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_BOOLEAN_AND) reduce 475) ((T_BOOLEAN_OR) reduce 475) ((T_COALESCE) reduce 475) ((T_INSTANCEOF) reduce 475) ((T_IS_EQUAL) reduce 475) ((T_IS_GREATER_OR_EQUAL) reduce 475) ((T_IS_IDENTICAL) reduce 475) ((T_IS_NOT_EQUAL) reduce 475) ((T_IS_NOT_IDENTICAL) reduce 475) ((T_IS_SMALLER_OR_EQUAL) reduce 475) ((T_LOGICAL_AND) reduce 475) ((T_LOGICAL_OR) reduce 475) ((T_LOGICAL_XOR) reduce 475) ((T_POW) reduce 475) ((T_SL) reduce 475) ((T_SPACESHIP) reduce 475) ((T_SR) reduce 475) (("^") reduce 475) (("|") reduce 475)) 686 ((("%") reduce 496) (("*") reduce 496) (("+") reduce 496) (("-") reduce 496) ((".") reduce 496) (("/") reduce 496) ((":") reduce 496) (("<") reduce 496) ((">") reduce 496) (("?") reduce 496) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_BOOLEAN_AND) reduce 496) ((T_BOOLEAN_OR) reduce 496) ((T_COALESCE) reduce 496) ((T_INSTANCEOF) reduce 496) ((T_IS_EQUAL) reduce 496) ((T_IS_GREATER_OR_EQUAL) reduce 496) ((T_IS_IDENTICAL) reduce 496) ((T_IS_NOT_EQUAL) reduce 496) ((T_IS_NOT_IDENTICAL) reduce 496) ((T_IS_SMALLER_OR_EQUAL) reduce 496) ((T_LOGICAL_AND) reduce 496) ((T_LOGICAL_OR) reduce 496) ((T_LOGICAL_XOR) reduce 496) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 496) ((T_OBJECT_OPERATOR) reduce 496) ((T_POW) reduce 496) ((T_SL) reduce 496) ((T_SPACESHIP) reduce 496) ((T_SR) reduce 496) (("[") reduce 496) (("^") reduce 496) (("{") reduce 496) (("|") reduce 496)) 687 ((("%") reduce 500) (("*") reduce 500) (("+") reduce 500) (("-") reduce 500) ((".") reduce 500) (("/") reduce 500) ((":") reduce 500) (("<") reduce 500) ((">") reduce 500) (("?") reduce 500) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_BOOLEAN_AND) reduce 500) ((T_BOOLEAN_OR) reduce 500) ((T_COALESCE) reduce 500) ((T_INSTANCEOF) reduce 500) ((T_IS_EQUAL) reduce 500) ((T_IS_GREATER_OR_EQUAL) reduce 500) ((T_IS_IDENTICAL) reduce 500) ((T_IS_NOT_EQUAL) reduce 500) ((T_IS_NOT_IDENTICAL) reduce 500) ((T_IS_SMALLER_OR_EQUAL) reduce 500) ((T_LOGICAL_AND) reduce 500) ((T_LOGICAL_OR) reduce 500) ((T_LOGICAL_XOR) reduce 500) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 500) ((T_OBJECT_OPERATOR) reduce 500) ((T_POW) reduce 500) ((T_SL) reduce 500) ((T_SPACESHIP) reduce 500) ((T_SR) reduce 500) (("[") reduce 500) (("^") reduce 500) (("{") reduce 500) (("|") reduce 500)) 693 ((("%") reduce 495) (("*") reduce 495) (("+") reduce 495) (("-") reduce 495) ((".") reduce 495) (("/") reduce 495) ((":") reduce 495) (("<") reduce 495) ((">") reduce 495) (("?") reduce 495) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_BOOLEAN_AND) reduce 495) ((T_BOOLEAN_OR) reduce 495) ((T_COALESCE) reduce 495) ((T_INSTANCEOF) reduce 495) ((T_IS_EQUAL) reduce 495) ((T_IS_GREATER_OR_EQUAL) reduce 495) ((T_IS_IDENTICAL) reduce 495) ((T_IS_NOT_EQUAL) reduce 495) ((T_IS_NOT_IDENTICAL) reduce 495) ((T_IS_SMALLER_OR_EQUAL) reduce 495) ((T_LOGICAL_AND) reduce 495) ((T_LOGICAL_OR) reduce 495) ((T_LOGICAL_XOR) reduce 495) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 495) ((T_OBJECT_OPERATOR) reduce 495) ((T_POW) reduce 495) ((T_SL) reduce 495) ((T_SPACESHIP) reduce 495) ((T_SR) reduce 495) (("[") reduce 495) (("^") reduce 495) (("{") reduce 495) (("|") reduce 495)) 695 ((("%") reduce 486) (("*") reduce 486) (("+") reduce 486) (("-") reduce 486) ((".") reduce 486) (("/") reduce 486) ((":") reduce 486) (("<") reduce 486) ((">") reduce 486) (("?") reduce 486) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_BOOLEAN_AND) reduce 486) ((T_BOOLEAN_OR) reduce 486) ((T_COALESCE) reduce 486) ((T_INSTANCEOF) reduce 486) ((T_IS_EQUAL) reduce 486) ((T_IS_GREATER_OR_EQUAL) reduce 486) ((T_IS_IDENTICAL) reduce 486) ((T_IS_NOT_EQUAL) reduce 486) ((T_IS_NOT_IDENTICAL) reduce 486) ((T_IS_SMALLER_OR_EQUAL) reduce 486) ((T_LOGICAL_AND) reduce 486) ((T_LOGICAL_OR) reduce 486) ((T_LOGICAL_XOR) reduce 486) ((T_POW) reduce 486) ((T_SL) reduce 486) ((T_SPACESHIP) reduce 486) ((T_SR) reduce 486) (("^") reduce 486) (("|") reduce 486)) 697 ((("%") reduce 499) (("*") reduce 499) (("+") reduce 499) (("-") reduce 499) ((".") reduce 499) (("/") reduce 499) ((":") reduce 499) (("<") reduce 499) ((">") reduce 499) (("?") reduce 499) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_BOOLEAN_AND) reduce 499) ((T_BOOLEAN_OR) reduce 499) ((T_COALESCE) reduce 499) ((T_INSTANCEOF) reduce 499) ((T_IS_EQUAL) reduce 499) ((T_IS_GREATER_OR_EQUAL) reduce 499) ((T_IS_IDENTICAL) reduce 499) ((T_IS_NOT_EQUAL) reduce 499) ((T_IS_NOT_IDENTICAL) reduce 499) ((T_IS_SMALLER_OR_EQUAL) reduce 499) ((T_LOGICAL_AND) reduce 499) ((T_LOGICAL_OR) reduce 499) ((T_LOGICAL_XOR) reduce 499) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 499) ((T_OBJECT_OPERATOR) reduce 499) ((T_POW) reduce 499) ((T_SL) reduce 499) ((T_SPACESHIP) reduce 499) ((T_SR) reduce 499) (("[") reduce 499) (("^") reduce 499) (("{") reduce 499) (("|") reduce 499)) 698 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) ((":") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 93) ((T_OBJECT_OPERATOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("[") reduce 93) (("^") reduce 93) (("{") reduce 93) (("|") reduce 93)) 699 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) ((":") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 92) ((T_OBJECT_OPERATOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("[") reduce 92) (("^") reduce 92) (("{") reduce 92) (("|") reduce 92)) 700 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) ((":") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 94) ((T_OBJECT_OPERATOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("[") reduce 94) (("^") reduce 94) (("{") reduce 94) (("|") reduce 94)) 702 ((("%") reduce 501) (("*") reduce 501) (("+") reduce 501) (("-") reduce 501) ((".") reduce 501) (("/") reduce 501) ((":") reduce 501) (("<") reduce 501) ((">") reduce 501) (("?") reduce 501) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_BOOLEAN_AND) reduce 501) ((T_BOOLEAN_OR) reduce 501) ((T_COALESCE) reduce 501) ((T_INSTANCEOF) reduce 501) ((T_IS_EQUAL) reduce 501) ((T_IS_GREATER_OR_EQUAL) reduce 501) ((T_IS_IDENTICAL) reduce 501) ((T_IS_NOT_EQUAL) reduce 501) ((T_IS_NOT_IDENTICAL) reduce 501) ((T_IS_SMALLER_OR_EQUAL) reduce 501) ((T_LOGICAL_AND) reduce 501) ((T_LOGICAL_OR) reduce 501) ((T_LOGICAL_XOR) reduce 501) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 501) ((T_OBJECT_OPERATOR) reduce 501) ((T_POW) reduce 501) ((T_SL) reduce 501) ((T_SPACESHIP) reduce 501) ((T_SR) reduce 501) (("[") reduce 501) (("^") reduce 501) (("{") reduce 501) (("|") reduce 501)) 710 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) ((":") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 91) ((T_OBJECT_OPERATOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("[") reduce 91) (("^") reduce 91) (("{") reduce 91) (("|") reduce 91)) 713 ((("%") reduce 498) (("*") reduce 498) (("+") reduce 498) (("-") reduce 498) ((".") reduce 498) (("/") reduce 498) ((":") reduce 498) (("<") reduce 498) ((">") reduce 498) (("?") reduce 498) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_BOOLEAN_AND) reduce 498) ((T_BOOLEAN_OR) reduce 498) ((T_COALESCE) reduce 498) ((T_INSTANCEOF) reduce 498) ((T_IS_EQUAL) reduce 498) ((T_IS_GREATER_OR_EQUAL) reduce 498) ((T_IS_IDENTICAL) reduce 498) ((T_IS_NOT_EQUAL) reduce 498) ((T_IS_NOT_IDENTICAL) reduce 498) ((T_IS_SMALLER_OR_EQUAL) reduce 498) ((T_LOGICAL_AND) reduce 498) ((T_LOGICAL_OR) reduce 498) ((T_LOGICAL_XOR) reduce 498) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 498) ((T_OBJECT_OPERATOR) reduce 498) ((T_POW) reduce 498) ((T_SL) reduce 498) ((T_SPACESHIP) reduce 498) ((T_SR) reduce 498) (("[") reduce 498) (("^") reduce 498) (("{") reduce 498) (("|") reduce 498)) 715 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) ((":") reduce 529) (("<") reduce 529) (("=") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AND_EQUAL) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_COALESCE_EQUAL) reduce 529) ((T_CONCAT_EQUAL) reduce 529) ((T_DEC) reduce 529) ((T_DIV_EQUAL) reduce 529) ((T_INC) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_MINUS_EQUAL) reduce 529) ((T_MOD_EQUAL) reduce 529) ((T_MUL_EQUAL) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_OR_EQUAL) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_PLUS_EQUAL) reduce 529) ((T_POW) reduce 529) ((T_POW_EQUAL) reduce 529) ((T_SL) reduce 529) ((T_SL_EQUAL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) ((T_SR_EQUAL) reduce 529) ((T_XOR_EQUAL) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 716 ((("!") shift) (("\"") shift) (("$") shift) (("%") reduce 440) (("(") shift) (("*") reduce 440) (("+") shift) (("-") shift) ((".") reduce 440) (("/") reduce 440) ((":") reduce 440) (("<") reduce 440) ((">") reduce 440) (("?") reduce 440) (("@") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOLEAN_AND) reduce 440) ((T_BOOLEAN_OR) reduce 440) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_COALESCE) reduce 440) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INSTANCEOF) reduce 440) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_IS_EQUAL) reduce 440) ((T_IS_GREATER_OR_EQUAL) reduce 440) ((T_IS_IDENTICAL) reduce 440) ((T_IS_NOT_EQUAL) reduce 440) ((T_IS_NOT_IDENTICAL) reduce 440) ((T_IS_SMALLER_OR_EQUAL) reduce 440) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_LOGICAL_AND) reduce 440) ((T_LOGICAL_OR) reduce 440) ((T_LOGICAL_XOR) reduce 440) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_POW) reduce 440) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_SL) reduce 440) ((T_SPACESHIP) reduce 440) ((T_SR) reduce 440) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("^") reduce 440) (("`") shift) (("|") reduce 440) (("~") shift)) 723 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) ((":") reduce 525) (("<") reduce 525) (("=") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AND_EQUAL) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_COALESCE_EQUAL) reduce 525) ((T_CONCAT_EQUAL) reduce 525) ((T_DEC) reduce 525) ((T_DIV_EQUAL) reduce 525) ((T_INC) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_MINUS_EQUAL) reduce 525) ((T_MOD_EQUAL) reduce 525) ((T_MUL_EQUAL) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_OR_EQUAL) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_PLUS_EQUAL) reduce 525) ((T_POW) reduce 525) ((T_POW_EQUAL) reduce 525) ((T_SL) reduce 525) ((T_SL_EQUAL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) ((T_SR_EQUAL) reduce 525) ((T_XOR_EQUAL) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 724 ((("%") reduce 493) (("*") reduce 493) (("+") reduce 493) (("-") reduce 493) ((".") reduce 493) (("/") reduce 493) ((":") reduce 493) (("<") reduce 493) ((">") reduce 493) (("?") reduce 493) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_BOOLEAN_AND) reduce 493) ((T_BOOLEAN_OR) reduce 493) ((T_COALESCE) reduce 493) ((T_INSTANCEOF) reduce 493) ((T_IS_EQUAL) reduce 493) ((T_IS_GREATER_OR_EQUAL) reduce 493) ((T_IS_IDENTICAL) reduce 493) ((T_IS_NOT_EQUAL) reduce 493) ((T_IS_NOT_IDENTICAL) reduce 493) ((T_IS_SMALLER_OR_EQUAL) reduce 493) ((T_LOGICAL_AND) reduce 493) ((T_LOGICAL_OR) reduce 493) ((T_LOGICAL_XOR) reduce 493) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 513) ((T_OBJECT_OPERATOR) reduce 513) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 513) ((T_POW) reduce 493) ((T_SL) reduce 493) ((T_SPACESHIP) reduce 493) ((T_SR) reduce 493) (("[") reduce 513) (("^") reduce 493) (("{") reduce 513) (("|") reduce 493)) 726 ((("%") reduce 492) (("*") reduce 492) (("+") reduce 492) (("-") reduce 492) ((".") reduce 492) (("/") reduce 492) ((":") reduce 492) (("<") reduce 492) ((">") reduce 492) (("?") reduce 492) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_BOOLEAN_AND) reduce 492) ((T_BOOLEAN_OR) reduce 492) ((T_COALESCE) reduce 492) ((T_INSTANCEOF) reduce 492) ((T_IS_EQUAL) reduce 492) ((T_IS_GREATER_OR_EQUAL) reduce 492) ((T_IS_IDENTICAL) reduce 492) ((T_IS_NOT_EQUAL) reduce 492) ((T_IS_NOT_IDENTICAL) reduce 492) ((T_IS_SMALLER_OR_EQUAL) reduce 492) ((T_LOGICAL_AND) reduce 492) ((T_LOGICAL_OR) reduce 492) ((T_LOGICAL_XOR) reduce 492) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 515) ((T_OBJECT_OPERATOR) reduce 515) ((T_POW) reduce 492) ((T_SL) reduce 492) ((T_SPACESHIP) reduce 492) ((T_SR) reduce 492) (("[") reduce 515) (("^") reduce 492) (("{") reduce 515) (("|") reduce 492)) 727 ((("%") reduce 491) (("(") reduce 518) (("*") reduce 491) (("+") reduce 491) (("-") reduce 491) ((".") reduce 491) (("/") reduce 491) ((":") reduce 491) (("<") reduce 491) ((">") reduce 491) (("?") reduce 491) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_BOOLEAN_AND) reduce 491) ((T_BOOLEAN_OR) reduce 491) ((T_COALESCE) reduce 491) ((T_INSTANCEOF) reduce 491) ((T_IS_EQUAL) reduce 491) ((T_IS_GREATER_OR_EQUAL) reduce 491) ((T_IS_IDENTICAL) reduce 491) ((T_IS_NOT_EQUAL) reduce 491) ((T_IS_NOT_IDENTICAL) reduce 491) ((T_IS_SMALLER_OR_EQUAL) reduce 491) ((T_LOGICAL_AND) reduce 491) ((T_LOGICAL_OR) reduce 491) ((T_LOGICAL_XOR) reduce 491) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 512) ((T_OBJECT_OPERATOR) reduce 512) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 512) ((T_POW) reduce 491) ((T_SL) reduce 491) ((T_SPACESHIP) reduce 491) ((T_SR) reduce 491) (("[") reduce 512) (("^") reduce 491) (("{") reduce 512) (("|") reduce 491)) 728 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 731 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) ((":") reduce 524) (("<") reduce 524) (("=") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AND_EQUAL) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_COALESCE_EQUAL) reduce 524) ((T_CONCAT_EQUAL) reduce 524) ((T_DEC) reduce 524) ((T_DIV_EQUAL) reduce 524) ((T_INC) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_MINUS_EQUAL) reduce 524) ((T_MOD_EQUAL) reduce 524) ((T_MUL_EQUAL) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_OR_EQUAL) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_PLUS_EQUAL) reduce 524) ((T_POW) reduce 524) ((T_POW_EQUAL) reduce 524) ((T_SL) reduce 524) ((T_SL_EQUAL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) ((T_SR_EQUAL) reduce 524) ((T_XOR_EQUAL) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 732 ((("%") reduce 445) (("*") reduce 445) (("+") reduce 445) (("-") reduce 445) ((".") reduce 445) (("/") reduce 445) ((":") reduce 445) (("<") reduce 445) ((">") reduce 445) (("?") reduce 445) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_BOOLEAN_AND) reduce 445) ((T_BOOLEAN_OR) reduce 445) ((T_COALESCE) reduce 445) ((T_INSTANCEOF) reduce 445) ((T_IS_EQUAL) reduce 445) ((T_IS_GREATER_OR_EQUAL) reduce 445) ((T_IS_IDENTICAL) reduce 445) ((T_IS_NOT_EQUAL) reduce 445) ((T_IS_NOT_IDENTICAL) reduce 445) ((T_IS_SMALLER_OR_EQUAL) reduce 445) ((T_LOGICAL_AND) reduce 445) ((T_LOGICAL_OR) reduce 445) ((T_LOGICAL_XOR) reduce 445) ((T_POW) reduce 445) ((T_SL) reduce 445) ((T_SPACESHIP) reduce 445) ((T_SR) reduce 445) (("^") reduce 445) (("|") reduce 445)) 733 ((("%") reduce 427) (("*") reduce 427) (("+") reduce 427) (("-") reduce 427) ((".") reduce 427) (("/") reduce 427) ((":") reduce 427) (("<") reduce 427) ((">") reduce 427) (("?") reduce 427) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_BOOLEAN_AND) reduce 427) ((T_BOOLEAN_OR) reduce 427) ((T_COALESCE) reduce 427) ((T_INSTANCEOF) reduce 427) ((T_IS_EQUAL) reduce 427) ((T_IS_GREATER_OR_EQUAL) reduce 427) ((T_IS_IDENTICAL) reduce 427) ((T_IS_NOT_EQUAL) reduce 427) ((T_IS_NOT_IDENTICAL) reduce 427) ((T_IS_SMALLER_OR_EQUAL) reduce 427) ((T_LOGICAL_AND) reduce 427) ((T_LOGICAL_OR) reduce 427) ((T_LOGICAL_XOR) reduce 427) ((T_POW) reduce 427) ((T_SL) reduce 427) ((T_SPACESHIP) reduce 427) ((T_SR) reduce 427) (("^") reduce 427) (("|") reduce 427)) 734 ((("%") reduce 449) (("*") reduce 449) (("+") reduce 449) (("-") reduce 449) ((".") reduce 449) (("/") reduce 449) ((":") reduce 449) (("<") reduce 449) ((">") reduce 449) (("?") reduce 449) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_BOOLEAN_AND) reduce 449) ((T_BOOLEAN_OR) reduce 449) ((T_COALESCE) reduce 449) ((T_INSTANCEOF) reduce 449) ((T_IS_EQUAL) reduce 449) ((T_IS_GREATER_OR_EQUAL) reduce 449) ((T_IS_IDENTICAL) reduce 449) ((T_IS_NOT_EQUAL) reduce 449) ((T_IS_NOT_IDENTICAL) reduce 449) ((T_IS_SMALLER_OR_EQUAL) reduce 449) ((T_LOGICAL_AND) reduce 449) ((T_LOGICAL_OR) reduce 449) ((T_LOGICAL_XOR) reduce 449) ((T_POW) reduce 449) ((T_SL) reduce 449) ((T_SPACESHIP) reduce 449) ((T_SR) reduce 449) (("^") reduce 449) (("|") reduce 449)) 735 ((("%") reduce 494) (("(") shift) (("*") reduce 494) (("+") reduce 494) (("-") reduce 494) ((".") reduce 494) (("/") reduce 494) ((":") reduce 494) (("<") reduce 494) ((">") reduce 494) (("?") reduce 494) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_BOOLEAN_AND) reduce 494) ((T_BOOLEAN_OR) reduce 494) ((T_COALESCE) reduce 494) ((T_INSTANCEOF) reduce 494) ((T_IS_EQUAL) reduce 494) ((T_IS_GREATER_OR_EQUAL) reduce 494) ((T_IS_IDENTICAL) reduce 494) ((T_IS_NOT_EQUAL) reduce 494) ((T_IS_NOT_IDENTICAL) reduce 494) ((T_IS_SMALLER_OR_EQUAL) reduce 494) ((T_LOGICAL_AND) reduce 494) ((T_LOGICAL_OR) reduce 494) ((T_LOGICAL_XOR) reduce 494) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 494) ((T_OBJECT_OPERATOR) reduce 494) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 494) ((T_SL) reduce 494) ((T_SPACESHIP) reduce 494) ((T_SR) reduce 494) (("[") reduce 494) (("^") reduce 494) (("{") reduce 494) (("|") reduce 494)) 736 ((("%") reduce 423) (("*") reduce 423) (("+") reduce 423) (("-") reduce 423) ((".") reduce 423) (("/") reduce 423) ((":") reduce 423) (("<") reduce 423) ((">") reduce 423) (("?") reduce 423) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_BOOLEAN_AND) reduce 423) ((T_BOOLEAN_OR) reduce 423) ((T_COALESCE) reduce 423) ((T_INSTANCEOF) reduce 423) ((T_IS_EQUAL) reduce 423) ((T_IS_GREATER_OR_EQUAL) reduce 423) ((T_IS_IDENTICAL) reduce 423) ((T_IS_NOT_EQUAL) reduce 423) ((T_IS_NOT_IDENTICAL) reduce 423) ((T_IS_SMALLER_OR_EQUAL) reduce 423) ((T_LOGICAL_AND) reduce 423) ((T_LOGICAL_OR) reduce 423) ((T_LOGICAL_XOR) reduce 423) ((T_POW) reduce 423) ((T_SL) reduce 423) ((T_SPACESHIP) reduce 423) ((T_SR) reduce 423) (("^") reduce 423) (("|") reduce 423)) 737 ((("%") reduce 437) (("*") reduce 437) (("+") reduce 437) (("-") reduce 437) ((".") reduce 437) (("/") reduce 437) ((":") reduce 437) (("<") reduce 437) ((">") reduce 437) (("?") reduce 437) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_BOOLEAN_AND) reduce 437) ((T_BOOLEAN_OR) reduce 437) ((T_COALESCE) reduce 437) ((T_INSTANCEOF) reduce 437) ((T_IS_EQUAL) reduce 437) ((T_IS_GREATER_OR_EQUAL) reduce 437) ((T_IS_IDENTICAL) reduce 437) ((T_IS_NOT_EQUAL) reduce 437) ((T_IS_NOT_IDENTICAL) reduce 437) ((T_IS_SMALLER_OR_EQUAL) reduce 437) ((T_LOGICAL_AND) reduce 437) ((T_LOGICAL_OR) reduce 437) ((T_LOGICAL_XOR) reduce 437) ((T_POW) reduce 437) ((T_SL) reduce 437) ((T_SPACESHIP) reduce 437) ((T_SR) reduce 437) (("^") reduce 437) (("|") reduce 437)) 738 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) ((":") reduce 519) (("<") reduce 519) (("=") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AND_EQUAL) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_COALESCE_EQUAL) reduce 519) ((T_CONCAT_EQUAL) reduce 519) ((T_DEC) reduce 519) ((T_DIV_EQUAL) reduce 519) ((T_INC) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_MINUS_EQUAL) reduce 519) ((T_MOD_EQUAL) reduce 519) ((T_MUL_EQUAL) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_OR_EQUAL) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_PLUS_EQUAL) reduce 519) ((T_POW) reduce 519) ((T_POW_EQUAL) reduce 519) ((T_SL) reduce 519) ((T_SL_EQUAL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) ((T_SR_EQUAL) reduce 519) ((T_XOR_EQUAL) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 739 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) ((":") reduce 526) (("<") reduce 526) (("=") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AND_EQUAL) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_COALESCE_EQUAL) reduce 526) ((T_CONCAT_EQUAL) reduce 526) ((T_DEC) reduce 526) ((T_DIV_EQUAL) reduce 526) ((T_INC) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_MINUS_EQUAL) reduce 526) ((T_MOD_EQUAL) reduce 526) ((T_MUL_EQUAL) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_OR_EQUAL) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_PLUS_EQUAL) reduce 526) ((T_POW) reduce 526) ((T_POW_EQUAL) reduce 526) ((T_SL) reduce 526) ((T_SL_EQUAL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) ((T_SR_EQUAL) reduce 526) ((T_XOR_EQUAL) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 740 ((("%") reduce 367) (("*") reduce 367) (("+") reduce 367) (("-") reduce 367) ((".") reduce 367) (("/") reduce 367) ((":") reduce 367) (("<") reduce 367) (("=") shift) ((">") reduce 367) (("?") reduce 367) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AND_EQUAL) shift) ((T_BOOLEAN_AND) reduce 367) ((T_BOOLEAN_OR) reduce 367) ((T_COALESCE) reduce 367) ((T_COALESCE_EQUAL) shift) ((T_CONCAT_EQUAL) shift) ((T_DEC) shift) ((T_DIV_EQUAL) shift) ((T_INC) shift) ((T_INSTANCEOF) reduce 367) ((T_IS_EQUAL) reduce 367) ((T_IS_GREATER_OR_EQUAL) reduce 367) ((T_IS_IDENTICAL) reduce 367) ((T_IS_NOT_EQUAL) reduce 367) ((T_IS_NOT_IDENTICAL) reduce 367) ((T_IS_SMALLER_OR_EQUAL) reduce 367) ((T_LOGICAL_AND) reduce 367) ((T_LOGICAL_OR) reduce 367) ((T_LOGICAL_XOR) reduce 367) ((T_MINUS_EQUAL) shift) ((T_MOD_EQUAL) shift) ((T_MUL_EQUAL) shift) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_OR_EQUAL) shift) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_PLUS_EQUAL) shift) ((T_POW) reduce 367) ((T_POW_EQUAL) shift) ((T_SL) reduce 367) ((T_SL_EQUAL) shift) ((T_SPACESHIP) reduce 367) ((T_SR) reduce 367) ((T_SR_EQUAL) shift) ((T_XOR_EQUAL) shift) (("[") reduce 510) (("^") reduce 367) (("{") reduce 510) (("|") reduce 367)) 743 ((("%") reduce 411) (("*") reduce 411) (("+") reduce 411) (("-") reduce 411) ((".") reduce 411) (("/") reduce 411) ((":") reduce 411) (("<") reduce 411) ((">") reduce 411) (("?") reduce 411) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_BOOLEAN_AND) reduce 411) ((T_BOOLEAN_OR) reduce 411) ((T_COALESCE) reduce 411) ((T_INSTANCEOF) reduce 411) ((T_IS_EQUAL) reduce 411) ((T_IS_GREATER_OR_EQUAL) reduce 411) ((T_IS_IDENTICAL) reduce 411) ((T_IS_NOT_EQUAL) reduce 411) ((T_IS_NOT_IDENTICAL) reduce 411) ((T_IS_SMALLER_OR_EQUAL) reduce 411) ((T_LOGICAL_AND) reduce 411) ((T_LOGICAL_OR) reduce 411) ((T_LOGICAL_XOR) reduce 411) ((T_POW) shift) ((T_SL) reduce 411) ((T_SPACESHIP) reduce 411) ((T_SR) reduce 411) (("^") reduce 411) (("|") reduce 411)) 774 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 395) (("<") shift) ((">") shift) (("?") reduce 395) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 395) ((T_BOOLEAN_OR) reduce 395) ((T_COALESCE) reduce 395) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 395) ((T_LOGICAL_OR) reduce 395) ((T_LOGICAL_XOR) reduce 395) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") reduce 395)) 775 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 398) (("<") shift) ((">") shift) (("?") reduce 398) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 398) ((T_BOOLEAN_OR) reduce 398) ((T_COALESCE) reduce 398) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 398) ((T_LOGICAL_OR) reduce 398) ((T_LOGICAL_XOR) reduce 398) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 398) (("|") reduce 398)) 776 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 407) (("/") shift) ((":") reduce 407) (("<") reduce 407) ((">") reduce 407) (("?") reduce 407) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_BOOLEAN_AND) reduce 407) ((T_BOOLEAN_OR) reduce 407) ((T_COALESCE) reduce 407) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 407) ((T_IS_GREATER_OR_EQUAL) reduce 407) ((T_IS_IDENTICAL) reduce 407) ((T_IS_NOT_EQUAL) reduce 407) ((T_IS_NOT_IDENTICAL) reduce 407) ((T_IS_SMALLER_OR_EQUAL) reduce 407) ((T_LOGICAL_AND) reduce 407) ((T_LOGICAL_OR) reduce 407) ((T_LOGICAL_XOR) reduce 407) ((T_POW) shift) ((T_SL) reduce 407) ((T_SPACESHIP) reduce 407) ((T_SR) reduce 407) (("^") reduce 407) (("|") reduce 407)) 777 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 420) (("<") shift) ((">") shift) (("?") reduce 420) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_BOOLEAN_AND) reduce 420) ((T_BOOLEAN_OR) reduce 420) ((T_COALESCE) reduce 420) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 420) ((T_LOGICAL_OR) reduce 420) ((T_LOGICAL_XOR) reduce 420) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 420) (("|") reduce 420)) 778 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 406) (("/") shift) ((":") reduce 406) (("<") reduce 406) ((">") reduce 406) (("?") reduce 406) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_BOOLEAN_AND) reduce 406) ((T_BOOLEAN_OR) reduce 406) ((T_COALESCE) reduce 406) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 406) ((T_IS_GREATER_OR_EQUAL) reduce 406) ((T_IS_IDENTICAL) reduce 406) ((T_IS_NOT_EQUAL) reduce 406) ((T_IS_NOT_IDENTICAL) reduce 406) ((T_IS_SMALLER_OR_EQUAL) reduce 406) ((T_LOGICAL_AND) reduce 406) ((T_LOGICAL_OR) reduce 406) ((T_LOGICAL_XOR) reduce 406) ((T_POW) shift) ((T_SL) reduce 406) ((T_SPACESHIP) reduce 406) ((T_SR) reduce 406) (("^") reduce 406) (("|") reduce 406)) 779 ((("%") reduce 403) (("*") reduce 403) (("+") reduce 403) (("-") reduce 403) ((".") reduce 403) (("/") reduce 403) ((":") reduce 403) (("<") reduce 403) ((">") reduce 403) (("?") reduce 403) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_BOOLEAN_AND) reduce 403) ((T_BOOLEAN_OR) reduce 403) ((T_COALESCE) reduce 403) ((T_INSTANCEOF) reduce 403) ((T_IS_EQUAL) reduce 403) ((T_IS_GREATER_OR_EQUAL) reduce 403) ((T_IS_IDENTICAL) reduce 403) ((T_IS_NOT_EQUAL) reduce 403) ((T_IS_NOT_IDENTICAL) reduce 403) ((T_IS_SMALLER_OR_EQUAL) reduce 403) ((T_LOGICAL_AND) reduce 403) ((T_LOGICAL_OR) reduce 403) ((T_LOGICAL_XOR) reduce 403) ((T_POW) shift) ((T_SL) reduce 403) ((T_SPACESHIP) reduce 403) ((T_SR) reduce 403) (("^") reduce 403) (("|") reduce 403)) 780 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 394) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 394) ((T_LOGICAL_XOR) reduce 394) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 781 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 392) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 392) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 782 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 393) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 393) ((T_LOGICAL_OR) reduce 393) ((T_LOGICAL_XOR) reduce 393) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 783 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 417) (("<") shift) ((">") shift) (("?") reduce 417) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_BOOLEAN_AND) reduce 417) ((T_BOOLEAN_OR) reduce 417) ((T_COALESCE) reduce 417) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 417) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 417) ((T_IS_NOT_EQUAL) reduce 417) ((T_IS_NOT_IDENTICAL) reduce 417) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 417) ((T_LOGICAL_OR) reduce 417) ((T_LOGICAL_XOR) reduce 417) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 417) ((T_SR) shift) (("^") reduce 417) (("|") reduce 417)) 784 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 413) (("<") shift) ((">") shift) (("?") reduce 413) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_BOOLEAN_AND) reduce 413) ((T_BOOLEAN_OR) reduce 413) ((T_COALESCE) reduce 413) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 413) ((T_LOGICAL_OR) reduce 413) ((T_LOGICAL_XOR) reduce 413) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 413) (("|") reduce 413)) 785 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 415) (("<") shift) ((">") shift) (("?") reduce 415) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_BOOLEAN_AND) reduce 415) ((T_BOOLEAN_OR) reduce 415) ((T_COALESCE) reduce 415) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 415) ((T_LOGICAL_OR) reduce 415) ((T_LOGICAL_XOR) reduce 415) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 415) (("|") reduce 415)) 786 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 412) (("<") shift) ((">") shift) (("?") reduce 412) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_BOOLEAN_AND) reduce 412) ((T_BOOLEAN_OR) reduce 412) ((T_COALESCE) reduce 412) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 412) ((T_LOGICAL_OR) reduce 412) ((T_LOGICAL_XOR) reduce 412) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 412) (("|") reduce 412)) 787 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 419) (("<") shift) ((">") shift) (("?") reduce 419) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_BOOLEAN_AND) reduce 419) ((T_BOOLEAN_OR) reduce 419) ((T_COALESCE) reduce 419) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 419) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 419) ((T_IS_NOT_EQUAL) reduce 419) ((T_IS_NOT_IDENTICAL) reduce 419) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 419) ((T_LOGICAL_OR) reduce 419) ((T_LOGICAL_XOR) reduce 419) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 419) ((T_SR) shift) (("^") reduce 419) (("|") reduce 419)) 788 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 414) (("<") shift) ((">") shift) (("?") reduce 414) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_BOOLEAN_AND) reduce 414) ((T_BOOLEAN_OR) reduce 414) ((T_COALESCE) reduce 414) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 414) ((T_LOGICAL_OR) reduce 414) ((T_LOGICAL_XOR) reduce 414) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 414) (("|") reduce 414)) 791 ((("%") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) ((":") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93)) 792 ((("%") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) ((":") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92)) 793 ((("%") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) ((":") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94)) 794 ((("%") reduce 470) (("*") reduce 470) (("+") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) ((":") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470)) 795 ((("%") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) ((":") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91)) 796 ((("%") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) ((":") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 797 ((("%") reduce 472) (("*") reduce 472) (("+") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) ((":") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472)) 798 ((("%") reduce 421) (("*") reduce 421) (("+") reduce 421) (("-") reduce 421) ((".") reduce 421) (("/") reduce 421) ((":") reduce 421) (("<") reduce 421) ((">") reduce 421) (("?") reduce 421) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_BOOLEAN_AND) reduce 421) ((T_BOOLEAN_OR) reduce 421) ((T_COALESCE) reduce 421) ((T_INSTANCEOF) reduce 421) ((T_IS_EQUAL) reduce 421) ((T_IS_GREATER_OR_EQUAL) reduce 421) ((T_IS_IDENTICAL) reduce 421) ((T_IS_NOT_EQUAL) reduce 421) ((T_IS_NOT_IDENTICAL) reduce 421) ((T_IS_SMALLER_OR_EQUAL) reduce 421) ((T_LOGICAL_AND) reduce 421) ((T_LOGICAL_OR) reduce 421) ((T_LOGICAL_XOR) reduce 421) ((T_POW) reduce 421) ((T_SL) reduce 421) ((T_SPACESHIP) reduce 421) ((T_SR) reduce 421) (("^") reduce 421) (("|") reduce 421)) 799 ((("%") reduce 471) (("*") reduce 471) (("+") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) ((":") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471)) 800 ((("%") reduce 473) (("*") reduce 473) (("+") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) ((":") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 801 ((("%") reduce 534) (("*") reduce 534) (("+") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) ((":") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 808 ((("%") reduce 536) (("*") reduce 536) (("+") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) ((":") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 810 ((("%") reduce 535) (("*") reduce 535) (("+") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) ((":") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 811 ((("%") reduce 540) (("*") reduce 540) (("+") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) ((":") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 812 ((("%") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) ((":") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 813 ((("%") reduce 537) (("*") reduce 537) (("+") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) ((":") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 814 ((("%") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) ((":") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 817 ((("%") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) ((":") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 818 ((("%") reduce 538) (("*") reduce 538) (("+") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) ((":") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 820 ((("%") reduce 539) (("*") reduce 539) (("+") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) ((":") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 822 ((("%") reduce 474) (("*") reduce 474) (("+") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) ((":") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474)) 823 ((("%") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) ((":") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 826 ((("%") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) ((":") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 827 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 426) (("<") shift) ((">") shift) (("?") reduce 426) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 426) ((T_LOGICAL_OR) reduce 426) ((T_LOGICAL_XOR) reduce 426) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 828 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 390) (("<") shift) ((">") shift) (("?") reduce 390) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) reduce 390) ((T_COALESCE) reduce 390) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 390) ((T_LOGICAL_OR) reduce 390) ((T_LOGICAL_XOR) reduce 390) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 829 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 391) (("<") shift) ((">") shift) (("?") reduce 391) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 391) ((T_BOOLEAN_OR) reduce 391) ((T_COALESCE) reduce 391) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 391) ((T_LOGICAL_OR) reduce 391) ((T_LOGICAL_XOR) reduce 391) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 830 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 396) (("<") shift) ((">") shift) (("?") reduce 396) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_BOOLEAN_AND) reduce 396) ((T_BOOLEAN_OR) reduce 396) ((T_COALESCE) reduce 396) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 396) ((T_LOGICAL_OR) reduce 396) ((T_LOGICAL_XOR) reduce 396) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 396) (("|") reduce 396)) 831 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 397) (("<") shift) ((">") shift) (("?") reduce 397) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_BOOLEAN_AND) reduce 397) ((T_BOOLEAN_OR) reduce 397) ((T_COALESCE) reduce 397) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 397) ((T_LOGICAL_OR) reduce 397) ((T_LOGICAL_XOR) reduce 397) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 397) (("|") reduce 397)) 835 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 424) (("<") shift) ((">") shift) (("?") reduce 424) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 424) ((T_LOGICAL_OR) reduce 424) ((T_LOGICAL_XOR) reduce 424) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 836 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 425) (("<") shift) ((">") shift) (("?") reduce 425) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 425) ((T_LOGICAL_OR) reduce 425) ((T_LOGICAL_XOR) reduce 425) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 837 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 418) (("<") shift) ((">") shift) (("?") reduce 418) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_BOOLEAN_AND) reduce 418) ((T_BOOLEAN_OR) reduce 418) ((T_COALESCE) reduce 418) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 418) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 418) ((T_IS_NOT_EQUAL) reduce 418) ((T_IS_NOT_IDENTICAL) reduce 418) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 418) ((T_LOGICAL_OR) reduce 418) ((T_LOGICAL_XOR) reduce 418) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 418) ((T_SR) shift) (("^") reduce 418) (("|") reduce 418)) 838 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 416) (("<") shift) ((">") shift) (("?") reduce 416) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_BOOLEAN_AND) reduce 416) ((T_BOOLEAN_OR) reduce 416) ((T_COALESCE) reduce 416) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 416) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 416) ((T_IS_NOT_EQUAL) reduce 416) ((T_IS_NOT_IDENTICAL) reduce 416) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 416) ((T_LOGICAL_OR) reduce 416) ((T_LOGICAL_XOR) reduce 416) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 416) ((T_SR) shift) (("^") reduce 416) (("|") reduce 416)) 839 ((("%") reduce 404) (("*") reduce 404) (("+") reduce 404) (("-") reduce 404) ((".") reduce 404) (("/") reduce 404) ((":") reduce 404) (("<") reduce 404) ((">") reduce 404) (("?") reduce 404) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_BOOLEAN_AND) reduce 404) ((T_BOOLEAN_OR) reduce 404) ((T_COALESCE) reduce 404) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 404) ((T_IS_GREATER_OR_EQUAL) reduce 404) ((T_IS_IDENTICAL) reduce 404) ((T_IS_NOT_EQUAL) reduce 404) ((T_IS_NOT_IDENTICAL) reduce 404) ((T_IS_SMALLER_OR_EQUAL) reduce 404) ((T_LOGICAL_AND) reduce 404) ((T_LOGICAL_OR) reduce 404) ((T_LOGICAL_XOR) reduce 404) ((T_POW) shift) ((T_SL) reduce 404) ((T_SPACESHIP) reduce 404) ((T_SR) reduce 404) (("^") reduce 404) (("|") reduce 404)) 840 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 399) (("/") shift) ((":") reduce 399) (("<") reduce 399) ((">") reduce 399) (("?") reduce 399) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_BOOLEAN_AND) reduce 399) ((T_BOOLEAN_OR) reduce 399) ((T_COALESCE) reduce 399) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 399) ((T_IS_GREATER_OR_EQUAL) reduce 399) ((T_IS_IDENTICAL) reduce 399) ((T_IS_NOT_EQUAL) reduce 399) ((T_IS_NOT_IDENTICAL) reduce 399) ((T_IS_SMALLER_OR_EQUAL) reduce 399) ((T_LOGICAL_AND) reduce 399) ((T_LOGICAL_OR) reduce 399) ((T_LOGICAL_XOR) reduce 399) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 399) ((T_SR) shift) (("^") reduce 399) (("|") reduce 399)) 841 ((("%") shift) (("*") shift) (("+") reduce 401) (("-") reduce 401) ((".") reduce 401) (("/") shift) ((":") reduce 401) (("<") reduce 401) ((">") reduce 401) (("?") reduce 401) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_BOOLEAN_AND) reduce 401) ((T_BOOLEAN_OR) reduce 401) ((T_COALESCE) reduce 401) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 401) ((T_IS_GREATER_OR_EQUAL) reduce 401) ((T_IS_IDENTICAL) reduce 401) ((T_IS_NOT_EQUAL) reduce 401) ((T_IS_NOT_IDENTICAL) reduce 401) ((T_IS_SMALLER_OR_EQUAL) reduce 401) ((T_LOGICAL_AND) reduce 401) ((T_LOGICAL_OR) reduce 401) ((T_LOGICAL_XOR) reduce 401) ((T_POW) shift) ((T_SL) reduce 401) ((T_SPACESHIP) reduce 401) ((T_SR) reduce 401) (("^") reduce 401) (("|") reduce 401)) 842 ((("%") shift) (("*") shift) (("+") reduce 400) (("-") reduce 400) ((".") reduce 400) (("/") shift) ((":") reduce 400) (("<") reduce 400) ((">") reduce 400) (("?") reduce 400) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_BOOLEAN_AND) reduce 400) ((T_BOOLEAN_OR) reduce 400) ((T_COALESCE) reduce 400) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 400) ((T_IS_GREATER_OR_EQUAL) reduce 400) ((T_IS_IDENTICAL) reduce 400) ((T_IS_NOT_EQUAL) reduce 400) ((T_IS_NOT_IDENTICAL) reduce 400) ((T_IS_SMALLER_OR_EQUAL) reduce 400) ((T_LOGICAL_AND) reduce 400) ((T_LOGICAL_OR) reduce 400) ((T_LOGICAL_XOR) reduce 400) ((T_POW) shift) ((T_SL) reduce 400) ((T_SPACESHIP) reduce 400) ((T_SR) reduce 400) (("^") reduce 400) (("|") reduce 400)) 843 ((("%") reduce 402) (("*") reduce 402) (("+") reduce 402) (("-") reduce 402) ((".") reduce 402) (("/") reduce 402) ((":") reduce 402) (("<") reduce 402) ((">") reduce 402) (("?") reduce 402) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_BOOLEAN_AND) reduce 402) ((T_BOOLEAN_OR) reduce 402) ((T_COALESCE) reduce 402) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 402) ((T_IS_GREATER_OR_EQUAL) reduce 402) ((T_IS_IDENTICAL) reduce 402) ((T_IS_NOT_EQUAL) reduce 402) ((T_IS_NOT_IDENTICAL) reduce 402) ((T_IS_SMALLER_OR_EQUAL) reduce 402) ((T_LOGICAL_AND) reduce 402) ((T_LOGICAL_OR) reduce 402) ((T_LOGICAL_XOR) reduce 402) ((T_POW) shift) ((T_SL) reduce 402) ((T_SPACESHIP) reduce 402) ((T_SR) reduce 402) (("^") reduce 402) (("|") reduce 402)) 844 ((("%") reduce 405) (("*") reduce 405) (("+") reduce 405) (("-") reduce 405) ((".") reduce 405) (("/") reduce 405) ((":") reduce 405) (("<") reduce 405) ((">") reduce 405) (("?") reduce 405) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_BOOLEAN_AND) reduce 405) ((T_BOOLEAN_OR) reduce 405) ((T_COALESCE) reduce 405) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 405) ((T_IS_GREATER_OR_EQUAL) reduce 405) ((T_IS_IDENTICAL) reduce 405) ((T_IS_NOT_EQUAL) reduce 405) ((T_IS_NOT_IDENTICAL) reduce 405) ((T_IS_SMALLER_OR_EQUAL) reduce 405) ((T_LOGICAL_AND) reduce 405) ((T_LOGICAL_OR) reduce 405) ((T_LOGICAL_XOR) reduce 405) ((T_POW) shift) ((T_SL) reduce 405) ((T_SPACESHIP) reduce 405) ((T_SR) reduce 405) (("^") reduce 405) (("|") reduce 405)) 845 ((("$") shift) ((T_ABSTRACT) shift) ((T_ARRAY) shift) ((T_AS) shift) ((T_BREAK) shift) ((T_CALLABLE) shift) ((T_CASE) shift) ((T_CATCH) shift) ((T_CLASS) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONST) shift) ((T_CONTINUE) shift) ((T_DECLARE) shift) ((T_DEFAULT) shift) ((T_DIR) shift) ((T_DO) shift) ((T_ECHO) shift) ((T_ELSE) shift) ((T_ELSEIF) shift) ((T_EMPTY) shift) ((T_ENDDECLARE) shift) ((T_ENDFOR) shift) ((T_ENDFOREACH) shift) ((T_ENDIF) shift) ((T_ENDSWITCH) shift) ((T_ENDWHILE) shift) ((T_ENUM) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_EXTENDS) shift) ((T_FILE) shift) ((T_FINAL) shift) ((T_FINALLY) shift) ((T_FN) shift) ((T_FOR) shift) ((T_FOREACH) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_GLOBAL) shift) ((T_GOTO) shift) ((T_IF) shift) ((T_IMPLEMENTS) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INSTANCEOF) shift) ((T_INSTEADOF) shift) ((T_INTERFACE) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAMESPACE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_PRINT) shift) ((T_PRIVATE) shift) ((T_PROTECTED) shift) ((T_PUBLIC) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_RETURN) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_SWITCH) shift) ((T_THROW) shift) ((T_TRAIT) shift) ((T_TRAIT_C) shift) ((T_TRY) shift) ((T_UNSET) shift) ((T_USE) shift) ((T_VAR) shift) ((T_VARIABLE) shift) ((T_WHILE) shift) ((T_YIELD) shift) (("{") shift)) 846 ((("%") reduce 73) (("(") reduce 73) (("*") reduce 73) (("+") reduce 73) (("-") reduce 73) ((".") reduce 73) (("/") reduce 73) ((":") reduce 73) (("<") reduce 73) ((">") reduce 73) (("?") reduce 73) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_BOOLEAN_AND) reduce 73) ((T_BOOLEAN_OR) reduce 73) ((T_COALESCE) reduce 73) ((T_INSTANCEOF) reduce 73) ((T_IS_EQUAL) reduce 73) ((T_IS_GREATER_OR_EQUAL) reduce 73) ((T_IS_IDENTICAL) reduce 73) ((T_IS_NOT_EQUAL) reduce 73) ((T_IS_NOT_IDENTICAL) reduce 73) ((T_IS_SMALLER_OR_EQUAL) reduce 73) ((T_LOGICAL_AND) reduce 73) ((T_LOGICAL_OR) reduce 73) ((T_LOGICAL_XOR) reduce 73) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 73) ((T_OBJECT_OPERATOR) reduce 73) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 73) ((T_POW) reduce 73) ((T_SL) reduce 73) ((T_SPACESHIP) reduce 73) ((T_SR) reduce 73) (("[") reduce 73) (("^") reduce 73) (("{") reduce 73) (("|") reduce 73)) 847 ((("%") reduce 52) (("(") reduce 52) (("*") reduce 52) (("+") reduce 52) (("-") reduce 52) ((".") reduce 52) (("/") reduce 52) ((":") reduce 52) (("<") reduce 52) ((">") reduce 52) (("?") reduce 52) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_BOOLEAN_AND) reduce 52) ((T_BOOLEAN_OR) reduce 52) ((T_COALESCE) reduce 52) ((T_INSTANCEOF) reduce 52) ((T_IS_EQUAL) reduce 52) ((T_IS_GREATER_OR_EQUAL) reduce 52) ((T_IS_IDENTICAL) reduce 52) ((T_IS_NOT_EQUAL) reduce 52) ((T_IS_NOT_IDENTICAL) reduce 52) ((T_IS_SMALLER_OR_EQUAL) reduce 52) ((T_LOGICAL_AND) reduce 52) ((T_LOGICAL_OR) reduce 52) ((T_LOGICAL_XOR) reduce 52) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 52) ((T_OBJECT_OPERATOR) reduce 52) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 52) ((T_POW) reduce 52) ((T_SL) reduce 52) ((T_SPACESHIP) reduce 52) ((T_SR) reduce 52) (("[") reduce 52) (("^") reduce 52) (("{") reduce 52) (("|") reduce 52)) 848 ((("%") reduce 27) (("(") reduce 27) (("*") reduce 27) (("+") reduce 27) (("-") reduce 27) ((".") reduce 27) (("/") reduce 27) ((":") reduce 27) (("<") reduce 27) ((">") reduce 27) (("?") reduce 27) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_BOOLEAN_AND) reduce 27) ((T_BOOLEAN_OR) reduce 27) ((T_COALESCE) reduce 27) ((T_INSTANCEOF) reduce 27) ((T_IS_EQUAL) reduce 27) ((T_IS_GREATER_OR_EQUAL) reduce 27) ((T_IS_IDENTICAL) reduce 27) ((T_IS_NOT_EQUAL) reduce 27) ((T_IS_NOT_IDENTICAL) reduce 27) ((T_IS_SMALLER_OR_EQUAL) reduce 27) ((T_LOGICAL_AND) reduce 27) ((T_LOGICAL_OR) reduce 27) ((T_LOGICAL_XOR) reduce 27) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 27) ((T_OBJECT_OPERATOR) reduce 27) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 27) ((T_POW) reduce 27) ((T_SL) reduce 27) ((T_SPACESHIP) reduce 27) ((T_SR) reduce 27) (("[") reduce 27) (("^") reduce 27) (("{") reduce 27) (("|") reduce 27)) 849 ((("%") reduce 51) (("(") reduce 51) (("*") reduce 51) (("+") reduce 51) (("-") reduce 51) ((".") reduce 51) (("/") reduce 51) ((":") reduce 51) (("<") reduce 51) ((">") reduce 51) (("?") reduce 51) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_BOOLEAN_AND) reduce 51) ((T_BOOLEAN_OR) reduce 51) ((T_COALESCE) reduce 51) ((T_INSTANCEOF) reduce 51) ((T_IS_EQUAL) reduce 51) ((T_IS_GREATER_OR_EQUAL) reduce 51) ((T_IS_IDENTICAL) reduce 51) ((T_IS_NOT_EQUAL) reduce 51) ((T_IS_NOT_IDENTICAL) reduce 51) ((T_IS_SMALLER_OR_EQUAL) reduce 51) ((T_LOGICAL_AND) reduce 51) ((T_LOGICAL_OR) reduce 51) ((T_LOGICAL_XOR) reduce 51) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 51) ((T_OBJECT_OPERATOR) reduce 51) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 51) ((T_POW) reduce 51) ((T_SL) reduce 51) ((T_SPACESHIP) reduce 51) ((T_SR) reduce 51) (("[") reduce 51) (("^") reduce 51) (("{") reduce 51) (("|") reduce 51)) 850 ((("%") reduce 53) (("(") reduce 53) (("*") reduce 53) (("+") reduce 53) (("-") reduce 53) ((".") reduce 53) (("/") reduce 53) ((":") reduce 53) (("<") reduce 53) ((">") reduce 53) (("?") reduce 53) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_BOOLEAN_AND) reduce 53) ((T_BOOLEAN_OR) reduce 53) ((T_COALESCE) reduce 53) ((T_INSTANCEOF) reduce 53) ((T_IS_EQUAL) reduce 53) ((T_IS_GREATER_OR_EQUAL) reduce 53) ((T_IS_IDENTICAL) reduce 53) ((T_IS_NOT_EQUAL) reduce 53) ((T_IS_NOT_IDENTICAL) reduce 53) ((T_IS_SMALLER_OR_EQUAL) reduce 53) ((T_LOGICAL_AND) reduce 53) ((T_LOGICAL_OR) reduce 53) ((T_LOGICAL_XOR) reduce 53) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 53) ((T_OBJECT_OPERATOR) reduce 53) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 53) ((T_POW) reduce 53) ((T_SL) reduce 53) ((T_SPACESHIP) reduce 53) ((T_SR) reduce 53) (("[") reduce 53) (("^") reduce 53) (("{") reduce 53) (("|") reduce 53)) 851 ((("%") reduce 49) (("(") reduce 49) (("*") reduce 49) (("+") reduce 49) (("-") reduce 49) ((".") reduce 49) (("/") reduce 49) ((":") reduce 49) (("<") reduce 49) ((">") reduce 49) (("?") reduce 49) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_BOOLEAN_AND) reduce 49) ((T_BOOLEAN_OR) reduce 49) ((T_COALESCE) reduce 49) ((T_INSTANCEOF) reduce 49) ((T_IS_EQUAL) reduce 49) ((T_IS_GREATER_OR_EQUAL) reduce 49) ((T_IS_IDENTICAL) reduce 49) ((T_IS_NOT_EQUAL) reduce 49) ((T_IS_NOT_IDENTICAL) reduce 49) ((T_IS_SMALLER_OR_EQUAL) reduce 49) ((T_LOGICAL_AND) reduce 49) ((T_LOGICAL_OR) reduce 49) ((T_LOGICAL_XOR) reduce 49) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 49) ((T_OBJECT_OPERATOR) reduce 49) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 49) ((T_POW) reduce 49) ((T_SL) reduce 49) ((T_SPACESHIP) reduce 49) ((T_SR) reduce 49) (("[") reduce 49) (("^") reduce 49) (("{") reduce 49) (("|") reduce 49)) 852 ((("%") reduce 29) (("(") reduce 29) (("*") reduce 29) (("+") reduce 29) (("-") reduce 29) ((".") reduce 29) (("/") reduce 29) ((":") reduce 29) (("<") reduce 29) ((">") reduce 29) (("?") reduce 29) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_BOOLEAN_AND) reduce 29) ((T_BOOLEAN_OR) reduce 29) ((T_COALESCE) reduce 29) ((T_INSTANCEOF) reduce 29) ((T_IS_EQUAL) reduce 29) ((T_IS_GREATER_OR_EQUAL) reduce 29) ((T_IS_IDENTICAL) reduce 29) ((T_IS_NOT_EQUAL) reduce 29) ((T_IS_NOT_IDENTICAL) reduce 29) ((T_IS_SMALLER_OR_EQUAL) reduce 29) ((T_LOGICAL_AND) reduce 29) ((T_LOGICAL_OR) reduce 29) ((T_LOGICAL_XOR) reduce 29) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 29) ((T_OBJECT_OPERATOR) reduce 29) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 29) ((T_POW) reduce 29) ((T_SL) reduce 29) ((T_SPACESHIP) reduce 29) ((T_SR) reduce 29) (("[") reduce 29) (("^") reduce 29) (("{") reduce 29) (("|") reduce 29)) 853 ((("%") reduce 59) (("(") reduce 59) (("*") reduce 59) (("+") reduce 59) (("-") reduce 59) ((".") reduce 59) (("/") reduce 59) ((":") reduce 59) (("<") reduce 59) ((">") reduce 59) (("?") reduce 59) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_BOOLEAN_AND) reduce 59) ((T_BOOLEAN_OR) reduce 59) ((T_COALESCE) reduce 59) ((T_INSTANCEOF) reduce 59) ((T_IS_EQUAL) reduce 59) ((T_IS_GREATER_OR_EQUAL) reduce 59) ((T_IS_IDENTICAL) reduce 59) ((T_IS_NOT_EQUAL) reduce 59) ((T_IS_NOT_IDENTICAL) reduce 59) ((T_IS_SMALLER_OR_EQUAL) reduce 59) ((T_LOGICAL_AND) reduce 59) ((T_LOGICAL_OR) reduce 59) ((T_LOGICAL_XOR) reduce 59) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 59) ((T_OBJECT_OPERATOR) reduce 59) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 59) ((T_POW) reduce 59) ((T_SL) reduce 59) ((T_SPACESHIP) reduce 59) ((T_SR) reduce 59) (("[") reduce 59) (("^") reduce 59) (("{") reduce 59) (("|") reduce 59)) 854 ((("%") reduce 60) (("(") reduce 60) (("*") reduce 60) (("+") reduce 60) (("-") reduce 60) ((".") reduce 60) (("/") reduce 60) ((":") reduce 60) (("<") reduce 60) ((">") reduce 60) (("?") reduce 60) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_BOOLEAN_AND) reduce 60) ((T_BOOLEAN_OR) reduce 60) ((T_COALESCE) reduce 60) ((T_INSTANCEOF) reduce 60) ((T_IS_EQUAL) reduce 60) ((T_IS_GREATER_OR_EQUAL) reduce 60) ((T_IS_IDENTICAL) reduce 60) ((T_IS_NOT_EQUAL) reduce 60) ((T_IS_NOT_IDENTICAL) reduce 60) ((T_IS_SMALLER_OR_EQUAL) reduce 60) ((T_LOGICAL_AND) reduce 60) ((T_LOGICAL_OR) reduce 60) ((T_LOGICAL_XOR) reduce 60) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 60) ((T_OBJECT_OPERATOR) reduce 60) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 60) ((T_POW) reduce 60) ((T_SL) reduce 60) ((T_SPACESHIP) reduce 60) ((T_SR) reduce 60) (("[") reduce 60) (("^") reduce 60) (("{") reduce 60) (("|") reduce 60)) 855 ((("%") reduce 11) (("(") reduce 11) (("*") reduce 11) (("+") reduce 11) (("-") reduce 11) ((".") reduce 11) (("/") reduce 11) ((":") reduce 11) (("<") reduce 11) ((">") reduce 11) (("?") reduce 11) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_BOOLEAN_AND) reduce 11) ((T_BOOLEAN_OR) reduce 11) ((T_COALESCE) reduce 11) ((T_INSTANCEOF) reduce 11) ((T_IS_EQUAL) reduce 11) ((T_IS_GREATER_OR_EQUAL) reduce 11) ((T_IS_IDENTICAL) reduce 11) ((T_IS_NOT_EQUAL) reduce 11) ((T_IS_NOT_IDENTICAL) reduce 11) ((T_IS_SMALLER_OR_EQUAL) reduce 11) ((T_LOGICAL_AND) reduce 11) ((T_LOGICAL_OR) reduce 11) ((T_LOGICAL_XOR) reduce 11) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 11) ((T_OBJECT_OPERATOR) reduce 11) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 11) ((T_POW) reduce 11) ((T_SL) reduce 11) ((T_SPACESHIP) reduce 11) ((T_SR) reduce 11) (("[") reduce 11) (("^") reduce 11) (("{") reduce 11) (("|") reduce 11)) 856 ((("%") reduce 42) (("(") reduce 42) (("*") reduce 42) (("+") reduce 42) (("-") reduce 42) ((".") reduce 42) (("/") reduce 42) ((":") reduce 42) (("<") reduce 42) ((">") reduce 42) (("?") reduce 42) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_BOOLEAN_AND) reduce 42) ((T_BOOLEAN_OR) reduce 42) ((T_COALESCE) reduce 42) ((T_INSTANCEOF) reduce 42) ((T_IS_EQUAL) reduce 42) ((T_IS_GREATER_OR_EQUAL) reduce 42) ((T_IS_IDENTICAL) reduce 42) ((T_IS_NOT_EQUAL) reduce 42) ((T_IS_NOT_IDENTICAL) reduce 42) ((T_IS_SMALLER_OR_EQUAL) reduce 42) ((T_LOGICAL_AND) reduce 42) ((T_LOGICAL_OR) reduce 42) ((T_LOGICAL_XOR) reduce 42) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 42) ((T_OBJECT_OPERATOR) reduce 42) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 42) ((T_POW) reduce 42) ((T_SL) reduce 42) ((T_SPACESHIP) reduce 42) ((T_SR) reduce 42) (("[") reduce 42) (("^") reduce 42) (("{") reduce 42) (("|") reduce 42)) 857 ((("%") reduce 39) (("(") reduce 39) (("*") reduce 39) (("+") reduce 39) (("-") reduce 39) ((".") reduce 39) (("/") reduce 39) ((":") reduce 39) (("<") reduce 39) ((">") reduce 39) (("?") reduce 39) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_BOOLEAN_AND) reduce 39) ((T_BOOLEAN_OR) reduce 39) ((T_COALESCE) reduce 39) ((T_INSTANCEOF) reduce 39) ((T_IS_EQUAL) reduce 39) ((T_IS_GREATER_OR_EQUAL) reduce 39) ((T_IS_IDENTICAL) reduce 39) ((T_IS_NOT_EQUAL) reduce 39) ((T_IS_NOT_IDENTICAL) reduce 39) ((T_IS_SMALLER_OR_EQUAL) reduce 39) ((T_LOGICAL_AND) reduce 39) ((T_LOGICAL_OR) reduce 39) ((T_LOGICAL_XOR) reduce 39) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 39) ((T_OBJECT_OPERATOR) reduce 39) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 39) ((T_POW) reduce 39) ((T_SL) reduce 39) ((T_SPACESHIP) reduce 39) ((T_SR) reduce 39) (("[") reduce 39) (("^") reduce 39) (("{") reduce 39) (("|") reduce 39)) 858 ((("%") reduce 25) (("(") reduce 25) (("*") reduce 25) (("+") reduce 25) (("-") reduce 25) ((".") reduce 25) (("/") reduce 25) ((":") reduce 25) (("<") reduce 25) ((">") reduce 25) (("?") reduce 25) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_BOOLEAN_AND) reduce 25) ((T_BOOLEAN_OR) reduce 25) ((T_COALESCE) reduce 25) ((T_INSTANCEOF) reduce 25) ((T_IS_EQUAL) reduce 25) ((T_IS_GREATER_OR_EQUAL) reduce 25) ((T_IS_IDENTICAL) reduce 25) ((T_IS_NOT_EQUAL) reduce 25) ((T_IS_NOT_IDENTICAL) reduce 25) ((T_IS_SMALLER_OR_EQUAL) reduce 25) ((T_LOGICAL_AND) reduce 25) ((T_LOGICAL_OR) reduce 25) ((T_LOGICAL_XOR) reduce 25) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 25) ((T_OBJECT_OPERATOR) reduce 25) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 25) ((T_POW) reduce 25) ((T_SL) reduce 25) ((T_SPACESHIP) reduce 25) ((T_SR) reduce 25) (("[") reduce 25) (("^") reduce 25) (("{") reduce 25) (("|") reduce 25)) 859 ((("%") reduce 50) (("(") reduce 50) (("*") reduce 50) (("+") reduce 50) (("-") reduce 50) ((".") reduce 50) (("/") reduce 50) ((":") reduce 50) (("<") reduce 50) ((">") reduce 50) (("?") reduce 50) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_BOOLEAN_AND) reduce 50) ((T_BOOLEAN_OR) reduce 50) ((T_COALESCE) reduce 50) ((T_INSTANCEOF) reduce 50) ((T_IS_EQUAL) reduce 50) ((T_IS_GREATER_OR_EQUAL) reduce 50) ((T_IS_IDENTICAL) reduce 50) ((T_IS_NOT_EQUAL) reduce 50) ((T_IS_NOT_IDENTICAL) reduce 50) ((T_IS_SMALLER_OR_EQUAL) reduce 50) ((T_LOGICAL_AND) reduce 50) ((T_LOGICAL_OR) reduce 50) ((T_LOGICAL_XOR) reduce 50) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 50) ((T_OBJECT_OPERATOR) reduce 50) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 50) ((T_POW) reduce 50) ((T_SL) reduce 50) ((T_SPACESHIP) reduce 50) ((T_SR) reduce 50) (("[") reduce 50) (("^") reduce 50) (("{") reduce 50) (("|") reduce 50)) 860 ((("%") reduce 66) (("(") reduce 66) (("*") reduce 66) (("+") reduce 66) (("-") reduce 66) ((".") reduce 66) (("/") reduce 66) ((":") reduce 66) (("<") reduce 66) ((">") reduce 66) (("?") reduce 66) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_BOOLEAN_AND) reduce 66) ((T_BOOLEAN_OR) reduce 66) ((T_COALESCE) reduce 66) ((T_INSTANCEOF) reduce 66) ((T_IS_EQUAL) reduce 66) ((T_IS_GREATER_OR_EQUAL) reduce 66) ((T_IS_IDENTICAL) reduce 66) ((T_IS_NOT_EQUAL) reduce 66) ((T_IS_NOT_IDENTICAL) reduce 66) ((T_IS_SMALLER_OR_EQUAL) reduce 66) ((T_LOGICAL_AND) reduce 66) ((T_LOGICAL_OR) reduce 66) ((T_LOGICAL_XOR) reduce 66) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 66) ((T_OBJECT_OPERATOR) reduce 66) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 66) ((T_POW) reduce 66) ((T_SL) reduce 66) ((T_SPACESHIP) reduce 66) ((T_SR) reduce 66) (("[") reduce 66) (("^") reduce 66) (("{") reduce 66) (("|") reduce 66)) 861 ((("%") reduce 18) (("(") reduce 18) (("*") reduce 18) (("+") reduce 18) (("-") reduce 18) ((".") reduce 18) (("/") reduce 18) ((":") reduce 18) (("<") reduce 18) ((">") reduce 18) (("?") reduce 18) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_BOOLEAN_AND) reduce 18) ((T_BOOLEAN_OR) reduce 18) ((T_COALESCE) reduce 18) ((T_INSTANCEOF) reduce 18) ((T_IS_EQUAL) reduce 18) ((T_IS_GREATER_OR_EQUAL) reduce 18) ((T_IS_IDENTICAL) reduce 18) ((T_IS_NOT_EQUAL) reduce 18) ((T_IS_NOT_IDENTICAL) reduce 18) ((T_IS_SMALLER_OR_EQUAL) reduce 18) ((T_LOGICAL_AND) reduce 18) ((T_LOGICAL_OR) reduce 18) ((T_LOGICAL_XOR) reduce 18) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 18) ((T_OBJECT_OPERATOR) reduce 18) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 18) ((T_POW) reduce 18) ((T_SL) reduce 18) ((T_SPACESHIP) reduce 18) ((T_SR) reduce 18) (("[") reduce 18) (("^") reduce 18) (("{") reduce 18) (("|") reduce 18)) 862 ((("%") reduce 17) (("(") reduce 17) (("*") reduce 17) (("+") reduce 17) (("-") reduce 17) ((".") reduce 17) (("/") reduce 17) ((":") reduce 17) (("<") reduce 17) ((">") reduce 17) (("?") reduce 17) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_BOOLEAN_AND) reduce 17) ((T_BOOLEAN_OR) reduce 17) ((T_COALESCE) reduce 17) ((T_INSTANCEOF) reduce 17) ((T_IS_EQUAL) reduce 17) ((T_IS_GREATER_OR_EQUAL) reduce 17) ((T_IS_IDENTICAL) reduce 17) ((T_IS_NOT_EQUAL) reduce 17) ((T_IS_NOT_IDENTICAL) reduce 17) ((T_IS_SMALLER_OR_EQUAL) reduce 17) ((T_LOGICAL_AND) reduce 17) ((T_LOGICAL_OR) reduce 17) ((T_LOGICAL_XOR) reduce 17) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 17) ((T_OBJECT_OPERATOR) reduce 17) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 17) ((T_POW) reduce 17) ((T_SL) reduce 17) ((T_SPACESHIP) reduce 17) ((T_SR) reduce 17) (("[") reduce 17) (("^") reduce 17) (("{") reduce 17) (("|") reduce 17)) 863 ((("%") reduce 15) (("(") reduce 15) (("*") reduce 15) (("+") reduce 15) (("-") reduce 15) ((".") reduce 15) (("/") reduce 15) ((":") reduce 15) (("<") reduce 15) ((">") reduce 15) (("?") reduce 15) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_BOOLEAN_AND) reduce 15) ((T_BOOLEAN_OR) reduce 15) ((T_COALESCE) reduce 15) ((T_INSTANCEOF) reduce 15) ((T_IS_EQUAL) reduce 15) ((T_IS_GREATER_OR_EQUAL) reduce 15) ((T_IS_IDENTICAL) reduce 15) ((T_IS_NOT_EQUAL) reduce 15) ((T_IS_NOT_IDENTICAL) reduce 15) ((T_IS_SMALLER_OR_EQUAL) reduce 15) ((T_LOGICAL_AND) reduce 15) ((T_LOGICAL_OR) reduce 15) ((T_LOGICAL_XOR) reduce 15) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 15) ((T_OBJECT_OPERATOR) reduce 15) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 15) ((T_POW) reduce 15) ((T_SL) reduce 15) ((T_SPACESHIP) reduce 15) ((T_SR) reduce 15) (("[") reduce 15) (("^") reduce 15) (("{") reduce 15) (("|") reduce 15)) 864 ((("%") reduce 14) (("(") reduce 14) (("*") reduce 14) (("+") reduce 14) (("-") reduce 14) ((".") reduce 14) (("/") reduce 14) ((":") reduce 14) (("<") reduce 14) ((">") reduce 14) (("?") reduce 14) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_BOOLEAN_AND) reduce 14) ((T_BOOLEAN_OR) reduce 14) ((T_COALESCE) reduce 14) ((T_INSTANCEOF) reduce 14) ((T_IS_EQUAL) reduce 14) ((T_IS_GREATER_OR_EQUAL) reduce 14) ((T_IS_IDENTICAL) reduce 14) ((T_IS_NOT_EQUAL) reduce 14) ((T_IS_NOT_IDENTICAL) reduce 14) ((T_IS_SMALLER_OR_EQUAL) reduce 14) ((T_LOGICAL_AND) reduce 14) ((T_LOGICAL_OR) reduce 14) ((T_LOGICAL_XOR) reduce 14) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 14) ((T_OBJECT_OPERATOR) reduce 14) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 14) ((T_POW) reduce 14) ((T_SL) reduce 14) ((T_SPACESHIP) reduce 14) ((T_SR) reduce 14) (("[") reduce 14) (("^") reduce 14) (("{") reduce 14) (("|") reduce 14)) 865 ((("%") reduce 38) (("(") reduce 38) (("*") reduce 38) (("+") reduce 38) (("-") reduce 38) ((".") reduce 38) (("/") reduce 38) ((":") reduce 38) (("<") reduce 38) ((">") reduce 38) (("?") reduce 38) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_BOOLEAN_AND) reduce 38) ((T_BOOLEAN_OR) reduce 38) ((T_COALESCE) reduce 38) ((T_INSTANCEOF) reduce 38) ((T_IS_EQUAL) reduce 38) ((T_IS_GREATER_OR_EQUAL) reduce 38) ((T_IS_IDENTICAL) reduce 38) ((T_IS_NOT_EQUAL) reduce 38) ((T_IS_NOT_IDENTICAL) reduce 38) ((T_IS_SMALLER_OR_EQUAL) reduce 38) ((T_LOGICAL_AND) reduce 38) ((T_LOGICAL_OR) reduce 38) ((T_LOGICAL_XOR) reduce 38) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 38) ((T_OBJECT_OPERATOR) reduce 38) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 38) ((T_POW) reduce 38) ((T_SL) reduce 38) ((T_SPACESHIP) reduce 38) ((T_SR) reduce 38) (("[") reduce 38) (("^") reduce 38) (("{") reduce 38) (("|") reduce 38)) 866 ((("%") reduce 26) (("(") reduce 26) (("*") reduce 26) (("+") reduce 26) (("-") reduce 26) ((".") reduce 26) (("/") reduce 26) ((":") reduce 26) (("<") reduce 26) ((">") reduce 26) (("?") reduce 26) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_BOOLEAN_AND) reduce 26) ((T_BOOLEAN_OR) reduce 26) ((T_COALESCE) reduce 26) ((T_INSTANCEOF) reduce 26) ((T_IS_EQUAL) reduce 26) ((T_IS_GREATER_OR_EQUAL) reduce 26) ((T_IS_IDENTICAL) reduce 26) ((T_IS_NOT_EQUAL) reduce 26) ((T_IS_NOT_IDENTICAL) reduce 26) ((T_IS_SMALLER_OR_EQUAL) reduce 26) ((T_LOGICAL_AND) reduce 26) ((T_LOGICAL_OR) reduce 26) ((T_LOGICAL_XOR) reduce 26) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 26) ((T_OBJECT_OPERATOR) reduce 26) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 26) ((T_POW) reduce 26) ((T_SL) reduce 26) ((T_SPACESHIP) reduce 26) ((T_SR) reduce 26) (("[") reduce 26) (("^") reduce 26) (("{") reduce 26) (("|") reduce 26)) 867 ((("%") reduce 22) (("(") reduce 22) (("*") reduce 22) (("+") reduce 22) (("-") reduce 22) ((".") reduce 22) (("/") reduce 22) ((":") reduce 22) (("<") reduce 22) ((">") reduce 22) (("?") reduce 22) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_BOOLEAN_AND) reduce 22) ((T_BOOLEAN_OR) reduce 22) ((T_COALESCE) reduce 22) ((T_INSTANCEOF) reduce 22) ((T_IS_EQUAL) reduce 22) ((T_IS_GREATER_OR_EQUAL) reduce 22) ((T_IS_IDENTICAL) reduce 22) ((T_IS_NOT_EQUAL) reduce 22) ((T_IS_NOT_IDENTICAL) reduce 22) ((T_IS_SMALLER_OR_EQUAL) reduce 22) ((T_LOGICAL_AND) reduce 22) ((T_LOGICAL_OR) reduce 22) ((T_LOGICAL_XOR) reduce 22) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 22) ((T_OBJECT_OPERATOR) reduce 22) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 22) ((T_POW) reduce 22) ((T_SL) reduce 22) ((T_SPACESHIP) reduce 22) ((T_SR) reduce 22) (("[") reduce 22) (("^") reduce 22) (("{") reduce 22) (("|") reduce 22)) 868 ((("%") reduce 24) (("(") reduce 24) (("*") reduce 24) (("+") reduce 24) (("-") reduce 24) ((".") reduce 24) (("/") reduce 24) ((":") reduce 24) (("<") reduce 24) ((">") reduce 24) (("?") reduce 24) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_BOOLEAN_AND) reduce 24) ((T_BOOLEAN_OR) reduce 24) ((T_COALESCE) reduce 24) ((T_INSTANCEOF) reduce 24) ((T_IS_EQUAL) reduce 24) ((T_IS_GREATER_OR_EQUAL) reduce 24) ((T_IS_IDENTICAL) reduce 24) ((T_IS_NOT_EQUAL) reduce 24) ((T_IS_NOT_IDENTICAL) reduce 24) ((T_IS_SMALLER_OR_EQUAL) reduce 24) ((T_LOGICAL_AND) reduce 24) ((T_LOGICAL_OR) reduce 24) ((T_LOGICAL_XOR) reduce 24) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 24) ((T_OBJECT_OPERATOR) reduce 24) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 24) ((T_POW) reduce 24) ((T_SL) reduce 24) ((T_SPACESHIP) reduce 24) ((T_SR) reduce 24) (("[") reduce 24) (("^") reduce 24) (("{") reduce 24) (("|") reduce 24)) 869 ((("%") reduce 16) (("(") reduce 16) (("*") reduce 16) (("+") reduce 16) (("-") reduce 16) ((".") reduce 16) (("/") reduce 16) ((":") reduce 16) (("<") reduce 16) ((">") reduce 16) (("?") reduce 16) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_BOOLEAN_AND) reduce 16) ((T_BOOLEAN_OR) reduce 16) ((T_COALESCE) reduce 16) ((T_INSTANCEOF) reduce 16) ((T_IS_EQUAL) reduce 16) ((T_IS_GREATER_OR_EQUAL) reduce 16) ((T_IS_IDENTICAL) reduce 16) ((T_IS_NOT_EQUAL) reduce 16) ((T_IS_NOT_IDENTICAL) reduce 16) ((T_IS_SMALLER_OR_EQUAL) reduce 16) ((T_LOGICAL_AND) reduce 16) ((T_LOGICAL_OR) reduce 16) ((T_LOGICAL_XOR) reduce 16) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 16) ((T_OBJECT_OPERATOR) reduce 16) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 16) ((T_POW) reduce 16) ((T_SL) reduce 16) ((T_SPACESHIP) reduce 16) ((T_SR) reduce 16) (("[") reduce 16) (("^") reduce 16) (("{") reduce 16) (("|") reduce 16)) 870 ((("%") reduce 48) (("(") reduce 48) (("*") reduce 48) (("+") reduce 48) (("-") reduce 48) ((".") reduce 48) (("/") reduce 48) ((":") reduce 48) (("<") reduce 48) ((">") reduce 48) (("?") reduce 48) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_BOOLEAN_AND) reduce 48) ((T_BOOLEAN_OR) reduce 48) ((T_COALESCE) reduce 48) ((T_INSTANCEOF) reduce 48) ((T_IS_EQUAL) reduce 48) ((T_IS_GREATER_OR_EQUAL) reduce 48) ((T_IS_IDENTICAL) reduce 48) ((T_IS_NOT_EQUAL) reduce 48) ((T_IS_NOT_IDENTICAL) reduce 48) ((T_IS_SMALLER_OR_EQUAL) reduce 48) ((T_LOGICAL_AND) reduce 48) ((T_LOGICAL_OR) reduce 48) ((T_LOGICAL_XOR) reduce 48) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 48) ((T_OBJECT_OPERATOR) reduce 48) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 48) ((T_POW) reduce 48) ((T_SL) reduce 48) ((T_SPACESHIP) reduce 48) ((T_SR) reduce 48) (("[") reduce 48) (("^") reduce 48) (("{") reduce 48) (("|") reduce 48)) 871 ((("%") reduce 20) (("(") reduce 20) (("*") reduce 20) (("+") reduce 20) (("-") reduce 20) ((".") reduce 20) (("/") reduce 20) ((":") reduce 20) (("<") reduce 20) ((">") reduce 20) (("?") reduce 20) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_BOOLEAN_AND) reduce 20) ((T_BOOLEAN_OR) reduce 20) ((T_COALESCE) reduce 20) ((T_INSTANCEOF) reduce 20) ((T_IS_EQUAL) reduce 20) ((T_IS_GREATER_OR_EQUAL) reduce 20) ((T_IS_IDENTICAL) reduce 20) ((T_IS_NOT_EQUAL) reduce 20) ((T_IS_NOT_IDENTICAL) reduce 20) ((T_IS_SMALLER_OR_EQUAL) reduce 20) ((T_LOGICAL_AND) reduce 20) ((T_LOGICAL_OR) reduce 20) ((T_LOGICAL_XOR) reduce 20) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 20) ((T_OBJECT_OPERATOR) reduce 20) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 20) ((T_POW) reduce 20) ((T_SL) reduce 20) ((T_SPACESHIP) reduce 20) ((T_SR) reduce 20) (("[") reduce 20) (("^") reduce 20) (("{") reduce 20) (("|") reduce 20)) 872 ((("%") reduce 70) (("(") reduce 70) (("*") reduce 70) (("+") reduce 70) (("-") reduce 70) ((".") reduce 70) (("/") reduce 70) ((":") reduce 70) (("<") reduce 70) ((">") reduce 70) (("?") reduce 70) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_BOOLEAN_AND) reduce 70) ((T_BOOLEAN_OR) reduce 70) ((T_COALESCE) reduce 70) ((T_INSTANCEOF) reduce 70) ((T_IS_EQUAL) reduce 70) ((T_IS_GREATER_OR_EQUAL) reduce 70) ((T_IS_IDENTICAL) reduce 70) ((T_IS_NOT_EQUAL) reduce 70) ((T_IS_NOT_IDENTICAL) reduce 70) ((T_IS_SMALLER_OR_EQUAL) reduce 70) ((T_LOGICAL_AND) reduce 70) ((T_LOGICAL_OR) reduce 70) ((T_LOGICAL_XOR) reduce 70) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 70) ((T_OBJECT_OPERATOR) reduce 70) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 70) ((T_POW) reduce 70) ((T_SL) reduce 70) ((T_SPACESHIP) reduce 70) ((T_SR) reduce 70) (("[") reduce 70) (("^") reduce 70) (("{") reduce 70) (("|") reduce 70)) 873 ((("%") reduce 3) (("(") reduce 3) (("*") reduce 3) (("+") reduce 3) (("-") reduce 3) ((".") reduce 3) (("/") reduce 3) ((":") reduce 3) (("<") reduce 3) ((">") reduce 3) (("?") reduce 3) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_BOOLEAN_AND) reduce 3) ((T_BOOLEAN_OR) reduce 3) ((T_COALESCE) reduce 3) ((T_INSTANCEOF) reduce 3) ((T_IS_EQUAL) reduce 3) ((T_IS_GREATER_OR_EQUAL) reduce 3) ((T_IS_IDENTICAL) reduce 3) ((T_IS_NOT_EQUAL) reduce 3) ((T_IS_NOT_IDENTICAL) reduce 3) ((T_IS_SMALLER_OR_EQUAL) reduce 3) ((T_LOGICAL_AND) reduce 3) ((T_LOGICAL_OR) reduce 3) ((T_LOGICAL_XOR) reduce 3) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 3) ((T_OBJECT_OPERATOR) reduce 3) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 3) ((T_POW) reduce 3) ((T_SL) reduce 3) ((T_SPACESHIP) reduce 3) ((T_SR) reduce 3) (("[") reduce 3) (("^") reduce 3) (("{") reduce 3) (("|") reduce 3)) 874 ((("%") reduce 12) (("(") reduce 12) (("*") reduce 12) (("+") reduce 12) (("-") reduce 12) ((".") reduce 12) (("/") reduce 12) ((":") reduce 12) (("<") reduce 12) ((">") reduce 12) (("?") reduce 12) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_BOOLEAN_AND) reduce 12) ((T_BOOLEAN_OR) reduce 12) ((T_COALESCE) reduce 12) ((T_INSTANCEOF) reduce 12) ((T_IS_EQUAL) reduce 12) ((T_IS_GREATER_OR_EQUAL) reduce 12) ((T_IS_IDENTICAL) reduce 12) ((T_IS_NOT_EQUAL) reduce 12) ((T_IS_NOT_IDENTICAL) reduce 12) ((T_IS_SMALLER_OR_EQUAL) reduce 12) ((T_LOGICAL_AND) reduce 12) ((T_LOGICAL_OR) reduce 12) ((T_LOGICAL_XOR) reduce 12) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 12) ((T_OBJECT_OPERATOR) reduce 12) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 12) ((T_POW) reduce 12) ((T_SL) reduce 12) ((T_SPACESHIP) reduce 12) ((T_SR) reduce 12) (("[") reduce 12) (("^") reduce 12) (("{") reduce 12) (("|") reduce 12)) 875 ((("%") reduce 54) (("(") reduce 54) (("*") reduce 54) (("+") reduce 54) (("-") reduce 54) ((".") reduce 54) (("/") reduce 54) ((":") reduce 54) (("<") reduce 54) ((">") reduce 54) (("?") reduce 54) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_BOOLEAN_AND) reduce 54) ((T_BOOLEAN_OR) reduce 54) ((T_COALESCE) reduce 54) ((T_INSTANCEOF) reduce 54) ((T_IS_EQUAL) reduce 54) ((T_IS_GREATER_OR_EQUAL) reduce 54) ((T_IS_IDENTICAL) reduce 54) ((T_IS_NOT_EQUAL) reduce 54) ((T_IS_NOT_IDENTICAL) reduce 54) ((T_IS_SMALLER_OR_EQUAL) reduce 54) ((T_LOGICAL_AND) reduce 54) ((T_LOGICAL_OR) reduce 54) ((T_LOGICAL_XOR) reduce 54) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 54) ((T_OBJECT_OPERATOR) reduce 54) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 54) ((T_POW) reduce 54) ((T_SL) reduce 54) ((T_SPACESHIP) reduce 54) ((T_SR) reduce 54) (("[") reduce 54) (("^") reduce 54) (("{") reduce 54) (("|") reduce 54)) 876 ((("%") reduce 65) (("(") reduce 65) (("*") reduce 65) (("+") reduce 65) (("-") reduce 65) ((".") reduce 65) (("/") reduce 65) ((":") reduce 65) (("<") reduce 65) ((">") reduce 65) (("?") reduce 65) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_BOOLEAN_AND) reduce 65) ((T_BOOLEAN_OR) reduce 65) ((T_COALESCE) reduce 65) ((T_INSTANCEOF) reduce 65) ((T_IS_EQUAL) reduce 65) ((T_IS_GREATER_OR_EQUAL) reduce 65) ((T_IS_IDENTICAL) reduce 65) ((T_IS_NOT_EQUAL) reduce 65) ((T_IS_NOT_IDENTICAL) reduce 65) ((T_IS_SMALLER_OR_EQUAL) reduce 65) ((T_LOGICAL_AND) reduce 65) ((T_LOGICAL_OR) reduce 65) ((T_LOGICAL_XOR) reduce 65) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 65) ((T_OBJECT_OPERATOR) reduce 65) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 65) ((T_POW) reduce 65) ((T_SL) reduce 65) ((T_SPACESHIP) reduce 65) ((T_SR) reduce 65) (("[") reduce 65) (("^") reduce 65) (("{") reduce 65) (("|") reduce 65)) 877 ((("%") reduce 74) (("(") reduce 74) (("*") reduce 74) (("+") reduce 74) (("-") reduce 74) ((".") reduce 74) (("/") reduce 74) ((":") reduce 74) (("<") reduce 74) ((">") reduce 74) (("?") reduce 74) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_BOOLEAN_AND) reduce 74) ((T_BOOLEAN_OR) reduce 74) ((T_COALESCE) reduce 74) ((T_INSTANCEOF) reduce 74) ((T_IS_EQUAL) reduce 74) ((T_IS_GREATER_OR_EQUAL) reduce 74) ((T_IS_IDENTICAL) reduce 74) ((T_IS_NOT_EQUAL) reduce 74) ((T_IS_NOT_IDENTICAL) reduce 74) ((T_IS_SMALLER_OR_EQUAL) reduce 74) ((T_LOGICAL_AND) reduce 74) ((T_LOGICAL_OR) reduce 74) ((T_LOGICAL_XOR) reduce 74) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 74) ((T_OBJECT_OPERATOR) reduce 74) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 74) ((T_POW) reduce 74) ((T_SL) reduce 74) ((T_SPACESHIP) reduce 74) ((T_SR) reduce 74) (("[") reduce 74) (("^") reduce 74) (("{") reduce 74) (("|") reduce 74)) 878 ((("%") reduce 30) (("(") reduce 30) (("*") reduce 30) (("+") reduce 30) (("-") reduce 30) ((".") reduce 30) (("/") reduce 30) ((":") reduce 30) (("<") reduce 30) ((">") reduce 30) (("?") reduce 30) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_BOOLEAN_AND) reduce 30) ((T_BOOLEAN_OR) reduce 30) ((T_COALESCE) reduce 30) ((T_INSTANCEOF) reduce 30) ((T_IS_EQUAL) reduce 30) ((T_IS_GREATER_OR_EQUAL) reduce 30) ((T_IS_IDENTICAL) reduce 30) ((T_IS_NOT_EQUAL) reduce 30) ((T_IS_NOT_IDENTICAL) reduce 30) ((T_IS_SMALLER_OR_EQUAL) reduce 30) ((T_LOGICAL_AND) reduce 30) ((T_LOGICAL_OR) reduce 30) ((T_LOGICAL_XOR) reduce 30) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 30) ((T_OBJECT_OPERATOR) reduce 30) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 30) ((T_POW) reduce 30) ((T_SL) reduce 30) ((T_SPACESHIP) reduce 30) ((T_SR) reduce 30) (("[") reduce 30) (("^") reduce 30) (("{") reduce 30) (("|") reduce 30)) 879 ((("%") reduce 68) (("(") reduce 68) (("*") reduce 68) (("+") reduce 68) (("-") reduce 68) ((".") reduce 68) (("/") reduce 68) ((":") reduce 68) (("<") reduce 68) ((">") reduce 68) (("?") reduce 68) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_BOOLEAN_AND) reduce 68) ((T_BOOLEAN_OR) reduce 68) ((T_COALESCE) reduce 68) ((T_INSTANCEOF) reduce 68) ((T_IS_EQUAL) reduce 68) ((T_IS_GREATER_OR_EQUAL) reduce 68) ((T_IS_IDENTICAL) reduce 68) ((T_IS_NOT_EQUAL) reduce 68) ((T_IS_NOT_IDENTICAL) reduce 68) ((T_IS_SMALLER_OR_EQUAL) reduce 68) ((T_LOGICAL_AND) reduce 68) ((T_LOGICAL_OR) reduce 68) ((T_LOGICAL_XOR) reduce 68) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 68) ((T_OBJECT_OPERATOR) reduce 68) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 68) ((T_POW) reduce 68) ((T_SL) reduce 68) ((T_SPACESHIP) reduce 68) ((T_SR) reduce 68) (("[") reduce 68) (("^") reduce 68) (("{") reduce 68) (("|") reduce 68)) 880 ((("%") reduce 21) (("(") reduce 21) (("*") reduce 21) (("+") reduce 21) (("-") reduce 21) ((".") reduce 21) (("/") reduce 21) ((":") reduce 21) (("<") reduce 21) ((">") reduce 21) (("?") reduce 21) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_BOOLEAN_AND) reduce 21) ((T_BOOLEAN_OR) reduce 21) ((T_COALESCE) reduce 21) ((T_INSTANCEOF) reduce 21) ((T_IS_EQUAL) reduce 21) ((T_IS_GREATER_OR_EQUAL) reduce 21) ((T_IS_IDENTICAL) reduce 21) ((T_IS_NOT_EQUAL) reduce 21) ((T_IS_NOT_IDENTICAL) reduce 21) ((T_IS_SMALLER_OR_EQUAL) reduce 21) ((T_LOGICAL_AND) reduce 21) ((T_LOGICAL_OR) reduce 21) ((T_LOGICAL_XOR) reduce 21) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 21) ((T_OBJECT_OPERATOR) reduce 21) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 21) ((T_POW) reduce 21) ((T_SL) reduce 21) ((T_SPACESHIP) reduce 21) ((T_SR) reduce 21) (("[") reduce 21) (("^") reduce 21) (("{") reduce 21) (("|") reduce 21)) 881 ((("%") reduce 23) (("(") reduce 23) (("*") reduce 23) (("+") reduce 23) (("-") reduce 23) ((".") reduce 23) (("/") reduce 23) ((":") reduce 23) (("<") reduce 23) ((">") reduce 23) (("?") reduce 23) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_BOOLEAN_AND) reduce 23) ((T_BOOLEAN_OR) reduce 23) ((T_COALESCE) reduce 23) ((T_INSTANCEOF) reduce 23) ((T_IS_EQUAL) reduce 23) ((T_IS_GREATER_OR_EQUAL) reduce 23) ((T_IS_IDENTICAL) reduce 23) ((T_IS_NOT_EQUAL) reduce 23) ((T_IS_NOT_IDENTICAL) reduce 23) ((T_IS_SMALLER_OR_EQUAL) reduce 23) ((T_LOGICAL_AND) reduce 23) ((T_LOGICAL_OR) reduce 23) ((T_LOGICAL_XOR) reduce 23) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 23) ((T_OBJECT_OPERATOR) reduce 23) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 23) ((T_POW) reduce 23) ((T_SL) reduce 23) ((T_SPACESHIP) reduce 23) ((T_SR) reduce 23) (("[") reduce 23) (("^") reduce 23) (("{") reduce 23) (("|") reduce 23)) 882 ((("%") reduce 41) (("(") reduce 41) (("*") reduce 41) (("+") reduce 41) (("-") reduce 41) ((".") reduce 41) (("/") reduce 41) ((":") reduce 41) (("<") reduce 41) ((">") reduce 41) (("?") reduce 41) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_BOOLEAN_AND) reduce 41) ((T_BOOLEAN_OR) reduce 41) ((T_COALESCE) reduce 41) ((T_INSTANCEOF) reduce 41) ((T_IS_EQUAL) reduce 41) ((T_IS_GREATER_OR_EQUAL) reduce 41) ((T_IS_IDENTICAL) reduce 41) ((T_IS_NOT_EQUAL) reduce 41) ((T_IS_NOT_IDENTICAL) reduce 41) ((T_IS_SMALLER_OR_EQUAL) reduce 41) ((T_LOGICAL_AND) reduce 41) ((T_LOGICAL_OR) reduce 41) ((T_LOGICAL_XOR) reduce 41) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 41) ((T_OBJECT_OPERATOR) reduce 41) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 41) ((T_POW) reduce 41) ((T_SL) reduce 41) ((T_SPACESHIP) reduce 41) ((T_SR) reduce 41) (("[") reduce 41) (("^") reduce 41) (("{") reduce 41) (("|") reduce 41)) 883 ((("%") reduce 62) (("(") reduce 62) (("*") reduce 62) (("+") reduce 62) (("-") reduce 62) ((".") reduce 62) (("/") reduce 62) ((":") reduce 62) (("<") reduce 62) ((">") reduce 62) (("?") reduce 62) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_BOOLEAN_AND) reduce 62) ((T_BOOLEAN_OR) reduce 62) ((T_COALESCE) reduce 62) ((T_INSTANCEOF) reduce 62) ((T_IS_EQUAL) reduce 62) ((T_IS_GREATER_OR_EQUAL) reduce 62) ((T_IS_IDENTICAL) reduce 62) ((T_IS_NOT_EQUAL) reduce 62) ((T_IS_NOT_IDENTICAL) reduce 62) ((T_IS_SMALLER_OR_EQUAL) reduce 62) ((T_LOGICAL_AND) reduce 62) ((T_LOGICAL_OR) reduce 62) ((T_LOGICAL_XOR) reduce 62) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 62) ((T_OBJECT_OPERATOR) reduce 62) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 62) ((T_POW) reduce 62) ((T_SL) reduce 62) ((T_SPACESHIP) reduce 62) ((T_SR) reduce 62) (("[") reduce 62) (("^") reduce 62) (("{") reduce 62) (("|") reduce 62)) 884 ((("%") reduce 34) (("(") reduce 34) (("*") reduce 34) (("+") reduce 34) (("-") reduce 34) ((".") reduce 34) (("/") reduce 34) ((":") reduce 34) (("<") reduce 34) ((">") reduce 34) (("?") reduce 34) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_BOOLEAN_AND) reduce 34) ((T_BOOLEAN_OR) reduce 34) ((T_COALESCE) reduce 34) ((T_INSTANCEOF) reduce 34) ((T_IS_EQUAL) reduce 34) ((T_IS_GREATER_OR_EQUAL) reduce 34) ((T_IS_IDENTICAL) reduce 34) ((T_IS_NOT_EQUAL) reduce 34) ((T_IS_NOT_IDENTICAL) reduce 34) ((T_IS_SMALLER_OR_EQUAL) reduce 34) ((T_LOGICAL_AND) reduce 34) ((T_LOGICAL_OR) reduce 34) ((T_LOGICAL_XOR) reduce 34) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 34) ((T_OBJECT_OPERATOR) reduce 34) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 34) ((T_POW) reduce 34) ((T_SL) reduce 34) ((T_SPACESHIP) reduce 34) ((T_SR) reduce 34) (("[") reduce 34) (("^") reduce 34) (("{") reduce 34) (("|") reduce 34)) 885 ((("%") reduce 40) (("(") reduce 40) (("*") reduce 40) (("+") reduce 40) (("-") reduce 40) ((".") reduce 40) (("/") reduce 40) ((":") reduce 40) (("<") reduce 40) ((">") reduce 40) (("?") reduce 40) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_BOOLEAN_AND) reduce 40) ((T_BOOLEAN_OR) reduce 40) ((T_COALESCE) reduce 40) ((T_INSTANCEOF) reduce 40) ((T_IS_EQUAL) reduce 40) ((T_IS_GREATER_OR_EQUAL) reduce 40) ((T_IS_IDENTICAL) reduce 40) ((T_IS_NOT_EQUAL) reduce 40) ((T_IS_NOT_IDENTICAL) reduce 40) ((T_IS_SMALLER_OR_EQUAL) reduce 40) ((T_LOGICAL_AND) reduce 40) ((T_LOGICAL_OR) reduce 40) ((T_LOGICAL_XOR) reduce 40) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 40) ((T_OBJECT_OPERATOR) reduce 40) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 40) ((T_POW) reduce 40) ((T_SL) reduce 40) ((T_SPACESHIP) reduce 40) ((T_SR) reduce 40) (("[") reduce 40) (("^") reduce 40) (("{") reduce 40) (("|") reduce 40)) 886 ((("%") reduce 13) (("(") reduce 13) (("*") reduce 13) (("+") reduce 13) (("-") reduce 13) ((".") reduce 13) (("/") reduce 13) ((":") reduce 13) (("<") reduce 13) ((">") reduce 13) (("?") reduce 13) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_BOOLEAN_AND) reduce 13) ((T_BOOLEAN_OR) reduce 13) ((T_COALESCE) reduce 13) ((T_INSTANCEOF) reduce 13) ((T_IS_EQUAL) reduce 13) ((T_IS_GREATER_OR_EQUAL) reduce 13) ((T_IS_IDENTICAL) reduce 13) ((T_IS_NOT_EQUAL) reduce 13) ((T_IS_NOT_IDENTICAL) reduce 13) ((T_IS_SMALLER_OR_EQUAL) reduce 13) ((T_LOGICAL_AND) reduce 13) ((T_LOGICAL_OR) reduce 13) ((T_LOGICAL_XOR) reduce 13) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 13) ((T_OBJECT_OPERATOR) reduce 13) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 13) ((T_POW) reduce 13) ((T_SL) reduce 13) ((T_SPACESHIP) reduce 13) ((T_SR) reduce 13) (("[") reduce 13) (("^") reduce 13) (("{") reduce 13) (("|") reduce 13)) 887 ((("%") reduce 55) (("(") reduce 55) (("*") reduce 55) (("+") reduce 55) (("-") reduce 55) ((".") reduce 55) (("/") reduce 55) ((":") reduce 55) (("<") reduce 55) ((">") reduce 55) (("?") reduce 55) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_BOOLEAN_AND) reduce 55) ((T_BOOLEAN_OR) reduce 55) ((T_COALESCE) reduce 55) ((T_INSTANCEOF) reduce 55) ((T_IS_EQUAL) reduce 55) ((T_IS_GREATER_OR_EQUAL) reduce 55) ((T_IS_IDENTICAL) reduce 55) ((T_IS_NOT_EQUAL) reduce 55) ((T_IS_NOT_IDENTICAL) reduce 55) ((T_IS_SMALLER_OR_EQUAL) reduce 55) ((T_LOGICAL_AND) reduce 55) ((T_LOGICAL_OR) reduce 55) ((T_LOGICAL_XOR) reduce 55) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 55) ((T_OBJECT_OPERATOR) reduce 55) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 55) ((T_POW) reduce 55) ((T_SL) reduce 55) ((T_SPACESHIP) reduce 55) ((T_SR) reduce 55) (("[") reduce 55) (("^") reduce 55) (("{") reduce 55) (("|") reduce 55)) 888 ((("%") reduce 1) (("(") reduce 1) (("*") reduce 1) (("+") reduce 1) (("-") reduce 1) ((".") reduce 1) (("/") reduce 1) ((":") reduce 1) (("<") reduce 1) ((">") reduce 1) (("?") reduce 1) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_BOOLEAN_AND) reduce 1) ((T_BOOLEAN_OR) reduce 1) ((T_COALESCE) reduce 1) ((T_INSTANCEOF) reduce 1) ((T_IS_EQUAL) reduce 1) ((T_IS_GREATER_OR_EQUAL) reduce 1) ((T_IS_IDENTICAL) reduce 1) ((T_IS_NOT_EQUAL) reduce 1) ((T_IS_NOT_IDENTICAL) reduce 1) ((T_IS_SMALLER_OR_EQUAL) reduce 1) ((T_LOGICAL_AND) reduce 1) ((T_LOGICAL_OR) reduce 1) ((T_LOGICAL_XOR) reduce 1) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 1) ((T_OBJECT_OPERATOR) reduce 1) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 1) ((T_POW) reduce 1) ((T_SL) reduce 1) ((T_SPACESHIP) reduce 1) ((T_SR) reduce 1) (("[") reduce 1) (("^") reduce 1) (("{") reduce 1) (("|") reduce 1)) 889 ((("%") reduce 2) (("(") reduce 2) (("*") reduce 2) (("+") reduce 2) (("-") reduce 2) ((".") reduce 2) (("/") reduce 2) ((":") reduce 2) (("<") reduce 2) ((">") reduce 2) (("?") reduce 2) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_BOOLEAN_AND) reduce 2) ((T_BOOLEAN_OR) reduce 2) ((T_COALESCE) reduce 2) ((T_INSTANCEOF) reduce 2) ((T_IS_EQUAL) reduce 2) ((T_IS_GREATER_OR_EQUAL) reduce 2) ((T_IS_IDENTICAL) reduce 2) ((T_IS_NOT_EQUAL) reduce 2) ((T_IS_NOT_IDENTICAL) reduce 2) ((T_IS_SMALLER_OR_EQUAL) reduce 2) ((T_LOGICAL_AND) reduce 2) ((T_LOGICAL_OR) reduce 2) ((T_LOGICAL_XOR) reduce 2) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 2) ((T_OBJECT_OPERATOR) reduce 2) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 2) ((T_POW) reduce 2) ((T_SL) reduce 2) ((T_SPACESHIP) reduce 2) ((T_SR) reduce 2) (("[") reduce 2) (("^") reduce 2) (("{") reduce 2) (("|") reduce 2)) 890 ((("%") reduce 9) (("(") reduce 9) (("*") reduce 9) (("+") reduce 9) (("-") reduce 9) ((".") reduce 9) (("/") reduce 9) ((":") reduce 9) (("<") reduce 9) ((">") reduce 9) (("?") reduce 9) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_BOOLEAN_AND) reduce 9) ((T_BOOLEAN_OR) reduce 9) ((T_COALESCE) reduce 9) ((T_INSTANCEOF) reduce 9) ((T_IS_EQUAL) reduce 9) ((T_IS_GREATER_OR_EQUAL) reduce 9) ((T_IS_IDENTICAL) reduce 9) ((T_IS_NOT_EQUAL) reduce 9) ((T_IS_NOT_IDENTICAL) reduce 9) ((T_IS_SMALLER_OR_EQUAL) reduce 9) ((T_LOGICAL_AND) reduce 9) ((T_LOGICAL_OR) reduce 9) ((T_LOGICAL_XOR) reduce 9) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 9) ((T_OBJECT_OPERATOR) reduce 9) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 9) ((T_POW) reduce 9) ((T_SL) reduce 9) ((T_SPACESHIP) reduce 9) ((T_SR) reduce 9) (("[") reduce 9) (("^") reduce 9) (("{") reduce 9) (("|") reduce 9)) 891 ((("%") reduce 33) (("(") reduce 33) (("*") reduce 33) (("+") reduce 33) (("-") reduce 33) ((".") reduce 33) (("/") reduce 33) ((":") reduce 33) (("<") reduce 33) ((">") reduce 33) (("?") reduce 33) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_BOOLEAN_AND) reduce 33) ((T_BOOLEAN_OR) reduce 33) ((T_COALESCE) reduce 33) ((T_INSTANCEOF) reduce 33) ((T_IS_EQUAL) reduce 33) ((T_IS_GREATER_OR_EQUAL) reduce 33) ((T_IS_IDENTICAL) reduce 33) ((T_IS_NOT_EQUAL) reduce 33) ((T_IS_NOT_IDENTICAL) reduce 33) ((T_IS_SMALLER_OR_EQUAL) reduce 33) ((T_LOGICAL_AND) reduce 33) ((T_LOGICAL_OR) reduce 33) ((T_LOGICAL_XOR) reduce 33) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 33) ((T_OBJECT_OPERATOR) reduce 33) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 33) ((T_POW) reduce 33) ((T_SL) reduce 33) ((T_SPACESHIP) reduce 33) ((T_SR) reduce 33) (("[") reduce 33) (("^") reduce 33) (("{") reduce 33) (("|") reduce 33)) 892 ((("%") reduce 58) (("(") reduce 58) (("*") reduce 58) (("+") reduce 58) (("-") reduce 58) ((".") reduce 58) (("/") reduce 58) ((":") reduce 58) (("<") reduce 58) ((">") reduce 58) (("?") reduce 58) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_BOOLEAN_AND) reduce 58) ((T_BOOLEAN_OR) reduce 58) ((T_COALESCE) reduce 58) ((T_INSTANCEOF) reduce 58) ((T_IS_EQUAL) reduce 58) ((T_IS_GREATER_OR_EQUAL) reduce 58) ((T_IS_IDENTICAL) reduce 58) ((T_IS_NOT_EQUAL) reduce 58) ((T_IS_NOT_IDENTICAL) reduce 58) ((T_IS_SMALLER_OR_EQUAL) reduce 58) ((T_LOGICAL_AND) reduce 58) ((T_LOGICAL_OR) reduce 58) ((T_LOGICAL_XOR) reduce 58) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 58) ((T_OBJECT_OPERATOR) reduce 58) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 58) ((T_POW) reduce 58) ((T_SL) reduce 58) ((T_SPACESHIP) reduce 58) ((T_SR) reduce 58) (("[") reduce 58) (("^") reduce 58) (("{") reduce 58) (("|") reduce 58)) 893 ((("%") reduce 37) (("(") reduce 37) (("*") reduce 37) (("+") reduce 37) (("-") reduce 37) ((".") reduce 37) (("/") reduce 37) ((":") reduce 37) (("<") reduce 37) ((">") reduce 37) (("?") reduce 37) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_BOOLEAN_AND) reduce 37) ((T_BOOLEAN_OR) reduce 37) ((T_COALESCE) reduce 37) ((T_INSTANCEOF) reduce 37) ((T_IS_EQUAL) reduce 37) ((T_IS_GREATER_OR_EQUAL) reduce 37) ((T_IS_IDENTICAL) reduce 37) ((T_IS_NOT_EQUAL) reduce 37) ((T_IS_NOT_IDENTICAL) reduce 37) ((T_IS_SMALLER_OR_EQUAL) reduce 37) ((T_LOGICAL_AND) reduce 37) ((T_LOGICAL_OR) reduce 37) ((T_LOGICAL_XOR) reduce 37) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 37) ((T_OBJECT_OPERATOR) reduce 37) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 37) ((T_POW) reduce 37) ((T_SL) reduce 37) ((T_SPACESHIP) reduce 37) ((T_SR) reduce 37) (("[") reduce 37) (("^") reduce 37) (("{") reduce 37) (("|") reduce 37)) 894 ((("%") reduce 64) (("(") reduce 64) (("*") reduce 64) (("+") reduce 64) (("-") reduce 64) ((".") reduce 64) (("/") reduce 64) ((":") reduce 64) (("<") reduce 64) ((">") reduce 64) (("?") reduce 64) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_BOOLEAN_AND) reduce 64) ((T_BOOLEAN_OR) reduce 64) ((T_COALESCE) reduce 64) ((T_INSTANCEOF) reduce 64) ((T_IS_EQUAL) reduce 64) ((T_IS_GREATER_OR_EQUAL) reduce 64) ((T_IS_IDENTICAL) reduce 64) ((T_IS_NOT_EQUAL) reduce 64) ((T_IS_NOT_IDENTICAL) reduce 64) ((T_IS_SMALLER_OR_EQUAL) reduce 64) ((T_LOGICAL_AND) reduce 64) ((T_LOGICAL_OR) reduce 64) ((T_LOGICAL_XOR) reduce 64) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 64) ((T_OBJECT_OPERATOR) reduce 64) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 64) ((T_POW) reduce 64) ((T_SL) reduce 64) ((T_SPACESHIP) reduce 64) ((T_SR) reduce 64) (("[") reduce 64) (("^") reduce 64) (("{") reduce 64) (("|") reduce 64)) 895 ((("%") reduce 46) (("(") reduce 46) (("*") reduce 46) (("+") reduce 46) (("-") reduce 46) ((".") reduce 46) (("/") reduce 46) ((":") reduce 46) (("<") reduce 46) ((">") reduce 46) (("?") reduce 46) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_BOOLEAN_AND) reduce 46) ((T_BOOLEAN_OR) reduce 46) ((T_COALESCE) reduce 46) ((T_INSTANCEOF) reduce 46) ((T_IS_EQUAL) reduce 46) ((T_IS_GREATER_OR_EQUAL) reduce 46) ((T_IS_IDENTICAL) reduce 46) ((T_IS_NOT_EQUAL) reduce 46) ((T_IS_NOT_IDENTICAL) reduce 46) ((T_IS_SMALLER_OR_EQUAL) reduce 46) ((T_LOGICAL_AND) reduce 46) ((T_LOGICAL_OR) reduce 46) ((T_LOGICAL_XOR) reduce 46) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 46) ((T_OBJECT_OPERATOR) reduce 46) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 46) ((T_POW) reduce 46) ((T_SL) reduce 46) ((T_SPACESHIP) reduce 46) ((T_SR) reduce 46) (("[") reduce 46) (("^") reduce 46) (("{") reduce 46) (("|") reduce 46)) 896 ((("%") reduce 8) (("(") reduce 8) (("*") reduce 8) (("+") reduce 8) (("-") reduce 8) ((".") reduce 8) (("/") reduce 8) ((":") reduce 8) (("<") reduce 8) ((">") reduce 8) (("?") reduce 8) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_BOOLEAN_AND) reduce 8) ((T_BOOLEAN_OR) reduce 8) ((T_COALESCE) reduce 8) ((T_INSTANCEOF) reduce 8) ((T_IS_EQUAL) reduce 8) ((T_IS_GREATER_OR_EQUAL) reduce 8) ((T_IS_IDENTICAL) reduce 8) ((T_IS_NOT_EQUAL) reduce 8) ((T_IS_NOT_IDENTICAL) reduce 8) ((T_IS_SMALLER_OR_EQUAL) reduce 8) ((T_LOGICAL_AND) reduce 8) ((T_LOGICAL_OR) reduce 8) ((T_LOGICAL_XOR) reduce 8) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 8) ((T_OBJECT_OPERATOR) reduce 8) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 8) ((T_POW) reduce 8) ((T_SL) reduce 8) ((T_SPACESHIP) reduce 8) ((T_SR) reduce 8) (("[") reduce 8) (("^") reduce 8) (("{") reduce 8) (("|") reduce 8)) 897 ((("%") reduce 6) (("(") reduce 6) (("*") reduce 6) (("+") reduce 6) (("-") reduce 6) ((".") reduce 6) (("/") reduce 6) ((":") reduce 6) (("<") reduce 6) ((">") reduce 6) (("?") reduce 6) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_BOOLEAN_AND) reduce 6) ((T_BOOLEAN_OR) reduce 6) ((T_COALESCE) reduce 6) ((T_INSTANCEOF) reduce 6) ((T_IS_EQUAL) reduce 6) ((T_IS_GREATER_OR_EQUAL) reduce 6) ((T_IS_IDENTICAL) reduce 6) ((T_IS_NOT_EQUAL) reduce 6) ((T_IS_NOT_IDENTICAL) reduce 6) ((T_IS_SMALLER_OR_EQUAL) reduce 6) ((T_LOGICAL_AND) reduce 6) ((T_LOGICAL_OR) reduce 6) ((T_LOGICAL_XOR) reduce 6) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 6) ((T_OBJECT_OPERATOR) reduce 6) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 6) ((T_POW) reduce 6) ((T_SL) reduce 6) ((T_SPACESHIP) reduce 6) ((T_SR) reduce 6) (("[") reduce 6) (("^") reduce 6) (("{") reduce 6) (("|") reduce 6)) 898 ((("%") reduce 7) (("(") reduce 7) (("*") reduce 7) (("+") reduce 7) (("-") reduce 7) ((".") reduce 7) (("/") reduce 7) ((":") reduce 7) (("<") reduce 7) ((">") reduce 7) (("?") reduce 7) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_BOOLEAN_AND) reduce 7) ((T_BOOLEAN_OR) reduce 7) ((T_COALESCE) reduce 7) ((T_INSTANCEOF) reduce 7) ((T_IS_EQUAL) reduce 7) ((T_IS_GREATER_OR_EQUAL) reduce 7) ((T_IS_IDENTICAL) reduce 7) ((T_IS_NOT_EQUAL) reduce 7) ((T_IS_NOT_IDENTICAL) reduce 7) ((T_IS_SMALLER_OR_EQUAL) reduce 7) ((T_LOGICAL_AND) reduce 7) ((T_LOGICAL_OR) reduce 7) ((T_LOGICAL_XOR) reduce 7) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 7) ((T_OBJECT_OPERATOR) reduce 7) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 7) ((T_POW) reduce 7) ((T_SL) reduce 7) ((T_SPACESHIP) reduce 7) ((T_SR) reduce 7) (("[") reduce 7) (("^") reduce 7) (("{") reduce 7) (("|") reduce 7)) 899 ((("%") reduce 69) (("(") reduce 69) (("*") reduce 69) (("+") reduce 69) (("-") reduce 69) ((".") reduce 69) (("/") reduce 69) ((":") reduce 69) (("<") reduce 69) ((">") reduce 69) (("?") reduce 69) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_BOOLEAN_AND) reduce 69) ((T_BOOLEAN_OR) reduce 69) ((T_COALESCE) reduce 69) ((T_INSTANCEOF) reduce 69) ((T_IS_EQUAL) reduce 69) ((T_IS_GREATER_OR_EQUAL) reduce 69) ((T_IS_IDENTICAL) reduce 69) ((T_IS_NOT_EQUAL) reduce 69) ((T_IS_NOT_IDENTICAL) reduce 69) ((T_IS_SMALLER_OR_EQUAL) reduce 69) ((T_LOGICAL_AND) reduce 69) ((T_LOGICAL_OR) reduce 69) ((T_LOGICAL_XOR) reduce 69) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 69) ((T_OBJECT_OPERATOR) reduce 69) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 69) ((T_POW) reduce 69) ((T_SL) reduce 69) ((T_SPACESHIP) reduce 69) ((T_SR) reduce 69) (("[") reduce 69) (("^") reduce 69) (("{") reduce 69) (("|") reduce 69)) 900 ((("%") reduce 63) (("(") reduce 63) (("*") reduce 63) (("+") reduce 63) (("-") reduce 63) ((".") reduce 63) (("/") reduce 63) ((":") reduce 63) (("<") reduce 63) ((">") reduce 63) (("?") reduce 63) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_BOOLEAN_AND) reduce 63) ((T_BOOLEAN_OR) reduce 63) ((T_COALESCE) reduce 63) ((T_INSTANCEOF) reduce 63) ((T_IS_EQUAL) reduce 63) ((T_IS_GREATER_OR_EQUAL) reduce 63) ((T_IS_IDENTICAL) reduce 63) ((T_IS_NOT_EQUAL) reduce 63) ((T_IS_NOT_IDENTICAL) reduce 63) ((T_IS_SMALLER_OR_EQUAL) reduce 63) ((T_LOGICAL_AND) reduce 63) ((T_LOGICAL_OR) reduce 63) ((T_LOGICAL_XOR) reduce 63) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 63) ((T_OBJECT_OPERATOR) reduce 63) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 63) ((T_POW) reduce 63) ((T_SL) reduce 63) ((T_SPACESHIP) reduce 63) ((T_SR) reduce 63) (("[") reduce 63) (("^") reduce 63) (("{") reduce 63) (("|") reduce 63)) 901 ((("%") reduce 56) (("(") reduce 56) (("*") reduce 56) (("+") reduce 56) (("-") reduce 56) ((".") reduce 56) (("/") reduce 56) ((":") reduce 56) (("<") reduce 56) ((">") reduce 56) (("?") reduce 56) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_BOOLEAN_AND) reduce 56) ((T_BOOLEAN_OR) reduce 56) ((T_COALESCE) reduce 56) ((T_INSTANCEOF) reduce 56) ((T_IS_EQUAL) reduce 56) ((T_IS_GREATER_OR_EQUAL) reduce 56) ((T_IS_IDENTICAL) reduce 56) ((T_IS_NOT_EQUAL) reduce 56) ((T_IS_NOT_IDENTICAL) reduce 56) ((T_IS_SMALLER_OR_EQUAL) reduce 56) ((T_LOGICAL_AND) reduce 56) ((T_LOGICAL_OR) reduce 56) ((T_LOGICAL_XOR) reduce 56) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 56) ((T_OBJECT_OPERATOR) reduce 56) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 56) ((T_POW) reduce 56) ((T_SL) reduce 56) ((T_SPACESHIP) reduce 56) ((T_SR) reduce 56) (("[") reduce 56) (("^") reduce 56) (("{") reduce 56) (("|") reduce 56)) 902 ((("%") reduce 10) (("(") reduce 10) (("*") reduce 10) (("+") reduce 10) (("-") reduce 10) ((".") reduce 10) (("/") reduce 10) ((":") reduce 10) (("<") reduce 10) ((">") reduce 10) (("?") reduce 10) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_BOOLEAN_AND) reduce 10) ((T_BOOLEAN_OR) reduce 10) ((T_COALESCE) reduce 10) ((T_INSTANCEOF) reduce 10) ((T_IS_EQUAL) reduce 10) ((T_IS_GREATER_OR_EQUAL) reduce 10) ((T_IS_IDENTICAL) reduce 10) ((T_IS_NOT_EQUAL) reduce 10) ((T_IS_NOT_IDENTICAL) reduce 10) ((T_IS_SMALLER_OR_EQUAL) reduce 10) ((T_LOGICAL_AND) reduce 10) ((T_LOGICAL_OR) reduce 10) ((T_LOGICAL_XOR) reduce 10) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 10) ((T_OBJECT_OPERATOR) reduce 10) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 10) ((T_POW) reduce 10) ((T_SL) reduce 10) ((T_SPACESHIP) reduce 10) ((T_SR) reduce 10) (("[") reduce 10) (("^") reduce 10) (("{") reduce 10) (("|") reduce 10)) 903 ((("%") reduce 67) (("(") reduce 67) (("*") reduce 67) (("+") reduce 67) (("-") reduce 67) ((".") reduce 67) (("/") reduce 67) ((":") reduce 67) (("<") reduce 67) ((">") reduce 67) (("?") reduce 67) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_BOOLEAN_AND) reduce 67) ((T_BOOLEAN_OR) reduce 67) ((T_COALESCE) reduce 67) ((T_INSTANCEOF) reduce 67) ((T_IS_EQUAL) reduce 67) ((T_IS_GREATER_OR_EQUAL) reduce 67) ((T_IS_IDENTICAL) reduce 67) ((T_IS_NOT_EQUAL) reduce 67) ((T_IS_NOT_IDENTICAL) reduce 67) ((T_IS_SMALLER_OR_EQUAL) reduce 67) ((T_LOGICAL_AND) reduce 67) ((T_LOGICAL_OR) reduce 67) ((T_LOGICAL_XOR) reduce 67) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 67) ((T_OBJECT_OPERATOR) reduce 67) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 67) ((T_POW) reduce 67) ((T_SL) reduce 67) ((T_SPACESHIP) reduce 67) ((T_SR) reduce 67) (("[") reduce 67) (("^") reduce 67) (("{") reduce 67) (("|") reduce 67)) 904 ((("%") reduce 44) (("(") reduce 44) (("*") reduce 44) (("+") reduce 44) (("-") reduce 44) ((".") reduce 44) (("/") reduce 44) ((":") reduce 44) (("<") reduce 44) ((">") reduce 44) (("?") reduce 44) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_BOOLEAN_AND) reduce 44) ((T_BOOLEAN_OR) reduce 44) ((T_COALESCE) reduce 44) ((T_INSTANCEOF) reduce 44) ((T_IS_EQUAL) reduce 44) ((T_IS_GREATER_OR_EQUAL) reduce 44) ((T_IS_IDENTICAL) reduce 44) ((T_IS_NOT_EQUAL) reduce 44) ((T_IS_NOT_IDENTICAL) reduce 44) ((T_IS_SMALLER_OR_EQUAL) reduce 44) ((T_LOGICAL_AND) reduce 44) ((T_LOGICAL_OR) reduce 44) ((T_LOGICAL_XOR) reduce 44) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 44) ((T_OBJECT_OPERATOR) reduce 44) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 44) ((T_POW) reduce 44) ((T_SL) reduce 44) ((T_SPACESHIP) reduce 44) ((T_SR) reduce 44) (("[") reduce 44) (("^") reduce 44) (("{") reduce 44) (("|") reduce 44)) 905 ((("%") reduce 75) (("(") reduce 75) (("*") reduce 75) (("+") reduce 75) (("-") reduce 75) ((".") reduce 75) (("/") reduce 75) ((":") reduce 75) (("<") reduce 75) ((">") reduce 75) (("?") reduce 75) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_BOOLEAN_AND) reduce 75) ((T_BOOLEAN_OR) reduce 75) ((T_COALESCE) reduce 75) ((T_INSTANCEOF) reduce 75) ((T_IS_EQUAL) reduce 75) ((T_IS_GREATER_OR_EQUAL) reduce 75) ((T_IS_IDENTICAL) reduce 75) ((T_IS_NOT_EQUAL) reduce 75) ((T_IS_NOT_IDENTICAL) reduce 75) ((T_IS_SMALLER_OR_EQUAL) reduce 75) ((T_LOGICAL_AND) reduce 75) ((T_LOGICAL_OR) reduce 75) ((T_LOGICAL_XOR) reduce 75) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 75) ((T_OBJECT_OPERATOR) reduce 75) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 75) ((T_POW) reduce 75) ((T_SL) reduce 75) ((T_SPACESHIP) reduce 75) ((T_SR) reduce 75) (("[") reduce 75) (("^") reduce 75) (("{") reduce 75) (("|") reduce 75)) 906 ((("%") reduce 76) (("(") reduce 76) (("*") reduce 76) (("+") reduce 76) (("-") reduce 76) ((".") reduce 76) (("/") reduce 76) ((":") reduce 76) (("<") reduce 76) ((">") reduce 76) (("?") reduce 76) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_BOOLEAN_AND) reduce 76) ((T_BOOLEAN_OR) reduce 76) ((T_COALESCE) reduce 76) ((T_INSTANCEOF) reduce 76) ((T_IS_EQUAL) reduce 76) ((T_IS_GREATER_OR_EQUAL) reduce 76) ((T_IS_IDENTICAL) reduce 76) ((T_IS_NOT_EQUAL) reduce 76) ((T_IS_NOT_IDENTICAL) reduce 76) ((T_IS_SMALLER_OR_EQUAL) reduce 76) ((T_LOGICAL_AND) reduce 76) ((T_LOGICAL_OR) reduce 76) ((T_LOGICAL_XOR) reduce 76) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 76) ((T_OBJECT_OPERATOR) reduce 76) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 76) ((T_POW) reduce 76) ((T_SL) reduce 76) ((T_SPACESHIP) reduce 76) ((T_SR) reduce 76) (("[") reduce 76) (("^") reduce 76) (("{") reduce 76) (("|") reduce 76)) 907 ((("%") reduce 77) (("(") reduce 77) (("*") reduce 77) (("+") reduce 77) (("-") reduce 77) ((".") reduce 77) (("/") reduce 77) ((":") reduce 77) (("<") reduce 77) ((">") reduce 77) (("?") reduce 77) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_BOOLEAN_AND) reduce 77) ((T_BOOLEAN_OR) reduce 77) ((T_COALESCE) reduce 77) ((T_INSTANCEOF) reduce 77) ((T_IS_EQUAL) reduce 77) ((T_IS_GREATER_OR_EQUAL) reduce 77) ((T_IS_IDENTICAL) reduce 77) ((T_IS_NOT_EQUAL) reduce 77) ((T_IS_NOT_IDENTICAL) reduce 77) ((T_IS_SMALLER_OR_EQUAL) reduce 77) ((T_LOGICAL_AND) reduce 77) ((T_LOGICAL_OR) reduce 77) ((T_LOGICAL_XOR) reduce 77) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 77) ((T_OBJECT_OPERATOR) reduce 77) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 77) ((T_POW) reduce 77) ((T_SL) reduce 77) ((T_SPACESHIP) reduce 77) ((T_SR) reduce 77) (("[") reduce 77) (("^") reduce 77) (("{") reduce 77) (("|") reduce 77)) 908 ((("%") reduce 78) (("(") reduce 78) (("*") reduce 78) (("+") reduce 78) (("-") reduce 78) ((".") reduce 78) (("/") reduce 78) ((":") reduce 78) (("<") reduce 78) ((">") reduce 78) (("?") reduce 78) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_BOOLEAN_AND) reduce 78) ((T_BOOLEAN_OR) reduce 78) ((T_COALESCE) reduce 78) ((T_INSTANCEOF) reduce 78) ((T_IS_EQUAL) reduce 78) ((T_IS_GREATER_OR_EQUAL) reduce 78) ((T_IS_IDENTICAL) reduce 78) ((T_IS_NOT_EQUAL) reduce 78) ((T_IS_NOT_IDENTICAL) reduce 78) ((T_IS_SMALLER_OR_EQUAL) reduce 78) ((T_LOGICAL_AND) reduce 78) ((T_LOGICAL_OR) reduce 78) ((T_LOGICAL_XOR) reduce 78) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 78) ((T_OBJECT_OPERATOR) reduce 78) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 78) ((T_POW) reduce 78) ((T_SL) reduce 78) ((T_SPACESHIP) reduce 78) ((T_SR) reduce 78) (("[") reduce 78) (("^") reduce 78) (("{") reduce 78) (("|") reduce 78)) 909 ((("%") reduce 4) (("(") reduce 4) (("*") reduce 4) (("+") reduce 4) (("-") reduce 4) ((".") reduce 4) (("/") reduce 4) ((":") reduce 4) (("<") reduce 4) ((">") reduce 4) (("?") reduce 4) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_BOOLEAN_AND) reduce 4) ((T_BOOLEAN_OR) reduce 4) ((T_COALESCE) reduce 4) ((T_INSTANCEOF) reduce 4) ((T_IS_EQUAL) reduce 4) ((T_IS_GREATER_OR_EQUAL) reduce 4) ((T_IS_IDENTICAL) reduce 4) ((T_IS_NOT_EQUAL) reduce 4) ((T_IS_NOT_IDENTICAL) reduce 4) ((T_IS_SMALLER_OR_EQUAL) reduce 4) ((T_LOGICAL_AND) reduce 4) ((T_LOGICAL_OR) reduce 4) ((T_LOGICAL_XOR) reduce 4) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 4) ((T_OBJECT_OPERATOR) reduce 4) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 4) ((T_POW) reduce 4) ((T_SL) reduce 4) ((T_SPACESHIP) reduce 4) ((T_SR) reduce 4) (("[") reduce 4) (("^") reduce 4) (("{") reduce 4) (("|") reduce 4)) 910 ((("%") reduce 5) (("(") reduce 5) (("*") reduce 5) (("+") reduce 5) (("-") reduce 5) ((".") reduce 5) (("/") reduce 5) ((":") reduce 5) (("<") reduce 5) ((">") reduce 5) (("?") reduce 5) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_BOOLEAN_AND) reduce 5) ((T_BOOLEAN_OR) reduce 5) ((T_COALESCE) reduce 5) ((T_INSTANCEOF) reduce 5) ((T_IS_EQUAL) reduce 5) ((T_IS_GREATER_OR_EQUAL) reduce 5) ((T_IS_IDENTICAL) reduce 5) ((T_IS_NOT_EQUAL) reduce 5) ((T_IS_NOT_IDENTICAL) reduce 5) ((T_IS_SMALLER_OR_EQUAL) reduce 5) ((T_LOGICAL_AND) reduce 5) ((T_LOGICAL_OR) reduce 5) ((T_LOGICAL_XOR) reduce 5) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 5) ((T_OBJECT_OPERATOR) reduce 5) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 5) ((T_POW) reduce 5) ((T_SL) reduce 5) ((T_SPACESHIP) reduce 5) ((T_SR) reduce 5) (("[") reduce 5) (("^") reduce 5) (("{") reduce 5) (("|") reduce 5)) 911 ((("%") reduce 43) (("(") reduce 43) (("*") reduce 43) (("+") reduce 43) (("-") reduce 43) ((".") reduce 43) (("/") reduce 43) ((":") reduce 43) (("<") reduce 43) ((">") reduce 43) (("?") reduce 43) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_BOOLEAN_AND) reduce 43) ((T_BOOLEAN_OR) reduce 43) ((T_COALESCE) reduce 43) ((T_INSTANCEOF) reduce 43) ((T_IS_EQUAL) reduce 43) ((T_IS_GREATER_OR_EQUAL) reduce 43) ((T_IS_IDENTICAL) reduce 43) ((T_IS_NOT_EQUAL) reduce 43) ((T_IS_NOT_IDENTICAL) reduce 43) ((T_IS_SMALLER_OR_EQUAL) reduce 43) ((T_LOGICAL_AND) reduce 43) ((T_LOGICAL_OR) reduce 43) ((T_LOGICAL_XOR) reduce 43) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 43) ((T_OBJECT_OPERATOR) reduce 43) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 43) ((T_POW) reduce 43) ((T_SL) reduce 43) ((T_SPACESHIP) reduce 43) ((T_SR) reduce 43) (("[") reduce 43) (("^") reduce 43) (("{") reduce 43) (("|") reduce 43)) 912 ((("%") reduce 72) (("(") reduce 72) (("*") reduce 72) (("+") reduce 72) (("-") reduce 72) ((".") reduce 72) (("/") reduce 72) ((":") reduce 72) (("<") reduce 72) ((">") reduce 72) (("?") reduce 72) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_BOOLEAN_AND) reduce 72) ((T_BOOLEAN_OR) reduce 72) ((T_COALESCE) reduce 72) ((T_INSTANCEOF) reduce 72) ((T_IS_EQUAL) reduce 72) ((T_IS_GREATER_OR_EQUAL) reduce 72) ((T_IS_IDENTICAL) reduce 72) ((T_IS_NOT_EQUAL) reduce 72) ((T_IS_NOT_IDENTICAL) reduce 72) ((T_IS_SMALLER_OR_EQUAL) reduce 72) ((T_LOGICAL_AND) reduce 72) ((T_LOGICAL_OR) reduce 72) ((T_LOGICAL_XOR) reduce 72) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 72) ((T_OBJECT_OPERATOR) reduce 72) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 72) ((T_POW) reduce 72) ((T_SL) reduce 72) ((T_SPACESHIP) reduce 72) ((T_SR) reduce 72) (("[") reduce 72) (("^") reduce 72) (("{") reduce 72) (("|") reduce 72)) 913 ((("%") reduce 81) (("(") reduce 81) (("*") reduce 81) (("+") reduce 81) (("-") reduce 81) ((".") reduce 81) (("/") reduce 81) ((":") reduce 81) (("<") reduce 81) ((">") reduce 81) (("?") reduce 81) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_BOOLEAN_AND) reduce 81) ((T_BOOLEAN_OR) reduce 81) ((T_COALESCE) reduce 81) ((T_INSTANCEOF) reduce 81) ((T_IS_EQUAL) reduce 81) ((T_IS_GREATER_OR_EQUAL) reduce 81) ((T_IS_IDENTICAL) reduce 81) ((T_IS_NOT_EQUAL) reduce 81) ((T_IS_NOT_IDENTICAL) reduce 81) ((T_IS_SMALLER_OR_EQUAL) reduce 81) ((T_LOGICAL_AND) reduce 81) ((T_LOGICAL_OR) reduce 81) ((T_LOGICAL_XOR) reduce 81) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 81) ((T_OBJECT_OPERATOR) reduce 81) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 81) ((T_POW) reduce 81) ((T_SL) reduce 81) ((T_SPACESHIP) reduce 81) ((T_SR) reduce 81) (("[") reduce 81) (("^") reduce 81) (("{") reduce 81) (("|") reduce 81)) 914 ((("%") reduce 47) (("(") reduce 47) (("*") reduce 47) (("+") reduce 47) (("-") reduce 47) ((".") reduce 47) (("/") reduce 47) ((":") reduce 47) (("<") reduce 47) ((">") reduce 47) (("?") reduce 47) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_BOOLEAN_AND) reduce 47) ((T_BOOLEAN_OR) reduce 47) ((T_COALESCE) reduce 47) ((T_INSTANCEOF) reduce 47) ((T_IS_EQUAL) reduce 47) ((T_IS_GREATER_OR_EQUAL) reduce 47) ((T_IS_IDENTICAL) reduce 47) ((T_IS_NOT_EQUAL) reduce 47) ((T_IS_NOT_IDENTICAL) reduce 47) ((T_IS_SMALLER_OR_EQUAL) reduce 47) ((T_LOGICAL_AND) reduce 47) ((T_LOGICAL_OR) reduce 47) ((T_LOGICAL_XOR) reduce 47) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 47) ((T_OBJECT_OPERATOR) reduce 47) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 47) ((T_POW) reduce 47) ((T_SL) reduce 47) ((T_SPACESHIP) reduce 47) ((T_SR) reduce 47) (("[") reduce 47) (("^") reduce 47) (("{") reduce 47) (("|") reduce 47)) 915 ((("%") reduce 31) (("(") reduce 31) (("*") reduce 31) (("+") reduce 31) (("-") reduce 31) ((".") reduce 31) (("/") reduce 31) ((":") reduce 31) (("<") reduce 31) ((">") reduce 31) (("?") reduce 31) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_BOOLEAN_AND) reduce 31) ((T_BOOLEAN_OR) reduce 31) ((T_COALESCE) reduce 31) ((T_INSTANCEOF) reduce 31) ((T_IS_EQUAL) reduce 31) ((T_IS_GREATER_OR_EQUAL) reduce 31) ((T_IS_IDENTICAL) reduce 31) ((T_IS_NOT_EQUAL) reduce 31) ((T_IS_NOT_IDENTICAL) reduce 31) ((T_IS_SMALLER_OR_EQUAL) reduce 31) ((T_LOGICAL_AND) reduce 31) ((T_LOGICAL_OR) reduce 31) ((T_LOGICAL_XOR) reduce 31) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 31) ((T_OBJECT_OPERATOR) reduce 31) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 31) ((T_POW) reduce 31) ((T_SL) reduce 31) ((T_SPACESHIP) reduce 31) ((T_SR) reduce 31) (("[") reduce 31) (("^") reduce 31) (("{") reduce 31) (("|") reduce 31)) 916 ((("%") reduce 57) (("(") reduce 57) (("*") reduce 57) (("+") reduce 57) (("-") reduce 57) ((".") reduce 57) (("/") reduce 57) ((":") reduce 57) (("<") reduce 57) ((">") reduce 57) (("?") reduce 57) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_BOOLEAN_AND) reduce 57) ((T_BOOLEAN_OR) reduce 57) ((T_COALESCE) reduce 57) ((T_INSTANCEOF) reduce 57) ((T_IS_EQUAL) reduce 57) ((T_IS_GREATER_OR_EQUAL) reduce 57) ((T_IS_IDENTICAL) reduce 57) ((T_IS_NOT_EQUAL) reduce 57) ((T_IS_NOT_IDENTICAL) reduce 57) ((T_IS_SMALLER_OR_EQUAL) reduce 57) ((T_LOGICAL_AND) reduce 57) ((T_LOGICAL_OR) reduce 57) ((T_LOGICAL_XOR) reduce 57) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 57) ((T_OBJECT_OPERATOR) reduce 57) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 57) ((T_POW) reduce 57) ((T_SL) reduce 57) ((T_SPACESHIP) reduce 57) ((T_SR) reduce 57) (("[") reduce 57) (("^") reduce 57) (("{") reduce 57) (("|") reduce 57)) 917 ((("%") reduce 61) (("(") reduce 61) (("*") reduce 61) (("+") reduce 61) (("-") reduce 61) ((".") reduce 61) (("/") reduce 61) ((":") reduce 61) (("<") reduce 61) ((">") reduce 61) (("?") reduce 61) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_BOOLEAN_AND) reduce 61) ((T_BOOLEAN_OR) reduce 61) ((T_COALESCE) reduce 61) ((T_INSTANCEOF) reduce 61) ((T_IS_EQUAL) reduce 61) ((T_IS_GREATER_OR_EQUAL) reduce 61) ((T_IS_IDENTICAL) reduce 61) ((T_IS_NOT_EQUAL) reduce 61) ((T_IS_NOT_IDENTICAL) reduce 61) ((T_IS_SMALLER_OR_EQUAL) reduce 61) ((T_LOGICAL_AND) reduce 61) ((T_LOGICAL_OR) reduce 61) ((T_LOGICAL_XOR) reduce 61) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 61) ((T_OBJECT_OPERATOR) reduce 61) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 61) ((T_POW) reduce 61) ((T_SL) reduce 61) ((T_SPACESHIP) reduce 61) ((T_SR) reduce 61) (("[") reduce 61) (("^") reduce 61) (("{") reduce 61) (("|") reduce 61)) 918 ((("%") reduce 28) (("(") reduce 28) (("*") reduce 28) (("+") reduce 28) (("-") reduce 28) ((".") reduce 28) (("/") reduce 28) ((":") reduce 28) (("<") reduce 28) ((">") reduce 28) (("?") reduce 28) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_BOOLEAN_AND) reduce 28) ((T_BOOLEAN_OR) reduce 28) ((T_COALESCE) reduce 28) ((T_INSTANCEOF) reduce 28) ((T_IS_EQUAL) reduce 28) ((T_IS_GREATER_OR_EQUAL) reduce 28) ((T_IS_IDENTICAL) reduce 28) ((T_IS_NOT_EQUAL) reduce 28) ((T_IS_NOT_IDENTICAL) reduce 28) ((T_IS_SMALLER_OR_EQUAL) reduce 28) ((T_LOGICAL_AND) reduce 28) ((T_LOGICAL_OR) reduce 28) ((T_LOGICAL_XOR) reduce 28) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 28) ((T_OBJECT_OPERATOR) reduce 28) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 28) ((T_POW) reduce 28) ((T_SL) reduce 28) ((T_SPACESHIP) reduce 28) ((T_SR) reduce 28) (("[") reduce 28) (("^") reduce 28) (("{") reduce 28) (("|") reduce 28)) 919 ((("%") reduce 36) (("(") reduce 36) (("*") reduce 36) (("+") reduce 36) (("-") reduce 36) ((".") reduce 36) (("/") reduce 36) ((":") reduce 36) (("<") reduce 36) ((">") reduce 36) (("?") reduce 36) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_BOOLEAN_AND) reduce 36) ((T_BOOLEAN_OR) reduce 36) ((T_COALESCE) reduce 36) ((T_INSTANCEOF) reduce 36) ((T_IS_EQUAL) reduce 36) ((T_IS_GREATER_OR_EQUAL) reduce 36) ((T_IS_IDENTICAL) reduce 36) ((T_IS_NOT_EQUAL) reduce 36) ((T_IS_NOT_IDENTICAL) reduce 36) ((T_IS_SMALLER_OR_EQUAL) reduce 36) ((T_LOGICAL_AND) reduce 36) ((T_LOGICAL_OR) reduce 36) ((T_LOGICAL_XOR) reduce 36) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 36) ((T_OBJECT_OPERATOR) reduce 36) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 36) ((T_POW) reduce 36) ((T_SL) reduce 36) ((T_SPACESHIP) reduce 36) ((T_SR) reduce 36) (("[") reduce 36) (("^") reduce 36) (("{") reduce 36) (("|") reduce 36)) 920 ((("%") reduce 32) (("(") reduce 32) (("*") reduce 32) (("+") reduce 32) (("-") reduce 32) ((".") reduce 32) (("/") reduce 32) ((":") reduce 32) (("<") reduce 32) ((">") reduce 32) (("?") reduce 32) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_BOOLEAN_AND) reduce 32) ((T_BOOLEAN_OR) reduce 32) ((T_COALESCE) reduce 32) ((T_INSTANCEOF) reduce 32) ((T_IS_EQUAL) reduce 32) ((T_IS_GREATER_OR_EQUAL) reduce 32) ((T_IS_IDENTICAL) reduce 32) ((T_IS_NOT_EQUAL) reduce 32) ((T_IS_NOT_IDENTICAL) reduce 32) ((T_IS_SMALLER_OR_EQUAL) reduce 32) ((T_LOGICAL_AND) reduce 32) ((T_LOGICAL_OR) reduce 32) ((T_LOGICAL_XOR) reduce 32) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 32) ((T_OBJECT_OPERATOR) reduce 32) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 32) ((T_POW) reduce 32) ((T_SL) reduce 32) ((T_SPACESHIP) reduce 32) ((T_SR) reduce 32) (("[") reduce 32) (("^") reduce 32) (("{") reduce 32) (("|") reduce 32)) 921 ((("%") reduce 35) (("(") reduce 35) (("*") reduce 35) (("+") reduce 35) (("-") reduce 35) ((".") reduce 35) (("/") reduce 35) ((":") reduce 35) (("<") reduce 35) ((">") reduce 35) (("?") reduce 35) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_BOOLEAN_AND) reduce 35) ((T_BOOLEAN_OR) reduce 35) ((T_COALESCE) reduce 35) ((T_INSTANCEOF) reduce 35) ((T_IS_EQUAL) reduce 35) ((T_IS_GREATER_OR_EQUAL) reduce 35) ((T_IS_IDENTICAL) reduce 35) ((T_IS_NOT_EQUAL) reduce 35) ((T_IS_NOT_IDENTICAL) reduce 35) ((T_IS_SMALLER_OR_EQUAL) reduce 35) ((T_LOGICAL_AND) reduce 35) ((T_LOGICAL_OR) reduce 35) ((T_LOGICAL_XOR) reduce 35) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 35) ((T_OBJECT_OPERATOR) reduce 35) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 35) ((T_POW) reduce 35) ((T_SL) reduce 35) ((T_SPACESHIP) reduce 35) ((T_SR) reduce 35) (("[") reduce 35) (("^") reduce 35) (("{") reduce 35) (("|") reduce 35)) 922 ((("%") reduce 19) (("(") reduce 19) (("*") reduce 19) (("+") reduce 19) (("-") reduce 19) ((".") reduce 19) (("/") reduce 19) ((":") reduce 19) (("<") reduce 19) ((">") reduce 19) (("?") reduce 19) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_BOOLEAN_AND) reduce 19) ((T_BOOLEAN_OR) reduce 19) ((T_COALESCE) reduce 19) ((T_INSTANCEOF) reduce 19) ((T_IS_EQUAL) reduce 19) ((T_IS_GREATER_OR_EQUAL) reduce 19) ((T_IS_IDENTICAL) reduce 19) ((T_IS_NOT_EQUAL) reduce 19) ((T_IS_NOT_IDENTICAL) reduce 19) ((T_IS_SMALLER_OR_EQUAL) reduce 19) ((T_LOGICAL_AND) reduce 19) ((T_LOGICAL_OR) reduce 19) ((T_LOGICAL_XOR) reduce 19) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 19) ((T_OBJECT_OPERATOR) reduce 19) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 19) ((T_POW) reduce 19) ((T_SL) reduce 19) ((T_SPACESHIP) reduce 19) ((T_SR) reduce 19) (("[") reduce 19) (("^") reduce 19) (("{") reduce 19) (("|") reduce 19)) 923 ((("%") reduce 45) (("(") reduce 45) (("*") reduce 45) (("+") reduce 45) (("-") reduce 45) ((".") reduce 45) (("/") reduce 45) ((":") reduce 45) (("<") reduce 45) ((">") reduce 45) (("?") reduce 45) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_BOOLEAN_AND) reduce 45) ((T_BOOLEAN_OR) reduce 45) ((T_COALESCE) reduce 45) ((T_INSTANCEOF) reduce 45) ((T_IS_EQUAL) reduce 45) ((T_IS_GREATER_OR_EQUAL) reduce 45) ((T_IS_IDENTICAL) reduce 45) ((T_IS_NOT_EQUAL) reduce 45) ((T_IS_NOT_IDENTICAL) reduce 45) ((T_IS_SMALLER_OR_EQUAL) reduce 45) ((T_LOGICAL_AND) reduce 45) ((T_LOGICAL_OR) reduce 45) ((T_LOGICAL_XOR) reduce 45) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 45) ((T_OBJECT_OPERATOR) reduce 45) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 45) ((T_POW) reduce 45) ((T_SL) reduce 45) ((T_SPACESHIP) reduce 45) ((T_SR) reduce 45) (("[") reduce 45) (("^") reduce 45) (("{") reduce 45) (("|") reduce 45)) 924 ((("%") reduce 504) (("(") reduce 541) (("*") reduce 504) (("+") reduce 504) (("-") reduce 504) ((".") reduce 504) (("/") reduce 504) ((":") reduce 504) (("<") reduce 504) ((">") reduce 504) (("?") reduce 504) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_BOOLEAN_AND) reduce 504) ((T_BOOLEAN_OR) reduce 504) ((T_COALESCE) reduce 504) ((T_INSTANCEOF) reduce 504) ((T_IS_EQUAL) reduce 504) ((T_IS_GREATER_OR_EQUAL) reduce 504) ((T_IS_IDENTICAL) reduce 504) ((T_IS_NOT_EQUAL) reduce 504) ((T_IS_NOT_IDENTICAL) reduce 504) ((T_IS_SMALLER_OR_EQUAL) reduce 504) ((T_LOGICAL_AND) reduce 504) ((T_LOGICAL_OR) reduce 504) ((T_LOGICAL_XOR) reduce 504) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 504) ((T_OBJECT_OPERATOR) reduce 504) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 504) ((T_POW) reduce 504) ((T_SL) reduce 504) ((T_SPACESHIP) reduce 504) ((T_SR) reduce 504) (("[") reduce 504) (("^") reduce 504) (("{") reduce 504) (("|") reduce 504)) 926 ((("%") reduce 71) (("(") reduce 71) (("*") reduce 71) (("+") reduce 71) (("-") reduce 71) ((".") reduce 71) (("/") reduce 71) ((":") reduce 71) (("<") reduce 71) ((">") reduce 71) (("?") reduce 71) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_BOOLEAN_AND) reduce 71) ((T_BOOLEAN_OR) reduce 71) ((T_COALESCE) reduce 71) ((T_INSTANCEOF) reduce 71) ((T_IS_EQUAL) reduce 71) ((T_IS_GREATER_OR_EQUAL) reduce 71) ((T_IS_IDENTICAL) reduce 71) ((T_IS_NOT_EQUAL) reduce 71) ((T_IS_NOT_IDENTICAL) reduce 71) ((T_IS_SMALLER_OR_EQUAL) reduce 71) ((T_LOGICAL_AND) reduce 71) ((T_LOGICAL_OR) reduce 71) ((T_LOGICAL_XOR) reduce 71) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 71) ((T_OBJECT_OPERATOR) reduce 71) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 71) ((T_POW) reduce 71) ((T_SL) reduce 71) ((T_SPACESHIP) reduce 71) ((T_SR) reduce 71) (("[") reduce 71) (("^") reduce 71) (("{") reduce 71) (("|") reduce 71)) 927 ((("%") reduce 82) (("(") reduce 82) (("*") reduce 82) (("+") reduce 82) (("-") reduce 82) ((".") reduce 82) (("/") reduce 82) ((":") reduce 82) (("<") reduce 82) ((">") reduce 82) (("?") reduce 82) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_BOOLEAN_AND) reduce 82) ((T_BOOLEAN_OR) reduce 82) ((T_COALESCE) reduce 82) ((T_INSTANCEOF) reduce 82) ((T_IS_EQUAL) reduce 82) ((T_IS_GREATER_OR_EQUAL) reduce 82) ((T_IS_IDENTICAL) reduce 82) ((T_IS_NOT_EQUAL) reduce 82) ((T_IS_NOT_IDENTICAL) reduce 82) ((T_IS_SMALLER_OR_EQUAL) reduce 82) ((T_LOGICAL_AND) reduce 82) ((T_LOGICAL_OR) reduce 82) ((T_LOGICAL_XOR) reduce 82) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 82) ((T_OBJECT_OPERATOR) reduce 82) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 82) ((T_POW) reduce 82) ((T_SL) reduce 82) ((T_SPACESHIP) reduce 82) ((T_SR) reduce 82) (("[") reduce 82) (("^") reduce 82) (("{") reduce 82) (("|") reduce 82)) 928 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) ((":") reduce 533) (("<") reduce 533) (("=") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AND_EQUAL) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_COALESCE_EQUAL) reduce 533) ((T_CONCAT_EQUAL) reduce 533) ((T_DEC) reduce 533) ((T_DIV_EQUAL) reduce 533) ((T_INC) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_MINUS_EQUAL) reduce 533) ((T_MOD_EQUAL) reduce 533) ((T_MUL_EQUAL) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_OR_EQUAL) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_PLUS_EQUAL) reduce 533) ((T_POW) reduce 533) ((T_POW_EQUAL) reduce 533) ((T_SL) reduce 533) ((T_SL_EQUAL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) ((T_SR_EQUAL) reduce 533) ((T_XOR_EQUAL) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 931 ((("%") reduce 506) (("(") reduce 542) (("*") reduce 506) (("+") reduce 506) (("-") reduce 506) ((".") reduce 506) (("/") reduce 506) ((":") reduce 506) (("<") reduce 506) ((">") reduce 506) (("?") reduce 506) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_BOOLEAN_AND) reduce 506) ((T_BOOLEAN_OR) reduce 506) ((T_COALESCE) reduce 506) ((T_INSTANCEOF) reduce 506) ((T_IS_EQUAL) reduce 506) ((T_IS_GREATER_OR_EQUAL) reduce 506) ((T_IS_IDENTICAL) reduce 506) ((T_IS_NOT_EQUAL) reduce 506) ((T_IS_NOT_IDENTICAL) reduce 506) ((T_IS_SMALLER_OR_EQUAL) reduce 506) ((T_LOGICAL_AND) reduce 506) ((T_LOGICAL_OR) reduce 506) ((T_LOGICAL_XOR) reduce 506) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 506) ((T_OBJECT_OPERATOR) reduce 506) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 506) ((T_POW) reduce 506) ((T_SL) reduce 506) ((T_SPACESHIP) reduce 506) ((T_SR) reduce 506) (("[") reduce 506) (("^") reduce 506) (("{") reduce 506) (("|") reduce 506)) 932 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) ((")") shift) (("+") shift) (("-") shift) (("@") shift) ((T_ABSTRACT) shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_AS) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_BREAK) shift) ((T_CALLABLE) shift) ((T_CASE) shift) ((T_CATCH) shift) ((T_CLASS) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONST) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_CONTINUE) shift) ((T_DEC) shift) ((T_DECLARE) shift) ((T_DEFAULT) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DO) shift) ((T_DOUBLE_CAST) shift) ((T_ECHO) shift) ((T_ELLIPSIS) shift) ((T_ELSE) shift) ((T_ELSEIF) shift) ((T_EMPTY) shift) ((T_ENDDECLARE) shift) ((T_ENDFOR) shift) ((T_ENDFOREACH) shift) ((T_ENDIF) shift) ((T_ENDSWITCH) shift) ((T_ENDWHILE) shift) ((T_ENUM) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_EXTENDS) shift) ((T_FILE) shift) ((T_FINAL) shift) ((T_FINALLY) shift) ((T_FN) shift) ((T_FOR) shift) ((T_FOREACH) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_GLOBAL) shift) ((T_GOTO) shift) ((T_IF) shift) ((T_IMPLEMENTS) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INSTANCEOF) shift) ((T_INSTEADOF) shift) ((T_INTERFACE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAMESPACE) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_PRIVATE) shift) ((T_PROTECTED) shift) ((T_PUBLIC) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_RETURN) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_SWITCH) shift) ((T_THROW) shift) ((T_TRAIT) shift) ((T_TRAIT_C) shift) ((T_TRY) shift) ((T_UNSET) shift) ((T_UNSET_CAST) shift) ((T_USE) shift) ((T_VAR) shift) ((T_VARIABLE) shift) ((T_WHILE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("~") shift)) 933 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) ((":") reduce 468) (("<") reduce 468) (("=") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AND_EQUAL) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_COALESCE_EQUAL) reduce 468) ((T_CONCAT_EQUAL) reduce 468) ((T_DEC) reduce 468) ((T_DIV_EQUAL) reduce 468) ((T_INC) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_MINUS_EQUAL) reduce 468) ((T_MOD_EQUAL) reduce 468) ((T_MUL_EQUAL) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_OR_EQUAL) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_PLUS_EQUAL) reduce 468) ((T_POW) reduce 468) ((T_POW_EQUAL) reduce 468) ((T_SL) reduce 468) ((T_SL_EQUAL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) ((T_SR_EQUAL) reduce 468) ((T_XOR_EQUAL) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 938 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) ((":") reduce 288) (("<") reduce 288) (("=") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AND_EQUAL) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_COALESCE_EQUAL) reduce 288) ((T_CONCAT_EQUAL) reduce 288) ((T_DEC) reduce 288) ((T_DIV_EQUAL) reduce 288) ((T_INC) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_MINUS_EQUAL) reduce 288) ((T_MOD_EQUAL) reduce 288) ((T_MUL_EQUAL) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_OR_EQUAL) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_PLUS_EQUAL) reduce 288) ((T_POW) reduce 288) ((T_POW_EQUAL) reduce 288) ((T_SL) reduce 288) ((T_SL_EQUAL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) ((T_SR_EQUAL) reduce 288) ((T_XOR_EQUAL) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 942 (((":") reduce 73)) 943 ((("(") shift) ((":") reduce 52)) 945 (((":") reduce 27)) 947 (((":") reduce 51)) 948 (((":") reduce 53)) 949 (((":") reduce 49)) 950 (((":") reduce 29)) 951 (((":") reduce 59)) 952 ((("%") reduce 502) ((")") reduce 502) (("*") reduce 502) (("+") reduce 502) ((",") reduce 502) (("-") reduce 502) ((".") reduce 502) (("/") reduce 502) ((":") reduce 60) (("<") reduce 502) ((">") reduce 502) (("?") reduce 502) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_BOOLEAN_AND) reduce 502) ((T_BOOLEAN_OR) reduce 502) ((T_COALESCE) reduce 502) ((T_INSTANCEOF) reduce 502) ((T_IS_EQUAL) reduce 502) ((T_IS_GREATER_OR_EQUAL) reduce 502) ((T_IS_IDENTICAL) reduce 502) ((T_IS_NOT_EQUAL) reduce 502) ((T_IS_NOT_IDENTICAL) reduce 502) ((T_IS_SMALLER_OR_EQUAL) reduce 502) ((T_LOGICAL_AND) reduce 502) ((T_LOGICAL_OR) reduce 502) ((T_LOGICAL_XOR) reduce 502) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 502) ((T_OBJECT_OPERATOR) reduce 502) ((T_POW) reduce 502) ((T_SL) reduce 502) ((T_SPACESHIP) reduce 502) ((T_SR) reduce 502) (("[") reduce 502) (("^") reduce 502) (("{") reduce 502) (("|") reduce 502)) 953 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) (("+") shift) (("-") shift) ((":") reduce 11) (("@") shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("~") shift)) 954 (((":") reduce 42)) 955 ((("%") reduce 484) (("(") reduce 484) ((")") reduce 484) (("*") reduce 484) (("+") reduce 484) ((",") reduce 484) (("-") reduce 484) ((".") reduce 484) (("/") reduce 484) (("<") reduce 484) ((">") reduce 484) (("?") reduce 484) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_BOOLEAN_AND) reduce 484) ((T_BOOLEAN_OR) reduce 484) ((T_COALESCE) reduce 484) ((T_INSTANCEOF) reduce 484) ((T_IS_EQUAL) reduce 484) ((T_IS_GREATER_OR_EQUAL) reduce 484) ((T_IS_IDENTICAL) reduce 484) ((T_IS_NOT_EQUAL) reduce 484) ((T_IS_NOT_IDENTICAL) reduce 484) ((T_IS_SMALLER_OR_EQUAL) reduce 484) ((T_LOGICAL_AND) reduce 484) ((T_LOGICAL_OR) reduce 484) ((T_LOGICAL_XOR) reduce 484) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 484) ((T_OBJECT_OPERATOR) reduce 484) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 484) ((T_POW) reduce 484) ((T_SL) reduce 484) ((T_SPACESHIP) reduce 484) ((T_SR) reduce 484) (("[") reduce 484) (("^") reduce 484) (("{") reduce 484) (("|") reduce 484)) 956 (((":") reduce 39)) 958 (((":") reduce 25)) 959 (((":") reduce 50)) 960 ((("%") reduce 497) ((")") reduce 497) (("*") reduce 497) (("+") reduce 497) ((",") reduce 497) (("-") reduce 497) ((".") reduce 497) (("/") reduce 497) ((":") reduce 66) (("<") reduce 497) ((">") reduce 497) (("?") reduce 497) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_BOOLEAN_AND) reduce 497) ((T_BOOLEAN_OR) reduce 497) ((T_COALESCE) reduce 497) ((T_INSTANCEOF) reduce 497) ((T_IS_EQUAL) reduce 497) ((T_IS_GREATER_OR_EQUAL) reduce 497) ((T_IS_IDENTICAL) reduce 497) ((T_IS_NOT_EQUAL) reduce 497) ((T_IS_NOT_IDENTICAL) reduce 497) ((T_IS_SMALLER_OR_EQUAL) reduce 497) ((T_LOGICAL_AND) reduce 497) ((T_LOGICAL_OR) reduce 497) ((T_LOGICAL_XOR) reduce 497) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 497) ((T_OBJECT_OPERATOR) reduce 497) ((T_POW) reduce 497) ((T_SL) reduce 497) ((T_SPACESHIP) reduce 497) ((T_SR) reduce 497) (("[") reduce 497) (("^") reduce 497) (("{") reduce 497) (("|") reduce 497)) 961 ((("%") reduce 487) ((")") reduce 487) (("*") reduce 487) (("+") reduce 487) ((",") reduce 487) (("-") reduce 487) ((".") reduce 487) (("/") reduce 487) (("<") reduce 487) ((">") reduce 487) (("?") reduce 487) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_BOOLEAN_AND) reduce 487) ((T_BOOLEAN_OR) reduce 487) ((T_COALESCE) reduce 487) ((T_INSTANCEOF) reduce 487) ((T_IS_EQUAL) reduce 487) ((T_IS_GREATER_OR_EQUAL) reduce 487) ((T_IS_IDENTICAL) reduce 487) ((T_IS_NOT_EQUAL) reduce 487) ((T_IS_NOT_IDENTICAL) reduce 487) ((T_IS_SMALLER_OR_EQUAL) reduce 487) ((T_LOGICAL_AND) reduce 487) ((T_LOGICAL_OR) reduce 487) ((T_LOGICAL_XOR) reduce 487) ((T_POW) reduce 487) ((T_SL) reduce 487) ((T_SPACESHIP) reduce 487) ((T_SR) reduce 487) (("^") reduce 487) (("|") reduce 487)) 962 (((":") reduce 18)) 964 (((":") reduce 17)) 965 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) ((")") shift) (("+") shift) (("-") shift) (("@") shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("~") shift)) 966 (((":") reduce 15)) 967 (((":") reduce 14)) 968 ((("(") shift) ((":") reduce 38)) 969 (((":") reduce 26)) 970 (((":") reduce 22)) 971 (((":") reduce 24)) 972 (((":") reduce 16)) 973 (((":") reduce 48)) 974 (((":") reduce 20)) 975 (((":") reduce 70)) 976 ((("(") shift) ((":") reduce 3)) 977 ((("%") reduce 475) (("(") shift) ((")") reduce 475) (("*") reduce 475) (("+") reduce 475) ((",") reduce 475) (("-") reduce 475) ((".") reduce 475) (("/") reduce 475) ((":") reduce 12) (("<") reduce 475) ((">") reduce 475) (("?") reduce 475) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_BOOLEAN_AND) reduce 475) ((T_BOOLEAN_OR) reduce 475) ((T_COALESCE) reduce 475) ((T_INSTANCEOF) reduce 475) ((T_IS_EQUAL) reduce 475) ((T_IS_GREATER_OR_EQUAL) reduce 475) ((T_IS_IDENTICAL) reduce 475) ((T_IS_NOT_EQUAL) reduce 475) ((T_IS_NOT_IDENTICAL) reduce 475) ((T_IS_SMALLER_OR_EQUAL) reduce 475) ((T_LOGICAL_AND) reduce 475) ((T_LOGICAL_OR) reduce 475) ((T_LOGICAL_XOR) reduce 475) ((T_POW) reduce 475) ((T_SL) reduce 475) ((T_SPACESHIP) reduce 475) ((T_SR) reduce 475) (("^") reduce 475) (("|") reduce 475)) 978 (((":") reduce 54)) 979 ((("%") reduce 496) ((")") reduce 496) (("*") reduce 496) (("+") reduce 496) ((",") reduce 496) (("-") reduce 496) ((".") reduce 496) (("/") reduce 496) ((":") reduce 65) (("<") reduce 496) ((">") reduce 496) (("?") reduce 496) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_BOOLEAN_AND) reduce 496) ((T_BOOLEAN_OR) reduce 496) ((T_COALESCE) reduce 496) ((T_INSTANCEOF) reduce 496) ((T_IS_EQUAL) reduce 496) ((T_IS_GREATER_OR_EQUAL) reduce 496) ((T_IS_IDENTICAL) reduce 496) ((T_IS_NOT_EQUAL) reduce 496) ((T_IS_NOT_IDENTICAL) reduce 496) ((T_IS_SMALLER_OR_EQUAL) reduce 496) ((T_LOGICAL_AND) reduce 496) ((T_LOGICAL_OR) reduce 496) ((T_LOGICAL_XOR) reduce 496) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 496) ((T_OBJECT_OPERATOR) reduce 496) ((T_POW) reduce 496) ((T_SL) reduce 496) ((T_SPACESHIP) reduce 496) ((T_SR) reduce 496) (("[") reduce 496) (("^") reduce 496) (("{") reduce 496) (("|") reduce 496)) 980 (((":") reduce 74)) 981 (((":") reduce 30)) 982 ((("(") reduce 452) ((":") reduce 68) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 452) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 452)) 983 (((":") reduce 21)) 984 (((":") reduce 23)) 985 ((("(") reduce 453) ((":") reduce 41) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 453) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 453)) 986 ((("%") reduce 500) ((")") reduce 500) (("*") reduce 500) (("+") reduce 500) ((",") reduce 500) (("-") reduce 500) ((".") reduce 500) (("/") reduce 500) ((":") reduce 62) (("<") reduce 500) ((">") reduce 500) (("?") reduce 500) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_BOOLEAN_AND) reduce 500) ((T_BOOLEAN_OR) reduce 500) ((T_COALESCE) reduce 500) ((T_INSTANCEOF) reduce 500) ((T_IS_EQUAL) reduce 500) ((T_IS_GREATER_OR_EQUAL) reduce 500) ((T_IS_IDENTICAL) reduce 500) ((T_IS_NOT_EQUAL) reduce 500) ((T_IS_NOT_IDENTICAL) reduce 500) ((T_IS_SMALLER_OR_EQUAL) reduce 500) ((T_LOGICAL_AND) reduce 500) ((T_LOGICAL_OR) reduce 500) ((T_LOGICAL_XOR) reduce 500) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 500) ((T_OBJECT_OPERATOR) reduce 500) ((T_POW) reduce 500) ((T_SL) reduce 500) ((T_SPACESHIP) reduce 500) ((T_SR) reduce 500) (("[") reduce 500) (("^") reduce 500) (("{") reduce 500) (("|") reduce 500)) 987 (((":") reduce 34)) 988 (((":") reduce 40)) 989 (((":") reduce 13)) 990 (((":") reduce 55)) 992 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) (("+") shift) (("-") shift) ((":") reduce 1) (("@") shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("~") shift)) 993 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) (("+") shift) (("-") shift) ((":") reduce 2) (("@") shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("~") shift)) 994 (((":") reduce 9)) 995 (((":") reduce 33)) 996 (((":") reduce 58)) 998 ((("(") shift) ((":") reduce 37)) 999 ((("%") reduce 495) ((")") reduce 495) (("*") reduce 495) (("+") reduce 495) ((",") reduce 495) (("-") reduce 495) ((".") reduce 495) (("/") reduce 495) ((":") reduce 64) (("<") reduce 495) ((">") reduce 495) (("?") reduce 495) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_BOOLEAN_AND) reduce 495) ((T_BOOLEAN_OR) reduce 495) ((T_COALESCE) reduce 495) ((T_INSTANCEOF) reduce 495) ((T_IS_EQUAL) reduce 495) ((T_IS_GREATER_OR_EQUAL) reduce 495) ((T_IS_IDENTICAL) reduce 495) ((T_IS_NOT_EQUAL) reduce 495) ((T_IS_NOT_IDENTICAL) reduce 495) ((T_IS_SMALLER_OR_EQUAL) reduce 495) ((T_LOGICAL_AND) reduce 495) ((T_LOGICAL_OR) reduce 495) ((T_LOGICAL_XOR) reduce 495) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 495) ((T_OBJECT_OPERATOR) reduce 495) ((T_POW) reduce 495) ((T_SL) reduce 495) ((T_SPACESHIP) reduce 495) ((T_SR) reduce 495) (("[") reduce 495) (("^") reduce 495) (("{") reduce 495) (("|") reduce 495)) 1000 ((("(") shift) ((":") reduce 46)) 1001 ((("%") reduce 486) ((")") reduce 486) (("*") reduce 486) (("+") reduce 486) ((",") reduce 486) (("-") reduce 486) ((".") reduce 486) (("/") reduce 486) (("<") reduce 486) ((">") reduce 486) (("?") reduce 486) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_BOOLEAN_AND) reduce 486) ((T_BOOLEAN_OR) reduce 486) ((T_COALESCE) reduce 486) ((T_INSTANCEOF) reduce 486) ((T_IS_EQUAL) reduce 486) ((T_IS_GREATER_OR_EQUAL) reduce 486) ((T_IS_IDENTICAL) reduce 486) ((T_IS_NOT_EQUAL) reduce 486) ((T_IS_NOT_IDENTICAL) reduce 486) ((T_IS_SMALLER_OR_EQUAL) reduce 486) ((T_LOGICAL_AND) reduce 486) ((T_LOGICAL_OR) reduce 486) ((T_LOGICAL_XOR) reduce 486) ((T_POW) reduce 486) ((T_SL) reduce 486) ((T_SPACESHIP) reduce 486) ((T_SR) reduce 486) (("^") reduce 486) (("|") reduce 486)) 1002 (((":") reduce 8)) 1003 (((":") reduce 6)) 1004 (((":") reduce 7)) 1005 ((("(") shift) ((":") reduce 69)) 1006 ((("%") reduce 499) ((")") reduce 499) (("*") reduce 499) (("+") reduce 499) ((",") reduce 499) (("-") reduce 499) ((".") reduce 499) (("/") reduce 499) ((":") reduce 63) (("<") reduce 499) ((">") reduce 499) (("?") reduce 499) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_BOOLEAN_AND) reduce 499) ((T_BOOLEAN_OR) reduce 499) ((T_COALESCE) reduce 499) ((T_INSTANCEOF) reduce 499) ((T_IS_EQUAL) reduce 499) ((T_IS_GREATER_OR_EQUAL) reduce 499) ((T_IS_IDENTICAL) reduce 499) ((T_IS_NOT_EQUAL) reduce 499) ((T_IS_NOT_IDENTICAL) reduce 499) ((T_IS_SMALLER_OR_EQUAL) reduce 499) ((T_LOGICAL_AND) reduce 499) ((T_LOGICAL_OR) reduce 499) ((T_LOGICAL_XOR) reduce 499) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 499) ((T_OBJECT_OPERATOR) reduce 499) ((T_POW) reduce 499) ((T_SL) reduce 499) ((T_SPACESHIP) reduce 499) ((T_SR) reduce 499) (("[") reduce 499) (("^") reduce 499) (("{") reduce 499) (("|") reduce 499)) 1007 (((":") reduce 56)) 1008 ((("%") reduce 93) (("(") reduce 93) ((")") reduce 93) (("*") reduce 93) (("+") reduce 93) ((",") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 93) ((T_OBJECT_OPERATOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("[") reduce 93) (("^") reduce 93) (("{") reduce 93) (("|") reduce 93)) 1009 ((("%") reduce 92) (("(") reduce 92) ((")") reduce 92) (("*") reduce 92) (("+") reduce 92) ((",") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 92) ((T_OBJECT_OPERATOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("[") reduce 92) (("^") reduce 92) (("{") reduce 92) (("|") reduce 92)) 1010 ((("%") reduce 94) (("(") reduce 94) ((")") reduce 94) (("*") reduce 94) (("+") reduce 94) ((",") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 94) ((T_OBJECT_OPERATOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("[") reduce 94) (("^") reduce 94) (("{") reduce 94) (("|") reduce 94)) 1011 ((("$") shift) (("(") shift) ((":") reduce 10) ((T_ABSTRACT) shift) ((T_ATTRIBUTE) shift) ((T_CLASS) reduce 192) ((T_FINAL) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_READONLY) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_VARIABLE) shift)) 1012 ((("%") reduce 501) ((")") reduce 501) (("*") reduce 501) (("+") reduce 501) ((",") reduce 501) (("-") reduce 501) ((".") reduce 501) (("/") reduce 501) ((":") reduce 67) (("<") reduce 501) ((">") reduce 501) (("?") reduce 501) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_BOOLEAN_AND) reduce 501) ((T_BOOLEAN_OR) reduce 501) ((T_COALESCE) reduce 501) ((T_INSTANCEOF) reduce 501) ((T_IS_EQUAL) reduce 501) ((T_IS_GREATER_OR_EQUAL) reduce 501) ((T_IS_IDENTICAL) reduce 501) ((T_IS_NOT_EQUAL) reduce 501) ((T_IS_NOT_IDENTICAL) reduce 501) ((T_IS_SMALLER_OR_EQUAL) reduce 501) ((T_LOGICAL_AND) reduce 501) ((T_LOGICAL_OR) reduce 501) ((T_LOGICAL_XOR) reduce 501) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 501) ((T_OBJECT_OPERATOR) reduce 501) ((T_POW) reduce 501) ((T_SL) reduce 501) ((T_SPACESHIP) reduce 501) ((T_SR) reduce 501) (("[") reduce 501) (("^") reduce 501) (("{") reduce 501) (("|") reduce 501)) 1014 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) (("+") shift) (("-") shift) ((":") reduce 44) (("@") shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("~") shift)) 1015 (((":") reduce 75)) 1016 (((":") reduce 76)) 1017 (((":") reduce 77)) 1018 ((("(") shift) ((":") reduce 78)) 1019 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) (("+") shift) (("-") shift) ((":") reduce 4) (("@") shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("~") shift)) 1020 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) (("+") shift) (("-") shift) ((":") reduce 5) (("@") shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("~") shift)) 1021 (((":") reduce 43)) 1023 (((":") reduce 72) ((T_FN) shift) ((T_FUNCTION) shift) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470)) 1024 ((("%") reduce 91) (("(") reduce 91) ((")") reduce 91) (("*") reduce 91) (("+") reduce 91) ((",") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) ((":") reduce 81) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 91) ((T_OBJECT_OPERATOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("[") reduce 91) (("^") reduce 91) (("{") reduce 91) (("|") reduce 91)) 1026 (((":") reduce 47)) 1027 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) (("+") shift) (("-") shift) ((":") reduce 31) (("@") shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("~") shift)) 1028 (((":") reduce 57)) 1029 ((("%") reduce 498) ((")") reduce 498) (("*") reduce 498) (("+") reduce 498) ((",") reduce 498) (("-") reduce 498) ((".") reduce 498) (("/") reduce 498) ((":") reduce 61) (("<") reduce 498) ((">") reduce 498) (("?") reduce 498) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_BOOLEAN_AND) reduce 498) ((T_BOOLEAN_OR) reduce 498) ((T_COALESCE) reduce 498) ((T_INSTANCEOF) reduce 498) ((T_IS_EQUAL) reduce 498) ((T_IS_GREATER_OR_EQUAL) reduce 498) ((T_IS_IDENTICAL) reduce 498) ((T_IS_NOT_EQUAL) reduce 498) ((T_IS_NOT_IDENTICAL) reduce 498) ((T_IS_SMALLER_OR_EQUAL) reduce 498) ((T_LOGICAL_AND) reduce 498) ((T_LOGICAL_OR) reduce 498) ((T_LOGICAL_XOR) reduce 498) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 498) ((T_OBJECT_OPERATOR) reduce 498) ((T_POW) reduce 498) ((T_SL) reduce 498) ((T_SPACESHIP) reduce 498) ((T_SR) reduce 498) (("[") reduce 498) (("^") reduce 498) (("{") reduce 498) (("|") reduce 498)) 1030 (((":") reduce 28)) 1031 (((":") reduce 36)) 1033 (((":") reduce 32)) 1034 (((":") reduce 35)) 1035 ((("%") reduce 529) (("(") reduce 529) ((")") reduce 529) (("*") reduce 529) (("+") reduce 529) ((",") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) (("=") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AND_EQUAL) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_COALESCE_EQUAL) reduce 529) ((T_CONCAT_EQUAL) reduce 529) ((T_DEC) reduce 529) ((T_DIV_EQUAL) reduce 529) ((T_INC) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_MINUS_EQUAL) reduce 529) ((T_MOD_EQUAL) reduce 529) ((T_MUL_EQUAL) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_OR_EQUAL) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_PLUS_EQUAL) reduce 529) ((T_POW) reduce 529) ((T_POW_EQUAL) reduce 529) ((T_SL) reduce 529) ((T_SL_EQUAL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) ((T_SR_EQUAL) reduce 529) ((T_XOR_EQUAL) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 1036 (((":") reduce 19)) 1037 ((("!") shift) (("\"") shift) (("$") shift) (("%") reduce 440) (("(") shift) ((")") reduce 440) (("*") reduce 440) (("+") shift) ((",") reduce 440) (("-") shift) ((".") reduce 440) (("/") reduce 440) ((":") reduce 45) (("<") reduce 440) ((">") reduce 440) (("?") reduce 440) (("@") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOLEAN_AND) reduce 440) ((T_BOOLEAN_OR) reduce 440) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_COALESCE) reduce 440) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INSTANCEOF) reduce 440) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_IS_EQUAL) reduce 440) ((T_IS_GREATER_OR_EQUAL) reduce 440) ((T_IS_IDENTICAL) reduce 440) ((T_IS_NOT_EQUAL) reduce 440) ((T_IS_NOT_IDENTICAL) reduce 440) ((T_IS_SMALLER_OR_EQUAL) reduce 440) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_LOGICAL_AND) reduce 440) ((T_LOGICAL_OR) reduce 440) ((T_LOGICAL_XOR) reduce 440) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_POW) reduce 440) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_SL) reduce 440) ((T_SPACESHIP) reduce 440) ((T_SR) reduce 440) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("^") reduce 440) (("`") shift) (("|") reduce 440) (("~") shift)) 1041 (((")") reduce 291) ((",") reduce 291)) 1045 ((("%") reduce 525) (("(") reduce 516) ((")") reduce 525) (("*") reduce 525) (("+") reduce 525) ((",") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) (("<") reduce 525) (("=") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AND_EQUAL) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_COALESCE_EQUAL) reduce 525) ((T_CONCAT_EQUAL) reduce 525) ((T_DEC) reduce 525) ((T_DIV_EQUAL) reduce 525) ((T_INC) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_MINUS_EQUAL) reduce 525) ((T_MOD_EQUAL) reduce 525) ((T_MUL_EQUAL) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_OR_EQUAL) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_PLUS_EQUAL) reduce 525) ((T_POW) reduce 525) ((T_POW_EQUAL) reduce 525) ((T_SL) reduce 525) ((T_SL_EQUAL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) ((T_SR_EQUAL) reduce 525) ((T_XOR_EQUAL) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 1046 ((("%") reduce 493) ((")") reduce 493) (("*") reduce 493) (("+") reduce 493) ((",") reduce 493) (("-") reduce 493) ((".") reduce 493) (("/") reduce 493) (("<") reduce 493) ((">") reduce 493) (("?") reduce 493) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_BOOLEAN_AND) reduce 493) ((T_BOOLEAN_OR) reduce 493) ((T_COALESCE) reduce 493) ((T_INSTANCEOF) reduce 493) ((T_IS_EQUAL) reduce 493) ((T_IS_GREATER_OR_EQUAL) reduce 493) ((T_IS_IDENTICAL) reduce 493) ((T_IS_NOT_EQUAL) reduce 493) ((T_IS_NOT_IDENTICAL) reduce 493) ((T_IS_SMALLER_OR_EQUAL) reduce 493) ((T_LOGICAL_AND) reduce 493) ((T_LOGICAL_OR) reduce 493) ((T_LOGICAL_XOR) reduce 493) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 513) ((T_OBJECT_OPERATOR) reduce 513) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 513) ((T_POW) reduce 493) ((T_SL) reduce 493) ((T_SPACESHIP) reduce 493) ((T_SR) reduce 493) (("[") reduce 513) (("^") reduce 493) (("{") reduce 513) (("|") reduce 493)) 1048 ((("%") reduce 492) ((")") reduce 492) (("*") reduce 492) (("+") reduce 492) ((",") reduce 492) (("-") reduce 492) ((".") reduce 492) (("/") reduce 492) (("<") reduce 492) ((">") reduce 492) (("?") reduce 492) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_BOOLEAN_AND) reduce 492) ((T_BOOLEAN_OR) reduce 492) ((T_COALESCE) reduce 492) ((T_INSTANCEOF) reduce 492) ((T_IS_EQUAL) reduce 492) ((T_IS_GREATER_OR_EQUAL) reduce 492) ((T_IS_IDENTICAL) reduce 492) ((T_IS_NOT_EQUAL) reduce 492) ((T_IS_NOT_IDENTICAL) reduce 492) ((T_IS_SMALLER_OR_EQUAL) reduce 492) ((T_LOGICAL_AND) reduce 492) ((T_LOGICAL_OR) reduce 492) ((T_LOGICAL_XOR) reduce 492) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 515) ((T_OBJECT_OPERATOR) reduce 515) ((T_POW) reduce 492) ((T_SL) reduce 492) ((T_SPACESHIP) reduce 492) ((T_SR) reduce 492) (("[") reduce 515) (("^") reduce 492) (("{") reduce 515) (("|") reduce 492)) 1049 ((("%") reduce 491) (("(") reduce 518) ((")") reduce 491) (("*") reduce 491) (("+") reduce 491) ((",") reduce 491) (("-") reduce 491) ((".") reduce 491) (("/") reduce 491) (("<") reduce 491) ((">") reduce 491) (("?") reduce 491) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_BOOLEAN_AND) reduce 491) ((T_BOOLEAN_OR) reduce 491) ((T_COALESCE) reduce 491) ((T_INSTANCEOF) reduce 491) ((T_IS_EQUAL) reduce 491) ((T_IS_GREATER_OR_EQUAL) reduce 491) ((T_IS_IDENTICAL) reduce 491) ((T_IS_NOT_EQUAL) reduce 491) ((T_IS_NOT_IDENTICAL) reduce 491) ((T_IS_SMALLER_OR_EQUAL) reduce 491) ((T_LOGICAL_AND) reduce 491) ((T_LOGICAL_OR) reduce 491) ((T_LOGICAL_XOR) reduce 491) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 512) ((T_OBJECT_OPERATOR) reduce 512) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 512) ((T_POW) reduce 491) ((T_SL) reduce 491) ((T_SPACESHIP) reduce 491) ((T_SR) reduce 491) (("[") reduce 512) (("^") reduce 491) (("{") reduce 512) (("|") reduce 491)) 1050 ((("%") shift) ((")") reduce 293) (("*") shift) (("+") shift) ((",") reduce 293) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 1053 ((("%") reduce 524) (("(") reduce 524) ((")") reduce 524) (("*") reduce 524) (("+") reduce 524) ((",") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) (("<") reduce 524) (("=") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AND_EQUAL) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_COALESCE_EQUAL) reduce 524) ((T_CONCAT_EQUAL) reduce 524) ((T_DEC) reduce 524) ((T_DIV_EQUAL) reduce 524) ((T_INC) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_MINUS_EQUAL) reduce 524) ((T_MOD_EQUAL) reduce 524) ((T_MUL_EQUAL) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_OR_EQUAL) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_PLUS_EQUAL) reduce 524) ((T_POW) reduce 524) ((T_POW_EQUAL) reduce 524) ((T_SL) reduce 524) ((T_SL_EQUAL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) ((T_SR_EQUAL) reduce 524) ((T_XOR_EQUAL) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 1054 (((":") shift)) 1055 ((("%") reduce 445) ((")") reduce 445) (("*") reduce 445) (("+") reduce 445) ((",") reduce 445) (("-") reduce 445) ((".") reduce 445) (("/") reduce 445) (("<") reduce 445) ((">") reduce 445) (("?") reduce 445) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_BOOLEAN_AND) reduce 445) ((T_BOOLEAN_OR) reduce 445) ((T_COALESCE) reduce 445) ((T_INSTANCEOF) reduce 445) ((T_IS_EQUAL) reduce 445) ((T_IS_GREATER_OR_EQUAL) reduce 445) ((T_IS_IDENTICAL) reduce 445) ((T_IS_NOT_EQUAL) reduce 445) ((T_IS_NOT_IDENTICAL) reduce 445) ((T_IS_SMALLER_OR_EQUAL) reduce 445) ((T_LOGICAL_AND) reduce 445) ((T_LOGICAL_OR) reduce 445) ((T_LOGICAL_XOR) reduce 445) ((T_POW) reduce 445) ((T_SL) reduce 445) ((T_SPACESHIP) reduce 445) ((T_SR) reduce 445) (("^") reduce 445) (("|") reduce 445)) 1056 ((("%") reduce 427) ((")") reduce 427) (("*") reduce 427) (("+") reduce 427) ((",") reduce 427) (("-") reduce 427) ((".") reduce 427) (("/") reduce 427) (("<") reduce 427) ((">") reduce 427) (("?") reduce 427) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_BOOLEAN_AND) reduce 427) ((T_BOOLEAN_OR) reduce 427) ((T_COALESCE) reduce 427) ((T_INSTANCEOF) reduce 427) ((T_IS_EQUAL) reduce 427) ((T_IS_GREATER_OR_EQUAL) reduce 427) ((T_IS_IDENTICAL) reduce 427) ((T_IS_NOT_EQUAL) reduce 427) ((T_IS_NOT_IDENTICAL) reduce 427) ((T_IS_SMALLER_OR_EQUAL) reduce 427) ((T_LOGICAL_AND) reduce 427) ((T_LOGICAL_OR) reduce 427) ((T_LOGICAL_XOR) reduce 427) ((T_POW) reduce 427) ((T_SL) reduce 427) ((T_SPACESHIP) reduce 427) ((T_SR) reduce 427) (("^") reduce 427) (("|") reduce 427)) 1057 ((("%") reduce 449) ((")") reduce 449) (("*") reduce 449) (("+") reduce 449) ((",") reduce 449) (("-") reduce 449) ((".") reduce 449) (("/") reduce 449) (("<") reduce 449) ((">") reduce 449) (("?") reduce 449) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_BOOLEAN_AND) reduce 449) ((T_BOOLEAN_OR) reduce 449) ((T_COALESCE) reduce 449) ((T_INSTANCEOF) reduce 449) ((T_IS_EQUAL) reduce 449) ((T_IS_GREATER_OR_EQUAL) reduce 449) ((T_IS_IDENTICAL) reduce 449) ((T_IS_NOT_EQUAL) reduce 449) ((T_IS_NOT_IDENTICAL) reduce 449) ((T_IS_SMALLER_OR_EQUAL) reduce 449) ((T_LOGICAL_AND) reduce 449) ((T_LOGICAL_OR) reduce 449) ((T_LOGICAL_XOR) reduce 449) ((T_POW) reduce 449) ((T_SL) reduce 449) ((T_SPACESHIP) reduce 449) ((T_SR) reduce 449) (("^") reduce 449) (("|") reduce 449)) 1058 ((("%") reduce 494) (("(") shift) ((")") reduce 494) (("*") reduce 494) (("+") reduce 494) ((",") reduce 494) (("-") reduce 494) ((".") reduce 494) (("/") reduce 494) (("<") reduce 494) ((">") reduce 494) (("?") reduce 494) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_BOOLEAN_AND) reduce 494) ((T_BOOLEAN_OR) reduce 494) ((T_COALESCE) reduce 494) ((T_INSTANCEOF) reduce 494) ((T_IS_EQUAL) reduce 494) ((T_IS_GREATER_OR_EQUAL) reduce 494) ((T_IS_IDENTICAL) reduce 494) ((T_IS_NOT_EQUAL) reduce 494) ((T_IS_NOT_IDENTICAL) reduce 494) ((T_IS_SMALLER_OR_EQUAL) reduce 494) ((T_LOGICAL_AND) reduce 494) ((T_LOGICAL_OR) reduce 494) ((T_LOGICAL_XOR) reduce 494) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 494) ((T_OBJECT_OPERATOR) reduce 494) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 494) ((T_SL) reduce 494) ((T_SPACESHIP) reduce 494) ((T_SR) reduce 494) (("[") reduce 494) (("^") reduce 494) (("{") reduce 494) (("|") reduce 494)) 1059 ((("%") reduce 423) ((")") reduce 423) (("*") reduce 423) (("+") reduce 423) ((",") reduce 423) (("-") reduce 423) ((".") reduce 423) (("/") reduce 423) (("<") reduce 423) ((">") reduce 423) (("?") reduce 423) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_BOOLEAN_AND) reduce 423) ((T_BOOLEAN_OR) reduce 423) ((T_COALESCE) reduce 423) ((T_INSTANCEOF) reduce 423) ((T_IS_EQUAL) reduce 423) ((T_IS_GREATER_OR_EQUAL) reduce 423) ((T_IS_IDENTICAL) reduce 423) ((T_IS_NOT_EQUAL) reduce 423) ((T_IS_NOT_IDENTICAL) reduce 423) ((T_IS_SMALLER_OR_EQUAL) reduce 423) ((T_LOGICAL_AND) reduce 423) ((T_LOGICAL_OR) reduce 423) ((T_LOGICAL_XOR) reduce 423) ((T_POW) reduce 423) ((T_SL) reduce 423) ((T_SPACESHIP) reduce 423) ((T_SR) reduce 423) (("^") reduce 423) (("|") reduce 423)) 1061 (((":") reduce 71)) 1062 ((("%") reduce 437) ((")") reduce 437) (("*") reduce 437) (("+") reduce 437) ((",") reduce 437) (("-") reduce 437) ((".") reduce 437) (("/") reduce 437) (("<") reduce 437) ((">") reduce 437) (("?") reduce 437) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_BOOLEAN_AND) reduce 437) ((T_BOOLEAN_OR) reduce 437) ((T_COALESCE) reduce 437) ((T_INSTANCEOF) reduce 437) ((T_IS_EQUAL) reduce 437) ((T_IS_GREATER_OR_EQUAL) reduce 437) ((T_IS_IDENTICAL) reduce 437) ((T_IS_NOT_EQUAL) reduce 437) ((T_IS_NOT_IDENTICAL) reduce 437) ((T_IS_SMALLER_OR_EQUAL) reduce 437) ((T_LOGICAL_AND) reduce 437) ((T_LOGICAL_OR) reduce 437) ((T_LOGICAL_XOR) reduce 437) ((T_POW) reduce 437) ((T_SL) reduce 437) ((T_SPACESHIP) reduce 437) ((T_SR) reduce 437) (("^") reduce 437) (("|") reduce 437)) 1063 (((":") reduce 82)) 1064 ((("%") reduce 519) (("(") reduce 519) ((")") reduce 519) (("*") reduce 519) (("+") reduce 519) ((",") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) (("<") reduce 519) (("=") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AND_EQUAL) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_COALESCE_EQUAL) reduce 519) ((T_CONCAT_EQUAL) reduce 519) ((T_DEC) reduce 519) ((T_DIV_EQUAL) reduce 519) ((T_INC) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_MINUS_EQUAL) reduce 519) ((T_MOD_EQUAL) reduce 519) ((T_MUL_EQUAL) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_OR_EQUAL) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_PLUS_EQUAL) reduce 519) ((T_POW) reduce 519) ((T_POW_EQUAL) reduce 519) ((T_SL) reduce 519) ((T_SL_EQUAL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) ((T_SR_EQUAL) reduce 519) ((T_XOR_EQUAL) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 1065 ((("%") reduce 526) ((")") reduce 526) (("*") reduce 526) (("+") reduce 526) ((",") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) (("<") reduce 526) (("=") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AND_EQUAL) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_COALESCE_EQUAL) reduce 526) ((T_CONCAT_EQUAL) reduce 526) ((T_DEC) reduce 526) ((T_DIV_EQUAL) reduce 526) ((T_INC) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_MINUS_EQUAL) reduce 526) ((T_MOD_EQUAL) reduce 526) ((T_MUL_EQUAL) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_OR_EQUAL) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_PLUS_EQUAL) reduce 526) ((T_POW) reduce 526) ((T_POW_EQUAL) reduce 526) ((T_SL) reduce 526) ((T_SL_EQUAL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) ((T_SR_EQUAL) reduce 526) ((T_XOR_EQUAL) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 1066 ((("%") reduce 367) ((")") reduce 367) (("*") reduce 367) (("+") reduce 367) ((",") reduce 367) (("-") reduce 367) ((".") reduce 367) (("/") reduce 367) (("<") reduce 367) (("=") shift) ((">") reduce 367) (("?") reduce 367) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AND_EQUAL) shift) ((T_BOOLEAN_AND) reduce 367) ((T_BOOLEAN_OR) reduce 367) ((T_COALESCE) reduce 367) ((T_COALESCE_EQUAL) shift) ((T_CONCAT_EQUAL) shift) ((T_DEC) shift) ((T_DIV_EQUAL) shift) ((T_INC) shift) ((T_INSTANCEOF) reduce 367) ((T_IS_EQUAL) reduce 367) ((T_IS_GREATER_OR_EQUAL) reduce 367) ((T_IS_IDENTICAL) reduce 367) ((T_IS_NOT_EQUAL) reduce 367) ((T_IS_NOT_IDENTICAL) reduce 367) ((T_IS_SMALLER_OR_EQUAL) reduce 367) ((T_LOGICAL_AND) reduce 367) ((T_LOGICAL_OR) reduce 367) ((T_LOGICAL_XOR) reduce 367) ((T_MINUS_EQUAL) shift) ((T_MOD_EQUAL) shift) ((T_MUL_EQUAL) shift) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_OR_EQUAL) shift) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_PLUS_EQUAL) shift) ((T_POW) reduce 367) ((T_POW_EQUAL) shift) ((T_SL) reduce 367) ((T_SL_EQUAL) shift) ((T_SPACESHIP) reduce 367) ((T_SR) reduce 367) ((T_SR_EQUAL) shift) ((T_XOR_EQUAL) shift) (("[") reduce 510) (("^") reduce 367) (("{") reduce 510) (("|") reduce 367)) 1070 ((("%") reduce 502) ((")") reduce 502) (("*") reduce 502) (("+") reduce 502) ((",") reduce 502) (("-") reduce 502) ((".") reduce 502) (("/") reduce 502) (("<") reduce 502) ((">") reduce 502) (("?") reduce 502) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_BOOLEAN_AND) reduce 502) ((T_BOOLEAN_OR) reduce 502) ((T_COALESCE) reduce 502) ((T_INSTANCEOF) reduce 502) ((T_IS_EQUAL) reduce 502) ((T_IS_GREATER_OR_EQUAL) reduce 502) ((T_IS_IDENTICAL) reduce 502) ((T_IS_NOT_EQUAL) reduce 502) ((T_IS_NOT_IDENTICAL) reduce 502) ((T_IS_SMALLER_OR_EQUAL) reduce 502) ((T_LOGICAL_AND) reduce 502) ((T_LOGICAL_OR) reduce 502) ((T_LOGICAL_XOR) reduce 502) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 502) ((T_OBJECT_OPERATOR) reduce 502) ((T_POW) reduce 502) ((T_SL) reduce 502) ((T_SPACESHIP) reduce 502) ((T_SR) reduce 502) (("[") reduce 502) (("^") reduce 502) (("{") reduce 502) (("|") reduce 502)) 1072 ((("%") reduce 497) ((")") reduce 497) (("*") reduce 497) (("+") reduce 497) ((",") reduce 497) (("-") reduce 497) ((".") reduce 497) (("/") reduce 497) (("<") reduce 497) ((">") reduce 497) (("?") reduce 497) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_BOOLEAN_AND) reduce 497) ((T_BOOLEAN_OR) reduce 497) ((T_COALESCE) reduce 497) ((T_INSTANCEOF) reduce 497) ((T_IS_EQUAL) reduce 497) ((T_IS_GREATER_OR_EQUAL) reduce 497) ((T_IS_IDENTICAL) reduce 497) ((T_IS_NOT_EQUAL) reduce 497) ((T_IS_NOT_IDENTICAL) reduce 497) ((T_IS_SMALLER_OR_EQUAL) reduce 497) ((T_LOGICAL_AND) reduce 497) ((T_LOGICAL_OR) reduce 497) ((T_LOGICAL_XOR) reduce 497) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 497) ((T_OBJECT_OPERATOR) reduce 497) ((T_POW) reduce 497) ((T_SL) reduce 497) ((T_SPACESHIP) reduce 497) ((T_SR) reduce 497) (("[") reduce 497) (("^") reduce 497) (("{") reduce 497) (("|") reduce 497)) 1075 ((("%") reduce 475) (("(") shift) ((")") reduce 475) (("*") reduce 475) (("+") reduce 475) ((",") reduce 475) (("-") reduce 475) ((".") reduce 475) (("/") reduce 475) (("<") reduce 475) ((">") reduce 475) (("?") reduce 475) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_BOOLEAN_AND) reduce 475) ((T_BOOLEAN_OR) reduce 475) ((T_COALESCE) reduce 475) ((T_INSTANCEOF) reduce 475) ((T_IS_EQUAL) reduce 475) ((T_IS_GREATER_OR_EQUAL) reduce 475) ((T_IS_IDENTICAL) reduce 475) ((T_IS_NOT_EQUAL) reduce 475) ((T_IS_NOT_IDENTICAL) reduce 475) ((T_IS_SMALLER_OR_EQUAL) reduce 475) ((T_LOGICAL_AND) reduce 475) ((T_LOGICAL_OR) reduce 475) ((T_LOGICAL_XOR) reduce 475) ((T_POW) reduce 475) ((T_SL) reduce 475) ((T_SPACESHIP) reduce 475) ((T_SR) reduce 475) (("^") reduce 475) (("|") reduce 475)) 1076 ((("%") reduce 496) ((")") reduce 496) (("*") reduce 496) (("+") reduce 496) ((",") reduce 496) (("-") reduce 496) ((".") reduce 496) (("/") reduce 496) (("<") reduce 496) ((">") reduce 496) (("?") reduce 496) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_BOOLEAN_AND) reduce 496) ((T_BOOLEAN_OR) reduce 496) ((T_COALESCE) reduce 496) ((T_INSTANCEOF) reduce 496) ((T_IS_EQUAL) reduce 496) ((T_IS_GREATER_OR_EQUAL) reduce 496) ((T_IS_IDENTICAL) reduce 496) ((T_IS_NOT_EQUAL) reduce 496) ((T_IS_NOT_IDENTICAL) reduce 496) ((T_IS_SMALLER_OR_EQUAL) reduce 496) ((T_LOGICAL_AND) reduce 496) ((T_LOGICAL_OR) reduce 496) ((T_LOGICAL_XOR) reduce 496) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 496) ((T_OBJECT_OPERATOR) reduce 496) ((T_POW) reduce 496) ((T_SL) reduce 496) ((T_SPACESHIP) reduce 496) ((T_SR) reduce 496) (("[") reduce 496) (("^") reduce 496) (("{") reduce 496) (("|") reduce 496)) 1077 ((("%") reduce 500) ((")") reduce 500) (("*") reduce 500) (("+") reduce 500) ((",") reduce 500) (("-") reduce 500) ((".") reduce 500) (("/") reduce 500) (("<") reduce 500) ((">") reduce 500) (("?") reduce 500) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_BOOLEAN_AND) reduce 500) ((T_BOOLEAN_OR) reduce 500) ((T_COALESCE) reduce 500) ((T_INSTANCEOF) reduce 500) ((T_IS_EQUAL) reduce 500) ((T_IS_GREATER_OR_EQUAL) reduce 500) ((T_IS_IDENTICAL) reduce 500) ((T_IS_NOT_EQUAL) reduce 500) ((T_IS_NOT_IDENTICAL) reduce 500) ((T_IS_SMALLER_OR_EQUAL) reduce 500) ((T_LOGICAL_AND) reduce 500) ((T_LOGICAL_OR) reduce 500) ((T_LOGICAL_XOR) reduce 500) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 500) ((T_OBJECT_OPERATOR) reduce 500) ((T_POW) reduce 500) ((T_SL) reduce 500) ((T_SPACESHIP) reduce 500) ((T_SR) reduce 500) (("[") reduce 500) (("^") reduce 500) (("{") reduce 500) (("|") reduce 500)) 1081 ((("%") reduce 495) ((")") reduce 495) (("*") reduce 495) (("+") reduce 495) ((",") reduce 495) (("-") reduce 495) ((".") reduce 495) (("/") reduce 495) (("<") reduce 495) ((">") reduce 495) (("?") reduce 495) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_BOOLEAN_AND) reduce 495) ((T_BOOLEAN_OR) reduce 495) ((T_COALESCE) reduce 495) ((T_INSTANCEOF) reduce 495) ((T_IS_EQUAL) reduce 495) ((T_IS_GREATER_OR_EQUAL) reduce 495) ((T_IS_IDENTICAL) reduce 495) ((T_IS_NOT_EQUAL) reduce 495) ((T_IS_NOT_IDENTICAL) reduce 495) ((T_IS_SMALLER_OR_EQUAL) reduce 495) ((T_LOGICAL_AND) reduce 495) ((T_LOGICAL_OR) reduce 495) ((T_LOGICAL_XOR) reduce 495) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 495) ((T_OBJECT_OPERATOR) reduce 495) ((T_POW) reduce 495) ((T_SL) reduce 495) ((T_SPACESHIP) reduce 495) ((T_SR) reduce 495) (("[") reduce 495) (("^") reduce 495) (("{") reduce 495) (("|") reduce 495)) 1084 ((("%") reduce 499) ((")") reduce 499) (("*") reduce 499) (("+") reduce 499) ((",") reduce 499) (("-") reduce 499) ((".") reduce 499) (("/") reduce 499) (("<") reduce 499) ((">") reduce 499) (("?") reduce 499) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_BOOLEAN_AND) reduce 499) ((T_BOOLEAN_OR) reduce 499) ((T_COALESCE) reduce 499) ((T_INSTANCEOF) reduce 499) ((T_IS_EQUAL) reduce 499) ((T_IS_GREATER_OR_EQUAL) reduce 499) ((T_IS_IDENTICAL) reduce 499) ((T_IS_NOT_EQUAL) reduce 499) ((T_IS_NOT_IDENTICAL) reduce 499) ((T_IS_SMALLER_OR_EQUAL) reduce 499) ((T_LOGICAL_AND) reduce 499) ((T_LOGICAL_OR) reduce 499) ((T_LOGICAL_XOR) reduce 499) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 499) ((T_OBJECT_OPERATOR) reduce 499) ((T_POW) reduce 499) ((T_SL) reduce 499) ((T_SPACESHIP) reduce 499) ((T_SR) reduce 499) (("[") reduce 499) (("^") reduce 499) (("{") reduce 499) (("|") reduce 499)) 1086 ((("%") reduce 501) ((")") reduce 501) (("*") reduce 501) (("+") reduce 501) ((",") reduce 501) (("-") reduce 501) ((".") reduce 501) (("/") reduce 501) (("<") reduce 501) ((">") reduce 501) (("?") reduce 501) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_BOOLEAN_AND) reduce 501) ((T_BOOLEAN_OR) reduce 501) ((T_COALESCE) reduce 501) ((T_INSTANCEOF) reduce 501) ((T_IS_EQUAL) reduce 501) ((T_IS_GREATER_OR_EQUAL) reduce 501) ((T_IS_IDENTICAL) reduce 501) ((T_IS_NOT_EQUAL) reduce 501) ((T_IS_NOT_IDENTICAL) reduce 501) ((T_IS_SMALLER_OR_EQUAL) reduce 501) ((T_LOGICAL_AND) reduce 501) ((T_LOGICAL_OR) reduce 501) ((T_LOGICAL_XOR) reduce 501) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 501) ((T_OBJECT_OPERATOR) reduce 501) ((T_POW) reduce 501) ((T_SL) reduce 501) ((T_SPACESHIP) reduce 501) ((T_SR) reduce 501) (("[") reduce 501) (("^") reduce 501) (("{") reduce 501) (("|") reduce 501)) 1092 ((("%") reduce 91) (("(") reduce 91) ((")") reduce 91) (("*") reduce 91) (("+") reduce 91) ((",") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 91) ((T_OBJECT_OPERATOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("[") reduce 91) (("^") reduce 91) (("{") reduce 91) (("|") reduce 91)) 1094 ((("%") reduce 498) ((")") reduce 498) (("*") reduce 498) (("+") reduce 498) ((",") reduce 498) (("-") reduce 498) ((".") reduce 498) (("/") reduce 498) (("<") reduce 498) ((">") reduce 498) (("?") reduce 498) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_BOOLEAN_AND) reduce 498) ((T_BOOLEAN_OR) reduce 498) ((T_COALESCE) reduce 498) ((T_INSTANCEOF) reduce 498) ((T_IS_EQUAL) reduce 498) ((T_IS_GREATER_OR_EQUAL) reduce 498) ((T_IS_IDENTICAL) reduce 498) ((T_IS_NOT_EQUAL) reduce 498) ((T_IS_NOT_IDENTICAL) reduce 498) ((T_IS_SMALLER_OR_EQUAL) reduce 498) ((T_LOGICAL_AND) reduce 498) ((T_LOGICAL_OR) reduce 498) ((T_LOGICAL_XOR) reduce 498) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 498) ((T_OBJECT_OPERATOR) reduce 498) ((T_POW) reduce 498) ((T_SL) reduce 498) ((T_SPACESHIP) reduce 498) ((T_SR) reduce 498) (("[") reduce 498) (("^") reduce 498) (("{") reduce 498) (("|") reduce 498)) 1095 ((("!") shift) (("\"") shift) (("$") shift) (("%") reduce 440) (("(") shift) ((")") reduce 440) (("*") reduce 440) (("+") shift) ((",") reduce 440) (("-") shift) ((".") reduce 440) (("/") reduce 440) (("<") reduce 440) ((">") reduce 440) (("?") reduce 440) (("@") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOLEAN_AND) reduce 440) ((T_BOOLEAN_OR) reduce 440) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_COALESCE) reduce 440) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INSTANCEOF) reduce 440) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_IS_EQUAL) reduce 440) ((T_IS_GREATER_OR_EQUAL) reduce 440) ((T_IS_IDENTICAL) reduce 440) ((T_IS_NOT_EQUAL) reduce 440) ((T_IS_NOT_IDENTICAL) reduce 440) ((T_IS_SMALLER_OR_EQUAL) reduce 440) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_LOGICAL_AND) reduce 440) ((T_LOGICAL_OR) reduce 440) ((T_LOGICAL_XOR) reduce 440) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_POW) reduce 440) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_SL) reduce 440) ((T_SPACESHIP) reduce 440) ((T_SR) reduce 440) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("^") reduce 440) (("`") shift) (("|") reduce 440) (("~") shift)) 1096 ((("%") reduce 411) ((")") reduce 411) (("*") reduce 411) (("+") reduce 411) ((",") reduce 411) (("-") reduce 411) ((".") reduce 411) (("/") reduce 411) (("<") reduce 411) ((">") reduce 411) (("?") reduce 411) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_BOOLEAN_AND) reduce 411) ((T_BOOLEAN_OR) reduce 411) ((T_COALESCE) reduce 411) ((T_INSTANCEOF) reduce 411) ((T_IS_EQUAL) reduce 411) ((T_IS_GREATER_OR_EQUAL) reduce 411) ((T_IS_IDENTICAL) reduce 411) ((T_IS_NOT_EQUAL) reduce 411) ((T_IS_NOT_IDENTICAL) reduce 411) ((T_IS_SMALLER_OR_EQUAL) reduce 411) ((T_LOGICAL_AND) reduce 411) ((T_LOGICAL_OR) reduce 411) ((T_LOGICAL_XOR) reduce 411) ((T_POW) shift) ((T_SL) reduce 411) ((T_SPACESHIP) reduce 411) ((T_SR) reduce 411) (("^") reduce 411) (("|") reduce 411)) 1127 ((("%") shift) ((")") reduce 395) (("*") shift) (("+") shift) ((",") reduce 395) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 395) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 395) ((T_BOOLEAN_OR) reduce 395) ((T_COALESCE) reduce 395) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 395) ((T_LOGICAL_OR) reduce 395) ((T_LOGICAL_XOR) reduce 395) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") reduce 395)) 1128 ((("%") shift) ((")") reduce 398) (("*") shift) (("+") shift) ((",") reduce 398) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 398) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 398) ((T_BOOLEAN_OR) reduce 398) ((T_COALESCE) reduce 398) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 398) ((T_LOGICAL_OR) reduce 398) ((T_LOGICAL_XOR) reduce 398) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 398) (("|") reduce 398)) 1129 ((("%") shift) ((")") reduce 407) (("*") shift) (("+") shift) ((",") reduce 407) (("-") shift) ((".") reduce 407) (("/") shift) (("<") reduce 407) ((">") reduce 407) (("?") reduce 407) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_BOOLEAN_AND) reduce 407) ((T_BOOLEAN_OR) reduce 407) ((T_COALESCE) reduce 407) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 407) ((T_IS_GREATER_OR_EQUAL) reduce 407) ((T_IS_IDENTICAL) reduce 407) ((T_IS_NOT_EQUAL) reduce 407) ((T_IS_NOT_IDENTICAL) reduce 407) ((T_IS_SMALLER_OR_EQUAL) reduce 407) ((T_LOGICAL_AND) reduce 407) ((T_LOGICAL_OR) reduce 407) ((T_LOGICAL_XOR) reduce 407) ((T_POW) shift) ((T_SL) reduce 407) ((T_SPACESHIP) reduce 407) ((T_SR) reduce 407) (("^") reduce 407) (("|") reduce 407)) 1130 ((("%") shift) ((")") reduce 420) (("*") shift) (("+") shift) ((",") reduce 420) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 420) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_BOOLEAN_AND) reduce 420) ((T_BOOLEAN_OR) reduce 420) ((T_COALESCE) reduce 420) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 420) ((T_LOGICAL_OR) reduce 420) ((T_LOGICAL_XOR) reduce 420) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 420) (("|") reduce 420)) 1131 ((("%") shift) ((")") reduce 406) (("*") shift) (("+") shift) ((",") reduce 406) (("-") shift) ((".") reduce 406) (("/") shift) (("<") reduce 406) ((">") reduce 406) (("?") reduce 406) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_BOOLEAN_AND) reduce 406) ((T_BOOLEAN_OR) reduce 406) ((T_COALESCE) reduce 406) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 406) ((T_IS_GREATER_OR_EQUAL) reduce 406) ((T_IS_IDENTICAL) reduce 406) ((T_IS_NOT_EQUAL) reduce 406) ((T_IS_NOT_IDENTICAL) reduce 406) ((T_IS_SMALLER_OR_EQUAL) reduce 406) ((T_LOGICAL_AND) reduce 406) ((T_LOGICAL_OR) reduce 406) ((T_LOGICAL_XOR) reduce 406) ((T_POW) shift) ((T_SL) reduce 406) ((T_SPACESHIP) reduce 406) ((T_SR) reduce 406) (("^") reduce 406) (("|") reduce 406)) 1132 ((("%") reduce 403) ((")") reduce 403) (("*") reduce 403) (("+") reduce 403) ((",") reduce 403) (("-") reduce 403) ((".") reduce 403) (("/") reduce 403) (("<") reduce 403) ((">") reduce 403) (("?") reduce 403) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_BOOLEAN_AND) reduce 403) ((T_BOOLEAN_OR) reduce 403) ((T_COALESCE) reduce 403) ((T_INSTANCEOF) reduce 403) ((T_IS_EQUAL) reduce 403) ((T_IS_GREATER_OR_EQUAL) reduce 403) ((T_IS_IDENTICAL) reduce 403) ((T_IS_NOT_EQUAL) reduce 403) ((T_IS_NOT_IDENTICAL) reduce 403) ((T_IS_SMALLER_OR_EQUAL) reduce 403) ((T_LOGICAL_AND) reduce 403) ((T_LOGICAL_OR) reduce 403) ((T_LOGICAL_XOR) reduce 403) ((T_POW) shift) ((T_SL) reduce 403) ((T_SPACESHIP) reduce 403) ((T_SR) reduce 403) (("^") reduce 403) (("|") reduce 403)) 1133 ((("%") shift) ((")") reduce 394) (("*") shift) (("+") shift) ((",") reduce 394) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 394) ((T_LOGICAL_XOR) reduce 394) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 1134 ((("%") shift) ((")") reduce 392) (("*") shift) (("+") shift) ((",") reduce 392) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 392) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 1135 ((("%") shift) ((")") reduce 393) (("*") shift) (("+") shift) ((",") reduce 393) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 393) ((T_LOGICAL_OR) reduce 393) ((T_LOGICAL_XOR) reduce 393) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 1136 ((("%") shift) ((")") reduce 417) (("*") shift) (("+") shift) ((",") reduce 417) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 417) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_BOOLEAN_AND) reduce 417) ((T_BOOLEAN_OR) reduce 417) ((T_COALESCE) reduce 417) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 417) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 417) ((T_IS_NOT_EQUAL) reduce 417) ((T_IS_NOT_IDENTICAL) reduce 417) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 417) ((T_LOGICAL_OR) reduce 417) ((T_LOGICAL_XOR) reduce 417) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 417) ((T_SR) shift) (("^") reduce 417) (("|") reduce 417)) 1137 ((("%") shift) ((")") reduce 413) (("*") shift) (("+") shift) ((",") reduce 413) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 413) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_BOOLEAN_AND) reduce 413) ((T_BOOLEAN_OR) reduce 413) ((T_COALESCE) reduce 413) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 413) ((T_LOGICAL_OR) reduce 413) ((T_LOGICAL_XOR) reduce 413) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 413) (("|") reduce 413)) 1138 ((("%") shift) ((")") reduce 415) (("*") shift) (("+") shift) ((",") reduce 415) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 415) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_BOOLEAN_AND) reduce 415) ((T_BOOLEAN_OR) reduce 415) ((T_COALESCE) reduce 415) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 415) ((T_LOGICAL_OR) reduce 415) ((T_LOGICAL_XOR) reduce 415) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 415) (("|") reduce 415)) 1139 ((("%") shift) ((")") reduce 412) (("*") shift) (("+") shift) ((",") reduce 412) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 412) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_BOOLEAN_AND) reduce 412) ((T_BOOLEAN_OR) reduce 412) ((T_COALESCE) reduce 412) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 412) ((T_LOGICAL_OR) reduce 412) ((T_LOGICAL_XOR) reduce 412) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 412) (("|") reduce 412)) 1140 ((("%") shift) ((")") reduce 419) (("*") shift) (("+") shift) ((",") reduce 419) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 419) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_BOOLEAN_AND) reduce 419) ((T_BOOLEAN_OR) reduce 419) ((T_COALESCE) reduce 419) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 419) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 419) ((T_IS_NOT_EQUAL) reduce 419) ((T_IS_NOT_IDENTICAL) reduce 419) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 419) ((T_LOGICAL_OR) reduce 419) ((T_LOGICAL_XOR) reduce 419) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 419) ((T_SR) shift) (("^") reduce 419) (("|") reduce 419)) 1141 ((("%") shift) ((")") reduce 414) (("*") shift) (("+") shift) ((",") reduce 414) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 414) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_BOOLEAN_AND) reduce 414) ((T_BOOLEAN_OR) reduce 414) ((T_COALESCE) reduce 414) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 414) ((T_LOGICAL_OR) reduce 414) ((T_LOGICAL_XOR) reduce 414) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 414) (("|") reduce 414)) 1144 ((("%") reduce 93) ((")") reduce 93) (("*") reduce 93) (("+") reduce 93) ((",") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93)) 1145 ((("%") reduce 92) ((")") reduce 92) (("*") reduce 92) (("+") reduce 92) ((",") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92)) 1146 ((("%") reduce 94) ((")") reduce 94) (("*") reduce 94) (("+") reduce 94) ((",") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94)) 1147 ((("%") reduce 470) ((")") reduce 470) (("*") reduce 470) (("+") reduce 470) ((",") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470)) 1148 ((("%") reduce 91) ((")") reduce 91) (("*") reduce 91) (("+") reduce 91) ((",") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91)) 1149 ((("%") reduce 529) ((")") reduce 529) (("*") reduce 529) (("+") reduce 529) ((",") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 1150 ((("%") reduce 472) ((")") reduce 472) (("*") reduce 472) (("+") reduce 472) ((",") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472)) 1151 ((("%") reduce 421) ((")") reduce 421) (("*") reduce 421) (("+") reduce 421) ((",") reduce 421) (("-") reduce 421) ((".") reduce 421) (("/") reduce 421) (("<") reduce 421) ((">") reduce 421) (("?") reduce 421) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_BOOLEAN_AND) reduce 421) ((T_BOOLEAN_OR) reduce 421) ((T_COALESCE) reduce 421) ((T_INSTANCEOF) reduce 421) ((T_IS_EQUAL) reduce 421) ((T_IS_GREATER_OR_EQUAL) reduce 421) ((T_IS_IDENTICAL) reduce 421) ((T_IS_NOT_EQUAL) reduce 421) ((T_IS_NOT_IDENTICAL) reduce 421) ((T_IS_SMALLER_OR_EQUAL) reduce 421) ((T_LOGICAL_AND) reduce 421) ((T_LOGICAL_OR) reduce 421) ((T_LOGICAL_XOR) reduce 421) ((T_POW) reduce 421) ((T_SL) reduce 421) ((T_SPACESHIP) reduce 421) ((T_SR) reduce 421) (("^") reduce 421) (("|") reduce 421)) 1152 ((("%") reduce 471) ((")") reduce 471) (("*") reduce 471) (("+") reduce 471) ((",") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471)) 1153 ((("%") reduce 473) ((")") reduce 473) (("*") reduce 473) (("+") reduce 473) ((",") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 1154 ((("%") reduce 534) ((")") reduce 534) (("*") reduce 534) (("+") reduce 534) ((",") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 1161 ((("%") reduce 536) ((")") reduce 536) (("*") reduce 536) (("+") reduce 536) ((",") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 1163 ((("%") reduce 535) ((")") reduce 535) (("*") reduce 535) (("+") reduce 535) ((",") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 1164 ((("%") reduce 540) ((")") reduce 540) (("*") reduce 540) (("+") reduce 540) ((",") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 1165 ((("%") reduce 544) ((")") reduce 544) (("*") reduce 544) (("+") reduce 544) ((",") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 1166 ((("%") reduce 537) ((")") reduce 537) (("*") reduce 537) (("+") reduce 537) ((",") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 1167 ((("%") reduce 546) ((")") reduce 546) (("*") reduce 546) (("+") reduce 546) ((",") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 1170 ((("%") reduce 545) ((")") reduce 545) (("*") reduce 545) (("+") reduce 545) ((",") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 1171 ((("%") reduce 538) ((")") reduce 538) (("*") reduce 538) (("+") reduce 538) ((",") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 1173 ((("%") reduce 539) ((")") reduce 539) (("*") reduce 539) (("+") reduce 539) ((",") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 1175 ((("%") reduce 474) ((")") reduce 474) (("*") reduce 474) (("+") reduce 474) ((",") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474)) 1176 ((("%") reduce 531) ((")") reduce 531) (("*") reduce 531) (("+") reduce 531) ((",") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 1179 ((("%") reduce 530) ((")") reduce 530) (("*") reduce 530) (("+") reduce 530) ((",") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 1180 ((("%") shift) ((")") reduce 426) (("*") shift) (("+") shift) ((",") reduce 426) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 426) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 426) ((T_LOGICAL_OR) reduce 426) ((T_LOGICAL_XOR) reduce 426) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 1181 ((("%") shift) ((")") reduce 390) (("*") shift) (("+") shift) ((",") reduce 390) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 390) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) reduce 390) ((T_COALESCE) reduce 390) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 390) ((T_LOGICAL_OR) reduce 390) ((T_LOGICAL_XOR) reduce 390) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 1182 ((("%") shift) ((")") reduce 391) (("*") shift) (("+") shift) ((",") reduce 391) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 391) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 391) ((T_BOOLEAN_OR) reduce 391) ((T_COALESCE) reduce 391) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 391) ((T_LOGICAL_OR) reduce 391) ((T_LOGICAL_XOR) reduce 391) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 1183 ((("%") shift) ((")") reduce 396) (("*") shift) (("+") shift) ((",") reduce 396) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 396) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_BOOLEAN_AND) reduce 396) ((T_BOOLEAN_OR) reduce 396) ((T_COALESCE) reduce 396) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 396) ((T_LOGICAL_OR) reduce 396) ((T_LOGICAL_XOR) reduce 396) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 396) (("|") reduce 396)) 1184 ((("%") shift) ((")") reduce 397) (("*") shift) (("+") shift) ((",") reduce 397) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 397) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_BOOLEAN_AND) reduce 397) ((T_BOOLEAN_OR) reduce 397) ((T_COALESCE) reduce 397) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 397) ((T_LOGICAL_OR) reduce 397) ((T_LOGICAL_XOR) reduce 397) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 397) (("|") reduce 397)) 1188 ((("%") shift) ((")") reduce 424) (("*") shift) (("+") shift) ((",") reduce 424) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 424) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 424) ((T_LOGICAL_OR) reduce 424) ((T_LOGICAL_XOR) reduce 424) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 1189 ((("%") shift) ((")") reduce 425) (("*") shift) (("+") shift) ((",") reduce 425) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 425) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 425) ((T_LOGICAL_OR) reduce 425) ((T_LOGICAL_XOR) reduce 425) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 1190 ((("%") shift) ((")") reduce 418) (("*") shift) (("+") shift) ((",") reduce 418) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 418) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_BOOLEAN_AND) reduce 418) ((T_BOOLEAN_OR) reduce 418) ((T_COALESCE) reduce 418) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 418) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 418) ((T_IS_NOT_EQUAL) reduce 418) ((T_IS_NOT_IDENTICAL) reduce 418) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 418) ((T_LOGICAL_OR) reduce 418) ((T_LOGICAL_XOR) reduce 418) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 418) ((T_SR) shift) (("^") reduce 418) (("|") reduce 418)) 1191 ((("%") shift) ((")") reduce 416) (("*") shift) (("+") shift) ((",") reduce 416) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 416) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_BOOLEAN_AND) reduce 416) ((T_BOOLEAN_OR) reduce 416) ((T_COALESCE) reduce 416) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 416) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 416) ((T_IS_NOT_EQUAL) reduce 416) ((T_IS_NOT_IDENTICAL) reduce 416) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 416) ((T_LOGICAL_OR) reduce 416) ((T_LOGICAL_XOR) reduce 416) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 416) ((T_SR) shift) (("^") reduce 416) (("|") reduce 416)) 1192 ((("%") reduce 404) ((")") reduce 404) (("*") reduce 404) (("+") reduce 404) ((",") reduce 404) (("-") reduce 404) ((".") reduce 404) (("/") reduce 404) (("<") reduce 404) ((">") reduce 404) (("?") reduce 404) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_BOOLEAN_AND) reduce 404) ((T_BOOLEAN_OR) reduce 404) ((T_COALESCE) reduce 404) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 404) ((T_IS_GREATER_OR_EQUAL) reduce 404) ((T_IS_IDENTICAL) reduce 404) ((T_IS_NOT_EQUAL) reduce 404) ((T_IS_NOT_IDENTICAL) reduce 404) ((T_IS_SMALLER_OR_EQUAL) reduce 404) ((T_LOGICAL_AND) reduce 404) ((T_LOGICAL_OR) reduce 404) ((T_LOGICAL_XOR) reduce 404) ((T_POW) shift) ((T_SL) reduce 404) ((T_SPACESHIP) reduce 404) ((T_SR) reduce 404) (("^") reduce 404) (("|") reduce 404)) 1193 ((("%") shift) ((")") reduce 399) (("*") shift) (("+") shift) ((",") reduce 399) (("-") shift) ((".") reduce 399) (("/") shift) (("<") reduce 399) ((">") reduce 399) (("?") reduce 399) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_BOOLEAN_AND) reduce 399) ((T_BOOLEAN_OR) reduce 399) ((T_COALESCE) reduce 399) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 399) ((T_IS_GREATER_OR_EQUAL) reduce 399) ((T_IS_IDENTICAL) reduce 399) ((T_IS_NOT_EQUAL) reduce 399) ((T_IS_NOT_IDENTICAL) reduce 399) ((T_IS_SMALLER_OR_EQUAL) reduce 399) ((T_LOGICAL_AND) reduce 399) ((T_LOGICAL_OR) reduce 399) ((T_LOGICAL_XOR) reduce 399) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 399) ((T_SR) shift) (("^") reduce 399) (("|") reduce 399)) 1194 ((("%") shift) ((")") reduce 401) (("*") shift) (("+") reduce 401) ((",") reduce 401) (("-") reduce 401) ((".") reduce 401) (("/") shift) (("<") reduce 401) ((">") reduce 401) (("?") reduce 401) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_BOOLEAN_AND) reduce 401) ((T_BOOLEAN_OR) reduce 401) ((T_COALESCE) reduce 401) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 401) ((T_IS_GREATER_OR_EQUAL) reduce 401) ((T_IS_IDENTICAL) reduce 401) ((T_IS_NOT_EQUAL) reduce 401) ((T_IS_NOT_IDENTICAL) reduce 401) ((T_IS_SMALLER_OR_EQUAL) reduce 401) ((T_LOGICAL_AND) reduce 401) ((T_LOGICAL_OR) reduce 401) ((T_LOGICAL_XOR) reduce 401) ((T_POW) shift) ((T_SL) reduce 401) ((T_SPACESHIP) reduce 401) ((T_SR) reduce 401) (("^") reduce 401) (("|") reduce 401)) 1195 ((("%") shift) ((")") reduce 400) (("*") shift) (("+") reduce 400) ((",") reduce 400) (("-") reduce 400) ((".") reduce 400) (("/") shift) (("<") reduce 400) ((">") reduce 400) (("?") reduce 400) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_BOOLEAN_AND) reduce 400) ((T_BOOLEAN_OR) reduce 400) ((T_COALESCE) reduce 400) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 400) ((T_IS_GREATER_OR_EQUAL) reduce 400) ((T_IS_IDENTICAL) reduce 400) ((T_IS_NOT_EQUAL) reduce 400) ((T_IS_NOT_IDENTICAL) reduce 400) ((T_IS_SMALLER_OR_EQUAL) reduce 400) ((T_LOGICAL_AND) reduce 400) ((T_LOGICAL_OR) reduce 400) ((T_LOGICAL_XOR) reduce 400) ((T_POW) shift) ((T_SL) reduce 400) ((T_SPACESHIP) reduce 400) ((T_SR) reduce 400) (("^") reduce 400) (("|") reduce 400)) 1196 ((("%") reduce 402) ((")") reduce 402) (("*") reduce 402) (("+") reduce 402) ((",") reduce 402) (("-") reduce 402) ((".") reduce 402) (("/") reduce 402) (("<") reduce 402) ((">") reduce 402) (("?") reduce 402) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_BOOLEAN_AND) reduce 402) ((T_BOOLEAN_OR) reduce 402) ((T_COALESCE) reduce 402) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 402) ((T_IS_GREATER_OR_EQUAL) reduce 402) ((T_IS_IDENTICAL) reduce 402) ((T_IS_NOT_EQUAL) reduce 402) ((T_IS_NOT_IDENTICAL) reduce 402) ((T_IS_SMALLER_OR_EQUAL) reduce 402) ((T_LOGICAL_AND) reduce 402) ((T_LOGICAL_OR) reduce 402) ((T_LOGICAL_XOR) reduce 402) ((T_POW) shift) ((T_SL) reduce 402) ((T_SPACESHIP) reduce 402) ((T_SR) reduce 402) (("^") reduce 402) (("|") reduce 402)) 1197 ((("%") reduce 405) ((")") reduce 405) (("*") reduce 405) (("+") reduce 405) ((",") reduce 405) (("-") reduce 405) ((".") reduce 405) (("/") reduce 405) (("<") reduce 405) ((">") reduce 405) (("?") reduce 405) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_BOOLEAN_AND) reduce 405) ((T_BOOLEAN_OR) reduce 405) ((T_COALESCE) reduce 405) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 405) ((T_IS_GREATER_OR_EQUAL) reduce 405) ((T_IS_IDENTICAL) reduce 405) ((T_IS_NOT_EQUAL) reduce 405) ((T_IS_NOT_IDENTICAL) reduce 405) ((T_IS_SMALLER_OR_EQUAL) reduce 405) ((T_LOGICAL_AND) reduce 405) ((T_LOGICAL_OR) reduce 405) ((T_LOGICAL_XOR) reduce 405) ((T_POW) shift) ((T_SL) reduce 405) ((T_SPACESHIP) reduce 405) ((T_SR) reduce 405) (("^") reduce 405) (("|") reduce 405)) 1208 ((("%") reduce 502) ((")") reduce 502) (("*") reduce 502) (("+") reduce 502) ((",") reduce 502) (("-") reduce 502) ((".") reduce 502) (("/") reduce 502) (("<") reduce 502) ((">") reduce 502) (("?") reduce 502) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_BOOLEAN_AND) reduce 502) ((T_BOOLEAN_OR) reduce 502) ((T_COALESCE) reduce 502) ((T_DOUBLE_ARROW) reduce 502) ((T_INSTANCEOF) reduce 502) ((T_IS_EQUAL) reduce 502) ((T_IS_GREATER_OR_EQUAL) reduce 502) ((T_IS_IDENTICAL) reduce 502) ((T_IS_NOT_EQUAL) reduce 502) ((T_IS_NOT_IDENTICAL) reduce 502) ((T_IS_SMALLER_OR_EQUAL) reduce 502) ((T_LOGICAL_AND) reduce 502) ((T_LOGICAL_OR) reduce 502) ((T_LOGICAL_XOR) reduce 502) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 502) ((T_OBJECT_OPERATOR) reduce 502) ((T_POW) reduce 502) ((T_SL) reduce 502) ((T_SPACESHIP) reduce 502) ((T_SR) reduce 502) (("[") reduce 502) (("^") reduce 502) (("{") reduce 502) (("|") reduce 502)) 1210 ((("%") reduce 484) (("(") reduce 484) ((")") reduce 484) (("*") reduce 484) (("+") reduce 484) ((",") reduce 484) (("-") reduce 484) ((".") reduce 484) (("/") reduce 484) (("<") reduce 484) ((">") reduce 484) (("?") reduce 484) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_BOOLEAN_AND) reduce 484) ((T_BOOLEAN_OR) reduce 484) ((T_COALESCE) reduce 484) ((T_DOUBLE_ARROW) reduce 484) ((T_INSTANCEOF) reduce 484) ((T_IS_EQUAL) reduce 484) ((T_IS_GREATER_OR_EQUAL) reduce 484) ((T_IS_IDENTICAL) reduce 484) ((T_IS_NOT_EQUAL) reduce 484) ((T_IS_NOT_IDENTICAL) reduce 484) ((T_IS_SMALLER_OR_EQUAL) reduce 484) ((T_LOGICAL_AND) reduce 484) ((T_LOGICAL_OR) reduce 484) ((T_LOGICAL_XOR) reduce 484) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 484) ((T_OBJECT_OPERATOR) reduce 484) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 484) ((T_POW) reduce 484) ((T_SL) reduce 484) ((T_SPACESHIP) reduce 484) ((T_SR) reduce 484) (("[") reduce 484) (("^") reduce 484) (("{") reduce 484) (("|") reduce 484)) 1212 ((("%") reduce 497) ((")") reduce 497) (("*") reduce 497) (("+") reduce 497) ((",") reduce 497) (("-") reduce 497) ((".") reduce 497) (("/") reduce 497) (("<") reduce 497) ((">") reduce 497) (("?") reduce 497) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_BOOLEAN_AND) reduce 497) ((T_BOOLEAN_OR) reduce 497) ((T_COALESCE) reduce 497) ((T_DOUBLE_ARROW) reduce 497) ((T_INSTANCEOF) reduce 497) ((T_IS_EQUAL) reduce 497) ((T_IS_GREATER_OR_EQUAL) reduce 497) ((T_IS_IDENTICAL) reduce 497) ((T_IS_NOT_EQUAL) reduce 497) ((T_IS_NOT_IDENTICAL) reduce 497) ((T_IS_SMALLER_OR_EQUAL) reduce 497) ((T_LOGICAL_AND) reduce 497) ((T_LOGICAL_OR) reduce 497) ((T_LOGICAL_XOR) reduce 497) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 497) ((T_OBJECT_OPERATOR) reduce 497) ((T_POW) reduce 497) ((T_SL) reduce 497) ((T_SPACESHIP) reduce 497) ((T_SR) reduce 497) (("[") reduce 497) (("^") reduce 497) (("{") reduce 497) (("|") reduce 497)) 1213 ((("%") reduce 487) ((")") reduce 487) (("*") reduce 487) (("+") reduce 487) ((",") reduce 487) (("-") reduce 487) ((".") reduce 487) (("/") reduce 487) (("<") reduce 487) ((">") reduce 487) (("?") reduce 487) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_BOOLEAN_AND) reduce 487) ((T_BOOLEAN_OR) reduce 487) ((T_COALESCE) reduce 487) ((T_DOUBLE_ARROW) reduce 487) ((T_INSTANCEOF) reduce 487) ((T_IS_EQUAL) reduce 487) ((T_IS_GREATER_OR_EQUAL) reduce 487) ((T_IS_IDENTICAL) reduce 487) ((T_IS_NOT_EQUAL) reduce 487) ((T_IS_NOT_IDENTICAL) reduce 487) ((T_IS_SMALLER_OR_EQUAL) reduce 487) ((T_LOGICAL_AND) reduce 487) ((T_LOGICAL_OR) reduce 487) ((T_LOGICAL_XOR) reduce 487) ((T_POW) reduce 487) ((T_SL) reduce 487) ((T_SPACESHIP) reduce 487) ((T_SR) reduce 487) (("^") reduce 487) (("|") reduce 487)) 1217 ((("%") reduce 475) (("(") shift) ((")") reduce 475) (("*") reduce 475) (("+") reduce 475) ((",") reduce 475) (("-") reduce 475) ((".") reduce 475) (("/") reduce 475) (("<") reduce 475) ((">") reduce 475) (("?") reduce 475) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_BOOLEAN_AND) reduce 475) ((T_BOOLEAN_OR) reduce 475) ((T_COALESCE) reduce 475) ((T_DOUBLE_ARROW) reduce 475) ((T_INSTANCEOF) reduce 475) ((T_IS_EQUAL) reduce 475) ((T_IS_GREATER_OR_EQUAL) reduce 475) ((T_IS_IDENTICAL) reduce 475) ((T_IS_NOT_EQUAL) reduce 475) ((T_IS_NOT_IDENTICAL) reduce 475) ((T_IS_SMALLER_OR_EQUAL) reduce 475) ((T_LOGICAL_AND) reduce 475) ((T_LOGICAL_OR) reduce 475) ((T_LOGICAL_XOR) reduce 475) ((T_POW) reduce 475) ((T_SL) reduce 475) ((T_SPACESHIP) reduce 475) ((T_SR) reduce 475) (("^") reduce 475) (("|") reduce 475)) 1218 ((("%") reduce 496) ((")") reduce 496) (("*") reduce 496) (("+") reduce 496) ((",") reduce 496) (("-") reduce 496) ((".") reduce 496) (("/") reduce 496) (("<") reduce 496) ((">") reduce 496) (("?") reduce 496) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_BOOLEAN_AND) reduce 496) ((T_BOOLEAN_OR) reduce 496) ((T_COALESCE) reduce 496) ((T_DOUBLE_ARROW) reduce 496) ((T_INSTANCEOF) reduce 496) ((T_IS_EQUAL) reduce 496) ((T_IS_GREATER_OR_EQUAL) reduce 496) ((T_IS_IDENTICAL) reduce 496) ((T_IS_NOT_EQUAL) reduce 496) ((T_IS_NOT_IDENTICAL) reduce 496) ((T_IS_SMALLER_OR_EQUAL) reduce 496) ((T_LOGICAL_AND) reduce 496) ((T_LOGICAL_OR) reduce 496) ((T_LOGICAL_XOR) reduce 496) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 496) ((T_OBJECT_OPERATOR) reduce 496) ((T_POW) reduce 496) ((T_SL) reduce 496) ((T_SPACESHIP) reduce 496) ((T_SR) reduce 496) (("[") reduce 496) (("^") reduce 496) (("{") reduce 496) (("|") reduce 496)) 1219 ((("%") reduce 500) ((")") reduce 500) (("*") reduce 500) (("+") reduce 500) ((",") reduce 500) (("-") reduce 500) ((".") reduce 500) (("/") reduce 500) (("<") reduce 500) ((">") reduce 500) (("?") reduce 500) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_BOOLEAN_AND) reduce 500) ((T_BOOLEAN_OR) reduce 500) ((T_COALESCE) reduce 500) ((T_DOUBLE_ARROW) reduce 500) ((T_INSTANCEOF) reduce 500) ((T_IS_EQUAL) reduce 500) ((T_IS_GREATER_OR_EQUAL) reduce 500) ((T_IS_IDENTICAL) reduce 500) ((T_IS_NOT_EQUAL) reduce 500) ((T_IS_NOT_IDENTICAL) reduce 500) ((T_IS_SMALLER_OR_EQUAL) reduce 500) ((T_LOGICAL_AND) reduce 500) ((T_LOGICAL_OR) reduce 500) ((T_LOGICAL_XOR) reduce 500) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 500) ((T_OBJECT_OPERATOR) reduce 500) ((T_POW) reduce 500) ((T_SL) reduce 500) ((T_SPACESHIP) reduce 500) ((T_SR) reduce 500) (("[") reduce 500) (("^") reduce 500) (("{") reduce 500) (("|") reduce 500)) 1225 ((("%") reduce 495) ((")") reduce 495) (("*") reduce 495) (("+") reduce 495) ((",") reduce 495) (("-") reduce 495) ((".") reduce 495) (("/") reduce 495) (("<") reduce 495) ((">") reduce 495) (("?") reduce 495) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_BOOLEAN_AND) reduce 495) ((T_BOOLEAN_OR) reduce 495) ((T_COALESCE) reduce 495) ((T_DOUBLE_ARROW) reduce 495) ((T_INSTANCEOF) reduce 495) ((T_IS_EQUAL) reduce 495) ((T_IS_GREATER_OR_EQUAL) reduce 495) ((T_IS_IDENTICAL) reduce 495) ((T_IS_NOT_EQUAL) reduce 495) ((T_IS_NOT_IDENTICAL) reduce 495) ((T_IS_SMALLER_OR_EQUAL) reduce 495) ((T_LOGICAL_AND) reduce 495) ((T_LOGICAL_OR) reduce 495) ((T_LOGICAL_XOR) reduce 495) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 495) ((T_OBJECT_OPERATOR) reduce 495) ((T_POW) reduce 495) ((T_SL) reduce 495) ((T_SPACESHIP) reduce 495) ((T_SR) reduce 495) (("[") reduce 495) (("^") reduce 495) (("{") reduce 495) (("|") reduce 495)) 1227 ((("%") reduce 486) ((")") reduce 486) (("*") reduce 486) (("+") reduce 486) ((",") reduce 486) (("-") reduce 486) ((".") reduce 486) (("/") reduce 486) (("<") reduce 486) ((">") reduce 486) (("?") reduce 486) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_BOOLEAN_AND) reduce 486) ((T_BOOLEAN_OR) reduce 486) ((T_COALESCE) reduce 486) ((T_DOUBLE_ARROW) reduce 486) ((T_INSTANCEOF) reduce 486) ((T_IS_EQUAL) reduce 486) ((T_IS_GREATER_OR_EQUAL) reduce 486) ((T_IS_IDENTICAL) reduce 486) ((T_IS_NOT_EQUAL) reduce 486) ((T_IS_NOT_IDENTICAL) reduce 486) ((T_IS_SMALLER_OR_EQUAL) reduce 486) ((T_LOGICAL_AND) reduce 486) ((T_LOGICAL_OR) reduce 486) ((T_LOGICAL_XOR) reduce 486) ((T_POW) reduce 486) ((T_SL) reduce 486) ((T_SPACESHIP) reduce 486) ((T_SR) reduce 486) (("^") reduce 486) (("|") reduce 486)) 1229 ((("%") reduce 499) ((")") reduce 499) (("*") reduce 499) (("+") reduce 499) ((",") reduce 499) (("-") reduce 499) ((".") reduce 499) (("/") reduce 499) (("<") reduce 499) ((">") reduce 499) (("?") reduce 499) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_BOOLEAN_AND) reduce 499) ((T_BOOLEAN_OR) reduce 499) ((T_COALESCE) reduce 499) ((T_DOUBLE_ARROW) reduce 499) ((T_INSTANCEOF) reduce 499) ((T_IS_EQUAL) reduce 499) ((T_IS_GREATER_OR_EQUAL) reduce 499) ((T_IS_IDENTICAL) reduce 499) ((T_IS_NOT_EQUAL) reduce 499) ((T_IS_NOT_IDENTICAL) reduce 499) ((T_IS_SMALLER_OR_EQUAL) reduce 499) ((T_LOGICAL_AND) reduce 499) ((T_LOGICAL_OR) reduce 499) ((T_LOGICAL_XOR) reduce 499) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 499) ((T_OBJECT_OPERATOR) reduce 499) ((T_POW) reduce 499) ((T_SL) reduce 499) ((T_SPACESHIP) reduce 499) ((T_SR) reduce 499) (("[") reduce 499) (("^") reduce 499) (("{") reduce 499) (("|") reduce 499)) 1230 ((("%") reduce 93) (("(") reduce 93) ((")") reduce 93) (("*") reduce 93) (("+") reduce 93) ((",") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 93) ((T_OBJECT_OPERATOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("[") reduce 93) (("^") reduce 93) (("{") reduce 93) (("|") reduce 93)) 1231 ((("%") reduce 92) (("(") reduce 92) ((")") reduce 92) (("*") reduce 92) (("+") reduce 92) ((",") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 92) ((T_OBJECT_OPERATOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("[") reduce 92) (("^") reduce 92) (("{") reduce 92) (("|") reduce 92)) 1232 ((("%") reduce 94) (("(") reduce 94) ((")") reduce 94) (("*") reduce 94) (("+") reduce 94) ((",") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 94) ((T_OBJECT_OPERATOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("[") reduce 94) (("^") reduce 94) (("{") reduce 94) (("|") reduce 94)) 1234 ((("%") reduce 501) ((")") reduce 501) (("*") reduce 501) (("+") reduce 501) ((",") reduce 501) (("-") reduce 501) ((".") reduce 501) (("/") reduce 501) (("<") reduce 501) ((">") reduce 501) (("?") reduce 501) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_BOOLEAN_AND) reduce 501) ((T_BOOLEAN_OR) reduce 501) ((T_COALESCE) reduce 501) ((T_DOUBLE_ARROW) reduce 501) ((T_INSTANCEOF) reduce 501) ((T_IS_EQUAL) reduce 501) ((T_IS_GREATER_OR_EQUAL) reduce 501) ((T_IS_IDENTICAL) reduce 501) ((T_IS_NOT_EQUAL) reduce 501) ((T_IS_NOT_IDENTICAL) reduce 501) ((T_IS_SMALLER_OR_EQUAL) reduce 501) ((T_LOGICAL_AND) reduce 501) ((T_LOGICAL_OR) reduce 501) ((T_LOGICAL_XOR) reduce 501) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 501) ((T_OBJECT_OPERATOR) reduce 501) ((T_POW) reduce 501) ((T_SL) reduce 501) ((T_SPACESHIP) reduce 501) ((T_SR) reduce 501) (("[") reduce 501) (("^") reduce 501) (("{") reduce 501) (("|") reduce 501)) 1242 ((("%") reduce 91) (("(") reduce 91) ((")") reduce 91) (("*") reduce 91) (("+") reduce 91) ((",") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 91) ((T_OBJECT_OPERATOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("[") reduce 91) (("^") reduce 91) (("{") reduce 91) (("|") reduce 91)) 1245 ((("%") reduce 498) ((")") reduce 498) (("*") reduce 498) (("+") reduce 498) ((",") reduce 498) (("-") reduce 498) ((".") reduce 498) (("/") reduce 498) (("<") reduce 498) ((">") reduce 498) (("?") reduce 498) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_BOOLEAN_AND) reduce 498) ((T_BOOLEAN_OR) reduce 498) ((T_COALESCE) reduce 498) ((T_DOUBLE_ARROW) reduce 498) ((T_INSTANCEOF) reduce 498) ((T_IS_EQUAL) reduce 498) ((T_IS_GREATER_OR_EQUAL) reduce 498) ((T_IS_IDENTICAL) reduce 498) ((T_IS_NOT_EQUAL) reduce 498) ((T_IS_NOT_IDENTICAL) reduce 498) ((T_IS_SMALLER_OR_EQUAL) reduce 498) ((T_LOGICAL_AND) reduce 498) ((T_LOGICAL_OR) reduce 498) ((T_LOGICAL_XOR) reduce 498) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 498) ((T_OBJECT_OPERATOR) reduce 498) ((T_POW) reduce 498) ((T_SL) reduce 498) ((T_SPACESHIP) reduce 498) ((T_SR) reduce 498) (("[") reduce 498) (("^") reduce 498) (("{") reduce 498) (("|") reduce 498)) 1247 ((("%") reduce 529) (("(") reduce 529) ((")") reduce 529) (("*") reduce 529) (("+") reduce 529) ((",") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) (("=") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AND_EQUAL) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_COALESCE_EQUAL) reduce 529) ((T_CONCAT_EQUAL) reduce 529) ((T_DEC) reduce 529) ((T_DIV_EQUAL) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INC) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_MINUS_EQUAL) reduce 529) ((T_MOD_EQUAL) reduce 529) ((T_MUL_EQUAL) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_OR_EQUAL) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_PLUS_EQUAL) reduce 529) ((T_POW) reduce 529) ((T_POW_EQUAL) reduce 529) ((T_SL) reduce 529) ((T_SL_EQUAL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) ((T_SR_EQUAL) reduce 529) ((T_XOR_EQUAL) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 1248 ((("!") shift) (("\"") shift) (("$") shift) (("%") reduce 440) (("(") shift) ((")") reduce 440) (("*") reduce 440) (("+") shift) ((",") reduce 440) (("-") shift) ((".") reduce 440) (("/") reduce 440) (("<") reduce 440) ((">") reduce 440) (("?") reduce 440) (("@") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOLEAN_AND) reduce 440) ((T_BOOLEAN_OR) reduce 440) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_COALESCE) reduce 440) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_ARROW) reduce 440) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INSTANCEOF) reduce 440) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_IS_EQUAL) reduce 440) ((T_IS_GREATER_OR_EQUAL) reduce 440) ((T_IS_IDENTICAL) reduce 440) ((T_IS_NOT_EQUAL) reduce 440) ((T_IS_NOT_IDENTICAL) reduce 440) ((T_IS_SMALLER_OR_EQUAL) reduce 440) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_LOGICAL_AND) reduce 440) ((T_LOGICAL_OR) reduce 440) ((T_LOGICAL_XOR) reduce 440) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_POW) reduce 440) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_SL) reduce 440) ((T_SPACESHIP) reduce 440) ((T_SR) reduce 440) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("^") reduce 440) (("`") shift) (("|") reduce 440) (("~") shift)) 1255 ((("%") reduce 525) (("(") reduce 516) ((")") reduce 525) (("*") reduce 525) (("+") reduce 525) ((",") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) (("<") reduce 525) (("=") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AND_EQUAL) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_COALESCE_EQUAL) reduce 525) ((T_CONCAT_EQUAL) reduce 525) ((T_DEC) reduce 525) ((T_DIV_EQUAL) reduce 525) ((T_DOUBLE_ARROW) reduce 525) ((T_INC) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_MINUS_EQUAL) reduce 525) ((T_MOD_EQUAL) reduce 525) ((T_MUL_EQUAL) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_OR_EQUAL) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_PLUS_EQUAL) reduce 525) ((T_POW) reduce 525) ((T_POW_EQUAL) reduce 525) ((T_SL) reduce 525) ((T_SL_EQUAL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) ((T_SR_EQUAL) reduce 525) ((T_XOR_EQUAL) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 1256 ((("%") reduce 493) ((")") reduce 493) (("*") reduce 493) (("+") reduce 493) ((",") reduce 493) (("-") reduce 493) ((".") reduce 493) (("/") reduce 493) (("<") reduce 493) ((">") reduce 493) (("?") reduce 493) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_BOOLEAN_AND) reduce 493) ((T_BOOLEAN_OR) reduce 493) ((T_COALESCE) reduce 493) ((T_DOUBLE_ARROW) reduce 493) ((T_INSTANCEOF) reduce 493) ((T_IS_EQUAL) reduce 493) ((T_IS_GREATER_OR_EQUAL) reduce 493) ((T_IS_IDENTICAL) reduce 493) ((T_IS_NOT_EQUAL) reduce 493) ((T_IS_NOT_IDENTICAL) reduce 493) ((T_IS_SMALLER_OR_EQUAL) reduce 493) ((T_LOGICAL_AND) reduce 493) ((T_LOGICAL_OR) reduce 493) ((T_LOGICAL_XOR) reduce 493) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 513) ((T_OBJECT_OPERATOR) reduce 513) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 513) ((T_POW) reduce 493) ((T_SL) reduce 493) ((T_SPACESHIP) reduce 493) ((T_SR) reduce 493) (("[") reduce 513) (("^") reduce 493) (("{") reduce 513) (("|") reduce 493)) 1258 ((("%") reduce 492) ((")") reduce 492) (("*") reduce 492) (("+") reduce 492) ((",") reduce 492) (("-") reduce 492) ((".") reduce 492) (("/") reduce 492) (("<") reduce 492) ((">") reduce 492) (("?") reduce 492) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_BOOLEAN_AND) reduce 492) ((T_BOOLEAN_OR) reduce 492) ((T_COALESCE) reduce 492) ((T_DOUBLE_ARROW) reduce 492) ((T_INSTANCEOF) reduce 492) ((T_IS_EQUAL) reduce 492) ((T_IS_GREATER_OR_EQUAL) reduce 492) ((T_IS_IDENTICAL) reduce 492) ((T_IS_NOT_EQUAL) reduce 492) ((T_IS_NOT_IDENTICAL) reduce 492) ((T_IS_SMALLER_OR_EQUAL) reduce 492) ((T_LOGICAL_AND) reduce 492) ((T_LOGICAL_OR) reduce 492) ((T_LOGICAL_XOR) reduce 492) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 515) ((T_OBJECT_OPERATOR) reduce 515) ((T_POW) reduce 492) ((T_SL) reduce 492) ((T_SPACESHIP) reduce 492) ((T_SR) reduce 492) (("[") reduce 515) (("^") reduce 492) (("{") reduce 515) (("|") reduce 492)) 1259 ((("%") reduce 491) (("(") reduce 518) ((")") reduce 491) (("*") reduce 491) (("+") reduce 491) ((",") reduce 491) (("-") reduce 491) ((".") reduce 491) (("/") reduce 491) (("<") reduce 491) ((">") reduce 491) (("?") reduce 491) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_BOOLEAN_AND) reduce 491) ((T_BOOLEAN_OR) reduce 491) ((T_COALESCE) reduce 491) ((T_DOUBLE_ARROW) reduce 491) ((T_INSTANCEOF) reduce 491) ((T_IS_EQUAL) reduce 491) ((T_IS_GREATER_OR_EQUAL) reduce 491) ((T_IS_IDENTICAL) reduce 491) ((T_IS_NOT_EQUAL) reduce 491) ((T_IS_NOT_IDENTICAL) reduce 491) ((T_IS_SMALLER_OR_EQUAL) reduce 491) ((T_LOGICAL_AND) reduce 491) ((T_LOGICAL_OR) reduce 491) ((T_LOGICAL_XOR) reduce 491) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 512) ((T_OBJECT_OPERATOR) reduce 512) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 512) ((T_POW) reduce 491) ((T_SL) reduce 491) ((T_SPACESHIP) reduce 491) ((T_SR) reduce 491) (("[") reduce 512) (("^") reduce 491) (("{") reduce 512) (("|") reduce 491)) 1260 ((("%") shift) ((")") reduce 441) (("*") shift) (("+") shift) ((",") reduce 441) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 441) ((T_LOGICAL_OR) reduce 441) ((T_LOGICAL_XOR) reduce 441) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 1263 ((("%") reduce 524) (("(") reduce 524) ((")") reduce 524) (("*") reduce 524) (("+") reduce 524) ((",") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) (("<") reduce 524) (("=") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AND_EQUAL) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_COALESCE_EQUAL) reduce 524) ((T_CONCAT_EQUAL) reduce 524) ((T_DEC) reduce 524) ((T_DIV_EQUAL) reduce 524) ((T_DOUBLE_ARROW) reduce 524) ((T_INC) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_MINUS_EQUAL) reduce 524) ((T_MOD_EQUAL) reduce 524) ((T_MUL_EQUAL) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_OR_EQUAL) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_PLUS_EQUAL) reduce 524) ((T_POW) reduce 524) ((T_POW_EQUAL) reduce 524) ((T_SL) reduce 524) ((T_SL_EQUAL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) ((T_SR_EQUAL) reduce 524) ((T_XOR_EQUAL) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 1264 ((("%") reduce 445) ((")") reduce 445) (("*") reduce 445) (("+") reduce 445) ((",") reduce 445) (("-") reduce 445) ((".") reduce 445) (("/") reduce 445) (("<") reduce 445) ((">") reduce 445) (("?") reduce 445) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_BOOLEAN_AND) reduce 445) ((T_BOOLEAN_OR) reduce 445) ((T_COALESCE) reduce 445) ((T_DOUBLE_ARROW) reduce 445) ((T_INSTANCEOF) reduce 445) ((T_IS_EQUAL) reduce 445) ((T_IS_GREATER_OR_EQUAL) reduce 445) ((T_IS_IDENTICAL) reduce 445) ((T_IS_NOT_EQUAL) reduce 445) ((T_IS_NOT_IDENTICAL) reduce 445) ((T_IS_SMALLER_OR_EQUAL) reduce 445) ((T_LOGICAL_AND) reduce 445) ((T_LOGICAL_OR) reduce 445) ((T_LOGICAL_XOR) reduce 445) ((T_POW) reduce 445) ((T_SL) reduce 445) ((T_SPACESHIP) reduce 445) ((T_SR) reduce 445) (("^") reduce 445) (("|") reduce 445)) 1265 ((("%") reduce 427) ((")") reduce 427) (("*") reduce 427) (("+") reduce 427) ((",") reduce 427) (("-") reduce 427) ((".") reduce 427) (("/") reduce 427) (("<") reduce 427) ((">") reduce 427) (("?") reduce 427) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_BOOLEAN_AND) reduce 427) ((T_BOOLEAN_OR) reduce 427) ((T_COALESCE) reduce 427) ((T_DOUBLE_ARROW) reduce 427) ((T_INSTANCEOF) reduce 427) ((T_IS_EQUAL) reduce 427) ((T_IS_GREATER_OR_EQUAL) reduce 427) ((T_IS_IDENTICAL) reduce 427) ((T_IS_NOT_EQUAL) reduce 427) ((T_IS_NOT_IDENTICAL) reduce 427) ((T_IS_SMALLER_OR_EQUAL) reduce 427) ((T_LOGICAL_AND) reduce 427) ((T_LOGICAL_OR) reduce 427) ((T_LOGICAL_XOR) reduce 427) ((T_POW) reduce 427) ((T_SL) reduce 427) ((T_SPACESHIP) reduce 427) ((T_SR) reduce 427) (("^") reduce 427) (("|") reduce 427)) 1266 ((("%") reduce 449) ((")") reduce 449) (("*") reduce 449) (("+") reduce 449) ((",") reduce 449) (("-") reduce 449) ((".") reduce 449) (("/") reduce 449) (("<") reduce 449) ((">") reduce 449) (("?") reduce 449) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_BOOLEAN_AND) reduce 449) ((T_BOOLEAN_OR) reduce 449) ((T_COALESCE) reduce 449) ((T_DOUBLE_ARROW) reduce 449) ((T_INSTANCEOF) reduce 449) ((T_IS_EQUAL) reduce 449) ((T_IS_GREATER_OR_EQUAL) reduce 449) ((T_IS_IDENTICAL) reduce 449) ((T_IS_NOT_EQUAL) reduce 449) ((T_IS_NOT_IDENTICAL) reduce 449) ((T_IS_SMALLER_OR_EQUAL) reduce 449) ((T_LOGICAL_AND) reduce 449) ((T_LOGICAL_OR) reduce 449) ((T_LOGICAL_XOR) reduce 449) ((T_POW) reduce 449) ((T_SL) reduce 449) ((T_SPACESHIP) reduce 449) ((T_SR) reduce 449) (("^") reduce 449) (("|") reduce 449)) 1267 ((("%") reduce 494) (("(") shift) ((")") reduce 494) (("*") reduce 494) (("+") reduce 494) ((",") reduce 494) (("-") reduce 494) ((".") reduce 494) (("/") reduce 494) (("<") reduce 494) ((">") reduce 494) (("?") reduce 494) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_BOOLEAN_AND) reduce 494) ((T_BOOLEAN_OR) reduce 494) ((T_COALESCE) reduce 494) ((T_DOUBLE_ARROW) reduce 494) ((T_INSTANCEOF) reduce 494) ((T_IS_EQUAL) reduce 494) ((T_IS_GREATER_OR_EQUAL) reduce 494) ((T_IS_IDENTICAL) reduce 494) ((T_IS_NOT_EQUAL) reduce 494) ((T_IS_NOT_IDENTICAL) reduce 494) ((T_IS_SMALLER_OR_EQUAL) reduce 494) ((T_LOGICAL_AND) reduce 494) ((T_LOGICAL_OR) reduce 494) ((T_LOGICAL_XOR) reduce 494) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 494) ((T_OBJECT_OPERATOR) reduce 494) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 494) ((T_SL) reduce 494) ((T_SPACESHIP) reduce 494) ((T_SR) reduce 494) (("[") reduce 494) (("^") reduce 494) (("{") reduce 494) (("|") reduce 494)) 1268 ((("%") reduce 423) ((")") reduce 423) (("*") reduce 423) (("+") reduce 423) ((",") reduce 423) (("-") reduce 423) ((".") reduce 423) (("/") reduce 423) (("<") reduce 423) ((">") reduce 423) (("?") reduce 423) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_BOOLEAN_AND) reduce 423) ((T_BOOLEAN_OR) reduce 423) ((T_COALESCE) reduce 423) ((T_DOUBLE_ARROW) reduce 423) ((T_INSTANCEOF) reduce 423) ((T_IS_EQUAL) reduce 423) ((T_IS_GREATER_OR_EQUAL) reduce 423) ((T_IS_IDENTICAL) reduce 423) ((T_IS_NOT_EQUAL) reduce 423) ((T_IS_NOT_IDENTICAL) reduce 423) ((T_IS_SMALLER_OR_EQUAL) reduce 423) ((T_LOGICAL_AND) reduce 423) ((T_LOGICAL_OR) reduce 423) ((T_LOGICAL_XOR) reduce 423) ((T_POW) reduce 423) ((T_SL) reduce 423) ((T_SPACESHIP) reduce 423) ((T_SR) reduce 423) (("^") reduce 423) (("|") reduce 423)) 1269 ((("%") reduce 437) ((")") reduce 437) (("*") reduce 437) (("+") reduce 437) ((",") reduce 437) (("-") reduce 437) ((".") reduce 437) (("/") reduce 437) (("<") reduce 437) ((">") reduce 437) (("?") reduce 437) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_BOOLEAN_AND) reduce 437) ((T_BOOLEAN_OR) reduce 437) ((T_COALESCE) reduce 437) ((T_DOUBLE_ARROW) reduce 437) ((T_INSTANCEOF) reduce 437) ((T_IS_EQUAL) reduce 437) ((T_IS_GREATER_OR_EQUAL) reduce 437) ((T_IS_IDENTICAL) reduce 437) ((T_IS_NOT_EQUAL) reduce 437) ((T_IS_NOT_IDENTICAL) reduce 437) ((T_IS_SMALLER_OR_EQUAL) reduce 437) ((T_LOGICAL_AND) reduce 437) ((T_LOGICAL_OR) reduce 437) ((T_LOGICAL_XOR) reduce 437) ((T_POW) reduce 437) ((T_SL) reduce 437) ((T_SPACESHIP) reduce 437) ((T_SR) reduce 437) (("^") reduce 437) (("|") reduce 437)) 1270 ((("%") reduce 519) (("(") reduce 519) ((")") reduce 519) (("*") reduce 519) (("+") reduce 519) ((",") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) (("<") reduce 519) (("=") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AND_EQUAL) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_COALESCE_EQUAL) reduce 519) ((T_CONCAT_EQUAL) reduce 519) ((T_DEC) reduce 519) ((T_DIV_EQUAL) reduce 519) ((T_DOUBLE_ARROW) reduce 519) ((T_INC) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_MINUS_EQUAL) reduce 519) ((T_MOD_EQUAL) reduce 519) ((T_MUL_EQUAL) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_OR_EQUAL) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_PLUS_EQUAL) reduce 519) ((T_POW) reduce 519) ((T_POW_EQUAL) reduce 519) ((T_SL) reduce 519) ((T_SL_EQUAL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) ((T_SR_EQUAL) reduce 519) ((T_XOR_EQUAL) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 1271 ((("%") reduce 526) ((")") reduce 526) (("*") reduce 526) (("+") reduce 526) ((",") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) (("<") reduce 526) (("=") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AND_EQUAL) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_COALESCE_EQUAL) reduce 526) ((T_CONCAT_EQUAL) reduce 526) ((T_DEC) reduce 526) ((T_DIV_EQUAL) reduce 526) ((T_DOUBLE_ARROW) reduce 526) ((T_INC) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_MINUS_EQUAL) reduce 526) ((T_MOD_EQUAL) reduce 526) ((T_MUL_EQUAL) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_OR_EQUAL) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_PLUS_EQUAL) reduce 526) ((T_POW) reduce 526) ((T_POW_EQUAL) reduce 526) ((T_SL) reduce 526) ((T_SL_EQUAL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) ((T_SR_EQUAL) reduce 526) ((T_XOR_EQUAL) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 1272 ((("%") reduce 367) ((")") reduce 367) (("*") reduce 367) (("+") reduce 367) ((",") reduce 367) (("-") reduce 367) ((".") reduce 367) (("/") reduce 367) (("<") reduce 367) (("=") shift) ((">") reduce 367) (("?") reduce 367) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AND_EQUAL) shift) ((T_BOOLEAN_AND) reduce 367) ((T_BOOLEAN_OR) reduce 367) ((T_COALESCE) reduce 367) ((T_COALESCE_EQUAL) shift) ((T_CONCAT_EQUAL) shift) ((T_DEC) shift) ((T_DIV_EQUAL) shift) ((T_DOUBLE_ARROW) reduce 367) ((T_INC) shift) ((T_INSTANCEOF) reduce 367) ((T_IS_EQUAL) reduce 367) ((T_IS_GREATER_OR_EQUAL) reduce 367) ((T_IS_IDENTICAL) reduce 367) ((T_IS_NOT_EQUAL) reduce 367) ((T_IS_NOT_IDENTICAL) reduce 367) ((T_IS_SMALLER_OR_EQUAL) reduce 367) ((T_LOGICAL_AND) reduce 367) ((T_LOGICAL_OR) reduce 367) ((T_LOGICAL_XOR) reduce 367) ((T_MINUS_EQUAL) shift) ((T_MOD_EQUAL) shift) ((T_MUL_EQUAL) shift) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_OR_EQUAL) shift) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_PLUS_EQUAL) shift) ((T_POW) reduce 367) ((T_POW_EQUAL) shift) ((T_SL) reduce 367) ((T_SL_EQUAL) shift) ((T_SPACESHIP) reduce 367) ((T_SR) reduce 367) ((T_SR_EQUAL) shift) ((T_XOR_EQUAL) shift) (("[") reduce 510) (("^") reduce 367) (("{") reduce 510) (("|") reduce 367)) 1275 ((("%") reduce 411) ((")") reduce 411) (("*") reduce 411) (("+") reduce 411) ((",") reduce 411) (("-") reduce 411) ((".") reduce 411) (("/") reduce 411) (("<") reduce 411) ((">") reduce 411) (("?") reduce 411) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_BOOLEAN_AND) reduce 411) ((T_BOOLEAN_OR) reduce 411) ((T_COALESCE) reduce 411) ((T_DOUBLE_ARROW) reduce 411) ((T_INSTANCEOF) reduce 411) ((T_IS_EQUAL) reduce 411) ((T_IS_GREATER_OR_EQUAL) reduce 411) ((T_IS_IDENTICAL) reduce 411) ((T_IS_NOT_EQUAL) reduce 411) ((T_IS_NOT_IDENTICAL) reduce 411) ((T_IS_SMALLER_OR_EQUAL) reduce 411) ((T_LOGICAL_AND) reduce 411) ((T_LOGICAL_OR) reduce 411) ((T_LOGICAL_XOR) reduce 411) ((T_POW) shift) ((T_SL) reduce 411) ((T_SPACESHIP) reduce 411) ((T_SR) reduce 411) (("^") reduce 411) (("|") reduce 411)) 1306 ((("%") shift) ((")") reduce 395) (("*") shift) (("+") shift) ((",") reduce 395) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 395) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 395) ((T_BOOLEAN_OR) reduce 395) ((T_COALESCE) reduce 395) ((T_DOUBLE_ARROW) reduce 395) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 395) ((T_LOGICAL_OR) reduce 395) ((T_LOGICAL_XOR) reduce 395) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") reduce 395)) 1307 ((("%") shift) ((")") reduce 398) (("*") shift) (("+") shift) ((",") reduce 398) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 398) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 398) ((T_BOOLEAN_OR) reduce 398) ((T_COALESCE) reduce 398) ((T_DOUBLE_ARROW) reduce 398) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 398) ((T_LOGICAL_OR) reduce 398) ((T_LOGICAL_XOR) reduce 398) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 398) (("|") reduce 398)) 1308 ((("%") shift) ((")") reduce 407) (("*") shift) (("+") shift) ((",") reduce 407) (("-") shift) ((".") reduce 407) (("/") shift) (("<") reduce 407) ((">") reduce 407) (("?") reduce 407) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_BOOLEAN_AND) reduce 407) ((T_BOOLEAN_OR) reduce 407) ((T_COALESCE) reduce 407) ((T_DOUBLE_ARROW) reduce 407) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 407) ((T_IS_GREATER_OR_EQUAL) reduce 407) ((T_IS_IDENTICAL) reduce 407) ((T_IS_NOT_EQUAL) reduce 407) ((T_IS_NOT_IDENTICAL) reduce 407) ((T_IS_SMALLER_OR_EQUAL) reduce 407) ((T_LOGICAL_AND) reduce 407) ((T_LOGICAL_OR) reduce 407) ((T_LOGICAL_XOR) reduce 407) ((T_POW) shift) ((T_SL) reduce 407) ((T_SPACESHIP) reduce 407) ((T_SR) reduce 407) (("^") reduce 407) (("|") reduce 407)) 1309 ((("%") shift) ((")") reduce 420) (("*") shift) (("+") shift) ((",") reduce 420) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 420) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_BOOLEAN_AND) reduce 420) ((T_BOOLEAN_OR) reduce 420) ((T_COALESCE) reduce 420) ((T_DOUBLE_ARROW) reduce 420) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 420) ((T_LOGICAL_OR) reduce 420) ((T_LOGICAL_XOR) reduce 420) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 420) (("|") reduce 420)) 1310 ((("%") shift) ((")") reduce 406) (("*") shift) (("+") shift) ((",") reduce 406) (("-") shift) ((".") reduce 406) (("/") shift) (("<") reduce 406) ((">") reduce 406) (("?") reduce 406) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_BOOLEAN_AND) reduce 406) ((T_BOOLEAN_OR) reduce 406) ((T_COALESCE) reduce 406) ((T_DOUBLE_ARROW) reduce 406) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 406) ((T_IS_GREATER_OR_EQUAL) reduce 406) ((T_IS_IDENTICAL) reduce 406) ((T_IS_NOT_EQUAL) reduce 406) ((T_IS_NOT_IDENTICAL) reduce 406) ((T_IS_SMALLER_OR_EQUAL) reduce 406) ((T_LOGICAL_AND) reduce 406) ((T_LOGICAL_OR) reduce 406) ((T_LOGICAL_XOR) reduce 406) ((T_POW) shift) ((T_SL) reduce 406) ((T_SPACESHIP) reduce 406) ((T_SR) reduce 406) (("^") reduce 406) (("|") reduce 406)) 1311 ((("%") reduce 403) ((")") reduce 403) (("*") reduce 403) (("+") reduce 403) ((",") reduce 403) (("-") reduce 403) ((".") reduce 403) (("/") reduce 403) (("<") reduce 403) ((">") reduce 403) (("?") reduce 403) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_BOOLEAN_AND) reduce 403) ((T_BOOLEAN_OR) reduce 403) ((T_COALESCE) reduce 403) ((T_DOUBLE_ARROW) reduce 403) ((T_INSTANCEOF) reduce 403) ((T_IS_EQUAL) reduce 403) ((T_IS_GREATER_OR_EQUAL) reduce 403) ((T_IS_IDENTICAL) reduce 403) ((T_IS_NOT_EQUAL) reduce 403) ((T_IS_NOT_IDENTICAL) reduce 403) ((T_IS_SMALLER_OR_EQUAL) reduce 403) ((T_LOGICAL_AND) reduce 403) ((T_LOGICAL_OR) reduce 403) ((T_LOGICAL_XOR) reduce 403) ((T_POW) shift) ((T_SL) reduce 403) ((T_SPACESHIP) reduce 403) ((T_SR) reduce 403) (("^") reduce 403) (("|") reduce 403)) 1312 ((("%") shift) ((")") reduce 394) (("*") shift) (("+") shift) ((",") reduce 394) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 394) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 394) ((T_LOGICAL_XOR) reduce 394) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 1313 ((("%") shift) ((")") reduce 392) (("*") shift) (("+") shift) ((",") reduce 392) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 392) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 392) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 1314 ((("%") shift) ((")") reduce 393) (("*") shift) (("+") shift) ((",") reduce 393) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 393) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 393) ((T_LOGICAL_OR) reduce 393) ((T_LOGICAL_XOR) reduce 393) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 1315 ((("%") shift) ((")") reduce 417) (("*") shift) (("+") shift) ((",") reduce 417) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 417) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_BOOLEAN_AND) reduce 417) ((T_BOOLEAN_OR) reduce 417) ((T_COALESCE) reduce 417) ((T_DOUBLE_ARROW) reduce 417) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 417) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 417) ((T_IS_NOT_EQUAL) reduce 417) ((T_IS_NOT_IDENTICAL) reduce 417) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 417) ((T_LOGICAL_OR) reduce 417) ((T_LOGICAL_XOR) reduce 417) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 417) ((T_SR) shift) (("^") reduce 417) (("|") reduce 417)) 1316 ((("%") shift) ((")") reduce 413) (("*") shift) (("+") shift) ((",") reduce 413) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 413) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_BOOLEAN_AND) reduce 413) ((T_BOOLEAN_OR) reduce 413) ((T_COALESCE) reduce 413) ((T_DOUBLE_ARROW) reduce 413) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 413) ((T_LOGICAL_OR) reduce 413) ((T_LOGICAL_XOR) reduce 413) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 413) (("|") reduce 413)) 1317 ((("%") shift) ((")") reduce 415) (("*") shift) (("+") shift) ((",") reduce 415) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 415) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_BOOLEAN_AND) reduce 415) ((T_BOOLEAN_OR) reduce 415) ((T_COALESCE) reduce 415) ((T_DOUBLE_ARROW) reduce 415) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 415) ((T_LOGICAL_OR) reduce 415) ((T_LOGICAL_XOR) reduce 415) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 415) (("|") reduce 415)) 1318 ((("%") shift) ((")") reduce 412) (("*") shift) (("+") shift) ((",") reduce 412) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 412) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_BOOLEAN_AND) reduce 412) ((T_BOOLEAN_OR) reduce 412) ((T_COALESCE) reduce 412) ((T_DOUBLE_ARROW) reduce 412) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 412) ((T_LOGICAL_OR) reduce 412) ((T_LOGICAL_XOR) reduce 412) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 412) (("|") reduce 412)) 1319 ((("%") shift) ((")") reduce 419) (("*") shift) (("+") shift) ((",") reduce 419) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 419) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_BOOLEAN_AND) reduce 419) ((T_BOOLEAN_OR) reduce 419) ((T_COALESCE) reduce 419) ((T_DOUBLE_ARROW) reduce 419) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 419) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 419) ((T_IS_NOT_EQUAL) reduce 419) ((T_IS_NOT_IDENTICAL) reduce 419) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 419) ((T_LOGICAL_OR) reduce 419) ((T_LOGICAL_XOR) reduce 419) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 419) ((T_SR) shift) (("^") reduce 419) (("|") reduce 419)) 1320 ((("%") shift) ((")") reduce 414) (("*") shift) (("+") shift) ((",") reduce 414) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 414) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_BOOLEAN_AND) reduce 414) ((T_BOOLEAN_OR) reduce 414) ((T_COALESCE) reduce 414) ((T_DOUBLE_ARROW) reduce 414) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 414) ((T_LOGICAL_OR) reduce 414) ((T_LOGICAL_XOR) reduce 414) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 414) (("|") reduce 414)) 1323 ((("%") reduce 93) ((")") reduce 93) (("*") reduce 93) (("+") reduce 93) ((",") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93)) 1324 ((("%") reduce 92) ((")") reduce 92) (("*") reduce 92) (("+") reduce 92) ((",") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92)) 1325 ((("%") reduce 94) ((")") reduce 94) (("*") reduce 94) (("+") reduce 94) ((",") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94)) 1326 ((("%") reduce 470) ((")") reduce 470) (("*") reduce 470) (("+") reduce 470) ((",") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_DOUBLE_ARROW) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470)) 1327 ((("%") reduce 91) ((")") reduce 91) (("*") reduce 91) (("+") reduce 91) ((",") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91)) 1328 ((("%") reduce 529) ((")") reduce 529) (("*") reduce 529) (("+") reduce 529) ((",") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 1329 ((("%") reduce 472) ((")") reduce 472) (("*") reduce 472) (("+") reduce 472) ((",") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_DOUBLE_ARROW) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472)) 1330 ((("%") reduce 421) ((")") reduce 421) (("*") reduce 421) (("+") reduce 421) ((",") reduce 421) (("-") reduce 421) ((".") reduce 421) (("/") reduce 421) (("<") reduce 421) ((">") reduce 421) (("?") reduce 421) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_BOOLEAN_AND) reduce 421) ((T_BOOLEAN_OR) reduce 421) ((T_COALESCE) reduce 421) ((T_DOUBLE_ARROW) reduce 421) ((T_INSTANCEOF) reduce 421) ((T_IS_EQUAL) reduce 421) ((T_IS_GREATER_OR_EQUAL) reduce 421) ((T_IS_IDENTICAL) reduce 421) ((T_IS_NOT_EQUAL) reduce 421) ((T_IS_NOT_IDENTICAL) reduce 421) ((T_IS_SMALLER_OR_EQUAL) reduce 421) ((T_LOGICAL_AND) reduce 421) ((T_LOGICAL_OR) reduce 421) ((T_LOGICAL_XOR) reduce 421) ((T_POW) reduce 421) ((T_SL) reduce 421) ((T_SPACESHIP) reduce 421) ((T_SR) reduce 421) (("^") reduce 421) (("|") reduce 421)) 1331 ((("%") reduce 471) ((")") reduce 471) (("*") reduce 471) (("+") reduce 471) ((",") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_DOUBLE_ARROW) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471)) 1332 ((("%") reduce 473) ((")") reduce 473) (("*") reduce 473) (("+") reduce 473) ((",") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_DOUBLE_ARROW) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 1333 ((("%") reduce 534) ((")") reduce 534) (("*") reduce 534) (("+") reduce 534) ((",") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_DOUBLE_ARROW) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 1340 ((("%") reduce 536) ((")") reduce 536) (("*") reduce 536) (("+") reduce 536) ((",") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_DOUBLE_ARROW) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 1342 ((("%") reduce 535) ((")") reduce 535) (("*") reduce 535) (("+") reduce 535) ((",") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_DOUBLE_ARROW) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 1343 ((("%") reduce 540) ((")") reduce 540) (("*") reduce 540) (("+") reduce 540) ((",") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_DOUBLE_ARROW) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 1344 ((("%") reduce 544) ((")") reduce 544) (("*") reduce 544) (("+") reduce 544) ((",") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 1345 ((("%") reduce 537) ((")") reduce 537) (("*") reduce 537) (("+") reduce 537) ((",") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_DOUBLE_ARROW) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 1346 ((("%") reduce 546) ((")") reduce 546) (("*") reduce 546) (("+") reduce 546) ((",") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 1349 ((("%") reduce 545) ((")") reduce 545) (("*") reduce 545) (("+") reduce 545) ((",") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 1350 ((("%") reduce 538) ((")") reduce 538) (("*") reduce 538) (("+") reduce 538) ((",") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_DOUBLE_ARROW) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 1352 ((("%") reduce 539) ((")") reduce 539) (("*") reduce 539) (("+") reduce 539) ((",") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_DOUBLE_ARROW) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 1354 ((("%") reduce 474) ((")") reduce 474) (("*") reduce 474) (("+") reduce 474) ((",") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_DOUBLE_ARROW) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474)) 1355 ((("%") reduce 531) ((")") reduce 531) (("*") reduce 531) (("+") reduce 531) ((",") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 1358 ((("%") reduce 530) ((")") reduce 530) (("*") reduce 530) (("+") reduce 530) ((",") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 1359 ((("%") shift) ((")") reduce 426) (("*") shift) (("+") shift) ((",") reduce 426) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 426) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 426) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 426) ((T_LOGICAL_OR) reduce 426) ((T_LOGICAL_XOR) reduce 426) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 1360 ((("%") shift) ((")") reduce 390) (("*") shift) (("+") shift) ((",") reduce 390) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 390) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) reduce 390) ((T_COALESCE) reduce 390) ((T_DOUBLE_ARROW) reduce 390) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 390) ((T_LOGICAL_OR) reduce 390) ((T_LOGICAL_XOR) reduce 390) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 1361 ((("%") shift) ((")") reduce 391) (("*") shift) (("+") shift) ((",") reduce 391) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 391) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 391) ((T_BOOLEAN_OR) reduce 391) ((T_COALESCE) reduce 391) ((T_DOUBLE_ARROW) reduce 391) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 391) ((T_LOGICAL_OR) reduce 391) ((T_LOGICAL_XOR) reduce 391) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 1362 ((("%") shift) ((")") reduce 396) (("*") shift) (("+") shift) ((",") reduce 396) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 396) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_BOOLEAN_AND) reduce 396) ((T_BOOLEAN_OR) reduce 396) ((T_COALESCE) reduce 396) ((T_DOUBLE_ARROW) reduce 396) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 396) ((T_LOGICAL_OR) reduce 396) ((T_LOGICAL_XOR) reduce 396) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 396) (("|") reduce 396)) 1363 ((("%") shift) ((")") reduce 397) (("*") shift) (("+") shift) ((",") reduce 397) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 397) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_BOOLEAN_AND) reduce 397) ((T_BOOLEAN_OR) reduce 397) ((T_COALESCE) reduce 397) ((T_DOUBLE_ARROW) reduce 397) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 397) ((T_LOGICAL_OR) reduce 397) ((T_LOGICAL_XOR) reduce 397) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 397) (("|") reduce 397)) 1367 ((("%") shift) ((")") reduce 424) (("*") shift) (("+") shift) ((",") reduce 424) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 424) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 424) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 424) ((T_LOGICAL_OR) reduce 424) ((T_LOGICAL_XOR) reduce 424) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 1368 ((("%") shift) ((")") reduce 425) (("*") shift) (("+") shift) ((",") reduce 425) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 425) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 425) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 425) ((T_LOGICAL_OR) reduce 425) ((T_LOGICAL_XOR) reduce 425) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 1369 ((("%") shift) ((")") reduce 418) (("*") shift) (("+") shift) ((",") reduce 418) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 418) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_BOOLEAN_AND) reduce 418) ((T_BOOLEAN_OR) reduce 418) ((T_COALESCE) reduce 418) ((T_DOUBLE_ARROW) reduce 418) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 418) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 418) ((T_IS_NOT_EQUAL) reduce 418) ((T_IS_NOT_IDENTICAL) reduce 418) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 418) ((T_LOGICAL_OR) reduce 418) ((T_LOGICAL_XOR) reduce 418) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 418) ((T_SR) shift) (("^") reduce 418) (("|") reduce 418)) 1370 ((("%") shift) ((")") reduce 416) (("*") shift) (("+") shift) ((",") reduce 416) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 416) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_BOOLEAN_AND) reduce 416) ((T_BOOLEAN_OR) reduce 416) ((T_COALESCE) reduce 416) ((T_DOUBLE_ARROW) reduce 416) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 416) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 416) ((T_IS_NOT_EQUAL) reduce 416) ((T_IS_NOT_IDENTICAL) reduce 416) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 416) ((T_LOGICAL_OR) reduce 416) ((T_LOGICAL_XOR) reduce 416) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 416) ((T_SR) shift) (("^") reduce 416) (("|") reduce 416)) 1371 ((("%") reduce 404) ((")") reduce 404) (("*") reduce 404) (("+") reduce 404) ((",") reduce 404) (("-") reduce 404) ((".") reduce 404) (("/") reduce 404) (("<") reduce 404) ((">") reduce 404) (("?") reduce 404) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_BOOLEAN_AND) reduce 404) ((T_BOOLEAN_OR) reduce 404) ((T_COALESCE) reduce 404) ((T_DOUBLE_ARROW) reduce 404) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 404) ((T_IS_GREATER_OR_EQUAL) reduce 404) ((T_IS_IDENTICAL) reduce 404) ((T_IS_NOT_EQUAL) reduce 404) ((T_IS_NOT_IDENTICAL) reduce 404) ((T_IS_SMALLER_OR_EQUAL) reduce 404) ((T_LOGICAL_AND) reduce 404) ((T_LOGICAL_OR) reduce 404) ((T_LOGICAL_XOR) reduce 404) ((T_POW) shift) ((T_SL) reduce 404) ((T_SPACESHIP) reduce 404) ((T_SR) reduce 404) (("^") reduce 404) (("|") reduce 404)) 1372 ((("%") shift) ((")") reduce 399) (("*") shift) (("+") shift) ((",") reduce 399) (("-") shift) ((".") reduce 399) (("/") shift) (("<") reduce 399) ((">") reduce 399) (("?") reduce 399) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_BOOLEAN_AND) reduce 399) ((T_BOOLEAN_OR) reduce 399) ((T_COALESCE) reduce 399) ((T_DOUBLE_ARROW) reduce 399) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 399) ((T_IS_GREATER_OR_EQUAL) reduce 399) ((T_IS_IDENTICAL) reduce 399) ((T_IS_NOT_EQUAL) reduce 399) ((T_IS_NOT_IDENTICAL) reduce 399) ((T_IS_SMALLER_OR_EQUAL) reduce 399) ((T_LOGICAL_AND) reduce 399) ((T_LOGICAL_OR) reduce 399) ((T_LOGICAL_XOR) reduce 399) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 399) ((T_SR) shift) (("^") reduce 399) (("|") reduce 399)) 1373 ((("%") shift) ((")") reduce 401) (("*") shift) (("+") reduce 401) ((",") reduce 401) (("-") reduce 401) ((".") reduce 401) (("/") shift) (("<") reduce 401) ((">") reduce 401) (("?") reduce 401) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_BOOLEAN_AND) reduce 401) ((T_BOOLEAN_OR) reduce 401) ((T_COALESCE) reduce 401) ((T_DOUBLE_ARROW) reduce 401) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 401) ((T_IS_GREATER_OR_EQUAL) reduce 401) ((T_IS_IDENTICAL) reduce 401) ((T_IS_NOT_EQUAL) reduce 401) ((T_IS_NOT_IDENTICAL) reduce 401) ((T_IS_SMALLER_OR_EQUAL) reduce 401) ((T_LOGICAL_AND) reduce 401) ((T_LOGICAL_OR) reduce 401) ((T_LOGICAL_XOR) reduce 401) ((T_POW) shift) ((T_SL) reduce 401) ((T_SPACESHIP) reduce 401) ((T_SR) reduce 401) (("^") reduce 401) (("|") reduce 401)) 1374 ((("%") shift) ((")") reduce 400) (("*") shift) (("+") reduce 400) ((",") reduce 400) (("-") reduce 400) ((".") reduce 400) (("/") shift) (("<") reduce 400) ((">") reduce 400) (("?") reduce 400) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_BOOLEAN_AND) reduce 400) ((T_BOOLEAN_OR) reduce 400) ((T_COALESCE) reduce 400) ((T_DOUBLE_ARROW) reduce 400) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 400) ((T_IS_GREATER_OR_EQUAL) reduce 400) ((T_IS_IDENTICAL) reduce 400) ((T_IS_NOT_EQUAL) reduce 400) ((T_IS_NOT_IDENTICAL) reduce 400) ((T_IS_SMALLER_OR_EQUAL) reduce 400) ((T_LOGICAL_AND) reduce 400) ((T_LOGICAL_OR) reduce 400) ((T_LOGICAL_XOR) reduce 400) ((T_POW) shift) ((T_SL) reduce 400) ((T_SPACESHIP) reduce 400) ((T_SR) reduce 400) (("^") reduce 400) (("|") reduce 400)) 1375 ((("%") reduce 402) ((")") reduce 402) (("*") reduce 402) (("+") reduce 402) ((",") reduce 402) (("-") reduce 402) ((".") reduce 402) (("/") reduce 402) (("<") reduce 402) ((">") reduce 402) (("?") reduce 402) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_BOOLEAN_AND) reduce 402) ((T_BOOLEAN_OR) reduce 402) ((T_COALESCE) reduce 402) ((T_DOUBLE_ARROW) reduce 402) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 402) ((T_IS_GREATER_OR_EQUAL) reduce 402) ((T_IS_IDENTICAL) reduce 402) ((T_IS_NOT_EQUAL) reduce 402) ((T_IS_NOT_IDENTICAL) reduce 402) ((T_IS_SMALLER_OR_EQUAL) reduce 402) ((T_LOGICAL_AND) reduce 402) ((T_LOGICAL_OR) reduce 402) ((T_LOGICAL_XOR) reduce 402) ((T_POW) shift) ((T_SL) reduce 402) ((T_SPACESHIP) reduce 402) ((T_SR) reduce 402) (("^") reduce 402) (("|") reduce 402)) 1376 ((("%") reduce 405) ((")") reduce 405) (("*") reduce 405) (("+") reduce 405) ((",") reduce 405) (("-") reduce 405) ((".") reduce 405) (("/") reduce 405) (("<") reduce 405) ((">") reduce 405) (("?") reduce 405) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_BOOLEAN_AND) reduce 405) ((T_BOOLEAN_OR) reduce 405) ((T_COALESCE) reduce 405) ((T_DOUBLE_ARROW) reduce 405) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 405) ((T_IS_GREATER_OR_EQUAL) reduce 405) ((T_IS_IDENTICAL) reduce 405) ((T_IS_NOT_EQUAL) reduce 405) ((T_IS_NOT_IDENTICAL) reduce 405) ((T_IS_SMALLER_OR_EQUAL) reduce 405) ((T_LOGICAL_AND) reduce 405) ((T_LOGICAL_OR) reduce 405) ((T_LOGICAL_XOR) reduce 405) ((T_POW) shift) ((T_SL) reduce 405) ((T_SPACESHIP) reduce 405) ((T_SR) reduce 405) (("^") reduce 405) (("|") reduce 405)) 1378 ((("%") reduce 73) (("(") reduce 73) ((")") reduce 73) (("*") reduce 73) (("+") reduce 73) ((",") reduce 73) (("-") reduce 73) ((".") reduce 73) (("/") reduce 73) (("<") reduce 73) ((">") reduce 73) (("?") reduce 73) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_BOOLEAN_AND) reduce 73) ((T_BOOLEAN_OR) reduce 73) ((T_COALESCE) reduce 73) ((T_DOUBLE_ARROW) reduce 73) ((T_INSTANCEOF) reduce 73) ((T_IS_EQUAL) reduce 73) ((T_IS_GREATER_OR_EQUAL) reduce 73) ((T_IS_IDENTICAL) reduce 73) ((T_IS_NOT_EQUAL) reduce 73) ((T_IS_NOT_IDENTICAL) reduce 73) ((T_IS_SMALLER_OR_EQUAL) reduce 73) ((T_LOGICAL_AND) reduce 73) ((T_LOGICAL_OR) reduce 73) ((T_LOGICAL_XOR) reduce 73) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 73) ((T_OBJECT_OPERATOR) reduce 73) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 73) ((T_POW) reduce 73) ((T_SL) reduce 73) ((T_SPACESHIP) reduce 73) ((T_SR) reduce 73) (("[") reduce 73) (("^") reduce 73) (("{") reduce 73) (("|") reduce 73)) 1379 ((("%") reduce 52) (("(") reduce 52) ((")") reduce 52) (("*") reduce 52) (("+") reduce 52) ((",") reduce 52) (("-") reduce 52) ((".") reduce 52) (("/") reduce 52) (("<") reduce 52) ((">") reduce 52) (("?") reduce 52) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_BOOLEAN_AND) reduce 52) ((T_BOOLEAN_OR) reduce 52) ((T_COALESCE) reduce 52) ((T_DOUBLE_ARROW) reduce 52) ((T_INSTANCEOF) reduce 52) ((T_IS_EQUAL) reduce 52) ((T_IS_GREATER_OR_EQUAL) reduce 52) ((T_IS_IDENTICAL) reduce 52) ((T_IS_NOT_EQUAL) reduce 52) ((T_IS_NOT_IDENTICAL) reduce 52) ((T_IS_SMALLER_OR_EQUAL) reduce 52) ((T_LOGICAL_AND) reduce 52) ((T_LOGICAL_OR) reduce 52) ((T_LOGICAL_XOR) reduce 52) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 52) ((T_OBJECT_OPERATOR) reduce 52) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 52) ((T_POW) reduce 52) ((T_SL) reduce 52) ((T_SPACESHIP) reduce 52) ((T_SR) reduce 52) (("[") reduce 52) (("^") reduce 52) (("{") reduce 52) (("|") reduce 52)) 1380 ((("%") reduce 27) (("(") reduce 27) ((")") reduce 27) (("*") reduce 27) (("+") reduce 27) ((",") reduce 27) (("-") reduce 27) ((".") reduce 27) (("/") reduce 27) (("<") reduce 27) ((">") reduce 27) (("?") reduce 27) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_BOOLEAN_AND) reduce 27) ((T_BOOLEAN_OR) reduce 27) ((T_COALESCE) reduce 27) ((T_DOUBLE_ARROW) reduce 27) ((T_INSTANCEOF) reduce 27) ((T_IS_EQUAL) reduce 27) ((T_IS_GREATER_OR_EQUAL) reduce 27) ((T_IS_IDENTICAL) reduce 27) ((T_IS_NOT_EQUAL) reduce 27) ((T_IS_NOT_IDENTICAL) reduce 27) ((T_IS_SMALLER_OR_EQUAL) reduce 27) ((T_LOGICAL_AND) reduce 27) ((T_LOGICAL_OR) reduce 27) ((T_LOGICAL_XOR) reduce 27) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 27) ((T_OBJECT_OPERATOR) reduce 27) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 27) ((T_POW) reduce 27) ((T_SL) reduce 27) ((T_SPACESHIP) reduce 27) ((T_SR) reduce 27) (("[") reduce 27) (("^") reduce 27) (("{") reduce 27) (("|") reduce 27)) 1381 ((("%") reduce 51) (("(") reduce 51) ((")") reduce 51) (("*") reduce 51) (("+") reduce 51) ((",") reduce 51) (("-") reduce 51) ((".") reduce 51) (("/") reduce 51) (("<") reduce 51) ((">") reduce 51) (("?") reduce 51) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_BOOLEAN_AND) reduce 51) ((T_BOOLEAN_OR) reduce 51) ((T_COALESCE) reduce 51) ((T_DOUBLE_ARROW) reduce 51) ((T_INSTANCEOF) reduce 51) ((T_IS_EQUAL) reduce 51) ((T_IS_GREATER_OR_EQUAL) reduce 51) ((T_IS_IDENTICAL) reduce 51) ((T_IS_NOT_EQUAL) reduce 51) ((T_IS_NOT_IDENTICAL) reduce 51) ((T_IS_SMALLER_OR_EQUAL) reduce 51) ((T_LOGICAL_AND) reduce 51) ((T_LOGICAL_OR) reduce 51) ((T_LOGICAL_XOR) reduce 51) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 51) ((T_OBJECT_OPERATOR) reduce 51) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 51) ((T_POW) reduce 51) ((T_SL) reduce 51) ((T_SPACESHIP) reduce 51) ((T_SR) reduce 51) (("[") reduce 51) (("^") reduce 51) (("{") reduce 51) (("|") reduce 51)) 1382 ((("%") reduce 53) (("(") reduce 53) ((")") reduce 53) (("*") reduce 53) (("+") reduce 53) ((",") reduce 53) (("-") reduce 53) ((".") reduce 53) (("/") reduce 53) (("<") reduce 53) ((">") reduce 53) (("?") reduce 53) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_BOOLEAN_AND) reduce 53) ((T_BOOLEAN_OR) reduce 53) ((T_COALESCE) reduce 53) ((T_DOUBLE_ARROW) reduce 53) ((T_INSTANCEOF) reduce 53) ((T_IS_EQUAL) reduce 53) ((T_IS_GREATER_OR_EQUAL) reduce 53) ((T_IS_IDENTICAL) reduce 53) ((T_IS_NOT_EQUAL) reduce 53) ((T_IS_NOT_IDENTICAL) reduce 53) ((T_IS_SMALLER_OR_EQUAL) reduce 53) ((T_LOGICAL_AND) reduce 53) ((T_LOGICAL_OR) reduce 53) ((T_LOGICAL_XOR) reduce 53) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 53) ((T_OBJECT_OPERATOR) reduce 53) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 53) ((T_POW) reduce 53) ((T_SL) reduce 53) ((T_SPACESHIP) reduce 53) ((T_SR) reduce 53) (("[") reduce 53) (("^") reduce 53) (("{") reduce 53) (("|") reduce 53)) 1383 ((("%") reduce 49) (("(") reduce 49) ((")") reduce 49) (("*") reduce 49) (("+") reduce 49) ((",") reduce 49) (("-") reduce 49) ((".") reduce 49) (("/") reduce 49) (("<") reduce 49) ((">") reduce 49) (("?") reduce 49) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_BOOLEAN_AND) reduce 49) ((T_BOOLEAN_OR) reduce 49) ((T_COALESCE) reduce 49) ((T_DOUBLE_ARROW) reduce 49) ((T_INSTANCEOF) reduce 49) ((T_IS_EQUAL) reduce 49) ((T_IS_GREATER_OR_EQUAL) reduce 49) ((T_IS_IDENTICAL) reduce 49) ((T_IS_NOT_EQUAL) reduce 49) ((T_IS_NOT_IDENTICAL) reduce 49) ((T_IS_SMALLER_OR_EQUAL) reduce 49) ((T_LOGICAL_AND) reduce 49) ((T_LOGICAL_OR) reduce 49) ((T_LOGICAL_XOR) reduce 49) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 49) ((T_OBJECT_OPERATOR) reduce 49) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 49) ((T_POW) reduce 49) ((T_SL) reduce 49) ((T_SPACESHIP) reduce 49) ((T_SR) reduce 49) (("[") reduce 49) (("^") reduce 49) (("{") reduce 49) (("|") reduce 49)) 1384 ((("%") reduce 29) (("(") reduce 29) ((")") reduce 29) (("*") reduce 29) (("+") reduce 29) ((",") reduce 29) (("-") reduce 29) ((".") reduce 29) (("/") reduce 29) (("<") reduce 29) ((">") reduce 29) (("?") reduce 29) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_BOOLEAN_AND) reduce 29) ((T_BOOLEAN_OR) reduce 29) ((T_COALESCE) reduce 29) ((T_DOUBLE_ARROW) reduce 29) ((T_INSTANCEOF) reduce 29) ((T_IS_EQUAL) reduce 29) ((T_IS_GREATER_OR_EQUAL) reduce 29) ((T_IS_IDENTICAL) reduce 29) ((T_IS_NOT_EQUAL) reduce 29) ((T_IS_NOT_IDENTICAL) reduce 29) ((T_IS_SMALLER_OR_EQUAL) reduce 29) ((T_LOGICAL_AND) reduce 29) ((T_LOGICAL_OR) reduce 29) ((T_LOGICAL_XOR) reduce 29) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 29) ((T_OBJECT_OPERATOR) reduce 29) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 29) ((T_POW) reduce 29) ((T_SL) reduce 29) ((T_SPACESHIP) reduce 29) ((T_SR) reduce 29) (("[") reduce 29) (("^") reduce 29) (("{") reduce 29) (("|") reduce 29)) 1385 ((("%") reduce 59) (("(") reduce 59) ((")") reduce 59) (("*") reduce 59) (("+") reduce 59) ((",") reduce 59) (("-") reduce 59) ((".") reduce 59) (("/") reduce 59) (("<") reduce 59) ((">") reduce 59) (("?") reduce 59) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_BOOLEAN_AND) reduce 59) ((T_BOOLEAN_OR) reduce 59) ((T_COALESCE) reduce 59) ((T_DOUBLE_ARROW) reduce 59) ((T_INSTANCEOF) reduce 59) ((T_IS_EQUAL) reduce 59) ((T_IS_GREATER_OR_EQUAL) reduce 59) ((T_IS_IDENTICAL) reduce 59) ((T_IS_NOT_EQUAL) reduce 59) ((T_IS_NOT_IDENTICAL) reduce 59) ((T_IS_SMALLER_OR_EQUAL) reduce 59) ((T_LOGICAL_AND) reduce 59) ((T_LOGICAL_OR) reduce 59) ((T_LOGICAL_XOR) reduce 59) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 59) ((T_OBJECT_OPERATOR) reduce 59) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 59) ((T_POW) reduce 59) ((T_SL) reduce 59) ((T_SPACESHIP) reduce 59) ((T_SR) reduce 59) (("[") reduce 59) (("^") reduce 59) (("{") reduce 59) (("|") reduce 59)) 1386 ((("%") reduce 60) (("(") reduce 60) ((")") reduce 60) (("*") reduce 60) (("+") reduce 60) ((",") reduce 60) (("-") reduce 60) ((".") reduce 60) (("/") reduce 60) (("<") reduce 60) ((">") reduce 60) (("?") reduce 60) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_BOOLEAN_AND) reduce 60) ((T_BOOLEAN_OR) reduce 60) ((T_COALESCE) reduce 60) ((T_DOUBLE_ARROW) reduce 60) ((T_INSTANCEOF) reduce 60) ((T_IS_EQUAL) reduce 60) ((T_IS_GREATER_OR_EQUAL) reduce 60) ((T_IS_IDENTICAL) reduce 60) ((T_IS_NOT_EQUAL) reduce 60) ((T_IS_NOT_IDENTICAL) reduce 60) ((T_IS_SMALLER_OR_EQUAL) reduce 60) ((T_LOGICAL_AND) reduce 60) ((T_LOGICAL_OR) reduce 60) ((T_LOGICAL_XOR) reduce 60) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 60) ((T_OBJECT_OPERATOR) reduce 60) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 60) ((T_POW) reduce 60) ((T_SL) reduce 60) ((T_SPACESHIP) reduce 60) ((T_SR) reduce 60) (("[") reduce 60) (("^") reduce 60) (("{") reduce 60) (("|") reduce 60)) 1387 ((("%") reduce 11) (("(") reduce 11) ((")") reduce 11) (("*") reduce 11) (("+") reduce 11) ((",") reduce 11) (("-") reduce 11) ((".") reduce 11) (("/") reduce 11) (("<") reduce 11) ((">") reduce 11) (("?") reduce 11) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_BOOLEAN_AND) reduce 11) ((T_BOOLEAN_OR) reduce 11) ((T_COALESCE) reduce 11) ((T_DOUBLE_ARROW) reduce 11) ((T_INSTANCEOF) reduce 11) ((T_IS_EQUAL) reduce 11) ((T_IS_GREATER_OR_EQUAL) reduce 11) ((T_IS_IDENTICAL) reduce 11) ((T_IS_NOT_EQUAL) reduce 11) ((T_IS_NOT_IDENTICAL) reduce 11) ((T_IS_SMALLER_OR_EQUAL) reduce 11) ((T_LOGICAL_AND) reduce 11) ((T_LOGICAL_OR) reduce 11) ((T_LOGICAL_XOR) reduce 11) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 11) ((T_OBJECT_OPERATOR) reduce 11) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 11) ((T_POW) reduce 11) ((T_SL) reduce 11) ((T_SPACESHIP) reduce 11) ((T_SR) reduce 11) (("[") reduce 11) (("^") reduce 11) (("{") reduce 11) (("|") reduce 11)) 1388 ((("%") reduce 42) (("(") reduce 42) ((")") reduce 42) (("*") reduce 42) (("+") reduce 42) ((",") reduce 42) (("-") reduce 42) ((".") reduce 42) (("/") reduce 42) (("<") reduce 42) ((">") reduce 42) (("?") reduce 42) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_BOOLEAN_AND) reduce 42) ((T_BOOLEAN_OR) reduce 42) ((T_COALESCE) reduce 42) ((T_DOUBLE_ARROW) reduce 42) ((T_INSTANCEOF) reduce 42) ((T_IS_EQUAL) reduce 42) ((T_IS_GREATER_OR_EQUAL) reduce 42) ((T_IS_IDENTICAL) reduce 42) ((T_IS_NOT_EQUAL) reduce 42) ((T_IS_NOT_IDENTICAL) reduce 42) ((T_IS_SMALLER_OR_EQUAL) reduce 42) ((T_LOGICAL_AND) reduce 42) ((T_LOGICAL_OR) reduce 42) ((T_LOGICAL_XOR) reduce 42) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 42) ((T_OBJECT_OPERATOR) reduce 42) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 42) ((T_POW) reduce 42) ((T_SL) reduce 42) ((T_SPACESHIP) reduce 42) ((T_SR) reduce 42) (("[") reduce 42) (("^") reduce 42) (("{") reduce 42) (("|") reduce 42)) 1389 ((("%") reduce 39) (("(") reduce 39) ((")") reduce 39) (("*") reduce 39) (("+") reduce 39) ((",") reduce 39) (("-") reduce 39) ((".") reduce 39) (("/") reduce 39) (("<") reduce 39) ((">") reduce 39) (("?") reduce 39) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_BOOLEAN_AND) reduce 39) ((T_BOOLEAN_OR) reduce 39) ((T_COALESCE) reduce 39) ((T_DOUBLE_ARROW) reduce 39) ((T_INSTANCEOF) reduce 39) ((T_IS_EQUAL) reduce 39) ((T_IS_GREATER_OR_EQUAL) reduce 39) ((T_IS_IDENTICAL) reduce 39) ((T_IS_NOT_EQUAL) reduce 39) ((T_IS_NOT_IDENTICAL) reduce 39) ((T_IS_SMALLER_OR_EQUAL) reduce 39) ((T_LOGICAL_AND) reduce 39) ((T_LOGICAL_OR) reduce 39) ((T_LOGICAL_XOR) reduce 39) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 39) ((T_OBJECT_OPERATOR) reduce 39) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 39) ((T_POW) reduce 39) ((T_SL) reduce 39) ((T_SPACESHIP) reduce 39) ((T_SR) reduce 39) (("[") reduce 39) (("^") reduce 39) (("{") reduce 39) (("|") reduce 39)) 1390 ((("%") reduce 25) (("(") reduce 25) ((")") reduce 25) (("*") reduce 25) (("+") reduce 25) ((",") reduce 25) (("-") reduce 25) ((".") reduce 25) (("/") reduce 25) (("<") reduce 25) ((">") reduce 25) (("?") reduce 25) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_BOOLEAN_AND) reduce 25) ((T_BOOLEAN_OR) reduce 25) ((T_COALESCE) reduce 25) ((T_DOUBLE_ARROW) reduce 25) ((T_INSTANCEOF) reduce 25) ((T_IS_EQUAL) reduce 25) ((T_IS_GREATER_OR_EQUAL) reduce 25) ((T_IS_IDENTICAL) reduce 25) ((T_IS_NOT_EQUAL) reduce 25) ((T_IS_NOT_IDENTICAL) reduce 25) ((T_IS_SMALLER_OR_EQUAL) reduce 25) ((T_LOGICAL_AND) reduce 25) ((T_LOGICAL_OR) reduce 25) ((T_LOGICAL_XOR) reduce 25) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 25) ((T_OBJECT_OPERATOR) reduce 25) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 25) ((T_POW) reduce 25) ((T_SL) reduce 25) ((T_SPACESHIP) reduce 25) ((T_SR) reduce 25) (("[") reduce 25) (("^") reduce 25) (("{") reduce 25) (("|") reduce 25)) 1391 ((("%") reduce 50) (("(") reduce 50) ((")") reduce 50) (("*") reduce 50) (("+") reduce 50) ((",") reduce 50) (("-") reduce 50) ((".") reduce 50) (("/") reduce 50) (("<") reduce 50) ((">") reduce 50) (("?") reduce 50) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_BOOLEAN_AND) reduce 50) ((T_BOOLEAN_OR) reduce 50) ((T_COALESCE) reduce 50) ((T_DOUBLE_ARROW) reduce 50) ((T_INSTANCEOF) reduce 50) ((T_IS_EQUAL) reduce 50) ((T_IS_GREATER_OR_EQUAL) reduce 50) ((T_IS_IDENTICAL) reduce 50) ((T_IS_NOT_EQUAL) reduce 50) ((T_IS_NOT_IDENTICAL) reduce 50) ((T_IS_SMALLER_OR_EQUAL) reduce 50) ((T_LOGICAL_AND) reduce 50) ((T_LOGICAL_OR) reduce 50) ((T_LOGICAL_XOR) reduce 50) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 50) ((T_OBJECT_OPERATOR) reduce 50) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 50) ((T_POW) reduce 50) ((T_SL) reduce 50) ((T_SPACESHIP) reduce 50) ((T_SR) reduce 50) (("[") reduce 50) (("^") reduce 50) (("{") reduce 50) (("|") reduce 50)) 1392 ((("%") reduce 66) (("(") reduce 66) ((")") reduce 66) (("*") reduce 66) (("+") reduce 66) ((",") reduce 66) (("-") reduce 66) ((".") reduce 66) (("/") reduce 66) (("<") reduce 66) ((">") reduce 66) (("?") reduce 66) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_BOOLEAN_AND) reduce 66) ((T_BOOLEAN_OR) reduce 66) ((T_COALESCE) reduce 66) ((T_DOUBLE_ARROW) reduce 66) ((T_INSTANCEOF) reduce 66) ((T_IS_EQUAL) reduce 66) ((T_IS_GREATER_OR_EQUAL) reduce 66) ((T_IS_IDENTICAL) reduce 66) ((T_IS_NOT_EQUAL) reduce 66) ((T_IS_NOT_IDENTICAL) reduce 66) ((T_IS_SMALLER_OR_EQUAL) reduce 66) ((T_LOGICAL_AND) reduce 66) ((T_LOGICAL_OR) reduce 66) ((T_LOGICAL_XOR) reduce 66) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 66) ((T_OBJECT_OPERATOR) reduce 66) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 66) ((T_POW) reduce 66) ((T_SL) reduce 66) ((T_SPACESHIP) reduce 66) ((T_SR) reduce 66) (("[") reduce 66) (("^") reduce 66) (("{") reduce 66) (("|") reduce 66)) 1393 ((("%") reduce 18) (("(") reduce 18) ((")") reduce 18) (("*") reduce 18) (("+") reduce 18) ((",") reduce 18) (("-") reduce 18) ((".") reduce 18) (("/") reduce 18) (("<") reduce 18) ((">") reduce 18) (("?") reduce 18) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_BOOLEAN_AND) reduce 18) ((T_BOOLEAN_OR) reduce 18) ((T_COALESCE) reduce 18) ((T_DOUBLE_ARROW) reduce 18) ((T_INSTANCEOF) reduce 18) ((T_IS_EQUAL) reduce 18) ((T_IS_GREATER_OR_EQUAL) reduce 18) ((T_IS_IDENTICAL) reduce 18) ((T_IS_NOT_EQUAL) reduce 18) ((T_IS_NOT_IDENTICAL) reduce 18) ((T_IS_SMALLER_OR_EQUAL) reduce 18) ((T_LOGICAL_AND) reduce 18) ((T_LOGICAL_OR) reduce 18) ((T_LOGICAL_XOR) reduce 18) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 18) ((T_OBJECT_OPERATOR) reduce 18) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 18) ((T_POW) reduce 18) ((T_SL) reduce 18) ((T_SPACESHIP) reduce 18) ((T_SR) reduce 18) (("[") reduce 18) (("^") reduce 18) (("{") reduce 18) (("|") reduce 18)) 1394 ((("%") reduce 17) (("(") reduce 17) ((")") reduce 17) (("*") reduce 17) (("+") reduce 17) ((",") reduce 17) (("-") reduce 17) ((".") reduce 17) (("/") reduce 17) (("<") reduce 17) ((">") reduce 17) (("?") reduce 17) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_BOOLEAN_AND) reduce 17) ((T_BOOLEAN_OR) reduce 17) ((T_COALESCE) reduce 17) ((T_DOUBLE_ARROW) reduce 17) ((T_INSTANCEOF) reduce 17) ((T_IS_EQUAL) reduce 17) ((T_IS_GREATER_OR_EQUAL) reduce 17) ((T_IS_IDENTICAL) reduce 17) ((T_IS_NOT_EQUAL) reduce 17) ((T_IS_NOT_IDENTICAL) reduce 17) ((T_IS_SMALLER_OR_EQUAL) reduce 17) ((T_LOGICAL_AND) reduce 17) ((T_LOGICAL_OR) reduce 17) ((T_LOGICAL_XOR) reduce 17) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 17) ((T_OBJECT_OPERATOR) reduce 17) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 17) ((T_POW) reduce 17) ((T_SL) reduce 17) ((T_SPACESHIP) reduce 17) ((T_SR) reduce 17) (("[") reduce 17) (("^") reduce 17) (("{") reduce 17) (("|") reduce 17)) 1395 ((("%") reduce 15) (("(") reduce 15) ((")") reduce 15) (("*") reduce 15) (("+") reduce 15) ((",") reduce 15) (("-") reduce 15) ((".") reduce 15) (("/") reduce 15) (("<") reduce 15) ((">") reduce 15) (("?") reduce 15) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_BOOLEAN_AND) reduce 15) ((T_BOOLEAN_OR) reduce 15) ((T_COALESCE) reduce 15) ((T_DOUBLE_ARROW) reduce 15) ((T_INSTANCEOF) reduce 15) ((T_IS_EQUAL) reduce 15) ((T_IS_GREATER_OR_EQUAL) reduce 15) ((T_IS_IDENTICAL) reduce 15) ((T_IS_NOT_EQUAL) reduce 15) ((T_IS_NOT_IDENTICAL) reduce 15) ((T_IS_SMALLER_OR_EQUAL) reduce 15) ((T_LOGICAL_AND) reduce 15) ((T_LOGICAL_OR) reduce 15) ((T_LOGICAL_XOR) reduce 15) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 15) ((T_OBJECT_OPERATOR) reduce 15) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 15) ((T_POW) reduce 15) ((T_SL) reduce 15) ((T_SPACESHIP) reduce 15) ((T_SR) reduce 15) (("[") reduce 15) (("^") reduce 15) (("{") reduce 15) (("|") reduce 15)) 1396 ((("%") reduce 14) (("(") reduce 14) ((")") reduce 14) (("*") reduce 14) (("+") reduce 14) ((",") reduce 14) (("-") reduce 14) ((".") reduce 14) (("/") reduce 14) (("<") reduce 14) ((">") reduce 14) (("?") reduce 14) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_BOOLEAN_AND) reduce 14) ((T_BOOLEAN_OR) reduce 14) ((T_COALESCE) reduce 14) ((T_DOUBLE_ARROW) reduce 14) ((T_INSTANCEOF) reduce 14) ((T_IS_EQUAL) reduce 14) ((T_IS_GREATER_OR_EQUAL) reduce 14) ((T_IS_IDENTICAL) reduce 14) ((T_IS_NOT_EQUAL) reduce 14) ((T_IS_NOT_IDENTICAL) reduce 14) ((T_IS_SMALLER_OR_EQUAL) reduce 14) ((T_LOGICAL_AND) reduce 14) ((T_LOGICAL_OR) reduce 14) ((T_LOGICAL_XOR) reduce 14) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 14) ((T_OBJECT_OPERATOR) reduce 14) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 14) ((T_POW) reduce 14) ((T_SL) reduce 14) ((T_SPACESHIP) reduce 14) ((T_SR) reduce 14) (("[") reduce 14) (("^") reduce 14) (("{") reduce 14) (("|") reduce 14)) 1397 ((("%") reduce 38) (("(") reduce 38) ((")") reduce 38) (("*") reduce 38) (("+") reduce 38) ((",") reduce 38) (("-") reduce 38) ((".") reduce 38) (("/") reduce 38) (("<") reduce 38) ((">") reduce 38) (("?") reduce 38) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_BOOLEAN_AND) reduce 38) ((T_BOOLEAN_OR) reduce 38) ((T_COALESCE) reduce 38) ((T_DOUBLE_ARROW) reduce 38) ((T_INSTANCEOF) reduce 38) ((T_IS_EQUAL) reduce 38) ((T_IS_GREATER_OR_EQUAL) reduce 38) ((T_IS_IDENTICAL) reduce 38) ((T_IS_NOT_EQUAL) reduce 38) ((T_IS_NOT_IDENTICAL) reduce 38) ((T_IS_SMALLER_OR_EQUAL) reduce 38) ((T_LOGICAL_AND) reduce 38) ((T_LOGICAL_OR) reduce 38) ((T_LOGICAL_XOR) reduce 38) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 38) ((T_OBJECT_OPERATOR) reduce 38) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 38) ((T_POW) reduce 38) ((T_SL) reduce 38) ((T_SPACESHIP) reduce 38) ((T_SR) reduce 38) (("[") reduce 38) (("^") reduce 38) (("{") reduce 38) (("|") reduce 38)) 1398 ((("%") reduce 26) (("(") reduce 26) ((")") reduce 26) (("*") reduce 26) (("+") reduce 26) ((",") reduce 26) (("-") reduce 26) ((".") reduce 26) (("/") reduce 26) (("<") reduce 26) ((">") reduce 26) (("?") reduce 26) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_BOOLEAN_AND) reduce 26) ((T_BOOLEAN_OR) reduce 26) ((T_COALESCE) reduce 26) ((T_DOUBLE_ARROW) reduce 26) ((T_INSTANCEOF) reduce 26) ((T_IS_EQUAL) reduce 26) ((T_IS_GREATER_OR_EQUAL) reduce 26) ((T_IS_IDENTICAL) reduce 26) ((T_IS_NOT_EQUAL) reduce 26) ((T_IS_NOT_IDENTICAL) reduce 26) ((T_IS_SMALLER_OR_EQUAL) reduce 26) ((T_LOGICAL_AND) reduce 26) ((T_LOGICAL_OR) reduce 26) ((T_LOGICAL_XOR) reduce 26) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 26) ((T_OBJECT_OPERATOR) reduce 26) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 26) ((T_POW) reduce 26) ((T_SL) reduce 26) ((T_SPACESHIP) reduce 26) ((T_SR) reduce 26) (("[") reduce 26) (("^") reduce 26) (("{") reduce 26) (("|") reduce 26)) 1399 ((("%") reduce 22) (("(") reduce 22) ((")") reduce 22) (("*") reduce 22) (("+") reduce 22) ((",") reduce 22) (("-") reduce 22) ((".") reduce 22) (("/") reduce 22) (("<") reduce 22) ((">") reduce 22) (("?") reduce 22) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_BOOLEAN_AND) reduce 22) ((T_BOOLEAN_OR) reduce 22) ((T_COALESCE) reduce 22) ((T_DOUBLE_ARROW) reduce 22) ((T_INSTANCEOF) reduce 22) ((T_IS_EQUAL) reduce 22) ((T_IS_GREATER_OR_EQUAL) reduce 22) ((T_IS_IDENTICAL) reduce 22) ((T_IS_NOT_EQUAL) reduce 22) ((T_IS_NOT_IDENTICAL) reduce 22) ((T_IS_SMALLER_OR_EQUAL) reduce 22) ((T_LOGICAL_AND) reduce 22) ((T_LOGICAL_OR) reduce 22) ((T_LOGICAL_XOR) reduce 22) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 22) ((T_OBJECT_OPERATOR) reduce 22) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 22) ((T_POW) reduce 22) ((T_SL) reduce 22) ((T_SPACESHIP) reduce 22) ((T_SR) reduce 22) (("[") reduce 22) (("^") reduce 22) (("{") reduce 22) (("|") reduce 22)) 1400 ((("%") reduce 24) (("(") reduce 24) ((")") reduce 24) (("*") reduce 24) (("+") reduce 24) ((",") reduce 24) (("-") reduce 24) ((".") reduce 24) (("/") reduce 24) (("<") reduce 24) ((">") reduce 24) (("?") reduce 24) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_BOOLEAN_AND) reduce 24) ((T_BOOLEAN_OR) reduce 24) ((T_COALESCE) reduce 24) ((T_DOUBLE_ARROW) reduce 24) ((T_INSTANCEOF) reduce 24) ((T_IS_EQUAL) reduce 24) ((T_IS_GREATER_OR_EQUAL) reduce 24) ((T_IS_IDENTICAL) reduce 24) ((T_IS_NOT_EQUAL) reduce 24) ((T_IS_NOT_IDENTICAL) reduce 24) ((T_IS_SMALLER_OR_EQUAL) reduce 24) ((T_LOGICAL_AND) reduce 24) ((T_LOGICAL_OR) reduce 24) ((T_LOGICAL_XOR) reduce 24) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 24) ((T_OBJECT_OPERATOR) reduce 24) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 24) ((T_POW) reduce 24) ((T_SL) reduce 24) ((T_SPACESHIP) reduce 24) ((T_SR) reduce 24) (("[") reduce 24) (("^") reduce 24) (("{") reduce 24) (("|") reduce 24)) 1401 ((("%") reduce 16) (("(") reduce 16) ((")") reduce 16) (("*") reduce 16) (("+") reduce 16) ((",") reduce 16) (("-") reduce 16) ((".") reduce 16) (("/") reduce 16) (("<") reduce 16) ((">") reduce 16) (("?") reduce 16) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_BOOLEAN_AND) reduce 16) ((T_BOOLEAN_OR) reduce 16) ((T_COALESCE) reduce 16) ((T_DOUBLE_ARROW) reduce 16) ((T_INSTANCEOF) reduce 16) ((T_IS_EQUAL) reduce 16) ((T_IS_GREATER_OR_EQUAL) reduce 16) ((T_IS_IDENTICAL) reduce 16) ((T_IS_NOT_EQUAL) reduce 16) ((T_IS_NOT_IDENTICAL) reduce 16) ((T_IS_SMALLER_OR_EQUAL) reduce 16) ((T_LOGICAL_AND) reduce 16) ((T_LOGICAL_OR) reduce 16) ((T_LOGICAL_XOR) reduce 16) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 16) ((T_OBJECT_OPERATOR) reduce 16) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 16) ((T_POW) reduce 16) ((T_SL) reduce 16) ((T_SPACESHIP) reduce 16) ((T_SR) reduce 16) (("[") reduce 16) (("^") reduce 16) (("{") reduce 16) (("|") reduce 16)) 1402 ((("%") reduce 48) (("(") reduce 48) ((")") reduce 48) (("*") reduce 48) (("+") reduce 48) ((",") reduce 48) (("-") reduce 48) ((".") reduce 48) (("/") reduce 48) (("<") reduce 48) ((">") reduce 48) (("?") reduce 48) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_BOOLEAN_AND) reduce 48) ((T_BOOLEAN_OR) reduce 48) ((T_COALESCE) reduce 48) ((T_DOUBLE_ARROW) reduce 48) ((T_INSTANCEOF) reduce 48) ((T_IS_EQUAL) reduce 48) ((T_IS_GREATER_OR_EQUAL) reduce 48) ((T_IS_IDENTICAL) reduce 48) ((T_IS_NOT_EQUAL) reduce 48) ((T_IS_NOT_IDENTICAL) reduce 48) ((T_IS_SMALLER_OR_EQUAL) reduce 48) ((T_LOGICAL_AND) reduce 48) ((T_LOGICAL_OR) reduce 48) ((T_LOGICAL_XOR) reduce 48) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 48) ((T_OBJECT_OPERATOR) reduce 48) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 48) ((T_POW) reduce 48) ((T_SL) reduce 48) ((T_SPACESHIP) reduce 48) ((T_SR) reduce 48) (("[") reduce 48) (("^") reduce 48) (("{") reduce 48) (("|") reduce 48)) 1403 ((("%") reduce 20) (("(") reduce 20) ((")") reduce 20) (("*") reduce 20) (("+") reduce 20) ((",") reduce 20) (("-") reduce 20) ((".") reduce 20) (("/") reduce 20) (("<") reduce 20) ((">") reduce 20) (("?") reduce 20) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_BOOLEAN_AND) reduce 20) ((T_BOOLEAN_OR) reduce 20) ((T_COALESCE) reduce 20) ((T_DOUBLE_ARROW) reduce 20) ((T_INSTANCEOF) reduce 20) ((T_IS_EQUAL) reduce 20) ((T_IS_GREATER_OR_EQUAL) reduce 20) ((T_IS_IDENTICAL) reduce 20) ((T_IS_NOT_EQUAL) reduce 20) ((T_IS_NOT_IDENTICAL) reduce 20) ((T_IS_SMALLER_OR_EQUAL) reduce 20) ((T_LOGICAL_AND) reduce 20) ((T_LOGICAL_OR) reduce 20) ((T_LOGICAL_XOR) reduce 20) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 20) ((T_OBJECT_OPERATOR) reduce 20) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 20) ((T_POW) reduce 20) ((T_SL) reduce 20) ((T_SPACESHIP) reduce 20) ((T_SR) reduce 20) (("[") reduce 20) (("^") reduce 20) (("{") reduce 20) (("|") reduce 20)) 1404 ((("%") reduce 70) (("(") reduce 70) ((")") reduce 70) (("*") reduce 70) (("+") reduce 70) ((",") reduce 70) (("-") reduce 70) ((".") reduce 70) (("/") reduce 70) (("<") reduce 70) ((">") reduce 70) (("?") reduce 70) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_BOOLEAN_AND) reduce 70) ((T_BOOLEAN_OR) reduce 70) ((T_COALESCE) reduce 70) ((T_DOUBLE_ARROW) reduce 70) ((T_INSTANCEOF) reduce 70) ((T_IS_EQUAL) reduce 70) ((T_IS_GREATER_OR_EQUAL) reduce 70) ((T_IS_IDENTICAL) reduce 70) ((T_IS_NOT_EQUAL) reduce 70) ((T_IS_NOT_IDENTICAL) reduce 70) ((T_IS_SMALLER_OR_EQUAL) reduce 70) ((T_LOGICAL_AND) reduce 70) ((T_LOGICAL_OR) reduce 70) ((T_LOGICAL_XOR) reduce 70) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 70) ((T_OBJECT_OPERATOR) reduce 70) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 70) ((T_POW) reduce 70) ((T_SL) reduce 70) ((T_SPACESHIP) reduce 70) ((T_SR) reduce 70) (("[") reduce 70) (("^") reduce 70) (("{") reduce 70) (("|") reduce 70)) 1405 ((("%") reduce 3) (("(") reduce 3) ((")") reduce 3) (("*") reduce 3) (("+") reduce 3) ((",") reduce 3) (("-") reduce 3) ((".") reduce 3) (("/") reduce 3) (("<") reduce 3) ((">") reduce 3) (("?") reduce 3) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_BOOLEAN_AND) reduce 3) ((T_BOOLEAN_OR) reduce 3) ((T_COALESCE) reduce 3) ((T_DOUBLE_ARROW) reduce 3) ((T_INSTANCEOF) reduce 3) ((T_IS_EQUAL) reduce 3) ((T_IS_GREATER_OR_EQUAL) reduce 3) ((T_IS_IDENTICAL) reduce 3) ((T_IS_NOT_EQUAL) reduce 3) ((T_IS_NOT_IDENTICAL) reduce 3) ((T_IS_SMALLER_OR_EQUAL) reduce 3) ((T_LOGICAL_AND) reduce 3) ((T_LOGICAL_OR) reduce 3) ((T_LOGICAL_XOR) reduce 3) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 3) ((T_OBJECT_OPERATOR) reduce 3) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 3) ((T_POW) reduce 3) ((T_SL) reduce 3) ((T_SPACESHIP) reduce 3) ((T_SR) reduce 3) (("[") reduce 3) (("^") reduce 3) (("{") reduce 3) (("|") reduce 3)) 1406 ((("%") reduce 12) (("(") reduce 12) ((")") reduce 12) (("*") reduce 12) (("+") reduce 12) ((",") reduce 12) (("-") reduce 12) ((".") reduce 12) (("/") reduce 12) (("<") reduce 12) ((">") reduce 12) (("?") reduce 12) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_BOOLEAN_AND) reduce 12) ((T_BOOLEAN_OR) reduce 12) ((T_COALESCE) reduce 12) ((T_DOUBLE_ARROW) reduce 12) ((T_INSTANCEOF) reduce 12) ((T_IS_EQUAL) reduce 12) ((T_IS_GREATER_OR_EQUAL) reduce 12) ((T_IS_IDENTICAL) reduce 12) ((T_IS_NOT_EQUAL) reduce 12) ((T_IS_NOT_IDENTICAL) reduce 12) ((T_IS_SMALLER_OR_EQUAL) reduce 12) ((T_LOGICAL_AND) reduce 12) ((T_LOGICAL_OR) reduce 12) ((T_LOGICAL_XOR) reduce 12) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 12) ((T_OBJECT_OPERATOR) reduce 12) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 12) ((T_POW) reduce 12) ((T_SL) reduce 12) ((T_SPACESHIP) reduce 12) ((T_SR) reduce 12) (("[") reduce 12) (("^") reduce 12) (("{") reduce 12) (("|") reduce 12)) 1407 ((("%") reduce 54) (("(") reduce 54) ((")") reduce 54) (("*") reduce 54) (("+") reduce 54) ((",") reduce 54) (("-") reduce 54) ((".") reduce 54) (("/") reduce 54) (("<") reduce 54) ((">") reduce 54) (("?") reduce 54) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_BOOLEAN_AND) reduce 54) ((T_BOOLEAN_OR) reduce 54) ((T_COALESCE) reduce 54) ((T_DOUBLE_ARROW) reduce 54) ((T_INSTANCEOF) reduce 54) ((T_IS_EQUAL) reduce 54) ((T_IS_GREATER_OR_EQUAL) reduce 54) ((T_IS_IDENTICAL) reduce 54) ((T_IS_NOT_EQUAL) reduce 54) ((T_IS_NOT_IDENTICAL) reduce 54) ((T_IS_SMALLER_OR_EQUAL) reduce 54) ((T_LOGICAL_AND) reduce 54) ((T_LOGICAL_OR) reduce 54) ((T_LOGICAL_XOR) reduce 54) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 54) ((T_OBJECT_OPERATOR) reduce 54) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 54) ((T_POW) reduce 54) ((T_SL) reduce 54) ((T_SPACESHIP) reduce 54) ((T_SR) reduce 54) (("[") reduce 54) (("^") reduce 54) (("{") reduce 54) (("|") reduce 54)) 1408 ((("%") reduce 65) (("(") reduce 65) ((")") reduce 65) (("*") reduce 65) (("+") reduce 65) ((",") reduce 65) (("-") reduce 65) ((".") reduce 65) (("/") reduce 65) (("<") reduce 65) ((">") reduce 65) (("?") reduce 65) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_BOOLEAN_AND) reduce 65) ((T_BOOLEAN_OR) reduce 65) ((T_COALESCE) reduce 65) ((T_DOUBLE_ARROW) reduce 65) ((T_INSTANCEOF) reduce 65) ((T_IS_EQUAL) reduce 65) ((T_IS_GREATER_OR_EQUAL) reduce 65) ((T_IS_IDENTICAL) reduce 65) ((T_IS_NOT_EQUAL) reduce 65) ((T_IS_NOT_IDENTICAL) reduce 65) ((T_IS_SMALLER_OR_EQUAL) reduce 65) ((T_LOGICAL_AND) reduce 65) ((T_LOGICAL_OR) reduce 65) ((T_LOGICAL_XOR) reduce 65) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 65) ((T_OBJECT_OPERATOR) reduce 65) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 65) ((T_POW) reduce 65) ((T_SL) reduce 65) ((T_SPACESHIP) reduce 65) ((T_SR) reduce 65) (("[") reduce 65) (("^") reduce 65) (("{") reduce 65) (("|") reduce 65)) 1409 ((("%") reduce 74) (("(") reduce 74) ((")") reduce 74) (("*") reduce 74) (("+") reduce 74) ((",") reduce 74) (("-") reduce 74) ((".") reduce 74) (("/") reduce 74) (("<") reduce 74) ((">") reduce 74) (("?") reduce 74) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_BOOLEAN_AND) reduce 74) ((T_BOOLEAN_OR) reduce 74) ((T_COALESCE) reduce 74) ((T_DOUBLE_ARROW) reduce 74) ((T_INSTANCEOF) reduce 74) ((T_IS_EQUAL) reduce 74) ((T_IS_GREATER_OR_EQUAL) reduce 74) ((T_IS_IDENTICAL) reduce 74) ((T_IS_NOT_EQUAL) reduce 74) ((T_IS_NOT_IDENTICAL) reduce 74) ((T_IS_SMALLER_OR_EQUAL) reduce 74) ((T_LOGICAL_AND) reduce 74) ((T_LOGICAL_OR) reduce 74) ((T_LOGICAL_XOR) reduce 74) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 74) ((T_OBJECT_OPERATOR) reduce 74) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 74) ((T_POW) reduce 74) ((T_SL) reduce 74) ((T_SPACESHIP) reduce 74) ((T_SR) reduce 74) (("[") reduce 74) (("^") reduce 74) (("{") reduce 74) (("|") reduce 74)) 1410 ((("%") reduce 30) (("(") reduce 30) ((")") reduce 30) (("*") reduce 30) (("+") reduce 30) ((",") reduce 30) (("-") reduce 30) ((".") reduce 30) (("/") reduce 30) (("<") reduce 30) ((">") reduce 30) (("?") reduce 30) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_BOOLEAN_AND) reduce 30) ((T_BOOLEAN_OR) reduce 30) ((T_COALESCE) reduce 30) ((T_DOUBLE_ARROW) reduce 30) ((T_INSTANCEOF) reduce 30) ((T_IS_EQUAL) reduce 30) ((T_IS_GREATER_OR_EQUAL) reduce 30) ((T_IS_IDENTICAL) reduce 30) ((T_IS_NOT_EQUAL) reduce 30) ((T_IS_NOT_IDENTICAL) reduce 30) ((T_IS_SMALLER_OR_EQUAL) reduce 30) ((T_LOGICAL_AND) reduce 30) ((T_LOGICAL_OR) reduce 30) ((T_LOGICAL_XOR) reduce 30) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 30) ((T_OBJECT_OPERATOR) reduce 30) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 30) ((T_POW) reduce 30) ((T_SL) reduce 30) ((T_SPACESHIP) reduce 30) ((T_SR) reduce 30) (("[") reduce 30) (("^") reduce 30) (("{") reduce 30) (("|") reduce 30)) 1411 ((("%") reduce 68) (("(") reduce 68) ((")") reduce 68) (("*") reduce 68) (("+") reduce 68) ((",") reduce 68) (("-") reduce 68) ((".") reduce 68) (("/") reduce 68) (("<") reduce 68) ((">") reduce 68) (("?") reduce 68) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_BOOLEAN_AND) reduce 68) ((T_BOOLEAN_OR) reduce 68) ((T_COALESCE) reduce 68) ((T_DOUBLE_ARROW) reduce 68) ((T_INSTANCEOF) reduce 68) ((T_IS_EQUAL) reduce 68) ((T_IS_GREATER_OR_EQUAL) reduce 68) ((T_IS_IDENTICAL) reduce 68) ((T_IS_NOT_EQUAL) reduce 68) ((T_IS_NOT_IDENTICAL) reduce 68) ((T_IS_SMALLER_OR_EQUAL) reduce 68) ((T_LOGICAL_AND) reduce 68) ((T_LOGICAL_OR) reduce 68) ((T_LOGICAL_XOR) reduce 68) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 68) ((T_OBJECT_OPERATOR) reduce 68) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 68) ((T_POW) reduce 68) ((T_SL) reduce 68) ((T_SPACESHIP) reduce 68) ((T_SR) reduce 68) (("[") reduce 68) (("^") reduce 68) (("{") reduce 68) (("|") reduce 68)) 1412 ((("%") reduce 21) (("(") reduce 21) ((")") reduce 21) (("*") reduce 21) (("+") reduce 21) ((",") reduce 21) (("-") reduce 21) ((".") reduce 21) (("/") reduce 21) (("<") reduce 21) ((">") reduce 21) (("?") reduce 21) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_BOOLEAN_AND) reduce 21) ((T_BOOLEAN_OR) reduce 21) ((T_COALESCE) reduce 21) ((T_DOUBLE_ARROW) reduce 21) ((T_INSTANCEOF) reduce 21) ((T_IS_EQUAL) reduce 21) ((T_IS_GREATER_OR_EQUAL) reduce 21) ((T_IS_IDENTICAL) reduce 21) ((T_IS_NOT_EQUAL) reduce 21) ((T_IS_NOT_IDENTICAL) reduce 21) ((T_IS_SMALLER_OR_EQUAL) reduce 21) ((T_LOGICAL_AND) reduce 21) ((T_LOGICAL_OR) reduce 21) ((T_LOGICAL_XOR) reduce 21) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 21) ((T_OBJECT_OPERATOR) reduce 21) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 21) ((T_POW) reduce 21) ((T_SL) reduce 21) ((T_SPACESHIP) reduce 21) ((T_SR) reduce 21) (("[") reduce 21) (("^") reduce 21) (("{") reduce 21) (("|") reduce 21)) 1413 ((("%") reduce 23) (("(") reduce 23) ((")") reduce 23) (("*") reduce 23) (("+") reduce 23) ((",") reduce 23) (("-") reduce 23) ((".") reduce 23) (("/") reduce 23) (("<") reduce 23) ((">") reduce 23) (("?") reduce 23) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_BOOLEAN_AND) reduce 23) ((T_BOOLEAN_OR) reduce 23) ((T_COALESCE) reduce 23) ((T_DOUBLE_ARROW) reduce 23) ((T_INSTANCEOF) reduce 23) ((T_IS_EQUAL) reduce 23) ((T_IS_GREATER_OR_EQUAL) reduce 23) ((T_IS_IDENTICAL) reduce 23) ((T_IS_NOT_EQUAL) reduce 23) ((T_IS_NOT_IDENTICAL) reduce 23) ((T_IS_SMALLER_OR_EQUAL) reduce 23) ((T_LOGICAL_AND) reduce 23) ((T_LOGICAL_OR) reduce 23) ((T_LOGICAL_XOR) reduce 23) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 23) ((T_OBJECT_OPERATOR) reduce 23) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 23) ((T_POW) reduce 23) ((T_SL) reduce 23) ((T_SPACESHIP) reduce 23) ((T_SR) reduce 23) (("[") reduce 23) (("^") reduce 23) (("{") reduce 23) (("|") reduce 23)) 1414 ((("%") reduce 41) (("(") reduce 41) ((")") reduce 41) (("*") reduce 41) (("+") reduce 41) ((",") reduce 41) (("-") reduce 41) ((".") reduce 41) (("/") reduce 41) (("<") reduce 41) ((">") reduce 41) (("?") reduce 41) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_BOOLEAN_AND) reduce 41) ((T_BOOLEAN_OR) reduce 41) ((T_COALESCE) reduce 41) ((T_DOUBLE_ARROW) reduce 41) ((T_INSTANCEOF) reduce 41) ((T_IS_EQUAL) reduce 41) ((T_IS_GREATER_OR_EQUAL) reduce 41) ((T_IS_IDENTICAL) reduce 41) ((T_IS_NOT_EQUAL) reduce 41) ((T_IS_NOT_IDENTICAL) reduce 41) ((T_IS_SMALLER_OR_EQUAL) reduce 41) ((T_LOGICAL_AND) reduce 41) ((T_LOGICAL_OR) reduce 41) ((T_LOGICAL_XOR) reduce 41) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 41) ((T_OBJECT_OPERATOR) reduce 41) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 41) ((T_POW) reduce 41) ((T_SL) reduce 41) ((T_SPACESHIP) reduce 41) ((T_SR) reduce 41) (("[") reduce 41) (("^") reduce 41) (("{") reduce 41) (("|") reduce 41)) 1415 ((("%") reduce 62) (("(") reduce 62) ((")") reduce 62) (("*") reduce 62) (("+") reduce 62) ((",") reduce 62) (("-") reduce 62) ((".") reduce 62) (("/") reduce 62) (("<") reduce 62) ((">") reduce 62) (("?") reduce 62) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_BOOLEAN_AND) reduce 62) ((T_BOOLEAN_OR) reduce 62) ((T_COALESCE) reduce 62) ((T_DOUBLE_ARROW) reduce 62) ((T_INSTANCEOF) reduce 62) ((T_IS_EQUAL) reduce 62) ((T_IS_GREATER_OR_EQUAL) reduce 62) ((T_IS_IDENTICAL) reduce 62) ((T_IS_NOT_EQUAL) reduce 62) ((T_IS_NOT_IDENTICAL) reduce 62) ((T_IS_SMALLER_OR_EQUAL) reduce 62) ((T_LOGICAL_AND) reduce 62) ((T_LOGICAL_OR) reduce 62) ((T_LOGICAL_XOR) reduce 62) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 62) ((T_OBJECT_OPERATOR) reduce 62) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 62) ((T_POW) reduce 62) ((T_SL) reduce 62) ((T_SPACESHIP) reduce 62) ((T_SR) reduce 62) (("[") reduce 62) (("^") reduce 62) (("{") reduce 62) (("|") reduce 62)) 1416 ((("%") reduce 34) (("(") reduce 34) ((")") reduce 34) (("*") reduce 34) (("+") reduce 34) ((",") reduce 34) (("-") reduce 34) ((".") reduce 34) (("/") reduce 34) (("<") reduce 34) ((">") reduce 34) (("?") reduce 34) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_BOOLEAN_AND) reduce 34) ((T_BOOLEAN_OR) reduce 34) ((T_COALESCE) reduce 34) ((T_DOUBLE_ARROW) reduce 34) ((T_INSTANCEOF) reduce 34) ((T_IS_EQUAL) reduce 34) ((T_IS_GREATER_OR_EQUAL) reduce 34) ((T_IS_IDENTICAL) reduce 34) ((T_IS_NOT_EQUAL) reduce 34) ((T_IS_NOT_IDENTICAL) reduce 34) ((T_IS_SMALLER_OR_EQUAL) reduce 34) ((T_LOGICAL_AND) reduce 34) ((T_LOGICAL_OR) reduce 34) ((T_LOGICAL_XOR) reduce 34) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 34) ((T_OBJECT_OPERATOR) reduce 34) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 34) ((T_POW) reduce 34) ((T_SL) reduce 34) ((T_SPACESHIP) reduce 34) ((T_SR) reduce 34) (("[") reduce 34) (("^") reduce 34) (("{") reduce 34) (("|") reduce 34)) 1417 ((("%") reduce 40) (("(") reduce 40) ((")") reduce 40) (("*") reduce 40) (("+") reduce 40) ((",") reduce 40) (("-") reduce 40) ((".") reduce 40) (("/") reduce 40) (("<") reduce 40) ((">") reduce 40) (("?") reduce 40) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_BOOLEAN_AND) reduce 40) ((T_BOOLEAN_OR) reduce 40) ((T_COALESCE) reduce 40) ((T_DOUBLE_ARROW) reduce 40) ((T_INSTANCEOF) reduce 40) ((T_IS_EQUAL) reduce 40) ((T_IS_GREATER_OR_EQUAL) reduce 40) ((T_IS_IDENTICAL) reduce 40) ((T_IS_NOT_EQUAL) reduce 40) ((T_IS_NOT_IDENTICAL) reduce 40) ((T_IS_SMALLER_OR_EQUAL) reduce 40) ((T_LOGICAL_AND) reduce 40) ((T_LOGICAL_OR) reduce 40) ((T_LOGICAL_XOR) reduce 40) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 40) ((T_OBJECT_OPERATOR) reduce 40) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 40) ((T_POW) reduce 40) ((T_SL) reduce 40) ((T_SPACESHIP) reduce 40) ((T_SR) reduce 40) (("[") reduce 40) (("^") reduce 40) (("{") reduce 40) (("|") reduce 40)) 1418 ((("%") reduce 13) (("(") reduce 13) ((")") reduce 13) (("*") reduce 13) (("+") reduce 13) ((",") reduce 13) (("-") reduce 13) ((".") reduce 13) (("/") reduce 13) (("<") reduce 13) ((">") reduce 13) (("?") reduce 13) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_BOOLEAN_AND) reduce 13) ((T_BOOLEAN_OR) reduce 13) ((T_COALESCE) reduce 13) ((T_DOUBLE_ARROW) reduce 13) ((T_INSTANCEOF) reduce 13) ((T_IS_EQUAL) reduce 13) ((T_IS_GREATER_OR_EQUAL) reduce 13) ((T_IS_IDENTICAL) reduce 13) ((T_IS_NOT_EQUAL) reduce 13) ((T_IS_NOT_IDENTICAL) reduce 13) ((T_IS_SMALLER_OR_EQUAL) reduce 13) ((T_LOGICAL_AND) reduce 13) ((T_LOGICAL_OR) reduce 13) ((T_LOGICAL_XOR) reduce 13) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 13) ((T_OBJECT_OPERATOR) reduce 13) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 13) ((T_POW) reduce 13) ((T_SL) reduce 13) ((T_SPACESHIP) reduce 13) ((T_SR) reduce 13) (("[") reduce 13) (("^") reduce 13) (("{") reduce 13) (("|") reduce 13)) 1419 ((("%") reduce 55) (("(") reduce 55) ((")") reduce 55) (("*") reduce 55) (("+") reduce 55) ((",") reduce 55) (("-") reduce 55) ((".") reduce 55) (("/") reduce 55) (("<") reduce 55) ((">") reduce 55) (("?") reduce 55) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_BOOLEAN_AND) reduce 55) ((T_BOOLEAN_OR) reduce 55) ((T_COALESCE) reduce 55) ((T_DOUBLE_ARROW) reduce 55) ((T_INSTANCEOF) reduce 55) ((T_IS_EQUAL) reduce 55) ((T_IS_GREATER_OR_EQUAL) reduce 55) ((T_IS_IDENTICAL) reduce 55) ((T_IS_NOT_EQUAL) reduce 55) ((T_IS_NOT_IDENTICAL) reduce 55) ((T_IS_SMALLER_OR_EQUAL) reduce 55) ((T_LOGICAL_AND) reduce 55) ((T_LOGICAL_OR) reduce 55) ((T_LOGICAL_XOR) reduce 55) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 55) ((T_OBJECT_OPERATOR) reduce 55) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 55) ((T_POW) reduce 55) ((T_SL) reduce 55) ((T_SPACESHIP) reduce 55) ((T_SR) reduce 55) (("[") reduce 55) (("^") reduce 55) (("{") reduce 55) (("|") reduce 55)) 1420 ((("%") reduce 1) (("(") reduce 1) ((")") reduce 1) (("*") reduce 1) (("+") reduce 1) ((",") reduce 1) (("-") reduce 1) ((".") reduce 1) (("/") reduce 1) (("<") reduce 1) ((">") reduce 1) (("?") reduce 1) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_BOOLEAN_AND) reduce 1) ((T_BOOLEAN_OR) reduce 1) ((T_COALESCE) reduce 1) ((T_DOUBLE_ARROW) reduce 1) ((T_INSTANCEOF) reduce 1) ((T_IS_EQUAL) reduce 1) ((T_IS_GREATER_OR_EQUAL) reduce 1) ((T_IS_IDENTICAL) reduce 1) ((T_IS_NOT_EQUAL) reduce 1) ((T_IS_NOT_IDENTICAL) reduce 1) ((T_IS_SMALLER_OR_EQUAL) reduce 1) ((T_LOGICAL_AND) reduce 1) ((T_LOGICAL_OR) reduce 1) ((T_LOGICAL_XOR) reduce 1) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 1) ((T_OBJECT_OPERATOR) reduce 1) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 1) ((T_POW) reduce 1) ((T_SL) reduce 1) ((T_SPACESHIP) reduce 1) ((T_SR) reduce 1) (("[") reduce 1) (("^") reduce 1) (("{") reduce 1) (("|") reduce 1)) 1421 ((("%") reduce 2) (("(") reduce 2) ((")") reduce 2) (("*") reduce 2) (("+") reduce 2) ((",") reduce 2) (("-") reduce 2) ((".") reduce 2) (("/") reduce 2) (("<") reduce 2) ((">") reduce 2) (("?") reduce 2) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_BOOLEAN_AND) reduce 2) ((T_BOOLEAN_OR) reduce 2) ((T_COALESCE) reduce 2) ((T_DOUBLE_ARROW) reduce 2) ((T_INSTANCEOF) reduce 2) ((T_IS_EQUAL) reduce 2) ((T_IS_GREATER_OR_EQUAL) reduce 2) ((T_IS_IDENTICAL) reduce 2) ((T_IS_NOT_EQUAL) reduce 2) ((T_IS_NOT_IDENTICAL) reduce 2) ((T_IS_SMALLER_OR_EQUAL) reduce 2) ((T_LOGICAL_AND) reduce 2) ((T_LOGICAL_OR) reduce 2) ((T_LOGICAL_XOR) reduce 2) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 2) ((T_OBJECT_OPERATOR) reduce 2) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 2) ((T_POW) reduce 2) ((T_SL) reduce 2) ((T_SPACESHIP) reduce 2) ((T_SR) reduce 2) (("[") reduce 2) (("^") reduce 2) (("{") reduce 2) (("|") reduce 2)) 1422 ((("%") reduce 9) (("(") reduce 9) ((")") reduce 9) (("*") reduce 9) (("+") reduce 9) ((",") reduce 9) (("-") reduce 9) ((".") reduce 9) (("/") reduce 9) (("<") reduce 9) ((">") reduce 9) (("?") reduce 9) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_BOOLEAN_AND) reduce 9) ((T_BOOLEAN_OR) reduce 9) ((T_COALESCE) reduce 9) ((T_DOUBLE_ARROW) reduce 9) ((T_INSTANCEOF) reduce 9) ((T_IS_EQUAL) reduce 9) ((T_IS_GREATER_OR_EQUAL) reduce 9) ((T_IS_IDENTICAL) reduce 9) ((T_IS_NOT_EQUAL) reduce 9) ((T_IS_NOT_IDENTICAL) reduce 9) ((T_IS_SMALLER_OR_EQUAL) reduce 9) ((T_LOGICAL_AND) reduce 9) ((T_LOGICAL_OR) reduce 9) ((T_LOGICAL_XOR) reduce 9) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 9) ((T_OBJECT_OPERATOR) reduce 9) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 9) ((T_POW) reduce 9) ((T_SL) reduce 9) ((T_SPACESHIP) reduce 9) ((T_SR) reduce 9) (("[") reduce 9) (("^") reduce 9) (("{") reduce 9) (("|") reduce 9)) 1423 ((("%") reduce 33) (("(") reduce 33) ((")") reduce 33) (("*") reduce 33) (("+") reduce 33) ((",") reduce 33) (("-") reduce 33) ((".") reduce 33) (("/") reduce 33) (("<") reduce 33) ((">") reduce 33) (("?") reduce 33) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_BOOLEAN_AND) reduce 33) ((T_BOOLEAN_OR) reduce 33) ((T_COALESCE) reduce 33) ((T_DOUBLE_ARROW) reduce 33) ((T_INSTANCEOF) reduce 33) ((T_IS_EQUAL) reduce 33) ((T_IS_GREATER_OR_EQUAL) reduce 33) ((T_IS_IDENTICAL) reduce 33) ((T_IS_NOT_EQUAL) reduce 33) ((T_IS_NOT_IDENTICAL) reduce 33) ((T_IS_SMALLER_OR_EQUAL) reduce 33) ((T_LOGICAL_AND) reduce 33) ((T_LOGICAL_OR) reduce 33) ((T_LOGICAL_XOR) reduce 33) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 33) ((T_OBJECT_OPERATOR) reduce 33) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 33) ((T_POW) reduce 33) ((T_SL) reduce 33) ((T_SPACESHIP) reduce 33) ((T_SR) reduce 33) (("[") reduce 33) (("^") reduce 33) (("{") reduce 33) (("|") reduce 33)) 1424 ((("%") reduce 58) (("(") reduce 58) ((")") reduce 58) (("*") reduce 58) (("+") reduce 58) ((",") reduce 58) (("-") reduce 58) ((".") reduce 58) (("/") reduce 58) (("<") reduce 58) ((">") reduce 58) (("?") reduce 58) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_BOOLEAN_AND) reduce 58) ((T_BOOLEAN_OR) reduce 58) ((T_COALESCE) reduce 58) ((T_DOUBLE_ARROW) reduce 58) ((T_INSTANCEOF) reduce 58) ((T_IS_EQUAL) reduce 58) ((T_IS_GREATER_OR_EQUAL) reduce 58) ((T_IS_IDENTICAL) reduce 58) ((T_IS_NOT_EQUAL) reduce 58) ((T_IS_NOT_IDENTICAL) reduce 58) ((T_IS_SMALLER_OR_EQUAL) reduce 58) ((T_LOGICAL_AND) reduce 58) ((T_LOGICAL_OR) reduce 58) ((T_LOGICAL_XOR) reduce 58) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 58) ((T_OBJECT_OPERATOR) reduce 58) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 58) ((T_POW) reduce 58) ((T_SL) reduce 58) ((T_SPACESHIP) reduce 58) ((T_SR) reduce 58) (("[") reduce 58) (("^") reduce 58) (("{") reduce 58) (("|") reduce 58)) 1425 ((("%") reduce 37) (("(") reduce 37) ((")") reduce 37) (("*") reduce 37) (("+") reduce 37) ((",") reduce 37) (("-") reduce 37) ((".") reduce 37) (("/") reduce 37) (("<") reduce 37) ((">") reduce 37) (("?") reduce 37) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_BOOLEAN_AND) reduce 37) ((T_BOOLEAN_OR) reduce 37) ((T_COALESCE) reduce 37) ((T_DOUBLE_ARROW) reduce 37) ((T_INSTANCEOF) reduce 37) ((T_IS_EQUAL) reduce 37) ((T_IS_GREATER_OR_EQUAL) reduce 37) ((T_IS_IDENTICAL) reduce 37) ((T_IS_NOT_EQUAL) reduce 37) ((T_IS_NOT_IDENTICAL) reduce 37) ((T_IS_SMALLER_OR_EQUAL) reduce 37) ((T_LOGICAL_AND) reduce 37) ((T_LOGICAL_OR) reduce 37) ((T_LOGICAL_XOR) reduce 37) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 37) ((T_OBJECT_OPERATOR) reduce 37) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 37) ((T_POW) reduce 37) ((T_SL) reduce 37) ((T_SPACESHIP) reduce 37) ((T_SR) reduce 37) (("[") reduce 37) (("^") reduce 37) (("{") reduce 37) (("|") reduce 37)) 1426 ((("%") reduce 64) (("(") reduce 64) ((")") reduce 64) (("*") reduce 64) (("+") reduce 64) ((",") reduce 64) (("-") reduce 64) ((".") reduce 64) (("/") reduce 64) (("<") reduce 64) ((">") reduce 64) (("?") reduce 64) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_BOOLEAN_AND) reduce 64) ((T_BOOLEAN_OR) reduce 64) ((T_COALESCE) reduce 64) ((T_DOUBLE_ARROW) reduce 64) ((T_INSTANCEOF) reduce 64) ((T_IS_EQUAL) reduce 64) ((T_IS_GREATER_OR_EQUAL) reduce 64) ((T_IS_IDENTICAL) reduce 64) ((T_IS_NOT_EQUAL) reduce 64) ((T_IS_NOT_IDENTICAL) reduce 64) ((T_IS_SMALLER_OR_EQUAL) reduce 64) ((T_LOGICAL_AND) reduce 64) ((T_LOGICAL_OR) reduce 64) ((T_LOGICAL_XOR) reduce 64) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 64) ((T_OBJECT_OPERATOR) reduce 64) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 64) ((T_POW) reduce 64) ((T_SL) reduce 64) ((T_SPACESHIP) reduce 64) ((T_SR) reduce 64) (("[") reduce 64) (("^") reduce 64) (("{") reduce 64) (("|") reduce 64)) 1427 ((("%") reduce 46) (("(") reduce 46) ((")") reduce 46) (("*") reduce 46) (("+") reduce 46) ((",") reduce 46) (("-") reduce 46) ((".") reduce 46) (("/") reduce 46) (("<") reduce 46) ((">") reduce 46) (("?") reduce 46) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_BOOLEAN_AND) reduce 46) ((T_BOOLEAN_OR) reduce 46) ((T_COALESCE) reduce 46) ((T_DOUBLE_ARROW) reduce 46) ((T_INSTANCEOF) reduce 46) ((T_IS_EQUAL) reduce 46) ((T_IS_GREATER_OR_EQUAL) reduce 46) ((T_IS_IDENTICAL) reduce 46) ((T_IS_NOT_EQUAL) reduce 46) ((T_IS_NOT_IDENTICAL) reduce 46) ((T_IS_SMALLER_OR_EQUAL) reduce 46) ((T_LOGICAL_AND) reduce 46) ((T_LOGICAL_OR) reduce 46) ((T_LOGICAL_XOR) reduce 46) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 46) ((T_OBJECT_OPERATOR) reduce 46) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 46) ((T_POW) reduce 46) ((T_SL) reduce 46) ((T_SPACESHIP) reduce 46) ((T_SR) reduce 46) (("[") reduce 46) (("^") reduce 46) (("{") reduce 46) (("|") reduce 46)) 1428 ((("%") reduce 8) (("(") reduce 8) ((")") reduce 8) (("*") reduce 8) (("+") reduce 8) ((",") reduce 8) (("-") reduce 8) ((".") reduce 8) (("/") reduce 8) (("<") reduce 8) ((">") reduce 8) (("?") reduce 8) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_BOOLEAN_AND) reduce 8) ((T_BOOLEAN_OR) reduce 8) ((T_COALESCE) reduce 8) ((T_DOUBLE_ARROW) reduce 8) ((T_INSTANCEOF) reduce 8) ((T_IS_EQUAL) reduce 8) ((T_IS_GREATER_OR_EQUAL) reduce 8) ((T_IS_IDENTICAL) reduce 8) ((T_IS_NOT_EQUAL) reduce 8) ((T_IS_NOT_IDENTICAL) reduce 8) ((T_IS_SMALLER_OR_EQUAL) reduce 8) ((T_LOGICAL_AND) reduce 8) ((T_LOGICAL_OR) reduce 8) ((T_LOGICAL_XOR) reduce 8) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 8) ((T_OBJECT_OPERATOR) reduce 8) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 8) ((T_POW) reduce 8) ((T_SL) reduce 8) ((T_SPACESHIP) reduce 8) ((T_SR) reduce 8) (("[") reduce 8) (("^") reduce 8) (("{") reduce 8) (("|") reduce 8)) 1429 ((("%") reduce 6) (("(") reduce 6) ((")") reduce 6) (("*") reduce 6) (("+") reduce 6) ((",") reduce 6) (("-") reduce 6) ((".") reduce 6) (("/") reduce 6) (("<") reduce 6) ((">") reduce 6) (("?") reduce 6) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_BOOLEAN_AND) reduce 6) ((T_BOOLEAN_OR) reduce 6) ((T_COALESCE) reduce 6) ((T_DOUBLE_ARROW) reduce 6) ((T_INSTANCEOF) reduce 6) ((T_IS_EQUAL) reduce 6) ((T_IS_GREATER_OR_EQUAL) reduce 6) ((T_IS_IDENTICAL) reduce 6) ((T_IS_NOT_EQUAL) reduce 6) ((T_IS_NOT_IDENTICAL) reduce 6) ((T_IS_SMALLER_OR_EQUAL) reduce 6) ((T_LOGICAL_AND) reduce 6) ((T_LOGICAL_OR) reduce 6) ((T_LOGICAL_XOR) reduce 6) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 6) ((T_OBJECT_OPERATOR) reduce 6) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 6) ((T_POW) reduce 6) ((T_SL) reduce 6) ((T_SPACESHIP) reduce 6) ((T_SR) reduce 6) (("[") reduce 6) (("^") reduce 6) (("{") reduce 6) (("|") reduce 6)) 1430 ((("%") reduce 7) (("(") reduce 7) ((")") reduce 7) (("*") reduce 7) (("+") reduce 7) ((",") reduce 7) (("-") reduce 7) ((".") reduce 7) (("/") reduce 7) (("<") reduce 7) ((">") reduce 7) (("?") reduce 7) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_BOOLEAN_AND) reduce 7) ((T_BOOLEAN_OR) reduce 7) ((T_COALESCE) reduce 7) ((T_DOUBLE_ARROW) reduce 7) ((T_INSTANCEOF) reduce 7) ((T_IS_EQUAL) reduce 7) ((T_IS_GREATER_OR_EQUAL) reduce 7) ((T_IS_IDENTICAL) reduce 7) ((T_IS_NOT_EQUAL) reduce 7) ((T_IS_NOT_IDENTICAL) reduce 7) ((T_IS_SMALLER_OR_EQUAL) reduce 7) ((T_LOGICAL_AND) reduce 7) ((T_LOGICAL_OR) reduce 7) ((T_LOGICAL_XOR) reduce 7) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 7) ((T_OBJECT_OPERATOR) reduce 7) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 7) ((T_POW) reduce 7) ((T_SL) reduce 7) ((T_SPACESHIP) reduce 7) ((T_SR) reduce 7) (("[") reduce 7) (("^") reduce 7) (("{") reduce 7) (("|") reduce 7)) 1431 ((("%") reduce 69) (("(") reduce 69) ((")") reduce 69) (("*") reduce 69) (("+") reduce 69) ((",") reduce 69) (("-") reduce 69) ((".") reduce 69) (("/") reduce 69) (("<") reduce 69) ((">") reduce 69) (("?") reduce 69) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_BOOLEAN_AND) reduce 69) ((T_BOOLEAN_OR) reduce 69) ((T_COALESCE) reduce 69) ((T_DOUBLE_ARROW) reduce 69) ((T_INSTANCEOF) reduce 69) ((T_IS_EQUAL) reduce 69) ((T_IS_GREATER_OR_EQUAL) reduce 69) ((T_IS_IDENTICAL) reduce 69) ((T_IS_NOT_EQUAL) reduce 69) ((T_IS_NOT_IDENTICAL) reduce 69) ((T_IS_SMALLER_OR_EQUAL) reduce 69) ((T_LOGICAL_AND) reduce 69) ((T_LOGICAL_OR) reduce 69) ((T_LOGICAL_XOR) reduce 69) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 69) ((T_OBJECT_OPERATOR) reduce 69) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 69) ((T_POW) reduce 69) ((T_SL) reduce 69) ((T_SPACESHIP) reduce 69) ((T_SR) reduce 69) (("[") reduce 69) (("^") reduce 69) (("{") reduce 69) (("|") reduce 69)) 1432 ((("%") reduce 63) (("(") reduce 63) ((")") reduce 63) (("*") reduce 63) (("+") reduce 63) ((",") reduce 63) (("-") reduce 63) ((".") reduce 63) (("/") reduce 63) (("<") reduce 63) ((">") reduce 63) (("?") reduce 63) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_BOOLEAN_AND) reduce 63) ((T_BOOLEAN_OR) reduce 63) ((T_COALESCE) reduce 63) ((T_DOUBLE_ARROW) reduce 63) ((T_INSTANCEOF) reduce 63) ((T_IS_EQUAL) reduce 63) ((T_IS_GREATER_OR_EQUAL) reduce 63) ((T_IS_IDENTICAL) reduce 63) ((T_IS_NOT_EQUAL) reduce 63) ((T_IS_NOT_IDENTICAL) reduce 63) ((T_IS_SMALLER_OR_EQUAL) reduce 63) ((T_LOGICAL_AND) reduce 63) ((T_LOGICAL_OR) reduce 63) ((T_LOGICAL_XOR) reduce 63) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 63) ((T_OBJECT_OPERATOR) reduce 63) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 63) ((T_POW) reduce 63) ((T_SL) reduce 63) ((T_SPACESHIP) reduce 63) ((T_SR) reduce 63) (("[") reduce 63) (("^") reduce 63) (("{") reduce 63) (("|") reduce 63)) 1433 ((("%") reduce 56) (("(") reduce 56) ((")") reduce 56) (("*") reduce 56) (("+") reduce 56) ((",") reduce 56) (("-") reduce 56) ((".") reduce 56) (("/") reduce 56) (("<") reduce 56) ((">") reduce 56) (("?") reduce 56) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_BOOLEAN_AND) reduce 56) ((T_BOOLEAN_OR) reduce 56) ((T_COALESCE) reduce 56) ((T_DOUBLE_ARROW) reduce 56) ((T_INSTANCEOF) reduce 56) ((T_IS_EQUAL) reduce 56) ((T_IS_GREATER_OR_EQUAL) reduce 56) ((T_IS_IDENTICAL) reduce 56) ((T_IS_NOT_EQUAL) reduce 56) ((T_IS_NOT_IDENTICAL) reduce 56) ((T_IS_SMALLER_OR_EQUAL) reduce 56) ((T_LOGICAL_AND) reduce 56) ((T_LOGICAL_OR) reduce 56) ((T_LOGICAL_XOR) reduce 56) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 56) ((T_OBJECT_OPERATOR) reduce 56) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 56) ((T_POW) reduce 56) ((T_SL) reduce 56) ((T_SPACESHIP) reduce 56) ((T_SR) reduce 56) (("[") reduce 56) (("^") reduce 56) (("{") reduce 56) (("|") reduce 56)) 1434 ((("%") reduce 10) (("(") reduce 10) ((")") reduce 10) (("*") reduce 10) (("+") reduce 10) ((",") reduce 10) (("-") reduce 10) ((".") reduce 10) (("/") reduce 10) (("<") reduce 10) ((">") reduce 10) (("?") reduce 10) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_BOOLEAN_AND) reduce 10) ((T_BOOLEAN_OR) reduce 10) ((T_COALESCE) reduce 10) ((T_DOUBLE_ARROW) reduce 10) ((T_INSTANCEOF) reduce 10) ((T_IS_EQUAL) reduce 10) ((T_IS_GREATER_OR_EQUAL) reduce 10) ((T_IS_IDENTICAL) reduce 10) ((T_IS_NOT_EQUAL) reduce 10) ((T_IS_NOT_IDENTICAL) reduce 10) ((T_IS_SMALLER_OR_EQUAL) reduce 10) ((T_LOGICAL_AND) reduce 10) ((T_LOGICAL_OR) reduce 10) ((T_LOGICAL_XOR) reduce 10) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 10) ((T_OBJECT_OPERATOR) reduce 10) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 10) ((T_POW) reduce 10) ((T_SL) reduce 10) ((T_SPACESHIP) reduce 10) ((T_SR) reduce 10) (("[") reduce 10) (("^") reduce 10) (("{") reduce 10) (("|") reduce 10)) 1435 ((("%") reduce 67) (("(") reduce 67) ((")") reduce 67) (("*") reduce 67) (("+") reduce 67) ((",") reduce 67) (("-") reduce 67) ((".") reduce 67) (("/") reduce 67) (("<") reduce 67) ((">") reduce 67) (("?") reduce 67) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_BOOLEAN_AND) reduce 67) ((T_BOOLEAN_OR) reduce 67) ((T_COALESCE) reduce 67) ((T_DOUBLE_ARROW) reduce 67) ((T_INSTANCEOF) reduce 67) ((T_IS_EQUAL) reduce 67) ((T_IS_GREATER_OR_EQUAL) reduce 67) ((T_IS_IDENTICAL) reduce 67) ((T_IS_NOT_EQUAL) reduce 67) ((T_IS_NOT_IDENTICAL) reduce 67) ((T_IS_SMALLER_OR_EQUAL) reduce 67) ((T_LOGICAL_AND) reduce 67) ((T_LOGICAL_OR) reduce 67) ((T_LOGICAL_XOR) reduce 67) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 67) ((T_OBJECT_OPERATOR) reduce 67) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 67) ((T_POW) reduce 67) ((T_SL) reduce 67) ((T_SPACESHIP) reduce 67) ((T_SR) reduce 67) (("[") reduce 67) (("^") reduce 67) (("{") reduce 67) (("|") reduce 67)) 1436 ((("%") reduce 44) (("(") reduce 44) ((")") reduce 44) (("*") reduce 44) (("+") reduce 44) ((",") reduce 44) (("-") reduce 44) ((".") reduce 44) (("/") reduce 44) (("<") reduce 44) ((">") reduce 44) (("?") reduce 44) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_BOOLEAN_AND) reduce 44) ((T_BOOLEAN_OR) reduce 44) ((T_COALESCE) reduce 44) ((T_DOUBLE_ARROW) reduce 44) ((T_INSTANCEOF) reduce 44) ((T_IS_EQUAL) reduce 44) ((T_IS_GREATER_OR_EQUAL) reduce 44) ((T_IS_IDENTICAL) reduce 44) ((T_IS_NOT_EQUAL) reduce 44) ((T_IS_NOT_IDENTICAL) reduce 44) ((T_IS_SMALLER_OR_EQUAL) reduce 44) ((T_LOGICAL_AND) reduce 44) ((T_LOGICAL_OR) reduce 44) ((T_LOGICAL_XOR) reduce 44) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 44) ((T_OBJECT_OPERATOR) reduce 44) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 44) ((T_POW) reduce 44) ((T_SL) reduce 44) ((T_SPACESHIP) reduce 44) ((T_SR) reduce 44) (("[") reduce 44) (("^") reduce 44) (("{") reduce 44) (("|") reduce 44)) 1437 ((("%") reduce 75) (("(") reduce 75) ((")") reduce 75) (("*") reduce 75) (("+") reduce 75) ((",") reduce 75) (("-") reduce 75) ((".") reduce 75) (("/") reduce 75) (("<") reduce 75) ((">") reduce 75) (("?") reduce 75) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_BOOLEAN_AND) reduce 75) ((T_BOOLEAN_OR) reduce 75) ((T_COALESCE) reduce 75) ((T_DOUBLE_ARROW) reduce 75) ((T_INSTANCEOF) reduce 75) ((T_IS_EQUAL) reduce 75) ((T_IS_GREATER_OR_EQUAL) reduce 75) ((T_IS_IDENTICAL) reduce 75) ((T_IS_NOT_EQUAL) reduce 75) ((T_IS_NOT_IDENTICAL) reduce 75) ((T_IS_SMALLER_OR_EQUAL) reduce 75) ((T_LOGICAL_AND) reduce 75) ((T_LOGICAL_OR) reduce 75) ((T_LOGICAL_XOR) reduce 75) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 75) ((T_OBJECT_OPERATOR) reduce 75) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 75) ((T_POW) reduce 75) ((T_SL) reduce 75) ((T_SPACESHIP) reduce 75) ((T_SR) reduce 75) (("[") reduce 75) (("^") reduce 75) (("{") reduce 75) (("|") reduce 75)) 1438 ((("%") reduce 76) (("(") reduce 76) ((")") reduce 76) (("*") reduce 76) (("+") reduce 76) ((",") reduce 76) (("-") reduce 76) ((".") reduce 76) (("/") reduce 76) (("<") reduce 76) ((">") reduce 76) (("?") reduce 76) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_BOOLEAN_AND) reduce 76) ((T_BOOLEAN_OR) reduce 76) ((T_COALESCE) reduce 76) ((T_DOUBLE_ARROW) reduce 76) ((T_INSTANCEOF) reduce 76) ((T_IS_EQUAL) reduce 76) ((T_IS_GREATER_OR_EQUAL) reduce 76) ((T_IS_IDENTICAL) reduce 76) ((T_IS_NOT_EQUAL) reduce 76) ((T_IS_NOT_IDENTICAL) reduce 76) ((T_IS_SMALLER_OR_EQUAL) reduce 76) ((T_LOGICAL_AND) reduce 76) ((T_LOGICAL_OR) reduce 76) ((T_LOGICAL_XOR) reduce 76) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 76) ((T_OBJECT_OPERATOR) reduce 76) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 76) ((T_POW) reduce 76) ((T_SL) reduce 76) ((T_SPACESHIP) reduce 76) ((T_SR) reduce 76) (("[") reduce 76) (("^") reduce 76) (("{") reduce 76) (("|") reduce 76)) 1439 ((("%") reduce 77) (("(") reduce 77) ((")") reduce 77) (("*") reduce 77) (("+") reduce 77) ((",") reduce 77) (("-") reduce 77) ((".") reduce 77) (("/") reduce 77) (("<") reduce 77) ((">") reduce 77) (("?") reduce 77) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_BOOLEAN_AND) reduce 77) ((T_BOOLEAN_OR) reduce 77) ((T_COALESCE) reduce 77) ((T_DOUBLE_ARROW) reduce 77) ((T_INSTANCEOF) reduce 77) ((T_IS_EQUAL) reduce 77) ((T_IS_GREATER_OR_EQUAL) reduce 77) ((T_IS_IDENTICAL) reduce 77) ((T_IS_NOT_EQUAL) reduce 77) ((T_IS_NOT_IDENTICAL) reduce 77) ((T_IS_SMALLER_OR_EQUAL) reduce 77) ((T_LOGICAL_AND) reduce 77) ((T_LOGICAL_OR) reduce 77) ((T_LOGICAL_XOR) reduce 77) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 77) ((T_OBJECT_OPERATOR) reduce 77) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 77) ((T_POW) reduce 77) ((T_SL) reduce 77) ((T_SPACESHIP) reduce 77) ((T_SR) reduce 77) (("[") reduce 77) (("^") reduce 77) (("{") reduce 77) (("|") reduce 77)) 1440 ((("%") reduce 78) (("(") reduce 78) ((")") reduce 78) (("*") reduce 78) (("+") reduce 78) ((",") reduce 78) (("-") reduce 78) ((".") reduce 78) (("/") reduce 78) (("<") reduce 78) ((">") reduce 78) (("?") reduce 78) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_BOOLEAN_AND) reduce 78) ((T_BOOLEAN_OR) reduce 78) ((T_COALESCE) reduce 78) ((T_DOUBLE_ARROW) reduce 78) ((T_INSTANCEOF) reduce 78) ((T_IS_EQUAL) reduce 78) ((T_IS_GREATER_OR_EQUAL) reduce 78) ((T_IS_IDENTICAL) reduce 78) ((T_IS_NOT_EQUAL) reduce 78) ((T_IS_NOT_IDENTICAL) reduce 78) ((T_IS_SMALLER_OR_EQUAL) reduce 78) ((T_LOGICAL_AND) reduce 78) ((T_LOGICAL_OR) reduce 78) ((T_LOGICAL_XOR) reduce 78) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 78) ((T_OBJECT_OPERATOR) reduce 78) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 78) ((T_POW) reduce 78) ((T_SL) reduce 78) ((T_SPACESHIP) reduce 78) ((T_SR) reduce 78) (("[") reduce 78) (("^") reduce 78) (("{") reduce 78) (("|") reduce 78)) 1441 ((("%") reduce 4) (("(") reduce 4) ((")") reduce 4) (("*") reduce 4) (("+") reduce 4) ((",") reduce 4) (("-") reduce 4) ((".") reduce 4) (("/") reduce 4) (("<") reduce 4) ((">") reduce 4) (("?") reduce 4) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_BOOLEAN_AND) reduce 4) ((T_BOOLEAN_OR) reduce 4) ((T_COALESCE) reduce 4) ((T_DOUBLE_ARROW) reduce 4) ((T_INSTANCEOF) reduce 4) ((T_IS_EQUAL) reduce 4) ((T_IS_GREATER_OR_EQUAL) reduce 4) ((T_IS_IDENTICAL) reduce 4) ((T_IS_NOT_EQUAL) reduce 4) ((T_IS_NOT_IDENTICAL) reduce 4) ((T_IS_SMALLER_OR_EQUAL) reduce 4) ((T_LOGICAL_AND) reduce 4) ((T_LOGICAL_OR) reduce 4) ((T_LOGICAL_XOR) reduce 4) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 4) ((T_OBJECT_OPERATOR) reduce 4) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 4) ((T_POW) reduce 4) ((T_SL) reduce 4) ((T_SPACESHIP) reduce 4) ((T_SR) reduce 4) (("[") reduce 4) (("^") reduce 4) (("{") reduce 4) (("|") reduce 4)) 1442 ((("%") reduce 5) (("(") reduce 5) ((")") reduce 5) (("*") reduce 5) (("+") reduce 5) ((",") reduce 5) (("-") reduce 5) ((".") reduce 5) (("/") reduce 5) (("<") reduce 5) ((">") reduce 5) (("?") reduce 5) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_BOOLEAN_AND) reduce 5) ((T_BOOLEAN_OR) reduce 5) ((T_COALESCE) reduce 5) ((T_DOUBLE_ARROW) reduce 5) ((T_INSTANCEOF) reduce 5) ((T_IS_EQUAL) reduce 5) ((T_IS_GREATER_OR_EQUAL) reduce 5) ((T_IS_IDENTICAL) reduce 5) ((T_IS_NOT_EQUAL) reduce 5) ((T_IS_NOT_IDENTICAL) reduce 5) ((T_IS_SMALLER_OR_EQUAL) reduce 5) ((T_LOGICAL_AND) reduce 5) ((T_LOGICAL_OR) reduce 5) ((T_LOGICAL_XOR) reduce 5) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 5) ((T_OBJECT_OPERATOR) reduce 5) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 5) ((T_POW) reduce 5) ((T_SL) reduce 5) ((T_SPACESHIP) reduce 5) ((T_SR) reduce 5) (("[") reduce 5) (("^") reduce 5) (("{") reduce 5) (("|") reduce 5)) 1443 ((("%") reduce 43) (("(") reduce 43) ((")") reduce 43) (("*") reduce 43) (("+") reduce 43) ((",") reduce 43) (("-") reduce 43) ((".") reduce 43) (("/") reduce 43) (("<") reduce 43) ((">") reduce 43) (("?") reduce 43) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_BOOLEAN_AND) reduce 43) ((T_BOOLEAN_OR) reduce 43) ((T_COALESCE) reduce 43) ((T_DOUBLE_ARROW) reduce 43) ((T_INSTANCEOF) reduce 43) ((T_IS_EQUAL) reduce 43) ((T_IS_GREATER_OR_EQUAL) reduce 43) ((T_IS_IDENTICAL) reduce 43) ((T_IS_NOT_EQUAL) reduce 43) ((T_IS_NOT_IDENTICAL) reduce 43) ((T_IS_SMALLER_OR_EQUAL) reduce 43) ((T_LOGICAL_AND) reduce 43) ((T_LOGICAL_OR) reduce 43) ((T_LOGICAL_XOR) reduce 43) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 43) ((T_OBJECT_OPERATOR) reduce 43) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 43) ((T_POW) reduce 43) ((T_SL) reduce 43) ((T_SPACESHIP) reduce 43) ((T_SR) reduce 43) (("[") reduce 43) (("^") reduce 43) (("{") reduce 43) (("|") reduce 43)) 1444 ((("%") reduce 72) (("(") reduce 72) ((")") reduce 72) (("*") reduce 72) (("+") reduce 72) ((",") reduce 72) (("-") reduce 72) ((".") reduce 72) (("/") reduce 72) (("<") reduce 72) ((">") reduce 72) (("?") reduce 72) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_BOOLEAN_AND) reduce 72) ((T_BOOLEAN_OR) reduce 72) ((T_COALESCE) reduce 72) ((T_DOUBLE_ARROW) reduce 72) ((T_INSTANCEOF) reduce 72) ((T_IS_EQUAL) reduce 72) ((T_IS_GREATER_OR_EQUAL) reduce 72) ((T_IS_IDENTICAL) reduce 72) ((T_IS_NOT_EQUAL) reduce 72) ((T_IS_NOT_IDENTICAL) reduce 72) ((T_IS_SMALLER_OR_EQUAL) reduce 72) ((T_LOGICAL_AND) reduce 72) ((T_LOGICAL_OR) reduce 72) ((T_LOGICAL_XOR) reduce 72) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 72) ((T_OBJECT_OPERATOR) reduce 72) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 72) ((T_POW) reduce 72) ((T_SL) reduce 72) ((T_SPACESHIP) reduce 72) ((T_SR) reduce 72) (("[") reduce 72) (("^") reduce 72) (("{") reduce 72) (("|") reduce 72)) 1445 ((("%") reduce 81) (("(") reduce 81) ((")") reduce 81) (("*") reduce 81) (("+") reduce 81) ((",") reduce 81) (("-") reduce 81) ((".") reduce 81) (("/") reduce 81) (("<") reduce 81) ((">") reduce 81) (("?") reduce 81) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_BOOLEAN_AND) reduce 81) ((T_BOOLEAN_OR) reduce 81) ((T_COALESCE) reduce 81) ((T_DOUBLE_ARROW) reduce 81) ((T_INSTANCEOF) reduce 81) ((T_IS_EQUAL) reduce 81) ((T_IS_GREATER_OR_EQUAL) reduce 81) ((T_IS_IDENTICAL) reduce 81) ((T_IS_NOT_EQUAL) reduce 81) ((T_IS_NOT_IDENTICAL) reduce 81) ((T_IS_SMALLER_OR_EQUAL) reduce 81) ((T_LOGICAL_AND) reduce 81) ((T_LOGICAL_OR) reduce 81) ((T_LOGICAL_XOR) reduce 81) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 81) ((T_OBJECT_OPERATOR) reduce 81) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 81) ((T_POW) reduce 81) ((T_SL) reduce 81) ((T_SPACESHIP) reduce 81) ((T_SR) reduce 81) (("[") reduce 81) (("^") reduce 81) (("{") reduce 81) (("|") reduce 81)) 1446 ((("%") reduce 47) (("(") reduce 47) ((")") reduce 47) (("*") reduce 47) (("+") reduce 47) ((",") reduce 47) (("-") reduce 47) ((".") reduce 47) (("/") reduce 47) (("<") reduce 47) ((">") reduce 47) (("?") reduce 47) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_BOOLEAN_AND) reduce 47) ((T_BOOLEAN_OR) reduce 47) ((T_COALESCE) reduce 47) ((T_DOUBLE_ARROW) reduce 47) ((T_INSTANCEOF) reduce 47) ((T_IS_EQUAL) reduce 47) ((T_IS_GREATER_OR_EQUAL) reduce 47) ((T_IS_IDENTICAL) reduce 47) ((T_IS_NOT_EQUAL) reduce 47) ((T_IS_NOT_IDENTICAL) reduce 47) ((T_IS_SMALLER_OR_EQUAL) reduce 47) ((T_LOGICAL_AND) reduce 47) ((T_LOGICAL_OR) reduce 47) ((T_LOGICAL_XOR) reduce 47) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 47) ((T_OBJECT_OPERATOR) reduce 47) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 47) ((T_POW) reduce 47) ((T_SL) reduce 47) ((T_SPACESHIP) reduce 47) ((T_SR) reduce 47) (("[") reduce 47) (("^") reduce 47) (("{") reduce 47) (("|") reduce 47)) 1447 ((("%") reduce 31) (("(") reduce 31) ((")") reduce 31) (("*") reduce 31) (("+") reduce 31) ((",") reduce 31) (("-") reduce 31) ((".") reduce 31) (("/") reduce 31) (("<") reduce 31) ((">") reduce 31) (("?") reduce 31) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_BOOLEAN_AND) reduce 31) ((T_BOOLEAN_OR) reduce 31) ((T_COALESCE) reduce 31) ((T_DOUBLE_ARROW) reduce 31) ((T_INSTANCEOF) reduce 31) ((T_IS_EQUAL) reduce 31) ((T_IS_GREATER_OR_EQUAL) reduce 31) ((T_IS_IDENTICAL) reduce 31) ((T_IS_NOT_EQUAL) reduce 31) ((T_IS_NOT_IDENTICAL) reduce 31) ((T_IS_SMALLER_OR_EQUAL) reduce 31) ((T_LOGICAL_AND) reduce 31) ((T_LOGICAL_OR) reduce 31) ((T_LOGICAL_XOR) reduce 31) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 31) ((T_OBJECT_OPERATOR) reduce 31) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 31) ((T_POW) reduce 31) ((T_SL) reduce 31) ((T_SPACESHIP) reduce 31) ((T_SR) reduce 31) (("[") reduce 31) (("^") reduce 31) (("{") reduce 31) (("|") reduce 31)) 1448 ((("%") reduce 57) (("(") reduce 57) ((")") reduce 57) (("*") reduce 57) (("+") reduce 57) ((",") reduce 57) (("-") reduce 57) ((".") reduce 57) (("/") reduce 57) (("<") reduce 57) ((">") reduce 57) (("?") reduce 57) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_BOOLEAN_AND) reduce 57) ((T_BOOLEAN_OR) reduce 57) ((T_COALESCE) reduce 57) ((T_DOUBLE_ARROW) reduce 57) ((T_INSTANCEOF) reduce 57) ((T_IS_EQUAL) reduce 57) ((T_IS_GREATER_OR_EQUAL) reduce 57) ((T_IS_IDENTICAL) reduce 57) ((T_IS_NOT_EQUAL) reduce 57) ((T_IS_NOT_IDENTICAL) reduce 57) ((T_IS_SMALLER_OR_EQUAL) reduce 57) ((T_LOGICAL_AND) reduce 57) ((T_LOGICAL_OR) reduce 57) ((T_LOGICAL_XOR) reduce 57) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 57) ((T_OBJECT_OPERATOR) reduce 57) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 57) ((T_POW) reduce 57) ((T_SL) reduce 57) ((T_SPACESHIP) reduce 57) ((T_SR) reduce 57) (("[") reduce 57) (("^") reduce 57) (("{") reduce 57) (("|") reduce 57)) 1449 ((("%") reduce 61) (("(") reduce 61) ((")") reduce 61) (("*") reduce 61) (("+") reduce 61) ((",") reduce 61) (("-") reduce 61) ((".") reduce 61) (("/") reduce 61) (("<") reduce 61) ((">") reduce 61) (("?") reduce 61) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_BOOLEAN_AND) reduce 61) ((T_BOOLEAN_OR) reduce 61) ((T_COALESCE) reduce 61) ((T_DOUBLE_ARROW) reduce 61) ((T_INSTANCEOF) reduce 61) ((T_IS_EQUAL) reduce 61) ((T_IS_GREATER_OR_EQUAL) reduce 61) ((T_IS_IDENTICAL) reduce 61) ((T_IS_NOT_EQUAL) reduce 61) ((T_IS_NOT_IDENTICAL) reduce 61) ((T_IS_SMALLER_OR_EQUAL) reduce 61) ((T_LOGICAL_AND) reduce 61) ((T_LOGICAL_OR) reduce 61) ((T_LOGICAL_XOR) reduce 61) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 61) ((T_OBJECT_OPERATOR) reduce 61) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 61) ((T_POW) reduce 61) ((T_SL) reduce 61) ((T_SPACESHIP) reduce 61) ((T_SR) reduce 61) (("[") reduce 61) (("^") reduce 61) (("{") reduce 61) (("|") reduce 61)) 1450 ((("%") reduce 28) (("(") reduce 28) ((")") reduce 28) (("*") reduce 28) (("+") reduce 28) ((",") reduce 28) (("-") reduce 28) ((".") reduce 28) (("/") reduce 28) (("<") reduce 28) ((">") reduce 28) (("?") reduce 28) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_BOOLEAN_AND) reduce 28) ((T_BOOLEAN_OR) reduce 28) ((T_COALESCE) reduce 28) ((T_DOUBLE_ARROW) reduce 28) ((T_INSTANCEOF) reduce 28) ((T_IS_EQUAL) reduce 28) ((T_IS_GREATER_OR_EQUAL) reduce 28) ((T_IS_IDENTICAL) reduce 28) ((T_IS_NOT_EQUAL) reduce 28) ((T_IS_NOT_IDENTICAL) reduce 28) ((T_IS_SMALLER_OR_EQUAL) reduce 28) ((T_LOGICAL_AND) reduce 28) ((T_LOGICAL_OR) reduce 28) ((T_LOGICAL_XOR) reduce 28) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 28) ((T_OBJECT_OPERATOR) reduce 28) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 28) ((T_POW) reduce 28) ((T_SL) reduce 28) ((T_SPACESHIP) reduce 28) ((T_SR) reduce 28) (("[") reduce 28) (("^") reduce 28) (("{") reduce 28) (("|") reduce 28)) 1451 ((("%") reduce 36) (("(") reduce 36) ((")") reduce 36) (("*") reduce 36) (("+") reduce 36) ((",") reduce 36) (("-") reduce 36) ((".") reduce 36) (("/") reduce 36) (("<") reduce 36) ((">") reduce 36) (("?") reduce 36) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_BOOLEAN_AND) reduce 36) ((T_BOOLEAN_OR) reduce 36) ((T_COALESCE) reduce 36) ((T_DOUBLE_ARROW) reduce 36) ((T_INSTANCEOF) reduce 36) ((T_IS_EQUAL) reduce 36) ((T_IS_GREATER_OR_EQUAL) reduce 36) ((T_IS_IDENTICAL) reduce 36) ((T_IS_NOT_EQUAL) reduce 36) ((T_IS_NOT_IDENTICAL) reduce 36) ((T_IS_SMALLER_OR_EQUAL) reduce 36) ((T_LOGICAL_AND) reduce 36) ((T_LOGICAL_OR) reduce 36) ((T_LOGICAL_XOR) reduce 36) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 36) ((T_OBJECT_OPERATOR) reduce 36) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 36) ((T_POW) reduce 36) ((T_SL) reduce 36) ((T_SPACESHIP) reduce 36) ((T_SR) reduce 36) (("[") reduce 36) (("^") reduce 36) (("{") reduce 36) (("|") reduce 36)) 1452 ((("%") reduce 32) (("(") reduce 32) ((")") reduce 32) (("*") reduce 32) (("+") reduce 32) ((",") reduce 32) (("-") reduce 32) ((".") reduce 32) (("/") reduce 32) (("<") reduce 32) ((">") reduce 32) (("?") reduce 32) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_BOOLEAN_AND) reduce 32) ((T_BOOLEAN_OR) reduce 32) ((T_COALESCE) reduce 32) ((T_DOUBLE_ARROW) reduce 32) ((T_INSTANCEOF) reduce 32) ((T_IS_EQUAL) reduce 32) ((T_IS_GREATER_OR_EQUAL) reduce 32) ((T_IS_IDENTICAL) reduce 32) ((T_IS_NOT_EQUAL) reduce 32) ((T_IS_NOT_IDENTICAL) reduce 32) ((T_IS_SMALLER_OR_EQUAL) reduce 32) ((T_LOGICAL_AND) reduce 32) ((T_LOGICAL_OR) reduce 32) ((T_LOGICAL_XOR) reduce 32) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 32) ((T_OBJECT_OPERATOR) reduce 32) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 32) ((T_POW) reduce 32) ((T_SL) reduce 32) ((T_SPACESHIP) reduce 32) ((T_SR) reduce 32) (("[") reduce 32) (("^") reduce 32) (("{") reduce 32) (("|") reduce 32)) 1453 ((("%") reduce 35) (("(") reduce 35) ((")") reduce 35) (("*") reduce 35) (("+") reduce 35) ((",") reduce 35) (("-") reduce 35) ((".") reduce 35) (("/") reduce 35) (("<") reduce 35) ((">") reduce 35) (("?") reduce 35) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_BOOLEAN_AND) reduce 35) ((T_BOOLEAN_OR) reduce 35) ((T_COALESCE) reduce 35) ((T_DOUBLE_ARROW) reduce 35) ((T_INSTANCEOF) reduce 35) ((T_IS_EQUAL) reduce 35) ((T_IS_GREATER_OR_EQUAL) reduce 35) ((T_IS_IDENTICAL) reduce 35) ((T_IS_NOT_EQUAL) reduce 35) ((T_IS_NOT_IDENTICAL) reduce 35) ((T_IS_SMALLER_OR_EQUAL) reduce 35) ((T_LOGICAL_AND) reduce 35) ((T_LOGICAL_OR) reduce 35) ((T_LOGICAL_XOR) reduce 35) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 35) ((T_OBJECT_OPERATOR) reduce 35) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 35) ((T_POW) reduce 35) ((T_SL) reduce 35) ((T_SPACESHIP) reduce 35) ((T_SR) reduce 35) (("[") reduce 35) (("^") reduce 35) (("{") reduce 35) (("|") reduce 35)) 1454 ((("%") reduce 19) (("(") reduce 19) ((")") reduce 19) (("*") reduce 19) (("+") reduce 19) ((",") reduce 19) (("-") reduce 19) ((".") reduce 19) (("/") reduce 19) (("<") reduce 19) ((">") reduce 19) (("?") reduce 19) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_BOOLEAN_AND) reduce 19) ((T_BOOLEAN_OR) reduce 19) ((T_COALESCE) reduce 19) ((T_DOUBLE_ARROW) reduce 19) ((T_INSTANCEOF) reduce 19) ((T_IS_EQUAL) reduce 19) ((T_IS_GREATER_OR_EQUAL) reduce 19) ((T_IS_IDENTICAL) reduce 19) ((T_IS_NOT_EQUAL) reduce 19) ((T_IS_NOT_IDENTICAL) reduce 19) ((T_IS_SMALLER_OR_EQUAL) reduce 19) ((T_LOGICAL_AND) reduce 19) ((T_LOGICAL_OR) reduce 19) ((T_LOGICAL_XOR) reduce 19) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 19) ((T_OBJECT_OPERATOR) reduce 19) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 19) ((T_POW) reduce 19) ((T_SL) reduce 19) ((T_SPACESHIP) reduce 19) ((T_SR) reduce 19) (("[") reduce 19) (("^") reduce 19) (("{") reduce 19) (("|") reduce 19)) 1455 ((("%") reduce 45) (("(") reduce 45) ((")") reduce 45) (("*") reduce 45) (("+") reduce 45) ((",") reduce 45) (("-") reduce 45) ((".") reduce 45) (("/") reduce 45) (("<") reduce 45) ((">") reduce 45) (("?") reduce 45) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_BOOLEAN_AND) reduce 45) ((T_BOOLEAN_OR) reduce 45) ((T_COALESCE) reduce 45) ((T_DOUBLE_ARROW) reduce 45) ((T_INSTANCEOF) reduce 45) ((T_IS_EQUAL) reduce 45) ((T_IS_GREATER_OR_EQUAL) reduce 45) ((T_IS_IDENTICAL) reduce 45) ((T_IS_NOT_EQUAL) reduce 45) ((T_IS_NOT_IDENTICAL) reduce 45) ((T_IS_SMALLER_OR_EQUAL) reduce 45) ((T_LOGICAL_AND) reduce 45) ((T_LOGICAL_OR) reduce 45) ((T_LOGICAL_XOR) reduce 45) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 45) ((T_OBJECT_OPERATOR) reduce 45) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 45) ((T_POW) reduce 45) ((T_SL) reduce 45) ((T_SPACESHIP) reduce 45) ((T_SR) reduce 45) (("[") reduce 45) (("^") reduce 45) (("{") reduce 45) (("|") reduce 45)) 1456 ((("%") reduce 504) (("(") reduce 541) ((")") reduce 504) (("*") reduce 504) (("+") reduce 504) ((",") reduce 504) (("-") reduce 504) ((".") reduce 504) (("/") reduce 504) (("<") reduce 504) ((">") reduce 504) (("?") reduce 504) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_BOOLEAN_AND) reduce 504) ((T_BOOLEAN_OR) reduce 504) ((T_COALESCE) reduce 504) ((T_DOUBLE_ARROW) reduce 504) ((T_INSTANCEOF) reduce 504) ((T_IS_EQUAL) reduce 504) ((T_IS_GREATER_OR_EQUAL) reduce 504) ((T_IS_IDENTICAL) reduce 504) ((T_IS_NOT_EQUAL) reduce 504) ((T_IS_NOT_IDENTICAL) reduce 504) ((T_IS_SMALLER_OR_EQUAL) reduce 504) ((T_LOGICAL_AND) reduce 504) ((T_LOGICAL_OR) reduce 504) ((T_LOGICAL_XOR) reduce 504) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 504) ((T_OBJECT_OPERATOR) reduce 504) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 504) ((T_POW) reduce 504) ((T_SL) reduce 504) ((T_SPACESHIP) reduce 504) ((T_SR) reduce 504) (("[") reduce 504) (("^") reduce 504) (("{") reduce 504) (("|") reduce 504)) 1458 ((("%") reduce 71) (("(") reduce 71) ((")") reduce 71) (("*") reduce 71) (("+") reduce 71) ((",") reduce 71) (("-") reduce 71) ((".") reduce 71) (("/") reduce 71) (("<") reduce 71) ((">") reduce 71) (("?") reduce 71) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_BOOLEAN_AND) reduce 71) ((T_BOOLEAN_OR) reduce 71) ((T_COALESCE) reduce 71) ((T_DOUBLE_ARROW) reduce 71) ((T_INSTANCEOF) reduce 71) ((T_IS_EQUAL) reduce 71) ((T_IS_GREATER_OR_EQUAL) reduce 71) ((T_IS_IDENTICAL) reduce 71) ((T_IS_NOT_EQUAL) reduce 71) ((T_IS_NOT_IDENTICAL) reduce 71) ((T_IS_SMALLER_OR_EQUAL) reduce 71) ((T_LOGICAL_AND) reduce 71) ((T_LOGICAL_OR) reduce 71) ((T_LOGICAL_XOR) reduce 71) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 71) ((T_OBJECT_OPERATOR) reduce 71) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 71) ((T_POW) reduce 71) ((T_SL) reduce 71) ((T_SPACESHIP) reduce 71) ((T_SR) reduce 71) (("[") reduce 71) (("^") reduce 71) (("{") reduce 71) (("|") reduce 71)) 1459 ((("%") reduce 82) (("(") reduce 82) ((")") reduce 82) (("*") reduce 82) (("+") reduce 82) ((",") reduce 82) (("-") reduce 82) ((".") reduce 82) (("/") reduce 82) (("<") reduce 82) ((">") reduce 82) (("?") reduce 82) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_BOOLEAN_AND) reduce 82) ((T_BOOLEAN_OR) reduce 82) ((T_COALESCE) reduce 82) ((T_DOUBLE_ARROW) reduce 82) ((T_INSTANCEOF) reduce 82) ((T_IS_EQUAL) reduce 82) ((T_IS_GREATER_OR_EQUAL) reduce 82) ((T_IS_IDENTICAL) reduce 82) ((T_IS_NOT_EQUAL) reduce 82) ((T_IS_NOT_IDENTICAL) reduce 82) ((T_IS_SMALLER_OR_EQUAL) reduce 82) ((T_LOGICAL_AND) reduce 82) ((T_LOGICAL_OR) reduce 82) ((T_LOGICAL_XOR) reduce 82) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 82) ((T_OBJECT_OPERATOR) reduce 82) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 82) ((T_POW) reduce 82) ((T_SL) reduce 82) ((T_SPACESHIP) reduce 82) ((T_SR) reduce 82) (("[") reduce 82) (("^") reduce 82) (("{") reduce 82) (("|") reduce 82)) 1460 ((("%") reduce 533) (("(") reduce 543) ((")") reduce 533) (("*") reduce 533) (("+") reduce 533) ((",") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) (("<") reduce 533) (("=") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AND_EQUAL) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_COALESCE_EQUAL) reduce 533) ((T_CONCAT_EQUAL) reduce 533) ((T_DEC) reduce 533) ((T_DIV_EQUAL) reduce 533) ((T_DOUBLE_ARROW) reduce 533) ((T_INC) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_MINUS_EQUAL) reduce 533) ((T_MOD_EQUAL) reduce 533) ((T_MUL_EQUAL) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_OR_EQUAL) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_PLUS_EQUAL) reduce 533) ((T_POW) reduce 533) ((T_POW_EQUAL) reduce 533) ((T_SL) reduce 533) ((T_SL_EQUAL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) ((T_SR_EQUAL) reduce 533) ((T_XOR_EQUAL) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 1463 ((("%") reduce 506) (("(") reduce 542) ((")") reduce 506) (("*") reduce 506) (("+") reduce 506) ((",") reduce 506) (("-") reduce 506) ((".") reduce 506) (("/") reduce 506) (("<") reduce 506) ((">") reduce 506) (("?") reduce 506) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_BOOLEAN_AND) reduce 506) ((T_BOOLEAN_OR) reduce 506) ((T_COALESCE) reduce 506) ((T_DOUBLE_ARROW) reduce 506) ((T_INSTANCEOF) reduce 506) ((T_IS_EQUAL) reduce 506) ((T_IS_GREATER_OR_EQUAL) reduce 506) ((T_IS_IDENTICAL) reduce 506) ((T_IS_NOT_EQUAL) reduce 506) ((T_IS_NOT_IDENTICAL) reduce 506) ((T_IS_SMALLER_OR_EQUAL) reduce 506) ((T_LOGICAL_AND) reduce 506) ((T_LOGICAL_OR) reduce 506) ((T_LOGICAL_XOR) reduce 506) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 506) ((T_OBJECT_OPERATOR) reduce 506) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 506) ((T_POW) reduce 506) ((T_SL) reduce 506) ((T_SPACESHIP) reduce 506) ((T_SR) reduce 506) (("[") reduce 506) (("^") reduce 506) (("{") reduce 506) (("|") reduce 506)) 1465 ((("%") reduce 468) (("(") reduce 468) ((")") reduce 468) (("*") reduce 468) (("+") reduce 468) ((",") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) (("<") reduce 468) (("=") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AND_EQUAL) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_COALESCE_EQUAL) reduce 468) ((T_CONCAT_EQUAL) reduce 468) ((T_DEC) reduce 468) ((T_DIV_EQUAL) reduce 468) ((T_DOUBLE_ARROW) reduce 468) ((T_INC) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_MINUS_EQUAL) reduce 468) ((T_MOD_EQUAL) reduce 468) ((T_MUL_EQUAL) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_OR_EQUAL) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_PLUS_EQUAL) reduce 468) ((T_POW) reduce 468) ((T_POW_EQUAL) reduce 468) ((T_SL) reduce 468) ((T_SL_EQUAL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) ((T_SR_EQUAL) reduce 468) ((T_XOR_EQUAL) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 1466 ((("%") reduce 288) (("(") reduce 288) ((")") reduce 288) (("*") reduce 288) (("+") reduce 288) ((",") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) (("=") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AND_EQUAL) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_COALESCE_EQUAL) reduce 288) ((T_CONCAT_EQUAL) reduce 288) ((T_DEC) reduce 288) ((T_DIV_EQUAL) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INC) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_MINUS_EQUAL) reduce 288) ((T_MOD_EQUAL) reduce 288) ((T_MUL_EQUAL) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_OR_EQUAL) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_PLUS_EQUAL) reduce 288) ((T_POW) reduce 288) ((T_POW_EQUAL) reduce 288) ((T_SL) reduce 288) ((T_SL_EQUAL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) ((T_SR_EQUAL) reduce 288) ((T_XOR_EQUAL) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 1469 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) ((")") reduce 124) (("+") shift) (("-") shift) (("@") shift) ((T_ABSTRACT) shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_AS) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_BREAK) shift) ((T_CALLABLE) shift) ((T_CASE) shift) ((T_CATCH) shift) ((T_CLASS) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONST) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_CONTINUE) shift) ((T_DEC) shift) ((T_DECLARE) shift) ((T_DEFAULT) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DO) shift) ((T_DOUBLE_CAST) shift) ((T_ECHO) shift) ((T_ELLIPSIS) shift) ((T_ELSE) shift) ((T_ELSEIF) shift) ((T_EMPTY) shift) ((T_ENDDECLARE) shift) ((T_ENDFOR) shift) ((T_ENDFOREACH) shift) ((T_ENDIF) shift) ((T_ENDSWITCH) shift) ((T_ENDWHILE) shift) ((T_ENUM) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_EXTENDS) shift) ((T_FILE) shift) ((T_FINAL) shift) ((T_FINALLY) shift) ((T_FN) shift) ((T_FOR) shift) ((T_FOREACH) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_GLOBAL) shift) ((T_GOTO) shift) ((T_IF) shift) ((T_IMPLEMENTS) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INSTANCEOF) shift) ((T_INSTEADOF) shift) ((T_INTERFACE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAMESPACE) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_PRIVATE) shift) ((T_PROTECTED) shift) ((T_PUBLIC) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_RETURN) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_SWITCH) shift) ((T_THROW) shift) ((T_TRAIT) shift) ((T_TRAIT_C) shift) ((T_TRY) shift) ((T_UNSET) shift) ((T_UNSET_CAST) shift) ((T_USE) shift) ((T_VAR) shift) ((T_VARIABLE) shift) ((T_WHILE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("~") shift)) 1471 ((("%") reduce 289) (("(") reduce 289) ((")") reduce 289) (("*") reduce 289) (("+") reduce 289) ((",") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) (("=") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AND_EQUAL) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_COALESCE_EQUAL) reduce 289) ((T_CONCAT_EQUAL) reduce 289) ((T_DEC) reduce 289) ((T_DIV_EQUAL) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INC) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_MINUS_EQUAL) reduce 289) ((T_MOD_EQUAL) reduce 289) ((T_MUL_EQUAL) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_OR_EQUAL) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_PLUS_EQUAL) reduce 289) ((T_POW) reduce 289) ((T_POW_EQUAL) reduce 289) ((T_SL) reduce 289) ((T_SL_EQUAL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) ((T_SR_EQUAL) reduce 289) ((T_XOR_EQUAL) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 1473 (((")") reduce 292) ((",") reduce 292)) 1474 ((("%") shift) ((")") reduce 295) (("*") shift) (("+") shift) ((",") reduce 295) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 1475 ((("%") reduce 290) (("(") reduce 290) ((")") reduce 290) (("*") reduce 290) (("+") reduce 290) ((",") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) (("=") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AND_EQUAL) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_COALESCE_EQUAL) reduce 290) ((T_CONCAT_EQUAL) reduce 290) ((T_DEC) reduce 290) ((T_DIV_EQUAL) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INC) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_MINUS_EQUAL) reduce 290) ((T_MOD_EQUAL) reduce 290) ((T_MUL_EQUAL) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_OR_EQUAL) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_PLUS_EQUAL) reduce 290) ((T_POW) reduce 290) ((T_POW_EQUAL) reduce 290) ((T_SL) reduce 290) ((T_SL_EQUAL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) ((T_SR_EQUAL) reduce 290) ((T_XOR_EQUAL) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 1476 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) (("+") shift) (("-") shift) (("@") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("~") shift)) 1480 ((("%") reduce 388) ((")") reduce 388) (("*") reduce 388) (("+") reduce 388) ((",") reduce 388) (("-") reduce 388) ((".") reduce 388) (("/") reduce 388) (("<") reduce 388) ((">") reduce 388) (("?") reduce 388) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_BOOLEAN_AND) reduce 388) ((T_BOOLEAN_OR) reduce 388) ((T_COALESCE) reduce 388) ((T_DOUBLE_ARROW) reduce 388) ((T_INSTANCEOF) reduce 388) ((T_IS_EQUAL) reduce 388) ((T_IS_GREATER_OR_EQUAL) reduce 388) ((T_IS_IDENTICAL) reduce 388) ((T_IS_NOT_EQUAL) reduce 388) ((T_IS_NOT_IDENTICAL) reduce 388) ((T_IS_SMALLER_OR_EQUAL) reduce 388) ((T_LOGICAL_AND) reduce 388) ((T_LOGICAL_OR) reduce 388) ((T_LOGICAL_XOR) reduce 388) ((T_POW) reduce 388) ((T_SL) reduce 388) ((T_SPACESHIP) reduce 388) ((T_SR) reduce 388) (("^") reduce 388) (("|") reduce 388)) 1482 ((("%") reduce 386) ((")") reduce 386) (("*") reduce 386) (("+") reduce 386) ((",") reduce 386) (("-") reduce 386) ((".") reduce 386) (("/") reduce 386) (("<") reduce 386) ((">") reduce 386) (("?") reduce 386) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_BOOLEAN_AND) reduce 386) ((T_BOOLEAN_OR) reduce 386) ((T_COALESCE) reduce 386) ((T_DOUBLE_ARROW) reduce 386) ((T_INSTANCEOF) reduce 386) ((T_IS_EQUAL) reduce 386) ((T_IS_GREATER_OR_EQUAL) reduce 386) ((T_IS_IDENTICAL) reduce 386) ((T_IS_NOT_EQUAL) reduce 386) ((T_IS_NOT_IDENTICAL) reduce 386) ((T_IS_SMALLER_OR_EQUAL) reduce 386) ((T_LOGICAL_AND) reduce 386) ((T_LOGICAL_OR) reduce 386) ((T_LOGICAL_XOR) reduce 386) ((T_POW) reduce 386) ((T_SL) reduce 386) ((T_SPACESHIP) reduce 386) ((T_SR) reduce 386) (("^") reduce 386) (("|") reduce 386)) 1492 ((("%") shift) ((")") reduce 382) (("*") shift) (("+") shift) ((",") reduce 382) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 382) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 382) ((T_LOGICAL_OR) reduce 382) ((T_LOGICAL_XOR) reduce 382) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 1493 ((("%") shift) ((")") reduce 384) (("*") shift) (("+") shift) ((",") reduce 384) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 384) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 384) ((T_LOGICAL_OR) reduce 384) ((T_LOGICAL_XOR) reduce 384) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 1494 ((("%") shift) ((")") reduce 383) (("*") shift) (("+") shift) ((",") reduce 383) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 383) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 383) ((T_LOGICAL_OR) reduce 383) ((T_LOGICAL_XOR) reduce 383) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 1495 ((("%") shift) ((")") reduce 376) (("*") shift) (("+") shift) ((",") reduce 376) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 376) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 376) ((T_LOGICAL_OR) reduce 376) ((T_LOGICAL_XOR) reduce 376) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 1496 ((("%") shift) ((")") reduce 373) (("*") shift) (("+") shift) ((",") reduce 373) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 373) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 373) ((T_LOGICAL_OR) reduce 373) ((T_LOGICAL_XOR) reduce 373) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 1497 ((("%") shift) ((")") reduce 381) (("*") shift) (("+") shift) ((",") reduce 381) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 381) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 381) ((T_LOGICAL_OR) reduce 381) ((T_LOGICAL_XOR) reduce 381) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 1498 ((("%") shift) ((")") reduce 375) (("*") shift) (("+") shift) ((",") reduce 375) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 375) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 375) ((T_LOGICAL_OR) reduce 375) ((T_LOGICAL_XOR) reduce 375) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 1499 ((("%") shift) ((")") reduce 379) (("*") shift) (("+") shift) ((",") reduce 379) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 379) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 379) ((T_LOGICAL_OR) reduce 379) ((T_LOGICAL_XOR) reduce 379) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 1500 ((("%") shift) ((")") reduce 374) (("*") shift) (("+") shift) ((",") reduce 374) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 374) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 374) ((T_LOGICAL_OR) reduce 374) ((T_LOGICAL_XOR) reduce 374) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 1501 ((("%") shift) ((")") reduce 377) (("*") shift) (("+") shift) ((",") reduce 377) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 377) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 377) ((T_LOGICAL_OR) reduce 377) ((T_LOGICAL_XOR) reduce 377) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 1502 ((("%") shift) ((")") reduce 378) (("*") shift) (("+") shift) ((",") reduce 378) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 378) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 378) ((T_LOGICAL_OR) reduce 378) ((T_LOGICAL_XOR) reduce 378) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 1503 ((("%") shift) ((")") reduce 385) (("*") shift) (("+") shift) ((",") reduce 385) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 385) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 385) ((T_LOGICAL_OR) reduce 385) ((T_LOGICAL_XOR) reduce 385) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 1504 ((("%") shift) ((")") reduce 380) (("*") shift) (("+") shift) ((",") reduce 380) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 380) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 380) ((T_LOGICAL_OR) reduce 380) ((T_LOGICAL_XOR) reduce 380) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 1505 ((("\"") reduce 79) (("$") reduce 79) (("(") reduce 79) ((T_ARRAY) reduce 79) ((T_CLASS_C) reduce 79) ((T_CONSTANT_ENCAPSED_STRING) reduce 79) ((T_DIR) reduce 79) ((T_FILE) reduce 79) ((T_FUNC_C) reduce 79) ((T_LINE) reduce 79) ((T_METHOD_C) reduce 79) ((T_NAME_FULLY_QUALIFIED) reduce 79) ((T_NAME_QUALIFIED) reduce 79) ((T_NAME_RELATIVE) reduce 79) ((T_NS_C) reduce 79) ((T_READONLY) reduce 79) ((T_STATIC) reduce 79) ((T_STRING) reduce 79) ((T_TRAIT_C) reduce 79) ((T_VARIABLE) reduce 79) (("[") reduce 79)) 1506 ((("\"") reduce 80) (("$") reduce 80) (("(") reduce 80) ((T_ARRAY) reduce 80) ((T_CLASS_C) reduce 80) ((T_CONSTANT_ENCAPSED_STRING) reduce 80) ((T_DIR) reduce 80) ((T_FILE) reduce 80) ((T_FUNC_C) reduce 80) ((T_LINE) reduce 80) ((T_METHOD_C) reduce 80) ((T_NAME_FULLY_QUALIFIED) reduce 80) ((T_NAME_QUALIFIED) reduce 80) ((T_NAME_RELATIVE) reduce 80) ((T_NS_C) reduce 80) ((T_READONLY) reduce 80) ((T_STATIC) reduce 80) ((T_STRING) reduce 80) ((T_TRAIT_C) reduce 80) ((T_VARIABLE) reduce 80) (("[") reduce 80)) 1508 ((("%") shift) ((")") reduce 370) (("*") shift) (("+") shift) ((",") reduce 370) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 370) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 370) ((T_LOGICAL_OR) reduce 370) ((T_LOGICAL_XOR) reduce 370) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 1513 (((T_NULLSAFE_OBJECT_OPERATOR) reduce 502) ((T_OBJECT_OPERATOR) reduce 502) (("[") reduce 502) (("{") reduce 502)) 1514 ((("(") reduce 484) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 484) ((T_OBJECT_OPERATOR) reduce 484) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 484) (("[") reduce 484) (("{") reduce 484)) 1515 (((T_NULLSAFE_OBJECT_OPERATOR) reduce 497) ((T_OBJECT_OPERATOR) reduce 497) (("[") reduce 497) (("{") reduce 497)) 1516 (((T_NULLSAFE_OBJECT_OPERATOR) reduce 496) ((T_OBJECT_OPERATOR) reduce 496) (("[") reduce 496) (("{") reduce 496)) 1517 (((T_NULLSAFE_OBJECT_OPERATOR) reduce 500) ((T_OBJECT_OPERATOR) reduce 500) (("[") reduce 500) (("{") reduce 500)) 1518 (((T_NULLSAFE_OBJECT_OPERATOR) reduce 495) ((T_OBJECT_OPERATOR) reduce 495) (("[") reduce 495) (("{") reduce 495)) 1519 (((T_NULLSAFE_OBJECT_OPERATOR) reduce 499) ((T_OBJECT_OPERATOR) reduce 499) (("[") reduce 499) (("{") reduce 499)) 1520 ((("(") reduce 93) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 93) ((T_OBJECT_OPERATOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) (("[") reduce 93) (("{") reduce 93)) 1521 ((("(") reduce 92) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 92) ((T_OBJECT_OPERATOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) (("[") reduce 92) (("{") reduce 92)) 1522 ((("(") reduce 94) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 94) ((T_OBJECT_OPERATOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) (("[") reduce 94) (("{") reduce 94)) 1523 (((T_NULLSAFE_OBJECT_OPERATOR) reduce 501) ((T_OBJECT_OPERATOR) reduce 501) (("[") reduce 501) (("{") reduce 501)) 1525 (((T_PAAMAYIM_NEKUDOTAYIM) reduce 470)) 1526 ((("(") reduce 91) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 91) ((T_OBJECT_OPERATOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) (("[") reduce 91) (("{") reduce 91)) 1527 (((T_NULLSAFE_OBJECT_OPERATOR) reduce 498) ((T_OBJECT_OPERATOR) reduce 498) (("[") reduce 498) (("{") reduce 498)) 1528 ((("%") reduce 529) (("(") reduce 529) ((")") reduce 529) (("*") reduce 529) (("+") reduce 529) ((",") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 1532 ((("%") reduce 525) (("(") reduce 516) ((")") reduce 525) (("*") reduce 525) (("+") reduce 525) ((",") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) (("<") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_DOUBLE_ARROW) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_POW) reduce 525) ((T_SL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 1533 (((T_NULLSAFE_OBJECT_OPERATOR) reduce 513) ((T_OBJECT_OPERATOR) reduce 513) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 513) (("[") reduce 513) (("{") reduce 513)) 1535 (((T_NULLSAFE_OBJECT_OPERATOR) reduce 515) ((T_OBJECT_OPERATOR) reduce 515) (("[") reduce 515) (("{") reduce 515)) 1536 ((("(") reduce 518) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 512) ((T_OBJECT_OPERATOR) reduce 512) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 512) (("[") reduce 512) (("{") reduce 512)) 1537 ((("%") reduce 524) (("(") reduce 524) ((")") reduce 524) (("*") reduce 524) (("+") reduce 524) ((",") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) (("<") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_DOUBLE_ARROW) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_POW) reduce 524) ((T_SL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 1538 ((("(") shift) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 494) ((T_OBJECT_OPERATOR) reduce 494) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) (("[") reduce 494) (("{") reduce 494)) 1539 ((("%") reduce 519) (("(") reduce 519) ((")") reduce 519) (("*") reduce 519) (("+") reduce 519) ((",") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) (("<") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_DOUBLE_ARROW) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_POW) reduce 519) ((T_SL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 1540 ((("%") reduce 526) ((")") reduce 526) (("*") reduce 526) (("+") reduce 526) ((",") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) (("<") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_DOUBLE_ARROW) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_POW) reduce 526) ((T_SL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 1541 ((("%") reduce 371) ((")") reduce 371) (("*") reduce 371) (("+") reduce 371) ((",") reduce 371) (("-") reduce 371) ((".") reduce 371) (("/") reduce 371) (("<") reduce 371) ((">") reduce 371) (("?") reduce 371) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_BOOLEAN_AND) reduce 371) ((T_BOOLEAN_OR) reduce 371) ((T_COALESCE) reduce 371) ((T_DOUBLE_ARROW) reduce 371) ((T_INSTANCEOF) reduce 371) ((T_IS_EQUAL) reduce 371) ((T_IS_GREATER_OR_EQUAL) reduce 371) ((T_IS_IDENTICAL) reduce 371) ((T_IS_NOT_EQUAL) reduce 371) ((T_IS_NOT_IDENTICAL) reduce 371) ((T_IS_SMALLER_OR_EQUAL) reduce 371) ((T_LOGICAL_AND) reduce 371) ((T_LOGICAL_OR) reduce 371) ((T_LOGICAL_XOR) reduce 371) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 371) ((T_SL) reduce 371) ((T_SPACESHIP) reduce 371) ((T_SR) reduce 371) (("[") reduce 510) (("^") reduce 371) (("{") reduce 510) (("|") reduce 371)) 1544 ((("(") reduce 73) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 73) ((T_OBJECT_OPERATOR) reduce 73) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 73) (("[") reduce 73) (("{") reduce 73)) 1545 ((("(") reduce 52) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 52) ((T_OBJECT_OPERATOR) reduce 52) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 52) (("[") reduce 52) (("{") reduce 52)) 1546 ((("(") reduce 27) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 27) ((T_OBJECT_OPERATOR) reduce 27) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 27) (("[") reduce 27) (("{") reduce 27)) 1547 ((("(") reduce 51) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 51) ((T_OBJECT_OPERATOR) reduce 51) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 51) (("[") reduce 51) (("{") reduce 51)) 1548 ((("(") reduce 53) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 53) ((T_OBJECT_OPERATOR) reduce 53) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 53) (("[") reduce 53) (("{") reduce 53)) 1549 ((("(") reduce 49) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 49) ((T_OBJECT_OPERATOR) reduce 49) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 49) (("[") reduce 49) (("{") reduce 49)) 1550 ((("(") reduce 29) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 29) ((T_OBJECT_OPERATOR) reduce 29) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 29) (("[") reduce 29) (("{") reduce 29)) 1551 ((("(") reduce 59) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 59) ((T_OBJECT_OPERATOR) reduce 59) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 59) (("[") reduce 59) (("{") reduce 59)) 1552 ((("(") reduce 60) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 60) ((T_OBJECT_OPERATOR) reduce 60) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 60) (("[") reduce 60) (("{") reduce 60)) 1553 ((("(") reduce 11) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 11) ((T_OBJECT_OPERATOR) reduce 11) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 11) (("[") reduce 11) (("{") reduce 11)) 1554 ((("(") reduce 42) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 42) ((T_OBJECT_OPERATOR) reduce 42) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 42) (("[") reduce 42) (("{") reduce 42)) 1555 ((("(") reduce 39) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 39) ((T_OBJECT_OPERATOR) reduce 39) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 39) (("[") reduce 39) (("{") reduce 39)) 1556 ((("(") reduce 25) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 25) ((T_OBJECT_OPERATOR) reduce 25) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 25) (("[") reduce 25) (("{") reduce 25)) 1557 ((("(") reduce 50) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 50) ((T_OBJECT_OPERATOR) reduce 50) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 50) (("[") reduce 50) (("{") reduce 50)) 1558 ((("(") reduce 66) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 66) ((T_OBJECT_OPERATOR) reduce 66) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 66) (("[") reduce 66) (("{") reduce 66)) 1559 ((("(") reduce 18) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 18) ((T_OBJECT_OPERATOR) reduce 18) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 18) (("[") reduce 18) (("{") reduce 18)) 1560 ((("(") reduce 17) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 17) ((T_OBJECT_OPERATOR) reduce 17) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 17) (("[") reduce 17) (("{") reduce 17)) 1561 ((("(") reduce 15) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 15) ((T_OBJECT_OPERATOR) reduce 15) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 15) (("[") reduce 15) (("{") reduce 15)) 1562 ((("(") reduce 14) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 14) ((T_OBJECT_OPERATOR) reduce 14) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 14) (("[") reduce 14) (("{") reduce 14)) 1563 ((("(") reduce 38) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 38) ((T_OBJECT_OPERATOR) reduce 38) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 38) (("[") reduce 38) (("{") reduce 38)) 1564 ((("(") reduce 26) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 26) ((T_OBJECT_OPERATOR) reduce 26) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 26) (("[") reduce 26) (("{") reduce 26)) 1565 ((("(") reduce 22) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 22) ((T_OBJECT_OPERATOR) reduce 22) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 22) (("[") reduce 22) (("{") reduce 22)) 1566 ((("(") reduce 24) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 24) ((T_OBJECT_OPERATOR) reduce 24) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 24) (("[") reduce 24) (("{") reduce 24)) 1567 ((("(") reduce 16) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 16) ((T_OBJECT_OPERATOR) reduce 16) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 16) (("[") reduce 16) (("{") reduce 16)) 1568 ((("(") reduce 48) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 48) ((T_OBJECT_OPERATOR) reduce 48) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 48) (("[") reduce 48) (("{") reduce 48)) 1569 ((("(") reduce 20) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 20) ((T_OBJECT_OPERATOR) reduce 20) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 20) (("[") reduce 20) (("{") reduce 20)) 1570 ((("(") reduce 70) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 70) ((T_OBJECT_OPERATOR) reduce 70) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 70) (("[") reduce 70) (("{") reduce 70)) 1571 ((("(") reduce 3) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 3) ((T_OBJECT_OPERATOR) reduce 3) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 3) (("[") reduce 3) (("{") reduce 3)) 1572 ((("(") reduce 12) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 12) ((T_OBJECT_OPERATOR) reduce 12) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 12) (("[") reduce 12) (("{") reduce 12)) 1573 ((("(") reduce 54) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 54) ((T_OBJECT_OPERATOR) reduce 54) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 54) (("[") reduce 54) (("{") reduce 54)) 1574 ((("(") reduce 65) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 65) ((T_OBJECT_OPERATOR) reduce 65) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 65) (("[") reduce 65) (("{") reduce 65)) 1575 ((("(") reduce 74) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 74) ((T_OBJECT_OPERATOR) reduce 74) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 74) (("[") reduce 74) (("{") reduce 74)) 1576 ((("(") reduce 30) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 30) ((T_OBJECT_OPERATOR) reduce 30) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 30) (("[") reduce 30) (("{") reduce 30)) 1577 ((("(") reduce 68) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 68) ((T_OBJECT_OPERATOR) reduce 68) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 68) (("[") reduce 68) (("{") reduce 68)) 1578 ((("(") reduce 21) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 21) ((T_OBJECT_OPERATOR) reduce 21) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 21) (("[") reduce 21) (("{") reduce 21)) 1579 ((("(") reduce 23) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 23) ((T_OBJECT_OPERATOR) reduce 23) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 23) (("[") reduce 23) (("{") reduce 23)) 1580 ((("(") reduce 41) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 41) ((T_OBJECT_OPERATOR) reduce 41) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 41) (("[") reduce 41) (("{") reduce 41)) 1581 ((("(") reduce 62) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 62) ((T_OBJECT_OPERATOR) reduce 62) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 62) (("[") reduce 62) (("{") reduce 62)) 1582 ((("(") reduce 34) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 34) ((T_OBJECT_OPERATOR) reduce 34) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 34) (("[") reduce 34) (("{") reduce 34)) 1583 ((("(") reduce 40) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 40) ((T_OBJECT_OPERATOR) reduce 40) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 40) (("[") reduce 40) (("{") reduce 40)) 1584 ((("(") reduce 13) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 13) ((T_OBJECT_OPERATOR) reduce 13) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 13) (("[") reduce 13) (("{") reduce 13)) 1585 ((("(") reduce 55) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 55) ((T_OBJECT_OPERATOR) reduce 55) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 55) (("[") reduce 55) (("{") reduce 55)) 1586 ((("(") reduce 1) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 1) ((T_OBJECT_OPERATOR) reduce 1) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 1) (("[") reduce 1) (("{") reduce 1)) 1587 ((("(") reduce 2) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 2) ((T_OBJECT_OPERATOR) reduce 2) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 2) (("[") reduce 2) (("{") reduce 2)) 1588 ((("(") reduce 9) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 9) ((T_OBJECT_OPERATOR) reduce 9) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 9) (("[") reduce 9) (("{") reduce 9)) 1589 ((("(") reduce 33) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 33) ((T_OBJECT_OPERATOR) reduce 33) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 33) (("[") reduce 33) (("{") reduce 33)) 1590 ((("(") reduce 58) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 58) ((T_OBJECT_OPERATOR) reduce 58) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 58) (("[") reduce 58) (("{") reduce 58)) 1591 ((("(") reduce 37) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 37) ((T_OBJECT_OPERATOR) reduce 37) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 37) (("[") reduce 37) (("{") reduce 37)) 1592 ((("(") reduce 64) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 64) ((T_OBJECT_OPERATOR) reduce 64) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 64) (("[") reduce 64) (("{") reduce 64)) 1593 ((("(") reduce 46) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 46) ((T_OBJECT_OPERATOR) reduce 46) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 46) (("[") reduce 46) (("{") reduce 46)) 1594 ((("(") reduce 8) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 8) ((T_OBJECT_OPERATOR) reduce 8) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 8) (("[") reduce 8) (("{") reduce 8)) 1595 ((("(") reduce 6) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 6) ((T_OBJECT_OPERATOR) reduce 6) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 6) (("[") reduce 6) (("{") reduce 6)) 1596 ((("(") reduce 7) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 7) ((T_OBJECT_OPERATOR) reduce 7) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 7) (("[") reduce 7) (("{") reduce 7)) 1597 ((("(") reduce 69) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 69) ((T_OBJECT_OPERATOR) reduce 69) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 69) (("[") reduce 69) (("{") reduce 69)) 1598 ((("(") reduce 63) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 63) ((T_OBJECT_OPERATOR) reduce 63) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 63) (("[") reduce 63) (("{") reduce 63)) 1599 ((("(") reduce 56) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 56) ((T_OBJECT_OPERATOR) reduce 56) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 56) (("[") reduce 56) (("{") reduce 56)) 1600 ((("(") reduce 10) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 10) ((T_OBJECT_OPERATOR) reduce 10) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 10) (("[") reduce 10) (("{") reduce 10)) 1601 ((("(") reduce 67) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 67) ((T_OBJECT_OPERATOR) reduce 67) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 67) (("[") reduce 67) (("{") reduce 67)) 1602 ((("(") reduce 44) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 44) ((T_OBJECT_OPERATOR) reduce 44) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 44) (("[") reduce 44) (("{") reduce 44)) 1603 ((("(") reduce 75) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 75) ((T_OBJECT_OPERATOR) reduce 75) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 75) (("[") reduce 75) (("{") reduce 75)) 1604 ((("(") reduce 76) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 76) ((T_OBJECT_OPERATOR) reduce 76) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 76) (("[") reduce 76) (("{") reduce 76)) 1605 ((("(") reduce 77) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 77) ((T_OBJECT_OPERATOR) reduce 77) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 77) (("[") reduce 77) (("{") reduce 77)) 1606 ((("(") reduce 78) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 78) ((T_OBJECT_OPERATOR) reduce 78) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 78) (("[") reduce 78) (("{") reduce 78)) 1607 ((("(") reduce 4) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 4) ((T_OBJECT_OPERATOR) reduce 4) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 4) (("[") reduce 4) (("{") reduce 4)) 1608 ((("(") reduce 5) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 5) ((T_OBJECT_OPERATOR) reduce 5) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 5) (("[") reduce 5) (("{") reduce 5)) 1609 ((("(") reduce 43) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 43) ((T_OBJECT_OPERATOR) reduce 43) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 43) (("[") reduce 43) (("{") reduce 43)) 1610 ((("(") reduce 72) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 72) ((T_OBJECT_OPERATOR) reduce 72) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 72) (("[") reduce 72) (("{") reduce 72)) 1611 ((("(") reduce 81) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 81) ((T_OBJECT_OPERATOR) reduce 81) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 81) (("[") reduce 81) (("{") reduce 81)) 1612 ((("(") reduce 47) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 47) ((T_OBJECT_OPERATOR) reduce 47) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 47) (("[") reduce 47) (("{") reduce 47)) 1613 ((("(") reduce 31) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 31) ((T_OBJECT_OPERATOR) reduce 31) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 31) (("[") reduce 31) (("{") reduce 31)) 1614 ((("(") reduce 57) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 57) ((T_OBJECT_OPERATOR) reduce 57) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 57) (("[") reduce 57) (("{") reduce 57)) 1615 ((("(") reduce 61) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 61) ((T_OBJECT_OPERATOR) reduce 61) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 61) (("[") reduce 61) (("{") reduce 61)) 1616 ((("(") reduce 28) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 28) ((T_OBJECT_OPERATOR) reduce 28) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 28) (("[") reduce 28) (("{") reduce 28)) 1617 ((("(") reduce 36) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 36) ((T_OBJECT_OPERATOR) reduce 36) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 36) (("[") reduce 36) (("{") reduce 36)) 1618 ((("(") reduce 32) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 32) ((T_OBJECT_OPERATOR) reduce 32) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 32) (("[") reduce 32) (("{") reduce 32)) 1619 ((("(") reduce 35) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 35) ((T_OBJECT_OPERATOR) reduce 35) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 35) (("[") reduce 35) (("{") reduce 35)) 1620 ((("(") reduce 19) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 19) ((T_OBJECT_OPERATOR) reduce 19) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 19) (("[") reduce 19) (("{") reduce 19)) 1621 ((("(") reduce 45) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 45) ((T_OBJECT_OPERATOR) reduce 45) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 45) (("[") reduce 45) (("{") reduce 45)) 1622 ((("(") reduce 541) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 504) ((T_OBJECT_OPERATOR) reduce 504) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 504) (("[") reduce 504) (("{") reduce 504)) 1624 ((("(") reduce 71) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 71) ((T_OBJECT_OPERATOR) reduce 71) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 71) (("[") reduce 71) (("{") reduce 71)) 1625 ((("(") reduce 82) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 82) ((T_OBJECT_OPERATOR) reduce 82) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 82) (("[") reduce 82) (("{") reduce 82)) 1626 ((("%") reduce 533) (("(") reduce 543) ((")") reduce 533) (("*") reduce 533) (("+") reduce 533) ((",") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) (("<") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_DOUBLE_ARROW) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_POW) reduce 533) ((T_SL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 1629 ((("(") reduce 542) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 506) ((T_OBJECT_OPERATOR) reduce 506) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 506) (("[") reduce 506) (("{") reduce 506)) 1631 ((("%") reduce 468) (("(") reduce 468) ((")") reduce 468) (("*") reduce 468) (("+") reduce 468) ((",") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) (("<") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_DOUBLE_ARROW) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_POW) reduce 468) ((T_SL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 1632 ((("%") reduce 288) (("(") reduce 288) ((")") reduce 288) (("*") reduce 288) (("+") reduce 288) ((",") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 1636 ((("%") reduce 289) (("(") reduce 289) ((")") reduce 289) (("*") reduce 289) (("+") reduce 289) ((",") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 1637 ((("%") reduce 290) (("(") reduce 290) ((")") reduce 290) (("*") reduce 290) (("+") reduce 290) ((",") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 1638 ((("%") reduce 465) (("(") reduce 465) ((")") reduce 465) (("*") reduce 465) (("+") reduce 465) ((",") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) (("<") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_DOUBLE_ARROW) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_POW) reduce 465) ((T_SL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 1640 ((("(") reduce 541) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 503) ((T_OBJECT_OPERATOR) reduce 503) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 503) (("[") reduce 503) (("{") reduce 503)) 1642 ((("%") reduce 532) (("(") reduce 543) ((")") reduce 532) (("*") reduce 532) (("+") reduce 532) ((",") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) (("<") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_DOUBLE_ARROW) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_POW) reduce 532) ((T_SL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 1645 ((("(") reduce 542) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 505) ((T_OBJECT_OPERATOR) reduce 505) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 505) (("[") reduce 505) (("{") reduce 505)) 1646 ((("%") reduce 467) (("(") reduce 467) ((")") reduce 467) (("*") reduce 467) (("+") reduce 467) ((",") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) (("<") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_DOUBLE_ARROW) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_POW) reduce 467) ((T_SL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 1647 ((("%") reduce 469) (("(") reduce 469) ((")") reduce 469) (("*") reduce 469) (("+") reduce 469) ((",") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) (("<") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_DOUBLE_ARROW) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_POW) reduce 469) ((T_SL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 1653 ((("%") reduce 521) (("(") reduce 521) ((")") reduce 521) (("*") reduce 521) (("+") reduce 521) ((",") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) (("<") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_DOUBLE_ARROW) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_POW) reduce 521) ((T_SL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 1655 ((("%") reduce 520) (("(") reduce 520) ((")") reduce 520) (("*") reduce 520) (("+") reduce 520) ((",") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) (("<") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_DOUBLE_ARROW) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_POW) reduce 520) ((T_SL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 1656 ((("%") reduce 544) (("(") reduce 544) ((")") reduce 544) (("*") reduce 544) (("+") reduce 544) ((",") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 1657 ((("%") reduce 527) (("(") shift) ((")") reduce 527) (("*") reduce 527) (("+") reduce 527) ((",") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) (("<") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_DOUBLE_ARROW) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_POW) reduce 527) ((T_SL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 1658 ((("%") reduce 546) (("(") reduce 546) ((")") reduce 546) (("*") reduce 546) (("+") reduce 546) ((",") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 1661 ((("%") reduce 545) (("(") reduce 545) ((")") reduce 545) (("*") reduce 545) (("+") reduce 545) ((",") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 1662 ((("%") reduce 522) (("(") reduce 522) ((")") reduce 522) (("*") reduce 522) (("+") reduce 522) ((",") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) (("<") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_DOUBLE_ARROW) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_POW) reduce 522) ((T_SL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 1663 ((("%") reduce 528) (("(") shift) ((")") reduce 528) (("*") reduce 528) (("+") reduce 528) ((",") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) (("<") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_DOUBLE_ARROW) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_POW) reduce 528) ((T_SL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 1664 ((("%") reduce 523) (("(") reduce 523) ((")") reduce 523) (("*") reduce 523) (("+") reduce 523) ((",") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) (("<") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_DOUBLE_ARROW) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_POW) reduce 523) ((T_SL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 1675 ((("%") reduce 502) (("*") reduce 502) (("+") reduce 502) ((",") reduce 502) (("-") reduce 502) ((".") reduce 502) (("/") reduce 502) (("<") reduce 502) ((">") reduce 502) (("?") reduce 502) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_BOOLEAN_AND) reduce 502) ((T_BOOLEAN_OR) reduce 502) ((T_COALESCE) reduce 502) ((T_DOUBLE_ARROW) reduce 502) ((T_INSTANCEOF) reduce 502) ((T_IS_EQUAL) reduce 502) ((T_IS_GREATER_OR_EQUAL) reduce 502) ((T_IS_IDENTICAL) reduce 502) ((T_IS_NOT_EQUAL) reduce 502) ((T_IS_NOT_IDENTICAL) reduce 502) ((T_IS_SMALLER_OR_EQUAL) reduce 502) ((T_LOGICAL_AND) reduce 502) ((T_LOGICAL_OR) reduce 502) ((T_LOGICAL_XOR) reduce 502) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 502) ((T_OBJECT_OPERATOR) reduce 502) ((T_POW) reduce 502) ((T_SL) reduce 502) ((T_SPACESHIP) reduce 502) ((T_SR) reduce 502) (("[") reduce 502) (("]") reduce 502) (("^") reduce 502) (("{") reduce 502) (("|") reduce 502)) 1677 ((("%") reduce 484) (("(") reduce 484) (("*") reduce 484) (("+") reduce 484) ((",") reduce 484) (("-") reduce 484) ((".") reduce 484) (("/") reduce 484) (("<") reduce 484) ((">") reduce 484) (("?") reduce 484) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_BOOLEAN_AND) reduce 484) ((T_BOOLEAN_OR) reduce 484) ((T_COALESCE) reduce 484) ((T_DOUBLE_ARROW) reduce 484) ((T_INSTANCEOF) reduce 484) ((T_IS_EQUAL) reduce 484) ((T_IS_GREATER_OR_EQUAL) reduce 484) ((T_IS_IDENTICAL) reduce 484) ((T_IS_NOT_EQUAL) reduce 484) ((T_IS_NOT_IDENTICAL) reduce 484) ((T_IS_SMALLER_OR_EQUAL) reduce 484) ((T_LOGICAL_AND) reduce 484) ((T_LOGICAL_OR) reduce 484) ((T_LOGICAL_XOR) reduce 484) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 484) ((T_OBJECT_OPERATOR) reduce 484) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 484) ((T_POW) reduce 484) ((T_SL) reduce 484) ((T_SPACESHIP) reduce 484) ((T_SR) reduce 484) (("[") reduce 484) (("]") reduce 484) (("^") reduce 484) (("{") reduce 484) (("|") reduce 484)) 1679 ((("%") reduce 497) (("*") reduce 497) (("+") reduce 497) ((",") reduce 497) (("-") reduce 497) ((".") reduce 497) (("/") reduce 497) (("<") reduce 497) ((">") reduce 497) (("?") reduce 497) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_BOOLEAN_AND) reduce 497) ((T_BOOLEAN_OR) reduce 497) ((T_COALESCE) reduce 497) ((T_DOUBLE_ARROW) reduce 497) ((T_INSTANCEOF) reduce 497) ((T_IS_EQUAL) reduce 497) ((T_IS_GREATER_OR_EQUAL) reduce 497) ((T_IS_IDENTICAL) reduce 497) ((T_IS_NOT_EQUAL) reduce 497) ((T_IS_NOT_IDENTICAL) reduce 497) ((T_IS_SMALLER_OR_EQUAL) reduce 497) ((T_LOGICAL_AND) reduce 497) ((T_LOGICAL_OR) reduce 497) ((T_LOGICAL_XOR) reduce 497) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 497) ((T_OBJECT_OPERATOR) reduce 497) ((T_POW) reduce 497) ((T_SL) reduce 497) ((T_SPACESHIP) reduce 497) ((T_SR) reduce 497) (("[") reduce 497) (("]") reduce 497) (("^") reduce 497) (("{") reduce 497) (("|") reduce 497)) 1680 ((("%") reduce 487) (("*") reduce 487) (("+") reduce 487) ((",") reduce 487) (("-") reduce 487) ((".") reduce 487) (("/") reduce 487) (("<") reduce 487) ((">") reduce 487) (("?") reduce 487) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_BOOLEAN_AND) reduce 487) ((T_BOOLEAN_OR) reduce 487) ((T_COALESCE) reduce 487) ((T_DOUBLE_ARROW) reduce 487) ((T_INSTANCEOF) reduce 487) ((T_IS_EQUAL) reduce 487) ((T_IS_GREATER_OR_EQUAL) reduce 487) ((T_IS_IDENTICAL) reduce 487) ((T_IS_NOT_EQUAL) reduce 487) ((T_IS_NOT_IDENTICAL) reduce 487) ((T_IS_SMALLER_OR_EQUAL) reduce 487) ((T_LOGICAL_AND) reduce 487) ((T_LOGICAL_OR) reduce 487) ((T_LOGICAL_XOR) reduce 487) ((T_POW) reduce 487) ((T_SL) reduce 487) ((T_SPACESHIP) reduce 487) ((T_SR) reduce 487) (("]") reduce 487) (("^") reduce 487) (("|") reduce 487)) 1685 ((("%") reduce 475) (("(") shift) (("*") reduce 475) (("+") reduce 475) ((",") reduce 475) (("-") reduce 475) ((".") reduce 475) (("/") reduce 475) (("<") reduce 475) ((">") reduce 475) (("?") reduce 475) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_BOOLEAN_AND) reduce 475) ((T_BOOLEAN_OR) reduce 475) ((T_COALESCE) reduce 475) ((T_DOUBLE_ARROW) reduce 475) ((T_INSTANCEOF) reduce 475) ((T_IS_EQUAL) reduce 475) ((T_IS_GREATER_OR_EQUAL) reduce 475) ((T_IS_IDENTICAL) reduce 475) ((T_IS_NOT_EQUAL) reduce 475) ((T_IS_NOT_IDENTICAL) reduce 475) ((T_IS_SMALLER_OR_EQUAL) reduce 475) ((T_LOGICAL_AND) reduce 475) ((T_LOGICAL_OR) reduce 475) ((T_LOGICAL_XOR) reduce 475) ((T_POW) reduce 475) ((T_SL) reduce 475) ((T_SPACESHIP) reduce 475) ((T_SR) reduce 475) (("]") reduce 475) (("^") reduce 475) (("|") reduce 475)) 1686 ((("%") reduce 496) (("*") reduce 496) (("+") reduce 496) ((",") reduce 496) (("-") reduce 496) ((".") reduce 496) (("/") reduce 496) (("<") reduce 496) ((">") reduce 496) (("?") reduce 496) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_BOOLEAN_AND) reduce 496) ((T_BOOLEAN_OR) reduce 496) ((T_COALESCE) reduce 496) ((T_DOUBLE_ARROW) reduce 496) ((T_INSTANCEOF) reduce 496) ((T_IS_EQUAL) reduce 496) ((T_IS_GREATER_OR_EQUAL) reduce 496) ((T_IS_IDENTICAL) reduce 496) ((T_IS_NOT_EQUAL) reduce 496) ((T_IS_NOT_IDENTICAL) reduce 496) ((T_IS_SMALLER_OR_EQUAL) reduce 496) ((T_LOGICAL_AND) reduce 496) ((T_LOGICAL_OR) reduce 496) ((T_LOGICAL_XOR) reduce 496) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 496) ((T_OBJECT_OPERATOR) reduce 496) ((T_POW) reduce 496) ((T_SL) reduce 496) ((T_SPACESHIP) reduce 496) ((T_SR) reduce 496) (("[") reduce 496) (("]") reduce 496) (("^") reduce 496) (("{") reduce 496) (("|") reduce 496)) 1687 ((("%") reduce 500) (("*") reduce 500) (("+") reduce 500) ((",") reduce 500) (("-") reduce 500) ((".") reduce 500) (("/") reduce 500) (("<") reduce 500) ((">") reduce 500) (("?") reduce 500) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_BOOLEAN_AND) reduce 500) ((T_BOOLEAN_OR) reduce 500) ((T_COALESCE) reduce 500) ((T_DOUBLE_ARROW) reduce 500) ((T_INSTANCEOF) reduce 500) ((T_IS_EQUAL) reduce 500) ((T_IS_GREATER_OR_EQUAL) reduce 500) ((T_IS_IDENTICAL) reduce 500) ((T_IS_NOT_EQUAL) reduce 500) ((T_IS_NOT_IDENTICAL) reduce 500) ((T_IS_SMALLER_OR_EQUAL) reduce 500) ((T_LOGICAL_AND) reduce 500) ((T_LOGICAL_OR) reduce 500) ((T_LOGICAL_XOR) reduce 500) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 500) ((T_OBJECT_OPERATOR) reduce 500) ((T_POW) reduce 500) ((T_SL) reduce 500) ((T_SPACESHIP) reduce 500) ((T_SR) reduce 500) (("[") reduce 500) (("]") reduce 500) (("^") reduce 500) (("{") reduce 500) (("|") reduce 500)) 1693 ((("%") reduce 495) (("*") reduce 495) (("+") reduce 495) ((",") reduce 495) (("-") reduce 495) ((".") reduce 495) (("/") reduce 495) (("<") reduce 495) ((">") reduce 495) (("?") reduce 495) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_BOOLEAN_AND) reduce 495) ((T_BOOLEAN_OR) reduce 495) ((T_COALESCE) reduce 495) ((T_DOUBLE_ARROW) reduce 495) ((T_INSTANCEOF) reduce 495) ((T_IS_EQUAL) reduce 495) ((T_IS_GREATER_OR_EQUAL) reduce 495) ((T_IS_IDENTICAL) reduce 495) ((T_IS_NOT_EQUAL) reduce 495) ((T_IS_NOT_IDENTICAL) reduce 495) ((T_IS_SMALLER_OR_EQUAL) reduce 495) ((T_LOGICAL_AND) reduce 495) ((T_LOGICAL_OR) reduce 495) ((T_LOGICAL_XOR) reduce 495) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 495) ((T_OBJECT_OPERATOR) reduce 495) ((T_POW) reduce 495) ((T_SL) reduce 495) ((T_SPACESHIP) reduce 495) ((T_SR) reduce 495) (("[") reduce 495) (("]") reduce 495) (("^") reduce 495) (("{") reduce 495) (("|") reduce 495)) 1695 ((("%") reduce 486) (("*") reduce 486) (("+") reduce 486) ((",") reduce 486) (("-") reduce 486) ((".") reduce 486) (("/") reduce 486) (("<") reduce 486) ((">") reduce 486) (("?") reduce 486) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_BOOLEAN_AND) reduce 486) ((T_BOOLEAN_OR) reduce 486) ((T_COALESCE) reduce 486) ((T_DOUBLE_ARROW) reduce 486) ((T_INSTANCEOF) reduce 486) ((T_IS_EQUAL) reduce 486) ((T_IS_GREATER_OR_EQUAL) reduce 486) ((T_IS_IDENTICAL) reduce 486) ((T_IS_NOT_EQUAL) reduce 486) ((T_IS_NOT_IDENTICAL) reduce 486) ((T_IS_SMALLER_OR_EQUAL) reduce 486) ((T_LOGICAL_AND) reduce 486) ((T_LOGICAL_OR) reduce 486) ((T_LOGICAL_XOR) reduce 486) ((T_POW) reduce 486) ((T_SL) reduce 486) ((T_SPACESHIP) reduce 486) ((T_SR) reduce 486) (("]") reduce 486) (("^") reduce 486) (("|") reduce 486)) 1697 ((("%") reduce 499) (("*") reduce 499) (("+") reduce 499) ((",") reduce 499) (("-") reduce 499) ((".") reduce 499) (("/") reduce 499) (("<") reduce 499) ((">") reduce 499) (("?") reduce 499) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_BOOLEAN_AND) reduce 499) ((T_BOOLEAN_OR) reduce 499) ((T_COALESCE) reduce 499) ((T_DOUBLE_ARROW) reduce 499) ((T_INSTANCEOF) reduce 499) ((T_IS_EQUAL) reduce 499) ((T_IS_GREATER_OR_EQUAL) reduce 499) ((T_IS_IDENTICAL) reduce 499) ((T_IS_NOT_EQUAL) reduce 499) ((T_IS_NOT_IDENTICAL) reduce 499) ((T_IS_SMALLER_OR_EQUAL) reduce 499) ((T_LOGICAL_AND) reduce 499) ((T_LOGICAL_OR) reduce 499) ((T_LOGICAL_XOR) reduce 499) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 499) ((T_OBJECT_OPERATOR) reduce 499) ((T_POW) reduce 499) ((T_SL) reduce 499) ((T_SPACESHIP) reduce 499) ((T_SR) reduce 499) (("[") reduce 499) (("]") reduce 499) (("^") reduce 499) (("{") reduce 499) (("|") reduce 499)) 1698 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) ((",") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 93) ((T_OBJECT_OPERATOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("[") reduce 93) (("]") reduce 93) (("^") reduce 93) (("{") reduce 93) (("|") reduce 93)) 1699 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) ((",") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 92) ((T_OBJECT_OPERATOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("[") reduce 92) (("]") reduce 92) (("^") reduce 92) (("{") reduce 92) (("|") reduce 92)) 1700 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) ((",") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 94) ((T_OBJECT_OPERATOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("[") reduce 94) (("]") reduce 94) (("^") reduce 94) (("{") reduce 94) (("|") reduce 94)) 1702 ((("%") reduce 501) (("*") reduce 501) (("+") reduce 501) ((",") reduce 501) (("-") reduce 501) ((".") reduce 501) (("/") reduce 501) (("<") reduce 501) ((">") reduce 501) (("?") reduce 501) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_BOOLEAN_AND) reduce 501) ((T_BOOLEAN_OR) reduce 501) ((T_COALESCE) reduce 501) ((T_DOUBLE_ARROW) reduce 501) ((T_INSTANCEOF) reduce 501) ((T_IS_EQUAL) reduce 501) ((T_IS_GREATER_OR_EQUAL) reduce 501) ((T_IS_IDENTICAL) reduce 501) ((T_IS_NOT_EQUAL) reduce 501) ((T_IS_NOT_IDENTICAL) reduce 501) ((T_IS_SMALLER_OR_EQUAL) reduce 501) ((T_LOGICAL_AND) reduce 501) ((T_LOGICAL_OR) reduce 501) ((T_LOGICAL_XOR) reduce 501) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 501) ((T_OBJECT_OPERATOR) reduce 501) ((T_POW) reduce 501) ((T_SL) reduce 501) ((T_SPACESHIP) reduce 501) ((T_SR) reduce 501) (("[") reduce 501) (("]") reduce 501) (("^") reduce 501) (("{") reduce 501) (("|") reduce 501)) 1710 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) ((",") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 91) ((T_OBJECT_OPERATOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("[") reduce 91) (("]") reduce 91) (("^") reduce 91) (("{") reduce 91) (("|") reduce 91)) 1713 ((("%") reduce 498) (("*") reduce 498) (("+") reduce 498) ((",") reduce 498) (("-") reduce 498) ((".") reduce 498) (("/") reduce 498) (("<") reduce 498) ((">") reduce 498) (("?") reduce 498) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_BOOLEAN_AND) reduce 498) ((T_BOOLEAN_OR) reduce 498) ((T_COALESCE) reduce 498) ((T_DOUBLE_ARROW) reduce 498) ((T_INSTANCEOF) reduce 498) ((T_IS_EQUAL) reduce 498) ((T_IS_GREATER_OR_EQUAL) reduce 498) ((T_IS_IDENTICAL) reduce 498) ((T_IS_NOT_EQUAL) reduce 498) ((T_IS_NOT_IDENTICAL) reduce 498) ((T_IS_SMALLER_OR_EQUAL) reduce 498) ((T_LOGICAL_AND) reduce 498) ((T_LOGICAL_OR) reduce 498) ((T_LOGICAL_XOR) reduce 498) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 498) ((T_OBJECT_OPERATOR) reduce 498) ((T_POW) reduce 498) ((T_SL) reduce 498) ((T_SPACESHIP) reduce 498) ((T_SR) reduce 498) (("[") reduce 498) (("]") reduce 498) (("^") reduce 498) (("{") reduce 498) (("|") reduce 498)) 1715 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) ((",") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) (("=") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AND_EQUAL) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_COALESCE_EQUAL) reduce 529) ((T_CONCAT_EQUAL) reduce 529) ((T_DEC) reduce 529) ((T_DIV_EQUAL) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INC) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_MINUS_EQUAL) reduce 529) ((T_MOD_EQUAL) reduce 529) ((T_MUL_EQUAL) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_OR_EQUAL) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_PLUS_EQUAL) reduce 529) ((T_POW) reduce 529) ((T_POW_EQUAL) reduce 529) ((T_SL) reduce 529) ((T_SL_EQUAL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) ((T_SR_EQUAL) reduce 529) ((T_XOR_EQUAL) reduce 529) (("[") reduce 529) (("]") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 1716 ((("!") shift) (("\"") shift) (("$") shift) (("%") reduce 440) (("(") shift) (("*") reduce 440) (("+") shift) ((",") reduce 440) (("-") shift) ((".") reduce 440) (("/") reduce 440) (("<") reduce 440) ((">") reduce 440) (("?") reduce 440) (("@") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOLEAN_AND) reduce 440) ((T_BOOLEAN_OR) reduce 440) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_COALESCE) reduce 440) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_ARROW) reduce 440) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INSTANCEOF) reduce 440) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_IS_EQUAL) reduce 440) ((T_IS_GREATER_OR_EQUAL) reduce 440) ((T_IS_IDENTICAL) reduce 440) ((T_IS_NOT_EQUAL) reduce 440) ((T_IS_NOT_IDENTICAL) reduce 440) ((T_IS_SMALLER_OR_EQUAL) reduce 440) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_LOGICAL_AND) reduce 440) ((T_LOGICAL_OR) reduce 440) ((T_LOGICAL_XOR) reduce 440) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_POW) reduce 440) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_SL) reduce 440) ((T_SPACESHIP) reduce 440) ((T_SR) reduce 440) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("]") reduce 440) (("^") reduce 440) (("`") shift) (("|") reduce 440) (("~") shift)) 1722 (((",") reduce 549) (("]") reduce 549)) 1726 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) ((",") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) (("<") reduce 525) (("=") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AND_EQUAL) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_COALESCE_EQUAL) reduce 525) ((T_CONCAT_EQUAL) reduce 525) ((T_DEC) reduce 525) ((T_DIV_EQUAL) reduce 525) ((T_DOUBLE_ARROW) reduce 525) ((T_INC) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_MINUS_EQUAL) reduce 525) ((T_MOD_EQUAL) reduce 525) ((T_MUL_EQUAL) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_OR_EQUAL) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_PLUS_EQUAL) reduce 525) ((T_POW) reduce 525) ((T_POW_EQUAL) reduce 525) ((T_SL) reduce 525) ((T_SL_EQUAL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) ((T_SR_EQUAL) reduce 525) ((T_XOR_EQUAL) reduce 525) (("[") reduce 525) (("]") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 1727 ((("%") reduce 493) (("*") reduce 493) (("+") reduce 493) ((",") reduce 493) (("-") reduce 493) ((".") reduce 493) (("/") reduce 493) (("<") reduce 493) ((">") reduce 493) (("?") reduce 493) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_BOOLEAN_AND) reduce 493) ((T_BOOLEAN_OR) reduce 493) ((T_COALESCE) reduce 493) ((T_DOUBLE_ARROW) reduce 493) ((T_INSTANCEOF) reduce 493) ((T_IS_EQUAL) reduce 493) ((T_IS_GREATER_OR_EQUAL) reduce 493) ((T_IS_IDENTICAL) reduce 493) ((T_IS_NOT_EQUAL) reduce 493) ((T_IS_NOT_IDENTICAL) reduce 493) ((T_IS_SMALLER_OR_EQUAL) reduce 493) ((T_LOGICAL_AND) reduce 493) ((T_LOGICAL_OR) reduce 493) ((T_LOGICAL_XOR) reduce 493) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 513) ((T_OBJECT_OPERATOR) reduce 513) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 513) ((T_POW) reduce 493) ((T_SL) reduce 493) ((T_SPACESHIP) reduce 493) ((T_SR) reduce 493) (("[") reduce 513) (("]") reduce 493) (("^") reduce 493) (("{") reduce 513) (("|") reduce 493)) 1729 ((("%") reduce 492) (("*") reduce 492) (("+") reduce 492) ((",") reduce 492) (("-") reduce 492) ((".") reduce 492) (("/") reduce 492) (("<") reduce 492) ((">") reduce 492) (("?") reduce 492) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_BOOLEAN_AND) reduce 492) ((T_BOOLEAN_OR) reduce 492) ((T_COALESCE) reduce 492) ((T_DOUBLE_ARROW) reduce 492) ((T_INSTANCEOF) reduce 492) ((T_IS_EQUAL) reduce 492) ((T_IS_GREATER_OR_EQUAL) reduce 492) ((T_IS_IDENTICAL) reduce 492) ((T_IS_NOT_EQUAL) reduce 492) ((T_IS_NOT_IDENTICAL) reduce 492) ((T_IS_SMALLER_OR_EQUAL) reduce 492) ((T_LOGICAL_AND) reduce 492) ((T_LOGICAL_OR) reduce 492) ((T_LOGICAL_XOR) reduce 492) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 515) ((T_OBJECT_OPERATOR) reduce 515) ((T_POW) reduce 492) ((T_SL) reduce 492) ((T_SPACESHIP) reduce 492) ((T_SR) reduce 492) (("[") reduce 515) (("]") reduce 492) (("^") reduce 492) (("{") reduce 515) (("|") reduce 492)) 1730 ((("%") reduce 491) (("(") reduce 518) (("*") reduce 491) (("+") reduce 491) ((",") reduce 491) (("-") reduce 491) ((".") reduce 491) (("/") reduce 491) (("<") reduce 491) ((">") reduce 491) (("?") reduce 491) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_BOOLEAN_AND) reduce 491) ((T_BOOLEAN_OR) reduce 491) ((T_COALESCE) reduce 491) ((T_DOUBLE_ARROW) reduce 491) ((T_INSTANCEOF) reduce 491) ((T_IS_EQUAL) reduce 491) ((T_IS_GREATER_OR_EQUAL) reduce 491) ((T_IS_IDENTICAL) reduce 491) ((T_IS_NOT_EQUAL) reduce 491) ((T_IS_NOT_IDENTICAL) reduce 491) ((T_IS_SMALLER_OR_EQUAL) reduce 491) ((T_LOGICAL_AND) reduce 491) ((T_LOGICAL_OR) reduce 491) ((T_LOGICAL_XOR) reduce 491) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 512) ((T_OBJECT_OPERATOR) reduce 512) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 512) ((T_POW) reduce 491) ((T_SL) reduce 491) ((T_SPACESHIP) reduce 491) ((T_SR) reduce 491) (("[") reduce 512) (("]") reduce 491) (("^") reduce 491) (("{") reduce 512) (("|") reduce 491)) 1731 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 553) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 553) (("^") shift) (("|") shift)) 1734 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) ((",") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) (("<") reduce 524) (("=") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AND_EQUAL) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_COALESCE_EQUAL) reduce 524) ((T_CONCAT_EQUAL) reduce 524) ((T_DEC) reduce 524) ((T_DIV_EQUAL) reduce 524) ((T_DOUBLE_ARROW) reduce 524) ((T_INC) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_MINUS_EQUAL) reduce 524) ((T_MOD_EQUAL) reduce 524) ((T_MUL_EQUAL) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_OR_EQUAL) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_PLUS_EQUAL) reduce 524) ((T_POW) reduce 524) ((T_POW_EQUAL) reduce 524) ((T_SL) reduce 524) ((T_SL_EQUAL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) ((T_SR_EQUAL) reduce 524) ((T_XOR_EQUAL) reduce 524) (("[") reduce 524) (("]") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 1735 ((("%") reduce 445) (("*") reduce 445) (("+") reduce 445) ((",") reduce 445) (("-") reduce 445) ((".") reduce 445) (("/") reduce 445) (("<") reduce 445) ((">") reduce 445) (("?") reduce 445) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_BOOLEAN_AND) reduce 445) ((T_BOOLEAN_OR) reduce 445) ((T_COALESCE) reduce 445) ((T_DOUBLE_ARROW) reduce 445) ((T_INSTANCEOF) reduce 445) ((T_IS_EQUAL) reduce 445) ((T_IS_GREATER_OR_EQUAL) reduce 445) ((T_IS_IDENTICAL) reduce 445) ((T_IS_NOT_EQUAL) reduce 445) ((T_IS_NOT_IDENTICAL) reduce 445) ((T_IS_SMALLER_OR_EQUAL) reduce 445) ((T_LOGICAL_AND) reduce 445) ((T_LOGICAL_OR) reduce 445) ((T_LOGICAL_XOR) reduce 445) ((T_POW) reduce 445) ((T_SL) reduce 445) ((T_SPACESHIP) reduce 445) ((T_SR) reduce 445) (("]") reduce 445) (("^") reduce 445) (("|") reduce 445)) 1736 ((("%") reduce 427) (("*") reduce 427) (("+") reduce 427) ((",") reduce 427) (("-") reduce 427) ((".") reduce 427) (("/") reduce 427) (("<") reduce 427) ((">") reduce 427) (("?") reduce 427) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_BOOLEAN_AND) reduce 427) ((T_BOOLEAN_OR) reduce 427) ((T_COALESCE) reduce 427) ((T_DOUBLE_ARROW) reduce 427) ((T_INSTANCEOF) reduce 427) ((T_IS_EQUAL) reduce 427) ((T_IS_GREATER_OR_EQUAL) reduce 427) ((T_IS_IDENTICAL) reduce 427) ((T_IS_NOT_EQUAL) reduce 427) ((T_IS_NOT_IDENTICAL) reduce 427) ((T_IS_SMALLER_OR_EQUAL) reduce 427) ((T_LOGICAL_AND) reduce 427) ((T_LOGICAL_OR) reduce 427) ((T_LOGICAL_XOR) reduce 427) ((T_POW) reduce 427) ((T_SL) reduce 427) ((T_SPACESHIP) reduce 427) ((T_SR) reduce 427) (("]") reduce 427) (("^") reduce 427) (("|") reduce 427)) 1737 ((("%") reduce 449) (("*") reduce 449) (("+") reduce 449) ((",") reduce 449) (("-") reduce 449) ((".") reduce 449) (("/") reduce 449) (("<") reduce 449) ((">") reduce 449) (("?") reduce 449) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_BOOLEAN_AND) reduce 449) ((T_BOOLEAN_OR) reduce 449) ((T_COALESCE) reduce 449) ((T_DOUBLE_ARROW) reduce 449) ((T_INSTANCEOF) reduce 449) ((T_IS_EQUAL) reduce 449) ((T_IS_GREATER_OR_EQUAL) reduce 449) ((T_IS_IDENTICAL) reduce 449) ((T_IS_NOT_EQUAL) reduce 449) ((T_IS_NOT_IDENTICAL) reduce 449) ((T_IS_SMALLER_OR_EQUAL) reduce 449) ((T_LOGICAL_AND) reduce 449) ((T_LOGICAL_OR) reduce 449) ((T_LOGICAL_XOR) reduce 449) ((T_POW) reduce 449) ((T_SL) reduce 449) ((T_SPACESHIP) reduce 449) ((T_SR) reduce 449) (("]") reduce 449) (("^") reduce 449) (("|") reduce 449)) 1738 ((("%") reduce 494) (("(") shift) (("*") reduce 494) (("+") reduce 494) ((",") reduce 494) (("-") reduce 494) ((".") reduce 494) (("/") reduce 494) (("<") reduce 494) ((">") reduce 494) (("?") reduce 494) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_BOOLEAN_AND) reduce 494) ((T_BOOLEAN_OR) reduce 494) ((T_COALESCE) reduce 494) ((T_DOUBLE_ARROW) reduce 494) ((T_INSTANCEOF) reduce 494) ((T_IS_EQUAL) reduce 494) ((T_IS_GREATER_OR_EQUAL) reduce 494) ((T_IS_IDENTICAL) reduce 494) ((T_IS_NOT_EQUAL) reduce 494) ((T_IS_NOT_IDENTICAL) reduce 494) ((T_IS_SMALLER_OR_EQUAL) reduce 494) ((T_LOGICAL_AND) reduce 494) ((T_LOGICAL_OR) reduce 494) ((T_LOGICAL_XOR) reduce 494) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 494) ((T_OBJECT_OPERATOR) reduce 494) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 494) ((T_SL) reduce 494) ((T_SPACESHIP) reduce 494) ((T_SR) reduce 494) (("[") reduce 494) (("]") reduce 494) (("^") reduce 494) (("{") reduce 494) (("|") reduce 494)) 1739 ((("%") reduce 423) (("*") reduce 423) (("+") reduce 423) ((",") reduce 423) (("-") reduce 423) ((".") reduce 423) (("/") reduce 423) (("<") reduce 423) ((">") reduce 423) (("?") reduce 423) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_BOOLEAN_AND) reduce 423) ((T_BOOLEAN_OR) reduce 423) ((T_COALESCE) reduce 423) ((T_DOUBLE_ARROW) reduce 423) ((T_INSTANCEOF) reduce 423) ((T_IS_EQUAL) reduce 423) ((T_IS_GREATER_OR_EQUAL) reduce 423) ((T_IS_IDENTICAL) reduce 423) ((T_IS_NOT_EQUAL) reduce 423) ((T_IS_NOT_IDENTICAL) reduce 423) ((T_IS_SMALLER_OR_EQUAL) reduce 423) ((T_LOGICAL_AND) reduce 423) ((T_LOGICAL_OR) reduce 423) ((T_LOGICAL_XOR) reduce 423) ((T_POW) reduce 423) ((T_SL) reduce 423) ((T_SPACESHIP) reduce 423) ((T_SR) reduce 423) (("]") reduce 423) (("^") reduce 423) (("|") reduce 423)) 1740 (((",") shift) (("]") reduce 547)) 1741 (((",") reduce 551) (("]") reduce 551)) 1742 ((("%") reduce 437) (("*") reduce 437) (("+") reduce 437) ((",") reduce 437) (("-") reduce 437) ((".") reduce 437) (("/") reduce 437) (("<") reduce 437) ((">") reduce 437) (("?") reduce 437) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_BOOLEAN_AND) reduce 437) ((T_BOOLEAN_OR) reduce 437) ((T_COALESCE) reduce 437) ((T_DOUBLE_ARROW) reduce 437) ((T_INSTANCEOF) reduce 437) ((T_IS_EQUAL) reduce 437) ((T_IS_GREATER_OR_EQUAL) reduce 437) ((T_IS_IDENTICAL) reduce 437) ((T_IS_NOT_EQUAL) reduce 437) ((T_IS_NOT_IDENTICAL) reduce 437) ((T_IS_SMALLER_OR_EQUAL) reduce 437) ((T_LOGICAL_AND) reduce 437) ((T_LOGICAL_OR) reduce 437) ((T_LOGICAL_XOR) reduce 437) ((T_POW) reduce 437) ((T_SL) reduce 437) ((T_SPACESHIP) reduce 437) ((T_SR) reduce 437) (("]") reduce 437) (("^") reduce 437) (("|") reduce 437)) 1743 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) ((",") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) (("<") reduce 519) (("=") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AND_EQUAL) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_COALESCE_EQUAL) reduce 519) ((T_CONCAT_EQUAL) reduce 519) ((T_DEC) reduce 519) ((T_DIV_EQUAL) reduce 519) ((T_DOUBLE_ARROW) reduce 519) ((T_INC) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_MINUS_EQUAL) reduce 519) ((T_MOD_EQUAL) reduce 519) ((T_MUL_EQUAL) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_OR_EQUAL) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_PLUS_EQUAL) reduce 519) ((T_POW) reduce 519) ((T_POW_EQUAL) reduce 519) ((T_SL) reduce 519) ((T_SL_EQUAL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) ((T_SR_EQUAL) reduce 519) ((T_XOR_EQUAL) reduce 519) (("[") reduce 519) (("]") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 1744 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) ((",") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) (("<") reduce 526) (("=") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AND_EQUAL) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_COALESCE_EQUAL) reduce 526) ((T_CONCAT_EQUAL) reduce 526) ((T_DEC) reduce 526) ((T_DIV_EQUAL) reduce 526) ((T_DOUBLE_ARROW) reduce 526) ((T_INC) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_MINUS_EQUAL) reduce 526) ((T_MOD_EQUAL) reduce 526) ((T_MUL_EQUAL) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_OR_EQUAL) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_PLUS_EQUAL) reduce 526) ((T_POW) reduce 526) ((T_POW_EQUAL) reduce 526) ((T_SL) reduce 526) ((T_SL_EQUAL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) ((T_SR_EQUAL) reduce 526) ((T_XOR_EQUAL) reduce 526) (("[") reduce 526) (("]") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 1745 ((("%") reduce 367) (("*") reduce 367) (("+") reduce 367) ((",") reduce 367) (("-") reduce 367) ((".") reduce 367) (("/") reduce 367) (("<") reduce 367) (("=") shift) ((">") reduce 367) (("?") reduce 367) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AND_EQUAL) shift) ((T_BOOLEAN_AND) reduce 367) ((T_BOOLEAN_OR) reduce 367) ((T_COALESCE) reduce 367) ((T_COALESCE_EQUAL) shift) ((T_CONCAT_EQUAL) shift) ((T_DEC) shift) ((T_DIV_EQUAL) shift) ((T_DOUBLE_ARROW) reduce 367) ((T_INC) shift) ((T_INSTANCEOF) reduce 367) ((T_IS_EQUAL) reduce 367) ((T_IS_GREATER_OR_EQUAL) reduce 367) ((T_IS_IDENTICAL) reduce 367) ((T_IS_NOT_EQUAL) reduce 367) ((T_IS_NOT_IDENTICAL) reduce 367) ((T_IS_SMALLER_OR_EQUAL) reduce 367) ((T_LOGICAL_AND) reduce 367) ((T_LOGICAL_OR) reduce 367) ((T_LOGICAL_XOR) reduce 367) ((T_MINUS_EQUAL) shift) ((T_MOD_EQUAL) shift) ((T_MUL_EQUAL) shift) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_OR_EQUAL) shift) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_PLUS_EQUAL) shift) ((T_POW) reduce 367) ((T_POW_EQUAL) shift) ((T_SL) reduce 367) ((T_SL_EQUAL) shift) ((T_SPACESHIP) reduce 367) ((T_SR) reduce 367) ((T_SR_EQUAL) shift) ((T_XOR_EQUAL) shift) (("[") reduce 510) (("]") reduce 367) (("^") reduce 367) (("{") reduce 510) (("|") reduce 367)) 1749 ((("%") reduce 411) (("*") reduce 411) (("+") reduce 411) ((",") reduce 411) (("-") reduce 411) ((".") reduce 411) (("/") reduce 411) (("<") reduce 411) ((">") reduce 411) (("?") reduce 411) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_BOOLEAN_AND) reduce 411) ((T_BOOLEAN_OR) reduce 411) ((T_COALESCE) reduce 411) ((T_DOUBLE_ARROW) reduce 411) ((T_INSTANCEOF) reduce 411) ((T_IS_EQUAL) reduce 411) ((T_IS_GREATER_OR_EQUAL) reduce 411) ((T_IS_IDENTICAL) reduce 411) ((T_IS_NOT_EQUAL) reduce 411) ((T_IS_NOT_IDENTICAL) reduce 411) ((T_IS_SMALLER_OR_EQUAL) reduce 411) ((T_LOGICAL_AND) reduce 411) ((T_LOGICAL_OR) reduce 411) ((T_LOGICAL_XOR) reduce 411) ((T_POW) shift) ((T_SL) reduce 411) ((T_SPACESHIP) reduce 411) ((T_SR) reduce 411) (("]") reduce 411) (("^") reduce 411) (("|") reduce 411)) 1780 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 395) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 395) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 395) ((T_BOOLEAN_OR) reduce 395) ((T_COALESCE) reduce 395) ((T_DOUBLE_ARROW) reduce 395) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 395) ((T_LOGICAL_OR) reduce 395) ((T_LOGICAL_XOR) reduce 395) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 395) (("^") shift) (("|") reduce 395)) 1781 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 398) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 398) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 398) ((T_BOOLEAN_OR) reduce 398) ((T_COALESCE) reduce 398) ((T_DOUBLE_ARROW) reduce 398) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 398) ((T_LOGICAL_OR) reduce 398) ((T_LOGICAL_XOR) reduce 398) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 398) (("^") reduce 398) (("|") reduce 398)) 1782 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 407) (("-") shift) ((".") reduce 407) (("/") shift) (("<") reduce 407) ((">") reduce 407) (("?") reduce 407) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_BOOLEAN_AND) reduce 407) ((T_BOOLEAN_OR) reduce 407) ((T_COALESCE) reduce 407) ((T_DOUBLE_ARROW) reduce 407) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 407) ((T_IS_GREATER_OR_EQUAL) reduce 407) ((T_IS_IDENTICAL) reduce 407) ((T_IS_NOT_EQUAL) reduce 407) ((T_IS_NOT_IDENTICAL) reduce 407) ((T_IS_SMALLER_OR_EQUAL) reduce 407) ((T_LOGICAL_AND) reduce 407) ((T_LOGICAL_OR) reduce 407) ((T_LOGICAL_XOR) reduce 407) ((T_POW) shift) ((T_SL) reduce 407) ((T_SPACESHIP) reduce 407) ((T_SR) reduce 407) (("]") reduce 407) (("^") reduce 407) (("|") reduce 407)) 1783 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 420) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 420) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_BOOLEAN_AND) reduce 420) ((T_BOOLEAN_OR) reduce 420) ((T_COALESCE) reduce 420) ((T_DOUBLE_ARROW) reduce 420) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 420) ((T_LOGICAL_OR) reduce 420) ((T_LOGICAL_XOR) reduce 420) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 420) (("^") reduce 420) (("|") reduce 420)) 1784 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 406) (("-") shift) ((".") reduce 406) (("/") shift) (("<") reduce 406) ((">") reduce 406) (("?") reduce 406) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_BOOLEAN_AND) reduce 406) ((T_BOOLEAN_OR) reduce 406) ((T_COALESCE) reduce 406) ((T_DOUBLE_ARROW) reduce 406) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 406) ((T_IS_GREATER_OR_EQUAL) reduce 406) ((T_IS_IDENTICAL) reduce 406) ((T_IS_NOT_EQUAL) reduce 406) ((T_IS_NOT_IDENTICAL) reduce 406) ((T_IS_SMALLER_OR_EQUAL) reduce 406) ((T_LOGICAL_AND) reduce 406) ((T_LOGICAL_OR) reduce 406) ((T_LOGICAL_XOR) reduce 406) ((T_POW) shift) ((T_SL) reduce 406) ((T_SPACESHIP) reduce 406) ((T_SR) reduce 406) (("]") reduce 406) (("^") reduce 406) (("|") reduce 406)) 1785 ((("%") reduce 403) (("*") reduce 403) (("+") reduce 403) ((",") reduce 403) (("-") reduce 403) ((".") reduce 403) (("/") reduce 403) (("<") reduce 403) ((">") reduce 403) (("?") reduce 403) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_BOOLEAN_AND) reduce 403) ((T_BOOLEAN_OR) reduce 403) ((T_COALESCE) reduce 403) ((T_DOUBLE_ARROW) reduce 403) ((T_INSTANCEOF) reduce 403) ((T_IS_EQUAL) reduce 403) ((T_IS_GREATER_OR_EQUAL) reduce 403) ((T_IS_IDENTICAL) reduce 403) ((T_IS_NOT_EQUAL) reduce 403) ((T_IS_NOT_IDENTICAL) reduce 403) ((T_IS_SMALLER_OR_EQUAL) reduce 403) ((T_LOGICAL_AND) reduce 403) ((T_LOGICAL_OR) reduce 403) ((T_LOGICAL_XOR) reduce 403) ((T_POW) shift) ((T_SL) reduce 403) ((T_SPACESHIP) reduce 403) ((T_SR) reduce 403) (("]") reduce 403) (("^") reduce 403) (("|") reduce 403)) 1786 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 394) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 394) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 394) ((T_LOGICAL_XOR) reduce 394) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 394) (("^") shift) (("|") shift)) 1787 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 392) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 392) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 392) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 392) (("^") shift) (("|") shift)) 1788 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 393) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 393) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 393) ((T_LOGICAL_OR) reduce 393) ((T_LOGICAL_XOR) reduce 393) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 393) (("^") shift) (("|") shift)) 1789 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 417) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 417) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_BOOLEAN_AND) reduce 417) ((T_BOOLEAN_OR) reduce 417) ((T_COALESCE) reduce 417) ((T_DOUBLE_ARROW) reduce 417) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 417) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 417) ((T_IS_NOT_EQUAL) reduce 417) ((T_IS_NOT_IDENTICAL) reduce 417) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 417) ((T_LOGICAL_OR) reduce 417) ((T_LOGICAL_XOR) reduce 417) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 417) ((T_SR) shift) (("]") reduce 417) (("^") reduce 417) (("|") reduce 417)) 1790 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 413) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 413) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_BOOLEAN_AND) reduce 413) ((T_BOOLEAN_OR) reduce 413) ((T_COALESCE) reduce 413) ((T_DOUBLE_ARROW) reduce 413) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 413) ((T_LOGICAL_OR) reduce 413) ((T_LOGICAL_XOR) reduce 413) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 413) (("^") reduce 413) (("|") reduce 413)) 1791 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 415) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 415) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_BOOLEAN_AND) reduce 415) ((T_BOOLEAN_OR) reduce 415) ((T_COALESCE) reduce 415) ((T_DOUBLE_ARROW) reduce 415) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 415) ((T_LOGICAL_OR) reduce 415) ((T_LOGICAL_XOR) reduce 415) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 415) (("^") reduce 415) (("|") reduce 415)) 1792 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 412) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 412) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_BOOLEAN_AND) reduce 412) ((T_BOOLEAN_OR) reduce 412) ((T_COALESCE) reduce 412) ((T_DOUBLE_ARROW) reduce 412) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 412) ((T_LOGICAL_OR) reduce 412) ((T_LOGICAL_XOR) reduce 412) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 412) (("^") reduce 412) (("|") reduce 412)) 1793 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 419) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 419) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_BOOLEAN_AND) reduce 419) ((T_BOOLEAN_OR) reduce 419) ((T_COALESCE) reduce 419) ((T_DOUBLE_ARROW) reduce 419) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 419) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 419) ((T_IS_NOT_EQUAL) reduce 419) ((T_IS_NOT_IDENTICAL) reduce 419) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 419) ((T_LOGICAL_OR) reduce 419) ((T_LOGICAL_XOR) reduce 419) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 419) ((T_SR) shift) (("]") reduce 419) (("^") reduce 419) (("|") reduce 419)) 1794 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 414) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 414) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_BOOLEAN_AND) reduce 414) ((T_BOOLEAN_OR) reduce 414) ((T_COALESCE) reduce 414) ((T_DOUBLE_ARROW) reduce 414) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 414) ((T_LOGICAL_OR) reduce 414) ((T_LOGICAL_XOR) reduce 414) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 414) (("^") reduce 414) (("|") reduce 414)) 1797 ((("%") reduce 93) (("*") reduce 93) (("+") reduce 93) ((",") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("]") reduce 93) (("^") reduce 93) (("|") reduce 93)) 1798 ((("%") reduce 92) (("*") reduce 92) (("+") reduce 92) ((",") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("]") reduce 92) (("^") reduce 92) (("|") reduce 92)) 1799 ((("%") reduce 94) (("*") reduce 94) (("+") reduce 94) ((",") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("]") reduce 94) (("^") reduce 94) (("|") reduce 94)) 1800 ((("%") reduce 470) (("*") reduce 470) (("+") reduce 470) ((",") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_DOUBLE_ARROW) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("]") reduce 470) (("^") reduce 470) (("|") reduce 470)) 1801 ((("%") reduce 91) (("*") reduce 91) (("+") reduce 91) ((",") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("]") reduce 91) (("^") reduce 91) (("|") reduce 91)) 1802 ((("%") reduce 529) (("*") reduce 529) (("+") reduce 529) ((",") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("]") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 1803 ((("%") reduce 472) (("*") reduce 472) (("+") reduce 472) ((",") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_DOUBLE_ARROW) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("]") reduce 472) (("^") reduce 472) (("|") reduce 472)) 1804 ((("%") reduce 421) (("*") reduce 421) (("+") reduce 421) ((",") reduce 421) (("-") reduce 421) ((".") reduce 421) (("/") reduce 421) (("<") reduce 421) ((">") reduce 421) (("?") reduce 421) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_BOOLEAN_AND) reduce 421) ((T_BOOLEAN_OR) reduce 421) ((T_COALESCE) reduce 421) ((T_DOUBLE_ARROW) reduce 421) ((T_INSTANCEOF) reduce 421) ((T_IS_EQUAL) reduce 421) ((T_IS_GREATER_OR_EQUAL) reduce 421) ((T_IS_IDENTICAL) reduce 421) ((T_IS_NOT_EQUAL) reduce 421) ((T_IS_NOT_IDENTICAL) reduce 421) ((T_IS_SMALLER_OR_EQUAL) reduce 421) ((T_LOGICAL_AND) reduce 421) ((T_LOGICAL_OR) reduce 421) ((T_LOGICAL_XOR) reduce 421) ((T_POW) reduce 421) ((T_SL) reduce 421) ((T_SPACESHIP) reduce 421) ((T_SR) reduce 421) (("]") reduce 421) (("^") reduce 421) (("|") reduce 421)) 1805 ((("%") reduce 471) (("*") reduce 471) (("+") reduce 471) ((",") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_DOUBLE_ARROW) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("]") reduce 471) (("^") reduce 471) (("|") reduce 471)) 1806 ((("%") reduce 473) (("*") reduce 473) (("+") reduce 473) ((",") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_DOUBLE_ARROW) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("]") reduce 473) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 1807 ((("%") reduce 534) (("*") reduce 534) (("+") reduce 534) ((",") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_DOUBLE_ARROW) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("]") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 1814 ((("%") reduce 536) (("*") reduce 536) (("+") reduce 536) ((",") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_DOUBLE_ARROW) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("]") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 1816 ((("%") reduce 535) (("*") reduce 535) (("+") reduce 535) ((",") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_DOUBLE_ARROW) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("]") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 1817 ((("%") reduce 540) (("*") reduce 540) (("+") reduce 540) ((",") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_DOUBLE_ARROW) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("]") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 1818 ((("%") reduce 544) (("*") reduce 544) (("+") reduce 544) ((",") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("]") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 1819 ((("%") reduce 537) (("*") reduce 537) (("+") reduce 537) ((",") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_DOUBLE_ARROW) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("]") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 1820 ((("%") reduce 546) (("*") reduce 546) (("+") reduce 546) ((",") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("]") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 1823 ((("%") reduce 545) (("*") reduce 545) (("+") reduce 545) ((",") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("]") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 1824 ((("%") reduce 538) (("*") reduce 538) (("+") reduce 538) ((",") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_DOUBLE_ARROW) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("]") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 1826 ((("%") reduce 539) (("*") reduce 539) (("+") reduce 539) ((",") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_DOUBLE_ARROW) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("]") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 1828 ((("%") reduce 474) (("*") reduce 474) (("+") reduce 474) ((",") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_DOUBLE_ARROW) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("]") reduce 474) (("^") reduce 474) (("|") reduce 474)) 1829 ((("%") reduce 531) (("*") reduce 531) (("+") reduce 531) ((",") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("]") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 1832 ((("%") reduce 530) (("*") reduce 530) (("+") reduce 530) ((",") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("]") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 1833 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 426) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 426) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 426) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 426) ((T_LOGICAL_OR) reduce 426) ((T_LOGICAL_XOR) reduce 426) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 426) (("^") shift) (("|") shift)) 1834 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 390) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 390) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) reduce 390) ((T_COALESCE) reduce 390) ((T_DOUBLE_ARROW) reduce 390) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 390) ((T_LOGICAL_OR) reduce 390) ((T_LOGICAL_XOR) reduce 390) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 390) (("^") shift) (("|") shift)) 1835 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 391) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 391) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 391) ((T_BOOLEAN_OR) reduce 391) ((T_COALESCE) reduce 391) ((T_DOUBLE_ARROW) reduce 391) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 391) ((T_LOGICAL_OR) reduce 391) ((T_LOGICAL_XOR) reduce 391) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 391) (("^") shift) (("|") shift)) 1836 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 396) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 396) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_BOOLEAN_AND) reduce 396) ((T_BOOLEAN_OR) reduce 396) ((T_COALESCE) reduce 396) ((T_DOUBLE_ARROW) reduce 396) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 396) ((T_LOGICAL_OR) reduce 396) ((T_LOGICAL_XOR) reduce 396) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 396) (("^") reduce 396) (("|") reduce 396)) 1837 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 397) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 397) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_BOOLEAN_AND) reduce 397) ((T_BOOLEAN_OR) reduce 397) ((T_COALESCE) reduce 397) ((T_DOUBLE_ARROW) reduce 397) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 397) ((T_LOGICAL_OR) reduce 397) ((T_LOGICAL_XOR) reduce 397) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 397) (("^") reduce 397) (("|") reduce 397)) 1841 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 424) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 424) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 424) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 424) ((T_LOGICAL_OR) reduce 424) ((T_LOGICAL_XOR) reduce 424) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 424) (("^") shift) (("|") shift)) 1842 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 425) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 425) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 425) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 425) ((T_LOGICAL_OR) reduce 425) ((T_LOGICAL_XOR) reduce 425) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 425) (("^") shift) (("|") shift)) 1843 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 418) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 418) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_BOOLEAN_AND) reduce 418) ((T_BOOLEAN_OR) reduce 418) ((T_COALESCE) reduce 418) ((T_DOUBLE_ARROW) reduce 418) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 418) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 418) ((T_IS_NOT_EQUAL) reduce 418) ((T_IS_NOT_IDENTICAL) reduce 418) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 418) ((T_LOGICAL_OR) reduce 418) ((T_LOGICAL_XOR) reduce 418) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 418) ((T_SR) shift) (("]") reduce 418) (("^") reduce 418) (("|") reduce 418)) 1844 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 416) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 416) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_BOOLEAN_AND) reduce 416) ((T_BOOLEAN_OR) reduce 416) ((T_COALESCE) reduce 416) ((T_DOUBLE_ARROW) reduce 416) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 416) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 416) ((T_IS_NOT_EQUAL) reduce 416) ((T_IS_NOT_IDENTICAL) reduce 416) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 416) ((T_LOGICAL_OR) reduce 416) ((T_LOGICAL_XOR) reduce 416) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 416) ((T_SR) shift) (("]") reduce 416) (("^") reduce 416) (("|") reduce 416)) 1845 ((("%") reduce 404) (("*") reduce 404) (("+") reduce 404) ((",") reduce 404) (("-") reduce 404) ((".") reduce 404) (("/") reduce 404) (("<") reduce 404) ((">") reduce 404) (("?") reduce 404) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_BOOLEAN_AND) reduce 404) ((T_BOOLEAN_OR) reduce 404) ((T_COALESCE) reduce 404) ((T_DOUBLE_ARROW) reduce 404) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 404) ((T_IS_GREATER_OR_EQUAL) reduce 404) ((T_IS_IDENTICAL) reduce 404) ((T_IS_NOT_EQUAL) reduce 404) ((T_IS_NOT_IDENTICAL) reduce 404) ((T_IS_SMALLER_OR_EQUAL) reduce 404) ((T_LOGICAL_AND) reduce 404) ((T_LOGICAL_OR) reduce 404) ((T_LOGICAL_XOR) reduce 404) ((T_POW) shift) ((T_SL) reduce 404) ((T_SPACESHIP) reduce 404) ((T_SR) reduce 404) (("]") reduce 404) (("^") reduce 404) (("|") reduce 404)) 1846 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 399) (("-") shift) ((".") reduce 399) (("/") shift) (("<") reduce 399) ((">") reduce 399) (("?") reduce 399) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_BOOLEAN_AND) reduce 399) ((T_BOOLEAN_OR) reduce 399) ((T_COALESCE) reduce 399) ((T_DOUBLE_ARROW) reduce 399) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 399) ((T_IS_GREATER_OR_EQUAL) reduce 399) ((T_IS_IDENTICAL) reduce 399) ((T_IS_NOT_EQUAL) reduce 399) ((T_IS_NOT_IDENTICAL) reduce 399) ((T_IS_SMALLER_OR_EQUAL) reduce 399) ((T_LOGICAL_AND) reduce 399) ((T_LOGICAL_OR) reduce 399) ((T_LOGICAL_XOR) reduce 399) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 399) ((T_SR) shift) (("]") reduce 399) (("^") reduce 399) (("|") reduce 399)) 1847 ((("%") shift) (("*") shift) (("+") reduce 401) ((",") reduce 401) (("-") reduce 401) ((".") reduce 401) (("/") shift) (("<") reduce 401) ((">") reduce 401) (("?") reduce 401) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_BOOLEAN_AND) reduce 401) ((T_BOOLEAN_OR) reduce 401) ((T_COALESCE) reduce 401) ((T_DOUBLE_ARROW) reduce 401) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 401) ((T_IS_GREATER_OR_EQUAL) reduce 401) ((T_IS_IDENTICAL) reduce 401) ((T_IS_NOT_EQUAL) reduce 401) ((T_IS_NOT_IDENTICAL) reduce 401) ((T_IS_SMALLER_OR_EQUAL) reduce 401) ((T_LOGICAL_AND) reduce 401) ((T_LOGICAL_OR) reduce 401) ((T_LOGICAL_XOR) reduce 401) ((T_POW) shift) ((T_SL) reduce 401) ((T_SPACESHIP) reduce 401) ((T_SR) reduce 401) (("]") reduce 401) (("^") reduce 401) (("|") reduce 401)) 1848 ((("%") shift) (("*") shift) (("+") reduce 400) ((",") reduce 400) (("-") reduce 400) ((".") reduce 400) (("/") shift) (("<") reduce 400) ((">") reduce 400) (("?") reduce 400) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_BOOLEAN_AND) reduce 400) ((T_BOOLEAN_OR) reduce 400) ((T_COALESCE) reduce 400) ((T_DOUBLE_ARROW) reduce 400) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 400) ((T_IS_GREATER_OR_EQUAL) reduce 400) ((T_IS_IDENTICAL) reduce 400) ((T_IS_NOT_EQUAL) reduce 400) ((T_IS_NOT_IDENTICAL) reduce 400) ((T_IS_SMALLER_OR_EQUAL) reduce 400) ((T_LOGICAL_AND) reduce 400) ((T_LOGICAL_OR) reduce 400) ((T_LOGICAL_XOR) reduce 400) ((T_POW) shift) ((T_SL) reduce 400) ((T_SPACESHIP) reduce 400) ((T_SR) reduce 400) (("]") reduce 400) (("^") reduce 400) (("|") reduce 400)) 1849 ((("%") reduce 402) (("*") reduce 402) (("+") reduce 402) ((",") reduce 402) (("-") reduce 402) ((".") reduce 402) (("/") reduce 402) (("<") reduce 402) ((">") reduce 402) (("?") reduce 402) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_BOOLEAN_AND) reduce 402) ((T_BOOLEAN_OR) reduce 402) ((T_COALESCE) reduce 402) ((T_DOUBLE_ARROW) reduce 402) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 402) ((T_IS_GREATER_OR_EQUAL) reduce 402) ((T_IS_IDENTICAL) reduce 402) ((T_IS_NOT_EQUAL) reduce 402) ((T_IS_NOT_IDENTICAL) reduce 402) ((T_IS_SMALLER_OR_EQUAL) reduce 402) ((T_LOGICAL_AND) reduce 402) ((T_LOGICAL_OR) reduce 402) ((T_LOGICAL_XOR) reduce 402) ((T_POW) shift) ((T_SL) reduce 402) ((T_SPACESHIP) reduce 402) ((T_SR) reduce 402) (("]") reduce 402) (("^") reduce 402) (("|") reduce 402)) 1850 ((("%") reduce 405) (("*") reduce 405) (("+") reduce 405) ((",") reduce 405) (("-") reduce 405) ((".") reduce 405) (("/") reduce 405) (("<") reduce 405) ((">") reduce 405) (("?") reduce 405) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_BOOLEAN_AND) reduce 405) ((T_BOOLEAN_OR) reduce 405) ((T_COALESCE) reduce 405) ((T_DOUBLE_ARROW) reduce 405) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 405) ((T_IS_GREATER_OR_EQUAL) reduce 405) ((T_IS_IDENTICAL) reduce 405) ((T_IS_NOT_EQUAL) reduce 405) ((T_IS_NOT_IDENTICAL) reduce 405) ((T_IS_SMALLER_OR_EQUAL) reduce 405) ((T_LOGICAL_AND) reduce 405) ((T_LOGICAL_OR) reduce 405) ((T_LOGICAL_XOR) reduce 405) ((T_POW) shift) ((T_SL) reduce 405) ((T_SPACESHIP) reduce 405) ((T_SR) reduce 405) (("]") reduce 405) (("^") reduce 405) (("|") reduce 405)) 1851 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) ((")") reduce 548) (("+") shift) ((",") reduce 548) (("-") shift) (("@") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_CAST) shift) ((T_ELLIPSIS) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("~") shift)) 1909 (((")") reduce 549) ((",") reduce 549)) 1918 ((("%") shift) ((")") reduce 553) (("*") shift) (("+") shift) ((",") reduce 553) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 1927 (((")") reduce 547) ((",") shift)) 1928 (((")") reduce 551) ((",") reduce 551)) 2040 ((("=") shift)) 2042 ((("%") shift) ((")") reduce 368) (("*") shift) (("+") shift) ((",") reduce 368) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 368) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 368) ((T_LOGICAL_OR) reduce 368) ((T_LOGICAL_XOR) reduce 368) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 2216 ((("%") reduce 466) (("(") reduce 466) ((")") reduce 466) (("*") reduce 466) (("+") reduce 466) ((",") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) (("<") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_DOUBLE_ARROW) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_POW) reduce 466) ((T_SL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 2217 ((("%") reduce 531) (("(") reduce 531) ((")") reduce 531) (("*") reduce 531) (("+") reduce 531) ((",") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 2220 ((("%") reduce 530) (("(") reduce 530) ((")") reduce 530) (("*") reduce 530) (("+") reduce 530) ((",") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 2222 (((")") reduce 550) ((",") reduce 550)) 2223 ((("%") reduce 465) (("(") reduce 465) ((")") reduce 465) (("*") reduce 465) (("+") reduce 465) ((",") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) (("<") reduce 465) (("=") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AND_EQUAL) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_COALESCE_EQUAL) reduce 465) ((T_CONCAT_EQUAL) reduce 465) ((T_DEC) reduce 465) ((T_DIV_EQUAL) reduce 465) ((T_DOUBLE_ARROW) reduce 465) ((T_INC) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_MINUS_EQUAL) reduce 465) ((T_MOD_EQUAL) reduce 465) ((T_MUL_EQUAL) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_OR_EQUAL) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_PLUS_EQUAL) reduce 465) ((T_POW) reduce 465) ((T_POW_EQUAL) reduce 465) ((T_SL) reduce 465) ((T_SL_EQUAL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) ((T_SR_EQUAL) reduce 465) ((T_XOR_EQUAL) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 2234 ((("%") reduce 455) ((")") reduce 455) (("*") reduce 455) (("+") reduce 455) ((",") reduce 455) (("-") reduce 455) ((".") reduce 455) (("/") reduce 455) (("<") reduce 455) ((">") reduce 455) (("?") reduce 455) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_BOOLEAN_AND) reduce 455) ((T_BOOLEAN_OR) reduce 455) ((T_COALESCE) reduce 455) ((T_DOUBLE_ARROW) reduce 455) ((T_INSTANCEOF) reduce 455) ((T_IS_EQUAL) reduce 455) ((T_IS_GREATER_OR_EQUAL) reduce 455) ((T_IS_IDENTICAL) reduce 455) ((T_IS_NOT_EQUAL) reduce 455) ((T_IS_NOT_IDENTICAL) reduce 455) ((T_IS_SMALLER_OR_EQUAL) reduce 455) ((T_LOGICAL_AND) reduce 455) ((T_LOGICAL_OR) reduce 455) ((T_LOGICAL_XOR) reduce 455) ((T_POW) reduce 455) ((T_SL) reduce 455) ((T_SPACESHIP) reduce 455) ((T_SR) reduce 455) (("^") reduce 455) (("|") reduce 455)) 2235 ((("%") reduce 450) ((")") reduce 450) (("*") reduce 450) (("+") reduce 450) ((",") reduce 450) (("-") reduce 450) ((".") reduce 450) (("/") reduce 450) (("<") reduce 450) ((">") reduce 450) (("?") reduce 450) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_BOOLEAN_AND) reduce 450) ((T_BOOLEAN_OR) reduce 450) ((T_COALESCE) reduce 450) ((T_DOUBLE_ARROW) reduce 450) ((T_INSTANCEOF) reduce 450) ((T_IS_EQUAL) reduce 450) ((T_IS_GREATER_OR_EQUAL) reduce 450) ((T_IS_IDENTICAL) reduce 450) ((T_IS_NOT_EQUAL) reduce 450) ((T_IS_NOT_IDENTICAL) reduce 450) ((T_IS_SMALLER_OR_EQUAL) reduce 450) ((T_LOGICAL_AND) reduce 450) ((T_LOGICAL_OR) reduce 450) ((T_LOGICAL_XOR) reduce 450) ((T_POW) reduce 450) ((T_SL) reduce 450) ((T_SPACESHIP) reduce 450) ((T_SR) reduce 450) (("^") reduce 450) (("|") reduce 450)) 2240 (((":") shift) ((T_DOUBLE_ARROW) reduce 286)) 2242 (((T_DOUBLE_ARROW) shift)) 2243 ((("!") reduce 455) (("\"") reduce 455) (("$") reduce 455) (("(") reduce 455) (("+") reduce 455) (("-") reduce 455) (("@") reduce 455) ((T_ARRAY) reduce 455) ((T_ARRAY_CAST) reduce 455) ((T_ATTRIBUTE) reduce 455) ((T_BOOL_CAST) reduce 455) ((T_CLASS_C) reduce 455) ((T_CLONE) reduce 455) ((T_CONSTANT_ENCAPSED_STRING) reduce 455) ((T_DEC) reduce 455) ((T_DIR) reduce 455) ((T_DNUMBER) reduce 455) ((T_DOUBLE_CAST) reduce 455) ((T_EMPTY) reduce 455) ((T_EVAL) reduce 455) ((T_EXIT) reduce 455) ((T_FILE) reduce 455) ((T_FN) reduce 455) ((T_FUNCTION) reduce 455) ((T_FUNC_C) reduce 455) ((T_INC) reduce 455) ((T_INCLUDE) reduce 455) ((T_INCLUDE_ONCE) reduce 455) ((T_INT_CAST) reduce 455) ((T_ISSET) reduce 455) ((T_LINE) reduce 455) ((T_LIST) reduce 455) ((T_LNUMBER) reduce 455) ((T_MATCH) reduce 455) ((T_METHOD_C) reduce 455) ((T_NAME_FULLY_QUALIFIED) reduce 455) ((T_NAME_QUALIFIED) reduce 455) ((T_NAME_RELATIVE) reduce 455) ((T_NEW) reduce 455) ((T_NS_C) reduce 455) ((T_OBJECT_CAST) reduce 455) ((T_PRINT) reduce 455) ((T_READONLY) reduce 455) ((T_REQUIRE) reduce 455) ((T_REQUIRE_ONCE) reduce 455) ((T_START_HEREDOC) reduce 455) ((T_STATIC) reduce 455) ((T_STRING) reduce 455) ((T_STRING_CAST) reduce 455) ((T_THROW) reduce 455) ((T_TRAIT_C) reduce 455) ((T_UNSET_CAST) reduce 455) ((T_VARIABLE) reduce 455) ((T_YIELD) reduce 455) ((T_YIELD_FROM) reduce 455) (("[") reduce 455) (("`") reduce 455) (("~") reduce 455)) 2244 ((("!") reduce 456) (("\"") reduce 456) (("$") reduce 456) (("(") reduce 456) (("+") reduce 456) (("-") reduce 456) (("@") reduce 456) ((T_ARRAY) reduce 456) ((T_ARRAY_CAST) reduce 456) ((T_ATTRIBUTE) reduce 456) ((T_BOOL_CAST) reduce 456) ((T_CLASS_C) reduce 456) ((T_CLONE) reduce 456) ((T_CONSTANT_ENCAPSED_STRING) reduce 456) ((T_DEC) reduce 456) ((T_DIR) reduce 456) ((T_DNUMBER) reduce 456) ((T_DOUBLE_CAST) reduce 456) ((T_EMPTY) reduce 456) ((T_EVAL) reduce 456) ((T_EXIT) reduce 456) ((T_FILE) reduce 456) ((T_FN) reduce 456) ((T_FUNCTION) reduce 456) ((T_FUNC_C) reduce 456) ((T_INC) reduce 456) ((T_INCLUDE) reduce 456) ((T_INCLUDE_ONCE) reduce 456) ((T_INT_CAST) reduce 456) ((T_ISSET) reduce 456) ((T_LINE) reduce 456) ((T_LIST) reduce 456) ((T_LNUMBER) reduce 456) ((T_MATCH) reduce 456) ((T_METHOD_C) reduce 456) ((T_NAME_FULLY_QUALIFIED) reduce 456) ((T_NAME_QUALIFIED) reduce 456) ((T_NAME_RELATIVE) reduce 456) ((T_NEW) reduce 456) ((T_NS_C) reduce 456) ((T_OBJECT_CAST) reduce 456) ((T_PRINT) reduce 456) ((T_READONLY) reduce 456) ((T_REQUIRE) reduce 456) ((T_REQUIRE_ONCE) reduce 456) ((T_START_HEREDOC) reduce 456) ((T_STATIC) reduce 456) ((T_STRING) reduce 456) ((T_STRING_CAST) reduce 456) ((T_THROW) reduce 456) ((T_TRAIT_C) reduce 456) ((T_UNSET_CAST) reduce 456) ((T_VARIABLE) reduce 456) ((T_YIELD) reduce 456) ((T_YIELD_FROM) reduce 456) (("[") reduce 456) (("`") reduce 456) (("~") reduce 456)) 2246 ((("%") shift) ((")") reduce 455) (("*") shift) (("+") shift) ((",") reduce 455) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 455) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 2247 ((("%") reduce 451) ((")") reduce 451) (("*") reduce 451) (("+") reduce 451) ((",") reduce 451) (("-") reduce 451) ((".") reduce 451) (("/") reduce 451) (("<") reduce 451) ((">") reduce 451) (("?") reduce 451) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_BOOLEAN_AND) reduce 451) ((T_BOOLEAN_OR) reduce 451) ((T_COALESCE) reduce 451) ((T_DOUBLE_ARROW) reduce 451) ((T_INSTANCEOF) reduce 451) ((T_IS_EQUAL) reduce 451) ((T_IS_GREATER_OR_EQUAL) reduce 451) ((T_IS_IDENTICAL) reduce 451) ((T_IS_NOT_EQUAL) reduce 451) ((T_IS_NOT_IDENTICAL) reduce 451) ((T_IS_SMALLER_OR_EQUAL) reduce 451) ((T_LOGICAL_AND) reduce 451) ((T_LOGICAL_OR) reduce 451) ((T_LOGICAL_XOR) reduce 451) ((T_POW) reduce 451) ((T_SL) reduce 451) ((T_SPACESHIP) reduce 451) ((T_SR) reduce 451) (("^") reduce 451) (("|") reduce 451)) 2248 (((T_ARRAY) shift) ((T_CALLABLE) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_STATIC) shift) ((T_STRING) shift)) 2250 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 277) ((T_DOUBLE_ARROW) reduce 277) (("|") reduce 277)) 2251 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 278) ((T_DOUBLE_ARROW) reduce 278) (("|") reduce 278)) 2252 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_DOUBLE_ARROW) reduce 93) (("|") reduce 93)) 2253 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_DOUBLE_ARROW) reduce 92) (("|") reduce 92)) 2254 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_DOUBLE_ARROW) reduce 94) (("|") reduce 94)) 2255 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 266) ((T_DOUBLE_ARROW) reduce 266) (("|") reduce 266)) 2256 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_DOUBLE_ARROW) reduce 91) (("|") reduce 91)) 2257 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_DOUBLE_ARROW) reduce 264)) 2258 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 279) ((T_DOUBLE_ARROW) reduce 279) (("|") reduce 279)) 2259 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_DOUBLE_ARROW) reduce 261) (("|") reduce 267)) 2260 (((T_DOUBLE_ARROW) reduce 287)) 2261 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 265) ((T_DOUBLE_ARROW) reduce 265) (("|") reduce 265)) 2262 (((T_DOUBLE_ARROW) reduce 263) (("|") shift)) 2263 ((("|") shift)) 2264 ((("(") shift) ((T_ARRAY) shift) ((T_CALLABLE) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_STATIC) shift) ((T_STRING) shift)) 2266 (((T_DOUBLE_ARROW) reduce 277) (("|") reduce 277)) 2267 (((T_DOUBLE_ARROW) reduce 278) (("|") reduce 278)) 2268 (((T_DOUBLE_ARROW) reduce 93) (("|") reduce 93)) 2269 (((T_DOUBLE_ARROW) reduce 92) (("|") reduce 92)) 2270 (((T_DOUBLE_ARROW) reduce 94) (("|") reduce 94)) 2271 (((T_DOUBLE_ARROW) reduce 266) (("|") reduce 266)) 2272 (((T_DOUBLE_ARROW) reduce 91) (("|") reduce 91)) 2273 (((T_DOUBLE_ARROW) reduce 279) (("|") reduce 279)) 2274 (((T_DOUBLE_ARROW) reduce 267) (("|") reduce 267)) 2275 (((T_DOUBLE_ARROW) reduce 265) (("|") reduce 265)) 2276 (((T_DOUBLE_ARROW) reduce 269) (("|") reduce 269)) 2277 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 277)) 2278 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 278)) 2279 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93)) 2280 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92)) 2281 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94)) 2282 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 266)) 2283 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91)) 2284 (((")") shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift)) 2285 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 279)) 2286 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift)) 2287 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 265)) 2289 (((")") reduce 277) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 277)) 2290 (((")") reduce 278) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 278)) 2291 (((")") reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93)) 2292 (((")") reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92)) 2293 (((")") reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94)) 2294 (((")") reduce 266) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 266)) 2295 (((")") reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91)) 2296 (((")") reduce 279) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 279)) 2297 (((")") reduce 271) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 271)) 2298 (((")") reduce 265) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 265)) 2299 (((T_DOUBLE_ARROW) reduce 268) (("|") reduce 268)) 2301 (((")") reduce 272) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 272)) 2303 (((T_DOUBLE_ARROW) reduce 270) (("|") reduce 270)) 2305 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 277) ((T_DOUBLE_ARROW) reduce 277)) 2306 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 278) ((T_DOUBLE_ARROW) reduce 278)) 2307 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_DOUBLE_ARROW) reduce 93)) 2308 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_DOUBLE_ARROW) reduce 92)) 2309 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_DOUBLE_ARROW) reduce 94)) 2310 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 266) ((T_DOUBLE_ARROW) reduce 266)) 2311 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_DOUBLE_ARROW) reduce 91)) 2312 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 279) ((T_DOUBLE_ARROW) reduce 279)) 2313 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 271) ((T_DOUBLE_ARROW) reduce 271)) 2314 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 265) ((T_DOUBLE_ARROW) reduce 265)) 2316 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 272) ((T_DOUBLE_ARROW) reduce 272)) 2317 (((T_DOUBLE_ARROW) reduce 277)) 2318 (((T_DOUBLE_ARROW) reduce 278)) 2319 (((T_DOUBLE_ARROW) reduce 93)) 2320 (((T_DOUBLE_ARROW) reduce 92)) 2321 (((T_DOUBLE_ARROW) reduce 94)) 2322 (((T_DOUBLE_ARROW) reduce 266)) 2323 (((T_DOUBLE_ARROW) reduce 91)) 2324 (((T_DOUBLE_ARROW) reduce 279)) 2325 (((T_DOUBLE_ARROW) reduce 262)) 2326 (((T_DOUBLE_ARROW) reduce 265)) 2328 ((("|") reduce 268)) 2393 ((("%") shift) ((")") reduce 552) (("*") shift) (("+") shift) ((",") reduce 552) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 2515 ((("%") shift) ((")") reduce 368) (("*") shift) (("+") shift) ((",") reduce 368) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 368) ((T_LOGICAL_OR) reduce 368) ((T_LOGICAL_XOR) reduce 368) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 2517 ((("%") reduce 73) (("(") reduce 73) ((")") reduce 73) (("*") reduce 73) (("+") reduce 73) ((",") reduce 73) (("-") reduce 73) ((".") reduce 73) (("/") reduce 73) (("<") reduce 73) ((">") reduce 73) (("?") reduce 73) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_BOOLEAN_AND) reduce 73) ((T_BOOLEAN_OR) reduce 73) ((T_COALESCE) reduce 73) ((T_INSTANCEOF) reduce 73) ((T_IS_EQUAL) reduce 73) ((T_IS_GREATER_OR_EQUAL) reduce 73) ((T_IS_IDENTICAL) reduce 73) ((T_IS_NOT_EQUAL) reduce 73) ((T_IS_NOT_IDENTICAL) reduce 73) ((T_IS_SMALLER_OR_EQUAL) reduce 73) ((T_LOGICAL_AND) reduce 73) ((T_LOGICAL_OR) reduce 73) ((T_LOGICAL_XOR) reduce 73) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 73) ((T_OBJECT_OPERATOR) reduce 73) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 73) ((T_POW) reduce 73) ((T_SL) reduce 73) ((T_SPACESHIP) reduce 73) ((T_SR) reduce 73) (("[") reduce 73) (("^") reduce 73) (("{") reduce 73) (("|") reduce 73)) 2518 ((("%") reduce 52) (("(") reduce 52) ((")") reduce 52) (("*") reduce 52) (("+") reduce 52) ((",") reduce 52) (("-") reduce 52) ((".") reduce 52) (("/") reduce 52) (("<") reduce 52) ((">") reduce 52) (("?") reduce 52) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_BOOLEAN_AND) reduce 52) ((T_BOOLEAN_OR) reduce 52) ((T_COALESCE) reduce 52) ((T_INSTANCEOF) reduce 52) ((T_IS_EQUAL) reduce 52) ((T_IS_GREATER_OR_EQUAL) reduce 52) ((T_IS_IDENTICAL) reduce 52) ((T_IS_NOT_EQUAL) reduce 52) ((T_IS_NOT_IDENTICAL) reduce 52) ((T_IS_SMALLER_OR_EQUAL) reduce 52) ((T_LOGICAL_AND) reduce 52) ((T_LOGICAL_OR) reduce 52) ((T_LOGICAL_XOR) reduce 52) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 52) ((T_OBJECT_OPERATOR) reduce 52) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 52) ((T_POW) reduce 52) ((T_SL) reduce 52) ((T_SPACESHIP) reduce 52) ((T_SR) reduce 52) (("[") reduce 52) (("^") reduce 52) (("{") reduce 52) (("|") reduce 52)) 2519 ((("%") reduce 27) (("(") reduce 27) ((")") reduce 27) (("*") reduce 27) (("+") reduce 27) ((",") reduce 27) (("-") reduce 27) ((".") reduce 27) (("/") reduce 27) (("<") reduce 27) ((">") reduce 27) (("?") reduce 27) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_BOOLEAN_AND) reduce 27) ((T_BOOLEAN_OR) reduce 27) ((T_COALESCE) reduce 27) ((T_INSTANCEOF) reduce 27) ((T_IS_EQUAL) reduce 27) ((T_IS_GREATER_OR_EQUAL) reduce 27) ((T_IS_IDENTICAL) reduce 27) ((T_IS_NOT_EQUAL) reduce 27) ((T_IS_NOT_IDENTICAL) reduce 27) ((T_IS_SMALLER_OR_EQUAL) reduce 27) ((T_LOGICAL_AND) reduce 27) ((T_LOGICAL_OR) reduce 27) ((T_LOGICAL_XOR) reduce 27) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 27) ((T_OBJECT_OPERATOR) reduce 27) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 27) ((T_POW) reduce 27) ((T_SL) reduce 27) ((T_SPACESHIP) reduce 27) ((T_SR) reduce 27) (("[") reduce 27) (("^") reduce 27) (("{") reduce 27) (("|") reduce 27)) 2520 ((("%") reduce 51) (("(") reduce 51) ((")") reduce 51) (("*") reduce 51) (("+") reduce 51) ((",") reduce 51) (("-") reduce 51) ((".") reduce 51) (("/") reduce 51) (("<") reduce 51) ((">") reduce 51) (("?") reduce 51) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_BOOLEAN_AND) reduce 51) ((T_BOOLEAN_OR) reduce 51) ((T_COALESCE) reduce 51) ((T_INSTANCEOF) reduce 51) ((T_IS_EQUAL) reduce 51) ((T_IS_GREATER_OR_EQUAL) reduce 51) ((T_IS_IDENTICAL) reduce 51) ((T_IS_NOT_EQUAL) reduce 51) ((T_IS_NOT_IDENTICAL) reduce 51) ((T_IS_SMALLER_OR_EQUAL) reduce 51) ((T_LOGICAL_AND) reduce 51) ((T_LOGICAL_OR) reduce 51) ((T_LOGICAL_XOR) reduce 51) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 51) ((T_OBJECT_OPERATOR) reduce 51) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 51) ((T_POW) reduce 51) ((T_SL) reduce 51) ((T_SPACESHIP) reduce 51) ((T_SR) reduce 51) (("[") reduce 51) (("^") reduce 51) (("{") reduce 51) (("|") reduce 51)) 2521 ((("%") reduce 53) (("(") reduce 53) ((")") reduce 53) (("*") reduce 53) (("+") reduce 53) ((",") reduce 53) (("-") reduce 53) ((".") reduce 53) (("/") reduce 53) (("<") reduce 53) ((">") reduce 53) (("?") reduce 53) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_BOOLEAN_AND) reduce 53) ((T_BOOLEAN_OR) reduce 53) ((T_COALESCE) reduce 53) ((T_INSTANCEOF) reduce 53) ((T_IS_EQUAL) reduce 53) ((T_IS_GREATER_OR_EQUAL) reduce 53) ((T_IS_IDENTICAL) reduce 53) ((T_IS_NOT_EQUAL) reduce 53) ((T_IS_NOT_IDENTICAL) reduce 53) ((T_IS_SMALLER_OR_EQUAL) reduce 53) ((T_LOGICAL_AND) reduce 53) ((T_LOGICAL_OR) reduce 53) ((T_LOGICAL_XOR) reduce 53) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 53) ((T_OBJECT_OPERATOR) reduce 53) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 53) ((T_POW) reduce 53) ((T_SL) reduce 53) ((T_SPACESHIP) reduce 53) ((T_SR) reduce 53) (("[") reduce 53) (("^") reduce 53) (("{") reduce 53) (("|") reduce 53)) 2522 ((("%") reduce 49) (("(") reduce 49) ((")") reduce 49) (("*") reduce 49) (("+") reduce 49) ((",") reduce 49) (("-") reduce 49) ((".") reduce 49) (("/") reduce 49) (("<") reduce 49) ((">") reduce 49) (("?") reduce 49) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_BOOLEAN_AND) reduce 49) ((T_BOOLEAN_OR) reduce 49) ((T_COALESCE) reduce 49) ((T_INSTANCEOF) reduce 49) ((T_IS_EQUAL) reduce 49) ((T_IS_GREATER_OR_EQUAL) reduce 49) ((T_IS_IDENTICAL) reduce 49) ((T_IS_NOT_EQUAL) reduce 49) ((T_IS_NOT_IDENTICAL) reduce 49) ((T_IS_SMALLER_OR_EQUAL) reduce 49) ((T_LOGICAL_AND) reduce 49) ((T_LOGICAL_OR) reduce 49) ((T_LOGICAL_XOR) reduce 49) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 49) ((T_OBJECT_OPERATOR) reduce 49) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 49) ((T_POW) reduce 49) ((T_SL) reduce 49) ((T_SPACESHIP) reduce 49) ((T_SR) reduce 49) (("[") reduce 49) (("^") reduce 49) (("{") reduce 49) (("|") reduce 49)) 2523 ((("%") reduce 29) (("(") reduce 29) ((")") reduce 29) (("*") reduce 29) (("+") reduce 29) ((",") reduce 29) (("-") reduce 29) ((".") reduce 29) (("/") reduce 29) (("<") reduce 29) ((">") reduce 29) (("?") reduce 29) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_BOOLEAN_AND) reduce 29) ((T_BOOLEAN_OR) reduce 29) ((T_COALESCE) reduce 29) ((T_INSTANCEOF) reduce 29) ((T_IS_EQUAL) reduce 29) ((T_IS_GREATER_OR_EQUAL) reduce 29) ((T_IS_IDENTICAL) reduce 29) ((T_IS_NOT_EQUAL) reduce 29) ((T_IS_NOT_IDENTICAL) reduce 29) ((T_IS_SMALLER_OR_EQUAL) reduce 29) ((T_LOGICAL_AND) reduce 29) ((T_LOGICAL_OR) reduce 29) ((T_LOGICAL_XOR) reduce 29) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 29) ((T_OBJECT_OPERATOR) reduce 29) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 29) ((T_POW) reduce 29) ((T_SL) reduce 29) ((T_SPACESHIP) reduce 29) ((T_SR) reduce 29) (("[") reduce 29) (("^") reduce 29) (("{") reduce 29) (("|") reduce 29)) 2524 ((("%") reduce 59) (("(") reduce 59) ((")") reduce 59) (("*") reduce 59) (("+") reduce 59) ((",") reduce 59) (("-") reduce 59) ((".") reduce 59) (("/") reduce 59) (("<") reduce 59) ((">") reduce 59) (("?") reduce 59) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_BOOLEAN_AND) reduce 59) ((T_BOOLEAN_OR) reduce 59) ((T_COALESCE) reduce 59) ((T_INSTANCEOF) reduce 59) ((T_IS_EQUAL) reduce 59) ((T_IS_GREATER_OR_EQUAL) reduce 59) ((T_IS_IDENTICAL) reduce 59) ((T_IS_NOT_EQUAL) reduce 59) ((T_IS_NOT_IDENTICAL) reduce 59) ((T_IS_SMALLER_OR_EQUAL) reduce 59) ((T_LOGICAL_AND) reduce 59) ((T_LOGICAL_OR) reduce 59) ((T_LOGICAL_XOR) reduce 59) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 59) ((T_OBJECT_OPERATOR) reduce 59) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 59) ((T_POW) reduce 59) ((T_SL) reduce 59) ((T_SPACESHIP) reduce 59) ((T_SR) reduce 59) (("[") reduce 59) (("^") reduce 59) (("{") reduce 59) (("|") reduce 59)) 2525 ((("%") reduce 60) (("(") reduce 60) ((")") reduce 60) (("*") reduce 60) (("+") reduce 60) ((",") reduce 60) (("-") reduce 60) ((".") reduce 60) (("/") reduce 60) (("<") reduce 60) ((">") reduce 60) (("?") reduce 60) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_BOOLEAN_AND) reduce 60) ((T_BOOLEAN_OR) reduce 60) ((T_COALESCE) reduce 60) ((T_INSTANCEOF) reduce 60) ((T_IS_EQUAL) reduce 60) ((T_IS_GREATER_OR_EQUAL) reduce 60) ((T_IS_IDENTICAL) reduce 60) ((T_IS_NOT_EQUAL) reduce 60) ((T_IS_NOT_IDENTICAL) reduce 60) ((T_IS_SMALLER_OR_EQUAL) reduce 60) ((T_LOGICAL_AND) reduce 60) ((T_LOGICAL_OR) reduce 60) ((T_LOGICAL_XOR) reduce 60) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 60) ((T_OBJECT_OPERATOR) reduce 60) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 60) ((T_POW) reduce 60) ((T_SL) reduce 60) ((T_SPACESHIP) reduce 60) ((T_SR) reduce 60) (("[") reduce 60) (("^") reduce 60) (("{") reduce 60) (("|") reduce 60)) 2526 ((("%") reduce 11) (("(") reduce 11) ((")") reduce 11) (("*") reduce 11) (("+") reduce 11) ((",") reduce 11) (("-") reduce 11) ((".") reduce 11) (("/") reduce 11) (("<") reduce 11) ((">") reduce 11) (("?") reduce 11) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_BOOLEAN_AND) reduce 11) ((T_BOOLEAN_OR) reduce 11) ((T_COALESCE) reduce 11) ((T_INSTANCEOF) reduce 11) ((T_IS_EQUAL) reduce 11) ((T_IS_GREATER_OR_EQUAL) reduce 11) ((T_IS_IDENTICAL) reduce 11) ((T_IS_NOT_EQUAL) reduce 11) ((T_IS_NOT_IDENTICAL) reduce 11) ((T_IS_SMALLER_OR_EQUAL) reduce 11) ((T_LOGICAL_AND) reduce 11) ((T_LOGICAL_OR) reduce 11) ((T_LOGICAL_XOR) reduce 11) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 11) ((T_OBJECT_OPERATOR) reduce 11) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 11) ((T_POW) reduce 11) ((T_SL) reduce 11) ((T_SPACESHIP) reduce 11) ((T_SR) reduce 11) (("[") reduce 11) (("^") reduce 11) (("{") reduce 11) (("|") reduce 11)) 2527 ((("%") reduce 42) (("(") reduce 42) ((")") reduce 42) (("*") reduce 42) (("+") reduce 42) ((",") reduce 42) (("-") reduce 42) ((".") reduce 42) (("/") reduce 42) (("<") reduce 42) ((">") reduce 42) (("?") reduce 42) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_BOOLEAN_AND) reduce 42) ((T_BOOLEAN_OR) reduce 42) ((T_COALESCE) reduce 42) ((T_INSTANCEOF) reduce 42) ((T_IS_EQUAL) reduce 42) ((T_IS_GREATER_OR_EQUAL) reduce 42) ((T_IS_IDENTICAL) reduce 42) ((T_IS_NOT_EQUAL) reduce 42) ((T_IS_NOT_IDENTICAL) reduce 42) ((T_IS_SMALLER_OR_EQUAL) reduce 42) ((T_LOGICAL_AND) reduce 42) ((T_LOGICAL_OR) reduce 42) ((T_LOGICAL_XOR) reduce 42) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 42) ((T_OBJECT_OPERATOR) reduce 42) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 42) ((T_POW) reduce 42) ((T_SL) reduce 42) ((T_SPACESHIP) reduce 42) ((T_SR) reduce 42) (("[") reduce 42) (("^") reduce 42) (("{") reduce 42) (("|") reduce 42)) 2528 ((("%") reduce 39) (("(") reduce 39) ((")") reduce 39) (("*") reduce 39) (("+") reduce 39) ((",") reduce 39) (("-") reduce 39) ((".") reduce 39) (("/") reduce 39) (("<") reduce 39) ((">") reduce 39) (("?") reduce 39) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_BOOLEAN_AND) reduce 39) ((T_BOOLEAN_OR) reduce 39) ((T_COALESCE) reduce 39) ((T_INSTANCEOF) reduce 39) ((T_IS_EQUAL) reduce 39) ((T_IS_GREATER_OR_EQUAL) reduce 39) ((T_IS_IDENTICAL) reduce 39) ((T_IS_NOT_EQUAL) reduce 39) ((T_IS_NOT_IDENTICAL) reduce 39) ((T_IS_SMALLER_OR_EQUAL) reduce 39) ((T_LOGICAL_AND) reduce 39) ((T_LOGICAL_OR) reduce 39) ((T_LOGICAL_XOR) reduce 39) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 39) ((T_OBJECT_OPERATOR) reduce 39) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 39) ((T_POW) reduce 39) ((T_SL) reduce 39) ((T_SPACESHIP) reduce 39) ((T_SR) reduce 39) (("[") reduce 39) (("^") reduce 39) (("{") reduce 39) (("|") reduce 39)) 2529 ((("%") reduce 25) (("(") reduce 25) ((")") reduce 25) (("*") reduce 25) (("+") reduce 25) ((",") reduce 25) (("-") reduce 25) ((".") reduce 25) (("/") reduce 25) (("<") reduce 25) ((">") reduce 25) (("?") reduce 25) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_BOOLEAN_AND) reduce 25) ((T_BOOLEAN_OR) reduce 25) ((T_COALESCE) reduce 25) ((T_INSTANCEOF) reduce 25) ((T_IS_EQUAL) reduce 25) ((T_IS_GREATER_OR_EQUAL) reduce 25) ((T_IS_IDENTICAL) reduce 25) ((T_IS_NOT_EQUAL) reduce 25) ((T_IS_NOT_IDENTICAL) reduce 25) ((T_IS_SMALLER_OR_EQUAL) reduce 25) ((T_LOGICAL_AND) reduce 25) ((T_LOGICAL_OR) reduce 25) ((T_LOGICAL_XOR) reduce 25) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 25) ((T_OBJECT_OPERATOR) reduce 25) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 25) ((T_POW) reduce 25) ((T_SL) reduce 25) ((T_SPACESHIP) reduce 25) ((T_SR) reduce 25) (("[") reduce 25) (("^") reduce 25) (("{") reduce 25) (("|") reduce 25)) 2530 ((("%") reduce 50) (("(") reduce 50) ((")") reduce 50) (("*") reduce 50) (("+") reduce 50) ((",") reduce 50) (("-") reduce 50) ((".") reduce 50) (("/") reduce 50) (("<") reduce 50) ((">") reduce 50) (("?") reduce 50) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_BOOLEAN_AND) reduce 50) ((T_BOOLEAN_OR) reduce 50) ((T_COALESCE) reduce 50) ((T_INSTANCEOF) reduce 50) ((T_IS_EQUAL) reduce 50) ((T_IS_GREATER_OR_EQUAL) reduce 50) ((T_IS_IDENTICAL) reduce 50) ((T_IS_NOT_EQUAL) reduce 50) ((T_IS_NOT_IDENTICAL) reduce 50) ((T_IS_SMALLER_OR_EQUAL) reduce 50) ((T_LOGICAL_AND) reduce 50) ((T_LOGICAL_OR) reduce 50) ((T_LOGICAL_XOR) reduce 50) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 50) ((T_OBJECT_OPERATOR) reduce 50) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 50) ((T_POW) reduce 50) ((T_SL) reduce 50) ((T_SPACESHIP) reduce 50) ((T_SR) reduce 50) (("[") reduce 50) (("^") reduce 50) (("{") reduce 50) (("|") reduce 50)) 2531 ((("%") reduce 66) (("(") reduce 66) ((")") reduce 66) (("*") reduce 66) (("+") reduce 66) ((",") reduce 66) (("-") reduce 66) ((".") reduce 66) (("/") reduce 66) (("<") reduce 66) ((">") reduce 66) (("?") reduce 66) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_BOOLEAN_AND) reduce 66) ((T_BOOLEAN_OR) reduce 66) ((T_COALESCE) reduce 66) ((T_INSTANCEOF) reduce 66) ((T_IS_EQUAL) reduce 66) ((T_IS_GREATER_OR_EQUAL) reduce 66) ((T_IS_IDENTICAL) reduce 66) ((T_IS_NOT_EQUAL) reduce 66) ((T_IS_NOT_IDENTICAL) reduce 66) ((T_IS_SMALLER_OR_EQUAL) reduce 66) ((T_LOGICAL_AND) reduce 66) ((T_LOGICAL_OR) reduce 66) ((T_LOGICAL_XOR) reduce 66) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 66) ((T_OBJECT_OPERATOR) reduce 66) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 66) ((T_POW) reduce 66) ((T_SL) reduce 66) ((T_SPACESHIP) reduce 66) ((T_SR) reduce 66) (("[") reduce 66) (("^") reduce 66) (("{") reduce 66) (("|") reduce 66)) 2532 ((("%") reduce 18) (("(") reduce 18) ((")") reduce 18) (("*") reduce 18) (("+") reduce 18) ((",") reduce 18) (("-") reduce 18) ((".") reduce 18) (("/") reduce 18) (("<") reduce 18) ((">") reduce 18) (("?") reduce 18) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_BOOLEAN_AND) reduce 18) ((T_BOOLEAN_OR) reduce 18) ((T_COALESCE) reduce 18) ((T_INSTANCEOF) reduce 18) ((T_IS_EQUAL) reduce 18) ((T_IS_GREATER_OR_EQUAL) reduce 18) ((T_IS_IDENTICAL) reduce 18) ((T_IS_NOT_EQUAL) reduce 18) ((T_IS_NOT_IDENTICAL) reduce 18) ((T_IS_SMALLER_OR_EQUAL) reduce 18) ((T_LOGICAL_AND) reduce 18) ((T_LOGICAL_OR) reduce 18) ((T_LOGICAL_XOR) reduce 18) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 18) ((T_OBJECT_OPERATOR) reduce 18) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 18) ((T_POW) reduce 18) ((T_SL) reduce 18) ((T_SPACESHIP) reduce 18) ((T_SR) reduce 18) (("[") reduce 18) (("^") reduce 18) (("{") reduce 18) (("|") reduce 18)) 2533 ((("%") reduce 17) (("(") reduce 17) ((")") reduce 17) (("*") reduce 17) (("+") reduce 17) ((",") reduce 17) (("-") reduce 17) ((".") reduce 17) (("/") reduce 17) (("<") reduce 17) ((">") reduce 17) (("?") reduce 17) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_BOOLEAN_AND) reduce 17) ((T_BOOLEAN_OR) reduce 17) ((T_COALESCE) reduce 17) ((T_INSTANCEOF) reduce 17) ((T_IS_EQUAL) reduce 17) ((T_IS_GREATER_OR_EQUAL) reduce 17) ((T_IS_IDENTICAL) reduce 17) ((T_IS_NOT_EQUAL) reduce 17) ((T_IS_NOT_IDENTICAL) reduce 17) ((T_IS_SMALLER_OR_EQUAL) reduce 17) ((T_LOGICAL_AND) reduce 17) ((T_LOGICAL_OR) reduce 17) ((T_LOGICAL_XOR) reduce 17) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 17) ((T_OBJECT_OPERATOR) reduce 17) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 17) ((T_POW) reduce 17) ((T_SL) reduce 17) ((T_SPACESHIP) reduce 17) ((T_SR) reduce 17) (("[") reduce 17) (("^") reduce 17) (("{") reduce 17) (("|") reduce 17)) 2534 ((("%") reduce 15) (("(") reduce 15) ((")") reduce 15) (("*") reduce 15) (("+") reduce 15) ((",") reduce 15) (("-") reduce 15) ((".") reduce 15) (("/") reduce 15) (("<") reduce 15) ((">") reduce 15) (("?") reduce 15) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_BOOLEAN_AND) reduce 15) ((T_BOOLEAN_OR) reduce 15) ((T_COALESCE) reduce 15) ((T_INSTANCEOF) reduce 15) ((T_IS_EQUAL) reduce 15) ((T_IS_GREATER_OR_EQUAL) reduce 15) ((T_IS_IDENTICAL) reduce 15) ((T_IS_NOT_EQUAL) reduce 15) ((T_IS_NOT_IDENTICAL) reduce 15) ((T_IS_SMALLER_OR_EQUAL) reduce 15) ((T_LOGICAL_AND) reduce 15) ((T_LOGICAL_OR) reduce 15) ((T_LOGICAL_XOR) reduce 15) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 15) ((T_OBJECT_OPERATOR) reduce 15) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 15) ((T_POW) reduce 15) ((T_SL) reduce 15) ((T_SPACESHIP) reduce 15) ((T_SR) reduce 15) (("[") reduce 15) (("^") reduce 15) (("{") reduce 15) (("|") reduce 15)) 2535 ((("%") reduce 14) (("(") reduce 14) ((")") reduce 14) (("*") reduce 14) (("+") reduce 14) ((",") reduce 14) (("-") reduce 14) ((".") reduce 14) (("/") reduce 14) (("<") reduce 14) ((">") reduce 14) (("?") reduce 14) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_BOOLEAN_AND) reduce 14) ((T_BOOLEAN_OR) reduce 14) ((T_COALESCE) reduce 14) ((T_INSTANCEOF) reduce 14) ((T_IS_EQUAL) reduce 14) ((T_IS_GREATER_OR_EQUAL) reduce 14) ((T_IS_IDENTICAL) reduce 14) ((T_IS_NOT_EQUAL) reduce 14) ((T_IS_NOT_IDENTICAL) reduce 14) ((T_IS_SMALLER_OR_EQUAL) reduce 14) ((T_LOGICAL_AND) reduce 14) ((T_LOGICAL_OR) reduce 14) ((T_LOGICAL_XOR) reduce 14) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 14) ((T_OBJECT_OPERATOR) reduce 14) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 14) ((T_POW) reduce 14) ((T_SL) reduce 14) ((T_SPACESHIP) reduce 14) ((T_SR) reduce 14) (("[") reduce 14) (("^") reduce 14) (("{") reduce 14) (("|") reduce 14)) 2536 ((("%") reduce 38) (("(") reduce 38) ((")") reduce 38) (("*") reduce 38) (("+") reduce 38) ((",") reduce 38) (("-") reduce 38) ((".") reduce 38) (("/") reduce 38) (("<") reduce 38) ((">") reduce 38) (("?") reduce 38) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_BOOLEAN_AND) reduce 38) ((T_BOOLEAN_OR) reduce 38) ((T_COALESCE) reduce 38) ((T_INSTANCEOF) reduce 38) ((T_IS_EQUAL) reduce 38) ((T_IS_GREATER_OR_EQUAL) reduce 38) ((T_IS_IDENTICAL) reduce 38) ((T_IS_NOT_EQUAL) reduce 38) ((T_IS_NOT_IDENTICAL) reduce 38) ((T_IS_SMALLER_OR_EQUAL) reduce 38) ((T_LOGICAL_AND) reduce 38) ((T_LOGICAL_OR) reduce 38) ((T_LOGICAL_XOR) reduce 38) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 38) ((T_OBJECT_OPERATOR) reduce 38) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 38) ((T_POW) reduce 38) ((T_SL) reduce 38) ((T_SPACESHIP) reduce 38) ((T_SR) reduce 38) (("[") reduce 38) (("^") reduce 38) (("{") reduce 38) (("|") reduce 38)) 2537 ((("%") reduce 26) (("(") reduce 26) ((")") reduce 26) (("*") reduce 26) (("+") reduce 26) ((",") reduce 26) (("-") reduce 26) ((".") reduce 26) (("/") reduce 26) (("<") reduce 26) ((">") reduce 26) (("?") reduce 26) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_BOOLEAN_AND) reduce 26) ((T_BOOLEAN_OR) reduce 26) ((T_COALESCE) reduce 26) ((T_INSTANCEOF) reduce 26) ((T_IS_EQUAL) reduce 26) ((T_IS_GREATER_OR_EQUAL) reduce 26) ((T_IS_IDENTICAL) reduce 26) ((T_IS_NOT_EQUAL) reduce 26) ((T_IS_NOT_IDENTICAL) reduce 26) ((T_IS_SMALLER_OR_EQUAL) reduce 26) ((T_LOGICAL_AND) reduce 26) ((T_LOGICAL_OR) reduce 26) ((T_LOGICAL_XOR) reduce 26) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 26) ((T_OBJECT_OPERATOR) reduce 26) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 26) ((T_POW) reduce 26) ((T_SL) reduce 26) ((T_SPACESHIP) reduce 26) ((T_SR) reduce 26) (("[") reduce 26) (("^") reduce 26) (("{") reduce 26) (("|") reduce 26)) 2538 ((("%") reduce 22) (("(") reduce 22) ((")") reduce 22) (("*") reduce 22) (("+") reduce 22) ((",") reduce 22) (("-") reduce 22) ((".") reduce 22) (("/") reduce 22) (("<") reduce 22) ((">") reduce 22) (("?") reduce 22) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_BOOLEAN_AND) reduce 22) ((T_BOOLEAN_OR) reduce 22) ((T_COALESCE) reduce 22) ((T_INSTANCEOF) reduce 22) ((T_IS_EQUAL) reduce 22) ((T_IS_GREATER_OR_EQUAL) reduce 22) ((T_IS_IDENTICAL) reduce 22) ((T_IS_NOT_EQUAL) reduce 22) ((T_IS_NOT_IDENTICAL) reduce 22) ((T_IS_SMALLER_OR_EQUAL) reduce 22) ((T_LOGICAL_AND) reduce 22) ((T_LOGICAL_OR) reduce 22) ((T_LOGICAL_XOR) reduce 22) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 22) ((T_OBJECT_OPERATOR) reduce 22) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 22) ((T_POW) reduce 22) ((T_SL) reduce 22) ((T_SPACESHIP) reduce 22) ((T_SR) reduce 22) (("[") reduce 22) (("^") reduce 22) (("{") reduce 22) (("|") reduce 22)) 2539 ((("%") reduce 24) (("(") reduce 24) ((")") reduce 24) (("*") reduce 24) (("+") reduce 24) ((",") reduce 24) (("-") reduce 24) ((".") reduce 24) (("/") reduce 24) (("<") reduce 24) ((">") reduce 24) (("?") reduce 24) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_BOOLEAN_AND) reduce 24) ((T_BOOLEAN_OR) reduce 24) ((T_COALESCE) reduce 24) ((T_INSTANCEOF) reduce 24) ((T_IS_EQUAL) reduce 24) ((T_IS_GREATER_OR_EQUAL) reduce 24) ((T_IS_IDENTICAL) reduce 24) ((T_IS_NOT_EQUAL) reduce 24) ((T_IS_NOT_IDENTICAL) reduce 24) ((T_IS_SMALLER_OR_EQUAL) reduce 24) ((T_LOGICAL_AND) reduce 24) ((T_LOGICAL_OR) reduce 24) ((T_LOGICAL_XOR) reduce 24) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 24) ((T_OBJECT_OPERATOR) reduce 24) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 24) ((T_POW) reduce 24) ((T_SL) reduce 24) ((T_SPACESHIP) reduce 24) ((T_SR) reduce 24) (("[") reduce 24) (("^") reduce 24) (("{") reduce 24) (("|") reduce 24)) 2540 ((("%") reduce 16) (("(") reduce 16) ((")") reduce 16) (("*") reduce 16) (("+") reduce 16) ((",") reduce 16) (("-") reduce 16) ((".") reduce 16) (("/") reduce 16) (("<") reduce 16) ((">") reduce 16) (("?") reduce 16) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_BOOLEAN_AND) reduce 16) ((T_BOOLEAN_OR) reduce 16) ((T_COALESCE) reduce 16) ((T_INSTANCEOF) reduce 16) ((T_IS_EQUAL) reduce 16) ((T_IS_GREATER_OR_EQUAL) reduce 16) ((T_IS_IDENTICAL) reduce 16) ((T_IS_NOT_EQUAL) reduce 16) ((T_IS_NOT_IDENTICAL) reduce 16) ((T_IS_SMALLER_OR_EQUAL) reduce 16) ((T_LOGICAL_AND) reduce 16) ((T_LOGICAL_OR) reduce 16) ((T_LOGICAL_XOR) reduce 16) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 16) ((T_OBJECT_OPERATOR) reduce 16) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 16) ((T_POW) reduce 16) ((T_SL) reduce 16) ((T_SPACESHIP) reduce 16) ((T_SR) reduce 16) (("[") reduce 16) (("^") reduce 16) (("{") reduce 16) (("|") reduce 16)) 2541 ((("%") reduce 48) (("(") reduce 48) ((")") reduce 48) (("*") reduce 48) (("+") reduce 48) ((",") reduce 48) (("-") reduce 48) ((".") reduce 48) (("/") reduce 48) (("<") reduce 48) ((">") reduce 48) (("?") reduce 48) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_BOOLEAN_AND) reduce 48) ((T_BOOLEAN_OR) reduce 48) ((T_COALESCE) reduce 48) ((T_INSTANCEOF) reduce 48) ((T_IS_EQUAL) reduce 48) ((T_IS_GREATER_OR_EQUAL) reduce 48) ((T_IS_IDENTICAL) reduce 48) ((T_IS_NOT_EQUAL) reduce 48) ((T_IS_NOT_IDENTICAL) reduce 48) ((T_IS_SMALLER_OR_EQUAL) reduce 48) ((T_LOGICAL_AND) reduce 48) ((T_LOGICAL_OR) reduce 48) ((T_LOGICAL_XOR) reduce 48) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 48) ((T_OBJECT_OPERATOR) reduce 48) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 48) ((T_POW) reduce 48) ((T_SL) reduce 48) ((T_SPACESHIP) reduce 48) ((T_SR) reduce 48) (("[") reduce 48) (("^") reduce 48) (("{") reduce 48) (("|") reduce 48)) 2542 ((("%") reduce 20) (("(") reduce 20) ((")") reduce 20) (("*") reduce 20) (("+") reduce 20) ((",") reduce 20) (("-") reduce 20) ((".") reduce 20) (("/") reduce 20) (("<") reduce 20) ((">") reduce 20) (("?") reduce 20) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_BOOLEAN_AND) reduce 20) ((T_BOOLEAN_OR) reduce 20) ((T_COALESCE) reduce 20) ((T_INSTANCEOF) reduce 20) ((T_IS_EQUAL) reduce 20) ((T_IS_GREATER_OR_EQUAL) reduce 20) ((T_IS_IDENTICAL) reduce 20) ((T_IS_NOT_EQUAL) reduce 20) ((T_IS_NOT_IDENTICAL) reduce 20) ((T_IS_SMALLER_OR_EQUAL) reduce 20) ((T_LOGICAL_AND) reduce 20) ((T_LOGICAL_OR) reduce 20) ((T_LOGICAL_XOR) reduce 20) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 20) ((T_OBJECT_OPERATOR) reduce 20) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 20) ((T_POW) reduce 20) ((T_SL) reduce 20) ((T_SPACESHIP) reduce 20) ((T_SR) reduce 20) (("[") reduce 20) (("^") reduce 20) (("{") reduce 20) (("|") reduce 20)) 2543 ((("%") reduce 70) (("(") reduce 70) ((")") reduce 70) (("*") reduce 70) (("+") reduce 70) ((",") reduce 70) (("-") reduce 70) ((".") reduce 70) (("/") reduce 70) (("<") reduce 70) ((">") reduce 70) (("?") reduce 70) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_BOOLEAN_AND) reduce 70) ((T_BOOLEAN_OR) reduce 70) ((T_COALESCE) reduce 70) ((T_INSTANCEOF) reduce 70) ((T_IS_EQUAL) reduce 70) ((T_IS_GREATER_OR_EQUAL) reduce 70) ((T_IS_IDENTICAL) reduce 70) ((T_IS_NOT_EQUAL) reduce 70) ((T_IS_NOT_IDENTICAL) reduce 70) ((T_IS_SMALLER_OR_EQUAL) reduce 70) ((T_LOGICAL_AND) reduce 70) ((T_LOGICAL_OR) reduce 70) ((T_LOGICAL_XOR) reduce 70) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 70) ((T_OBJECT_OPERATOR) reduce 70) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 70) ((T_POW) reduce 70) ((T_SL) reduce 70) ((T_SPACESHIP) reduce 70) ((T_SR) reduce 70) (("[") reduce 70) (("^") reduce 70) (("{") reduce 70) (("|") reduce 70)) 2544 ((("%") reduce 3) (("(") reduce 3) ((")") reduce 3) (("*") reduce 3) (("+") reduce 3) ((",") reduce 3) (("-") reduce 3) ((".") reduce 3) (("/") reduce 3) (("<") reduce 3) ((">") reduce 3) (("?") reduce 3) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_BOOLEAN_AND) reduce 3) ((T_BOOLEAN_OR) reduce 3) ((T_COALESCE) reduce 3) ((T_INSTANCEOF) reduce 3) ((T_IS_EQUAL) reduce 3) ((T_IS_GREATER_OR_EQUAL) reduce 3) ((T_IS_IDENTICAL) reduce 3) ((T_IS_NOT_EQUAL) reduce 3) ((T_IS_NOT_IDENTICAL) reduce 3) ((T_IS_SMALLER_OR_EQUAL) reduce 3) ((T_LOGICAL_AND) reduce 3) ((T_LOGICAL_OR) reduce 3) ((T_LOGICAL_XOR) reduce 3) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 3) ((T_OBJECT_OPERATOR) reduce 3) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 3) ((T_POW) reduce 3) ((T_SL) reduce 3) ((T_SPACESHIP) reduce 3) ((T_SR) reduce 3) (("[") reduce 3) (("^") reduce 3) (("{") reduce 3) (("|") reduce 3)) 2545 ((("%") reduce 12) (("(") reduce 12) ((")") reduce 12) (("*") reduce 12) (("+") reduce 12) ((",") reduce 12) (("-") reduce 12) ((".") reduce 12) (("/") reduce 12) (("<") reduce 12) ((">") reduce 12) (("?") reduce 12) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_BOOLEAN_AND) reduce 12) ((T_BOOLEAN_OR) reduce 12) ((T_COALESCE) reduce 12) ((T_INSTANCEOF) reduce 12) ((T_IS_EQUAL) reduce 12) ((T_IS_GREATER_OR_EQUAL) reduce 12) ((T_IS_IDENTICAL) reduce 12) ((T_IS_NOT_EQUAL) reduce 12) ((T_IS_NOT_IDENTICAL) reduce 12) ((T_IS_SMALLER_OR_EQUAL) reduce 12) ((T_LOGICAL_AND) reduce 12) ((T_LOGICAL_OR) reduce 12) ((T_LOGICAL_XOR) reduce 12) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 12) ((T_OBJECT_OPERATOR) reduce 12) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 12) ((T_POW) reduce 12) ((T_SL) reduce 12) ((T_SPACESHIP) reduce 12) ((T_SR) reduce 12) (("[") reduce 12) (("^") reduce 12) (("{") reduce 12) (("|") reduce 12)) 2546 ((("%") reduce 54) (("(") reduce 54) ((")") reduce 54) (("*") reduce 54) (("+") reduce 54) ((",") reduce 54) (("-") reduce 54) ((".") reduce 54) (("/") reduce 54) (("<") reduce 54) ((">") reduce 54) (("?") reduce 54) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_BOOLEAN_AND) reduce 54) ((T_BOOLEAN_OR) reduce 54) ((T_COALESCE) reduce 54) ((T_INSTANCEOF) reduce 54) ((T_IS_EQUAL) reduce 54) ((T_IS_GREATER_OR_EQUAL) reduce 54) ((T_IS_IDENTICAL) reduce 54) ((T_IS_NOT_EQUAL) reduce 54) ((T_IS_NOT_IDENTICAL) reduce 54) ((T_IS_SMALLER_OR_EQUAL) reduce 54) ((T_LOGICAL_AND) reduce 54) ((T_LOGICAL_OR) reduce 54) ((T_LOGICAL_XOR) reduce 54) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 54) ((T_OBJECT_OPERATOR) reduce 54) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 54) ((T_POW) reduce 54) ((T_SL) reduce 54) ((T_SPACESHIP) reduce 54) ((T_SR) reduce 54) (("[") reduce 54) (("^") reduce 54) (("{") reduce 54) (("|") reduce 54)) 2547 ((("%") reduce 65) (("(") reduce 65) ((")") reduce 65) (("*") reduce 65) (("+") reduce 65) ((",") reduce 65) (("-") reduce 65) ((".") reduce 65) (("/") reduce 65) (("<") reduce 65) ((">") reduce 65) (("?") reduce 65) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_BOOLEAN_AND) reduce 65) ((T_BOOLEAN_OR) reduce 65) ((T_COALESCE) reduce 65) ((T_INSTANCEOF) reduce 65) ((T_IS_EQUAL) reduce 65) ((T_IS_GREATER_OR_EQUAL) reduce 65) ((T_IS_IDENTICAL) reduce 65) ((T_IS_NOT_EQUAL) reduce 65) ((T_IS_NOT_IDENTICAL) reduce 65) ((T_IS_SMALLER_OR_EQUAL) reduce 65) ((T_LOGICAL_AND) reduce 65) ((T_LOGICAL_OR) reduce 65) ((T_LOGICAL_XOR) reduce 65) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 65) ((T_OBJECT_OPERATOR) reduce 65) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 65) ((T_POW) reduce 65) ((T_SL) reduce 65) ((T_SPACESHIP) reduce 65) ((T_SR) reduce 65) (("[") reduce 65) (("^") reduce 65) (("{") reduce 65) (("|") reduce 65)) 2548 ((("%") reduce 74) (("(") reduce 74) ((")") reduce 74) (("*") reduce 74) (("+") reduce 74) ((",") reduce 74) (("-") reduce 74) ((".") reduce 74) (("/") reduce 74) (("<") reduce 74) ((">") reduce 74) (("?") reduce 74) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_BOOLEAN_AND) reduce 74) ((T_BOOLEAN_OR) reduce 74) ((T_COALESCE) reduce 74) ((T_INSTANCEOF) reduce 74) ((T_IS_EQUAL) reduce 74) ((T_IS_GREATER_OR_EQUAL) reduce 74) ((T_IS_IDENTICAL) reduce 74) ((T_IS_NOT_EQUAL) reduce 74) ((T_IS_NOT_IDENTICAL) reduce 74) ((T_IS_SMALLER_OR_EQUAL) reduce 74) ((T_LOGICAL_AND) reduce 74) ((T_LOGICAL_OR) reduce 74) ((T_LOGICAL_XOR) reduce 74) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 74) ((T_OBJECT_OPERATOR) reduce 74) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 74) ((T_POW) reduce 74) ((T_SL) reduce 74) ((T_SPACESHIP) reduce 74) ((T_SR) reduce 74) (("[") reduce 74) (("^") reduce 74) (("{") reduce 74) (("|") reduce 74)) 2549 ((("%") reduce 30) (("(") reduce 30) ((")") reduce 30) (("*") reduce 30) (("+") reduce 30) ((",") reduce 30) (("-") reduce 30) ((".") reduce 30) (("/") reduce 30) (("<") reduce 30) ((">") reduce 30) (("?") reduce 30) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_BOOLEAN_AND) reduce 30) ((T_BOOLEAN_OR) reduce 30) ((T_COALESCE) reduce 30) ((T_INSTANCEOF) reduce 30) ((T_IS_EQUAL) reduce 30) ((T_IS_GREATER_OR_EQUAL) reduce 30) ((T_IS_IDENTICAL) reduce 30) ((T_IS_NOT_EQUAL) reduce 30) ((T_IS_NOT_IDENTICAL) reduce 30) ((T_IS_SMALLER_OR_EQUAL) reduce 30) ((T_LOGICAL_AND) reduce 30) ((T_LOGICAL_OR) reduce 30) ((T_LOGICAL_XOR) reduce 30) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 30) ((T_OBJECT_OPERATOR) reduce 30) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 30) ((T_POW) reduce 30) ((T_SL) reduce 30) ((T_SPACESHIP) reduce 30) ((T_SR) reduce 30) (("[") reduce 30) (("^") reduce 30) (("{") reduce 30) (("|") reduce 30)) 2550 ((("%") reduce 68) (("(") reduce 68) ((")") reduce 68) (("*") reduce 68) (("+") reduce 68) ((",") reduce 68) (("-") reduce 68) ((".") reduce 68) (("/") reduce 68) (("<") reduce 68) ((">") reduce 68) (("?") reduce 68) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_BOOLEAN_AND) reduce 68) ((T_BOOLEAN_OR) reduce 68) ((T_COALESCE) reduce 68) ((T_INSTANCEOF) reduce 68) ((T_IS_EQUAL) reduce 68) ((T_IS_GREATER_OR_EQUAL) reduce 68) ((T_IS_IDENTICAL) reduce 68) ((T_IS_NOT_EQUAL) reduce 68) ((T_IS_NOT_IDENTICAL) reduce 68) ((T_IS_SMALLER_OR_EQUAL) reduce 68) ((T_LOGICAL_AND) reduce 68) ((T_LOGICAL_OR) reduce 68) ((T_LOGICAL_XOR) reduce 68) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 68) ((T_OBJECT_OPERATOR) reduce 68) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 68) ((T_POW) reduce 68) ((T_SL) reduce 68) ((T_SPACESHIP) reduce 68) ((T_SR) reduce 68) (("[") reduce 68) (("^") reduce 68) (("{") reduce 68) (("|") reduce 68)) 2551 ((("%") reduce 21) (("(") reduce 21) ((")") reduce 21) (("*") reduce 21) (("+") reduce 21) ((",") reduce 21) (("-") reduce 21) ((".") reduce 21) (("/") reduce 21) (("<") reduce 21) ((">") reduce 21) (("?") reduce 21) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_BOOLEAN_AND) reduce 21) ((T_BOOLEAN_OR) reduce 21) ((T_COALESCE) reduce 21) ((T_INSTANCEOF) reduce 21) ((T_IS_EQUAL) reduce 21) ((T_IS_GREATER_OR_EQUAL) reduce 21) ((T_IS_IDENTICAL) reduce 21) ((T_IS_NOT_EQUAL) reduce 21) ((T_IS_NOT_IDENTICAL) reduce 21) ((T_IS_SMALLER_OR_EQUAL) reduce 21) ((T_LOGICAL_AND) reduce 21) ((T_LOGICAL_OR) reduce 21) ((T_LOGICAL_XOR) reduce 21) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 21) ((T_OBJECT_OPERATOR) reduce 21) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 21) ((T_POW) reduce 21) ((T_SL) reduce 21) ((T_SPACESHIP) reduce 21) ((T_SR) reduce 21) (("[") reduce 21) (("^") reduce 21) (("{") reduce 21) (("|") reduce 21)) 2552 ((("%") reduce 23) (("(") reduce 23) ((")") reduce 23) (("*") reduce 23) (("+") reduce 23) ((",") reduce 23) (("-") reduce 23) ((".") reduce 23) (("/") reduce 23) (("<") reduce 23) ((">") reduce 23) (("?") reduce 23) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_BOOLEAN_AND) reduce 23) ((T_BOOLEAN_OR) reduce 23) ((T_COALESCE) reduce 23) ((T_INSTANCEOF) reduce 23) ((T_IS_EQUAL) reduce 23) ((T_IS_GREATER_OR_EQUAL) reduce 23) ((T_IS_IDENTICAL) reduce 23) ((T_IS_NOT_EQUAL) reduce 23) ((T_IS_NOT_IDENTICAL) reduce 23) ((T_IS_SMALLER_OR_EQUAL) reduce 23) ((T_LOGICAL_AND) reduce 23) ((T_LOGICAL_OR) reduce 23) ((T_LOGICAL_XOR) reduce 23) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 23) ((T_OBJECT_OPERATOR) reduce 23) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 23) ((T_POW) reduce 23) ((T_SL) reduce 23) ((T_SPACESHIP) reduce 23) ((T_SR) reduce 23) (("[") reduce 23) (("^") reduce 23) (("{") reduce 23) (("|") reduce 23)) 2553 ((("%") reduce 41) (("(") reduce 41) ((")") reduce 41) (("*") reduce 41) (("+") reduce 41) ((",") reduce 41) (("-") reduce 41) ((".") reduce 41) (("/") reduce 41) (("<") reduce 41) ((">") reduce 41) (("?") reduce 41) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_BOOLEAN_AND) reduce 41) ((T_BOOLEAN_OR) reduce 41) ((T_COALESCE) reduce 41) ((T_INSTANCEOF) reduce 41) ((T_IS_EQUAL) reduce 41) ((T_IS_GREATER_OR_EQUAL) reduce 41) ((T_IS_IDENTICAL) reduce 41) ((T_IS_NOT_EQUAL) reduce 41) ((T_IS_NOT_IDENTICAL) reduce 41) ((T_IS_SMALLER_OR_EQUAL) reduce 41) ((T_LOGICAL_AND) reduce 41) ((T_LOGICAL_OR) reduce 41) ((T_LOGICAL_XOR) reduce 41) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 41) ((T_OBJECT_OPERATOR) reduce 41) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 41) ((T_POW) reduce 41) ((T_SL) reduce 41) ((T_SPACESHIP) reduce 41) ((T_SR) reduce 41) (("[") reduce 41) (("^") reduce 41) (("{") reduce 41) (("|") reduce 41)) 2554 ((("%") reduce 62) (("(") reduce 62) ((")") reduce 62) (("*") reduce 62) (("+") reduce 62) ((",") reduce 62) (("-") reduce 62) ((".") reduce 62) (("/") reduce 62) (("<") reduce 62) ((">") reduce 62) (("?") reduce 62) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_BOOLEAN_AND) reduce 62) ((T_BOOLEAN_OR) reduce 62) ((T_COALESCE) reduce 62) ((T_INSTANCEOF) reduce 62) ((T_IS_EQUAL) reduce 62) ((T_IS_GREATER_OR_EQUAL) reduce 62) ((T_IS_IDENTICAL) reduce 62) ((T_IS_NOT_EQUAL) reduce 62) ((T_IS_NOT_IDENTICAL) reduce 62) ((T_IS_SMALLER_OR_EQUAL) reduce 62) ((T_LOGICAL_AND) reduce 62) ((T_LOGICAL_OR) reduce 62) ((T_LOGICAL_XOR) reduce 62) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 62) ((T_OBJECT_OPERATOR) reduce 62) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 62) ((T_POW) reduce 62) ((T_SL) reduce 62) ((T_SPACESHIP) reduce 62) ((T_SR) reduce 62) (("[") reduce 62) (("^") reduce 62) (("{") reduce 62) (("|") reduce 62)) 2555 ((("%") reduce 34) (("(") reduce 34) ((")") reduce 34) (("*") reduce 34) (("+") reduce 34) ((",") reduce 34) (("-") reduce 34) ((".") reduce 34) (("/") reduce 34) (("<") reduce 34) ((">") reduce 34) (("?") reduce 34) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_BOOLEAN_AND) reduce 34) ((T_BOOLEAN_OR) reduce 34) ((T_COALESCE) reduce 34) ((T_INSTANCEOF) reduce 34) ((T_IS_EQUAL) reduce 34) ((T_IS_GREATER_OR_EQUAL) reduce 34) ((T_IS_IDENTICAL) reduce 34) ((T_IS_NOT_EQUAL) reduce 34) ((T_IS_NOT_IDENTICAL) reduce 34) ((T_IS_SMALLER_OR_EQUAL) reduce 34) ((T_LOGICAL_AND) reduce 34) ((T_LOGICAL_OR) reduce 34) ((T_LOGICAL_XOR) reduce 34) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 34) ((T_OBJECT_OPERATOR) reduce 34) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 34) ((T_POW) reduce 34) ((T_SL) reduce 34) ((T_SPACESHIP) reduce 34) ((T_SR) reduce 34) (("[") reduce 34) (("^") reduce 34) (("{") reduce 34) (("|") reduce 34)) 2556 ((("%") reduce 40) (("(") reduce 40) ((")") reduce 40) (("*") reduce 40) (("+") reduce 40) ((",") reduce 40) (("-") reduce 40) ((".") reduce 40) (("/") reduce 40) (("<") reduce 40) ((">") reduce 40) (("?") reduce 40) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_BOOLEAN_AND) reduce 40) ((T_BOOLEAN_OR) reduce 40) ((T_COALESCE) reduce 40) ((T_INSTANCEOF) reduce 40) ((T_IS_EQUAL) reduce 40) ((T_IS_GREATER_OR_EQUAL) reduce 40) ((T_IS_IDENTICAL) reduce 40) ((T_IS_NOT_EQUAL) reduce 40) ((T_IS_NOT_IDENTICAL) reduce 40) ((T_IS_SMALLER_OR_EQUAL) reduce 40) ((T_LOGICAL_AND) reduce 40) ((T_LOGICAL_OR) reduce 40) ((T_LOGICAL_XOR) reduce 40) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 40) ((T_OBJECT_OPERATOR) reduce 40) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 40) ((T_POW) reduce 40) ((T_SL) reduce 40) ((T_SPACESHIP) reduce 40) ((T_SR) reduce 40) (("[") reduce 40) (("^") reduce 40) (("{") reduce 40) (("|") reduce 40)) 2557 ((("%") reduce 13) (("(") reduce 13) ((")") reduce 13) (("*") reduce 13) (("+") reduce 13) ((",") reduce 13) (("-") reduce 13) ((".") reduce 13) (("/") reduce 13) (("<") reduce 13) ((">") reduce 13) (("?") reduce 13) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_BOOLEAN_AND) reduce 13) ((T_BOOLEAN_OR) reduce 13) ((T_COALESCE) reduce 13) ((T_INSTANCEOF) reduce 13) ((T_IS_EQUAL) reduce 13) ((T_IS_GREATER_OR_EQUAL) reduce 13) ((T_IS_IDENTICAL) reduce 13) ((T_IS_NOT_EQUAL) reduce 13) ((T_IS_NOT_IDENTICAL) reduce 13) ((T_IS_SMALLER_OR_EQUAL) reduce 13) ((T_LOGICAL_AND) reduce 13) ((T_LOGICAL_OR) reduce 13) ((T_LOGICAL_XOR) reduce 13) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 13) ((T_OBJECT_OPERATOR) reduce 13) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 13) ((T_POW) reduce 13) ((T_SL) reduce 13) ((T_SPACESHIP) reduce 13) ((T_SR) reduce 13) (("[") reduce 13) (("^") reduce 13) (("{") reduce 13) (("|") reduce 13)) 2558 ((("%") reduce 55) (("(") reduce 55) ((")") reduce 55) (("*") reduce 55) (("+") reduce 55) ((",") reduce 55) (("-") reduce 55) ((".") reduce 55) (("/") reduce 55) (("<") reduce 55) ((">") reduce 55) (("?") reduce 55) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_BOOLEAN_AND) reduce 55) ((T_BOOLEAN_OR) reduce 55) ((T_COALESCE) reduce 55) ((T_INSTANCEOF) reduce 55) ((T_IS_EQUAL) reduce 55) ((T_IS_GREATER_OR_EQUAL) reduce 55) ((T_IS_IDENTICAL) reduce 55) ((T_IS_NOT_EQUAL) reduce 55) ((T_IS_NOT_IDENTICAL) reduce 55) ((T_IS_SMALLER_OR_EQUAL) reduce 55) ((T_LOGICAL_AND) reduce 55) ((T_LOGICAL_OR) reduce 55) ((T_LOGICAL_XOR) reduce 55) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 55) ((T_OBJECT_OPERATOR) reduce 55) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 55) ((T_POW) reduce 55) ((T_SL) reduce 55) ((T_SPACESHIP) reduce 55) ((T_SR) reduce 55) (("[") reduce 55) (("^") reduce 55) (("{") reduce 55) (("|") reduce 55)) 2559 ((("%") reduce 1) (("(") reduce 1) ((")") reduce 1) (("*") reduce 1) (("+") reduce 1) ((",") reduce 1) (("-") reduce 1) ((".") reduce 1) (("/") reduce 1) (("<") reduce 1) ((">") reduce 1) (("?") reduce 1) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_BOOLEAN_AND) reduce 1) ((T_BOOLEAN_OR) reduce 1) ((T_COALESCE) reduce 1) ((T_INSTANCEOF) reduce 1) ((T_IS_EQUAL) reduce 1) ((T_IS_GREATER_OR_EQUAL) reduce 1) ((T_IS_IDENTICAL) reduce 1) ((T_IS_NOT_EQUAL) reduce 1) ((T_IS_NOT_IDENTICAL) reduce 1) ((T_IS_SMALLER_OR_EQUAL) reduce 1) ((T_LOGICAL_AND) reduce 1) ((T_LOGICAL_OR) reduce 1) ((T_LOGICAL_XOR) reduce 1) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 1) ((T_OBJECT_OPERATOR) reduce 1) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 1) ((T_POW) reduce 1) ((T_SL) reduce 1) ((T_SPACESHIP) reduce 1) ((T_SR) reduce 1) (("[") reduce 1) (("^") reduce 1) (("{") reduce 1) (("|") reduce 1)) 2560 ((("%") reduce 2) (("(") reduce 2) ((")") reduce 2) (("*") reduce 2) (("+") reduce 2) ((",") reduce 2) (("-") reduce 2) ((".") reduce 2) (("/") reduce 2) (("<") reduce 2) ((">") reduce 2) (("?") reduce 2) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_BOOLEAN_AND) reduce 2) ((T_BOOLEAN_OR) reduce 2) ((T_COALESCE) reduce 2) ((T_INSTANCEOF) reduce 2) ((T_IS_EQUAL) reduce 2) ((T_IS_GREATER_OR_EQUAL) reduce 2) ((T_IS_IDENTICAL) reduce 2) ((T_IS_NOT_EQUAL) reduce 2) ((T_IS_NOT_IDENTICAL) reduce 2) ((T_IS_SMALLER_OR_EQUAL) reduce 2) ((T_LOGICAL_AND) reduce 2) ((T_LOGICAL_OR) reduce 2) ((T_LOGICAL_XOR) reduce 2) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 2) ((T_OBJECT_OPERATOR) reduce 2) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 2) ((T_POW) reduce 2) ((T_SL) reduce 2) ((T_SPACESHIP) reduce 2) ((T_SR) reduce 2) (("[") reduce 2) (("^") reduce 2) (("{") reduce 2) (("|") reduce 2)) 2561 ((("%") reduce 9) (("(") reduce 9) ((")") reduce 9) (("*") reduce 9) (("+") reduce 9) ((",") reduce 9) (("-") reduce 9) ((".") reduce 9) (("/") reduce 9) (("<") reduce 9) ((">") reduce 9) (("?") reduce 9) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_BOOLEAN_AND) reduce 9) ((T_BOOLEAN_OR) reduce 9) ((T_COALESCE) reduce 9) ((T_INSTANCEOF) reduce 9) ((T_IS_EQUAL) reduce 9) ((T_IS_GREATER_OR_EQUAL) reduce 9) ((T_IS_IDENTICAL) reduce 9) ((T_IS_NOT_EQUAL) reduce 9) ((T_IS_NOT_IDENTICAL) reduce 9) ((T_IS_SMALLER_OR_EQUAL) reduce 9) ((T_LOGICAL_AND) reduce 9) ((T_LOGICAL_OR) reduce 9) ((T_LOGICAL_XOR) reduce 9) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 9) ((T_OBJECT_OPERATOR) reduce 9) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 9) ((T_POW) reduce 9) ((T_SL) reduce 9) ((T_SPACESHIP) reduce 9) ((T_SR) reduce 9) (("[") reduce 9) (("^") reduce 9) (("{") reduce 9) (("|") reduce 9)) 2562 ((("%") reduce 33) (("(") reduce 33) ((")") reduce 33) (("*") reduce 33) (("+") reduce 33) ((",") reduce 33) (("-") reduce 33) ((".") reduce 33) (("/") reduce 33) (("<") reduce 33) ((">") reduce 33) (("?") reduce 33) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_BOOLEAN_AND) reduce 33) ((T_BOOLEAN_OR) reduce 33) ((T_COALESCE) reduce 33) ((T_INSTANCEOF) reduce 33) ((T_IS_EQUAL) reduce 33) ((T_IS_GREATER_OR_EQUAL) reduce 33) ((T_IS_IDENTICAL) reduce 33) ((T_IS_NOT_EQUAL) reduce 33) ((T_IS_NOT_IDENTICAL) reduce 33) ((T_IS_SMALLER_OR_EQUAL) reduce 33) ((T_LOGICAL_AND) reduce 33) ((T_LOGICAL_OR) reduce 33) ((T_LOGICAL_XOR) reduce 33) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 33) ((T_OBJECT_OPERATOR) reduce 33) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 33) ((T_POW) reduce 33) ((T_SL) reduce 33) ((T_SPACESHIP) reduce 33) ((T_SR) reduce 33) (("[") reduce 33) (("^") reduce 33) (("{") reduce 33) (("|") reduce 33)) 2563 ((("%") reduce 58) (("(") reduce 58) ((")") reduce 58) (("*") reduce 58) (("+") reduce 58) ((",") reduce 58) (("-") reduce 58) ((".") reduce 58) (("/") reduce 58) (("<") reduce 58) ((">") reduce 58) (("?") reduce 58) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_BOOLEAN_AND) reduce 58) ((T_BOOLEAN_OR) reduce 58) ((T_COALESCE) reduce 58) ((T_INSTANCEOF) reduce 58) ((T_IS_EQUAL) reduce 58) ((T_IS_GREATER_OR_EQUAL) reduce 58) ((T_IS_IDENTICAL) reduce 58) ((T_IS_NOT_EQUAL) reduce 58) ((T_IS_NOT_IDENTICAL) reduce 58) ((T_IS_SMALLER_OR_EQUAL) reduce 58) ((T_LOGICAL_AND) reduce 58) ((T_LOGICAL_OR) reduce 58) ((T_LOGICAL_XOR) reduce 58) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 58) ((T_OBJECT_OPERATOR) reduce 58) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 58) ((T_POW) reduce 58) ((T_SL) reduce 58) ((T_SPACESHIP) reduce 58) ((T_SR) reduce 58) (("[") reduce 58) (("^") reduce 58) (("{") reduce 58) (("|") reduce 58)) 2564 ((("%") reduce 37) (("(") reduce 37) ((")") reduce 37) (("*") reduce 37) (("+") reduce 37) ((",") reduce 37) (("-") reduce 37) ((".") reduce 37) (("/") reduce 37) (("<") reduce 37) ((">") reduce 37) (("?") reduce 37) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_BOOLEAN_AND) reduce 37) ((T_BOOLEAN_OR) reduce 37) ((T_COALESCE) reduce 37) ((T_INSTANCEOF) reduce 37) ((T_IS_EQUAL) reduce 37) ((T_IS_GREATER_OR_EQUAL) reduce 37) ((T_IS_IDENTICAL) reduce 37) ((T_IS_NOT_EQUAL) reduce 37) ((T_IS_NOT_IDENTICAL) reduce 37) ((T_IS_SMALLER_OR_EQUAL) reduce 37) ((T_LOGICAL_AND) reduce 37) ((T_LOGICAL_OR) reduce 37) ((T_LOGICAL_XOR) reduce 37) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 37) ((T_OBJECT_OPERATOR) reduce 37) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 37) ((T_POW) reduce 37) ((T_SL) reduce 37) ((T_SPACESHIP) reduce 37) ((T_SR) reduce 37) (("[") reduce 37) (("^") reduce 37) (("{") reduce 37) (("|") reduce 37)) 2565 ((("%") reduce 64) (("(") reduce 64) ((")") reduce 64) (("*") reduce 64) (("+") reduce 64) ((",") reduce 64) (("-") reduce 64) ((".") reduce 64) (("/") reduce 64) (("<") reduce 64) ((">") reduce 64) (("?") reduce 64) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_BOOLEAN_AND) reduce 64) ((T_BOOLEAN_OR) reduce 64) ((T_COALESCE) reduce 64) ((T_INSTANCEOF) reduce 64) ((T_IS_EQUAL) reduce 64) ((T_IS_GREATER_OR_EQUAL) reduce 64) ((T_IS_IDENTICAL) reduce 64) ((T_IS_NOT_EQUAL) reduce 64) ((T_IS_NOT_IDENTICAL) reduce 64) ((T_IS_SMALLER_OR_EQUAL) reduce 64) ((T_LOGICAL_AND) reduce 64) ((T_LOGICAL_OR) reduce 64) ((T_LOGICAL_XOR) reduce 64) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 64) ((T_OBJECT_OPERATOR) reduce 64) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 64) ((T_POW) reduce 64) ((T_SL) reduce 64) ((T_SPACESHIP) reduce 64) ((T_SR) reduce 64) (("[") reduce 64) (("^") reduce 64) (("{") reduce 64) (("|") reduce 64)) 2566 ((("%") reduce 46) (("(") reduce 46) ((")") reduce 46) (("*") reduce 46) (("+") reduce 46) ((",") reduce 46) (("-") reduce 46) ((".") reduce 46) (("/") reduce 46) (("<") reduce 46) ((">") reduce 46) (("?") reduce 46) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_BOOLEAN_AND) reduce 46) ((T_BOOLEAN_OR) reduce 46) ((T_COALESCE) reduce 46) ((T_INSTANCEOF) reduce 46) ((T_IS_EQUAL) reduce 46) ((T_IS_GREATER_OR_EQUAL) reduce 46) ((T_IS_IDENTICAL) reduce 46) ((T_IS_NOT_EQUAL) reduce 46) ((T_IS_NOT_IDENTICAL) reduce 46) ((T_IS_SMALLER_OR_EQUAL) reduce 46) ((T_LOGICAL_AND) reduce 46) ((T_LOGICAL_OR) reduce 46) ((T_LOGICAL_XOR) reduce 46) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 46) ((T_OBJECT_OPERATOR) reduce 46) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 46) ((T_POW) reduce 46) ((T_SL) reduce 46) ((T_SPACESHIP) reduce 46) ((T_SR) reduce 46) (("[") reduce 46) (("^") reduce 46) (("{") reduce 46) (("|") reduce 46)) 2567 ((("%") reduce 8) (("(") reduce 8) ((")") reduce 8) (("*") reduce 8) (("+") reduce 8) ((",") reduce 8) (("-") reduce 8) ((".") reduce 8) (("/") reduce 8) (("<") reduce 8) ((">") reduce 8) (("?") reduce 8) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_BOOLEAN_AND) reduce 8) ((T_BOOLEAN_OR) reduce 8) ((T_COALESCE) reduce 8) ((T_INSTANCEOF) reduce 8) ((T_IS_EQUAL) reduce 8) ((T_IS_GREATER_OR_EQUAL) reduce 8) ((T_IS_IDENTICAL) reduce 8) ((T_IS_NOT_EQUAL) reduce 8) ((T_IS_NOT_IDENTICAL) reduce 8) ((T_IS_SMALLER_OR_EQUAL) reduce 8) ((T_LOGICAL_AND) reduce 8) ((T_LOGICAL_OR) reduce 8) ((T_LOGICAL_XOR) reduce 8) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 8) ((T_OBJECT_OPERATOR) reduce 8) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 8) ((T_POW) reduce 8) ((T_SL) reduce 8) ((T_SPACESHIP) reduce 8) ((T_SR) reduce 8) (("[") reduce 8) (("^") reduce 8) (("{") reduce 8) (("|") reduce 8)) 2568 ((("%") reduce 6) (("(") reduce 6) ((")") reduce 6) (("*") reduce 6) (("+") reduce 6) ((",") reduce 6) (("-") reduce 6) ((".") reduce 6) (("/") reduce 6) (("<") reduce 6) ((">") reduce 6) (("?") reduce 6) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_BOOLEAN_AND) reduce 6) ((T_BOOLEAN_OR) reduce 6) ((T_COALESCE) reduce 6) ((T_INSTANCEOF) reduce 6) ((T_IS_EQUAL) reduce 6) ((T_IS_GREATER_OR_EQUAL) reduce 6) ((T_IS_IDENTICAL) reduce 6) ((T_IS_NOT_EQUAL) reduce 6) ((T_IS_NOT_IDENTICAL) reduce 6) ((T_IS_SMALLER_OR_EQUAL) reduce 6) ((T_LOGICAL_AND) reduce 6) ((T_LOGICAL_OR) reduce 6) ((T_LOGICAL_XOR) reduce 6) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 6) ((T_OBJECT_OPERATOR) reduce 6) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 6) ((T_POW) reduce 6) ((T_SL) reduce 6) ((T_SPACESHIP) reduce 6) ((T_SR) reduce 6) (("[") reduce 6) (("^") reduce 6) (("{") reduce 6) (("|") reduce 6)) 2569 ((("%") reduce 7) (("(") reduce 7) ((")") reduce 7) (("*") reduce 7) (("+") reduce 7) ((",") reduce 7) (("-") reduce 7) ((".") reduce 7) (("/") reduce 7) (("<") reduce 7) ((">") reduce 7) (("?") reduce 7) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_BOOLEAN_AND) reduce 7) ((T_BOOLEAN_OR) reduce 7) ((T_COALESCE) reduce 7) ((T_INSTANCEOF) reduce 7) ((T_IS_EQUAL) reduce 7) ((T_IS_GREATER_OR_EQUAL) reduce 7) ((T_IS_IDENTICAL) reduce 7) ((T_IS_NOT_EQUAL) reduce 7) ((T_IS_NOT_IDENTICAL) reduce 7) ((T_IS_SMALLER_OR_EQUAL) reduce 7) ((T_LOGICAL_AND) reduce 7) ((T_LOGICAL_OR) reduce 7) ((T_LOGICAL_XOR) reduce 7) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 7) ((T_OBJECT_OPERATOR) reduce 7) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 7) ((T_POW) reduce 7) ((T_SL) reduce 7) ((T_SPACESHIP) reduce 7) ((T_SR) reduce 7) (("[") reduce 7) (("^") reduce 7) (("{") reduce 7) (("|") reduce 7)) 2570 ((("%") reduce 69) (("(") reduce 69) ((")") reduce 69) (("*") reduce 69) (("+") reduce 69) ((",") reduce 69) (("-") reduce 69) ((".") reduce 69) (("/") reduce 69) (("<") reduce 69) ((">") reduce 69) (("?") reduce 69) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_BOOLEAN_AND) reduce 69) ((T_BOOLEAN_OR) reduce 69) ((T_COALESCE) reduce 69) ((T_INSTANCEOF) reduce 69) ((T_IS_EQUAL) reduce 69) ((T_IS_GREATER_OR_EQUAL) reduce 69) ((T_IS_IDENTICAL) reduce 69) ((T_IS_NOT_EQUAL) reduce 69) ((T_IS_NOT_IDENTICAL) reduce 69) ((T_IS_SMALLER_OR_EQUAL) reduce 69) ((T_LOGICAL_AND) reduce 69) ((T_LOGICAL_OR) reduce 69) ((T_LOGICAL_XOR) reduce 69) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 69) ((T_OBJECT_OPERATOR) reduce 69) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 69) ((T_POW) reduce 69) ((T_SL) reduce 69) ((T_SPACESHIP) reduce 69) ((T_SR) reduce 69) (("[") reduce 69) (("^") reduce 69) (("{") reduce 69) (("|") reduce 69)) 2571 ((("%") reduce 63) (("(") reduce 63) ((")") reduce 63) (("*") reduce 63) (("+") reduce 63) ((",") reduce 63) (("-") reduce 63) ((".") reduce 63) (("/") reduce 63) (("<") reduce 63) ((">") reduce 63) (("?") reduce 63) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_BOOLEAN_AND) reduce 63) ((T_BOOLEAN_OR) reduce 63) ((T_COALESCE) reduce 63) ((T_INSTANCEOF) reduce 63) ((T_IS_EQUAL) reduce 63) ((T_IS_GREATER_OR_EQUAL) reduce 63) ((T_IS_IDENTICAL) reduce 63) ((T_IS_NOT_EQUAL) reduce 63) ((T_IS_NOT_IDENTICAL) reduce 63) ((T_IS_SMALLER_OR_EQUAL) reduce 63) ((T_LOGICAL_AND) reduce 63) ((T_LOGICAL_OR) reduce 63) ((T_LOGICAL_XOR) reduce 63) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 63) ((T_OBJECT_OPERATOR) reduce 63) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 63) ((T_POW) reduce 63) ((T_SL) reduce 63) ((T_SPACESHIP) reduce 63) ((T_SR) reduce 63) (("[") reduce 63) (("^") reduce 63) (("{") reduce 63) (("|") reduce 63)) 2572 ((("%") reduce 56) (("(") reduce 56) ((")") reduce 56) (("*") reduce 56) (("+") reduce 56) ((",") reduce 56) (("-") reduce 56) ((".") reduce 56) (("/") reduce 56) (("<") reduce 56) ((">") reduce 56) (("?") reduce 56) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_BOOLEAN_AND) reduce 56) ((T_BOOLEAN_OR) reduce 56) ((T_COALESCE) reduce 56) ((T_INSTANCEOF) reduce 56) ((T_IS_EQUAL) reduce 56) ((T_IS_GREATER_OR_EQUAL) reduce 56) ((T_IS_IDENTICAL) reduce 56) ((T_IS_NOT_EQUAL) reduce 56) ((T_IS_NOT_IDENTICAL) reduce 56) ((T_IS_SMALLER_OR_EQUAL) reduce 56) ((T_LOGICAL_AND) reduce 56) ((T_LOGICAL_OR) reduce 56) ((T_LOGICAL_XOR) reduce 56) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 56) ((T_OBJECT_OPERATOR) reduce 56) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 56) ((T_POW) reduce 56) ((T_SL) reduce 56) ((T_SPACESHIP) reduce 56) ((T_SR) reduce 56) (("[") reduce 56) (("^") reduce 56) (("{") reduce 56) (("|") reduce 56)) 2573 ((("%") reduce 10) (("(") reduce 10) ((")") reduce 10) (("*") reduce 10) (("+") reduce 10) ((",") reduce 10) (("-") reduce 10) ((".") reduce 10) (("/") reduce 10) (("<") reduce 10) ((">") reduce 10) (("?") reduce 10) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_BOOLEAN_AND) reduce 10) ((T_BOOLEAN_OR) reduce 10) ((T_COALESCE) reduce 10) ((T_INSTANCEOF) reduce 10) ((T_IS_EQUAL) reduce 10) ((T_IS_GREATER_OR_EQUAL) reduce 10) ((T_IS_IDENTICAL) reduce 10) ((T_IS_NOT_EQUAL) reduce 10) ((T_IS_NOT_IDENTICAL) reduce 10) ((T_IS_SMALLER_OR_EQUAL) reduce 10) ((T_LOGICAL_AND) reduce 10) ((T_LOGICAL_OR) reduce 10) ((T_LOGICAL_XOR) reduce 10) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 10) ((T_OBJECT_OPERATOR) reduce 10) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 10) ((T_POW) reduce 10) ((T_SL) reduce 10) ((T_SPACESHIP) reduce 10) ((T_SR) reduce 10) (("[") reduce 10) (("^") reduce 10) (("{") reduce 10) (("|") reduce 10)) 2574 ((("%") reduce 67) (("(") reduce 67) ((")") reduce 67) (("*") reduce 67) (("+") reduce 67) ((",") reduce 67) (("-") reduce 67) ((".") reduce 67) (("/") reduce 67) (("<") reduce 67) ((">") reduce 67) (("?") reduce 67) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_BOOLEAN_AND) reduce 67) ((T_BOOLEAN_OR) reduce 67) ((T_COALESCE) reduce 67) ((T_INSTANCEOF) reduce 67) ((T_IS_EQUAL) reduce 67) ((T_IS_GREATER_OR_EQUAL) reduce 67) ((T_IS_IDENTICAL) reduce 67) ((T_IS_NOT_EQUAL) reduce 67) ((T_IS_NOT_IDENTICAL) reduce 67) ((T_IS_SMALLER_OR_EQUAL) reduce 67) ((T_LOGICAL_AND) reduce 67) ((T_LOGICAL_OR) reduce 67) ((T_LOGICAL_XOR) reduce 67) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 67) ((T_OBJECT_OPERATOR) reduce 67) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 67) ((T_POW) reduce 67) ((T_SL) reduce 67) ((T_SPACESHIP) reduce 67) ((T_SR) reduce 67) (("[") reduce 67) (("^") reduce 67) (("{") reduce 67) (("|") reduce 67)) 2575 ((("%") reduce 44) (("(") reduce 44) ((")") reduce 44) (("*") reduce 44) (("+") reduce 44) ((",") reduce 44) (("-") reduce 44) ((".") reduce 44) (("/") reduce 44) (("<") reduce 44) ((">") reduce 44) (("?") reduce 44) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_BOOLEAN_AND) reduce 44) ((T_BOOLEAN_OR) reduce 44) ((T_COALESCE) reduce 44) ((T_INSTANCEOF) reduce 44) ((T_IS_EQUAL) reduce 44) ((T_IS_GREATER_OR_EQUAL) reduce 44) ((T_IS_IDENTICAL) reduce 44) ((T_IS_NOT_EQUAL) reduce 44) ((T_IS_NOT_IDENTICAL) reduce 44) ((T_IS_SMALLER_OR_EQUAL) reduce 44) ((T_LOGICAL_AND) reduce 44) ((T_LOGICAL_OR) reduce 44) ((T_LOGICAL_XOR) reduce 44) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 44) ((T_OBJECT_OPERATOR) reduce 44) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 44) ((T_POW) reduce 44) ((T_SL) reduce 44) ((T_SPACESHIP) reduce 44) ((T_SR) reduce 44) (("[") reduce 44) (("^") reduce 44) (("{") reduce 44) (("|") reduce 44)) 2576 ((("%") reduce 75) (("(") reduce 75) ((")") reduce 75) (("*") reduce 75) (("+") reduce 75) ((",") reduce 75) (("-") reduce 75) ((".") reduce 75) (("/") reduce 75) (("<") reduce 75) ((">") reduce 75) (("?") reduce 75) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_BOOLEAN_AND) reduce 75) ((T_BOOLEAN_OR) reduce 75) ((T_COALESCE) reduce 75) ((T_INSTANCEOF) reduce 75) ((T_IS_EQUAL) reduce 75) ((T_IS_GREATER_OR_EQUAL) reduce 75) ((T_IS_IDENTICAL) reduce 75) ((T_IS_NOT_EQUAL) reduce 75) ((T_IS_NOT_IDENTICAL) reduce 75) ((T_IS_SMALLER_OR_EQUAL) reduce 75) ((T_LOGICAL_AND) reduce 75) ((T_LOGICAL_OR) reduce 75) ((T_LOGICAL_XOR) reduce 75) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 75) ((T_OBJECT_OPERATOR) reduce 75) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 75) ((T_POW) reduce 75) ((T_SL) reduce 75) ((T_SPACESHIP) reduce 75) ((T_SR) reduce 75) (("[") reduce 75) (("^") reduce 75) (("{") reduce 75) (("|") reduce 75)) 2577 ((("%") reduce 76) (("(") reduce 76) ((")") reduce 76) (("*") reduce 76) (("+") reduce 76) ((",") reduce 76) (("-") reduce 76) ((".") reduce 76) (("/") reduce 76) (("<") reduce 76) ((">") reduce 76) (("?") reduce 76) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_BOOLEAN_AND) reduce 76) ((T_BOOLEAN_OR) reduce 76) ((T_COALESCE) reduce 76) ((T_INSTANCEOF) reduce 76) ((T_IS_EQUAL) reduce 76) ((T_IS_GREATER_OR_EQUAL) reduce 76) ((T_IS_IDENTICAL) reduce 76) ((T_IS_NOT_EQUAL) reduce 76) ((T_IS_NOT_IDENTICAL) reduce 76) ((T_IS_SMALLER_OR_EQUAL) reduce 76) ((T_LOGICAL_AND) reduce 76) ((T_LOGICAL_OR) reduce 76) ((T_LOGICAL_XOR) reduce 76) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 76) ((T_OBJECT_OPERATOR) reduce 76) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 76) ((T_POW) reduce 76) ((T_SL) reduce 76) ((T_SPACESHIP) reduce 76) ((T_SR) reduce 76) (("[") reduce 76) (("^") reduce 76) (("{") reduce 76) (("|") reduce 76)) 2578 ((("%") reduce 77) (("(") reduce 77) ((")") reduce 77) (("*") reduce 77) (("+") reduce 77) ((",") reduce 77) (("-") reduce 77) ((".") reduce 77) (("/") reduce 77) (("<") reduce 77) ((">") reduce 77) (("?") reduce 77) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_BOOLEAN_AND) reduce 77) ((T_BOOLEAN_OR) reduce 77) ((T_COALESCE) reduce 77) ((T_INSTANCEOF) reduce 77) ((T_IS_EQUAL) reduce 77) ((T_IS_GREATER_OR_EQUAL) reduce 77) ((T_IS_IDENTICAL) reduce 77) ((T_IS_NOT_EQUAL) reduce 77) ((T_IS_NOT_IDENTICAL) reduce 77) ((T_IS_SMALLER_OR_EQUAL) reduce 77) ((T_LOGICAL_AND) reduce 77) ((T_LOGICAL_OR) reduce 77) ((T_LOGICAL_XOR) reduce 77) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 77) ((T_OBJECT_OPERATOR) reduce 77) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 77) ((T_POW) reduce 77) ((T_SL) reduce 77) ((T_SPACESHIP) reduce 77) ((T_SR) reduce 77) (("[") reduce 77) (("^") reduce 77) (("{") reduce 77) (("|") reduce 77)) 2579 ((("%") reduce 78) (("(") reduce 78) ((")") reduce 78) (("*") reduce 78) (("+") reduce 78) ((",") reduce 78) (("-") reduce 78) ((".") reduce 78) (("/") reduce 78) (("<") reduce 78) ((">") reduce 78) (("?") reduce 78) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_BOOLEAN_AND) reduce 78) ((T_BOOLEAN_OR) reduce 78) ((T_COALESCE) reduce 78) ((T_INSTANCEOF) reduce 78) ((T_IS_EQUAL) reduce 78) ((T_IS_GREATER_OR_EQUAL) reduce 78) ((T_IS_IDENTICAL) reduce 78) ((T_IS_NOT_EQUAL) reduce 78) ((T_IS_NOT_IDENTICAL) reduce 78) ((T_IS_SMALLER_OR_EQUAL) reduce 78) ((T_LOGICAL_AND) reduce 78) ((T_LOGICAL_OR) reduce 78) ((T_LOGICAL_XOR) reduce 78) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 78) ((T_OBJECT_OPERATOR) reduce 78) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 78) ((T_POW) reduce 78) ((T_SL) reduce 78) ((T_SPACESHIP) reduce 78) ((T_SR) reduce 78) (("[") reduce 78) (("^") reduce 78) (("{") reduce 78) (("|") reduce 78)) 2580 ((("%") reduce 4) (("(") reduce 4) ((")") reduce 4) (("*") reduce 4) (("+") reduce 4) ((",") reduce 4) (("-") reduce 4) ((".") reduce 4) (("/") reduce 4) (("<") reduce 4) ((">") reduce 4) (("?") reduce 4) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_BOOLEAN_AND) reduce 4) ((T_BOOLEAN_OR) reduce 4) ((T_COALESCE) reduce 4) ((T_INSTANCEOF) reduce 4) ((T_IS_EQUAL) reduce 4) ((T_IS_GREATER_OR_EQUAL) reduce 4) ((T_IS_IDENTICAL) reduce 4) ((T_IS_NOT_EQUAL) reduce 4) ((T_IS_NOT_IDENTICAL) reduce 4) ((T_IS_SMALLER_OR_EQUAL) reduce 4) ((T_LOGICAL_AND) reduce 4) ((T_LOGICAL_OR) reduce 4) ((T_LOGICAL_XOR) reduce 4) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 4) ((T_OBJECT_OPERATOR) reduce 4) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 4) ((T_POW) reduce 4) ((T_SL) reduce 4) ((T_SPACESHIP) reduce 4) ((T_SR) reduce 4) (("[") reduce 4) (("^") reduce 4) (("{") reduce 4) (("|") reduce 4)) 2581 ((("%") reduce 5) (("(") reduce 5) ((")") reduce 5) (("*") reduce 5) (("+") reduce 5) ((",") reduce 5) (("-") reduce 5) ((".") reduce 5) (("/") reduce 5) (("<") reduce 5) ((">") reduce 5) (("?") reduce 5) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_BOOLEAN_AND) reduce 5) ((T_BOOLEAN_OR) reduce 5) ((T_COALESCE) reduce 5) ((T_INSTANCEOF) reduce 5) ((T_IS_EQUAL) reduce 5) ((T_IS_GREATER_OR_EQUAL) reduce 5) ((T_IS_IDENTICAL) reduce 5) ((T_IS_NOT_EQUAL) reduce 5) ((T_IS_NOT_IDENTICAL) reduce 5) ((T_IS_SMALLER_OR_EQUAL) reduce 5) ((T_LOGICAL_AND) reduce 5) ((T_LOGICAL_OR) reduce 5) ((T_LOGICAL_XOR) reduce 5) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 5) ((T_OBJECT_OPERATOR) reduce 5) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 5) ((T_POW) reduce 5) ((T_SL) reduce 5) ((T_SPACESHIP) reduce 5) ((T_SR) reduce 5) (("[") reduce 5) (("^") reduce 5) (("{") reduce 5) (("|") reduce 5)) 2582 ((("%") reduce 43) (("(") reduce 43) ((")") reduce 43) (("*") reduce 43) (("+") reduce 43) ((",") reduce 43) (("-") reduce 43) ((".") reduce 43) (("/") reduce 43) (("<") reduce 43) ((">") reduce 43) (("?") reduce 43) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_BOOLEAN_AND) reduce 43) ((T_BOOLEAN_OR) reduce 43) ((T_COALESCE) reduce 43) ((T_INSTANCEOF) reduce 43) ((T_IS_EQUAL) reduce 43) ((T_IS_GREATER_OR_EQUAL) reduce 43) ((T_IS_IDENTICAL) reduce 43) ((T_IS_NOT_EQUAL) reduce 43) ((T_IS_NOT_IDENTICAL) reduce 43) ((T_IS_SMALLER_OR_EQUAL) reduce 43) ((T_LOGICAL_AND) reduce 43) ((T_LOGICAL_OR) reduce 43) ((T_LOGICAL_XOR) reduce 43) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 43) ((T_OBJECT_OPERATOR) reduce 43) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 43) ((T_POW) reduce 43) ((T_SL) reduce 43) ((T_SPACESHIP) reduce 43) ((T_SR) reduce 43) (("[") reduce 43) (("^") reduce 43) (("{") reduce 43) (("|") reduce 43)) 2583 ((("%") reduce 72) (("(") reduce 72) ((")") reduce 72) (("*") reduce 72) (("+") reduce 72) ((",") reduce 72) (("-") reduce 72) ((".") reduce 72) (("/") reduce 72) (("<") reduce 72) ((">") reduce 72) (("?") reduce 72) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_BOOLEAN_AND) reduce 72) ((T_BOOLEAN_OR) reduce 72) ((T_COALESCE) reduce 72) ((T_INSTANCEOF) reduce 72) ((T_IS_EQUAL) reduce 72) ((T_IS_GREATER_OR_EQUAL) reduce 72) ((T_IS_IDENTICAL) reduce 72) ((T_IS_NOT_EQUAL) reduce 72) ((T_IS_NOT_IDENTICAL) reduce 72) ((T_IS_SMALLER_OR_EQUAL) reduce 72) ((T_LOGICAL_AND) reduce 72) ((T_LOGICAL_OR) reduce 72) ((T_LOGICAL_XOR) reduce 72) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 72) ((T_OBJECT_OPERATOR) reduce 72) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 72) ((T_POW) reduce 72) ((T_SL) reduce 72) ((T_SPACESHIP) reduce 72) ((T_SR) reduce 72) (("[") reduce 72) (("^") reduce 72) (("{") reduce 72) (("|") reduce 72)) 2584 ((("%") reduce 81) (("(") reduce 81) ((")") reduce 81) (("*") reduce 81) (("+") reduce 81) ((",") reduce 81) (("-") reduce 81) ((".") reduce 81) (("/") reduce 81) (("<") reduce 81) ((">") reduce 81) (("?") reduce 81) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_BOOLEAN_AND) reduce 81) ((T_BOOLEAN_OR) reduce 81) ((T_COALESCE) reduce 81) ((T_INSTANCEOF) reduce 81) ((T_IS_EQUAL) reduce 81) ((T_IS_GREATER_OR_EQUAL) reduce 81) ((T_IS_IDENTICAL) reduce 81) ((T_IS_NOT_EQUAL) reduce 81) ((T_IS_NOT_IDENTICAL) reduce 81) ((T_IS_SMALLER_OR_EQUAL) reduce 81) ((T_LOGICAL_AND) reduce 81) ((T_LOGICAL_OR) reduce 81) ((T_LOGICAL_XOR) reduce 81) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 81) ((T_OBJECT_OPERATOR) reduce 81) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 81) ((T_POW) reduce 81) ((T_SL) reduce 81) ((T_SPACESHIP) reduce 81) ((T_SR) reduce 81) (("[") reduce 81) (("^") reduce 81) (("{") reduce 81) (("|") reduce 81)) 2585 ((("%") reduce 47) (("(") reduce 47) ((")") reduce 47) (("*") reduce 47) (("+") reduce 47) ((",") reduce 47) (("-") reduce 47) ((".") reduce 47) (("/") reduce 47) (("<") reduce 47) ((">") reduce 47) (("?") reduce 47) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_BOOLEAN_AND) reduce 47) ((T_BOOLEAN_OR) reduce 47) ((T_COALESCE) reduce 47) ((T_INSTANCEOF) reduce 47) ((T_IS_EQUAL) reduce 47) ((T_IS_GREATER_OR_EQUAL) reduce 47) ((T_IS_IDENTICAL) reduce 47) ((T_IS_NOT_EQUAL) reduce 47) ((T_IS_NOT_IDENTICAL) reduce 47) ((T_IS_SMALLER_OR_EQUAL) reduce 47) ((T_LOGICAL_AND) reduce 47) ((T_LOGICAL_OR) reduce 47) ((T_LOGICAL_XOR) reduce 47) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 47) ((T_OBJECT_OPERATOR) reduce 47) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 47) ((T_POW) reduce 47) ((T_SL) reduce 47) ((T_SPACESHIP) reduce 47) ((T_SR) reduce 47) (("[") reduce 47) (("^") reduce 47) (("{") reduce 47) (("|") reduce 47)) 2586 ((("%") reduce 31) (("(") reduce 31) ((")") reduce 31) (("*") reduce 31) (("+") reduce 31) ((",") reduce 31) (("-") reduce 31) ((".") reduce 31) (("/") reduce 31) (("<") reduce 31) ((">") reduce 31) (("?") reduce 31) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_BOOLEAN_AND) reduce 31) ((T_BOOLEAN_OR) reduce 31) ((T_COALESCE) reduce 31) ((T_INSTANCEOF) reduce 31) ((T_IS_EQUAL) reduce 31) ((T_IS_GREATER_OR_EQUAL) reduce 31) ((T_IS_IDENTICAL) reduce 31) ((T_IS_NOT_EQUAL) reduce 31) ((T_IS_NOT_IDENTICAL) reduce 31) ((T_IS_SMALLER_OR_EQUAL) reduce 31) ((T_LOGICAL_AND) reduce 31) ((T_LOGICAL_OR) reduce 31) ((T_LOGICAL_XOR) reduce 31) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 31) ((T_OBJECT_OPERATOR) reduce 31) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 31) ((T_POW) reduce 31) ((T_SL) reduce 31) ((T_SPACESHIP) reduce 31) ((T_SR) reduce 31) (("[") reduce 31) (("^") reduce 31) (("{") reduce 31) (("|") reduce 31)) 2587 ((("%") reduce 57) (("(") reduce 57) ((")") reduce 57) (("*") reduce 57) (("+") reduce 57) ((",") reduce 57) (("-") reduce 57) ((".") reduce 57) (("/") reduce 57) (("<") reduce 57) ((">") reduce 57) (("?") reduce 57) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_BOOLEAN_AND) reduce 57) ((T_BOOLEAN_OR) reduce 57) ((T_COALESCE) reduce 57) ((T_INSTANCEOF) reduce 57) ((T_IS_EQUAL) reduce 57) ((T_IS_GREATER_OR_EQUAL) reduce 57) ((T_IS_IDENTICAL) reduce 57) ((T_IS_NOT_EQUAL) reduce 57) ((T_IS_NOT_IDENTICAL) reduce 57) ((T_IS_SMALLER_OR_EQUAL) reduce 57) ((T_LOGICAL_AND) reduce 57) ((T_LOGICAL_OR) reduce 57) ((T_LOGICAL_XOR) reduce 57) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 57) ((T_OBJECT_OPERATOR) reduce 57) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 57) ((T_POW) reduce 57) ((T_SL) reduce 57) ((T_SPACESHIP) reduce 57) ((T_SR) reduce 57) (("[") reduce 57) (("^") reduce 57) (("{") reduce 57) (("|") reduce 57)) 2588 ((("%") reduce 61) (("(") reduce 61) ((")") reduce 61) (("*") reduce 61) (("+") reduce 61) ((",") reduce 61) (("-") reduce 61) ((".") reduce 61) (("/") reduce 61) (("<") reduce 61) ((">") reduce 61) (("?") reduce 61) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_BOOLEAN_AND) reduce 61) ((T_BOOLEAN_OR) reduce 61) ((T_COALESCE) reduce 61) ((T_INSTANCEOF) reduce 61) ((T_IS_EQUAL) reduce 61) ((T_IS_GREATER_OR_EQUAL) reduce 61) ((T_IS_IDENTICAL) reduce 61) ((T_IS_NOT_EQUAL) reduce 61) ((T_IS_NOT_IDENTICAL) reduce 61) ((T_IS_SMALLER_OR_EQUAL) reduce 61) ((T_LOGICAL_AND) reduce 61) ((T_LOGICAL_OR) reduce 61) ((T_LOGICAL_XOR) reduce 61) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 61) ((T_OBJECT_OPERATOR) reduce 61) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 61) ((T_POW) reduce 61) ((T_SL) reduce 61) ((T_SPACESHIP) reduce 61) ((T_SR) reduce 61) (("[") reduce 61) (("^") reduce 61) (("{") reduce 61) (("|") reduce 61)) 2589 ((("%") reduce 28) (("(") reduce 28) ((")") reduce 28) (("*") reduce 28) (("+") reduce 28) ((",") reduce 28) (("-") reduce 28) ((".") reduce 28) (("/") reduce 28) (("<") reduce 28) ((">") reduce 28) (("?") reduce 28) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_BOOLEAN_AND) reduce 28) ((T_BOOLEAN_OR) reduce 28) ((T_COALESCE) reduce 28) ((T_INSTANCEOF) reduce 28) ((T_IS_EQUAL) reduce 28) ((T_IS_GREATER_OR_EQUAL) reduce 28) ((T_IS_IDENTICAL) reduce 28) ((T_IS_NOT_EQUAL) reduce 28) ((T_IS_NOT_IDENTICAL) reduce 28) ((T_IS_SMALLER_OR_EQUAL) reduce 28) ((T_LOGICAL_AND) reduce 28) ((T_LOGICAL_OR) reduce 28) ((T_LOGICAL_XOR) reduce 28) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 28) ((T_OBJECT_OPERATOR) reduce 28) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 28) ((T_POW) reduce 28) ((T_SL) reduce 28) ((T_SPACESHIP) reduce 28) ((T_SR) reduce 28) (("[") reduce 28) (("^") reduce 28) (("{") reduce 28) (("|") reduce 28)) 2590 ((("%") reduce 36) (("(") reduce 36) ((")") reduce 36) (("*") reduce 36) (("+") reduce 36) ((",") reduce 36) (("-") reduce 36) ((".") reduce 36) (("/") reduce 36) (("<") reduce 36) ((">") reduce 36) (("?") reduce 36) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_BOOLEAN_AND) reduce 36) ((T_BOOLEAN_OR) reduce 36) ((T_COALESCE) reduce 36) ((T_INSTANCEOF) reduce 36) ((T_IS_EQUAL) reduce 36) ((T_IS_GREATER_OR_EQUAL) reduce 36) ((T_IS_IDENTICAL) reduce 36) ((T_IS_NOT_EQUAL) reduce 36) ((T_IS_NOT_IDENTICAL) reduce 36) ((T_IS_SMALLER_OR_EQUAL) reduce 36) ((T_LOGICAL_AND) reduce 36) ((T_LOGICAL_OR) reduce 36) ((T_LOGICAL_XOR) reduce 36) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 36) ((T_OBJECT_OPERATOR) reduce 36) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 36) ((T_POW) reduce 36) ((T_SL) reduce 36) ((T_SPACESHIP) reduce 36) ((T_SR) reduce 36) (("[") reduce 36) (("^") reduce 36) (("{") reduce 36) (("|") reduce 36)) 2591 ((("%") reduce 32) (("(") reduce 32) ((")") reduce 32) (("*") reduce 32) (("+") reduce 32) ((",") reduce 32) (("-") reduce 32) ((".") reduce 32) (("/") reduce 32) (("<") reduce 32) ((">") reduce 32) (("?") reduce 32) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_BOOLEAN_AND) reduce 32) ((T_BOOLEAN_OR) reduce 32) ((T_COALESCE) reduce 32) ((T_INSTANCEOF) reduce 32) ((T_IS_EQUAL) reduce 32) ((T_IS_GREATER_OR_EQUAL) reduce 32) ((T_IS_IDENTICAL) reduce 32) ((T_IS_NOT_EQUAL) reduce 32) ((T_IS_NOT_IDENTICAL) reduce 32) ((T_IS_SMALLER_OR_EQUAL) reduce 32) ((T_LOGICAL_AND) reduce 32) ((T_LOGICAL_OR) reduce 32) ((T_LOGICAL_XOR) reduce 32) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 32) ((T_OBJECT_OPERATOR) reduce 32) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 32) ((T_POW) reduce 32) ((T_SL) reduce 32) ((T_SPACESHIP) reduce 32) ((T_SR) reduce 32) (("[") reduce 32) (("^") reduce 32) (("{") reduce 32) (("|") reduce 32)) 2592 ((("%") reduce 35) (("(") reduce 35) ((")") reduce 35) (("*") reduce 35) (("+") reduce 35) ((",") reduce 35) (("-") reduce 35) ((".") reduce 35) (("/") reduce 35) (("<") reduce 35) ((">") reduce 35) (("?") reduce 35) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_BOOLEAN_AND) reduce 35) ((T_BOOLEAN_OR) reduce 35) ((T_COALESCE) reduce 35) ((T_INSTANCEOF) reduce 35) ((T_IS_EQUAL) reduce 35) ((T_IS_GREATER_OR_EQUAL) reduce 35) ((T_IS_IDENTICAL) reduce 35) ((T_IS_NOT_EQUAL) reduce 35) ((T_IS_NOT_IDENTICAL) reduce 35) ((T_IS_SMALLER_OR_EQUAL) reduce 35) ((T_LOGICAL_AND) reduce 35) ((T_LOGICAL_OR) reduce 35) ((T_LOGICAL_XOR) reduce 35) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 35) ((T_OBJECT_OPERATOR) reduce 35) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 35) ((T_POW) reduce 35) ((T_SL) reduce 35) ((T_SPACESHIP) reduce 35) ((T_SR) reduce 35) (("[") reduce 35) (("^") reduce 35) (("{") reduce 35) (("|") reduce 35)) 2593 ((("%") reduce 19) (("(") reduce 19) ((")") reduce 19) (("*") reduce 19) (("+") reduce 19) ((",") reduce 19) (("-") reduce 19) ((".") reduce 19) (("/") reduce 19) (("<") reduce 19) ((">") reduce 19) (("?") reduce 19) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_BOOLEAN_AND) reduce 19) ((T_BOOLEAN_OR) reduce 19) ((T_COALESCE) reduce 19) ((T_INSTANCEOF) reduce 19) ((T_IS_EQUAL) reduce 19) ((T_IS_GREATER_OR_EQUAL) reduce 19) ((T_IS_IDENTICAL) reduce 19) ((T_IS_NOT_EQUAL) reduce 19) ((T_IS_NOT_IDENTICAL) reduce 19) ((T_IS_SMALLER_OR_EQUAL) reduce 19) ((T_LOGICAL_AND) reduce 19) ((T_LOGICAL_OR) reduce 19) ((T_LOGICAL_XOR) reduce 19) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 19) ((T_OBJECT_OPERATOR) reduce 19) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 19) ((T_POW) reduce 19) ((T_SL) reduce 19) ((T_SPACESHIP) reduce 19) ((T_SR) reduce 19) (("[") reduce 19) (("^") reduce 19) (("{") reduce 19) (("|") reduce 19)) 2594 ((("%") reduce 45) (("(") reduce 45) ((")") reduce 45) (("*") reduce 45) (("+") reduce 45) ((",") reduce 45) (("-") reduce 45) ((".") reduce 45) (("/") reduce 45) (("<") reduce 45) ((">") reduce 45) (("?") reduce 45) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_BOOLEAN_AND) reduce 45) ((T_BOOLEAN_OR) reduce 45) ((T_COALESCE) reduce 45) ((T_INSTANCEOF) reduce 45) ((T_IS_EQUAL) reduce 45) ((T_IS_GREATER_OR_EQUAL) reduce 45) ((T_IS_IDENTICAL) reduce 45) ((T_IS_NOT_EQUAL) reduce 45) ((T_IS_NOT_IDENTICAL) reduce 45) ((T_IS_SMALLER_OR_EQUAL) reduce 45) ((T_LOGICAL_AND) reduce 45) ((T_LOGICAL_OR) reduce 45) ((T_LOGICAL_XOR) reduce 45) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 45) ((T_OBJECT_OPERATOR) reduce 45) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 45) ((T_POW) reduce 45) ((T_SL) reduce 45) ((T_SPACESHIP) reduce 45) ((T_SR) reduce 45) (("[") reduce 45) (("^") reduce 45) (("{") reduce 45) (("|") reduce 45)) 2595 ((("%") reduce 504) (("(") reduce 541) ((")") reduce 504) (("*") reduce 504) (("+") reduce 504) ((",") reduce 504) (("-") reduce 504) ((".") reduce 504) (("/") reduce 504) (("<") reduce 504) ((">") reduce 504) (("?") reduce 504) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_BOOLEAN_AND) reduce 504) ((T_BOOLEAN_OR) reduce 504) ((T_COALESCE) reduce 504) ((T_INSTANCEOF) reduce 504) ((T_IS_EQUAL) reduce 504) ((T_IS_GREATER_OR_EQUAL) reduce 504) ((T_IS_IDENTICAL) reduce 504) ((T_IS_NOT_EQUAL) reduce 504) ((T_IS_NOT_IDENTICAL) reduce 504) ((T_IS_SMALLER_OR_EQUAL) reduce 504) ((T_LOGICAL_AND) reduce 504) ((T_LOGICAL_OR) reduce 504) ((T_LOGICAL_XOR) reduce 504) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 504) ((T_OBJECT_OPERATOR) reduce 504) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 504) ((T_POW) reduce 504) ((T_SL) reduce 504) ((T_SPACESHIP) reduce 504) ((T_SR) reduce 504) (("[") reduce 504) (("^") reduce 504) (("{") reduce 504) (("|") reduce 504)) 2597 ((("%") reduce 71) (("(") reduce 71) ((")") reduce 71) (("*") reduce 71) (("+") reduce 71) ((",") reduce 71) (("-") reduce 71) ((".") reduce 71) (("/") reduce 71) (("<") reduce 71) ((">") reduce 71) (("?") reduce 71) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_BOOLEAN_AND) reduce 71) ((T_BOOLEAN_OR) reduce 71) ((T_COALESCE) reduce 71) ((T_INSTANCEOF) reduce 71) ((T_IS_EQUAL) reduce 71) ((T_IS_GREATER_OR_EQUAL) reduce 71) ((T_IS_IDENTICAL) reduce 71) ((T_IS_NOT_EQUAL) reduce 71) ((T_IS_NOT_IDENTICAL) reduce 71) ((T_IS_SMALLER_OR_EQUAL) reduce 71) ((T_LOGICAL_AND) reduce 71) ((T_LOGICAL_OR) reduce 71) ((T_LOGICAL_XOR) reduce 71) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 71) ((T_OBJECT_OPERATOR) reduce 71) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 71) ((T_POW) reduce 71) ((T_SL) reduce 71) ((T_SPACESHIP) reduce 71) ((T_SR) reduce 71) (("[") reduce 71) (("^") reduce 71) (("{") reduce 71) (("|") reduce 71)) 2598 ((("%") reduce 82) (("(") reduce 82) ((")") reduce 82) (("*") reduce 82) (("+") reduce 82) ((",") reduce 82) (("-") reduce 82) ((".") reduce 82) (("/") reduce 82) (("<") reduce 82) ((">") reduce 82) (("?") reduce 82) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_BOOLEAN_AND) reduce 82) ((T_BOOLEAN_OR) reduce 82) ((T_COALESCE) reduce 82) ((T_INSTANCEOF) reduce 82) ((T_IS_EQUAL) reduce 82) ((T_IS_GREATER_OR_EQUAL) reduce 82) ((T_IS_IDENTICAL) reduce 82) ((T_IS_NOT_EQUAL) reduce 82) ((T_IS_NOT_IDENTICAL) reduce 82) ((T_IS_SMALLER_OR_EQUAL) reduce 82) ((T_LOGICAL_AND) reduce 82) ((T_LOGICAL_OR) reduce 82) ((T_LOGICAL_XOR) reduce 82) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 82) ((T_OBJECT_OPERATOR) reduce 82) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 82) ((T_POW) reduce 82) ((T_SL) reduce 82) ((T_SPACESHIP) reduce 82) ((T_SR) reduce 82) (("[") reduce 82) (("^") reduce 82) (("{") reduce 82) (("|") reduce 82)) 2599 ((("%") reduce 533) (("(") reduce 543) ((")") reduce 533) (("*") reduce 533) (("+") reduce 533) ((",") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) (("<") reduce 533) (("=") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AND_EQUAL) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_COALESCE_EQUAL) reduce 533) ((T_CONCAT_EQUAL) reduce 533) ((T_DEC) reduce 533) ((T_DIV_EQUAL) reduce 533) ((T_INC) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_MINUS_EQUAL) reduce 533) ((T_MOD_EQUAL) reduce 533) ((T_MUL_EQUAL) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_OR_EQUAL) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_PLUS_EQUAL) reduce 533) ((T_POW) reduce 533) ((T_POW_EQUAL) reduce 533) ((T_SL) reduce 533) ((T_SL_EQUAL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) ((T_SR_EQUAL) reduce 533) ((T_XOR_EQUAL) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 2602 ((("%") reduce 506) (("(") reduce 542) ((")") reduce 506) (("*") reduce 506) (("+") reduce 506) ((",") reduce 506) (("-") reduce 506) ((".") reduce 506) (("/") reduce 506) (("<") reduce 506) ((">") reduce 506) (("?") reduce 506) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_BOOLEAN_AND) reduce 506) ((T_BOOLEAN_OR) reduce 506) ((T_COALESCE) reduce 506) ((T_INSTANCEOF) reduce 506) ((T_IS_EQUAL) reduce 506) ((T_IS_GREATER_OR_EQUAL) reduce 506) ((T_IS_IDENTICAL) reduce 506) ((T_IS_NOT_EQUAL) reduce 506) ((T_IS_NOT_IDENTICAL) reduce 506) ((T_IS_SMALLER_OR_EQUAL) reduce 506) ((T_LOGICAL_AND) reduce 506) ((T_LOGICAL_OR) reduce 506) ((T_LOGICAL_XOR) reduce 506) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 506) ((T_OBJECT_OPERATOR) reduce 506) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 506) ((T_POW) reduce 506) ((T_SL) reduce 506) ((T_SPACESHIP) reduce 506) ((T_SR) reduce 506) (("[") reduce 506) (("^") reduce 506) (("{") reduce 506) (("|") reduce 506)) 2604 ((("%") reduce 468) (("(") reduce 468) ((")") reduce 468) (("*") reduce 468) (("+") reduce 468) ((",") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) (("<") reduce 468) (("=") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AND_EQUAL) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_COALESCE_EQUAL) reduce 468) ((T_CONCAT_EQUAL) reduce 468) ((T_DEC) reduce 468) ((T_DIV_EQUAL) reduce 468) ((T_INC) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_MINUS_EQUAL) reduce 468) ((T_MOD_EQUAL) reduce 468) ((T_MUL_EQUAL) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_OR_EQUAL) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_PLUS_EQUAL) reduce 468) ((T_POW) reduce 468) ((T_POW_EQUAL) reduce 468) ((T_SL) reduce 468) ((T_SL_EQUAL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) ((T_SR_EQUAL) reduce 468) ((T_XOR_EQUAL) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 2605 ((("%") reduce 288) (("(") reduce 288) ((")") reduce 288) (("*") reduce 288) (("+") reduce 288) ((",") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) (("=") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AND_EQUAL) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_COALESCE_EQUAL) reduce 288) ((T_CONCAT_EQUAL) reduce 288) ((T_DEC) reduce 288) ((T_DIV_EQUAL) reduce 288) ((T_INC) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_MINUS_EQUAL) reduce 288) ((T_MOD_EQUAL) reduce 288) ((T_MUL_EQUAL) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_OR_EQUAL) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_PLUS_EQUAL) reduce 288) ((T_POW) reduce 288) ((T_POW_EQUAL) reduce 288) ((T_SL) reduce 288) ((T_SL_EQUAL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) ((T_SR_EQUAL) reduce 288) ((T_XOR_EQUAL) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 2609 ((("%") reduce 289) (("(") reduce 289) ((")") reduce 289) (("*") reduce 289) (("+") reduce 289) ((",") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) (("=") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AND_EQUAL) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_COALESCE_EQUAL) reduce 289) ((T_CONCAT_EQUAL) reduce 289) ((T_DEC) reduce 289) ((T_DIV_EQUAL) reduce 289) ((T_INC) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_MINUS_EQUAL) reduce 289) ((T_MOD_EQUAL) reduce 289) ((T_MUL_EQUAL) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_OR_EQUAL) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_PLUS_EQUAL) reduce 289) ((T_POW) reduce 289) ((T_POW_EQUAL) reduce 289) ((T_SL) reduce 289) ((T_SL_EQUAL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) ((T_SR_EQUAL) reduce 289) ((T_XOR_EQUAL) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 2610 ((("%") reduce 290) (("(") reduce 290) ((")") reduce 290) (("*") reduce 290) (("+") reduce 290) ((",") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) (("=") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AND_EQUAL) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_COALESCE_EQUAL) reduce 290) ((T_CONCAT_EQUAL) reduce 290) ((T_DEC) reduce 290) ((T_DIV_EQUAL) reduce 290) ((T_INC) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_MINUS_EQUAL) reduce 290) ((T_MOD_EQUAL) reduce 290) ((T_MUL_EQUAL) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_OR_EQUAL) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_PLUS_EQUAL) reduce 290) ((T_POW) reduce 290) ((T_POW_EQUAL) reduce 290) ((T_SL) reduce 290) ((T_SL_EQUAL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) ((T_SR_EQUAL) reduce 290) ((T_XOR_EQUAL) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 2615 ((("%") reduce 388) ((")") reduce 388) (("*") reduce 388) (("+") reduce 388) ((",") reduce 388) (("-") reduce 388) ((".") reduce 388) (("/") reduce 388) (("<") reduce 388) ((">") reduce 388) (("?") reduce 388) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_BOOLEAN_AND) reduce 388) ((T_BOOLEAN_OR) reduce 388) ((T_COALESCE) reduce 388) ((T_INSTANCEOF) reduce 388) ((T_IS_EQUAL) reduce 388) ((T_IS_GREATER_OR_EQUAL) reduce 388) ((T_IS_IDENTICAL) reduce 388) ((T_IS_NOT_EQUAL) reduce 388) ((T_IS_NOT_IDENTICAL) reduce 388) ((T_IS_SMALLER_OR_EQUAL) reduce 388) ((T_LOGICAL_AND) reduce 388) ((T_LOGICAL_OR) reduce 388) ((T_LOGICAL_XOR) reduce 388) ((T_POW) reduce 388) ((T_SL) reduce 388) ((T_SPACESHIP) reduce 388) ((T_SR) reduce 388) (("^") reduce 388) (("|") reduce 388)) 2617 ((("%") reduce 386) ((")") reduce 386) (("*") reduce 386) (("+") reduce 386) ((",") reduce 386) (("-") reduce 386) ((".") reduce 386) (("/") reduce 386) (("<") reduce 386) ((">") reduce 386) (("?") reduce 386) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_BOOLEAN_AND) reduce 386) ((T_BOOLEAN_OR) reduce 386) ((T_COALESCE) reduce 386) ((T_INSTANCEOF) reduce 386) ((T_IS_EQUAL) reduce 386) ((T_IS_GREATER_OR_EQUAL) reduce 386) ((T_IS_IDENTICAL) reduce 386) ((T_IS_NOT_EQUAL) reduce 386) ((T_IS_NOT_IDENTICAL) reduce 386) ((T_IS_SMALLER_OR_EQUAL) reduce 386) ((T_LOGICAL_AND) reduce 386) ((T_LOGICAL_OR) reduce 386) ((T_LOGICAL_XOR) reduce 386) ((T_POW) reduce 386) ((T_SL) reduce 386) ((T_SPACESHIP) reduce 386) ((T_SR) reduce 386) (("^") reduce 386) (("|") reduce 386)) 2627 ((("%") shift) ((")") reduce 382) (("*") shift) (("+") shift) ((",") reduce 382) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 382) ((T_LOGICAL_OR) reduce 382) ((T_LOGICAL_XOR) reduce 382) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 2628 ((("%") shift) ((")") reduce 384) (("*") shift) (("+") shift) ((",") reduce 384) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 384) ((T_LOGICAL_OR) reduce 384) ((T_LOGICAL_XOR) reduce 384) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 2629 ((("%") shift) ((")") reduce 383) (("*") shift) (("+") shift) ((",") reduce 383) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 383) ((T_LOGICAL_OR) reduce 383) ((T_LOGICAL_XOR) reduce 383) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 2630 ((("%") shift) ((")") reduce 376) (("*") shift) (("+") shift) ((",") reduce 376) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 376) ((T_LOGICAL_OR) reduce 376) ((T_LOGICAL_XOR) reduce 376) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 2631 ((("%") shift) ((")") reduce 373) (("*") shift) (("+") shift) ((",") reduce 373) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 373) ((T_LOGICAL_OR) reduce 373) ((T_LOGICAL_XOR) reduce 373) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 2632 ((("%") shift) ((")") reduce 381) (("*") shift) (("+") shift) ((",") reduce 381) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 381) ((T_LOGICAL_OR) reduce 381) ((T_LOGICAL_XOR) reduce 381) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 2633 ((("%") shift) ((")") reduce 375) (("*") shift) (("+") shift) ((",") reduce 375) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 375) ((T_LOGICAL_OR) reduce 375) ((T_LOGICAL_XOR) reduce 375) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 2634 ((("%") shift) ((")") reduce 379) (("*") shift) (("+") shift) ((",") reduce 379) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 379) ((T_LOGICAL_OR) reduce 379) ((T_LOGICAL_XOR) reduce 379) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 2635 ((("%") shift) ((")") reduce 374) (("*") shift) (("+") shift) ((",") reduce 374) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 374) ((T_LOGICAL_OR) reduce 374) ((T_LOGICAL_XOR) reduce 374) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 2636 ((("%") shift) ((")") reduce 377) (("*") shift) (("+") shift) ((",") reduce 377) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 377) ((T_LOGICAL_OR) reduce 377) ((T_LOGICAL_XOR) reduce 377) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 2637 ((("%") shift) ((")") reduce 378) (("*") shift) (("+") shift) ((",") reduce 378) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 378) ((T_LOGICAL_OR) reduce 378) ((T_LOGICAL_XOR) reduce 378) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 2638 ((("%") shift) ((")") reduce 385) (("*") shift) (("+") shift) ((",") reduce 385) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 385) ((T_LOGICAL_OR) reduce 385) ((T_LOGICAL_XOR) reduce 385) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 2639 ((("%") shift) ((")") reduce 380) (("*") shift) (("+") shift) ((",") reduce 380) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 380) ((T_LOGICAL_OR) reduce 380) ((T_LOGICAL_XOR) reduce 380) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 2641 ((("%") shift) ((")") reduce 370) (("*") shift) (("+") shift) ((",") reduce 370) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 370) ((T_LOGICAL_OR) reduce 370) ((T_LOGICAL_XOR) reduce 370) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 2644 ((("%") reduce 529) (("(") reduce 529) ((")") reduce 529) (("*") reduce 529) (("+") reduce 529) ((",") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 2647 ((("%") reduce 525) (("(") reduce 516) ((")") reduce 525) (("*") reduce 525) (("+") reduce 525) ((",") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) (("<") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_POW) reduce 525) ((T_SL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 2649 ((("%") reduce 524) (("(") reduce 524) ((")") reduce 524) (("*") reduce 524) (("+") reduce 524) ((",") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) (("<") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_POW) reduce 524) ((T_SL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 2651 ((("%") reduce 519) (("(") reduce 519) ((")") reduce 519) (("*") reduce 519) (("+") reduce 519) ((",") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) (("<") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_POW) reduce 519) ((T_SL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 2652 ((("%") reduce 526) ((")") reduce 526) (("*") reduce 526) (("+") reduce 526) ((",") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) (("<") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_POW) reduce 526) ((T_SL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 2653 ((("%") reduce 371) ((")") reduce 371) (("*") reduce 371) (("+") reduce 371) ((",") reduce 371) (("-") reduce 371) ((".") reduce 371) (("/") reduce 371) (("<") reduce 371) ((">") reduce 371) (("?") reduce 371) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_BOOLEAN_AND) reduce 371) ((T_BOOLEAN_OR) reduce 371) ((T_COALESCE) reduce 371) ((T_INSTANCEOF) reduce 371) ((T_IS_EQUAL) reduce 371) ((T_IS_GREATER_OR_EQUAL) reduce 371) ((T_IS_IDENTICAL) reduce 371) ((T_IS_NOT_EQUAL) reduce 371) ((T_IS_NOT_IDENTICAL) reduce 371) ((T_IS_SMALLER_OR_EQUAL) reduce 371) ((T_LOGICAL_AND) reduce 371) ((T_LOGICAL_OR) reduce 371) ((T_LOGICAL_XOR) reduce 371) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 371) ((T_SL) reduce 371) ((T_SPACESHIP) reduce 371) ((T_SR) reduce 371) (("[") reduce 510) (("^") reduce 371) (("{") reduce 510) (("|") reduce 371)) 2657 ((("%") reduce 533) (("(") reduce 543) ((")") reduce 533) (("*") reduce 533) (("+") reduce 533) ((",") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) (("<") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_POW) reduce 533) ((T_SL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 2659 ((("%") reduce 468) (("(") reduce 468) ((")") reduce 468) (("*") reduce 468) (("+") reduce 468) ((",") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) (("<") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_POW) reduce 468) ((T_SL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 2660 ((("%") reduce 288) (("(") reduce 288) ((")") reduce 288) (("*") reduce 288) (("+") reduce 288) ((",") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 2664 ((("%") reduce 289) (("(") reduce 289) ((")") reduce 289) (("*") reduce 289) (("+") reduce 289) ((",") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 2665 ((("%") reduce 290) (("(") reduce 290) ((")") reduce 290) (("*") reduce 290) (("+") reduce 290) ((",") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 2666 ((("%") reduce 465) (("(") reduce 465) ((")") reduce 465) (("*") reduce 465) (("+") reduce 465) ((",") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) (("<") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_POW) reduce 465) ((T_SL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 2669 ((("%") reduce 532) (("(") reduce 543) ((")") reduce 532) (("*") reduce 532) (("+") reduce 532) ((",") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) (("<") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_POW) reduce 532) ((T_SL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 2670 ((("%") reduce 467) (("(") reduce 467) ((")") reduce 467) (("*") reduce 467) (("+") reduce 467) ((",") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) (("<") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_POW) reduce 467) ((T_SL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 2671 ((("%") reduce 469) (("(") reduce 469) ((")") reduce 469) (("*") reduce 469) (("+") reduce 469) ((",") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) (("<") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_POW) reduce 469) ((T_SL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 2677 ((("%") reduce 521) (("(") reduce 521) ((")") reduce 521) (("*") reduce 521) (("+") reduce 521) ((",") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) (("<") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_POW) reduce 521) ((T_SL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 2679 ((("%") reduce 520) (("(") reduce 520) ((")") reduce 520) (("*") reduce 520) (("+") reduce 520) ((",") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) (("<") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_POW) reduce 520) ((T_SL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 2680 ((("%") reduce 544) (("(") reduce 544) ((")") reduce 544) (("*") reduce 544) (("+") reduce 544) ((",") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 2681 ((("%") reduce 527) (("(") shift) ((")") reduce 527) (("*") reduce 527) (("+") reduce 527) ((",") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) (("<") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_POW) reduce 527) ((T_SL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 2682 ((("%") reduce 546) (("(") reduce 546) ((")") reduce 546) (("*") reduce 546) (("+") reduce 546) ((",") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 2685 ((("%") reduce 545) (("(") reduce 545) ((")") reduce 545) (("*") reduce 545) (("+") reduce 545) ((",") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 2686 ((("%") reduce 522) (("(") reduce 522) ((")") reduce 522) (("*") reduce 522) (("+") reduce 522) ((",") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) (("<") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_POW) reduce 522) ((T_SL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 2687 ((("%") reduce 528) (("(") shift) ((")") reduce 528) (("*") reduce 528) (("+") reduce 528) ((",") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) (("<") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_POW) reduce 528) ((T_SL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 2688 ((("%") reduce 523) (("(") reduce 523) ((")") reduce 523) (("*") reduce 523) (("+") reduce 523) ((",") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) (("<") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_POW) reduce 523) ((T_SL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 2689 ((("%") reduce 466) (("(") reduce 466) ((")") reduce 466) (("*") reduce 466) (("+") reduce 466) ((",") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) (("<") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_POW) reduce 466) ((T_SL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 2690 ((("%") reduce 531) (("(") reduce 531) ((")") reduce 531) (("*") reduce 531) (("+") reduce 531) ((",") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 2693 ((("%") reduce 530) (("(") reduce 530) ((")") reduce 530) (("*") reduce 530) (("+") reduce 530) ((",") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 2694 ((("%") reduce 465) (("(") reduce 465) ((")") reduce 465) (("*") reduce 465) (("+") reduce 465) ((",") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) (("<") reduce 465) (("=") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AND_EQUAL) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_COALESCE_EQUAL) reduce 465) ((T_CONCAT_EQUAL) reduce 465) ((T_DEC) reduce 465) ((T_DIV_EQUAL) reduce 465) ((T_INC) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_MINUS_EQUAL) reduce 465) ((T_MOD_EQUAL) reduce 465) ((T_MUL_EQUAL) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_OR_EQUAL) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_PLUS_EQUAL) reduce 465) ((T_POW) reduce 465) ((T_POW_EQUAL) reduce 465) ((T_SL) reduce 465) ((T_SL_EQUAL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) ((T_SR_EQUAL) reduce 465) ((T_XOR_EQUAL) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 2705 ((("%") reduce 455) ((")") reduce 455) (("*") reduce 455) (("+") reduce 455) ((",") reduce 455) (("-") reduce 455) ((".") reduce 455) (("/") reduce 455) (("<") reduce 455) ((">") reduce 455) (("?") reduce 455) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_BOOLEAN_AND) reduce 455) ((T_BOOLEAN_OR) reduce 455) ((T_COALESCE) reduce 455) ((T_INSTANCEOF) reduce 455) ((T_IS_EQUAL) reduce 455) ((T_IS_GREATER_OR_EQUAL) reduce 455) ((T_IS_IDENTICAL) reduce 455) ((T_IS_NOT_EQUAL) reduce 455) ((T_IS_NOT_IDENTICAL) reduce 455) ((T_IS_SMALLER_OR_EQUAL) reduce 455) ((T_LOGICAL_AND) reduce 455) ((T_LOGICAL_OR) reduce 455) ((T_LOGICAL_XOR) reduce 455) ((T_POW) reduce 455) ((T_SL) reduce 455) ((T_SPACESHIP) reduce 455) ((T_SR) reduce 455) (("^") reduce 455) (("|") reduce 455)) 2706 ((("%") reduce 450) ((")") reduce 450) (("*") reduce 450) (("+") reduce 450) ((",") reduce 450) (("-") reduce 450) ((".") reduce 450) (("/") reduce 450) (("<") reduce 450) ((">") reduce 450) (("?") reduce 450) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_BOOLEAN_AND) reduce 450) ((T_BOOLEAN_OR) reduce 450) ((T_COALESCE) reduce 450) ((T_INSTANCEOF) reduce 450) ((T_IS_EQUAL) reduce 450) ((T_IS_GREATER_OR_EQUAL) reduce 450) ((T_IS_IDENTICAL) reduce 450) ((T_IS_NOT_EQUAL) reduce 450) ((T_IS_NOT_IDENTICAL) reduce 450) ((T_IS_SMALLER_OR_EQUAL) reduce 450) ((T_LOGICAL_AND) reduce 450) ((T_LOGICAL_OR) reduce 450) ((T_LOGICAL_XOR) reduce 450) ((T_POW) reduce 450) ((T_SL) reduce 450) ((T_SPACESHIP) reduce 450) ((T_SR) reduce 450) (("^") reduce 450) (("|") reduce 450)) 2716 ((("%") shift) ((")") reduce 455) (("*") shift) (("+") shift) ((",") reduce 455) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 2717 ((("%") reduce 451) ((")") reduce 451) (("*") reduce 451) (("+") reduce 451) ((",") reduce 451) (("-") reduce 451) ((".") reduce 451) (("/") reduce 451) (("<") reduce 451) ((">") reduce 451) (("?") reduce 451) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_BOOLEAN_AND) reduce 451) ((T_BOOLEAN_OR) reduce 451) ((T_COALESCE) reduce 451) ((T_INSTANCEOF) reduce 451) ((T_IS_EQUAL) reduce 451) ((T_IS_GREATER_OR_EQUAL) reduce 451) ((T_IS_IDENTICAL) reduce 451) ((T_IS_NOT_EQUAL) reduce 451) ((T_IS_NOT_IDENTICAL) reduce 451) ((T_IS_SMALLER_OR_EQUAL) reduce 451) ((T_LOGICAL_AND) reduce 451) ((T_LOGICAL_OR) reduce 451) ((T_LOGICAL_XOR) reduce 451) ((T_POW) reduce 451) ((T_SL) reduce 451) ((T_SPACESHIP) reduce 451) ((T_SR) reduce 451) (("^") reduce 451) (("|") reduce 451)) 2719 ((("%") reduce 503) (("(") reduce 541) ((")") reduce 503) (("*") reduce 503) (("+") reduce 503) ((",") reduce 503) (("-") reduce 503) ((".") reduce 503) (("/") reduce 503) (("<") reduce 503) ((">") reduce 503) (("?") reduce 503) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_BOOLEAN_AND) reduce 503) ((T_BOOLEAN_OR) reduce 503) ((T_COALESCE) reduce 503) ((T_INSTANCEOF) reduce 503) ((T_IS_EQUAL) reduce 503) ((T_IS_GREATER_OR_EQUAL) reduce 503) ((T_IS_IDENTICAL) reduce 503) ((T_IS_NOT_EQUAL) reduce 503) ((T_IS_NOT_IDENTICAL) reduce 503) ((T_IS_SMALLER_OR_EQUAL) reduce 503) ((T_LOGICAL_AND) reduce 503) ((T_LOGICAL_OR) reduce 503) ((T_LOGICAL_XOR) reduce 503) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 503) ((T_OBJECT_OPERATOR) reduce 503) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 503) ((T_POW) reduce 503) ((T_SL) reduce 503) ((T_SPACESHIP) reduce 503) ((T_SR) reduce 503) (("[") reduce 503) (("^") reduce 503) (("{") reduce 503) (("|") reduce 503)) 2721 ((("%") reduce 532) (("(") reduce 543) ((")") reduce 532) (("*") reduce 532) (("+") reduce 532) ((",") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) (("<") reduce 532) (("=") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AND_EQUAL) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_COALESCE_EQUAL) reduce 532) ((T_CONCAT_EQUAL) reduce 532) ((T_DEC) reduce 532) ((T_DIV_EQUAL) reduce 532) ((T_INC) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_MINUS_EQUAL) reduce 532) ((T_MOD_EQUAL) reduce 532) ((T_MUL_EQUAL) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_OR_EQUAL) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_PLUS_EQUAL) reduce 532) ((T_POW) reduce 532) ((T_POW_EQUAL) reduce 532) ((T_SL) reduce 532) ((T_SL_EQUAL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) ((T_SR_EQUAL) reduce 532) ((T_XOR_EQUAL) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 2724 ((("%") reduce 505) (("(") reduce 542) ((")") reduce 505) (("*") reduce 505) (("+") reduce 505) ((",") reduce 505) (("-") reduce 505) ((".") reduce 505) (("/") reduce 505) (("<") reduce 505) ((">") reduce 505) (("?") reduce 505) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_BOOLEAN_AND) reduce 505) ((T_BOOLEAN_OR) reduce 505) ((T_COALESCE) reduce 505) ((T_INSTANCEOF) reduce 505) ((T_IS_EQUAL) reduce 505) ((T_IS_GREATER_OR_EQUAL) reduce 505) ((T_IS_IDENTICAL) reduce 505) ((T_IS_NOT_EQUAL) reduce 505) ((T_IS_NOT_IDENTICAL) reduce 505) ((T_IS_SMALLER_OR_EQUAL) reduce 505) ((T_LOGICAL_AND) reduce 505) ((T_LOGICAL_OR) reduce 505) ((T_LOGICAL_XOR) reduce 505) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 505) ((T_OBJECT_OPERATOR) reduce 505) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 505) ((T_POW) reduce 505) ((T_SL) reduce 505) ((T_SPACESHIP) reduce 505) ((T_SR) reduce 505) (("[") reduce 505) (("^") reduce 505) (("{") reduce 505) (("|") reduce 505)) 2725 ((("%") reduce 467) (("(") reduce 467) ((")") reduce 467) (("*") reduce 467) (("+") reduce 467) ((",") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) (("<") reduce 467) (("=") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AND_EQUAL) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_COALESCE_EQUAL) reduce 467) ((T_CONCAT_EQUAL) reduce 467) ((T_DEC) reduce 467) ((T_DIV_EQUAL) reduce 467) ((T_INC) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_MINUS_EQUAL) reduce 467) ((T_MOD_EQUAL) reduce 467) ((T_MUL_EQUAL) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_OR_EQUAL) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_PLUS_EQUAL) reduce 467) ((T_POW) reduce 467) ((T_POW_EQUAL) reduce 467) ((T_SL) reduce 467) ((T_SL_EQUAL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) ((T_SR_EQUAL) reduce 467) ((T_XOR_EQUAL) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 2726 ((("%") reduce 469) (("(") reduce 469) ((")") reduce 469) (("*") reduce 469) (("+") reduce 469) ((",") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) (("<") reduce 469) (("=") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AND_EQUAL) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_COALESCE_EQUAL) reduce 469) ((T_CONCAT_EQUAL) reduce 469) ((T_DEC) reduce 469) ((T_DIV_EQUAL) reduce 469) ((T_INC) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_MINUS_EQUAL) reduce 469) ((T_MOD_EQUAL) reduce 469) ((T_MUL_EQUAL) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_OR_EQUAL) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_PLUS_EQUAL) reduce 469) ((T_POW) reduce 469) ((T_POW_EQUAL) reduce 469) ((T_SL) reduce 469) ((T_SL_EQUAL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) ((T_SR_EQUAL) reduce 469) ((T_XOR_EQUAL) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 2727 (((T_FN) shift) ((T_FUNCTION) shift)) 2728 (((T_ATTRIBUTE) reduce 101) ((T_FN) reduce 101) ((T_FUNCTION) reduce 101) ((T_STATIC) reduce 101)) 2729 ((("%") reduce 446) ((")") reduce 446) (("*") reduce 446) (("+") reduce 446) ((",") reduce 446) (("-") reduce 446) ((".") reduce 446) (("/") reduce 446) (("<") reduce 446) ((">") reduce 446) (("?") reduce 446) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_BOOLEAN_AND) reduce 446) ((T_BOOLEAN_OR) reduce 446) ((T_COALESCE) reduce 446) ((T_INSTANCEOF) reduce 446) ((T_IS_EQUAL) reduce 446) ((T_IS_GREATER_OR_EQUAL) reduce 446) ((T_IS_IDENTICAL) reduce 446) ((T_IS_NOT_EQUAL) reduce 446) ((T_IS_NOT_IDENTICAL) reduce 446) ((T_IS_SMALLER_OR_EQUAL) reduce 446) ((T_LOGICAL_AND) reduce 446) ((T_LOGICAL_OR) reduce 446) ((T_LOGICAL_XOR) reduce 446) ((T_POW) reduce 446) ((T_SL) reduce 446) ((T_SPACESHIP) reduce 446) ((T_SR) reduce 446) (("^") reduce 446) (("|") reduce 446)) 2730 ((("%") reduce 448) ((")") reduce 448) (("*") reduce 448) (("+") reduce 448) ((",") reduce 448) (("-") reduce 448) ((".") reduce 448) (("/") reduce 448) (("<") reduce 448) ((">") reduce 448) (("?") reduce 448) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_BOOLEAN_AND) reduce 448) ((T_BOOLEAN_OR) reduce 448) ((T_COALESCE) reduce 448) ((T_INSTANCEOF) reduce 448) ((T_IS_EQUAL) reduce 448) ((T_IS_GREATER_OR_EQUAL) reduce 448) ((T_IS_IDENTICAL) reduce 448) ((T_IS_NOT_EQUAL) reduce 448) ((T_IS_NOT_IDENTICAL) reduce 448) ((T_IS_SMALLER_OR_EQUAL) reduce 448) ((T_LOGICAL_AND) reduce 448) ((T_LOGICAL_OR) reduce 448) ((T_LOGICAL_XOR) reduce 448) ((T_POW) reduce 448) ((T_SL) reduce 448) ((T_SPACESHIP) reduce 448) ((T_SR) reduce 448) (("^") reduce 448) (("|") reduce 448)) 2736 ((("%") reduce 521) (("(") reduce 521) ((")") reduce 521) (("*") reduce 521) (("+") reduce 521) ((",") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) (("<") reduce 521) (("=") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AND_EQUAL) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_COALESCE_EQUAL) reduce 521) ((T_CONCAT_EQUAL) reduce 521) ((T_DEC) reduce 521) ((T_DIV_EQUAL) reduce 521) ((T_INC) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_MINUS_EQUAL) reduce 521) ((T_MOD_EQUAL) reduce 521) ((T_MUL_EQUAL) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_OR_EQUAL) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_PLUS_EQUAL) reduce 521) ((T_POW) reduce 521) ((T_POW_EQUAL) reduce 521) ((T_SL) reduce 521) ((T_SL_EQUAL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) ((T_SR_EQUAL) reduce 521) ((T_XOR_EQUAL) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 2738 ((("%") reduce 520) (("(") reduce 520) ((")") reduce 520) (("*") reduce 520) (("+") reduce 520) ((",") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) (("<") reduce 520) (("=") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AND_EQUAL) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_COALESCE_EQUAL) reduce 520) ((T_CONCAT_EQUAL) reduce 520) ((T_DEC) reduce 520) ((T_DIV_EQUAL) reduce 520) ((T_INC) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_MINUS_EQUAL) reduce 520) ((T_MOD_EQUAL) reduce 520) ((T_MUL_EQUAL) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_OR_EQUAL) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_PLUS_EQUAL) reduce 520) ((T_POW) reduce 520) ((T_POW_EQUAL) reduce 520) ((T_SL) reduce 520) ((T_SL_EQUAL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) ((T_SR_EQUAL) reduce 520) ((T_XOR_EQUAL) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 2739 ((("%") reduce 544) (("(") reduce 544) ((")") reduce 544) (("*") reduce 544) (("+") reduce 544) ((",") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) (("=") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AND_EQUAL) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_COALESCE_EQUAL) reduce 544) ((T_CONCAT_EQUAL) reduce 544) ((T_DEC) reduce 544) ((T_DIV_EQUAL) reduce 544) ((T_INC) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_MINUS_EQUAL) reduce 544) ((T_MOD_EQUAL) reduce 544) ((T_MUL_EQUAL) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_OR_EQUAL) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_PLUS_EQUAL) reduce 544) ((T_POW) reduce 544) ((T_POW_EQUAL) reduce 544) ((T_SL) reduce 544) ((T_SL_EQUAL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) ((T_SR_EQUAL) reduce 544) ((T_XOR_EQUAL) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 2740 ((("%") reduce 527) (("(") shift) ((")") reduce 527) (("*") reduce 527) (("+") reduce 527) ((",") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) (("<") reduce 527) (("=") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AND_EQUAL) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_COALESCE_EQUAL) reduce 527) ((T_CONCAT_EQUAL) reduce 527) ((T_DEC) reduce 527) ((T_DIV_EQUAL) reduce 527) ((T_INC) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_MINUS_EQUAL) reduce 527) ((T_MOD_EQUAL) reduce 527) ((T_MUL_EQUAL) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_OR_EQUAL) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_PLUS_EQUAL) reduce 527) ((T_POW) reduce 527) ((T_POW_EQUAL) reduce 527) ((T_SL) reduce 527) ((T_SL_EQUAL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) ((T_SR_EQUAL) reduce 527) ((T_XOR_EQUAL) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 2741 ((("%") reduce 546) (("(") reduce 546) ((")") reduce 546) (("*") reduce 546) (("+") reduce 546) ((",") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) (("=") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AND_EQUAL) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_COALESCE_EQUAL) reduce 546) ((T_CONCAT_EQUAL) reduce 546) ((T_DEC) reduce 546) ((T_DIV_EQUAL) reduce 546) ((T_INC) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_MINUS_EQUAL) reduce 546) ((T_MOD_EQUAL) reduce 546) ((T_MUL_EQUAL) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_OR_EQUAL) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_PLUS_EQUAL) reduce 546) ((T_POW) reduce 546) ((T_POW_EQUAL) reduce 546) ((T_SL) reduce 546) ((T_SL_EQUAL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) ((T_SR_EQUAL) reduce 546) ((T_XOR_EQUAL) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 2744 ((("%") reduce 545) (("(") reduce 545) ((")") reduce 545) (("*") reduce 545) (("+") reduce 545) ((",") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) (("=") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AND_EQUAL) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_COALESCE_EQUAL) reduce 545) ((T_CONCAT_EQUAL) reduce 545) ((T_DEC) reduce 545) ((T_DIV_EQUAL) reduce 545) ((T_INC) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_MINUS_EQUAL) reduce 545) ((T_MOD_EQUAL) reduce 545) ((T_MUL_EQUAL) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_OR_EQUAL) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_PLUS_EQUAL) reduce 545) ((T_POW) reduce 545) ((T_POW_EQUAL) reduce 545) ((T_SL) reduce 545) ((T_SL_EQUAL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) ((T_SR_EQUAL) reduce 545) ((T_XOR_EQUAL) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 2745 ((("%") reduce 522) (("(") reduce 522) ((")") reduce 522) (("*") reduce 522) (("+") reduce 522) ((",") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) (("<") reduce 522) (("=") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AND_EQUAL) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_COALESCE_EQUAL) reduce 522) ((T_CONCAT_EQUAL) reduce 522) ((T_DEC) reduce 522) ((T_DIV_EQUAL) reduce 522) ((T_INC) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_MINUS_EQUAL) reduce 522) ((T_MOD_EQUAL) reduce 522) ((T_MUL_EQUAL) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_OR_EQUAL) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_PLUS_EQUAL) reduce 522) ((T_POW) reduce 522) ((T_POW_EQUAL) reduce 522) ((T_SL) reduce 522) ((T_SL_EQUAL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) ((T_SR_EQUAL) reduce 522) ((T_XOR_EQUAL) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 2746 ((("%") reduce 528) (("(") shift) ((")") reduce 528) (("*") reduce 528) (("+") reduce 528) ((",") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) (("<") reduce 528) (("=") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AND_EQUAL) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_COALESCE_EQUAL) reduce 528) ((T_CONCAT_EQUAL) reduce 528) ((T_DEC) reduce 528) ((T_DIV_EQUAL) reduce 528) ((T_INC) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_MINUS_EQUAL) reduce 528) ((T_MOD_EQUAL) reduce 528) ((T_MUL_EQUAL) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_OR_EQUAL) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_PLUS_EQUAL) reduce 528) ((T_POW) reduce 528) ((T_POW_EQUAL) reduce 528) ((T_SL) reduce 528) ((T_SL_EQUAL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) ((T_SR_EQUAL) reduce 528) ((T_XOR_EQUAL) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 2747 ((("%") reduce 523) (("(") reduce 523) ((")") reduce 523) (("*") reduce 523) (("+") reduce 523) ((",") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) (("<") reduce 523) (("=") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AND_EQUAL) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_COALESCE_EQUAL) reduce 523) ((T_CONCAT_EQUAL) reduce 523) ((T_DEC) reduce 523) ((T_DIV_EQUAL) reduce 523) ((T_INC) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_MINUS_EQUAL) reduce 523) ((T_MOD_EQUAL) reduce 523) ((T_MUL_EQUAL) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_OR_EQUAL) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_PLUS_EQUAL) reduce 523) ((T_POW) reduce 523) ((T_POW_EQUAL) reduce 523) ((T_SL) reduce 523) ((T_SL_EQUAL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) ((T_SR_EQUAL) reduce 523) ((T_XOR_EQUAL) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 2750 ((("(") reduce 529) ((")") reduce 529) ((",") reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) (("[") reduce 529) (("{") reduce 529)) 2753 ((("(") reduce 516) ((")") reduce 525) ((",") reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) (("[") reduce 525) (("{") reduce 525)) 2755 ((("(") reduce 524) ((")") reduce 524) ((",") reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) (("[") reduce 524) (("{") reduce 524)) 2757 ((("(") reduce 519) ((")") reduce 519) ((",") reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) (("[") reduce 519) (("{") reduce 519)) 2758 (((")") reduce 526) ((",") reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) (("[") reduce 526) (("{") reduce 526)) 2759 (((")") reduce 554) ((",") reduce 554) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) (("[") reduce 510) (("{") reduce 510)) 2763 ((("(") reduce 543) ((")") reduce 533) ((",") reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) (("[") reduce 533) (("{") reduce 533)) 2765 ((("(") reduce 468) ((")") reduce 468) ((",") reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) (("[") reduce 468) (("{") reduce 468)) 2766 ((("(") reduce 288) ((")") reduce 288) ((",") reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) (("[") reduce 288) (("{") reduce 288)) 2770 ((("(") reduce 289) ((")") reduce 289) ((",") reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) (("[") reduce 289) (("{") reduce 289)) 2771 ((("(") reduce 290) ((")") reduce 290) ((",") reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) (("[") reduce 290) (("{") reduce 290)) 2772 ((("(") reduce 465) ((")") reduce 465) ((",") reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) (("[") reduce 465) (("{") reduce 465)) 2775 ((("(") reduce 543) ((")") reduce 532) ((",") reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) (("[") reduce 532) (("{") reduce 532)) 2776 ((("(") reduce 467) ((")") reduce 467) ((",") reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) (("[") reduce 467) (("{") reduce 467)) 2777 ((("(") reduce 469) ((")") reduce 469) ((",") reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) (("[") reduce 469) (("{") reduce 469)) 2783 ((("(") reduce 521) ((")") reduce 521) ((",") reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) (("[") reduce 521) (("{") reduce 521)) 2785 ((("(") reduce 520) ((")") reduce 520) ((",") reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) (("[") reduce 520) (("{") reduce 520)) 2786 ((("(") reduce 544) ((")") reduce 544) ((",") reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) (("[") reduce 544) (("{") reduce 544)) 2787 ((("(") shift) ((")") reduce 527) ((",") reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) (("[") reduce 527) (("{") reduce 527)) 2788 ((("(") reduce 546) ((")") reduce 546) ((",") reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) (("[") reduce 546) (("{") reduce 546)) 2791 ((("(") reduce 545) ((")") reduce 545) ((",") reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) (("[") reduce 545) (("{") reduce 545)) 2792 ((("(") reduce 522) ((")") reduce 522) ((",") reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) (("[") reduce 522) (("{") reduce 522)) 2793 ((("(") shift) ((")") reduce 528) ((",") reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) (("[") reduce 528) (("{") reduce 528)) 2794 ((("(") reduce 523) ((")") reduce 523) ((",") reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) (("[") reduce 523) (("{") reduce 523)) 2795 ((("(") reduce 466) ((")") reduce 466) ((",") reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) (("[") reduce 466) (("{") reduce 466)) 2796 ((("(") reduce 531) ((")") reduce 531) ((",") reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) (("[") reduce 531) (("{") reduce 531)) 2799 ((("(") reduce 530) ((")") reduce 530) ((",") reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) (("[") reduce 530) (("{") reduce 530)) 2801 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) (("+") shift) (("-") shift) (("@") shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_STRING_VARNAME) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("~") shift)) 2802 (((T_CURLY_OPEN) shift) ((T_DOLLAR_OPEN_CURLY_BRACES) shift) ((T_VARIABLE) shift) (("`") reduce 478)) 2803 (((T_CURLY_OPEN) reduce 563) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 563) ((T_ENCAPSED_AND_WHITESPACE) reduce 563) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_VARIABLE) reduce 563) (("[") shift) (("`") reduce 563)) 2804 ((("`") shift)) 2805 (((T_CURLY_OPEN) shift) ((T_DOLLAR_OPEN_CURLY_BRACES) shift) ((T_ENCAPSED_AND_WHITESPACE) shift) ((T_VARIABLE) shift) (("`") reduce 479)) 2806 (((T_CURLY_OPEN) reduce 561) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 561) ((T_ENCAPSED_AND_WHITESPACE) reduce 561) ((T_VARIABLE) reduce 561) (("`") reduce 561)) 2807 (((T_CURLY_OPEN) reduce 560) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 560) ((T_ENCAPSED_AND_WHITESPACE) reduce 560) ((T_VARIABLE) reduce 560) (("`") reduce 560)) 2808 (((T_CURLY_OPEN) reduce 559) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 559) ((T_ENCAPSED_AND_WHITESPACE) reduce 559) ((T_VARIABLE) reduce 559) (("`") reduce 559)) 2809 ((("%") reduce 438) ((")") reduce 438) (("*") reduce 438) (("+") reduce 438) ((",") reduce 438) (("-") reduce 438) ((".") reduce 438) (("/") reduce 438) (("<") reduce 438) ((">") reduce 438) (("?") reduce 438) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_BOOLEAN_AND) reduce 438) ((T_BOOLEAN_OR) reduce 438) ((T_COALESCE) reduce 438) ((T_INSTANCEOF) reduce 438) ((T_IS_EQUAL) reduce 438) ((T_IS_GREATER_OR_EQUAL) reduce 438) ((T_IS_IDENTICAL) reduce 438) ((T_IS_NOT_EQUAL) reduce 438) ((T_IS_NOT_IDENTICAL) reduce 438) ((T_IS_SMALLER_OR_EQUAL) reduce 438) ((T_LOGICAL_AND) reduce 438) ((T_LOGICAL_OR) reduce 438) ((T_LOGICAL_XOR) reduce 438) ((T_POW) reduce 438) ((T_SL) reduce 438) ((T_SPACESHIP) reduce 438) ((T_SR) reduce 438) (("^") reduce 438) (("|") reduce 438)) 2812 ((("-") shift) ((T_NUM_STRING) shift) ((T_STRING) shift) ((T_VARIABLE) shift)) 2813 (((T_NUM_STRING) shift)) 2814 ((("]") reduce 572)) 2815 ((("]") reduce 571)) 2816 ((("]") reduce 574)) 2818 (((T_CURLY_OPEN) reduce 564) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 564) ((T_ENCAPSED_AND_WHITESPACE) reduce 564) ((T_VARIABLE) reduce 564) (("`") reduce 564)) 2819 ((("]") reduce 573)) 2820 (((T_CURLY_OPEN) reduce 565) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 565) ((T_ENCAPSED_AND_WHITESPACE) reduce 565) ((T_VARIABLE) reduce 565) (("`") reduce 565)) 2821 (((T_CURLY_OPEN) reduce 566) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 566) ((T_ENCAPSED_AND_WHITESPACE) reduce 566) ((T_VARIABLE) reduce 566) (("`") reduce 566)) 2822 (((T_CURLY_OPEN) reduce 562) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 562) ((T_ENCAPSED_AND_WHITESPACE) reduce 562) ((T_VARIABLE) reduce 562) (("`") reduce 562)) 2823 ((("[") shift) (("}") shift)) 2825 (((T_CURLY_OPEN) reduce 567) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 567) ((T_ENCAPSED_AND_WHITESPACE) reduce 567) ((T_VARIABLE) reduce 567) (("`") reduce 567)) 2827 (((T_CURLY_OPEN) reduce 568) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 568) ((T_ENCAPSED_AND_WHITESPACE) reduce 568) ((T_VARIABLE) reduce 568) (("`") reduce 568)) 2828 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") shift) (("^") shift) (("|") shift)) 2829 ((("}") shift)) 2830 (((T_CURLY_OPEN) reduce 569) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 569) ((T_ENCAPSED_AND_WHITESPACE) reduce 569) ((T_VARIABLE) reduce 569) (("`") reduce 569)) 2833 ((("(") reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) (("[") reduce 529) (("{") reduce 529) (("}") reduce 529)) 2836 ((("(") reduce 516) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) (("[") reduce 525) (("{") reduce 525) (("}") reduce 525)) 2838 ((("(") reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) (("[") reduce 524) (("{") reduce 524) (("}") reduce 524)) 2840 ((("(") reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) (("[") reduce 519) (("{") reduce 519) (("}") reduce 519)) 2841 (((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) (("[") reduce 526) (("{") reduce 526) (("}") reduce 526)) 2842 (((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) (("[") reduce 510) (("{") reduce 510) (("}") shift)) 2846 ((("(") reduce 543) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) (("[") reduce 533) (("{") reduce 533) (("}") reduce 533)) 2848 ((("(") reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) (("[") reduce 468) (("{") reduce 468) (("}") reduce 468)) 2849 ((("(") reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) (("[") reduce 288) (("{") reduce 288) (("}") reduce 288)) 2853 ((("(") reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) (("[") reduce 289) (("{") reduce 289) (("}") reduce 289)) 2854 ((("(") reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) (("[") reduce 290) (("{") reduce 290) (("}") reduce 290)) 2855 (((T_CURLY_OPEN) reduce 570) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 570) ((T_ENCAPSED_AND_WHITESPACE) reduce 570) ((T_VARIABLE) reduce 570) (("`") reduce 570)) 2856 ((("(") reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) (("[") reduce 465) (("{") reduce 465) (("}") reduce 465)) 2859 ((("(") reduce 543) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) (("[") reduce 532) (("{") reduce 532) (("}") reduce 532)) 2860 ((("(") reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) (("[") reduce 467) (("{") reduce 467) (("}") reduce 467)) 2861 ((("(") reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) (("[") reduce 469) (("{") reduce 469) (("}") reduce 469)) 2867 ((("(") reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) (("[") reduce 521) (("{") reduce 521) (("}") reduce 521)) 2869 ((("(") reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) (("[") reduce 520) (("{") reduce 520) (("}") reduce 520)) 2870 ((("(") reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) (("[") reduce 544) (("{") reduce 544) (("}") reduce 544)) 2871 ((("(") shift) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) (("[") reduce 527) (("{") reduce 527) (("}") reduce 527)) 2872 ((("(") reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) (("[") reduce 546) (("{") reduce 546) (("}") reduce 546)) 2875 ((("(") reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) (("[") reduce 545) (("{") reduce 545) (("}") reduce 545)) 2876 ((("(") reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) (("[") reduce 522) (("{") reduce 522) (("}") reduce 522)) 2877 ((("(") shift) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) (("[") reduce 528) (("{") reduce 528) (("}") reduce 528)) 2878 ((("(") reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) (("[") reduce 523) (("{") reduce 523) (("}") reduce 523)) 2879 ((("(") reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) (("[") reduce 466) (("{") reduce 466) (("}") reduce 466)) 2880 ((("(") reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) (("[") reduce 531) (("{") reduce 531) (("}") reduce 531)) 2883 ((("(") reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) (("[") reduce 530) (("{") reduce 530) (("}") reduce 530)) 2885 ((("%") reduce 483) (("(") reduce 483) ((")") reduce 483) (("*") reduce 483) (("+") reduce 483) ((",") reduce 483) (("-") reduce 483) ((".") reduce 483) (("/") reduce 483) (("<") reduce 483) (("=") shift) ((">") reduce 483) (("?") reduce 483) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_BOOLEAN_AND) reduce 483) ((T_BOOLEAN_OR) reduce 483) ((T_COALESCE) reduce 483) ((T_INSTANCEOF) reduce 483) ((T_IS_EQUAL) reduce 483) ((T_IS_GREATER_OR_EQUAL) reduce 483) ((T_IS_IDENTICAL) reduce 483) ((T_IS_NOT_EQUAL) reduce 483) ((T_IS_NOT_IDENTICAL) reduce 483) ((T_IS_SMALLER_OR_EQUAL) reduce 483) ((T_LOGICAL_AND) reduce 483) ((T_LOGICAL_OR) reduce 483) ((T_LOGICAL_XOR) reduce 483) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 483) ((T_OBJECT_OPERATOR) reduce 483) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 483) ((T_POW) reduce 483) ((T_SL) reduce 483) ((T_SPACESHIP) reduce 483) ((T_SR) reduce 483) (("[") reduce 483) (("^") reduce 483) (("{") reduce 483) (("|") reduce 483)) 2887 ((("%") shift) ((")") reduce 369) (("*") shift) (("+") shift) ((",") reduce 369) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 369) ((T_LOGICAL_OR) reduce 369) ((T_LOGICAL_XOR) reduce 369) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 2888 ((("%") shift) ((")") reduce 443) (("*") shift) (("+") shift) ((",") reduce 443) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 443) ((T_LOGICAL_OR) reduce 443) ((T_LOGICAL_XOR) reduce 443) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 2891 ((("%") shift) ((")") reduce 442) (("*") shift) (("+") shift) ((",") reduce 442) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 442) ((T_LOGICAL_OR) reduce 442) ((T_LOGICAL_XOR) reduce 442) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 2892 ((("%") reduce 434) ((")") reduce 434) (("*") reduce 434) (("+") reduce 434) ((",") reduce 434) (("-") reduce 434) ((".") reduce 434) (("/") reduce 434) (("<") reduce 434) ((">") reduce 434) (("?") reduce 434) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_BOOLEAN_AND) reduce 434) ((T_BOOLEAN_OR) reduce 434) ((T_COALESCE) reduce 434) ((T_INSTANCEOF) reduce 434) ((T_IS_EQUAL) reduce 434) ((T_IS_GREATER_OR_EQUAL) reduce 434) ((T_IS_IDENTICAL) reduce 434) ((T_IS_NOT_EQUAL) reduce 434) ((T_IS_NOT_IDENTICAL) reduce 434) ((T_IS_SMALLER_OR_EQUAL) reduce 434) ((T_LOGICAL_AND) reduce 434) ((T_LOGICAL_OR) reduce 434) ((T_LOGICAL_XOR) reduce 434) ((T_POW) shift) ((T_SL) reduce 434) ((T_SPACESHIP) reduce 434) ((T_SR) reduce 434) (("^") reduce 434) (("|") reduce 434)) 2893 ((("%") shift) ((")") reduce 444) (("*") shift) (("+") shift) ((",") reduce 444) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 2894 ((("%") reduce 430) ((")") reduce 430) (("*") reduce 430) (("+") reduce 430) ((",") reduce 430) (("-") reduce 430) ((".") reduce 430) (("/") reduce 430) (("<") reduce 430) ((">") reduce 430) (("?") reduce 430) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_BOOLEAN_AND) reduce 430) ((T_BOOLEAN_OR) reduce 430) ((T_COALESCE) reduce 430) ((T_INSTANCEOF) reduce 430) ((T_IS_EQUAL) reduce 430) ((T_IS_GREATER_OR_EQUAL) reduce 430) ((T_IS_IDENTICAL) reduce 430) ((T_IS_NOT_EQUAL) reduce 430) ((T_IS_NOT_IDENTICAL) reduce 430) ((T_IS_SMALLER_OR_EQUAL) reduce 430) ((T_LOGICAL_AND) reduce 430) ((T_LOGICAL_OR) reduce 430) ((T_LOGICAL_XOR) reduce 430) ((T_POW) shift) ((T_SL) reduce 430) ((T_SPACESHIP) reduce 430) ((T_SR) reduce 430) (("^") reduce 430) (("|") reduce 430)) 2895 ((("%") reduce 447) ((")") reduce 447) (("*") reduce 447) (("+") reduce 447) ((",") reduce 447) (("-") reduce 447) ((".") reduce 447) (("/") reduce 447) (("<") reduce 447) ((">") reduce 447) (("?") reduce 447) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_BOOLEAN_AND) reduce 447) ((T_BOOLEAN_OR) reduce 447) ((T_COALESCE) reduce 447) ((T_INSTANCEOF) reduce 447) ((T_IS_EQUAL) reduce 447) ((T_IS_GREATER_OR_EQUAL) reduce 447) ((T_IS_IDENTICAL) reduce 447) ((T_IS_NOT_EQUAL) reduce 447) ((T_IS_NOT_IDENTICAL) reduce 447) ((T_IS_SMALLER_OR_EQUAL) reduce 447) ((T_LOGICAL_AND) reduce 447) ((T_LOGICAL_OR) reduce 447) ((T_LOGICAL_XOR) reduce 447) ((T_POW) reduce 447) ((T_SL) reduce 447) ((T_SPACESHIP) reduce 447) ((T_SR) reduce 447) (("^") reduce 447) (("|") reduce 447)) 2898 (((T_CURLY_OPEN) shift) ((T_DOLLAR_OPEN_CURLY_BRACES) shift) ((T_END_HEREDOC) shift) ((T_VARIABLE) shift)) 2899 ((("%") reduce 489) ((")") reduce 489) (("*") reduce 489) (("+") reduce 489) ((",") reduce 489) (("-") reduce 489) ((".") reduce 489) (("/") reduce 489) (("<") reduce 489) ((">") reduce 489) (("?") reduce 489) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_BOOLEAN_AND) reduce 489) ((T_BOOLEAN_OR) reduce 489) ((T_COALESCE) reduce 489) ((T_INSTANCEOF) reduce 489) ((T_IS_EQUAL) reduce 489) ((T_IS_GREATER_OR_EQUAL) reduce 489) ((T_IS_IDENTICAL) reduce 489) ((T_IS_NOT_EQUAL) reduce 489) ((T_IS_NOT_IDENTICAL) reduce 489) ((T_IS_SMALLER_OR_EQUAL) reduce 489) ((T_LOGICAL_AND) reduce 489) ((T_LOGICAL_OR) reduce 489) ((T_LOGICAL_XOR) reduce 489) ((T_POW) reduce 489) ((T_SL) reduce 489) ((T_SPACESHIP) reduce 489) ((T_SR) reduce 489) (("^") reduce 489) (("|") reduce 489)) 2900 (((T_CURLY_OPEN) reduce 563) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 563) ((T_ENCAPSED_AND_WHITESPACE) reduce 563) ((T_END_HEREDOC) reduce 563) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_VARIABLE) reduce 563) (("[") shift)) 2902 (((T_CURLY_OPEN) reduce 561) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 561) ((T_ENCAPSED_AND_WHITESPACE) reduce 561) ((T_END_HEREDOC) reduce 561) ((T_VARIABLE) reduce 561)) 2903 (((T_CURLY_OPEN) reduce 560) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 560) ((T_ENCAPSED_AND_WHITESPACE) reduce 560) ((T_END_HEREDOC) reduce 560) ((T_VARIABLE) reduce 560)) 2904 ((("%") reduce 490) ((")") reduce 490) (("*") reduce 490) (("+") reduce 490) ((",") reduce 490) (("-") reduce 490) ((".") reduce 490) (("/") reduce 490) (("<") reduce 490) ((">") reduce 490) (("?") reduce 490) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_BOOLEAN_AND) reduce 490) ((T_BOOLEAN_OR) reduce 490) ((T_COALESCE) reduce 490) ((T_INSTANCEOF) reduce 490) ((T_IS_EQUAL) reduce 490) ((T_IS_GREATER_OR_EQUAL) reduce 490) ((T_IS_IDENTICAL) reduce 490) ((T_IS_NOT_EQUAL) reduce 490) ((T_IS_NOT_IDENTICAL) reduce 490) ((T_IS_SMALLER_OR_EQUAL) reduce 490) ((T_LOGICAL_AND) reduce 490) ((T_LOGICAL_OR) reduce 490) ((T_LOGICAL_XOR) reduce 490) ((T_POW) reduce 490) ((T_SL) reduce 490) ((T_SPACESHIP) reduce 490) ((T_SR) reduce 490) (("^") reduce 490) (("|") reduce 490)) 2905 (((T_CURLY_OPEN) reduce 559) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 559) ((T_ENCAPSED_AND_WHITESPACE) reduce 559) ((T_END_HEREDOC) reduce 559) ((T_VARIABLE) reduce 559)) 2910 (((T_CURLY_OPEN) reduce 564) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 564) ((T_ENCAPSED_AND_WHITESPACE) reduce 564) ((T_END_HEREDOC) reduce 564) ((T_VARIABLE) reduce 564)) 2911 (((T_CURLY_OPEN) reduce 565) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 565) ((T_ENCAPSED_AND_WHITESPACE) reduce 565) ((T_END_HEREDOC) reduce 565) ((T_VARIABLE) reduce 565)) 2912 (((T_CURLY_OPEN) reduce 566) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 566) ((T_ENCAPSED_AND_WHITESPACE) reduce 566) ((T_END_HEREDOC) reduce 566) ((T_VARIABLE) reduce 566)) 2913 ((("%") reduce 488) ((")") reduce 488) (("*") reduce 488) (("+") reduce 488) ((",") reduce 488) (("-") reduce 488) ((".") reduce 488) (("/") reduce 488) (("<") reduce 488) ((">") reduce 488) (("?") reduce 488) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_BOOLEAN_AND) reduce 488) ((T_BOOLEAN_OR) reduce 488) ((T_COALESCE) reduce 488) ((T_INSTANCEOF) reduce 488) ((T_IS_EQUAL) reduce 488) ((T_IS_GREATER_OR_EQUAL) reduce 488) ((T_IS_IDENTICAL) reduce 488) ((T_IS_NOT_EQUAL) reduce 488) ((T_IS_NOT_IDENTICAL) reduce 488) ((T_IS_SMALLER_OR_EQUAL) reduce 488) ((T_LOGICAL_AND) reduce 488) ((T_LOGICAL_OR) reduce 488) ((T_LOGICAL_XOR) reduce 488) ((T_POW) reduce 488) ((T_SL) reduce 488) ((T_SPACESHIP) reduce 488) ((T_SR) reduce 488) (("^") reduce 488) (("|") reduce 488)) 2914 (((T_CURLY_OPEN) reduce 562) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 562) ((T_ENCAPSED_AND_WHITESPACE) reduce 562) ((T_END_HEREDOC) reduce 562) ((T_VARIABLE) reduce 562)) 2917 (((T_CURLY_OPEN) reduce 567) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 567) ((T_ENCAPSED_AND_WHITESPACE) reduce 567) ((T_END_HEREDOC) reduce 567) ((T_VARIABLE) reduce 567)) 2919 (((T_CURLY_OPEN) reduce 568) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 568) ((T_ENCAPSED_AND_WHITESPACE) reduce 568) ((T_END_HEREDOC) reduce 568) ((T_VARIABLE) reduce 568)) 2922 (((T_CURLY_OPEN) reduce 569) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 569) ((T_ENCAPSED_AND_WHITESPACE) reduce 569) ((T_END_HEREDOC) reduce 569) ((T_VARIABLE) reduce 569)) 2924 (((T_CURLY_OPEN) reduce 570) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 570) ((T_ENCAPSED_AND_WHITESPACE) reduce 570) ((T_END_HEREDOC) reduce 570) ((T_VARIABLE) reduce 570)) 2925 ((("%") shift) ((")") reduce 581) (("*") shift) (("+") shift) ((",") reduce 581) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 2926 ((("%") shift) ((")") reduce 580) (("*") shift) (("+") shift) ((",") reduce 580) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 2927 ((("%") reduce 466) (("(") reduce 466) ((")") reduce 466) (("*") reduce 466) (("+") reduce 466) ((",") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) (("<") reduce 466) (("=") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AND_EQUAL) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_COALESCE_EQUAL) reduce 466) ((T_CONCAT_EQUAL) reduce 466) ((T_DEC) reduce 466) ((T_DIV_EQUAL) reduce 466) ((T_INC) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_MINUS_EQUAL) reduce 466) ((T_MOD_EQUAL) reduce 466) ((T_MUL_EQUAL) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_OR_EQUAL) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_PLUS_EQUAL) reduce 466) ((T_POW) reduce 466) ((T_POW_EQUAL) reduce 466) ((T_SL) reduce 466) ((T_SL_EQUAL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) ((T_SR_EQUAL) reduce 466) ((T_XOR_EQUAL) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 2928 ((("%") shift) ((")") reduce 439) (("*") shift) (("+") shift) ((",") reduce 439) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 439) ((T_LOGICAL_OR) reduce 439) ((T_LOGICAL_XOR) reduce 439) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 2929 ((("%") reduce 432) ((")") reduce 432) (("*") reduce 432) (("+") reduce 432) ((",") reduce 432) (("-") reduce 432) ((".") reduce 432) (("/") reduce 432) (("<") reduce 432) ((">") reduce 432) (("?") reduce 432) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_BOOLEAN_AND) reduce 432) ((T_BOOLEAN_OR) reduce 432) ((T_COALESCE) reduce 432) ((T_INSTANCEOF) reduce 432) ((T_IS_EQUAL) reduce 432) ((T_IS_GREATER_OR_EQUAL) reduce 432) ((T_IS_IDENTICAL) reduce 432) ((T_IS_NOT_EQUAL) reduce 432) ((T_IS_NOT_IDENTICAL) reduce 432) ((T_IS_SMALLER_OR_EQUAL) reduce 432) ((T_LOGICAL_AND) reduce 432) ((T_LOGICAL_OR) reduce 432) ((T_LOGICAL_XOR) reduce 432) ((T_POW) shift) ((T_SL) reduce 432) ((T_SPACESHIP) reduce 432) ((T_SR) reduce 432) (("^") reduce 432) (("|") reduce 432)) 2933 ((("%") reduce 93) (("(") reduce 93) ((")") reduce 93) (("*") reduce 93) (("+") reduce 93) ((",") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93)) 2934 ((("%") reduce 92) (("(") reduce 92) ((")") reduce 92) (("*") reduce 92) (("+") reduce 92) ((",") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92)) 2935 ((("%") reduce 94) (("(") reduce 94) ((")") reduce 94) (("*") reduce 94) (("+") reduce 94) ((",") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94)) 2936 (((T_ABSTRACT) reduce 196) ((T_CLASS) reduce 196) ((T_FINAL) reduce 196) ((T_READONLY) reduce 196)) 2937 ((("%") reduce 470) (("(") reduce 470) ((")") reduce 470) (("*") reduce 470) (("+") reduce 470) ((",") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470)) 2938 ((("%") reduce 91) (("(") reduce 91) ((")") reduce 91) (("*") reduce 91) (("+") reduce 91) ((",") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91)) 2940 ((("%") reduce 365) ((")") reduce 365) (("*") reduce 365) (("+") reduce 365) ((",") reduce 365) (("-") reduce 365) ((".") reduce 365) (("/") reduce 365) (("<") reduce 365) ((">") reduce 365) (("?") reduce 365) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_BOOLEAN_AND) reduce 365) ((T_BOOLEAN_OR) reduce 365) ((T_COALESCE) reduce 365) ((T_INSTANCEOF) reduce 365) ((T_IS_EQUAL) reduce 365) ((T_IS_GREATER_OR_EQUAL) reduce 365) ((T_IS_IDENTICAL) reduce 365) ((T_IS_NOT_EQUAL) reduce 365) ((T_IS_NOT_IDENTICAL) reduce 365) ((T_IS_SMALLER_OR_EQUAL) reduce 365) ((T_LOGICAL_AND) reduce 365) ((T_LOGICAL_OR) reduce 365) ((T_LOGICAL_XOR) reduce 365) ((T_POW) reduce 365) ((T_SL) reduce 365) ((T_SPACESHIP) reduce 365) ((T_SR) reduce 365) (("^") reduce 365) (("|") reduce 365)) 2941 (((T_ABSTRACT) shift) ((T_CLASS) reduce 193) ((T_FINAL) shift) ((T_READONLY) shift)) 2942 (((T_CLASS) shift)) 2943 (((T_ABSTRACT) reduce 100) ((T_ATTRIBUTE) reduce 100) ((T_CLASS) reduce 100) ((T_FINAL) reduce 100) ((T_READONLY) reduce 100)) 2944 (((T_ABSTRACT) shift) ((T_ATTRIBUTE) shift) ((T_CLASS) reduce 192) ((T_FINAL) shift) ((T_READONLY) shift)) 2945 (((T_ABSTRACT) reduce 190) ((T_CLASS) reduce 190) ((T_FINAL) reduce 190) ((T_READONLY) reduce 190)) 2946 ((("%") reduce 472) (("(") reduce 472) ((")") reduce 472) (("*") reduce 472) (("+") reduce 472) ((",") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472)) 2947 ((("%") reduce 480) (("(") shift) ((")") reduce 480) (("*") reduce 480) (("+") reduce 480) ((",") reduce 480) (("-") reduce 480) ((".") reduce 480) (("/") reduce 480) (("<") reduce 480) ((">") reduce 480) (("?") reduce 480) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_BOOLEAN_AND) reduce 480) ((T_BOOLEAN_OR) reduce 480) ((T_COALESCE) reduce 480) ((T_INSTANCEOF) reduce 480) ((T_IS_EQUAL) reduce 480) ((T_IS_GREATER_OR_EQUAL) reduce 480) ((T_IS_IDENTICAL) reduce 480) ((T_IS_NOT_EQUAL) reduce 480) ((T_IS_NOT_IDENTICAL) reduce 480) ((T_IS_SMALLER_OR_EQUAL) reduce 480) ((T_LOGICAL_AND) reduce 480) ((T_LOGICAL_OR) reduce 480) ((T_LOGICAL_XOR) reduce 480) ((T_POW) reduce 480) ((T_SL) reduce 480) ((T_SPACESHIP) reduce 480) ((T_SR) reduce 480) (("^") reduce 480) (("|") reduce 480)) 2948 ((("%") reduce 471) (("(") reduce 471) ((")") reduce 471) (("*") reduce 471) (("+") reduce 471) ((",") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471)) 2949 ((("%") reduce 473) (("(") reduce 473) ((")") reduce 473) (("*") reduce 473) (("+") reduce 473) ((",") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 2950 ((("%") reduce 534) (("(") reduce 534) ((")") reduce 534) (("*") reduce 534) (("+") reduce 534) ((",") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 2957 ((("%") reduce 536) (("(") reduce 536) ((")") reduce 536) (("*") reduce 536) (("+") reduce 536) ((",") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 2959 ((("%") reduce 535) (("(") reduce 535) ((")") reduce 535) (("*") reduce 535) (("+") reduce 535) ((",") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 2960 ((("%") reduce 540) (("(") reduce 540) ((")") reduce 540) (("*") reduce 540) (("+") reduce 540) ((",") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 2962 ((("%") reduce 537) (("(") reduce 537) ((")") reduce 537) (("*") reduce 537) (("+") reduce 537) ((",") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 2967 ((("%") reduce 538) (("(") reduce 538) ((")") reduce 538) (("*") reduce 538) (("+") reduce 538) ((",") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 2969 ((("%") reduce 481) ((")") reduce 481) (("*") reduce 481) (("+") reduce 481) ((",") reduce 481) (("-") reduce 481) ((".") reduce 481) (("/") reduce 481) (("<") reduce 481) ((">") reduce 481) (("?") reduce 481) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_BOOLEAN_AND) reduce 481) ((T_BOOLEAN_OR) reduce 481) ((T_COALESCE) reduce 481) ((T_INSTANCEOF) reduce 481) ((T_IS_EQUAL) reduce 481) ((T_IS_GREATER_OR_EQUAL) reduce 481) ((T_IS_IDENTICAL) reduce 481) ((T_IS_NOT_EQUAL) reduce 481) ((T_IS_NOT_IDENTICAL) reduce 481) ((T_IS_SMALLER_OR_EQUAL) reduce 481) ((T_LOGICAL_AND) reduce 481) ((T_LOGICAL_OR) reduce 481) ((T_LOGICAL_XOR) reduce 481) ((T_POW) reduce 481) ((T_SL) reduce 481) ((T_SPACESHIP) reduce 481) ((T_SR) reduce 481) (("^") reduce 481) (("|") reduce 481)) 2970 ((("%") reduce 364) ((")") reduce 364) (("*") reduce 364) (("+") reduce 364) ((",") reduce 364) (("-") reduce 364) ((".") reduce 364) (("/") reduce 364) (("<") reduce 364) ((">") reduce 364) (("?") reduce 364) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_BOOLEAN_AND) reduce 364) ((T_BOOLEAN_OR) reduce 364) ((T_COALESCE) reduce 364) ((T_INSTANCEOF) reduce 364) ((T_IS_EQUAL) reduce 364) ((T_IS_GREATER_OR_EQUAL) reduce 364) ((T_IS_IDENTICAL) reduce 364) ((T_IS_NOT_EQUAL) reduce 364) ((T_IS_NOT_IDENTICAL) reduce 364) ((T_IS_SMALLER_OR_EQUAL) reduce 364) ((T_LOGICAL_AND) reduce 364) ((T_LOGICAL_OR) reduce 364) ((T_LOGICAL_XOR) reduce 364) ((T_POW) reduce 364) ((T_SL) reduce 364) ((T_SPACESHIP) reduce 364) ((T_SR) reduce 364) (("^") reduce 364) (("|") reduce 364)) 2971 ((("%") reduce 288) ((")") reduce 288) (("*") reduce 288) (("+") reduce 288) ((",") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("^") reduce 288) (("|") reduce 288)) 2975 ((("%") reduce 289) ((")") reduce 289) (("*") reduce 289) (("+") reduce 289) ((",") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("^") reduce 289) (("|") reduce 289)) 2976 ((("%") reduce 290) ((")") reduce 290) (("*") reduce 290) (("+") reduce 290) ((",") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("^") reduce 290) (("|") reduce 290)) 2978 ((("%") reduce 539) (("(") reduce 539) ((")") reduce 539) (("*") reduce 539) (("+") reduce 539) ((",") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 2979 ((("%") reduce 366) ((")") reduce 366) (("*") reduce 366) (("+") reduce 366) ((",") reduce 366) (("-") reduce 366) ((".") reduce 366) (("/") reduce 366) (("<") reduce 366) ((">") reduce 366) (("?") reduce 366) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_BOOLEAN_AND) reduce 366) ((T_BOOLEAN_OR) reduce 366) ((T_COALESCE) reduce 366) ((T_INSTANCEOF) reduce 366) ((T_IS_EQUAL) reduce 366) ((T_IS_GREATER_OR_EQUAL) reduce 366) ((T_IS_IDENTICAL) reduce 366) ((T_IS_NOT_EQUAL) reduce 366) ((T_IS_NOT_IDENTICAL) reduce 366) ((T_IS_SMALLER_OR_EQUAL) reduce 366) ((T_LOGICAL_AND) reduce 366) ((T_LOGICAL_OR) reduce 366) ((T_LOGICAL_XOR) reduce 366) ((T_POW) reduce 366) ((T_SL) reduce 366) ((T_SPACESHIP) reduce 366) ((T_SR) reduce 366) (("^") reduce 366) (("|") reduce 366)) 2980 (((T_ABSTRACT) reduce 101) ((T_ATTRIBUTE) reduce 101) ((T_CLASS) reduce 101) ((T_FINAL) reduce 101) ((T_READONLY) reduce 101)) 2981 ((("(") shift) ((T_EXTENDS) reduce 480) ((T_IMPLEMENTS) reduce 480) (("{") reduce 480)) 2983 (((T_EXTENDS) reduce 481) ((T_IMPLEMENTS) reduce 481) (("{") reduce 481)) 2984 (((T_EXTENDS) shift) ((T_IMPLEMENTS) reduce 205) (("{") reduce 205)) 2986 (((T_IMPLEMENTS) shift) (("{") reduce 209)) 2988 ((("{") reduce 454)) 2990 (((T_ABSTRACT) reduce 304) ((T_ATTRIBUTE) reduce 304) ((T_CASE) reduce 304) ((T_CONST) reduce 304) ((T_FINAL) reduce 304) ((T_FUNCTION) reduce 304) ((T_PRIVATE) reduce 304) ((T_PROTECTED) reduce 304) ((T_PUBLIC) reduce 304) ((T_READONLY) reduce 304) ((T_STATIC) reduce 304) ((T_USE) reduce 304) ((T_VAR) reduce 304) (("}") reduce 304)) 2991 (((T_ABSTRACT) shift) ((T_ATTRIBUTE) shift) ((T_CASE) shift) ((T_CONST) reduce 336) ((T_FINAL) shift) ((T_FUNCTION) reduce 334) ((T_PRIVATE) shift) ((T_PROTECTED) shift) ((T_PUBLIC) shift) ((T_READONLY) shift) ((T_STATIC) shift) ((T_USE) shift) ((T_VAR) shift) (("}") shift)) 2992 ((("(") reduce 344) (("?") reduce 344) ((T_ABSTRACT) reduce 344) ((T_ARRAY) reduce 344) ((T_CALLABLE) reduce 344) ((T_CONST) reduce 344) ((T_FINAL) reduce 344) ((T_FUNCTION) reduce 344) ((T_NAME_FULLY_QUALIFIED) reduce 344) ((T_NAME_QUALIFIED) reduce 344) ((T_NAME_RELATIVE) reduce 344) ((T_PRIVATE) reduce 344) ((T_PROTECTED) reduce 344) ((T_PUBLIC) reduce 344) ((T_READONLY) reduce 344) ((T_STATIC) reduce 344) ((T_STRING) reduce 344) ((T_VARIABLE) reduce 344)) 2994 (((T_ABSTRACT) reduce 454) ((T_ARRAY) reduce 454) ((T_AS) reduce 454) ((T_BREAK) reduce 454) ((T_CALLABLE) reduce 454) ((T_CASE) reduce 454) ((T_CATCH) reduce 454) ((T_CLASS) reduce 454) ((T_CLASS_C) reduce 454) ((T_CLONE) reduce 454) ((T_CONST) reduce 454) ((T_CONTINUE) reduce 454) ((T_DECLARE) reduce 454) ((T_DEFAULT) reduce 454) ((T_DIR) reduce 454) ((T_DO) reduce 454) ((T_ECHO) reduce 454) ((T_ELSE) reduce 454) ((T_ELSEIF) reduce 454) ((T_EMPTY) reduce 454) ((T_ENDDECLARE) reduce 454) ((T_ENDFOR) reduce 454) ((T_ENDFOREACH) reduce 454) ((T_ENDIF) reduce 454) ((T_ENDSWITCH) reduce 454) ((T_ENDWHILE) reduce 454) ((T_ENUM) reduce 454) ((T_EVAL) reduce 454) ((T_EXIT) reduce 454) ((T_EXTENDS) reduce 454) ((T_FILE) reduce 454) ((T_FINAL) reduce 454) ((T_FINALLY) reduce 454) ((T_FN) reduce 454) ((T_FOR) reduce 454) ((T_FOREACH) reduce 454) ((T_FUNCTION) reduce 454) ((T_FUNC_C) reduce 454) ((T_GLOBAL) reduce 454) ((T_GOTO) reduce 454) ((T_IF) reduce 454) ((T_IMPLEMENTS) reduce 454) ((T_INCLUDE) reduce 454) ((T_INCLUDE_ONCE) reduce 454) ((T_INSTANCEOF) reduce 454) ((T_INSTEADOF) reduce 454) ((T_INTERFACE) reduce 454) ((T_ISSET) reduce 454) ((T_LINE) reduce 454) ((T_LIST) reduce 454) ((T_LOGICAL_AND) reduce 454) ((T_LOGICAL_OR) reduce 454) ((T_LOGICAL_XOR) reduce 454) ((T_MATCH) reduce 454) ((T_METHOD_C) reduce 454) ((T_NAMESPACE) reduce 454) ((T_NEW) reduce 454) ((T_NS_C) reduce 454) ((T_PRINT) reduce 454) ((T_PRIVATE) reduce 454) ((T_PROTECTED) reduce 454) ((T_PUBLIC) reduce 454) ((T_READONLY) reduce 454) ((T_REQUIRE) reduce 454) ((T_REQUIRE_ONCE) reduce 454) ((T_RETURN) reduce 454) ((T_STATIC) reduce 454) ((T_STRING) reduce 454) ((T_SWITCH) reduce 454) ((T_THROW) reduce 454) ((T_TRAIT) reduce 454) ((T_TRAIT_C) reduce 454) ((T_TRY) reduce 454) ((T_UNSET) reduce 454) ((T_USE) reduce 454) ((T_VAR) reduce 454) ((T_WHILE) reduce 454) ((T_YIELD) reduce 454)) 2995 ((("(") reduce 345) (("?") reduce 345) ((T_ABSTRACT) reduce 345) ((T_ARRAY) reduce 345) ((T_CALLABLE) reduce 345) ((T_CONST) reduce 345) ((T_FINAL) reduce 345) ((T_FUNCTION) reduce 345) ((T_NAME_FULLY_QUALIFIED) reduce 345) ((T_NAME_QUALIFIED) reduce 345) ((T_NAME_RELATIVE) reduce 345) ((T_PRIVATE) reduce 345) ((T_PROTECTED) reduce 345) ((T_PUBLIC) reduce 345) ((T_READONLY) reduce 345) ((T_STATIC) reduce 345) ((T_STRING) reduce 345) ((T_VARIABLE) reduce 345)) 2996 ((("(") reduce 342) (("?") reduce 342) ((T_ABSTRACT) reduce 342) ((T_ARRAY) reduce 342) ((T_CALLABLE) reduce 342) ((T_CONST) reduce 342) ((T_FINAL) reduce 342) ((T_FUNCTION) reduce 342) ((T_NAME_FULLY_QUALIFIED) reduce 342) ((T_NAME_QUALIFIED) reduce 342) ((T_NAME_RELATIVE) reduce 342) ((T_PRIVATE) reduce 342) ((T_PROTECTED) reduce 342) ((T_PUBLIC) reduce 342) ((T_READONLY) reduce 342) ((T_STATIC) reduce 342) ((T_STRING) reduce 342) ((T_VARIABLE) reduce 342)) 2997 ((("(") reduce 341) (("?") reduce 341) ((T_ABSTRACT) reduce 341) ((T_ARRAY) reduce 341) ((T_CALLABLE) reduce 341) ((T_CONST) reduce 341) ((T_FINAL) reduce 341) ((T_FUNCTION) reduce 341) ((T_NAME_FULLY_QUALIFIED) reduce 341) ((T_NAME_QUALIFIED) reduce 341) ((T_NAME_RELATIVE) reduce 341) ((T_PRIVATE) reduce 341) ((T_PROTECTED) reduce 341) ((T_PUBLIC) reduce 341) ((T_READONLY) reduce 341) ((T_STATIC) reduce 341) ((T_STRING) reduce 341) ((T_VARIABLE) reduce 341)) 2998 ((("(") reduce 340) (("?") reduce 340) ((T_ABSTRACT) reduce 340) ((T_ARRAY) reduce 340) ((T_CALLABLE) reduce 340) ((T_CONST) reduce 340) ((T_FINAL) reduce 340) ((T_FUNCTION) reduce 340) ((T_NAME_FULLY_QUALIFIED) reduce 340) ((T_NAME_QUALIFIED) reduce 340) ((T_NAME_RELATIVE) reduce 340) ((T_PRIVATE) reduce 340) ((T_PROTECTED) reduce 340) ((T_PUBLIC) reduce 340) ((T_READONLY) reduce 340) ((T_STATIC) reduce 340) ((T_STRING) reduce 340) ((T_VARIABLE) reduce 340)) 2999 ((("(") reduce 346) (("?") reduce 346) ((T_ABSTRACT) reduce 346) ((T_ARRAY) reduce 346) ((T_CALLABLE) reduce 346) ((T_CONST) reduce 346) ((T_FINAL) reduce 346) ((T_FUNCTION) reduce 346) ((T_NAME_FULLY_QUALIFIED) reduce 346) ((T_NAME_QUALIFIED) reduce 346) ((T_NAME_RELATIVE) reduce 346) ((T_PRIVATE) reduce 346) ((T_PROTECTED) reduce 346) ((T_PUBLIC) reduce 346) ((T_READONLY) reduce 346) ((T_STATIC) reduce 346) ((T_STRING) reduce 346) ((T_VARIABLE) reduce 346)) 3000 ((("(") reduce 343) (("?") reduce 343) ((T_ABSTRACT) reduce 343) ((T_ARRAY) reduce 343) ((T_CALLABLE) reduce 343) ((T_CONST) reduce 343) ((T_FINAL) reduce 343) ((T_FUNCTION) reduce 343) ((T_NAME_FULLY_QUALIFIED) reduce 343) ((T_NAME_QUALIFIED) reduce 343) ((T_NAME_RELATIVE) reduce 343) ((T_PRIVATE) reduce 343) ((T_PROTECTED) reduce 343) ((T_PUBLIC) reduce 343) ((T_READONLY) reduce 343) ((T_STATIC) reduce 343) ((T_STRING) reduce 343) ((T_VARIABLE) reduce 343)) 3002 ((("(") reduce 333) (("?") reduce 333) ((T_ARRAY) reduce 333) ((T_CALLABLE) reduce 333) ((T_NAME_FULLY_QUALIFIED) reduce 333) ((T_NAME_QUALIFIED) reduce 333) ((T_NAME_RELATIVE) reduce 333) ((T_STRING) reduce 333) ((T_VARIABLE) reduce 333)) 3003 (((T_ABSTRACT) reduce 100) ((T_ATTRIBUTE) reduce 100) ((T_CASE) reduce 100) ((T_CONST) reduce 100) ((T_FINAL) reduce 100) ((T_FUNCTION) reduce 100) ((T_PRIVATE) reduce 100) ((T_PROTECTED) reduce 100) ((T_PUBLIC) reduce 100) ((T_READONLY) reduce 100) ((T_STATIC) reduce 100) ((T_VAR) reduce 100)) 3004 (((T_ABSTRACT) reduce 310) ((T_ATTRIBUTE) reduce 310) ((T_CASE) reduce 310) ((T_CONST) reduce 310) ((T_FINAL) reduce 310) ((T_FUNCTION) reduce 310) ((T_PRIVATE) reduce 310) ((T_PROTECTED) reduce 310) ((T_PUBLIC) reduce 310) ((T_READONLY) reduce 310) ((T_STATIC) reduce 310) ((T_USE) reduce 310) ((T_VAR) reduce 310) (("}") reduce 310)) 3005 (((T_ABSTRACT) shift) ((T_ATTRIBUTE) shift) ((T_CASE) shift) ((T_CONST) reduce 336) ((T_FINAL) shift) ((T_FUNCTION) reduce 334) ((T_PRIVATE) shift) ((T_PROTECTED) shift) ((T_PUBLIC) shift) ((T_READONLY) shift) ((T_STATIC) shift) ((T_VAR) shift)) 3006 (((T_CONST) shift)) 3007 (((T_ABSTRACT) reduce 303) ((T_ATTRIBUTE) reduce 303) ((T_CASE) reduce 303) ((T_CONST) reduce 303) ((T_FINAL) reduce 303) ((T_FUNCTION) reduce 303) ((T_PRIVATE) reduce 303) ((T_PROTECTED) reduce 303) ((T_PUBLIC) reduce 303) ((T_READONLY) reduce 303) ((T_STATIC) reduce 303) ((T_USE) reduce 303) ((T_VAR) reduce 303) (("}") reduce 303)) 3008 (((T_ABSTRACT) reduce 309) ((T_ATTRIBUTE) reduce 309) ((T_CASE) reduce 309) ((T_CONST) reduce 309) ((T_FINAL) reduce 309) ((T_FUNCTION) reduce 309) ((T_PRIVATE) reduce 309) ((T_PROTECTED) reduce 309) ((T_PUBLIC) reduce 309) ((T_READONLY) reduce 309) ((T_STATIC) reduce 309) ((T_USE) reduce 309) ((T_VAR) reduce 309) (("}") reduce 309)) 3009 ((("(") reduce 338) (("?") reduce 338) ((T_ABSTRACT) reduce 338) ((T_ARRAY) reduce 338) ((T_CALLABLE) reduce 338) ((T_CONST) reduce 338) ((T_FINAL) reduce 338) ((T_FUNCTION) reduce 338) ((T_NAME_FULLY_QUALIFIED) reduce 338) ((T_NAME_QUALIFIED) reduce 338) ((T_NAME_RELATIVE) reduce 338) ((T_PRIVATE) reduce 338) ((T_PROTECTED) reduce 338) ((T_PUBLIC) reduce 338) ((T_READONLY) reduce 338) ((T_STATIC) reduce 338) ((T_STRING) reduce 338) ((T_VARIABLE) reduce 338)) 3010 (((T_FUNCTION) shift)) 3011 ((("(") reduce 332) (("?") reduce 332) ((T_ABSTRACT) shift) ((T_ARRAY) reduce 332) ((T_CALLABLE) reduce 332) ((T_CONST) reduce 337) ((T_FINAL) shift) ((T_FUNCTION) reduce 335) ((T_NAME_FULLY_QUALIFIED) reduce 332) ((T_NAME_QUALIFIED) reduce 332) ((T_NAME_RELATIVE) reduce 332) ((T_PRIVATE) shift) ((T_PROTECTED) shift) ((T_PUBLIC) shift) ((T_READONLY) shift) ((T_STATIC) shift) ((T_STRING) reduce 332) ((T_VARIABLE) reduce 332)) 3012 ((("(") shift) (("?") shift) ((T_ARRAY) shift) ((T_CALLABLE) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_STRING) shift) ((T_VARIABLE) reduce 259)) 3013 ((("%") reduce 363) ((")") reduce 363) (("*") reduce 363) (("+") reduce 363) ((",") reduce 363) (("-") reduce 363) ((".") reduce 363) (("/") reduce 363) (("<") reduce 363) ((">") reduce 363) (("?") reduce 363) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_BOOLEAN_AND) reduce 363) ((T_BOOLEAN_OR) reduce 363) ((T_COALESCE) reduce 363) ((T_INSTANCEOF) reduce 363) ((T_IS_EQUAL) reduce 363) ((T_IS_GREATER_OR_EQUAL) reduce 363) ((T_IS_IDENTICAL) reduce 363) ((T_IS_NOT_EQUAL) reduce 363) ((T_IS_NOT_IDENTICAL) reduce 363) ((T_IS_SMALLER_OR_EQUAL) reduce 363) ((T_LOGICAL_AND) reduce 363) ((T_LOGICAL_OR) reduce 363) ((T_LOGICAL_XOR) reduce 363) ((T_POW) reduce 363) ((T_SL) reduce 363) ((T_SPACESHIP) reduce 363) ((T_SR) reduce 363) (("^") reduce 363) (("|") reduce 363)) 3014 (((T_ARRAY) shift) ((T_CALLABLE) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_STRING) shift)) 3016 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 277) ((T_VARIABLE) reduce 277) (("|") reduce 277)) 3017 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 278) ((T_VARIABLE) reduce 278) (("|") reduce 278)) 3018 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_VARIABLE) reduce 93) (("|") reduce 93)) 3019 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_VARIABLE) reduce 92) (("|") reduce 92)) 3020 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_VARIABLE) reduce 94) (("|") reduce 94)) 3021 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_VARIABLE) reduce 91) (("|") reduce 91)) 3022 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_VARIABLE) reduce 276)) 3023 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 279) ((T_VARIABLE) reduce 279) (("|") reduce 279)) 3024 (((T_VARIABLE) shift)) 3025 (((T_VARIABLE) reduce 260)) 3026 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_VARIABLE) reduce 273) (("|") reduce 280)) 3027 (((T_VARIABLE) reduce 275) (("|") shift)) 3029 ((("(") shift) ((T_ARRAY) shift) ((T_CALLABLE) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_STRING) shift)) 3031 (((T_VARIABLE) reduce 277) (("|") reduce 277)) 3032 (((T_VARIABLE) reduce 278) (("|") reduce 278)) 3033 (((T_VARIABLE) reduce 93) (("|") reduce 93)) 3034 (((T_VARIABLE) reduce 92) (("|") reduce 92)) 3035 (((T_VARIABLE) reduce 94) (("|") reduce 94)) 3036 (((T_VARIABLE) reduce 91) (("|") reduce 91)) 3037 (((T_VARIABLE) reduce 279) (("|") reduce 279)) 3038 (((T_VARIABLE) reduce 280) (("|") reduce 280)) 3039 (((T_VARIABLE) reduce 282) (("|") reduce 282)) 3043 (((")") reduce 284) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 284)) 3044 (((T_VARIABLE) reduce 281) (("|") reduce 281)) 3046 (((")") reduce 285) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 285)) 3048 (((T_VARIABLE) reduce 283) (("|") reduce 283)) 3050 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 277) ((T_VARIABLE) reduce 277)) 3051 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 278) ((T_VARIABLE) reduce 278)) 3052 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_VARIABLE) reduce 93)) 3053 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_VARIABLE) reduce 92)) 3054 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_VARIABLE) reduce 94)) 3055 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_VARIABLE) reduce 91)) 3056 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 279) ((T_VARIABLE) reduce 279)) 3057 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 284) ((T_VARIABLE) reduce 284)) 3058 (((",") reduce 454) ((";") reduce 454) (("=") shift)) 3059 (((",") reduce 348) ((";") reduce 348)) 3060 (((",") shift) ((";") shift)) 3062 (((T_ABSTRACT) reduce 305) ((T_ATTRIBUTE) reduce 305) ((T_CASE) reduce 305) ((T_CONST) reduce 305) ((T_FINAL) reduce 305) ((T_FUNCTION) reduce 305) ((T_PRIVATE) reduce 305) ((T_PROTECTED) reduce 305) ((T_PUBLIC) reduce 305) ((T_READONLY) reduce 305) ((T_STATIC) reduce 305) ((T_USE) reduce 305) ((T_VAR) reduce 305) (("}") reduce 305)) 3063 (((",") reduce 347) ((";") reduce 347)) 3065 (((",") reduce 349) ((";") reduce 349)) 3076 ((("%") reduce 502) (("*") reduce 502) (("+") reduce 502) ((",") reduce 502) (("-") reduce 502) ((".") reduce 502) (("/") reduce 502) ((";") reduce 502) (("<") reduce 502) ((">") reduce 502) (("?") reduce 502) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_BOOLEAN_AND) reduce 502) ((T_BOOLEAN_OR) reduce 502) ((T_COALESCE) reduce 502) ((T_INSTANCEOF) reduce 502) ((T_IS_EQUAL) reduce 502) ((T_IS_GREATER_OR_EQUAL) reduce 502) ((T_IS_IDENTICAL) reduce 502) ((T_IS_NOT_EQUAL) reduce 502) ((T_IS_NOT_IDENTICAL) reduce 502) ((T_IS_SMALLER_OR_EQUAL) reduce 502) ((T_LOGICAL_AND) reduce 502) ((T_LOGICAL_OR) reduce 502) ((T_LOGICAL_XOR) reduce 502) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 502) ((T_OBJECT_OPERATOR) reduce 502) ((T_POW) reduce 502) ((T_SL) reduce 502) ((T_SPACESHIP) reduce 502) ((T_SR) reduce 502) (("[") reduce 502) (("^") reduce 502) (("{") reduce 502) (("|") reduce 502)) 3078 ((("%") reduce 484) (("(") reduce 484) (("*") reduce 484) (("+") reduce 484) ((",") reduce 484) (("-") reduce 484) ((".") reduce 484) (("/") reduce 484) ((";") reduce 484) (("<") reduce 484) ((">") reduce 484) (("?") reduce 484) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_BOOLEAN_AND) reduce 484) ((T_BOOLEAN_OR) reduce 484) ((T_COALESCE) reduce 484) ((T_INSTANCEOF) reduce 484) ((T_IS_EQUAL) reduce 484) ((T_IS_GREATER_OR_EQUAL) reduce 484) ((T_IS_IDENTICAL) reduce 484) ((T_IS_NOT_EQUAL) reduce 484) ((T_IS_NOT_IDENTICAL) reduce 484) ((T_IS_SMALLER_OR_EQUAL) reduce 484) ((T_LOGICAL_AND) reduce 484) ((T_LOGICAL_OR) reduce 484) ((T_LOGICAL_XOR) reduce 484) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 484) ((T_OBJECT_OPERATOR) reduce 484) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 484) ((T_POW) reduce 484) ((T_SL) reduce 484) ((T_SPACESHIP) reduce 484) ((T_SR) reduce 484) (("[") reduce 484) (("^") reduce 484) (("{") reduce 484) (("|") reduce 484)) 3080 ((("%") reduce 497) (("*") reduce 497) (("+") reduce 497) ((",") reduce 497) (("-") reduce 497) ((".") reduce 497) (("/") reduce 497) ((";") reduce 497) (("<") reduce 497) ((">") reduce 497) (("?") reduce 497) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_BOOLEAN_AND) reduce 497) ((T_BOOLEAN_OR) reduce 497) ((T_COALESCE) reduce 497) ((T_INSTANCEOF) reduce 497) ((T_IS_EQUAL) reduce 497) ((T_IS_GREATER_OR_EQUAL) reduce 497) ((T_IS_IDENTICAL) reduce 497) ((T_IS_NOT_EQUAL) reduce 497) ((T_IS_NOT_IDENTICAL) reduce 497) ((T_IS_SMALLER_OR_EQUAL) reduce 497) ((T_LOGICAL_AND) reduce 497) ((T_LOGICAL_OR) reduce 497) ((T_LOGICAL_XOR) reduce 497) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 497) ((T_OBJECT_OPERATOR) reduce 497) ((T_POW) reduce 497) ((T_SL) reduce 497) ((T_SPACESHIP) reduce 497) ((T_SR) reduce 497) (("[") reduce 497) (("^") reduce 497) (("{") reduce 497) (("|") reduce 497)) 3081 ((("%") reduce 487) (("*") reduce 487) (("+") reduce 487) ((",") reduce 487) (("-") reduce 487) ((".") reduce 487) (("/") reduce 487) ((";") reduce 487) (("<") reduce 487) ((">") reduce 487) (("?") reduce 487) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_BOOLEAN_AND) reduce 487) ((T_BOOLEAN_OR) reduce 487) ((T_COALESCE) reduce 487) ((T_INSTANCEOF) reduce 487) ((T_IS_EQUAL) reduce 487) ((T_IS_GREATER_OR_EQUAL) reduce 487) ((T_IS_IDENTICAL) reduce 487) ((T_IS_NOT_EQUAL) reduce 487) ((T_IS_NOT_IDENTICAL) reduce 487) ((T_IS_SMALLER_OR_EQUAL) reduce 487) ((T_LOGICAL_AND) reduce 487) ((T_LOGICAL_OR) reduce 487) ((T_LOGICAL_XOR) reduce 487) ((T_POW) reduce 487) ((T_SL) reduce 487) ((T_SPACESHIP) reduce 487) ((T_SR) reduce 487) (("^") reduce 487) (("|") reduce 487)) 3085 ((("%") reduce 475) (("(") shift) (("*") reduce 475) (("+") reduce 475) ((",") reduce 475) (("-") reduce 475) ((".") reduce 475) (("/") reduce 475) ((";") reduce 475) (("<") reduce 475) ((">") reduce 475) (("?") reduce 475) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_BOOLEAN_AND) reduce 475) ((T_BOOLEAN_OR) reduce 475) ((T_COALESCE) reduce 475) ((T_INSTANCEOF) reduce 475) ((T_IS_EQUAL) reduce 475) ((T_IS_GREATER_OR_EQUAL) reduce 475) ((T_IS_IDENTICAL) reduce 475) ((T_IS_NOT_EQUAL) reduce 475) ((T_IS_NOT_IDENTICAL) reduce 475) ((T_IS_SMALLER_OR_EQUAL) reduce 475) ((T_LOGICAL_AND) reduce 475) ((T_LOGICAL_OR) reduce 475) ((T_LOGICAL_XOR) reduce 475) ((T_POW) reduce 475) ((T_SL) reduce 475) ((T_SPACESHIP) reduce 475) ((T_SR) reduce 475) (("^") reduce 475) (("|") reduce 475)) 3086 ((("%") reduce 496) (("*") reduce 496) (("+") reduce 496) ((",") reduce 496) (("-") reduce 496) ((".") reduce 496) (("/") reduce 496) ((";") reduce 496) (("<") reduce 496) ((">") reduce 496) (("?") reduce 496) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_BOOLEAN_AND) reduce 496) ((T_BOOLEAN_OR) reduce 496) ((T_COALESCE) reduce 496) ((T_INSTANCEOF) reduce 496) ((T_IS_EQUAL) reduce 496) ((T_IS_GREATER_OR_EQUAL) reduce 496) ((T_IS_IDENTICAL) reduce 496) ((T_IS_NOT_EQUAL) reduce 496) ((T_IS_NOT_IDENTICAL) reduce 496) ((T_IS_SMALLER_OR_EQUAL) reduce 496) ((T_LOGICAL_AND) reduce 496) ((T_LOGICAL_OR) reduce 496) ((T_LOGICAL_XOR) reduce 496) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 496) ((T_OBJECT_OPERATOR) reduce 496) ((T_POW) reduce 496) ((T_SL) reduce 496) ((T_SPACESHIP) reduce 496) ((T_SR) reduce 496) (("[") reduce 496) (("^") reduce 496) (("{") reduce 496) (("|") reduce 496)) 3087 ((("%") reduce 500) (("*") reduce 500) (("+") reduce 500) ((",") reduce 500) (("-") reduce 500) ((".") reduce 500) (("/") reduce 500) ((";") reduce 500) (("<") reduce 500) ((">") reduce 500) (("?") reduce 500) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_BOOLEAN_AND) reduce 500) ((T_BOOLEAN_OR) reduce 500) ((T_COALESCE) reduce 500) ((T_INSTANCEOF) reduce 500) ((T_IS_EQUAL) reduce 500) ((T_IS_GREATER_OR_EQUAL) reduce 500) ((T_IS_IDENTICAL) reduce 500) ((T_IS_NOT_EQUAL) reduce 500) ((T_IS_NOT_IDENTICAL) reduce 500) ((T_IS_SMALLER_OR_EQUAL) reduce 500) ((T_LOGICAL_AND) reduce 500) ((T_LOGICAL_OR) reduce 500) ((T_LOGICAL_XOR) reduce 500) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 500) ((T_OBJECT_OPERATOR) reduce 500) ((T_POW) reduce 500) ((T_SL) reduce 500) ((T_SPACESHIP) reduce 500) ((T_SR) reduce 500) (("[") reduce 500) (("^") reduce 500) (("{") reduce 500) (("|") reduce 500)) 3093 ((("%") reduce 495) (("*") reduce 495) (("+") reduce 495) ((",") reduce 495) (("-") reduce 495) ((".") reduce 495) (("/") reduce 495) ((";") reduce 495) (("<") reduce 495) ((">") reduce 495) (("?") reduce 495) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_BOOLEAN_AND) reduce 495) ((T_BOOLEAN_OR) reduce 495) ((T_COALESCE) reduce 495) ((T_INSTANCEOF) reduce 495) ((T_IS_EQUAL) reduce 495) ((T_IS_GREATER_OR_EQUAL) reduce 495) ((T_IS_IDENTICAL) reduce 495) ((T_IS_NOT_EQUAL) reduce 495) ((T_IS_NOT_IDENTICAL) reduce 495) ((T_IS_SMALLER_OR_EQUAL) reduce 495) ((T_LOGICAL_AND) reduce 495) ((T_LOGICAL_OR) reduce 495) ((T_LOGICAL_XOR) reduce 495) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 495) ((T_OBJECT_OPERATOR) reduce 495) ((T_POW) reduce 495) ((T_SL) reduce 495) ((T_SPACESHIP) reduce 495) ((T_SR) reduce 495) (("[") reduce 495) (("^") reduce 495) (("{") reduce 495) (("|") reduce 495)) 3095 ((("%") reduce 486) (("*") reduce 486) (("+") reduce 486) ((",") reduce 486) (("-") reduce 486) ((".") reduce 486) (("/") reduce 486) ((";") reduce 486) (("<") reduce 486) ((">") reduce 486) (("?") reduce 486) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_BOOLEAN_AND) reduce 486) ((T_BOOLEAN_OR) reduce 486) ((T_COALESCE) reduce 486) ((T_INSTANCEOF) reduce 486) ((T_IS_EQUAL) reduce 486) ((T_IS_GREATER_OR_EQUAL) reduce 486) ((T_IS_IDENTICAL) reduce 486) ((T_IS_NOT_EQUAL) reduce 486) ((T_IS_NOT_IDENTICAL) reduce 486) ((T_IS_SMALLER_OR_EQUAL) reduce 486) ((T_LOGICAL_AND) reduce 486) ((T_LOGICAL_OR) reduce 486) ((T_LOGICAL_XOR) reduce 486) ((T_POW) reduce 486) ((T_SL) reduce 486) ((T_SPACESHIP) reduce 486) ((T_SR) reduce 486) (("^") reduce 486) (("|") reduce 486)) 3097 ((("%") reduce 499) (("*") reduce 499) (("+") reduce 499) ((",") reduce 499) (("-") reduce 499) ((".") reduce 499) (("/") reduce 499) ((";") reduce 499) (("<") reduce 499) ((">") reduce 499) (("?") reduce 499) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_BOOLEAN_AND) reduce 499) ((T_BOOLEAN_OR) reduce 499) ((T_COALESCE) reduce 499) ((T_INSTANCEOF) reduce 499) ((T_IS_EQUAL) reduce 499) ((T_IS_GREATER_OR_EQUAL) reduce 499) ((T_IS_IDENTICAL) reduce 499) ((T_IS_NOT_EQUAL) reduce 499) ((T_IS_NOT_IDENTICAL) reduce 499) ((T_IS_SMALLER_OR_EQUAL) reduce 499) ((T_LOGICAL_AND) reduce 499) ((T_LOGICAL_OR) reduce 499) ((T_LOGICAL_XOR) reduce 499) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 499) ((T_OBJECT_OPERATOR) reduce 499) ((T_POW) reduce 499) ((T_SL) reduce 499) ((T_SPACESHIP) reduce 499) ((T_SR) reduce 499) (("[") reduce 499) (("^") reduce 499) (("{") reduce 499) (("|") reduce 499)) 3098 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) ((",") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) ((";") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 93) ((T_OBJECT_OPERATOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("[") reduce 93) (("^") reduce 93) (("{") reduce 93) (("|") reduce 93)) 3099 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) ((",") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) ((";") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 92) ((T_OBJECT_OPERATOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("[") reduce 92) (("^") reduce 92) (("{") reduce 92) (("|") reduce 92)) 3100 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) ((",") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) ((";") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 94) ((T_OBJECT_OPERATOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("[") reduce 94) (("^") reduce 94) (("{") reduce 94) (("|") reduce 94)) 3102 ((("%") reduce 501) (("*") reduce 501) (("+") reduce 501) ((",") reduce 501) (("-") reduce 501) ((".") reduce 501) (("/") reduce 501) ((";") reduce 501) (("<") reduce 501) ((">") reduce 501) (("?") reduce 501) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_BOOLEAN_AND) reduce 501) ((T_BOOLEAN_OR) reduce 501) ((T_COALESCE) reduce 501) ((T_INSTANCEOF) reduce 501) ((T_IS_EQUAL) reduce 501) ((T_IS_GREATER_OR_EQUAL) reduce 501) ((T_IS_IDENTICAL) reduce 501) ((T_IS_NOT_EQUAL) reduce 501) ((T_IS_NOT_IDENTICAL) reduce 501) ((T_IS_SMALLER_OR_EQUAL) reduce 501) ((T_LOGICAL_AND) reduce 501) ((T_LOGICAL_OR) reduce 501) ((T_LOGICAL_XOR) reduce 501) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 501) ((T_OBJECT_OPERATOR) reduce 501) ((T_POW) reduce 501) ((T_SL) reduce 501) ((T_SPACESHIP) reduce 501) ((T_SR) reduce 501) (("[") reduce 501) (("^") reduce 501) (("{") reduce 501) (("|") reduce 501)) 3110 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) ((",") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) ((";") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 91) ((T_OBJECT_OPERATOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("[") reduce 91) (("^") reduce 91) (("{") reduce 91) (("|") reduce 91)) 3113 ((("%") reduce 498) (("*") reduce 498) (("+") reduce 498) ((",") reduce 498) (("-") reduce 498) ((".") reduce 498) (("/") reduce 498) ((";") reduce 498) (("<") reduce 498) ((">") reduce 498) (("?") reduce 498) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_BOOLEAN_AND) reduce 498) ((T_BOOLEAN_OR) reduce 498) ((T_COALESCE) reduce 498) ((T_INSTANCEOF) reduce 498) ((T_IS_EQUAL) reduce 498) ((T_IS_GREATER_OR_EQUAL) reduce 498) ((T_IS_IDENTICAL) reduce 498) ((T_IS_NOT_EQUAL) reduce 498) ((T_IS_NOT_IDENTICAL) reduce 498) ((T_IS_SMALLER_OR_EQUAL) reduce 498) ((T_LOGICAL_AND) reduce 498) ((T_LOGICAL_OR) reduce 498) ((T_LOGICAL_XOR) reduce 498) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 498) ((T_OBJECT_OPERATOR) reduce 498) ((T_POW) reduce 498) ((T_SL) reduce 498) ((T_SPACESHIP) reduce 498) ((T_SR) reduce 498) (("[") reduce 498) (("^") reduce 498) (("{") reduce 498) (("|") reduce 498)) 3115 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) ((",") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) ((";") reduce 529) (("<") reduce 529) (("=") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AND_EQUAL) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_COALESCE_EQUAL) reduce 529) ((T_CONCAT_EQUAL) reduce 529) ((T_DEC) reduce 529) ((T_DIV_EQUAL) reduce 529) ((T_INC) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_MINUS_EQUAL) reduce 529) ((T_MOD_EQUAL) reduce 529) ((T_MUL_EQUAL) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_OR_EQUAL) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_PLUS_EQUAL) reduce 529) ((T_POW) reduce 529) ((T_POW_EQUAL) reduce 529) ((T_SL) reduce 529) ((T_SL_EQUAL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) ((T_SR_EQUAL) reduce 529) ((T_XOR_EQUAL) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 3116 ((("!") shift) (("\"") shift) (("$") shift) (("%") reduce 440) (("(") shift) (("*") reduce 440) (("+") shift) ((",") reduce 440) (("-") shift) ((".") reduce 440) (("/") reduce 440) ((";") reduce 440) (("<") reduce 440) ((">") reduce 440) (("?") reduce 440) (("@") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOLEAN_AND) reduce 440) ((T_BOOLEAN_OR) reduce 440) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_COALESCE) reduce 440) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INSTANCEOF) reduce 440) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_IS_EQUAL) reduce 440) ((T_IS_GREATER_OR_EQUAL) reduce 440) ((T_IS_IDENTICAL) reduce 440) ((T_IS_NOT_EQUAL) reduce 440) ((T_IS_NOT_IDENTICAL) reduce 440) ((T_IS_SMALLER_OR_EQUAL) reduce 440) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_LOGICAL_AND) reduce 440) ((T_LOGICAL_OR) reduce 440) ((T_LOGICAL_XOR) reduce 440) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_POW) reduce 440) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_SL) reduce 440) ((T_SPACESHIP) reduce 440) ((T_SR) reduce 440) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("^") reduce 440) (("`") shift) (("|") reduce 440) (("~") shift)) 3123 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) ((",") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) ((";") reduce 525) (("<") reduce 525) (("=") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AND_EQUAL) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_COALESCE_EQUAL) reduce 525) ((T_CONCAT_EQUAL) reduce 525) ((T_DEC) reduce 525) ((T_DIV_EQUAL) reduce 525) ((T_INC) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_MINUS_EQUAL) reduce 525) ((T_MOD_EQUAL) reduce 525) ((T_MUL_EQUAL) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_OR_EQUAL) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_PLUS_EQUAL) reduce 525) ((T_POW) reduce 525) ((T_POW_EQUAL) reduce 525) ((T_SL) reduce 525) ((T_SL_EQUAL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) ((T_SR_EQUAL) reduce 525) ((T_XOR_EQUAL) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 3124 ((("%") reduce 493) (("*") reduce 493) (("+") reduce 493) ((",") reduce 493) (("-") reduce 493) ((".") reduce 493) (("/") reduce 493) ((";") reduce 493) (("<") reduce 493) ((">") reduce 493) (("?") reduce 493) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_BOOLEAN_AND) reduce 493) ((T_BOOLEAN_OR) reduce 493) ((T_COALESCE) reduce 493) ((T_INSTANCEOF) reduce 493) ((T_IS_EQUAL) reduce 493) ((T_IS_GREATER_OR_EQUAL) reduce 493) ((T_IS_IDENTICAL) reduce 493) ((T_IS_NOT_EQUAL) reduce 493) ((T_IS_NOT_IDENTICAL) reduce 493) ((T_IS_SMALLER_OR_EQUAL) reduce 493) ((T_LOGICAL_AND) reduce 493) ((T_LOGICAL_OR) reduce 493) ((T_LOGICAL_XOR) reduce 493) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 513) ((T_OBJECT_OPERATOR) reduce 513) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 513) ((T_POW) reduce 493) ((T_SL) reduce 493) ((T_SPACESHIP) reduce 493) ((T_SR) reduce 493) (("[") reduce 513) (("^") reduce 493) (("{") reduce 513) (("|") reduce 493)) 3126 ((("%") reduce 492) (("*") reduce 492) (("+") reduce 492) ((",") reduce 492) (("-") reduce 492) ((".") reduce 492) (("/") reduce 492) ((";") reduce 492) (("<") reduce 492) ((">") reduce 492) (("?") reduce 492) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_BOOLEAN_AND) reduce 492) ((T_BOOLEAN_OR) reduce 492) ((T_COALESCE) reduce 492) ((T_INSTANCEOF) reduce 492) ((T_IS_EQUAL) reduce 492) ((T_IS_GREATER_OR_EQUAL) reduce 492) ((T_IS_IDENTICAL) reduce 492) ((T_IS_NOT_EQUAL) reduce 492) ((T_IS_NOT_IDENTICAL) reduce 492) ((T_IS_SMALLER_OR_EQUAL) reduce 492) ((T_LOGICAL_AND) reduce 492) ((T_LOGICAL_OR) reduce 492) ((T_LOGICAL_XOR) reduce 492) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 515) ((T_OBJECT_OPERATOR) reduce 515) ((T_POW) reduce 492) ((T_SL) reduce 492) ((T_SPACESHIP) reduce 492) ((T_SR) reduce 492) (("[") reduce 515) (("^") reduce 492) (("{") reduce 515) (("|") reduce 492)) 3127 ((("%") reduce 491) (("(") reduce 518) (("*") reduce 491) (("+") reduce 491) ((",") reduce 491) (("-") reduce 491) ((".") reduce 491) (("/") reduce 491) ((";") reduce 491) (("<") reduce 491) ((">") reduce 491) (("?") reduce 491) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_BOOLEAN_AND) reduce 491) ((T_BOOLEAN_OR) reduce 491) ((T_COALESCE) reduce 491) ((T_INSTANCEOF) reduce 491) ((T_IS_EQUAL) reduce 491) ((T_IS_GREATER_OR_EQUAL) reduce 491) ((T_IS_IDENTICAL) reduce 491) ((T_IS_NOT_EQUAL) reduce 491) ((T_IS_NOT_IDENTICAL) reduce 491) ((T_IS_SMALLER_OR_EQUAL) reduce 491) ((T_LOGICAL_AND) reduce 491) ((T_LOGICAL_OR) reduce 491) ((T_LOGICAL_XOR) reduce 491) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 512) ((T_OBJECT_OPERATOR) reduce 512) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 512) ((T_POW) reduce 491) ((T_SL) reduce 491) ((T_SPACESHIP) reduce 491) ((T_SR) reduce 491) (("[") reduce 512) (("^") reduce 491) (("{") reduce 512) (("|") reduce 491)) 3128 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 454) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 454) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3131 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) ((",") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) ((";") reduce 524) (("<") reduce 524) (("=") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AND_EQUAL) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_COALESCE_EQUAL) reduce 524) ((T_CONCAT_EQUAL) reduce 524) ((T_DEC) reduce 524) ((T_DIV_EQUAL) reduce 524) ((T_INC) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_MINUS_EQUAL) reduce 524) ((T_MOD_EQUAL) reduce 524) ((T_MUL_EQUAL) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_OR_EQUAL) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_PLUS_EQUAL) reduce 524) ((T_POW) reduce 524) ((T_POW_EQUAL) reduce 524) ((T_SL) reduce 524) ((T_SL_EQUAL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) ((T_SR_EQUAL) reduce 524) ((T_XOR_EQUAL) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 3132 ((("%") reduce 445) (("*") reduce 445) (("+") reduce 445) ((",") reduce 445) (("-") reduce 445) ((".") reduce 445) (("/") reduce 445) ((";") reduce 445) (("<") reduce 445) ((">") reduce 445) (("?") reduce 445) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_BOOLEAN_AND) reduce 445) ((T_BOOLEAN_OR) reduce 445) ((T_COALESCE) reduce 445) ((T_INSTANCEOF) reduce 445) ((T_IS_EQUAL) reduce 445) ((T_IS_GREATER_OR_EQUAL) reduce 445) ((T_IS_IDENTICAL) reduce 445) ((T_IS_NOT_EQUAL) reduce 445) ((T_IS_NOT_IDENTICAL) reduce 445) ((T_IS_SMALLER_OR_EQUAL) reduce 445) ((T_LOGICAL_AND) reduce 445) ((T_LOGICAL_OR) reduce 445) ((T_LOGICAL_XOR) reduce 445) ((T_POW) reduce 445) ((T_SL) reduce 445) ((T_SPACESHIP) reduce 445) ((T_SR) reduce 445) (("^") reduce 445) (("|") reduce 445)) 3133 ((("%") reduce 427) (("*") reduce 427) (("+") reduce 427) ((",") reduce 427) (("-") reduce 427) ((".") reduce 427) (("/") reduce 427) ((";") reduce 427) (("<") reduce 427) ((">") reduce 427) (("?") reduce 427) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_BOOLEAN_AND) reduce 427) ((T_BOOLEAN_OR) reduce 427) ((T_COALESCE) reduce 427) ((T_INSTANCEOF) reduce 427) ((T_IS_EQUAL) reduce 427) ((T_IS_GREATER_OR_EQUAL) reduce 427) ((T_IS_IDENTICAL) reduce 427) ((T_IS_NOT_EQUAL) reduce 427) ((T_IS_NOT_IDENTICAL) reduce 427) ((T_IS_SMALLER_OR_EQUAL) reduce 427) ((T_LOGICAL_AND) reduce 427) ((T_LOGICAL_OR) reduce 427) ((T_LOGICAL_XOR) reduce 427) ((T_POW) reduce 427) ((T_SL) reduce 427) ((T_SPACESHIP) reduce 427) ((T_SR) reduce 427) (("^") reduce 427) (("|") reduce 427)) 3134 ((("%") reduce 449) (("*") reduce 449) (("+") reduce 449) ((",") reduce 449) (("-") reduce 449) ((".") reduce 449) (("/") reduce 449) ((";") reduce 449) (("<") reduce 449) ((">") reduce 449) (("?") reduce 449) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_BOOLEAN_AND) reduce 449) ((T_BOOLEAN_OR) reduce 449) ((T_COALESCE) reduce 449) ((T_INSTANCEOF) reduce 449) ((T_IS_EQUAL) reduce 449) ((T_IS_GREATER_OR_EQUAL) reduce 449) ((T_IS_IDENTICAL) reduce 449) ((T_IS_NOT_EQUAL) reduce 449) ((T_IS_NOT_IDENTICAL) reduce 449) ((T_IS_SMALLER_OR_EQUAL) reduce 449) ((T_LOGICAL_AND) reduce 449) ((T_LOGICAL_OR) reduce 449) ((T_LOGICAL_XOR) reduce 449) ((T_POW) reduce 449) ((T_SL) reduce 449) ((T_SPACESHIP) reduce 449) ((T_SR) reduce 449) (("^") reduce 449) (("|") reduce 449)) 3135 ((("%") reduce 494) (("(") shift) (("*") reduce 494) (("+") reduce 494) ((",") reduce 494) (("-") reduce 494) ((".") reduce 494) (("/") reduce 494) ((";") reduce 494) (("<") reduce 494) ((">") reduce 494) (("?") reduce 494) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_BOOLEAN_AND) reduce 494) ((T_BOOLEAN_OR) reduce 494) ((T_COALESCE) reduce 494) ((T_INSTANCEOF) reduce 494) ((T_IS_EQUAL) reduce 494) ((T_IS_GREATER_OR_EQUAL) reduce 494) ((T_IS_IDENTICAL) reduce 494) ((T_IS_NOT_EQUAL) reduce 494) ((T_IS_NOT_IDENTICAL) reduce 494) ((T_IS_SMALLER_OR_EQUAL) reduce 494) ((T_LOGICAL_AND) reduce 494) ((T_LOGICAL_OR) reduce 494) ((T_LOGICAL_XOR) reduce 494) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 494) ((T_OBJECT_OPERATOR) reduce 494) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 494) ((T_SL) reduce 494) ((T_SPACESHIP) reduce 494) ((T_SR) reduce 494) (("[") reduce 494) (("^") reduce 494) (("{") reduce 494) (("|") reduce 494)) 3136 ((("%") reduce 423) (("*") reduce 423) (("+") reduce 423) ((",") reduce 423) (("-") reduce 423) ((".") reduce 423) (("/") reduce 423) ((";") reduce 423) (("<") reduce 423) ((">") reduce 423) (("?") reduce 423) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_BOOLEAN_AND) reduce 423) ((T_BOOLEAN_OR) reduce 423) ((T_COALESCE) reduce 423) ((T_INSTANCEOF) reduce 423) ((T_IS_EQUAL) reduce 423) ((T_IS_GREATER_OR_EQUAL) reduce 423) ((T_IS_IDENTICAL) reduce 423) ((T_IS_NOT_EQUAL) reduce 423) ((T_IS_NOT_IDENTICAL) reduce 423) ((T_IS_SMALLER_OR_EQUAL) reduce 423) ((T_LOGICAL_AND) reduce 423) ((T_LOGICAL_OR) reduce 423) ((T_LOGICAL_XOR) reduce 423) ((T_POW) reduce 423) ((T_SL) reduce 423) ((T_SPACESHIP) reduce 423) ((T_SR) reduce 423) (("^") reduce 423) (("|") reduce 423)) 3137 ((("%") reduce 437) (("*") reduce 437) (("+") reduce 437) ((",") reduce 437) (("-") reduce 437) ((".") reduce 437) (("/") reduce 437) ((";") reduce 437) (("<") reduce 437) ((">") reduce 437) (("?") reduce 437) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_BOOLEAN_AND) reduce 437) ((T_BOOLEAN_OR) reduce 437) ((T_COALESCE) reduce 437) ((T_INSTANCEOF) reduce 437) ((T_IS_EQUAL) reduce 437) ((T_IS_GREATER_OR_EQUAL) reduce 437) ((T_IS_IDENTICAL) reduce 437) ((T_IS_NOT_EQUAL) reduce 437) ((T_IS_NOT_IDENTICAL) reduce 437) ((T_IS_SMALLER_OR_EQUAL) reduce 437) ((T_LOGICAL_AND) reduce 437) ((T_LOGICAL_OR) reduce 437) ((T_LOGICAL_XOR) reduce 437) ((T_POW) reduce 437) ((T_SL) reduce 437) ((T_SPACESHIP) reduce 437) ((T_SR) reduce 437) (("^") reduce 437) (("|") reduce 437)) 3138 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) ((",") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) ((";") reduce 519) (("<") reduce 519) (("=") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AND_EQUAL) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_COALESCE_EQUAL) reduce 519) ((T_CONCAT_EQUAL) reduce 519) ((T_DEC) reduce 519) ((T_DIV_EQUAL) reduce 519) ((T_INC) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_MINUS_EQUAL) reduce 519) ((T_MOD_EQUAL) reduce 519) ((T_MUL_EQUAL) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_OR_EQUAL) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_PLUS_EQUAL) reduce 519) ((T_POW) reduce 519) ((T_POW_EQUAL) reduce 519) ((T_SL) reduce 519) ((T_SL_EQUAL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) ((T_SR_EQUAL) reduce 519) ((T_XOR_EQUAL) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 3139 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) ((",") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) ((";") reduce 526) (("<") reduce 526) (("=") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AND_EQUAL) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_COALESCE_EQUAL) reduce 526) ((T_CONCAT_EQUAL) reduce 526) ((T_DEC) reduce 526) ((T_DIV_EQUAL) reduce 526) ((T_INC) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_MINUS_EQUAL) reduce 526) ((T_MOD_EQUAL) reduce 526) ((T_MUL_EQUAL) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_OR_EQUAL) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_PLUS_EQUAL) reduce 526) ((T_POW) reduce 526) ((T_POW_EQUAL) reduce 526) ((T_SL) reduce 526) ((T_SL_EQUAL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) ((T_SR_EQUAL) reduce 526) ((T_XOR_EQUAL) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 3140 ((("%") reduce 367) (("*") reduce 367) (("+") reduce 367) ((",") reduce 367) (("-") reduce 367) ((".") reduce 367) (("/") reduce 367) ((";") reduce 367) (("<") reduce 367) (("=") shift) ((">") reduce 367) (("?") reduce 367) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AND_EQUAL) shift) ((T_BOOLEAN_AND) reduce 367) ((T_BOOLEAN_OR) reduce 367) ((T_COALESCE) reduce 367) ((T_COALESCE_EQUAL) shift) ((T_CONCAT_EQUAL) shift) ((T_DEC) shift) ((T_DIV_EQUAL) shift) ((T_INC) shift) ((T_INSTANCEOF) reduce 367) ((T_IS_EQUAL) reduce 367) ((T_IS_GREATER_OR_EQUAL) reduce 367) ((T_IS_IDENTICAL) reduce 367) ((T_IS_NOT_EQUAL) reduce 367) ((T_IS_NOT_IDENTICAL) reduce 367) ((T_IS_SMALLER_OR_EQUAL) reduce 367) ((T_LOGICAL_AND) reduce 367) ((T_LOGICAL_OR) reduce 367) ((T_LOGICAL_XOR) reduce 367) ((T_MINUS_EQUAL) shift) ((T_MOD_EQUAL) shift) ((T_MUL_EQUAL) shift) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_OR_EQUAL) shift) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_PLUS_EQUAL) shift) ((T_POW) reduce 367) ((T_POW_EQUAL) shift) ((T_SL) reduce 367) ((T_SL_EQUAL) shift) ((T_SPACESHIP) reduce 367) ((T_SR) reduce 367) ((T_SR_EQUAL) shift) ((T_XOR_EQUAL) shift) (("[") reduce 510) (("^") reduce 367) (("{") reduce 510) (("|") reduce 367)) 3143 ((("%") reduce 411) (("*") reduce 411) (("+") reduce 411) ((",") reduce 411) (("-") reduce 411) ((".") reduce 411) (("/") reduce 411) ((";") reduce 411) (("<") reduce 411) ((">") reduce 411) (("?") reduce 411) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_BOOLEAN_AND) reduce 411) ((T_BOOLEAN_OR) reduce 411) ((T_COALESCE) reduce 411) ((T_INSTANCEOF) reduce 411) ((T_IS_EQUAL) reduce 411) ((T_IS_GREATER_OR_EQUAL) reduce 411) ((T_IS_IDENTICAL) reduce 411) ((T_IS_NOT_EQUAL) reduce 411) ((T_IS_NOT_IDENTICAL) reduce 411) ((T_IS_SMALLER_OR_EQUAL) reduce 411) ((T_LOGICAL_AND) reduce 411) ((T_LOGICAL_OR) reduce 411) ((T_LOGICAL_XOR) reduce 411) ((T_POW) shift) ((T_SL) reduce 411) ((T_SPACESHIP) reduce 411) ((T_SR) reduce 411) (("^") reduce 411) (("|") reduce 411)) 3174 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 395) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 395) (("<") shift) ((">") shift) (("?") reduce 395) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 395) ((T_BOOLEAN_OR) reduce 395) ((T_COALESCE) reduce 395) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 395) ((T_LOGICAL_OR) reduce 395) ((T_LOGICAL_XOR) reduce 395) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") reduce 395)) 3175 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 398) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 398) (("<") shift) ((">") shift) (("?") reduce 398) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 398) ((T_BOOLEAN_OR) reduce 398) ((T_COALESCE) reduce 398) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 398) ((T_LOGICAL_OR) reduce 398) ((T_LOGICAL_XOR) reduce 398) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 398) (("|") reduce 398)) 3176 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 407) (("-") shift) ((".") reduce 407) (("/") shift) ((";") reduce 407) (("<") reduce 407) ((">") reduce 407) (("?") reduce 407) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_BOOLEAN_AND) reduce 407) ((T_BOOLEAN_OR) reduce 407) ((T_COALESCE) reduce 407) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 407) ((T_IS_GREATER_OR_EQUAL) reduce 407) ((T_IS_IDENTICAL) reduce 407) ((T_IS_NOT_EQUAL) reduce 407) ((T_IS_NOT_IDENTICAL) reduce 407) ((T_IS_SMALLER_OR_EQUAL) reduce 407) ((T_LOGICAL_AND) reduce 407) ((T_LOGICAL_OR) reduce 407) ((T_LOGICAL_XOR) reduce 407) ((T_POW) shift) ((T_SL) reduce 407) ((T_SPACESHIP) reduce 407) ((T_SR) reduce 407) (("^") reduce 407) (("|") reduce 407)) 3177 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 420) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 420) (("<") shift) ((">") shift) (("?") reduce 420) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_BOOLEAN_AND) reduce 420) ((T_BOOLEAN_OR) reduce 420) ((T_COALESCE) reduce 420) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 420) ((T_LOGICAL_OR) reduce 420) ((T_LOGICAL_XOR) reduce 420) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 420) (("|") reduce 420)) 3178 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 406) (("-") shift) ((".") reduce 406) (("/") shift) ((";") reduce 406) (("<") reduce 406) ((">") reduce 406) (("?") reduce 406) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_BOOLEAN_AND) reduce 406) ((T_BOOLEAN_OR) reduce 406) ((T_COALESCE) reduce 406) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 406) ((T_IS_GREATER_OR_EQUAL) reduce 406) ((T_IS_IDENTICAL) reduce 406) ((T_IS_NOT_EQUAL) reduce 406) ((T_IS_NOT_IDENTICAL) reduce 406) ((T_IS_SMALLER_OR_EQUAL) reduce 406) ((T_LOGICAL_AND) reduce 406) ((T_LOGICAL_OR) reduce 406) ((T_LOGICAL_XOR) reduce 406) ((T_POW) shift) ((T_SL) reduce 406) ((T_SPACESHIP) reduce 406) ((T_SR) reduce 406) (("^") reduce 406) (("|") reduce 406)) 3179 ((("%") reduce 403) (("*") reduce 403) (("+") reduce 403) ((",") reduce 403) (("-") reduce 403) ((".") reduce 403) (("/") reduce 403) ((";") reduce 403) (("<") reduce 403) ((">") reduce 403) (("?") reduce 403) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_BOOLEAN_AND) reduce 403) ((T_BOOLEAN_OR) reduce 403) ((T_COALESCE) reduce 403) ((T_INSTANCEOF) reduce 403) ((T_IS_EQUAL) reduce 403) ((T_IS_GREATER_OR_EQUAL) reduce 403) ((T_IS_IDENTICAL) reduce 403) ((T_IS_NOT_EQUAL) reduce 403) ((T_IS_NOT_IDENTICAL) reduce 403) ((T_IS_SMALLER_OR_EQUAL) reduce 403) ((T_LOGICAL_AND) reduce 403) ((T_LOGICAL_OR) reduce 403) ((T_LOGICAL_XOR) reduce 403) ((T_POW) shift) ((T_SL) reduce 403) ((T_SPACESHIP) reduce 403) ((T_SR) reduce 403) (("^") reduce 403) (("|") reduce 403)) 3180 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 394) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 394) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 394) ((T_LOGICAL_XOR) reduce 394) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3181 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 392) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 392) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 392) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3182 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 393) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 393) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 393) ((T_LOGICAL_OR) reduce 393) ((T_LOGICAL_XOR) reduce 393) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3183 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 417) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 417) (("<") shift) ((">") shift) (("?") reduce 417) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_BOOLEAN_AND) reduce 417) ((T_BOOLEAN_OR) reduce 417) ((T_COALESCE) reduce 417) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 417) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 417) ((T_IS_NOT_EQUAL) reduce 417) ((T_IS_NOT_IDENTICAL) reduce 417) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 417) ((T_LOGICAL_OR) reduce 417) ((T_LOGICAL_XOR) reduce 417) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 417) ((T_SR) shift) (("^") reduce 417) (("|") reduce 417)) 3184 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 413) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 413) (("<") shift) ((">") shift) (("?") reduce 413) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_BOOLEAN_AND) reduce 413) ((T_BOOLEAN_OR) reduce 413) ((T_COALESCE) reduce 413) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 413) ((T_LOGICAL_OR) reduce 413) ((T_LOGICAL_XOR) reduce 413) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 413) (("|") reduce 413)) 3185 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 415) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 415) (("<") shift) ((">") shift) (("?") reduce 415) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_BOOLEAN_AND) reduce 415) ((T_BOOLEAN_OR) reduce 415) ((T_COALESCE) reduce 415) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 415) ((T_LOGICAL_OR) reduce 415) ((T_LOGICAL_XOR) reduce 415) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 415) (("|") reduce 415)) 3186 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 412) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 412) (("<") shift) ((">") shift) (("?") reduce 412) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_BOOLEAN_AND) reduce 412) ((T_BOOLEAN_OR) reduce 412) ((T_COALESCE) reduce 412) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 412) ((T_LOGICAL_OR) reduce 412) ((T_LOGICAL_XOR) reduce 412) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 412) (("|") reduce 412)) 3187 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 419) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 419) (("<") shift) ((">") shift) (("?") reduce 419) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_BOOLEAN_AND) reduce 419) ((T_BOOLEAN_OR) reduce 419) ((T_COALESCE) reduce 419) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 419) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 419) ((T_IS_NOT_EQUAL) reduce 419) ((T_IS_NOT_IDENTICAL) reduce 419) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 419) ((T_LOGICAL_OR) reduce 419) ((T_LOGICAL_XOR) reduce 419) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 419) ((T_SR) shift) (("^") reduce 419) (("|") reduce 419)) 3188 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 414) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 414) (("<") shift) ((">") shift) (("?") reduce 414) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_BOOLEAN_AND) reduce 414) ((T_BOOLEAN_OR) reduce 414) ((T_COALESCE) reduce 414) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 414) ((T_LOGICAL_OR) reduce 414) ((T_LOGICAL_XOR) reduce 414) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 414) (("|") reduce 414)) 3191 ((("%") reduce 93) (("*") reduce 93) (("+") reduce 93) ((",") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) ((";") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93)) 3192 ((("%") reduce 92) (("*") reduce 92) (("+") reduce 92) ((",") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) ((";") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92)) 3193 ((("%") reduce 94) (("*") reduce 94) (("+") reduce 94) ((",") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) ((";") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94)) 3194 ((("%") reduce 470) (("*") reduce 470) (("+") reduce 470) ((",") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) ((";") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470)) 3195 ((("%") reduce 91) (("*") reduce 91) (("+") reduce 91) ((",") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) ((";") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91)) 3196 ((("%") reduce 529) (("*") reduce 529) (("+") reduce 529) ((",") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) ((";") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 3197 ((("%") reduce 472) (("*") reduce 472) (("+") reduce 472) ((",") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) ((";") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472)) 3198 ((("%") reduce 421) (("*") reduce 421) (("+") reduce 421) ((",") reduce 421) (("-") reduce 421) ((".") reduce 421) (("/") reduce 421) ((";") reduce 421) (("<") reduce 421) ((">") reduce 421) (("?") reduce 421) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_BOOLEAN_AND) reduce 421) ((T_BOOLEAN_OR) reduce 421) ((T_COALESCE) reduce 421) ((T_INSTANCEOF) reduce 421) ((T_IS_EQUAL) reduce 421) ((T_IS_GREATER_OR_EQUAL) reduce 421) ((T_IS_IDENTICAL) reduce 421) ((T_IS_NOT_EQUAL) reduce 421) ((T_IS_NOT_IDENTICAL) reduce 421) ((T_IS_SMALLER_OR_EQUAL) reduce 421) ((T_LOGICAL_AND) reduce 421) ((T_LOGICAL_OR) reduce 421) ((T_LOGICAL_XOR) reduce 421) ((T_POW) reduce 421) ((T_SL) reduce 421) ((T_SPACESHIP) reduce 421) ((T_SR) reduce 421) (("^") reduce 421) (("|") reduce 421)) 3199 ((("%") reduce 471) (("*") reduce 471) (("+") reduce 471) ((",") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) ((";") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471)) 3200 ((("%") reduce 473) (("*") reduce 473) (("+") reduce 473) ((",") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) ((";") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 3201 ((("%") reduce 534) (("*") reduce 534) (("+") reduce 534) ((",") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) ((";") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 3208 ((("%") reduce 536) (("*") reduce 536) (("+") reduce 536) ((",") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) ((";") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 3210 ((("%") reduce 535) (("*") reduce 535) (("+") reduce 535) ((",") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) ((";") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 3211 ((("%") reduce 540) (("*") reduce 540) (("+") reduce 540) ((",") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) ((";") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 3212 ((("%") reduce 544) (("*") reduce 544) (("+") reduce 544) ((",") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) ((";") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 3213 ((("%") reduce 537) (("*") reduce 537) (("+") reduce 537) ((",") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) ((";") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 3214 ((("%") reduce 546) (("*") reduce 546) (("+") reduce 546) ((",") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) ((";") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 3217 ((("%") reduce 545) (("*") reduce 545) (("+") reduce 545) ((",") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) ((";") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 3218 ((("%") reduce 538) (("*") reduce 538) (("+") reduce 538) ((",") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) ((";") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 3220 ((("%") reduce 539) (("*") reduce 539) (("+") reduce 539) ((",") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) ((";") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 3222 ((("%") reduce 474) (("*") reduce 474) (("+") reduce 474) ((",") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) ((";") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474)) 3223 ((("%") reduce 531) (("*") reduce 531) (("+") reduce 531) ((",") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) ((";") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 3226 ((("%") reduce 530) (("*") reduce 530) (("+") reduce 530) ((",") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) ((";") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 3227 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 426) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 426) (("<") shift) ((">") shift) (("?") reduce 426) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 426) ((T_LOGICAL_OR) reduce 426) ((T_LOGICAL_XOR) reduce 426) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3228 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 390) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 390) (("<") shift) ((">") shift) (("?") reduce 390) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) reduce 390) ((T_COALESCE) reduce 390) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 390) ((T_LOGICAL_OR) reduce 390) ((T_LOGICAL_XOR) reduce 390) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3229 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 391) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 391) (("<") shift) ((">") shift) (("?") reduce 391) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 391) ((T_BOOLEAN_OR) reduce 391) ((T_COALESCE) reduce 391) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 391) ((T_LOGICAL_OR) reduce 391) ((T_LOGICAL_XOR) reduce 391) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3230 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 396) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 396) (("<") shift) ((">") shift) (("?") reduce 396) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_BOOLEAN_AND) reduce 396) ((T_BOOLEAN_OR) reduce 396) ((T_COALESCE) reduce 396) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 396) ((T_LOGICAL_OR) reduce 396) ((T_LOGICAL_XOR) reduce 396) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 396) (("|") reduce 396)) 3231 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 397) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 397) (("<") shift) ((">") shift) (("?") reduce 397) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_BOOLEAN_AND) reduce 397) ((T_BOOLEAN_OR) reduce 397) ((T_COALESCE) reduce 397) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 397) ((T_LOGICAL_OR) reduce 397) ((T_LOGICAL_XOR) reduce 397) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 397) (("|") reduce 397)) 3235 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 424) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 424) (("<") shift) ((">") shift) (("?") reduce 424) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 424) ((T_LOGICAL_OR) reduce 424) ((T_LOGICAL_XOR) reduce 424) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3236 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 425) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 425) (("<") shift) ((">") shift) (("?") reduce 425) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 425) ((T_LOGICAL_OR) reduce 425) ((T_LOGICAL_XOR) reduce 425) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3237 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 418) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 418) (("<") shift) ((">") shift) (("?") reduce 418) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_BOOLEAN_AND) reduce 418) ((T_BOOLEAN_OR) reduce 418) ((T_COALESCE) reduce 418) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 418) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 418) ((T_IS_NOT_EQUAL) reduce 418) ((T_IS_NOT_IDENTICAL) reduce 418) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 418) ((T_LOGICAL_OR) reduce 418) ((T_LOGICAL_XOR) reduce 418) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 418) ((T_SR) shift) (("^") reduce 418) (("|") reduce 418)) 3238 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 416) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 416) (("<") shift) ((">") shift) (("?") reduce 416) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_BOOLEAN_AND) reduce 416) ((T_BOOLEAN_OR) reduce 416) ((T_COALESCE) reduce 416) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 416) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 416) ((T_IS_NOT_EQUAL) reduce 416) ((T_IS_NOT_IDENTICAL) reduce 416) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 416) ((T_LOGICAL_OR) reduce 416) ((T_LOGICAL_XOR) reduce 416) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 416) ((T_SR) shift) (("^") reduce 416) (("|") reduce 416)) 3239 ((("%") reduce 404) (("*") reduce 404) (("+") reduce 404) ((",") reduce 404) (("-") reduce 404) ((".") reduce 404) (("/") reduce 404) ((";") reduce 404) (("<") reduce 404) ((">") reduce 404) (("?") reduce 404) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_BOOLEAN_AND) reduce 404) ((T_BOOLEAN_OR) reduce 404) ((T_COALESCE) reduce 404) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 404) ((T_IS_GREATER_OR_EQUAL) reduce 404) ((T_IS_IDENTICAL) reduce 404) ((T_IS_NOT_EQUAL) reduce 404) ((T_IS_NOT_IDENTICAL) reduce 404) ((T_IS_SMALLER_OR_EQUAL) reduce 404) ((T_LOGICAL_AND) reduce 404) ((T_LOGICAL_OR) reduce 404) ((T_LOGICAL_XOR) reduce 404) ((T_POW) shift) ((T_SL) reduce 404) ((T_SPACESHIP) reduce 404) ((T_SR) reduce 404) (("^") reduce 404) (("|") reduce 404)) 3240 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 399) (("-") shift) ((".") reduce 399) (("/") shift) ((";") reduce 399) (("<") reduce 399) ((">") reduce 399) (("?") reduce 399) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_BOOLEAN_AND) reduce 399) ((T_BOOLEAN_OR) reduce 399) ((T_COALESCE) reduce 399) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 399) ((T_IS_GREATER_OR_EQUAL) reduce 399) ((T_IS_IDENTICAL) reduce 399) ((T_IS_NOT_EQUAL) reduce 399) ((T_IS_NOT_IDENTICAL) reduce 399) ((T_IS_SMALLER_OR_EQUAL) reduce 399) ((T_LOGICAL_AND) reduce 399) ((T_LOGICAL_OR) reduce 399) ((T_LOGICAL_XOR) reduce 399) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 399) ((T_SR) shift) (("^") reduce 399) (("|") reduce 399)) 3241 ((("%") shift) (("*") shift) (("+") reduce 401) ((",") reduce 401) (("-") reduce 401) ((".") reduce 401) (("/") shift) ((";") reduce 401) (("<") reduce 401) ((">") reduce 401) (("?") reduce 401) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_BOOLEAN_AND) reduce 401) ((T_BOOLEAN_OR) reduce 401) ((T_COALESCE) reduce 401) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 401) ((T_IS_GREATER_OR_EQUAL) reduce 401) ((T_IS_IDENTICAL) reduce 401) ((T_IS_NOT_EQUAL) reduce 401) ((T_IS_NOT_IDENTICAL) reduce 401) ((T_IS_SMALLER_OR_EQUAL) reduce 401) ((T_LOGICAL_AND) reduce 401) ((T_LOGICAL_OR) reduce 401) ((T_LOGICAL_XOR) reduce 401) ((T_POW) shift) ((T_SL) reduce 401) ((T_SPACESHIP) reduce 401) ((T_SR) reduce 401) (("^") reduce 401) (("|") reduce 401)) 3242 ((("%") shift) (("*") shift) (("+") reduce 400) ((",") reduce 400) (("-") reduce 400) ((".") reduce 400) (("/") shift) ((";") reduce 400) (("<") reduce 400) ((">") reduce 400) (("?") reduce 400) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_BOOLEAN_AND) reduce 400) ((T_BOOLEAN_OR) reduce 400) ((T_COALESCE) reduce 400) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 400) ((T_IS_GREATER_OR_EQUAL) reduce 400) ((T_IS_IDENTICAL) reduce 400) ((T_IS_NOT_EQUAL) reduce 400) ((T_IS_NOT_IDENTICAL) reduce 400) ((T_IS_SMALLER_OR_EQUAL) reduce 400) ((T_LOGICAL_AND) reduce 400) ((T_LOGICAL_OR) reduce 400) ((T_LOGICAL_XOR) reduce 400) ((T_POW) shift) ((T_SL) reduce 400) ((T_SPACESHIP) reduce 400) ((T_SR) reduce 400) (("^") reduce 400) (("|") reduce 400)) 3243 ((("%") reduce 402) (("*") reduce 402) (("+") reduce 402) ((",") reduce 402) (("-") reduce 402) ((".") reduce 402) (("/") reduce 402) ((";") reduce 402) (("<") reduce 402) ((">") reduce 402) (("?") reduce 402) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_BOOLEAN_AND) reduce 402) ((T_BOOLEAN_OR) reduce 402) ((T_COALESCE) reduce 402) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 402) ((T_IS_GREATER_OR_EQUAL) reduce 402) ((T_IS_IDENTICAL) reduce 402) ((T_IS_NOT_EQUAL) reduce 402) ((T_IS_NOT_IDENTICAL) reduce 402) ((T_IS_SMALLER_OR_EQUAL) reduce 402) ((T_LOGICAL_AND) reduce 402) ((T_LOGICAL_OR) reduce 402) ((T_LOGICAL_XOR) reduce 402) ((T_POW) shift) ((T_SL) reduce 402) ((T_SPACESHIP) reduce 402) ((T_SR) reduce 402) (("^") reduce 402) (("|") reduce 402)) 3244 ((("%") reduce 405) (("*") reduce 405) (("+") reduce 405) ((",") reduce 405) (("-") reduce 405) ((".") reduce 405) (("/") reduce 405) ((";") reduce 405) (("<") reduce 405) ((">") reduce 405) (("?") reduce 405) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_BOOLEAN_AND) reduce 405) ((T_BOOLEAN_OR) reduce 405) ((T_COALESCE) reduce 405) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 405) ((T_IS_GREATER_OR_EQUAL) reduce 405) ((T_IS_IDENTICAL) reduce 405) ((T_IS_NOT_EQUAL) reduce 405) ((T_IS_NOT_IDENTICAL) reduce 405) ((T_IS_SMALLER_OR_EQUAL) reduce 405) ((T_LOGICAL_AND) reduce 405) ((T_LOGICAL_OR) reduce 405) ((T_LOGICAL_XOR) reduce 405) ((T_POW) shift) ((T_SL) reduce 405) ((T_SPACESHIP) reduce 405) ((T_SR) reduce 405) (("^") reduce 405) (("|") reduce 405)) 3246 ((("%") reduce 73) (("(") reduce 73) (("*") reduce 73) (("+") reduce 73) ((",") reduce 73) (("-") reduce 73) ((".") reduce 73) (("/") reduce 73) ((";") reduce 73) (("<") reduce 73) ((">") reduce 73) (("?") reduce 73) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_BOOLEAN_AND) reduce 73) ((T_BOOLEAN_OR) reduce 73) ((T_COALESCE) reduce 73) ((T_INSTANCEOF) reduce 73) ((T_IS_EQUAL) reduce 73) ((T_IS_GREATER_OR_EQUAL) reduce 73) ((T_IS_IDENTICAL) reduce 73) ((T_IS_NOT_EQUAL) reduce 73) ((T_IS_NOT_IDENTICAL) reduce 73) ((T_IS_SMALLER_OR_EQUAL) reduce 73) ((T_LOGICAL_AND) reduce 73) ((T_LOGICAL_OR) reduce 73) ((T_LOGICAL_XOR) reduce 73) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 73) ((T_OBJECT_OPERATOR) reduce 73) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 73) ((T_POW) reduce 73) ((T_SL) reduce 73) ((T_SPACESHIP) reduce 73) ((T_SR) reduce 73) (("[") reduce 73) (("^") reduce 73) (("{") reduce 73) (("|") reduce 73)) 3247 ((("%") reduce 52) (("(") reduce 52) (("*") reduce 52) (("+") reduce 52) ((",") reduce 52) (("-") reduce 52) ((".") reduce 52) (("/") reduce 52) ((";") reduce 52) (("<") reduce 52) ((">") reduce 52) (("?") reduce 52) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_BOOLEAN_AND) reduce 52) ((T_BOOLEAN_OR) reduce 52) ((T_COALESCE) reduce 52) ((T_INSTANCEOF) reduce 52) ((T_IS_EQUAL) reduce 52) ((T_IS_GREATER_OR_EQUAL) reduce 52) ((T_IS_IDENTICAL) reduce 52) ((T_IS_NOT_EQUAL) reduce 52) ((T_IS_NOT_IDENTICAL) reduce 52) ((T_IS_SMALLER_OR_EQUAL) reduce 52) ((T_LOGICAL_AND) reduce 52) ((T_LOGICAL_OR) reduce 52) ((T_LOGICAL_XOR) reduce 52) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 52) ((T_OBJECT_OPERATOR) reduce 52) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 52) ((T_POW) reduce 52) ((T_SL) reduce 52) ((T_SPACESHIP) reduce 52) ((T_SR) reduce 52) (("[") reduce 52) (("^") reduce 52) (("{") reduce 52) (("|") reduce 52)) 3248 ((("%") reduce 27) (("(") reduce 27) (("*") reduce 27) (("+") reduce 27) ((",") reduce 27) (("-") reduce 27) ((".") reduce 27) (("/") reduce 27) ((";") reduce 27) (("<") reduce 27) ((">") reduce 27) (("?") reduce 27) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_BOOLEAN_AND) reduce 27) ((T_BOOLEAN_OR) reduce 27) ((T_COALESCE) reduce 27) ((T_INSTANCEOF) reduce 27) ((T_IS_EQUAL) reduce 27) ((T_IS_GREATER_OR_EQUAL) reduce 27) ((T_IS_IDENTICAL) reduce 27) ((T_IS_NOT_EQUAL) reduce 27) ((T_IS_NOT_IDENTICAL) reduce 27) ((T_IS_SMALLER_OR_EQUAL) reduce 27) ((T_LOGICAL_AND) reduce 27) ((T_LOGICAL_OR) reduce 27) ((T_LOGICAL_XOR) reduce 27) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 27) ((T_OBJECT_OPERATOR) reduce 27) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 27) ((T_POW) reduce 27) ((T_SL) reduce 27) ((T_SPACESHIP) reduce 27) ((T_SR) reduce 27) (("[") reduce 27) (("^") reduce 27) (("{") reduce 27) (("|") reduce 27)) 3249 ((("%") reduce 51) (("(") reduce 51) (("*") reduce 51) (("+") reduce 51) ((",") reduce 51) (("-") reduce 51) ((".") reduce 51) (("/") reduce 51) ((";") reduce 51) (("<") reduce 51) ((">") reduce 51) (("?") reduce 51) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_BOOLEAN_AND) reduce 51) ((T_BOOLEAN_OR) reduce 51) ((T_COALESCE) reduce 51) ((T_INSTANCEOF) reduce 51) ((T_IS_EQUAL) reduce 51) ((T_IS_GREATER_OR_EQUAL) reduce 51) ((T_IS_IDENTICAL) reduce 51) ((T_IS_NOT_EQUAL) reduce 51) ((T_IS_NOT_IDENTICAL) reduce 51) ((T_IS_SMALLER_OR_EQUAL) reduce 51) ((T_LOGICAL_AND) reduce 51) ((T_LOGICAL_OR) reduce 51) ((T_LOGICAL_XOR) reduce 51) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 51) ((T_OBJECT_OPERATOR) reduce 51) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 51) ((T_POW) reduce 51) ((T_SL) reduce 51) ((T_SPACESHIP) reduce 51) ((T_SR) reduce 51) (("[") reduce 51) (("^") reduce 51) (("{") reduce 51) (("|") reduce 51)) 3250 ((("%") reduce 53) (("(") reduce 53) (("*") reduce 53) (("+") reduce 53) ((",") reduce 53) (("-") reduce 53) ((".") reduce 53) (("/") reduce 53) ((";") reduce 53) (("<") reduce 53) ((">") reduce 53) (("?") reduce 53) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_BOOLEAN_AND) reduce 53) ((T_BOOLEAN_OR) reduce 53) ((T_COALESCE) reduce 53) ((T_INSTANCEOF) reduce 53) ((T_IS_EQUAL) reduce 53) ((T_IS_GREATER_OR_EQUAL) reduce 53) ((T_IS_IDENTICAL) reduce 53) ((T_IS_NOT_EQUAL) reduce 53) ((T_IS_NOT_IDENTICAL) reduce 53) ((T_IS_SMALLER_OR_EQUAL) reduce 53) ((T_LOGICAL_AND) reduce 53) ((T_LOGICAL_OR) reduce 53) ((T_LOGICAL_XOR) reduce 53) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 53) ((T_OBJECT_OPERATOR) reduce 53) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 53) ((T_POW) reduce 53) ((T_SL) reduce 53) ((T_SPACESHIP) reduce 53) ((T_SR) reduce 53) (("[") reduce 53) (("^") reduce 53) (("{") reduce 53) (("|") reduce 53)) 3251 ((("%") reduce 49) (("(") reduce 49) (("*") reduce 49) (("+") reduce 49) ((",") reduce 49) (("-") reduce 49) ((".") reduce 49) (("/") reduce 49) ((";") reduce 49) (("<") reduce 49) ((">") reduce 49) (("?") reduce 49) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_BOOLEAN_AND) reduce 49) ((T_BOOLEAN_OR) reduce 49) ((T_COALESCE) reduce 49) ((T_INSTANCEOF) reduce 49) ((T_IS_EQUAL) reduce 49) ((T_IS_GREATER_OR_EQUAL) reduce 49) ((T_IS_IDENTICAL) reduce 49) ((T_IS_NOT_EQUAL) reduce 49) ((T_IS_NOT_IDENTICAL) reduce 49) ((T_IS_SMALLER_OR_EQUAL) reduce 49) ((T_LOGICAL_AND) reduce 49) ((T_LOGICAL_OR) reduce 49) ((T_LOGICAL_XOR) reduce 49) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 49) ((T_OBJECT_OPERATOR) reduce 49) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 49) ((T_POW) reduce 49) ((T_SL) reduce 49) ((T_SPACESHIP) reduce 49) ((T_SR) reduce 49) (("[") reduce 49) (("^") reduce 49) (("{") reduce 49) (("|") reduce 49)) 3252 ((("%") reduce 29) (("(") reduce 29) (("*") reduce 29) (("+") reduce 29) ((",") reduce 29) (("-") reduce 29) ((".") reduce 29) (("/") reduce 29) ((";") reduce 29) (("<") reduce 29) ((">") reduce 29) (("?") reduce 29) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_BOOLEAN_AND) reduce 29) ((T_BOOLEAN_OR) reduce 29) ((T_COALESCE) reduce 29) ((T_INSTANCEOF) reduce 29) ((T_IS_EQUAL) reduce 29) ((T_IS_GREATER_OR_EQUAL) reduce 29) ((T_IS_IDENTICAL) reduce 29) ((T_IS_NOT_EQUAL) reduce 29) ((T_IS_NOT_IDENTICAL) reduce 29) ((T_IS_SMALLER_OR_EQUAL) reduce 29) ((T_LOGICAL_AND) reduce 29) ((T_LOGICAL_OR) reduce 29) ((T_LOGICAL_XOR) reduce 29) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 29) ((T_OBJECT_OPERATOR) reduce 29) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 29) ((T_POW) reduce 29) ((T_SL) reduce 29) ((T_SPACESHIP) reduce 29) ((T_SR) reduce 29) (("[") reduce 29) (("^") reduce 29) (("{") reduce 29) (("|") reduce 29)) 3253 ((("%") reduce 59) (("(") reduce 59) (("*") reduce 59) (("+") reduce 59) ((",") reduce 59) (("-") reduce 59) ((".") reduce 59) (("/") reduce 59) ((";") reduce 59) (("<") reduce 59) ((">") reduce 59) (("?") reduce 59) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_BOOLEAN_AND) reduce 59) ((T_BOOLEAN_OR) reduce 59) ((T_COALESCE) reduce 59) ((T_INSTANCEOF) reduce 59) ((T_IS_EQUAL) reduce 59) ((T_IS_GREATER_OR_EQUAL) reduce 59) ((T_IS_IDENTICAL) reduce 59) ((T_IS_NOT_EQUAL) reduce 59) ((T_IS_NOT_IDENTICAL) reduce 59) ((T_IS_SMALLER_OR_EQUAL) reduce 59) ((T_LOGICAL_AND) reduce 59) ((T_LOGICAL_OR) reduce 59) ((T_LOGICAL_XOR) reduce 59) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 59) ((T_OBJECT_OPERATOR) reduce 59) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 59) ((T_POW) reduce 59) ((T_SL) reduce 59) ((T_SPACESHIP) reduce 59) ((T_SR) reduce 59) (("[") reduce 59) (("^") reduce 59) (("{") reduce 59) (("|") reduce 59)) 3254 ((("%") reduce 60) (("(") reduce 60) (("*") reduce 60) (("+") reduce 60) ((",") reduce 60) (("-") reduce 60) ((".") reduce 60) (("/") reduce 60) ((";") reduce 60) (("<") reduce 60) ((">") reduce 60) (("?") reduce 60) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_BOOLEAN_AND) reduce 60) ((T_BOOLEAN_OR) reduce 60) ((T_COALESCE) reduce 60) ((T_INSTANCEOF) reduce 60) ((T_IS_EQUAL) reduce 60) ((T_IS_GREATER_OR_EQUAL) reduce 60) ((T_IS_IDENTICAL) reduce 60) ((T_IS_NOT_EQUAL) reduce 60) ((T_IS_NOT_IDENTICAL) reduce 60) ((T_IS_SMALLER_OR_EQUAL) reduce 60) ((T_LOGICAL_AND) reduce 60) ((T_LOGICAL_OR) reduce 60) ((T_LOGICAL_XOR) reduce 60) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 60) ((T_OBJECT_OPERATOR) reduce 60) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 60) ((T_POW) reduce 60) ((T_SL) reduce 60) ((T_SPACESHIP) reduce 60) ((T_SR) reduce 60) (("[") reduce 60) (("^") reduce 60) (("{") reduce 60) (("|") reduce 60)) 3255 ((("%") reduce 11) (("(") reduce 11) (("*") reduce 11) (("+") reduce 11) ((",") reduce 11) (("-") reduce 11) ((".") reduce 11) (("/") reduce 11) ((";") reduce 11) (("<") reduce 11) ((">") reduce 11) (("?") reduce 11) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_BOOLEAN_AND) reduce 11) ((T_BOOLEAN_OR) reduce 11) ((T_COALESCE) reduce 11) ((T_INSTANCEOF) reduce 11) ((T_IS_EQUAL) reduce 11) ((T_IS_GREATER_OR_EQUAL) reduce 11) ((T_IS_IDENTICAL) reduce 11) ((T_IS_NOT_EQUAL) reduce 11) ((T_IS_NOT_IDENTICAL) reduce 11) ((T_IS_SMALLER_OR_EQUAL) reduce 11) ((T_LOGICAL_AND) reduce 11) ((T_LOGICAL_OR) reduce 11) ((T_LOGICAL_XOR) reduce 11) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 11) ((T_OBJECT_OPERATOR) reduce 11) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 11) ((T_POW) reduce 11) ((T_SL) reduce 11) ((T_SPACESHIP) reduce 11) ((T_SR) reduce 11) (("[") reduce 11) (("^") reduce 11) (("{") reduce 11) (("|") reduce 11)) 3256 ((("%") reduce 42) (("(") reduce 42) (("*") reduce 42) (("+") reduce 42) ((",") reduce 42) (("-") reduce 42) ((".") reduce 42) (("/") reduce 42) ((";") reduce 42) (("<") reduce 42) ((">") reduce 42) (("?") reduce 42) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_BOOLEAN_AND) reduce 42) ((T_BOOLEAN_OR) reduce 42) ((T_COALESCE) reduce 42) ((T_INSTANCEOF) reduce 42) ((T_IS_EQUAL) reduce 42) ((T_IS_GREATER_OR_EQUAL) reduce 42) ((T_IS_IDENTICAL) reduce 42) ((T_IS_NOT_EQUAL) reduce 42) ((T_IS_NOT_IDENTICAL) reduce 42) ((T_IS_SMALLER_OR_EQUAL) reduce 42) ((T_LOGICAL_AND) reduce 42) ((T_LOGICAL_OR) reduce 42) ((T_LOGICAL_XOR) reduce 42) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 42) ((T_OBJECT_OPERATOR) reduce 42) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 42) ((T_POW) reduce 42) ((T_SL) reduce 42) ((T_SPACESHIP) reduce 42) ((T_SR) reduce 42) (("[") reduce 42) (("^") reduce 42) (("{") reduce 42) (("|") reduce 42)) 3257 ((("%") reduce 39) (("(") reduce 39) (("*") reduce 39) (("+") reduce 39) ((",") reduce 39) (("-") reduce 39) ((".") reduce 39) (("/") reduce 39) ((";") reduce 39) (("<") reduce 39) ((">") reduce 39) (("?") reduce 39) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_BOOLEAN_AND) reduce 39) ((T_BOOLEAN_OR) reduce 39) ((T_COALESCE) reduce 39) ((T_INSTANCEOF) reduce 39) ((T_IS_EQUAL) reduce 39) ((T_IS_GREATER_OR_EQUAL) reduce 39) ((T_IS_IDENTICAL) reduce 39) ((T_IS_NOT_EQUAL) reduce 39) ((T_IS_NOT_IDENTICAL) reduce 39) ((T_IS_SMALLER_OR_EQUAL) reduce 39) ((T_LOGICAL_AND) reduce 39) ((T_LOGICAL_OR) reduce 39) ((T_LOGICAL_XOR) reduce 39) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 39) ((T_OBJECT_OPERATOR) reduce 39) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 39) ((T_POW) reduce 39) ((T_SL) reduce 39) ((T_SPACESHIP) reduce 39) ((T_SR) reduce 39) (("[") reduce 39) (("^") reduce 39) (("{") reduce 39) (("|") reduce 39)) 3258 ((("%") reduce 25) (("(") reduce 25) (("*") reduce 25) (("+") reduce 25) ((",") reduce 25) (("-") reduce 25) ((".") reduce 25) (("/") reduce 25) ((";") reduce 25) (("<") reduce 25) ((">") reduce 25) (("?") reduce 25) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_BOOLEAN_AND) reduce 25) ((T_BOOLEAN_OR) reduce 25) ((T_COALESCE) reduce 25) ((T_INSTANCEOF) reduce 25) ((T_IS_EQUAL) reduce 25) ((T_IS_GREATER_OR_EQUAL) reduce 25) ((T_IS_IDENTICAL) reduce 25) ((T_IS_NOT_EQUAL) reduce 25) ((T_IS_NOT_IDENTICAL) reduce 25) ((T_IS_SMALLER_OR_EQUAL) reduce 25) ((T_LOGICAL_AND) reduce 25) ((T_LOGICAL_OR) reduce 25) ((T_LOGICAL_XOR) reduce 25) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 25) ((T_OBJECT_OPERATOR) reduce 25) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 25) ((T_POW) reduce 25) ((T_SL) reduce 25) ((T_SPACESHIP) reduce 25) ((T_SR) reduce 25) (("[") reduce 25) (("^") reduce 25) (("{") reduce 25) (("|") reduce 25)) 3259 ((("%") reduce 50) (("(") reduce 50) (("*") reduce 50) (("+") reduce 50) ((",") reduce 50) (("-") reduce 50) ((".") reduce 50) (("/") reduce 50) ((";") reduce 50) (("<") reduce 50) ((">") reduce 50) (("?") reduce 50) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_BOOLEAN_AND) reduce 50) ((T_BOOLEAN_OR) reduce 50) ((T_COALESCE) reduce 50) ((T_INSTANCEOF) reduce 50) ((T_IS_EQUAL) reduce 50) ((T_IS_GREATER_OR_EQUAL) reduce 50) ((T_IS_IDENTICAL) reduce 50) ((T_IS_NOT_EQUAL) reduce 50) ((T_IS_NOT_IDENTICAL) reduce 50) ((T_IS_SMALLER_OR_EQUAL) reduce 50) ((T_LOGICAL_AND) reduce 50) ((T_LOGICAL_OR) reduce 50) ((T_LOGICAL_XOR) reduce 50) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 50) ((T_OBJECT_OPERATOR) reduce 50) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 50) ((T_POW) reduce 50) ((T_SL) reduce 50) ((T_SPACESHIP) reduce 50) ((T_SR) reduce 50) (("[") reduce 50) (("^") reduce 50) (("{") reduce 50) (("|") reduce 50)) 3260 ((("%") reduce 66) (("(") reduce 66) (("*") reduce 66) (("+") reduce 66) ((",") reduce 66) (("-") reduce 66) ((".") reduce 66) (("/") reduce 66) ((";") reduce 66) (("<") reduce 66) ((">") reduce 66) (("?") reduce 66) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_BOOLEAN_AND) reduce 66) ((T_BOOLEAN_OR) reduce 66) ((T_COALESCE) reduce 66) ((T_INSTANCEOF) reduce 66) ((T_IS_EQUAL) reduce 66) ((T_IS_GREATER_OR_EQUAL) reduce 66) ((T_IS_IDENTICAL) reduce 66) ((T_IS_NOT_EQUAL) reduce 66) ((T_IS_NOT_IDENTICAL) reduce 66) ((T_IS_SMALLER_OR_EQUAL) reduce 66) ((T_LOGICAL_AND) reduce 66) ((T_LOGICAL_OR) reduce 66) ((T_LOGICAL_XOR) reduce 66) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 66) ((T_OBJECT_OPERATOR) reduce 66) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 66) ((T_POW) reduce 66) ((T_SL) reduce 66) ((T_SPACESHIP) reduce 66) ((T_SR) reduce 66) (("[") reduce 66) (("^") reduce 66) (("{") reduce 66) (("|") reduce 66)) 3261 ((("%") reduce 18) (("(") reduce 18) (("*") reduce 18) (("+") reduce 18) ((",") reduce 18) (("-") reduce 18) ((".") reduce 18) (("/") reduce 18) ((";") reduce 18) (("<") reduce 18) ((">") reduce 18) (("?") reduce 18) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_BOOLEAN_AND) reduce 18) ((T_BOOLEAN_OR) reduce 18) ((T_COALESCE) reduce 18) ((T_INSTANCEOF) reduce 18) ((T_IS_EQUAL) reduce 18) ((T_IS_GREATER_OR_EQUAL) reduce 18) ((T_IS_IDENTICAL) reduce 18) ((T_IS_NOT_EQUAL) reduce 18) ((T_IS_NOT_IDENTICAL) reduce 18) ((T_IS_SMALLER_OR_EQUAL) reduce 18) ((T_LOGICAL_AND) reduce 18) ((T_LOGICAL_OR) reduce 18) ((T_LOGICAL_XOR) reduce 18) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 18) ((T_OBJECT_OPERATOR) reduce 18) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 18) ((T_POW) reduce 18) ((T_SL) reduce 18) ((T_SPACESHIP) reduce 18) ((T_SR) reduce 18) (("[") reduce 18) (("^") reduce 18) (("{") reduce 18) (("|") reduce 18)) 3262 ((("%") reduce 17) (("(") reduce 17) (("*") reduce 17) (("+") reduce 17) ((",") reduce 17) (("-") reduce 17) ((".") reduce 17) (("/") reduce 17) ((";") reduce 17) (("<") reduce 17) ((">") reduce 17) (("?") reduce 17) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_BOOLEAN_AND) reduce 17) ((T_BOOLEAN_OR) reduce 17) ((T_COALESCE) reduce 17) ((T_INSTANCEOF) reduce 17) ((T_IS_EQUAL) reduce 17) ((T_IS_GREATER_OR_EQUAL) reduce 17) ((T_IS_IDENTICAL) reduce 17) ((T_IS_NOT_EQUAL) reduce 17) ((T_IS_NOT_IDENTICAL) reduce 17) ((T_IS_SMALLER_OR_EQUAL) reduce 17) ((T_LOGICAL_AND) reduce 17) ((T_LOGICAL_OR) reduce 17) ((T_LOGICAL_XOR) reduce 17) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 17) ((T_OBJECT_OPERATOR) reduce 17) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 17) ((T_POW) reduce 17) ((T_SL) reduce 17) ((T_SPACESHIP) reduce 17) ((T_SR) reduce 17) (("[") reduce 17) (("^") reduce 17) (("{") reduce 17) (("|") reduce 17)) 3263 ((("%") reduce 15) (("(") reduce 15) (("*") reduce 15) (("+") reduce 15) ((",") reduce 15) (("-") reduce 15) ((".") reduce 15) (("/") reduce 15) ((";") reduce 15) (("<") reduce 15) ((">") reduce 15) (("?") reduce 15) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_BOOLEAN_AND) reduce 15) ((T_BOOLEAN_OR) reduce 15) ((T_COALESCE) reduce 15) ((T_INSTANCEOF) reduce 15) ((T_IS_EQUAL) reduce 15) ((T_IS_GREATER_OR_EQUAL) reduce 15) ((T_IS_IDENTICAL) reduce 15) ((T_IS_NOT_EQUAL) reduce 15) ((T_IS_NOT_IDENTICAL) reduce 15) ((T_IS_SMALLER_OR_EQUAL) reduce 15) ((T_LOGICAL_AND) reduce 15) ((T_LOGICAL_OR) reduce 15) ((T_LOGICAL_XOR) reduce 15) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 15) ((T_OBJECT_OPERATOR) reduce 15) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 15) ((T_POW) reduce 15) ((T_SL) reduce 15) ((T_SPACESHIP) reduce 15) ((T_SR) reduce 15) (("[") reduce 15) (("^") reduce 15) (("{") reduce 15) (("|") reduce 15)) 3264 ((("%") reduce 14) (("(") reduce 14) (("*") reduce 14) (("+") reduce 14) ((",") reduce 14) (("-") reduce 14) ((".") reduce 14) (("/") reduce 14) ((";") reduce 14) (("<") reduce 14) ((">") reduce 14) (("?") reduce 14) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_BOOLEAN_AND) reduce 14) ((T_BOOLEAN_OR) reduce 14) ((T_COALESCE) reduce 14) ((T_INSTANCEOF) reduce 14) ((T_IS_EQUAL) reduce 14) ((T_IS_GREATER_OR_EQUAL) reduce 14) ((T_IS_IDENTICAL) reduce 14) ((T_IS_NOT_EQUAL) reduce 14) ((T_IS_NOT_IDENTICAL) reduce 14) ((T_IS_SMALLER_OR_EQUAL) reduce 14) ((T_LOGICAL_AND) reduce 14) ((T_LOGICAL_OR) reduce 14) ((T_LOGICAL_XOR) reduce 14) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 14) ((T_OBJECT_OPERATOR) reduce 14) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 14) ((T_POW) reduce 14) ((T_SL) reduce 14) ((T_SPACESHIP) reduce 14) ((T_SR) reduce 14) (("[") reduce 14) (("^") reduce 14) (("{") reduce 14) (("|") reduce 14)) 3265 ((("%") reduce 38) (("(") reduce 38) (("*") reduce 38) (("+") reduce 38) ((",") reduce 38) (("-") reduce 38) ((".") reduce 38) (("/") reduce 38) ((";") reduce 38) (("<") reduce 38) ((">") reduce 38) (("?") reduce 38) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_BOOLEAN_AND) reduce 38) ((T_BOOLEAN_OR) reduce 38) ((T_COALESCE) reduce 38) ((T_INSTANCEOF) reduce 38) ((T_IS_EQUAL) reduce 38) ((T_IS_GREATER_OR_EQUAL) reduce 38) ((T_IS_IDENTICAL) reduce 38) ((T_IS_NOT_EQUAL) reduce 38) ((T_IS_NOT_IDENTICAL) reduce 38) ((T_IS_SMALLER_OR_EQUAL) reduce 38) ((T_LOGICAL_AND) reduce 38) ((T_LOGICAL_OR) reduce 38) ((T_LOGICAL_XOR) reduce 38) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 38) ((T_OBJECT_OPERATOR) reduce 38) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 38) ((T_POW) reduce 38) ((T_SL) reduce 38) ((T_SPACESHIP) reduce 38) ((T_SR) reduce 38) (("[") reduce 38) (("^") reduce 38) (("{") reduce 38) (("|") reduce 38)) 3266 ((("%") reduce 26) (("(") reduce 26) (("*") reduce 26) (("+") reduce 26) ((",") reduce 26) (("-") reduce 26) ((".") reduce 26) (("/") reduce 26) ((";") reduce 26) (("<") reduce 26) ((">") reduce 26) (("?") reduce 26) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_BOOLEAN_AND) reduce 26) ((T_BOOLEAN_OR) reduce 26) ((T_COALESCE) reduce 26) ((T_INSTANCEOF) reduce 26) ((T_IS_EQUAL) reduce 26) ((T_IS_GREATER_OR_EQUAL) reduce 26) ((T_IS_IDENTICAL) reduce 26) ((T_IS_NOT_EQUAL) reduce 26) ((T_IS_NOT_IDENTICAL) reduce 26) ((T_IS_SMALLER_OR_EQUAL) reduce 26) ((T_LOGICAL_AND) reduce 26) ((T_LOGICAL_OR) reduce 26) ((T_LOGICAL_XOR) reduce 26) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 26) ((T_OBJECT_OPERATOR) reduce 26) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 26) ((T_POW) reduce 26) ((T_SL) reduce 26) ((T_SPACESHIP) reduce 26) ((T_SR) reduce 26) (("[") reduce 26) (("^") reduce 26) (("{") reduce 26) (("|") reduce 26)) 3267 ((("%") reduce 22) (("(") reduce 22) (("*") reduce 22) (("+") reduce 22) ((",") reduce 22) (("-") reduce 22) ((".") reduce 22) (("/") reduce 22) ((";") reduce 22) (("<") reduce 22) ((">") reduce 22) (("?") reduce 22) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_BOOLEAN_AND) reduce 22) ((T_BOOLEAN_OR) reduce 22) ((T_COALESCE) reduce 22) ((T_INSTANCEOF) reduce 22) ((T_IS_EQUAL) reduce 22) ((T_IS_GREATER_OR_EQUAL) reduce 22) ((T_IS_IDENTICAL) reduce 22) ((T_IS_NOT_EQUAL) reduce 22) ((T_IS_NOT_IDENTICAL) reduce 22) ((T_IS_SMALLER_OR_EQUAL) reduce 22) ((T_LOGICAL_AND) reduce 22) ((T_LOGICAL_OR) reduce 22) ((T_LOGICAL_XOR) reduce 22) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 22) ((T_OBJECT_OPERATOR) reduce 22) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 22) ((T_POW) reduce 22) ((T_SL) reduce 22) ((T_SPACESHIP) reduce 22) ((T_SR) reduce 22) (("[") reduce 22) (("^") reduce 22) (("{") reduce 22) (("|") reduce 22)) 3268 ((("%") reduce 24) (("(") reduce 24) (("*") reduce 24) (("+") reduce 24) ((",") reduce 24) (("-") reduce 24) ((".") reduce 24) (("/") reduce 24) ((";") reduce 24) (("<") reduce 24) ((">") reduce 24) (("?") reduce 24) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_BOOLEAN_AND) reduce 24) ((T_BOOLEAN_OR) reduce 24) ((T_COALESCE) reduce 24) ((T_INSTANCEOF) reduce 24) ((T_IS_EQUAL) reduce 24) ((T_IS_GREATER_OR_EQUAL) reduce 24) ((T_IS_IDENTICAL) reduce 24) ((T_IS_NOT_EQUAL) reduce 24) ((T_IS_NOT_IDENTICAL) reduce 24) ((T_IS_SMALLER_OR_EQUAL) reduce 24) ((T_LOGICAL_AND) reduce 24) ((T_LOGICAL_OR) reduce 24) ((T_LOGICAL_XOR) reduce 24) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 24) ((T_OBJECT_OPERATOR) reduce 24) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 24) ((T_POW) reduce 24) ((T_SL) reduce 24) ((T_SPACESHIP) reduce 24) ((T_SR) reduce 24) (("[") reduce 24) (("^") reduce 24) (("{") reduce 24) (("|") reduce 24)) 3269 ((("%") reduce 16) (("(") reduce 16) (("*") reduce 16) (("+") reduce 16) ((",") reduce 16) (("-") reduce 16) ((".") reduce 16) (("/") reduce 16) ((";") reduce 16) (("<") reduce 16) ((">") reduce 16) (("?") reduce 16) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_BOOLEAN_AND) reduce 16) ((T_BOOLEAN_OR) reduce 16) ((T_COALESCE) reduce 16) ((T_INSTANCEOF) reduce 16) ((T_IS_EQUAL) reduce 16) ((T_IS_GREATER_OR_EQUAL) reduce 16) ((T_IS_IDENTICAL) reduce 16) ((T_IS_NOT_EQUAL) reduce 16) ((T_IS_NOT_IDENTICAL) reduce 16) ((T_IS_SMALLER_OR_EQUAL) reduce 16) ((T_LOGICAL_AND) reduce 16) ((T_LOGICAL_OR) reduce 16) ((T_LOGICAL_XOR) reduce 16) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 16) ((T_OBJECT_OPERATOR) reduce 16) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 16) ((T_POW) reduce 16) ((T_SL) reduce 16) ((T_SPACESHIP) reduce 16) ((T_SR) reduce 16) (("[") reduce 16) (("^") reduce 16) (("{") reduce 16) (("|") reduce 16)) 3270 ((("%") reduce 48) (("(") reduce 48) (("*") reduce 48) (("+") reduce 48) ((",") reduce 48) (("-") reduce 48) ((".") reduce 48) (("/") reduce 48) ((";") reduce 48) (("<") reduce 48) ((">") reduce 48) (("?") reduce 48) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_BOOLEAN_AND) reduce 48) ((T_BOOLEAN_OR) reduce 48) ((T_COALESCE) reduce 48) ((T_INSTANCEOF) reduce 48) ((T_IS_EQUAL) reduce 48) ((T_IS_GREATER_OR_EQUAL) reduce 48) ((T_IS_IDENTICAL) reduce 48) ((T_IS_NOT_EQUAL) reduce 48) ((T_IS_NOT_IDENTICAL) reduce 48) ((T_IS_SMALLER_OR_EQUAL) reduce 48) ((T_LOGICAL_AND) reduce 48) ((T_LOGICAL_OR) reduce 48) ((T_LOGICAL_XOR) reduce 48) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 48) ((T_OBJECT_OPERATOR) reduce 48) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 48) ((T_POW) reduce 48) ((T_SL) reduce 48) ((T_SPACESHIP) reduce 48) ((T_SR) reduce 48) (("[") reduce 48) (("^") reduce 48) (("{") reduce 48) (("|") reduce 48)) 3271 ((("%") reduce 20) (("(") reduce 20) (("*") reduce 20) (("+") reduce 20) ((",") reduce 20) (("-") reduce 20) ((".") reduce 20) (("/") reduce 20) ((";") reduce 20) (("<") reduce 20) ((">") reduce 20) (("?") reduce 20) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_BOOLEAN_AND) reduce 20) ((T_BOOLEAN_OR) reduce 20) ((T_COALESCE) reduce 20) ((T_INSTANCEOF) reduce 20) ((T_IS_EQUAL) reduce 20) ((T_IS_GREATER_OR_EQUAL) reduce 20) ((T_IS_IDENTICAL) reduce 20) ((T_IS_NOT_EQUAL) reduce 20) ((T_IS_NOT_IDENTICAL) reduce 20) ((T_IS_SMALLER_OR_EQUAL) reduce 20) ((T_LOGICAL_AND) reduce 20) ((T_LOGICAL_OR) reduce 20) ((T_LOGICAL_XOR) reduce 20) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 20) ((T_OBJECT_OPERATOR) reduce 20) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 20) ((T_POW) reduce 20) ((T_SL) reduce 20) ((T_SPACESHIP) reduce 20) ((T_SR) reduce 20) (("[") reduce 20) (("^") reduce 20) (("{") reduce 20) (("|") reduce 20)) 3272 ((("%") reduce 70) (("(") reduce 70) (("*") reduce 70) (("+") reduce 70) ((",") reduce 70) (("-") reduce 70) ((".") reduce 70) (("/") reduce 70) ((";") reduce 70) (("<") reduce 70) ((">") reduce 70) (("?") reduce 70) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_BOOLEAN_AND) reduce 70) ((T_BOOLEAN_OR) reduce 70) ((T_COALESCE) reduce 70) ((T_INSTANCEOF) reduce 70) ((T_IS_EQUAL) reduce 70) ((T_IS_GREATER_OR_EQUAL) reduce 70) ((T_IS_IDENTICAL) reduce 70) ((T_IS_NOT_EQUAL) reduce 70) ((T_IS_NOT_IDENTICAL) reduce 70) ((T_IS_SMALLER_OR_EQUAL) reduce 70) ((T_LOGICAL_AND) reduce 70) ((T_LOGICAL_OR) reduce 70) ((T_LOGICAL_XOR) reduce 70) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 70) ((T_OBJECT_OPERATOR) reduce 70) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 70) ((T_POW) reduce 70) ((T_SL) reduce 70) ((T_SPACESHIP) reduce 70) ((T_SR) reduce 70) (("[") reduce 70) (("^") reduce 70) (("{") reduce 70) (("|") reduce 70)) 3273 ((("%") reduce 3) (("(") reduce 3) (("*") reduce 3) (("+") reduce 3) ((",") reduce 3) (("-") reduce 3) ((".") reduce 3) (("/") reduce 3) ((";") reduce 3) (("<") reduce 3) ((">") reduce 3) (("?") reduce 3) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_BOOLEAN_AND) reduce 3) ((T_BOOLEAN_OR) reduce 3) ((T_COALESCE) reduce 3) ((T_INSTANCEOF) reduce 3) ((T_IS_EQUAL) reduce 3) ((T_IS_GREATER_OR_EQUAL) reduce 3) ((T_IS_IDENTICAL) reduce 3) ((T_IS_NOT_EQUAL) reduce 3) ((T_IS_NOT_IDENTICAL) reduce 3) ((T_IS_SMALLER_OR_EQUAL) reduce 3) ((T_LOGICAL_AND) reduce 3) ((T_LOGICAL_OR) reduce 3) ((T_LOGICAL_XOR) reduce 3) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 3) ((T_OBJECT_OPERATOR) reduce 3) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 3) ((T_POW) reduce 3) ((T_SL) reduce 3) ((T_SPACESHIP) reduce 3) ((T_SR) reduce 3) (("[") reduce 3) (("^") reduce 3) (("{") reduce 3) (("|") reduce 3)) 3274 ((("%") reduce 12) (("(") reduce 12) (("*") reduce 12) (("+") reduce 12) ((",") reduce 12) (("-") reduce 12) ((".") reduce 12) (("/") reduce 12) ((";") reduce 12) (("<") reduce 12) ((">") reduce 12) (("?") reduce 12) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_BOOLEAN_AND) reduce 12) ((T_BOOLEAN_OR) reduce 12) ((T_COALESCE) reduce 12) ((T_INSTANCEOF) reduce 12) ((T_IS_EQUAL) reduce 12) ((T_IS_GREATER_OR_EQUAL) reduce 12) ((T_IS_IDENTICAL) reduce 12) ((T_IS_NOT_EQUAL) reduce 12) ((T_IS_NOT_IDENTICAL) reduce 12) ((T_IS_SMALLER_OR_EQUAL) reduce 12) ((T_LOGICAL_AND) reduce 12) ((T_LOGICAL_OR) reduce 12) ((T_LOGICAL_XOR) reduce 12) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 12) ((T_OBJECT_OPERATOR) reduce 12) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 12) ((T_POW) reduce 12) ((T_SL) reduce 12) ((T_SPACESHIP) reduce 12) ((T_SR) reduce 12) (("[") reduce 12) (("^") reduce 12) (("{") reduce 12) (("|") reduce 12)) 3275 ((("%") reduce 54) (("(") reduce 54) (("*") reduce 54) (("+") reduce 54) ((",") reduce 54) (("-") reduce 54) ((".") reduce 54) (("/") reduce 54) ((";") reduce 54) (("<") reduce 54) ((">") reduce 54) (("?") reduce 54) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_BOOLEAN_AND) reduce 54) ((T_BOOLEAN_OR) reduce 54) ((T_COALESCE) reduce 54) ((T_INSTANCEOF) reduce 54) ((T_IS_EQUAL) reduce 54) ((T_IS_GREATER_OR_EQUAL) reduce 54) ((T_IS_IDENTICAL) reduce 54) ((T_IS_NOT_EQUAL) reduce 54) ((T_IS_NOT_IDENTICAL) reduce 54) ((T_IS_SMALLER_OR_EQUAL) reduce 54) ((T_LOGICAL_AND) reduce 54) ((T_LOGICAL_OR) reduce 54) ((T_LOGICAL_XOR) reduce 54) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 54) ((T_OBJECT_OPERATOR) reduce 54) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 54) ((T_POW) reduce 54) ((T_SL) reduce 54) ((T_SPACESHIP) reduce 54) ((T_SR) reduce 54) (("[") reduce 54) (("^") reduce 54) (("{") reduce 54) (("|") reduce 54)) 3276 ((("%") reduce 65) (("(") reduce 65) (("*") reduce 65) (("+") reduce 65) ((",") reduce 65) (("-") reduce 65) ((".") reduce 65) (("/") reduce 65) ((";") reduce 65) (("<") reduce 65) ((">") reduce 65) (("?") reduce 65) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_BOOLEAN_AND) reduce 65) ((T_BOOLEAN_OR) reduce 65) ((T_COALESCE) reduce 65) ((T_INSTANCEOF) reduce 65) ((T_IS_EQUAL) reduce 65) ((T_IS_GREATER_OR_EQUAL) reduce 65) ((T_IS_IDENTICAL) reduce 65) ((T_IS_NOT_EQUAL) reduce 65) ((T_IS_NOT_IDENTICAL) reduce 65) ((T_IS_SMALLER_OR_EQUAL) reduce 65) ((T_LOGICAL_AND) reduce 65) ((T_LOGICAL_OR) reduce 65) ((T_LOGICAL_XOR) reduce 65) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 65) ((T_OBJECT_OPERATOR) reduce 65) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 65) ((T_POW) reduce 65) ((T_SL) reduce 65) ((T_SPACESHIP) reduce 65) ((T_SR) reduce 65) (("[") reduce 65) (("^") reduce 65) (("{") reduce 65) (("|") reduce 65)) 3277 ((("%") reduce 74) (("(") reduce 74) (("*") reduce 74) (("+") reduce 74) ((",") reduce 74) (("-") reduce 74) ((".") reduce 74) (("/") reduce 74) ((";") reduce 74) (("<") reduce 74) ((">") reduce 74) (("?") reduce 74) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_BOOLEAN_AND) reduce 74) ((T_BOOLEAN_OR) reduce 74) ((T_COALESCE) reduce 74) ((T_INSTANCEOF) reduce 74) ((T_IS_EQUAL) reduce 74) ((T_IS_GREATER_OR_EQUAL) reduce 74) ((T_IS_IDENTICAL) reduce 74) ((T_IS_NOT_EQUAL) reduce 74) ((T_IS_NOT_IDENTICAL) reduce 74) ((T_IS_SMALLER_OR_EQUAL) reduce 74) ((T_LOGICAL_AND) reduce 74) ((T_LOGICAL_OR) reduce 74) ((T_LOGICAL_XOR) reduce 74) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 74) ((T_OBJECT_OPERATOR) reduce 74) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 74) ((T_POW) reduce 74) ((T_SL) reduce 74) ((T_SPACESHIP) reduce 74) ((T_SR) reduce 74) (("[") reduce 74) (("^") reduce 74) (("{") reduce 74) (("|") reduce 74)) 3278 ((("%") reduce 30) (("(") reduce 30) (("*") reduce 30) (("+") reduce 30) ((",") reduce 30) (("-") reduce 30) ((".") reduce 30) (("/") reduce 30) ((";") reduce 30) (("<") reduce 30) ((">") reduce 30) (("?") reduce 30) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_BOOLEAN_AND) reduce 30) ((T_BOOLEAN_OR) reduce 30) ((T_COALESCE) reduce 30) ((T_INSTANCEOF) reduce 30) ((T_IS_EQUAL) reduce 30) ((T_IS_GREATER_OR_EQUAL) reduce 30) ((T_IS_IDENTICAL) reduce 30) ((T_IS_NOT_EQUAL) reduce 30) ((T_IS_NOT_IDENTICAL) reduce 30) ((T_IS_SMALLER_OR_EQUAL) reduce 30) ((T_LOGICAL_AND) reduce 30) ((T_LOGICAL_OR) reduce 30) ((T_LOGICAL_XOR) reduce 30) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 30) ((T_OBJECT_OPERATOR) reduce 30) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 30) ((T_POW) reduce 30) ((T_SL) reduce 30) ((T_SPACESHIP) reduce 30) ((T_SR) reduce 30) (("[") reduce 30) (("^") reduce 30) (("{") reduce 30) (("|") reduce 30)) 3279 ((("%") reduce 68) (("(") reduce 68) (("*") reduce 68) (("+") reduce 68) ((",") reduce 68) (("-") reduce 68) ((".") reduce 68) (("/") reduce 68) ((";") reduce 68) (("<") reduce 68) ((">") reduce 68) (("?") reduce 68) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_BOOLEAN_AND) reduce 68) ((T_BOOLEAN_OR) reduce 68) ((T_COALESCE) reduce 68) ((T_INSTANCEOF) reduce 68) ((T_IS_EQUAL) reduce 68) ((T_IS_GREATER_OR_EQUAL) reduce 68) ((T_IS_IDENTICAL) reduce 68) ((T_IS_NOT_EQUAL) reduce 68) ((T_IS_NOT_IDENTICAL) reduce 68) ((T_IS_SMALLER_OR_EQUAL) reduce 68) ((T_LOGICAL_AND) reduce 68) ((T_LOGICAL_OR) reduce 68) ((T_LOGICAL_XOR) reduce 68) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 68) ((T_OBJECT_OPERATOR) reduce 68) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 68) ((T_POW) reduce 68) ((T_SL) reduce 68) ((T_SPACESHIP) reduce 68) ((T_SR) reduce 68) (("[") reduce 68) (("^") reduce 68) (("{") reduce 68) (("|") reduce 68)) 3280 ((("%") reduce 21) (("(") reduce 21) (("*") reduce 21) (("+") reduce 21) ((",") reduce 21) (("-") reduce 21) ((".") reduce 21) (("/") reduce 21) ((";") reduce 21) (("<") reduce 21) ((">") reduce 21) (("?") reduce 21) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_BOOLEAN_AND) reduce 21) ((T_BOOLEAN_OR) reduce 21) ((T_COALESCE) reduce 21) ((T_INSTANCEOF) reduce 21) ((T_IS_EQUAL) reduce 21) ((T_IS_GREATER_OR_EQUAL) reduce 21) ((T_IS_IDENTICAL) reduce 21) ((T_IS_NOT_EQUAL) reduce 21) ((T_IS_NOT_IDENTICAL) reduce 21) ((T_IS_SMALLER_OR_EQUAL) reduce 21) ((T_LOGICAL_AND) reduce 21) ((T_LOGICAL_OR) reduce 21) ((T_LOGICAL_XOR) reduce 21) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 21) ((T_OBJECT_OPERATOR) reduce 21) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 21) ((T_POW) reduce 21) ((T_SL) reduce 21) ((T_SPACESHIP) reduce 21) ((T_SR) reduce 21) (("[") reduce 21) (("^") reduce 21) (("{") reduce 21) (("|") reduce 21)) 3281 ((("%") reduce 23) (("(") reduce 23) (("*") reduce 23) (("+") reduce 23) ((",") reduce 23) (("-") reduce 23) ((".") reduce 23) (("/") reduce 23) ((";") reduce 23) (("<") reduce 23) ((">") reduce 23) (("?") reduce 23) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_BOOLEAN_AND) reduce 23) ((T_BOOLEAN_OR) reduce 23) ((T_COALESCE) reduce 23) ((T_INSTANCEOF) reduce 23) ((T_IS_EQUAL) reduce 23) ((T_IS_GREATER_OR_EQUAL) reduce 23) ((T_IS_IDENTICAL) reduce 23) ((T_IS_NOT_EQUAL) reduce 23) ((T_IS_NOT_IDENTICAL) reduce 23) ((T_IS_SMALLER_OR_EQUAL) reduce 23) ((T_LOGICAL_AND) reduce 23) ((T_LOGICAL_OR) reduce 23) ((T_LOGICAL_XOR) reduce 23) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 23) ((T_OBJECT_OPERATOR) reduce 23) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 23) ((T_POW) reduce 23) ((T_SL) reduce 23) ((T_SPACESHIP) reduce 23) ((T_SR) reduce 23) (("[") reduce 23) (("^") reduce 23) (("{") reduce 23) (("|") reduce 23)) 3282 ((("%") reduce 41) (("(") reduce 41) (("*") reduce 41) (("+") reduce 41) ((",") reduce 41) (("-") reduce 41) ((".") reduce 41) (("/") reduce 41) ((";") reduce 41) (("<") reduce 41) ((">") reduce 41) (("?") reduce 41) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_BOOLEAN_AND) reduce 41) ((T_BOOLEAN_OR) reduce 41) ((T_COALESCE) reduce 41) ((T_INSTANCEOF) reduce 41) ((T_IS_EQUAL) reduce 41) ((T_IS_GREATER_OR_EQUAL) reduce 41) ((T_IS_IDENTICAL) reduce 41) ((T_IS_NOT_EQUAL) reduce 41) ((T_IS_NOT_IDENTICAL) reduce 41) ((T_IS_SMALLER_OR_EQUAL) reduce 41) ((T_LOGICAL_AND) reduce 41) ((T_LOGICAL_OR) reduce 41) ((T_LOGICAL_XOR) reduce 41) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 41) ((T_OBJECT_OPERATOR) reduce 41) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 41) ((T_POW) reduce 41) ((T_SL) reduce 41) ((T_SPACESHIP) reduce 41) ((T_SR) reduce 41) (("[") reduce 41) (("^") reduce 41) (("{") reduce 41) (("|") reduce 41)) 3283 ((("%") reduce 62) (("(") reduce 62) (("*") reduce 62) (("+") reduce 62) ((",") reduce 62) (("-") reduce 62) ((".") reduce 62) (("/") reduce 62) ((";") reduce 62) (("<") reduce 62) ((">") reduce 62) (("?") reduce 62) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_BOOLEAN_AND) reduce 62) ((T_BOOLEAN_OR) reduce 62) ((T_COALESCE) reduce 62) ((T_INSTANCEOF) reduce 62) ((T_IS_EQUAL) reduce 62) ((T_IS_GREATER_OR_EQUAL) reduce 62) ((T_IS_IDENTICAL) reduce 62) ((T_IS_NOT_EQUAL) reduce 62) ((T_IS_NOT_IDENTICAL) reduce 62) ((T_IS_SMALLER_OR_EQUAL) reduce 62) ((T_LOGICAL_AND) reduce 62) ((T_LOGICAL_OR) reduce 62) ((T_LOGICAL_XOR) reduce 62) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 62) ((T_OBJECT_OPERATOR) reduce 62) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 62) ((T_POW) reduce 62) ((T_SL) reduce 62) ((T_SPACESHIP) reduce 62) ((T_SR) reduce 62) (("[") reduce 62) (("^") reduce 62) (("{") reduce 62) (("|") reduce 62)) 3284 ((("%") reduce 34) (("(") reduce 34) (("*") reduce 34) (("+") reduce 34) ((",") reduce 34) (("-") reduce 34) ((".") reduce 34) (("/") reduce 34) ((";") reduce 34) (("<") reduce 34) ((">") reduce 34) (("?") reduce 34) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_BOOLEAN_AND) reduce 34) ((T_BOOLEAN_OR) reduce 34) ((T_COALESCE) reduce 34) ((T_INSTANCEOF) reduce 34) ((T_IS_EQUAL) reduce 34) ((T_IS_GREATER_OR_EQUAL) reduce 34) ((T_IS_IDENTICAL) reduce 34) ((T_IS_NOT_EQUAL) reduce 34) ((T_IS_NOT_IDENTICAL) reduce 34) ((T_IS_SMALLER_OR_EQUAL) reduce 34) ((T_LOGICAL_AND) reduce 34) ((T_LOGICAL_OR) reduce 34) ((T_LOGICAL_XOR) reduce 34) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 34) ((T_OBJECT_OPERATOR) reduce 34) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 34) ((T_POW) reduce 34) ((T_SL) reduce 34) ((T_SPACESHIP) reduce 34) ((T_SR) reduce 34) (("[") reduce 34) (("^") reduce 34) (("{") reduce 34) (("|") reduce 34)) 3285 ((("%") reduce 40) (("(") reduce 40) (("*") reduce 40) (("+") reduce 40) ((",") reduce 40) (("-") reduce 40) ((".") reduce 40) (("/") reduce 40) ((";") reduce 40) (("<") reduce 40) ((">") reduce 40) (("?") reduce 40) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_BOOLEAN_AND) reduce 40) ((T_BOOLEAN_OR) reduce 40) ((T_COALESCE) reduce 40) ((T_INSTANCEOF) reduce 40) ((T_IS_EQUAL) reduce 40) ((T_IS_GREATER_OR_EQUAL) reduce 40) ((T_IS_IDENTICAL) reduce 40) ((T_IS_NOT_EQUAL) reduce 40) ((T_IS_NOT_IDENTICAL) reduce 40) ((T_IS_SMALLER_OR_EQUAL) reduce 40) ((T_LOGICAL_AND) reduce 40) ((T_LOGICAL_OR) reduce 40) ((T_LOGICAL_XOR) reduce 40) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 40) ((T_OBJECT_OPERATOR) reduce 40) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 40) ((T_POW) reduce 40) ((T_SL) reduce 40) ((T_SPACESHIP) reduce 40) ((T_SR) reduce 40) (("[") reduce 40) (("^") reduce 40) (("{") reduce 40) (("|") reduce 40)) 3286 ((("%") reduce 13) (("(") reduce 13) (("*") reduce 13) (("+") reduce 13) ((",") reduce 13) (("-") reduce 13) ((".") reduce 13) (("/") reduce 13) ((";") reduce 13) (("<") reduce 13) ((">") reduce 13) (("?") reduce 13) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_BOOLEAN_AND) reduce 13) ((T_BOOLEAN_OR) reduce 13) ((T_COALESCE) reduce 13) ((T_INSTANCEOF) reduce 13) ((T_IS_EQUAL) reduce 13) ((T_IS_GREATER_OR_EQUAL) reduce 13) ((T_IS_IDENTICAL) reduce 13) ((T_IS_NOT_EQUAL) reduce 13) ((T_IS_NOT_IDENTICAL) reduce 13) ((T_IS_SMALLER_OR_EQUAL) reduce 13) ((T_LOGICAL_AND) reduce 13) ((T_LOGICAL_OR) reduce 13) ((T_LOGICAL_XOR) reduce 13) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 13) ((T_OBJECT_OPERATOR) reduce 13) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 13) ((T_POW) reduce 13) ((T_SL) reduce 13) ((T_SPACESHIP) reduce 13) ((T_SR) reduce 13) (("[") reduce 13) (("^") reduce 13) (("{") reduce 13) (("|") reduce 13)) 3287 ((("%") reduce 55) (("(") reduce 55) (("*") reduce 55) (("+") reduce 55) ((",") reduce 55) (("-") reduce 55) ((".") reduce 55) (("/") reduce 55) ((";") reduce 55) (("<") reduce 55) ((">") reduce 55) (("?") reduce 55) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_BOOLEAN_AND) reduce 55) ((T_BOOLEAN_OR) reduce 55) ((T_COALESCE) reduce 55) ((T_INSTANCEOF) reduce 55) ((T_IS_EQUAL) reduce 55) ((T_IS_GREATER_OR_EQUAL) reduce 55) ((T_IS_IDENTICAL) reduce 55) ((T_IS_NOT_EQUAL) reduce 55) ((T_IS_NOT_IDENTICAL) reduce 55) ((T_IS_SMALLER_OR_EQUAL) reduce 55) ((T_LOGICAL_AND) reduce 55) ((T_LOGICAL_OR) reduce 55) ((T_LOGICAL_XOR) reduce 55) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 55) ((T_OBJECT_OPERATOR) reduce 55) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 55) ((T_POW) reduce 55) ((T_SL) reduce 55) ((T_SPACESHIP) reduce 55) ((T_SR) reduce 55) (("[") reduce 55) (("^") reduce 55) (("{") reduce 55) (("|") reduce 55)) 3288 ((("%") reduce 1) (("(") reduce 1) (("*") reduce 1) (("+") reduce 1) ((",") reduce 1) (("-") reduce 1) ((".") reduce 1) (("/") reduce 1) ((";") reduce 1) (("<") reduce 1) ((">") reduce 1) (("?") reduce 1) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_BOOLEAN_AND) reduce 1) ((T_BOOLEAN_OR) reduce 1) ((T_COALESCE) reduce 1) ((T_INSTANCEOF) reduce 1) ((T_IS_EQUAL) reduce 1) ((T_IS_GREATER_OR_EQUAL) reduce 1) ((T_IS_IDENTICAL) reduce 1) ((T_IS_NOT_EQUAL) reduce 1) ((T_IS_NOT_IDENTICAL) reduce 1) ((T_IS_SMALLER_OR_EQUAL) reduce 1) ((T_LOGICAL_AND) reduce 1) ((T_LOGICAL_OR) reduce 1) ((T_LOGICAL_XOR) reduce 1) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 1) ((T_OBJECT_OPERATOR) reduce 1) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 1) ((T_POW) reduce 1) ((T_SL) reduce 1) ((T_SPACESHIP) reduce 1) ((T_SR) reduce 1) (("[") reduce 1) (("^") reduce 1) (("{") reduce 1) (("|") reduce 1)) 3289 ((("%") reduce 2) (("(") reduce 2) (("*") reduce 2) (("+") reduce 2) ((",") reduce 2) (("-") reduce 2) ((".") reduce 2) (("/") reduce 2) ((";") reduce 2) (("<") reduce 2) ((">") reduce 2) (("?") reduce 2) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_BOOLEAN_AND) reduce 2) ((T_BOOLEAN_OR) reduce 2) ((T_COALESCE) reduce 2) ((T_INSTANCEOF) reduce 2) ((T_IS_EQUAL) reduce 2) ((T_IS_GREATER_OR_EQUAL) reduce 2) ((T_IS_IDENTICAL) reduce 2) ((T_IS_NOT_EQUAL) reduce 2) ((T_IS_NOT_IDENTICAL) reduce 2) ((T_IS_SMALLER_OR_EQUAL) reduce 2) ((T_LOGICAL_AND) reduce 2) ((T_LOGICAL_OR) reduce 2) ((T_LOGICAL_XOR) reduce 2) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 2) ((T_OBJECT_OPERATOR) reduce 2) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 2) ((T_POW) reduce 2) ((T_SL) reduce 2) ((T_SPACESHIP) reduce 2) ((T_SR) reduce 2) (("[") reduce 2) (("^") reduce 2) (("{") reduce 2) (("|") reduce 2)) 3290 ((("%") reduce 9) (("(") reduce 9) (("*") reduce 9) (("+") reduce 9) ((",") reduce 9) (("-") reduce 9) ((".") reduce 9) (("/") reduce 9) ((";") reduce 9) (("<") reduce 9) ((">") reduce 9) (("?") reduce 9) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_BOOLEAN_AND) reduce 9) ((T_BOOLEAN_OR) reduce 9) ((T_COALESCE) reduce 9) ((T_INSTANCEOF) reduce 9) ((T_IS_EQUAL) reduce 9) ((T_IS_GREATER_OR_EQUAL) reduce 9) ((T_IS_IDENTICAL) reduce 9) ((T_IS_NOT_EQUAL) reduce 9) ((T_IS_NOT_IDENTICAL) reduce 9) ((T_IS_SMALLER_OR_EQUAL) reduce 9) ((T_LOGICAL_AND) reduce 9) ((T_LOGICAL_OR) reduce 9) ((T_LOGICAL_XOR) reduce 9) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 9) ((T_OBJECT_OPERATOR) reduce 9) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 9) ((T_POW) reduce 9) ((T_SL) reduce 9) ((T_SPACESHIP) reduce 9) ((T_SR) reduce 9) (("[") reduce 9) (("^") reduce 9) (("{") reduce 9) (("|") reduce 9)) 3291 ((("%") reduce 33) (("(") reduce 33) (("*") reduce 33) (("+") reduce 33) ((",") reduce 33) (("-") reduce 33) ((".") reduce 33) (("/") reduce 33) ((";") reduce 33) (("<") reduce 33) ((">") reduce 33) (("?") reduce 33) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_BOOLEAN_AND) reduce 33) ((T_BOOLEAN_OR) reduce 33) ((T_COALESCE) reduce 33) ((T_INSTANCEOF) reduce 33) ((T_IS_EQUAL) reduce 33) ((T_IS_GREATER_OR_EQUAL) reduce 33) ((T_IS_IDENTICAL) reduce 33) ((T_IS_NOT_EQUAL) reduce 33) ((T_IS_NOT_IDENTICAL) reduce 33) ((T_IS_SMALLER_OR_EQUAL) reduce 33) ((T_LOGICAL_AND) reduce 33) ((T_LOGICAL_OR) reduce 33) ((T_LOGICAL_XOR) reduce 33) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 33) ((T_OBJECT_OPERATOR) reduce 33) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 33) ((T_POW) reduce 33) ((T_SL) reduce 33) ((T_SPACESHIP) reduce 33) ((T_SR) reduce 33) (("[") reduce 33) (("^") reduce 33) (("{") reduce 33) (("|") reduce 33)) 3292 ((("%") reduce 58) (("(") reduce 58) (("*") reduce 58) (("+") reduce 58) ((",") reduce 58) (("-") reduce 58) ((".") reduce 58) (("/") reduce 58) ((";") reduce 58) (("<") reduce 58) ((">") reduce 58) (("?") reduce 58) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_BOOLEAN_AND) reduce 58) ((T_BOOLEAN_OR) reduce 58) ((T_COALESCE) reduce 58) ((T_INSTANCEOF) reduce 58) ((T_IS_EQUAL) reduce 58) ((T_IS_GREATER_OR_EQUAL) reduce 58) ((T_IS_IDENTICAL) reduce 58) ((T_IS_NOT_EQUAL) reduce 58) ((T_IS_NOT_IDENTICAL) reduce 58) ((T_IS_SMALLER_OR_EQUAL) reduce 58) ((T_LOGICAL_AND) reduce 58) ((T_LOGICAL_OR) reduce 58) ((T_LOGICAL_XOR) reduce 58) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 58) ((T_OBJECT_OPERATOR) reduce 58) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 58) ((T_POW) reduce 58) ((T_SL) reduce 58) ((T_SPACESHIP) reduce 58) ((T_SR) reduce 58) (("[") reduce 58) (("^") reduce 58) (("{") reduce 58) (("|") reduce 58)) 3293 ((("%") reduce 37) (("(") reduce 37) (("*") reduce 37) (("+") reduce 37) ((",") reduce 37) (("-") reduce 37) ((".") reduce 37) (("/") reduce 37) ((";") reduce 37) (("<") reduce 37) ((">") reduce 37) (("?") reduce 37) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_BOOLEAN_AND) reduce 37) ((T_BOOLEAN_OR) reduce 37) ((T_COALESCE) reduce 37) ((T_INSTANCEOF) reduce 37) ((T_IS_EQUAL) reduce 37) ((T_IS_GREATER_OR_EQUAL) reduce 37) ((T_IS_IDENTICAL) reduce 37) ((T_IS_NOT_EQUAL) reduce 37) ((T_IS_NOT_IDENTICAL) reduce 37) ((T_IS_SMALLER_OR_EQUAL) reduce 37) ((T_LOGICAL_AND) reduce 37) ((T_LOGICAL_OR) reduce 37) ((T_LOGICAL_XOR) reduce 37) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 37) ((T_OBJECT_OPERATOR) reduce 37) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 37) ((T_POW) reduce 37) ((T_SL) reduce 37) ((T_SPACESHIP) reduce 37) ((T_SR) reduce 37) (("[") reduce 37) (("^") reduce 37) (("{") reduce 37) (("|") reduce 37)) 3294 ((("%") reduce 64) (("(") reduce 64) (("*") reduce 64) (("+") reduce 64) ((",") reduce 64) (("-") reduce 64) ((".") reduce 64) (("/") reduce 64) ((";") reduce 64) (("<") reduce 64) ((">") reduce 64) (("?") reduce 64) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_BOOLEAN_AND) reduce 64) ((T_BOOLEAN_OR) reduce 64) ((T_COALESCE) reduce 64) ((T_INSTANCEOF) reduce 64) ((T_IS_EQUAL) reduce 64) ((T_IS_GREATER_OR_EQUAL) reduce 64) ((T_IS_IDENTICAL) reduce 64) ((T_IS_NOT_EQUAL) reduce 64) ((T_IS_NOT_IDENTICAL) reduce 64) ((T_IS_SMALLER_OR_EQUAL) reduce 64) ((T_LOGICAL_AND) reduce 64) ((T_LOGICAL_OR) reduce 64) ((T_LOGICAL_XOR) reduce 64) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 64) ((T_OBJECT_OPERATOR) reduce 64) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 64) ((T_POW) reduce 64) ((T_SL) reduce 64) ((T_SPACESHIP) reduce 64) ((T_SR) reduce 64) (("[") reduce 64) (("^") reduce 64) (("{") reduce 64) (("|") reduce 64)) 3295 ((("%") reduce 46) (("(") reduce 46) (("*") reduce 46) (("+") reduce 46) ((",") reduce 46) (("-") reduce 46) ((".") reduce 46) (("/") reduce 46) ((";") reduce 46) (("<") reduce 46) ((">") reduce 46) (("?") reduce 46) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_BOOLEAN_AND) reduce 46) ((T_BOOLEAN_OR) reduce 46) ((T_COALESCE) reduce 46) ((T_INSTANCEOF) reduce 46) ((T_IS_EQUAL) reduce 46) ((T_IS_GREATER_OR_EQUAL) reduce 46) ((T_IS_IDENTICAL) reduce 46) ((T_IS_NOT_EQUAL) reduce 46) ((T_IS_NOT_IDENTICAL) reduce 46) ((T_IS_SMALLER_OR_EQUAL) reduce 46) ((T_LOGICAL_AND) reduce 46) ((T_LOGICAL_OR) reduce 46) ((T_LOGICAL_XOR) reduce 46) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 46) ((T_OBJECT_OPERATOR) reduce 46) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 46) ((T_POW) reduce 46) ((T_SL) reduce 46) ((T_SPACESHIP) reduce 46) ((T_SR) reduce 46) (("[") reduce 46) (("^") reduce 46) (("{") reduce 46) (("|") reduce 46)) 3296 ((("%") reduce 8) (("(") reduce 8) (("*") reduce 8) (("+") reduce 8) ((",") reduce 8) (("-") reduce 8) ((".") reduce 8) (("/") reduce 8) ((";") reduce 8) (("<") reduce 8) ((">") reduce 8) (("?") reduce 8) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_BOOLEAN_AND) reduce 8) ((T_BOOLEAN_OR) reduce 8) ((T_COALESCE) reduce 8) ((T_INSTANCEOF) reduce 8) ((T_IS_EQUAL) reduce 8) ((T_IS_GREATER_OR_EQUAL) reduce 8) ((T_IS_IDENTICAL) reduce 8) ((T_IS_NOT_EQUAL) reduce 8) ((T_IS_NOT_IDENTICAL) reduce 8) ((T_IS_SMALLER_OR_EQUAL) reduce 8) ((T_LOGICAL_AND) reduce 8) ((T_LOGICAL_OR) reduce 8) ((T_LOGICAL_XOR) reduce 8) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 8) ((T_OBJECT_OPERATOR) reduce 8) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 8) ((T_POW) reduce 8) ((T_SL) reduce 8) ((T_SPACESHIP) reduce 8) ((T_SR) reduce 8) (("[") reduce 8) (("^") reduce 8) (("{") reduce 8) (("|") reduce 8)) 3297 ((("%") reduce 6) (("(") reduce 6) (("*") reduce 6) (("+") reduce 6) ((",") reduce 6) (("-") reduce 6) ((".") reduce 6) (("/") reduce 6) ((";") reduce 6) (("<") reduce 6) ((">") reduce 6) (("?") reduce 6) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_BOOLEAN_AND) reduce 6) ((T_BOOLEAN_OR) reduce 6) ((T_COALESCE) reduce 6) ((T_INSTANCEOF) reduce 6) ((T_IS_EQUAL) reduce 6) ((T_IS_GREATER_OR_EQUAL) reduce 6) ((T_IS_IDENTICAL) reduce 6) ((T_IS_NOT_EQUAL) reduce 6) ((T_IS_NOT_IDENTICAL) reduce 6) ((T_IS_SMALLER_OR_EQUAL) reduce 6) ((T_LOGICAL_AND) reduce 6) ((T_LOGICAL_OR) reduce 6) ((T_LOGICAL_XOR) reduce 6) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 6) ((T_OBJECT_OPERATOR) reduce 6) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 6) ((T_POW) reduce 6) ((T_SL) reduce 6) ((T_SPACESHIP) reduce 6) ((T_SR) reduce 6) (("[") reduce 6) (("^") reduce 6) (("{") reduce 6) (("|") reduce 6)) 3298 ((("%") reduce 7) (("(") reduce 7) (("*") reduce 7) (("+") reduce 7) ((",") reduce 7) (("-") reduce 7) ((".") reduce 7) (("/") reduce 7) ((";") reduce 7) (("<") reduce 7) ((">") reduce 7) (("?") reduce 7) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_BOOLEAN_AND) reduce 7) ((T_BOOLEAN_OR) reduce 7) ((T_COALESCE) reduce 7) ((T_INSTANCEOF) reduce 7) ((T_IS_EQUAL) reduce 7) ((T_IS_GREATER_OR_EQUAL) reduce 7) ((T_IS_IDENTICAL) reduce 7) ((T_IS_NOT_EQUAL) reduce 7) ((T_IS_NOT_IDENTICAL) reduce 7) ((T_IS_SMALLER_OR_EQUAL) reduce 7) ((T_LOGICAL_AND) reduce 7) ((T_LOGICAL_OR) reduce 7) ((T_LOGICAL_XOR) reduce 7) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 7) ((T_OBJECT_OPERATOR) reduce 7) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 7) ((T_POW) reduce 7) ((T_SL) reduce 7) ((T_SPACESHIP) reduce 7) ((T_SR) reduce 7) (("[") reduce 7) (("^") reduce 7) (("{") reduce 7) (("|") reduce 7)) 3299 ((("%") reduce 69) (("(") reduce 69) (("*") reduce 69) (("+") reduce 69) ((",") reduce 69) (("-") reduce 69) ((".") reduce 69) (("/") reduce 69) ((";") reduce 69) (("<") reduce 69) ((">") reduce 69) (("?") reduce 69) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_BOOLEAN_AND) reduce 69) ((T_BOOLEAN_OR) reduce 69) ((T_COALESCE) reduce 69) ((T_INSTANCEOF) reduce 69) ((T_IS_EQUAL) reduce 69) ((T_IS_GREATER_OR_EQUAL) reduce 69) ((T_IS_IDENTICAL) reduce 69) ((T_IS_NOT_EQUAL) reduce 69) ((T_IS_NOT_IDENTICAL) reduce 69) ((T_IS_SMALLER_OR_EQUAL) reduce 69) ((T_LOGICAL_AND) reduce 69) ((T_LOGICAL_OR) reduce 69) ((T_LOGICAL_XOR) reduce 69) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 69) ((T_OBJECT_OPERATOR) reduce 69) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 69) ((T_POW) reduce 69) ((T_SL) reduce 69) ((T_SPACESHIP) reduce 69) ((T_SR) reduce 69) (("[") reduce 69) (("^") reduce 69) (("{") reduce 69) (("|") reduce 69)) 3300 ((("%") reduce 63) (("(") reduce 63) (("*") reduce 63) (("+") reduce 63) ((",") reduce 63) (("-") reduce 63) ((".") reduce 63) (("/") reduce 63) ((";") reduce 63) (("<") reduce 63) ((">") reduce 63) (("?") reduce 63) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_BOOLEAN_AND) reduce 63) ((T_BOOLEAN_OR) reduce 63) ((T_COALESCE) reduce 63) ((T_INSTANCEOF) reduce 63) ((T_IS_EQUAL) reduce 63) ((T_IS_GREATER_OR_EQUAL) reduce 63) ((T_IS_IDENTICAL) reduce 63) ((T_IS_NOT_EQUAL) reduce 63) ((T_IS_NOT_IDENTICAL) reduce 63) ((T_IS_SMALLER_OR_EQUAL) reduce 63) ((T_LOGICAL_AND) reduce 63) ((T_LOGICAL_OR) reduce 63) ((T_LOGICAL_XOR) reduce 63) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 63) ((T_OBJECT_OPERATOR) reduce 63) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 63) ((T_POW) reduce 63) ((T_SL) reduce 63) ((T_SPACESHIP) reduce 63) ((T_SR) reduce 63) (("[") reduce 63) (("^") reduce 63) (("{") reduce 63) (("|") reduce 63)) 3301 ((("%") reduce 56) (("(") reduce 56) (("*") reduce 56) (("+") reduce 56) ((",") reduce 56) (("-") reduce 56) ((".") reduce 56) (("/") reduce 56) ((";") reduce 56) (("<") reduce 56) ((">") reduce 56) (("?") reduce 56) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_BOOLEAN_AND) reduce 56) ((T_BOOLEAN_OR) reduce 56) ((T_COALESCE) reduce 56) ((T_INSTANCEOF) reduce 56) ((T_IS_EQUAL) reduce 56) ((T_IS_GREATER_OR_EQUAL) reduce 56) ((T_IS_IDENTICAL) reduce 56) ((T_IS_NOT_EQUAL) reduce 56) ((T_IS_NOT_IDENTICAL) reduce 56) ((T_IS_SMALLER_OR_EQUAL) reduce 56) ((T_LOGICAL_AND) reduce 56) ((T_LOGICAL_OR) reduce 56) ((T_LOGICAL_XOR) reduce 56) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 56) ((T_OBJECT_OPERATOR) reduce 56) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 56) ((T_POW) reduce 56) ((T_SL) reduce 56) ((T_SPACESHIP) reduce 56) ((T_SR) reduce 56) (("[") reduce 56) (("^") reduce 56) (("{") reduce 56) (("|") reduce 56)) 3302 ((("%") reduce 10) (("(") reduce 10) (("*") reduce 10) (("+") reduce 10) ((",") reduce 10) (("-") reduce 10) ((".") reduce 10) (("/") reduce 10) ((";") reduce 10) (("<") reduce 10) ((">") reduce 10) (("?") reduce 10) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_BOOLEAN_AND) reduce 10) ((T_BOOLEAN_OR) reduce 10) ((T_COALESCE) reduce 10) ((T_INSTANCEOF) reduce 10) ((T_IS_EQUAL) reduce 10) ((T_IS_GREATER_OR_EQUAL) reduce 10) ((T_IS_IDENTICAL) reduce 10) ((T_IS_NOT_EQUAL) reduce 10) ((T_IS_NOT_IDENTICAL) reduce 10) ((T_IS_SMALLER_OR_EQUAL) reduce 10) ((T_LOGICAL_AND) reduce 10) ((T_LOGICAL_OR) reduce 10) ((T_LOGICAL_XOR) reduce 10) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 10) ((T_OBJECT_OPERATOR) reduce 10) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 10) ((T_POW) reduce 10) ((T_SL) reduce 10) ((T_SPACESHIP) reduce 10) ((T_SR) reduce 10) (("[") reduce 10) (("^") reduce 10) (("{") reduce 10) (("|") reduce 10)) 3303 ((("%") reduce 67) (("(") reduce 67) (("*") reduce 67) (("+") reduce 67) ((",") reduce 67) (("-") reduce 67) ((".") reduce 67) (("/") reduce 67) ((";") reduce 67) (("<") reduce 67) ((">") reduce 67) (("?") reduce 67) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_BOOLEAN_AND) reduce 67) ((T_BOOLEAN_OR) reduce 67) ((T_COALESCE) reduce 67) ((T_INSTANCEOF) reduce 67) ((T_IS_EQUAL) reduce 67) ((T_IS_GREATER_OR_EQUAL) reduce 67) ((T_IS_IDENTICAL) reduce 67) ((T_IS_NOT_EQUAL) reduce 67) ((T_IS_NOT_IDENTICAL) reduce 67) ((T_IS_SMALLER_OR_EQUAL) reduce 67) ((T_LOGICAL_AND) reduce 67) ((T_LOGICAL_OR) reduce 67) ((T_LOGICAL_XOR) reduce 67) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 67) ((T_OBJECT_OPERATOR) reduce 67) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 67) ((T_POW) reduce 67) ((T_SL) reduce 67) ((T_SPACESHIP) reduce 67) ((T_SR) reduce 67) (("[") reduce 67) (("^") reduce 67) (("{") reduce 67) (("|") reduce 67)) 3304 ((("%") reduce 44) (("(") reduce 44) (("*") reduce 44) (("+") reduce 44) ((",") reduce 44) (("-") reduce 44) ((".") reduce 44) (("/") reduce 44) ((";") reduce 44) (("<") reduce 44) ((">") reduce 44) (("?") reduce 44) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_BOOLEAN_AND) reduce 44) ((T_BOOLEAN_OR) reduce 44) ((T_COALESCE) reduce 44) ((T_INSTANCEOF) reduce 44) ((T_IS_EQUAL) reduce 44) ((T_IS_GREATER_OR_EQUAL) reduce 44) ((T_IS_IDENTICAL) reduce 44) ((T_IS_NOT_EQUAL) reduce 44) ((T_IS_NOT_IDENTICAL) reduce 44) ((T_IS_SMALLER_OR_EQUAL) reduce 44) ((T_LOGICAL_AND) reduce 44) ((T_LOGICAL_OR) reduce 44) ((T_LOGICAL_XOR) reduce 44) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 44) ((T_OBJECT_OPERATOR) reduce 44) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 44) ((T_POW) reduce 44) ((T_SL) reduce 44) ((T_SPACESHIP) reduce 44) ((T_SR) reduce 44) (("[") reduce 44) (("^") reduce 44) (("{") reduce 44) (("|") reduce 44)) 3305 ((("%") reduce 75) (("(") reduce 75) (("*") reduce 75) (("+") reduce 75) ((",") reduce 75) (("-") reduce 75) ((".") reduce 75) (("/") reduce 75) ((";") reduce 75) (("<") reduce 75) ((">") reduce 75) (("?") reduce 75) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_BOOLEAN_AND) reduce 75) ((T_BOOLEAN_OR) reduce 75) ((T_COALESCE) reduce 75) ((T_INSTANCEOF) reduce 75) ((T_IS_EQUAL) reduce 75) ((T_IS_GREATER_OR_EQUAL) reduce 75) ((T_IS_IDENTICAL) reduce 75) ((T_IS_NOT_EQUAL) reduce 75) ((T_IS_NOT_IDENTICAL) reduce 75) ((T_IS_SMALLER_OR_EQUAL) reduce 75) ((T_LOGICAL_AND) reduce 75) ((T_LOGICAL_OR) reduce 75) ((T_LOGICAL_XOR) reduce 75) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 75) ((T_OBJECT_OPERATOR) reduce 75) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 75) ((T_POW) reduce 75) ((T_SL) reduce 75) ((T_SPACESHIP) reduce 75) ((T_SR) reduce 75) (("[") reduce 75) (("^") reduce 75) (("{") reduce 75) (("|") reduce 75)) 3306 ((("%") reduce 76) (("(") reduce 76) (("*") reduce 76) (("+") reduce 76) ((",") reduce 76) (("-") reduce 76) ((".") reduce 76) (("/") reduce 76) ((";") reduce 76) (("<") reduce 76) ((">") reduce 76) (("?") reduce 76) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_BOOLEAN_AND) reduce 76) ((T_BOOLEAN_OR) reduce 76) ((T_COALESCE) reduce 76) ((T_INSTANCEOF) reduce 76) ((T_IS_EQUAL) reduce 76) ((T_IS_GREATER_OR_EQUAL) reduce 76) ((T_IS_IDENTICAL) reduce 76) ((T_IS_NOT_EQUAL) reduce 76) ((T_IS_NOT_IDENTICAL) reduce 76) ((T_IS_SMALLER_OR_EQUAL) reduce 76) ((T_LOGICAL_AND) reduce 76) ((T_LOGICAL_OR) reduce 76) ((T_LOGICAL_XOR) reduce 76) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 76) ((T_OBJECT_OPERATOR) reduce 76) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 76) ((T_POW) reduce 76) ((T_SL) reduce 76) ((T_SPACESHIP) reduce 76) ((T_SR) reduce 76) (("[") reduce 76) (("^") reduce 76) (("{") reduce 76) (("|") reduce 76)) 3307 ((("%") reduce 77) (("(") reduce 77) (("*") reduce 77) (("+") reduce 77) ((",") reduce 77) (("-") reduce 77) ((".") reduce 77) (("/") reduce 77) ((";") reduce 77) (("<") reduce 77) ((">") reduce 77) (("?") reduce 77) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_BOOLEAN_AND) reduce 77) ((T_BOOLEAN_OR) reduce 77) ((T_COALESCE) reduce 77) ((T_INSTANCEOF) reduce 77) ((T_IS_EQUAL) reduce 77) ((T_IS_GREATER_OR_EQUAL) reduce 77) ((T_IS_IDENTICAL) reduce 77) ((T_IS_NOT_EQUAL) reduce 77) ((T_IS_NOT_IDENTICAL) reduce 77) ((T_IS_SMALLER_OR_EQUAL) reduce 77) ((T_LOGICAL_AND) reduce 77) ((T_LOGICAL_OR) reduce 77) ((T_LOGICAL_XOR) reduce 77) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 77) ((T_OBJECT_OPERATOR) reduce 77) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 77) ((T_POW) reduce 77) ((T_SL) reduce 77) ((T_SPACESHIP) reduce 77) ((T_SR) reduce 77) (("[") reduce 77) (("^") reduce 77) (("{") reduce 77) (("|") reduce 77)) 3308 ((("%") reduce 78) (("(") reduce 78) (("*") reduce 78) (("+") reduce 78) ((",") reduce 78) (("-") reduce 78) ((".") reduce 78) (("/") reduce 78) ((";") reduce 78) (("<") reduce 78) ((">") reduce 78) (("?") reduce 78) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_BOOLEAN_AND) reduce 78) ((T_BOOLEAN_OR) reduce 78) ((T_COALESCE) reduce 78) ((T_INSTANCEOF) reduce 78) ((T_IS_EQUAL) reduce 78) ((T_IS_GREATER_OR_EQUAL) reduce 78) ((T_IS_IDENTICAL) reduce 78) ((T_IS_NOT_EQUAL) reduce 78) ((T_IS_NOT_IDENTICAL) reduce 78) ((T_IS_SMALLER_OR_EQUAL) reduce 78) ((T_LOGICAL_AND) reduce 78) ((T_LOGICAL_OR) reduce 78) ((T_LOGICAL_XOR) reduce 78) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 78) ((T_OBJECT_OPERATOR) reduce 78) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 78) ((T_POW) reduce 78) ((T_SL) reduce 78) ((T_SPACESHIP) reduce 78) ((T_SR) reduce 78) (("[") reduce 78) (("^") reduce 78) (("{") reduce 78) (("|") reduce 78)) 3309 ((("%") reduce 4) (("(") reduce 4) (("*") reduce 4) (("+") reduce 4) ((",") reduce 4) (("-") reduce 4) ((".") reduce 4) (("/") reduce 4) ((";") reduce 4) (("<") reduce 4) ((">") reduce 4) (("?") reduce 4) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_BOOLEAN_AND) reduce 4) ((T_BOOLEAN_OR) reduce 4) ((T_COALESCE) reduce 4) ((T_INSTANCEOF) reduce 4) ((T_IS_EQUAL) reduce 4) ((T_IS_GREATER_OR_EQUAL) reduce 4) ((T_IS_IDENTICAL) reduce 4) ((T_IS_NOT_EQUAL) reduce 4) ((T_IS_NOT_IDENTICAL) reduce 4) ((T_IS_SMALLER_OR_EQUAL) reduce 4) ((T_LOGICAL_AND) reduce 4) ((T_LOGICAL_OR) reduce 4) ((T_LOGICAL_XOR) reduce 4) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 4) ((T_OBJECT_OPERATOR) reduce 4) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 4) ((T_POW) reduce 4) ((T_SL) reduce 4) ((T_SPACESHIP) reduce 4) ((T_SR) reduce 4) (("[") reduce 4) (("^") reduce 4) (("{") reduce 4) (("|") reduce 4)) 3310 ((("%") reduce 5) (("(") reduce 5) (("*") reduce 5) (("+") reduce 5) ((",") reduce 5) (("-") reduce 5) ((".") reduce 5) (("/") reduce 5) ((";") reduce 5) (("<") reduce 5) ((">") reduce 5) (("?") reduce 5) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_BOOLEAN_AND) reduce 5) ((T_BOOLEAN_OR) reduce 5) ((T_COALESCE) reduce 5) ((T_INSTANCEOF) reduce 5) ((T_IS_EQUAL) reduce 5) ((T_IS_GREATER_OR_EQUAL) reduce 5) ((T_IS_IDENTICAL) reduce 5) ((T_IS_NOT_EQUAL) reduce 5) ((T_IS_NOT_IDENTICAL) reduce 5) ((T_IS_SMALLER_OR_EQUAL) reduce 5) ((T_LOGICAL_AND) reduce 5) ((T_LOGICAL_OR) reduce 5) ((T_LOGICAL_XOR) reduce 5) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 5) ((T_OBJECT_OPERATOR) reduce 5) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 5) ((T_POW) reduce 5) ((T_SL) reduce 5) ((T_SPACESHIP) reduce 5) ((T_SR) reduce 5) (("[") reduce 5) (("^") reduce 5) (("{") reduce 5) (("|") reduce 5)) 3311 ((("%") reduce 43) (("(") reduce 43) (("*") reduce 43) (("+") reduce 43) ((",") reduce 43) (("-") reduce 43) ((".") reduce 43) (("/") reduce 43) ((";") reduce 43) (("<") reduce 43) ((">") reduce 43) (("?") reduce 43) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_BOOLEAN_AND) reduce 43) ((T_BOOLEAN_OR) reduce 43) ((T_COALESCE) reduce 43) ((T_INSTANCEOF) reduce 43) ((T_IS_EQUAL) reduce 43) ((T_IS_GREATER_OR_EQUAL) reduce 43) ((T_IS_IDENTICAL) reduce 43) ((T_IS_NOT_EQUAL) reduce 43) ((T_IS_NOT_IDENTICAL) reduce 43) ((T_IS_SMALLER_OR_EQUAL) reduce 43) ((T_LOGICAL_AND) reduce 43) ((T_LOGICAL_OR) reduce 43) ((T_LOGICAL_XOR) reduce 43) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 43) ((T_OBJECT_OPERATOR) reduce 43) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 43) ((T_POW) reduce 43) ((T_SL) reduce 43) ((T_SPACESHIP) reduce 43) ((T_SR) reduce 43) (("[") reduce 43) (("^") reduce 43) (("{") reduce 43) (("|") reduce 43)) 3312 ((("%") reduce 72) (("(") reduce 72) (("*") reduce 72) (("+") reduce 72) ((",") reduce 72) (("-") reduce 72) ((".") reduce 72) (("/") reduce 72) ((";") reduce 72) (("<") reduce 72) ((">") reduce 72) (("?") reduce 72) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_BOOLEAN_AND) reduce 72) ((T_BOOLEAN_OR) reduce 72) ((T_COALESCE) reduce 72) ((T_INSTANCEOF) reduce 72) ((T_IS_EQUAL) reduce 72) ((T_IS_GREATER_OR_EQUAL) reduce 72) ((T_IS_IDENTICAL) reduce 72) ((T_IS_NOT_EQUAL) reduce 72) ((T_IS_NOT_IDENTICAL) reduce 72) ((T_IS_SMALLER_OR_EQUAL) reduce 72) ((T_LOGICAL_AND) reduce 72) ((T_LOGICAL_OR) reduce 72) ((T_LOGICAL_XOR) reduce 72) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 72) ((T_OBJECT_OPERATOR) reduce 72) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 72) ((T_POW) reduce 72) ((T_SL) reduce 72) ((T_SPACESHIP) reduce 72) ((T_SR) reduce 72) (("[") reduce 72) (("^") reduce 72) (("{") reduce 72) (("|") reduce 72)) 3313 ((("%") reduce 81) (("(") reduce 81) (("*") reduce 81) (("+") reduce 81) ((",") reduce 81) (("-") reduce 81) ((".") reduce 81) (("/") reduce 81) ((";") reduce 81) (("<") reduce 81) ((">") reduce 81) (("?") reduce 81) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_BOOLEAN_AND) reduce 81) ((T_BOOLEAN_OR) reduce 81) ((T_COALESCE) reduce 81) ((T_INSTANCEOF) reduce 81) ((T_IS_EQUAL) reduce 81) ((T_IS_GREATER_OR_EQUAL) reduce 81) ((T_IS_IDENTICAL) reduce 81) ((T_IS_NOT_EQUAL) reduce 81) ((T_IS_NOT_IDENTICAL) reduce 81) ((T_IS_SMALLER_OR_EQUAL) reduce 81) ((T_LOGICAL_AND) reduce 81) ((T_LOGICAL_OR) reduce 81) ((T_LOGICAL_XOR) reduce 81) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 81) ((T_OBJECT_OPERATOR) reduce 81) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 81) ((T_POW) reduce 81) ((T_SL) reduce 81) ((T_SPACESHIP) reduce 81) ((T_SR) reduce 81) (("[") reduce 81) (("^") reduce 81) (("{") reduce 81) (("|") reduce 81)) 3314 ((("%") reduce 47) (("(") reduce 47) (("*") reduce 47) (("+") reduce 47) ((",") reduce 47) (("-") reduce 47) ((".") reduce 47) (("/") reduce 47) ((";") reduce 47) (("<") reduce 47) ((">") reduce 47) (("?") reduce 47) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_BOOLEAN_AND) reduce 47) ((T_BOOLEAN_OR) reduce 47) ((T_COALESCE) reduce 47) ((T_INSTANCEOF) reduce 47) ((T_IS_EQUAL) reduce 47) ((T_IS_GREATER_OR_EQUAL) reduce 47) ((T_IS_IDENTICAL) reduce 47) ((T_IS_NOT_EQUAL) reduce 47) ((T_IS_NOT_IDENTICAL) reduce 47) ((T_IS_SMALLER_OR_EQUAL) reduce 47) ((T_LOGICAL_AND) reduce 47) ((T_LOGICAL_OR) reduce 47) ((T_LOGICAL_XOR) reduce 47) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 47) ((T_OBJECT_OPERATOR) reduce 47) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 47) ((T_POW) reduce 47) ((T_SL) reduce 47) ((T_SPACESHIP) reduce 47) ((T_SR) reduce 47) (("[") reduce 47) (("^") reduce 47) (("{") reduce 47) (("|") reduce 47)) 3315 ((("%") reduce 31) (("(") reduce 31) (("*") reduce 31) (("+") reduce 31) ((",") reduce 31) (("-") reduce 31) ((".") reduce 31) (("/") reduce 31) ((";") reduce 31) (("<") reduce 31) ((">") reduce 31) (("?") reduce 31) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_BOOLEAN_AND) reduce 31) ((T_BOOLEAN_OR) reduce 31) ((T_COALESCE) reduce 31) ((T_INSTANCEOF) reduce 31) ((T_IS_EQUAL) reduce 31) ((T_IS_GREATER_OR_EQUAL) reduce 31) ((T_IS_IDENTICAL) reduce 31) ((T_IS_NOT_EQUAL) reduce 31) ((T_IS_NOT_IDENTICAL) reduce 31) ((T_IS_SMALLER_OR_EQUAL) reduce 31) ((T_LOGICAL_AND) reduce 31) ((T_LOGICAL_OR) reduce 31) ((T_LOGICAL_XOR) reduce 31) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 31) ((T_OBJECT_OPERATOR) reduce 31) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 31) ((T_POW) reduce 31) ((T_SL) reduce 31) ((T_SPACESHIP) reduce 31) ((T_SR) reduce 31) (("[") reduce 31) (("^") reduce 31) (("{") reduce 31) (("|") reduce 31)) 3316 ((("%") reduce 57) (("(") reduce 57) (("*") reduce 57) (("+") reduce 57) ((",") reduce 57) (("-") reduce 57) ((".") reduce 57) (("/") reduce 57) ((";") reduce 57) (("<") reduce 57) ((">") reduce 57) (("?") reduce 57) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_BOOLEAN_AND) reduce 57) ((T_BOOLEAN_OR) reduce 57) ((T_COALESCE) reduce 57) ((T_INSTANCEOF) reduce 57) ((T_IS_EQUAL) reduce 57) ((T_IS_GREATER_OR_EQUAL) reduce 57) ((T_IS_IDENTICAL) reduce 57) ((T_IS_NOT_EQUAL) reduce 57) ((T_IS_NOT_IDENTICAL) reduce 57) ((T_IS_SMALLER_OR_EQUAL) reduce 57) ((T_LOGICAL_AND) reduce 57) ((T_LOGICAL_OR) reduce 57) ((T_LOGICAL_XOR) reduce 57) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 57) ((T_OBJECT_OPERATOR) reduce 57) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 57) ((T_POW) reduce 57) ((T_SL) reduce 57) ((T_SPACESHIP) reduce 57) ((T_SR) reduce 57) (("[") reduce 57) (("^") reduce 57) (("{") reduce 57) (("|") reduce 57)) 3317 ((("%") reduce 61) (("(") reduce 61) (("*") reduce 61) (("+") reduce 61) ((",") reduce 61) (("-") reduce 61) ((".") reduce 61) (("/") reduce 61) ((";") reduce 61) (("<") reduce 61) ((">") reduce 61) (("?") reduce 61) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_BOOLEAN_AND) reduce 61) ((T_BOOLEAN_OR) reduce 61) ((T_COALESCE) reduce 61) ((T_INSTANCEOF) reduce 61) ((T_IS_EQUAL) reduce 61) ((T_IS_GREATER_OR_EQUAL) reduce 61) ((T_IS_IDENTICAL) reduce 61) ((T_IS_NOT_EQUAL) reduce 61) ((T_IS_NOT_IDENTICAL) reduce 61) ((T_IS_SMALLER_OR_EQUAL) reduce 61) ((T_LOGICAL_AND) reduce 61) ((T_LOGICAL_OR) reduce 61) ((T_LOGICAL_XOR) reduce 61) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 61) ((T_OBJECT_OPERATOR) reduce 61) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 61) ((T_POW) reduce 61) ((T_SL) reduce 61) ((T_SPACESHIP) reduce 61) ((T_SR) reduce 61) (("[") reduce 61) (("^") reduce 61) (("{") reduce 61) (("|") reduce 61)) 3318 ((("%") reduce 28) (("(") reduce 28) (("*") reduce 28) (("+") reduce 28) ((",") reduce 28) (("-") reduce 28) ((".") reduce 28) (("/") reduce 28) ((";") reduce 28) (("<") reduce 28) ((">") reduce 28) (("?") reduce 28) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_BOOLEAN_AND) reduce 28) ((T_BOOLEAN_OR) reduce 28) ((T_COALESCE) reduce 28) ((T_INSTANCEOF) reduce 28) ((T_IS_EQUAL) reduce 28) ((T_IS_GREATER_OR_EQUAL) reduce 28) ((T_IS_IDENTICAL) reduce 28) ((T_IS_NOT_EQUAL) reduce 28) ((T_IS_NOT_IDENTICAL) reduce 28) ((T_IS_SMALLER_OR_EQUAL) reduce 28) ((T_LOGICAL_AND) reduce 28) ((T_LOGICAL_OR) reduce 28) ((T_LOGICAL_XOR) reduce 28) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 28) ((T_OBJECT_OPERATOR) reduce 28) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 28) ((T_POW) reduce 28) ((T_SL) reduce 28) ((T_SPACESHIP) reduce 28) ((T_SR) reduce 28) (("[") reduce 28) (("^") reduce 28) (("{") reduce 28) (("|") reduce 28)) 3319 ((("%") reduce 36) (("(") reduce 36) (("*") reduce 36) (("+") reduce 36) ((",") reduce 36) (("-") reduce 36) ((".") reduce 36) (("/") reduce 36) ((";") reduce 36) (("<") reduce 36) ((">") reduce 36) (("?") reduce 36) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_BOOLEAN_AND) reduce 36) ((T_BOOLEAN_OR) reduce 36) ((T_COALESCE) reduce 36) ((T_INSTANCEOF) reduce 36) ((T_IS_EQUAL) reduce 36) ((T_IS_GREATER_OR_EQUAL) reduce 36) ((T_IS_IDENTICAL) reduce 36) ((T_IS_NOT_EQUAL) reduce 36) ((T_IS_NOT_IDENTICAL) reduce 36) ((T_IS_SMALLER_OR_EQUAL) reduce 36) ((T_LOGICAL_AND) reduce 36) ((T_LOGICAL_OR) reduce 36) ((T_LOGICAL_XOR) reduce 36) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 36) ((T_OBJECT_OPERATOR) reduce 36) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 36) ((T_POW) reduce 36) ((T_SL) reduce 36) ((T_SPACESHIP) reduce 36) ((T_SR) reduce 36) (("[") reduce 36) (("^") reduce 36) (("{") reduce 36) (("|") reduce 36)) 3320 ((("%") reduce 32) (("(") reduce 32) (("*") reduce 32) (("+") reduce 32) ((",") reduce 32) (("-") reduce 32) ((".") reduce 32) (("/") reduce 32) ((";") reduce 32) (("<") reduce 32) ((">") reduce 32) (("?") reduce 32) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_BOOLEAN_AND) reduce 32) ((T_BOOLEAN_OR) reduce 32) ((T_COALESCE) reduce 32) ((T_INSTANCEOF) reduce 32) ((T_IS_EQUAL) reduce 32) ((T_IS_GREATER_OR_EQUAL) reduce 32) ((T_IS_IDENTICAL) reduce 32) ((T_IS_NOT_EQUAL) reduce 32) ((T_IS_NOT_IDENTICAL) reduce 32) ((T_IS_SMALLER_OR_EQUAL) reduce 32) ((T_LOGICAL_AND) reduce 32) ((T_LOGICAL_OR) reduce 32) ((T_LOGICAL_XOR) reduce 32) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 32) ((T_OBJECT_OPERATOR) reduce 32) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 32) ((T_POW) reduce 32) ((T_SL) reduce 32) ((T_SPACESHIP) reduce 32) ((T_SR) reduce 32) (("[") reduce 32) (("^") reduce 32) (("{") reduce 32) (("|") reduce 32)) 3321 ((("%") reduce 35) (("(") reduce 35) (("*") reduce 35) (("+") reduce 35) ((",") reduce 35) (("-") reduce 35) ((".") reduce 35) (("/") reduce 35) ((";") reduce 35) (("<") reduce 35) ((">") reduce 35) (("?") reduce 35) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_BOOLEAN_AND) reduce 35) ((T_BOOLEAN_OR) reduce 35) ((T_COALESCE) reduce 35) ((T_INSTANCEOF) reduce 35) ((T_IS_EQUAL) reduce 35) ((T_IS_GREATER_OR_EQUAL) reduce 35) ((T_IS_IDENTICAL) reduce 35) ((T_IS_NOT_EQUAL) reduce 35) ((T_IS_NOT_IDENTICAL) reduce 35) ((T_IS_SMALLER_OR_EQUAL) reduce 35) ((T_LOGICAL_AND) reduce 35) ((T_LOGICAL_OR) reduce 35) ((T_LOGICAL_XOR) reduce 35) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 35) ((T_OBJECT_OPERATOR) reduce 35) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 35) ((T_POW) reduce 35) ((T_SL) reduce 35) ((T_SPACESHIP) reduce 35) ((T_SR) reduce 35) (("[") reduce 35) (("^") reduce 35) (("{") reduce 35) (("|") reduce 35)) 3322 ((("%") reduce 19) (("(") reduce 19) (("*") reduce 19) (("+") reduce 19) ((",") reduce 19) (("-") reduce 19) ((".") reduce 19) (("/") reduce 19) ((";") reduce 19) (("<") reduce 19) ((">") reduce 19) (("?") reduce 19) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_BOOLEAN_AND) reduce 19) ((T_BOOLEAN_OR) reduce 19) ((T_COALESCE) reduce 19) ((T_INSTANCEOF) reduce 19) ((T_IS_EQUAL) reduce 19) ((T_IS_GREATER_OR_EQUAL) reduce 19) ((T_IS_IDENTICAL) reduce 19) ((T_IS_NOT_EQUAL) reduce 19) ((T_IS_NOT_IDENTICAL) reduce 19) ((T_IS_SMALLER_OR_EQUAL) reduce 19) ((T_LOGICAL_AND) reduce 19) ((T_LOGICAL_OR) reduce 19) ((T_LOGICAL_XOR) reduce 19) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 19) ((T_OBJECT_OPERATOR) reduce 19) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 19) ((T_POW) reduce 19) ((T_SL) reduce 19) ((T_SPACESHIP) reduce 19) ((T_SR) reduce 19) (("[") reduce 19) (("^") reduce 19) (("{") reduce 19) (("|") reduce 19)) 3323 ((("%") reduce 45) (("(") reduce 45) (("*") reduce 45) (("+") reduce 45) ((",") reduce 45) (("-") reduce 45) ((".") reduce 45) (("/") reduce 45) ((";") reduce 45) (("<") reduce 45) ((">") reduce 45) (("?") reduce 45) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_BOOLEAN_AND) reduce 45) ((T_BOOLEAN_OR) reduce 45) ((T_COALESCE) reduce 45) ((T_INSTANCEOF) reduce 45) ((T_IS_EQUAL) reduce 45) ((T_IS_GREATER_OR_EQUAL) reduce 45) ((T_IS_IDENTICAL) reduce 45) ((T_IS_NOT_EQUAL) reduce 45) ((T_IS_NOT_IDENTICAL) reduce 45) ((T_IS_SMALLER_OR_EQUAL) reduce 45) ((T_LOGICAL_AND) reduce 45) ((T_LOGICAL_OR) reduce 45) ((T_LOGICAL_XOR) reduce 45) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 45) ((T_OBJECT_OPERATOR) reduce 45) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 45) ((T_POW) reduce 45) ((T_SL) reduce 45) ((T_SPACESHIP) reduce 45) ((T_SR) reduce 45) (("[") reduce 45) (("^") reduce 45) (("{") reduce 45) (("|") reduce 45)) 3324 ((("%") reduce 504) (("(") reduce 541) (("*") reduce 504) (("+") reduce 504) ((",") reduce 504) (("-") reduce 504) ((".") reduce 504) (("/") reduce 504) ((";") reduce 504) (("<") reduce 504) ((">") reduce 504) (("?") reduce 504) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_BOOLEAN_AND) reduce 504) ((T_BOOLEAN_OR) reduce 504) ((T_COALESCE) reduce 504) ((T_INSTANCEOF) reduce 504) ((T_IS_EQUAL) reduce 504) ((T_IS_GREATER_OR_EQUAL) reduce 504) ((T_IS_IDENTICAL) reduce 504) ((T_IS_NOT_EQUAL) reduce 504) ((T_IS_NOT_IDENTICAL) reduce 504) ((T_IS_SMALLER_OR_EQUAL) reduce 504) ((T_LOGICAL_AND) reduce 504) ((T_LOGICAL_OR) reduce 504) ((T_LOGICAL_XOR) reduce 504) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 504) ((T_OBJECT_OPERATOR) reduce 504) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 504) ((T_POW) reduce 504) ((T_SL) reduce 504) ((T_SPACESHIP) reduce 504) ((T_SR) reduce 504) (("[") reduce 504) (("^") reduce 504) (("{") reduce 504) (("|") reduce 504)) 3326 ((("%") reduce 71) (("(") reduce 71) (("*") reduce 71) (("+") reduce 71) ((",") reduce 71) (("-") reduce 71) ((".") reduce 71) (("/") reduce 71) ((";") reduce 71) (("<") reduce 71) ((">") reduce 71) (("?") reduce 71) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_BOOLEAN_AND) reduce 71) ((T_BOOLEAN_OR) reduce 71) ((T_COALESCE) reduce 71) ((T_INSTANCEOF) reduce 71) ((T_IS_EQUAL) reduce 71) ((T_IS_GREATER_OR_EQUAL) reduce 71) ((T_IS_IDENTICAL) reduce 71) ((T_IS_NOT_EQUAL) reduce 71) ((T_IS_NOT_IDENTICAL) reduce 71) ((T_IS_SMALLER_OR_EQUAL) reduce 71) ((T_LOGICAL_AND) reduce 71) ((T_LOGICAL_OR) reduce 71) ((T_LOGICAL_XOR) reduce 71) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 71) ((T_OBJECT_OPERATOR) reduce 71) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 71) ((T_POW) reduce 71) ((T_SL) reduce 71) ((T_SPACESHIP) reduce 71) ((T_SR) reduce 71) (("[") reduce 71) (("^") reduce 71) (("{") reduce 71) (("|") reduce 71)) 3327 ((("%") reduce 82) (("(") reduce 82) (("*") reduce 82) (("+") reduce 82) ((",") reduce 82) (("-") reduce 82) ((".") reduce 82) (("/") reduce 82) ((";") reduce 82) (("<") reduce 82) ((">") reduce 82) (("?") reduce 82) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_BOOLEAN_AND) reduce 82) ((T_BOOLEAN_OR) reduce 82) ((T_COALESCE) reduce 82) ((T_INSTANCEOF) reduce 82) ((T_IS_EQUAL) reduce 82) ((T_IS_GREATER_OR_EQUAL) reduce 82) ((T_IS_IDENTICAL) reduce 82) ((T_IS_NOT_EQUAL) reduce 82) ((T_IS_NOT_IDENTICAL) reduce 82) ((T_IS_SMALLER_OR_EQUAL) reduce 82) ((T_LOGICAL_AND) reduce 82) ((T_LOGICAL_OR) reduce 82) ((T_LOGICAL_XOR) reduce 82) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 82) ((T_OBJECT_OPERATOR) reduce 82) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 82) ((T_POW) reduce 82) ((T_SL) reduce 82) ((T_SPACESHIP) reduce 82) ((T_SR) reduce 82) (("[") reduce 82) (("^") reduce 82) (("{") reduce 82) (("|") reduce 82)) 3328 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) ((",") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) ((";") reduce 533) (("<") reduce 533) (("=") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AND_EQUAL) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_COALESCE_EQUAL) reduce 533) ((T_CONCAT_EQUAL) reduce 533) ((T_DEC) reduce 533) ((T_DIV_EQUAL) reduce 533) ((T_INC) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_MINUS_EQUAL) reduce 533) ((T_MOD_EQUAL) reduce 533) ((T_MUL_EQUAL) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_OR_EQUAL) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_PLUS_EQUAL) reduce 533) ((T_POW) reduce 533) ((T_POW_EQUAL) reduce 533) ((T_SL) reduce 533) ((T_SL_EQUAL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) ((T_SR_EQUAL) reduce 533) ((T_XOR_EQUAL) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 3331 ((("%") reduce 506) (("(") reduce 542) (("*") reduce 506) (("+") reduce 506) ((",") reduce 506) (("-") reduce 506) ((".") reduce 506) (("/") reduce 506) ((";") reduce 506) (("<") reduce 506) ((">") reduce 506) (("?") reduce 506) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_BOOLEAN_AND) reduce 506) ((T_BOOLEAN_OR) reduce 506) ((T_COALESCE) reduce 506) ((T_INSTANCEOF) reduce 506) ((T_IS_EQUAL) reduce 506) ((T_IS_GREATER_OR_EQUAL) reduce 506) ((T_IS_IDENTICAL) reduce 506) ((T_IS_NOT_EQUAL) reduce 506) ((T_IS_NOT_IDENTICAL) reduce 506) ((T_IS_SMALLER_OR_EQUAL) reduce 506) ((T_LOGICAL_AND) reduce 506) ((T_LOGICAL_OR) reduce 506) ((T_LOGICAL_XOR) reduce 506) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 506) ((T_OBJECT_OPERATOR) reduce 506) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 506) ((T_POW) reduce 506) ((T_SL) reduce 506) ((T_SPACESHIP) reduce 506) ((T_SR) reduce 506) (("[") reduce 506) (("^") reduce 506) (("{") reduce 506) (("|") reduce 506)) 3333 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) ((",") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) ((";") reduce 468) (("<") reduce 468) (("=") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AND_EQUAL) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_COALESCE_EQUAL) reduce 468) ((T_CONCAT_EQUAL) reduce 468) ((T_DEC) reduce 468) ((T_DIV_EQUAL) reduce 468) ((T_INC) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_MINUS_EQUAL) reduce 468) ((T_MOD_EQUAL) reduce 468) ((T_MUL_EQUAL) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_OR_EQUAL) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_PLUS_EQUAL) reduce 468) ((T_POW) reduce 468) ((T_POW_EQUAL) reduce 468) ((T_SL) reduce 468) ((T_SL_EQUAL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) ((T_SR_EQUAL) reduce 468) ((T_XOR_EQUAL) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 3334 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) ((",") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) ((";") reduce 288) (("<") reduce 288) (("=") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AND_EQUAL) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_COALESCE_EQUAL) reduce 288) ((T_CONCAT_EQUAL) reduce 288) ((T_DEC) reduce 288) ((T_DIV_EQUAL) reduce 288) ((T_INC) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_MINUS_EQUAL) reduce 288) ((T_MOD_EQUAL) reduce 288) ((T_MUL_EQUAL) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_OR_EQUAL) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_PLUS_EQUAL) reduce 288) ((T_POW) reduce 288) ((T_POW_EQUAL) reduce 288) ((T_SL) reduce 288) ((T_SL_EQUAL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) ((T_SR_EQUAL) reduce 288) ((T_XOR_EQUAL) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 3338 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) ((",") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) ((";") reduce 289) (("<") reduce 289) (("=") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AND_EQUAL) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_COALESCE_EQUAL) reduce 289) ((T_CONCAT_EQUAL) reduce 289) ((T_DEC) reduce 289) ((T_DIV_EQUAL) reduce 289) ((T_INC) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_MINUS_EQUAL) reduce 289) ((T_MOD_EQUAL) reduce 289) ((T_MUL_EQUAL) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_OR_EQUAL) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_PLUS_EQUAL) reduce 289) ((T_POW) reduce 289) ((T_POW_EQUAL) reduce 289) ((T_SL) reduce 289) ((T_SL_EQUAL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) ((T_SR_EQUAL) reduce 289) ((T_XOR_EQUAL) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 3339 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) ((",") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) ((";") reduce 290) (("<") reduce 290) (("=") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AND_EQUAL) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_COALESCE_EQUAL) reduce 290) ((T_CONCAT_EQUAL) reduce 290) ((T_DEC) reduce 290) ((T_DIV_EQUAL) reduce 290) ((T_INC) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_MINUS_EQUAL) reduce 290) ((T_MOD_EQUAL) reduce 290) ((T_MUL_EQUAL) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_OR_EQUAL) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_PLUS_EQUAL) reduce 290) ((T_POW) reduce 290) ((T_POW_EQUAL) reduce 290) ((T_SL) reduce 290) ((T_SL_EQUAL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) ((T_SR_EQUAL) reduce 290) ((T_XOR_EQUAL) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 3344 ((("%") reduce 388) (("*") reduce 388) (("+") reduce 388) ((",") reduce 388) (("-") reduce 388) ((".") reduce 388) (("/") reduce 388) ((";") reduce 388) (("<") reduce 388) ((">") reduce 388) (("?") reduce 388) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_BOOLEAN_AND) reduce 388) ((T_BOOLEAN_OR) reduce 388) ((T_COALESCE) reduce 388) ((T_INSTANCEOF) reduce 388) ((T_IS_EQUAL) reduce 388) ((T_IS_GREATER_OR_EQUAL) reduce 388) ((T_IS_IDENTICAL) reduce 388) ((T_IS_NOT_EQUAL) reduce 388) ((T_IS_NOT_IDENTICAL) reduce 388) ((T_IS_SMALLER_OR_EQUAL) reduce 388) ((T_LOGICAL_AND) reduce 388) ((T_LOGICAL_OR) reduce 388) ((T_LOGICAL_XOR) reduce 388) ((T_POW) reduce 388) ((T_SL) reduce 388) ((T_SPACESHIP) reduce 388) ((T_SR) reduce 388) (("^") reduce 388) (("|") reduce 388)) 3346 ((("%") reduce 386) (("*") reduce 386) (("+") reduce 386) ((",") reduce 386) (("-") reduce 386) ((".") reduce 386) (("/") reduce 386) ((";") reduce 386) (("<") reduce 386) ((">") reduce 386) (("?") reduce 386) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_BOOLEAN_AND) reduce 386) ((T_BOOLEAN_OR) reduce 386) ((T_COALESCE) reduce 386) ((T_INSTANCEOF) reduce 386) ((T_IS_EQUAL) reduce 386) ((T_IS_GREATER_OR_EQUAL) reduce 386) ((T_IS_IDENTICAL) reduce 386) ((T_IS_NOT_EQUAL) reduce 386) ((T_IS_NOT_IDENTICAL) reduce 386) ((T_IS_SMALLER_OR_EQUAL) reduce 386) ((T_LOGICAL_AND) reduce 386) ((T_LOGICAL_OR) reduce 386) ((T_LOGICAL_XOR) reduce 386) ((T_POW) reduce 386) ((T_SL) reduce 386) ((T_SPACESHIP) reduce 386) ((T_SR) reduce 386) (("^") reduce 386) (("|") reduce 386)) 3356 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 382) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 382) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 382) ((T_LOGICAL_OR) reduce 382) ((T_LOGICAL_XOR) reduce 382) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3357 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 384) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 384) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 384) ((T_LOGICAL_OR) reduce 384) ((T_LOGICAL_XOR) reduce 384) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3358 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 383) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 383) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 383) ((T_LOGICAL_OR) reduce 383) ((T_LOGICAL_XOR) reduce 383) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3359 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 376) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 376) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 376) ((T_LOGICAL_OR) reduce 376) ((T_LOGICAL_XOR) reduce 376) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3360 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 373) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 373) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 373) ((T_LOGICAL_OR) reduce 373) ((T_LOGICAL_XOR) reduce 373) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3361 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 381) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 381) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 381) ((T_LOGICAL_OR) reduce 381) ((T_LOGICAL_XOR) reduce 381) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3362 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 375) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 375) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 375) ((T_LOGICAL_OR) reduce 375) ((T_LOGICAL_XOR) reduce 375) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3363 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 379) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 379) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 379) ((T_LOGICAL_OR) reduce 379) ((T_LOGICAL_XOR) reduce 379) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3364 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 374) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 374) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 374) ((T_LOGICAL_OR) reduce 374) ((T_LOGICAL_XOR) reduce 374) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3365 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 377) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 377) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 377) ((T_LOGICAL_OR) reduce 377) ((T_LOGICAL_XOR) reduce 377) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3366 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 378) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 378) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 378) ((T_LOGICAL_OR) reduce 378) ((T_LOGICAL_XOR) reduce 378) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3367 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 385) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 385) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 385) ((T_LOGICAL_OR) reduce 385) ((T_LOGICAL_XOR) reduce 385) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3368 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 380) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 380) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 380) ((T_LOGICAL_OR) reduce 380) ((T_LOGICAL_XOR) reduce 380) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3370 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 370) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 370) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 370) ((T_LOGICAL_OR) reduce 370) ((T_LOGICAL_XOR) reduce 370) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3373 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) ((",") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) ((";") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 3376 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) ((",") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) ((";") reduce 525) (("<") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_POW) reduce 525) ((T_SL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 3378 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) ((",") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) ((";") reduce 524) (("<") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_POW) reduce 524) ((T_SL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 3380 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) ((",") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) ((";") reduce 519) (("<") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_POW) reduce 519) ((T_SL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 3381 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) ((",") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) ((";") reduce 526) (("<") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_POW) reduce 526) ((T_SL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 3382 ((("%") reduce 371) (("*") reduce 371) (("+") reduce 371) ((",") reduce 371) (("-") reduce 371) ((".") reduce 371) (("/") reduce 371) ((";") reduce 371) (("<") reduce 371) ((">") reduce 371) (("?") reduce 371) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_BOOLEAN_AND) reduce 371) ((T_BOOLEAN_OR) reduce 371) ((T_COALESCE) reduce 371) ((T_INSTANCEOF) reduce 371) ((T_IS_EQUAL) reduce 371) ((T_IS_GREATER_OR_EQUAL) reduce 371) ((T_IS_IDENTICAL) reduce 371) ((T_IS_NOT_EQUAL) reduce 371) ((T_IS_NOT_IDENTICAL) reduce 371) ((T_IS_SMALLER_OR_EQUAL) reduce 371) ((T_LOGICAL_AND) reduce 371) ((T_LOGICAL_OR) reduce 371) ((T_LOGICAL_XOR) reduce 371) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 371) ((T_SL) reduce 371) ((T_SPACESHIP) reduce 371) ((T_SR) reduce 371) (("[") reduce 510) (("^") reduce 371) (("{") reduce 510) (("|") reduce 371)) 3386 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) ((",") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) ((";") reduce 533) (("<") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_POW) reduce 533) ((T_SL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 3388 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) ((",") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) ((";") reduce 468) (("<") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_POW) reduce 468) ((T_SL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 3389 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) ((",") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) ((";") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 3393 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) ((",") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) ((";") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 3394 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) ((",") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) ((";") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 3395 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) ((",") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) ((";") reduce 465) (("<") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_POW) reduce 465) ((T_SL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 3398 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) ((",") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) ((";") reduce 532) (("<") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_POW) reduce 532) ((T_SL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 3399 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) ((",") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) ((";") reduce 467) (("<") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_POW) reduce 467) ((T_SL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 3400 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) ((",") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) ((";") reduce 469) (("<") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_POW) reduce 469) ((T_SL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 3406 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) ((",") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) ((";") reduce 521) (("<") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_POW) reduce 521) ((T_SL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 3408 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) ((",") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) ((";") reduce 520) (("<") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_POW) reduce 520) ((T_SL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 3409 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) ((",") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) ((";") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 3410 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) ((",") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) ((";") reduce 527) (("<") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_POW) reduce 527) ((T_SL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 3411 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) ((",") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) ((";") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 3414 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) ((",") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) ((";") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 3415 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) ((",") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) ((";") reduce 522) (("<") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_POW) reduce 522) ((T_SL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 3416 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) ((",") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) ((";") reduce 528) (("<") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_POW) reduce 528) ((T_SL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 3417 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) ((",") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) ((";") reduce 523) (("<") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_POW) reduce 523) ((T_SL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 3418 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) ((",") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) ((";") reduce 466) (("<") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_POW) reduce 466) ((T_SL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 3419 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) ((",") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) ((";") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 3422 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) ((",") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) ((";") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 3423 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) ((",") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) ((";") reduce 465) (("<") reduce 465) (("=") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AND_EQUAL) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_COALESCE_EQUAL) reduce 465) ((T_CONCAT_EQUAL) reduce 465) ((T_DEC) reduce 465) ((T_DIV_EQUAL) reduce 465) ((T_INC) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_MINUS_EQUAL) reduce 465) ((T_MOD_EQUAL) reduce 465) ((T_MUL_EQUAL) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_OR_EQUAL) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_PLUS_EQUAL) reduce 465) ((T_POW) reduce 465) ((T_POW_EQUAL) reduce 465) ((T_SL) reduce 465) ((T_SL_EQUAL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) ((T_SR_EQUAL) reduce 465) ((T_XOR_EQUAL) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 3434 ((("%") reduce 455) (("*") reduce 455) (("+") reduce 455) ((",") reduce 455) (("-") reduce 455) ((".") reduce 455) (("/") reduce 455) ((";") reduce 455) (("<") reduce 455) ((">") reduce 455) (("?") reduce 455) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_BOOLEAN_AND) reduce 455) ((T_BOOLEAN_OR) reduce 455) ((T_COALESCE) reduce 455) ((T_INSTANCEOF) reduce 455) ((T_IS_EQUAL) reduce 455) ((T_IS_GREATER_OR_EQUAL) reduce 455) ((T_IS_IDENTICAL) reduce 455) ((T_IS_NOT_EQUAL) reduce 455) ((T_IS_NOT_IDENTICAL) reduce 455) ((T_IS_SMALLER_OR_EQUAL) reduce 455) ((T_LOGICAL_AND) reduce 455) ((T_LOGICAL_OR) reduce 455) ((T_LOGICAL_XOR) reduce 455) ((T_POW) reduce 455) ((T_SL) reduce 455) ((T_SPACESHIP) reduce 455) ((T_SR) reduce 455) (("^") reduce 455) (("|") reduce 455)) 3435 ((("%") reduce 450) (("*") reduce 450) (("+") reduce 450) ((",") reduce 450) (("-") reduce 450) ((".") reduce 450) (("/") reduce 450) ((";") reduce 450) (("<") reduce 450) ((">") reduce 450) (("?") reduce 450) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_BOOLEAN_AND) reduce 450) ((T_BOOLEAN_OR) reduce 450) ((T_COALESCE) reduce 450) ((T_INSTANCEOF) reduce 450) ((T_IS_EQUAL) reduce 450) ((T_IS_GREATER_OR_EQUAL) reduce 450) ((T_IS_IDENTICAL) reduce 450) ((T_IS_NOT_EQUAL) reduce 450) ((T_IS_NOT_IDENTICAL) reduce 450) ((T_IS_SMALLER_OR_EQUAL) reduce 450) ((T_LOGICAL_AND) reduce 450) ((T_LOGICAL_OR) reduce 450) ((T_LOGICAL_XOR) reduce 450) ((T_POW) reduce 450) ((T_SL) reduce 450) ((T_SPACESHIP) reduce 450) ((T_SR) reduce 450) (("^") reduce 450) (("|") reduce 450)) 3445 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 455) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 455) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3446 ((("%") reduce 451) (("*") reduce 451) (("+") reduce 451) ((",") reduce 451) (("-") reduce 451) ((".") reduce 451) (("/") reduce 451) ((";") reduce 451) (("<") reduce 451) ((">") reduce 451) (("?") reduce 451) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_BOOLEAN_AND) reduce 451) ((T_BOOLEAN_OR) reduce 451) ((T_COALESCE) reduce 451) ((T_INSTANCEOF) reduce 451) ((T_IS_EQUAL) reduce 451) ((T_IS_GREATER_OR_EQUAL) reduce 451) ((T_IS_IDENTICAL) reduce 451) ((T_IS_NOT_EQUAL) reduce 451) ((T_IS_NOT_IDENTICAL) reduce 451) ((T_IS_SMALLER_OR_EQUAL) reduce 451) ((T_LOGICAL_AND) reduce 451) ((T_LOGICAL_OR) reduce 451) ((T_LOGICAL_XOR) reduce 451) ((T_POW) reduce 451) ((T_SL) reduce 451) ((T_SPACESHIP) reduce 451) ((T_SR) reduce 451) (("^") reduce 451) (("|") reduce 451)) 3447 (((",") reduce 350) ((";") reduce 350)) 3449 ((("%") reduce 503) (("(") reduce 541) (("*") reduce 503) (("+") reduce 503) ((",") reduce 503) (("-") reduce 503) ((".") reduce 503) (("/") reduce 503) ((";") reduce 503) (("<") reduce 503) ((">") reduce 503) (("?") reduce 503) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_BOOLEAN_AND) reduce 503) ((T_BOOLEAN_OR) reduce 503) ((T_COALESCE) reduce 503) ((T_INSTANCEOF) reduce 503) ((T_IS_EQUAL) reduce 503) ((T_IS_GREATER_OR_EQUAL) reduce 503) ((T_IS_IDENTICAL) reduce 503) ((T_IS_NOT_EQUAL) reduce 503) ((T_IS_NOT_IDENTICAL) reduce 503) ((T_IS_SMALLER_OR_EQUAL) reduce 503) ((T_LOGICAL_AND) reduce 503) ((T_LOGICAL_OR) reduce 503) ((T_LOGICAL_XOR) reduce 503) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 503) ((T_OBJECT_OPERATOR) reduce 503) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 503) ((T_POW) reduce 503) ((T_SL) reduce 503) ((T_SPACESHIP) reduce 503) ((T_SR) reduce 503) (("[") reduce 503) (("^") reduce 503) (("{") reduce 503) (("|") reduce 503)) 3451 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) ((",") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) ((";") reduce 532) (("<") reduce 532) (("=") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AND_EQUAL) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_COALESCE_EQUAL) reduce 532) ((T_CONCAT_EQUAL) reduce 532) ((T_DEC) reduce 532) ((T_DIV_EQUAL) reduce 532) ((T_INC) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_MINUS_EQUAL) reduce 532) ((T_MOD_EQUAL) reduce 532) ((T_MUL_EQUAL) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_OR_EQUAL) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_PLUS_EQUAL) reduce 532) ((T_POW) reduce 532) ((T_POW_EQUAL) reduce 532) ((T_SL) reduce 532) ((T_SL_EQUAL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) ((T_SR_EQUAL) reduce 532) ((T_XOR_EQUAL) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 3454 ((("%") reduce 505) (("(") reduce 542) (("*") reduce 505) (("+") reduce 505) ((",") reduce 505) (("-") reduce 505) ((".") reduce 505) (("/") reduce 505) ((";") reduce 505) (("<") reduce 505) ((">") reduce 505) (("?") reduce 505) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_BOOLEAN_AND) reduce 505) ((T_BOOLEAN_OR) reduce 505) ((T_COALESCE) reduce 505) ((T_INSTANCEOF) reduce 505) ((T_IS_EQUAL) reduce 505) ((T_IS_GREATER_OR_EQUAL) reduce 505) ((T_IS_IDENTICAL) reduce 505) ((T_IS_NOT_EQUAL) reduce 505) ((T_IS_NOT_IDENTICAL) reduce 505) ((T_IS_SMALLER_OR_EQUAL) reduce 505) ((T_LOGICAL_AND) reduce 505) ((T_LOGICAL_OR) reduce 505) ((T_LOGICAL_XOR) reduce 505) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 505) ((T_OBJECT_OPERATOR) reduce 505) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 505) ((T_POW) reduce 505) ((T_SL) reduce 505) ((T_SPACESHIP) reduce 505) ((T_SR) reduce 505) (("[") reduce 505) (("^") reduce 505) (("{") reduce 505) (("|") reduce 505)) 3455 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) ((",") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) ((";") reduce 467) (("<") reduce 467) (("=") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AND_EQUAL) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_COALESCE_EQUAL) reduce 467) ((T_CONCAT_EQUAL) reduce 467) ((T_DEC) reduce 467) ((T_DIV_EQUAL) reduce 467) ((T_INC) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_MINUS_EQUAL) reduce 467) ((T_MOD_EQUAL) reduce 467) ((T_MUL_EQUAL) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_OR_EQUAL) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_PLUS_EQUAL) reduce 467) ((T_POW) reduce 467) ((T_POW_EQUAL) reduce 467) ((T_SL) reduce 467) ((T_SL_EQUAL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) ((T_SR_EQUAL) reduce 467) ((T_XOR_EQUAL) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 3456 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) ((",") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) ((";") reduce 469) (("<") reduce 469) (("=") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AND_EQUAL) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_COALESCE_EQUAL) reduce 469) ((T_CONCAT_EQUAL) reduce 469) ((T_DEC) reduce 469) ((T_DIV_EQUAL) reduce 469) ((T_INC) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_MINUS_EQUAL) reduce 469) ((T_MOD_EQUAL) reduce 469) ((T_MUL_EQUAL) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_OR_EQUAL) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_PLUS_EQUAL) reduce 469) ((T_POW) reduce 469) ((T_POW_EQUAL) reduce 469) ((T_SL) reduce 469) ((T_SL_EQUAL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) ((T_SR_EQUAL) reduce 469) ((T_XOR_EQUAL) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 3458 ((("%") reduce 446) (("*") reduce 446) (("+") reduce 446) ((",") reduce 446) (("-") reduce 446) ((".") reduce 446) (("/") reduce 446) ((";") reduce 446) (("<") reduce 446) ((">") reduce 446) (("?") reduce 446) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_BOOLEAN_AND) reduce 446) ((T_BOOLEAN_OR) reduce 446) ((T_COALESCE) reduce 446) ((T_INSTANCEOF) reduce 446) ((T_IS_EQUAL) reduce 446) ((T_IS_GREATER_OR_EQUAL) reduce 446) ((T_IS_IDENTICAL) reduce 446) ((T_IS_NOT_EQUAL) reduce 446) ((T_IS_NOT_IDENTICAL) reduce 446) ((T_IS_SMALLER_OR_EQUAL) reduce 446) ((T_LOGICAL_AND) reduce 446) ((T_LOGICAL_OR) reduce 446) ((T_LOGICAL_XOR) reduce 446) ((T_POW) reduce 446) ((T_SL) reduce 446) ((T_SPACESHIP) reduce 446) ((T_SR) reduce 446) (("^") reduce 446) (("|") reduce 446)) 3459 ((("%") reduce 448) (("*") reduce 448) (("+") reduce 448) ((",") reduce 448) (("-") reduce 448) ((".") reduce 448) (("/") reduce 448) ((";") reduce 448) (("<") reduce 448) ((">") reduce 448) (("?") reduce 448) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_BOOLEAN_AND) reduce 448) ((T_BOOLEAN_OR) reduce 448) ((T_COALESCE) reduce 448) ((T_INSTANCEOF) reduce 448) ((T_IS_EQUAL) reduce 448) ((T_IS_GREATER_OR_EQUAL) reduce 448) ((T_IS_IDENTICAL) reduce 448) ((T_IS_NOT_EQUAL) reduce 448) ((T_IS_NOT_IDENTICAL) reduce 448) ((T_IS_SMALLER_OR_EQUAL) reduce 448) ((T_LOGICAL_AND) reduce 448) ((T_LOGICAL_OR) reduce 448) ((T_LOGICAL_XOR) reduce 448) ((T_POW) reduce 448) ((T_SL) reduce 448) ((T_SPACESHIP) reduce 448) ((T_SR) reduce 448) (("^") reduce 448) (("|") reduce 448)) 3465 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) ((",") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) ((";") reduce 521) (("<") reduce 521) (("=") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AND_EQUAL) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_COALESCE_EQUAL) reduce 521) ((T_CONCAT_EQUAL) reduce 521) ((T_DEC) reduce 521) ((T_DIV_EQUAL) reduce 521) ((T_INC) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_MINUS_EQUAL) reduce 521) ((T_MOD_EQUAL) reduce 521) ((T_MUL_EQUAL) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_OR_EQUAL) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_PLUS_EQUAL) reduce 521) ((T_POW) reduce 521) ((T_POW_EQUAL) reduce 521) ((T_SL) reduce 521) ((T_SL_EQUAL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) ((T_SR_EQUAL) reduce 521) ((T_XOR_EQUAL) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 3467 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) ((",") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) ((";") reduce 520) (("<") reduce 520) (("=") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AND_EQUAL) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_COALESCE_EQUAL) reduce 520) ((T_CONCAT_EQUAL) reduce 520) ((T_DEC) reduce 520) ((T_DIV_EQUAL) reduce 520) ((T_INC) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_MINUS_EQUAL) reduce 520) ((T_MOD_EQUAL) reduce 520) ((T_MUL_EQUAL) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_OR_EQUAL) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_PLUS_EQUAL) reduce 520) ((T_POW) reduce 520) ((T_POW_EQUAL) reduce 520) ((T_SL) reduce 520) ((T_SL_EQUAL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) ((T_SR_EQUAL) reduce 520) ((T_XOR_EQUAL) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 3468 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) ((",") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) ((";") reduce 544) (("<") reduce 544) (("=") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AND_EQUAL) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_COALESCE_EQUAL) reduce 544) ((T_CONCAT_EQUAL) reduce 544) ((T_DEC) reduce 544) ((T_DIV_EQUAL) reduce 544) ((T_INC) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_MINUS_EQUAL) reduce 544) ((T_MOD_EQUAL) reduce 544) ((T_MUL_EQUAL) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_OR_EQUAL) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_PLUS_EQUAL) reduce 544) ((T_POW) reduce 544) ((T_POW_EQUAL) reduce 544) ((T_SL) reduce 544) ((T_SL_EQUAL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) ((T_SR_EQUAL) reduce 544) ((T_XOR_EQUAL) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 3469 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) ((",") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) ((";") reduce 527) (("<") reduce 527) (("=") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AND_EQUAL) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_COALESCE_EQUAL) reduce 527) ((T_CONCAT_EQUAL) reduce 527) ((T_DEC) reduce 527) ((T_DIV_EQUAL) reduce 527) ((T_INC) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_MINUS_EQUAL) reduce 527) ((T_MOD_EQUAL) reduce 527) ((T_MUL_EQUAL) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_OR_EQUAL) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_PLUS_EQUAL) reduce 527) ((T_POW) reduce 527) ((T_POW_EQUAL) reduce 527) ((T_SL) reduce 527) ((T_SL_EQUAL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) ((T_SR_EQUAL) reduce 527) ((T_XOR_EQUAL) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 3470 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) ((",") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) ((";") reduce 546) (("<") reduce 546) (("=") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AND_EQUAL) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_COALESCE_EQUAL) reduce 546) ((T_CONCAT_EQUAL) reduce 546) ((T_DEC) reduce 546) ((T_DIV_EQUAL) reduce 546) ((T_INC) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_MINUS_EQUAL) reduce 546) ((T_MOD_EQUAL) reduce 546) ((T_MUL_EQUAL) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_OR_EQUAL) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_PLUS_EQUAL) reduce 546) ((T_POW) reduce 546) ((T_POW_EQUAL) reduce 546) ((T_SL) reduce 546) ((T_SL_EQUAL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) ((T_SR_EQUAL) reduce 546) ((T_XOR_EQUAL) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 3473 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) ((",") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) ((";") reduce 545) (("<") reduce 545) (("=") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AND_EQUAL) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_COALESCE_EQUAL) reduce 545) ((T_CONCAT_EQUAL) reduce 545) ((T_DEC) reduce 545) ((T_DIV_EQUAL) reduce 545) ((T_INC) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_MINUS_EQUAL) reduce 545) ((T_MOD_EQUAL) reduce 545) ((T_MUL_EQUAL) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_OR_EQUAL) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_PLUS_EQUAL) reduce 545) ((T_POW) reduce 545) ((T_POW_EQUAL) reduce 545) ((T_SL) reduce 545) ((T_SL_EQUAL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) ((T_SR_EQUAL) reduce 545) ((T_XOR_EQUAL) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 3474 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) ((",") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) ((";") reduce 522) (("<") reduce 522) (("=") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AND_EQUAL) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_COALESCE_EQUAL) reduce 522) ((T_CONCAT_EQUAL) reduce 522) ((T_DEC) reduce 522) ((T_DIV_EQUAL) reduce 522) ((T_INC) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_MINUS_EQUAL) reduce 522) ((T_MOD_EQUAL) reduce 522) ((T_MUL_EQUAL) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_OR_EQUAL) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_PLUS_EQUAL) reduce 522) ((T_POW) reduce 522) ((T_POW_EQUAL) reduce 522) ((T_SL) reduce 522) ((T_SL_EQUAL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) ((T_SR_EQUAL) reduce 522) ((T_XOR_EQUAL) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 3475 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) ((",") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) ((";") reduce 528) (("<") reduce 528) (("=") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AND_EQUAL) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_COALESCE_EQUAL) reduce 528) ((T_CONCAT_EQUAL) reduce 528) ((T_DEC) reduce 528) ((T_DIV_EQUAL) reduce 528) ((T_INC) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_MINUS_EQUAL) reduce 528) ((T_MOD_EQUAL) reduce 528) ((T_MUL_EQUAL) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_OR_EQUAL) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_PLUS_EQUAL) reduce 528) ((T_POW) reduce 528) ((T_POW_EQUAL) reduce 528) ((T_SL) reduce 528) ((T_SL_EQUAL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) ((T_SR_EQUAL) reduce 528) ((T_XOR_EQUAL) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 3476 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) ((",") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) ((";") reduce 523) (("<") reduce 523) (("=") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AND_EQUAL) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_COALESCE_EQUAL) reduce 523) ((T_CONCAT_EQUAL) reduce 523) ((T_DEC) reduce 523) ((T_DIV_EQUAL) reduce 523) ((T_INC) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_MINUS_EQUAL) reduce 523) ((T_MOD_EQUAL) reduce 523) ((T_MUL_EQUAL) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_OR_EQUAL) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_PLUS_EQUAL) reduce 523) ((T_POW) reduce 523) ((T_POW_EQUAL) reduce 523) ((T_SL) reduce 523) ((T_SL_EQUAL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) ((T_SR_EQUAL) reduce 523) ((T_XOR_EQUAL) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 3478 ((("%") reduce 438) (("*") reduce 438) (("+") reduce 438) ((",") reduce 438) (("-") reduce 438) ((".") reduce 438) (("/") reduce 438) ((";") reduce 438) (("<") reduce 438) ((">") reduce 438) (("?") reduce 438) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_BOOLEAN_AND) reduce 438) ((T_BOOLEAN_OR) reduce 438) ((T_COALESCE) reduce 438) ((T_INSTANCEOF) reduce 438) ((T_IS_EQUAL) reduce 438) ((T_IS_GREATER_OR_EQUAL) reduce 438) ((T_IS_IDENTICAL) reduce 438) ((T_IS_NOT_EQUAL) reduce 438) ((T_IS_NOT_IDENTICAL) reduce 438) ((T_IS_SMALLER_OR_EQUAL) reduce 438) ((T_LOGICAL_AND) reduce 438) ((T_LOGICAL_OR) reduce 438) ((T_LOGICAL_XOR) reduce 438) ((T_POW) reduce 438) ((T_SL) reduce 438) ((T_SPACESHIP) reduce 438) ((T_SR) reduce 438) (("^") reduce 438) (("|") reduce 438)) 3480 ((("%") reduce 483) (("(") reduce 483) (("*") reduce 483) (("+") reduce 483) ((",") reduce 483) (("-") reduce 483) ((".") reduce 483) (("/") reduce 483) ((";") reduce 483) (("<") reduce 483) (("=") shift) ((">") reduce 483) (("?") reduce 483) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_BOOLEAN_AND) reduce 483) ((T_BOOLEAN_OR) reduce 483) ((T_COALESCE) reduce 483) ((T_INSTANCEOF) reduce 483) ((T_IS_EQUAL) reduce 483) ((T_IS_GREATER_OR_EQUAL) reduce 483) ((T_IS_IDENTICAL) reduce 483) ((T_IS_NOT_EQUAL) reduce 483) ((T_IS_NOT_IDENTICAL) reduce 483) ((T_IS_SMALLER_OR_EQUAL) reduce 483) ((T_LOGICAL_AND) reduce 483) ((T_LOGICAL_OR) reduce 483) ((T_LOGICAL_XOR) reduce 483) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 483) ((T_OBJECT_OPERATOR) reduce 483) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 483) ((T_POW) reduce 483) ((T_SL) reduce 483) ((T_SPACESHIP) reduce 483) ((T_SR) reduce 483) (("[") reduce 483) (("^") reduce 483) (("{") reduce 483) (("|") reduce 483)) 3482 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 369) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 369) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 369) ((T_LOGICAL_OR) reduce 369) ((T_LOGICAL_XOR) reduce 369) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3483 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 443) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 443) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 443) ((T_LOGICAL_OR) reduce 443) ((T_LOGICAL_XOR) reduce 443) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3494 ((("%") reduce 502) (("*") reduce 502) (("+") reduce 502) ((",") reduce 502) (("-") reduce 502) ((".") reduce 502) (("/") reduce 502) ((";") reduce 502) (("<") reduce 502) ((">") reduce 502) (("?") reduce 502) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_BOOLEAN_AND) reduce 502) ((T_BOOLEAN_OR) reduce 502) ((T_COALESCE) reduce 502) ((T_DOUBLE_ARROW) reduce 502) ((T_INSTANCEOF) reduce 502) ((T_IS_EQUAL) reduce 502) ((T_IS_GREATER_OR_EQUAL) reduce 502) ((T_IS_IDENTICAL) reduce 502) ((T_IS_NOT_EQUAL) reduce 502) ((T_IS_NOT_IDENTICAL) reduce 502) ((T_IS_SMALLER_OR_EQUAL) reduce 502) ((T_LOGICAL_AND) reduce 502) ((T_LOGICAL_OR) reduce 502) ((T_LOGICAL_XOR) reduce 502) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 502) ((T_OBJECT_OPERATOR) reduce 502) ((T_POW) reduce 502) ((T_SL) reduce 502) ((T_SPACESHIP) reduce 502) ((T_SR) reduce 502) (("[") reduce 502) (("^") reduce 502) (("{") reduce 502) (("|") reduce 502)) 3496 ((("%") reduce 484) (("(") reduce 484) (("*") reduce 484) (("+") reduce 484) ((",") reduce 484) (("-") reduce 484) ((".") reduce 484) (("/") reduce 484) ((";") reduce 484) (("<") reduce 484) ((">") reduce 484) (("?") reduce 484) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_BOOLEAN_AND) reduce 484) ((T_BOOLEAN_OR) reduce 484) ((T_COALESCE) reduce 484) ((T_DOUBLE_ARROW) reduce 484) ((T_INSTANCEOF) reduce 484) ((T_IS_EQUAL) reduce 484) ((T_IS_GREATER_OR_EQUAL) reduce 484) ((T_IS_IDENTICAL) reduce 484) ((T_IS_NOT_EQUAL) reduce 484) ((T_IS_NOT_IDENTICAL) reduce 484) ((T_IS_SMALLER_OR_EQUAL) reduce 484) ((T_LOGICAL_AND) reduce 484) ((T_LOGICAL_OR) reduce 484) ((T_LOGICAL_XOR) reduce 484) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 484) ((T_OBJECT_OPERATOR) reduce 484) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 484) ((T_POW) reduce 484) ((T_SL) reduce 484) ((T_SPACESHIP) reduce 484) ((T_SR) reduce 484) (("[") reduce 484) (("^") reduce 484) (("{") reduce 484) (("|") reduce 484)) 3498 ((("%") reduce 497) (("*") reduce 497) (("+") reduce 497) ((",") reduce 497) (("-") reduce 497) ((".") reduce 497) (("/") reduce 497) ((";") reduce 497) (("<") reduce 497) ((">") reduce 497) (("?") reduce 497) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_BOOLEAN_AND) reduce 497) ((T_BOOLEAN_OR) reduce 497) ((T_COALESCE) reduce 497) ((T_DOUBLE_ARROW) reduce 497) ((T_INSTANCEOF) reduce 497) ((T_IS_EQUAL) reduce 497) ((T_IS_GREATER_OR_EQUAL) reduce 497) ((T_IS_IDENTICAL) reduce 497) ((T_IS_NOT_EQUAL) reduce 497) ((T_IS_NOT_IDENTICAL) reduce 497) ((T_IS_SMALLER_OR_EQUAL) reduce 497) ((T_LOGICAL_AND) reduce 497) ((T_LOGICAL_OR) reduce 497) ((T_LOGICAL_XOR) reduce 497) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 497) ((T_OBJECT_OPERATOR) reduce 497) ((T_POW) reduce 497) ((T_SL) reduce 497) ((T_SPACESHIP) reduce 497) ((T_SR) reduce 497) (("[") reduce 497) (("^") reduce 497) (("{") reduce 497) (("|") reduce 497)) 3499 ((("%") reduce 487) (("*") reduce 487) (("+") reduce 487) ((",") reduce 487) (("-") reduce 487) ((".") reduce 487) (("/") reduce 487) ((";") reduce 487) (("<") reduce 487) ((">") reduce 487) (("?") reduce 487) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_BOOLEAN_AND) reduce 487) ((T_BOOLEAN_OR) reduce 487) ((T_COALESCE) reduce 487) ((T_DOUBLE_ARROW) reduce 487) ((T_INSTANCEOF) reduce 487) ((T_IS_EQUAL) reduce 487) ((T_IS_GREATER_OR_EQUAL) reduce 487) ((T_IS_IDENTICAL) reduce 487) ((T_IS_NOT_EQUAL) reduce 487) ((T_IS_NOT_IDENTICAL) reduce 487) ((T_IS_SMALLER_OR_EQUAL) reduce 487) ((T_LOGICAL_AND) reduce 487) ((T_LOGICAL_OR) reduce 487) ((T_LOGICAL_XOR) reduce 487) ((T_POW) reduce 487) ((T_SL) reduce 487) ((T_SPACESHIP) reduce 487) ((T_SR) reduce 487) (("^") reduce 487) (("|") reduce 487)) 3503 ((("%") reduce 475) (("(") shift) (("*") reduce 475) (("+") reduce 475) ((",") reduce 475) (("-") reduce 475) ((".") reduce 475) (("/") reduce 475) ((";") reduce 475) (("<") reduce 475) ((">") reduce 475) (("?") reduce 475) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_BOOLEAN_AND) reduce 475) ((T_BOOLEAN_OR) reduce 475) ((T_COALESCE) reduce 475) ((T_DOUBLE_ARROW) reduce 475) ((T_INSTANCEOF) reduce 475) ((T_IS_EQUAL) reduce 475) ((T_IS_GREATER_OR_EQUAL) reduce 475) ((T_IS_IDENTICAL) reduce 475) ((T_IS_NOT_EQUAL) reduce 475) ((T_IS_NOT_IDENTICAL) reduce 475) ((T_IS_SMALLER_OR_EQUAL) reduce 475) ((T_LOGICAL_AND) reduce 475) ((T_LOGICAL_OR) reduce 475) ((T_LOGICAL_XOR) reduce 475) ((T_POW) reduce 475) ((T_SL) reduce 475) ((T_SPACESHIP) reduce 475) ((T_SR) reduce 475) (("^") reduce 475) (("|") reduce 475)) 3504 ((("%") reduce 496) (("*") reduce 496) (("+") reduce 496) ((",") reduce 496) (("-") reduce 496) ((".") reduce 496) (("/") reduce 496) ((";") reduce 496) (("<") reduce 496) ((">") reduce 496) (("?") reduce 496) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_BOOLEAN_AND) reduce 496) ((T_BOOLEAN_OR) reduce 496) ((T_COALESCE) reduce 496) ((T_DOUBLE_ARROW) reduce 496) ((T_INSTANCEOF) reduce 496) ((T_IS_EQUAL) reduce 496) ((T_IS_GREATER_OR_EQUAL) reduce 496) ((T_IS_IDENTICAL) reduce 496) ((T_IS_NOT_EQUAL) reduce 496) ((T_IS_NOT_IDENTICAL) reduce 496) ((T_IS_SMALLER_OR_EQUAL) reduce 496) ((T_LOGICAL_AND) reduce 496) ((T_LOGICAL_OR) reduce 496) ((T_LOGICAL_XOR) reduce 496) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 496) ((T_OBJECT_OPERATOR) reduce 496) ((T_POW) reduce 496) ((T_SL) reduce 496) ((T_SPACESHIP) reduce 496) ((T_SR) reduce 496) (("[") reduce 496) (("^") reduce 496) (("{") reduce 496) (("|") reduce 496)) 3505 ((("%") reduce 500) (("*") reduce 500) (("+") reduce 500) ((",") reduce 500) (("-") reduce 500) ((".") reduce 500) (("/") reduce 500) ((";") reduce 500) (("<") reduce 500) ((">") reduce 500) (("?") reduce 500) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_BOOLEAN_AND) reduce 500) ((T_BOOLEAN_OR) reduce 500) ((T_COALESCE) reduce 500) ((T_DOUBLE_ARROW) reduce 500) ((T_INSTANCEOF) reduce 500) ((T_IS_EQUAL) reduce 500) ((T_IS_GREATER_OR_EQUAL) reduce 500) ((T_IS_IDENTICAL) reduce 500) ((T_IS_NOT_EQUAL) reduce 500) ((T_IS_NOT_IDENTICAL) reduce 500) ((T_IS_SMALLER_OR_EQUAL) reduce 500) ((T_LOGICAL_AND) reduce 500) ((T_LOGICAL_OR) reduce 500) ((T_LOGICAL_XOR) reduce 500) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 500) ((T_OBJECT_OPERATOR) reduce 500) ((T_POW) reduce 500) ((T_SL) reduce 500) ((T_SPACESHIP) reduce 500) ((T_SR) reduce 500) (("[") reduce 500) (("^") reduce 500) (("{") reduce 500) (("|") reduce 500)) 3511 ((("%") reduce 495) (("*") reduce 495) (("+") reduce 495) ((",") reduce 495) (("-") reduce 495) ((".") reduce 495) (("/") reduce 495) ((";") reduce 495) (("<") reduce 495) ((">") reduce 495) (("?") reduce 495) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_BOOLEAN_AND) reduce 495) ((T_BOOLEAN_OR) reduce 495) ((T_COALESCE) reduce 495) ((T_DOUBLE_ARROW) reduce 495) ((T_INSTANCEOF) reduce 495) ((T_IS_EQUAL) reduce 495) ((T_IS_GREATER_OR_EQUAL) reduce 495) ((T_IS_IDENTICAL) reduce 495) ((T_IS_NOT_EQUAL) reduce 495) ((T_IS_NOT_IDENTICAL) reduce 495) ((T_IS_SMALLER_OR_EQUAL) reduce 495) ((T_LOGICAL_AND) reduce 495) ((T_LOGICAL_OR) reduce 495) ((T_LOGICAL_XOR) reduce 495) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 495) ((T_OBJECT_OPERATOR) reduce 495) ((T_POW) reduce 495) ((T_SL) reduce 495) ((T_SPACESHIP) reduce 495) ((T_SR) reduce 495) (("[") reduce 495) (("^") reduce 495) (("{") reduce 495) (("|") reduce 495)) 3513 ((("%") reduce 486) (("*") reduce 486) (("+") reduce 486) ((",") reduce 486) (("-") reduce 486) ((".") reduce 486) (("/") reduce 486) ((";") reduce 486) (("<") reduce 486) ((">") reduce 486) (("?") reduce 486) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_BOOLEAN_AND) reduce 486) ((T_BOOLEAN_OR) reduce 486) ((T_COALESCE) reduce 486) ((T_DOUBLE_ARROW) reduce 486) ((T_INSTANCEOF) reduce 486) ((T_IS_EQUAL) reduce 486) ((T_IS_GREATER_OR_EQUAL) reduce 486) ((T_IS_IDENTICAL) reduce 486) ((T_IS_NOT_EQUAL) reduce 486) ((T_IS_NOT_IDENTICAL) reduce 486) ((T_IS_SMALLER_OR_EQUAL) reduce 486) ((T_LOGICAL_AND) reduce 486) ((T_LOGICAL_OR) reduce 486) ((T_LOGICAL_XOR) reduce 486) ((T_POW) reduce 486) ((T_SL) reduce 486) ((T_SPACESHIP) reduce 486) ((T_SR) reduce 486) (("^") reduce 486) (("|") reduce 486)) 3515 ((("%") reduce 499) (("*") reduce 499) (("+") reduce 499) ((",") reduce 499) (("-") reduce 499) ((".") reduce 499) (("/") reduce 499) ((";") reduce 499) (("<") reduce 499) ((">") reduce 499) (("?") reduce 499) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_BOOLEAN_AND) reduce 499) ((T_BOOLEAN_OR) reduce 499) ((T_COALESCE) reduce 499) ((T_DOUBLE_ARROW) reduce 499) ((T_INSTANCEOF) reduce 499) ((T_IS_EQUAL) reduce 499) ((T_IS_GREATER_OR_EQUAL) reduce 499) ((T_IS_IDENTICAL) reduce 499) ((T_IS_NOT_EQUAL) reduce 499) ((T_IS_NOT_IDENTICAL) reduce 499) ((T_IS_SMALLER_OR_EQUAL) reduce 499) ((T_LOGICAL_AND) reduce 499) ((T_LOGICAL_OR) reduce 499) ((T_LOGICAL_XOR) reduce 499) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 499) ((T_OBJECT_OPERATOR) reduce 499) ((T_POW) reduce 499) ((T_SL) reduce 499) ((T_SPACESHIP) reduce 499) ((T_SR) reduce 499) (("[") reduce 499) (("^") reduce 499) (("{") reduce 499) (("|") reduce 499)) 3516 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) ((",") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) ((";") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 93) ((T_OBJECT_OPERATOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("[") reduce 93) (("^") reduce 93) (("{") reduce 93) (("|") reduce 93)) 3517 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) ((",") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) ((";") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 92) ((T_OBJECT_OPERATOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("[") reduce 92) (("^") reduce 92) (("{") reduce 92) (("|") reduce 92)) 3518 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) ((",") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) ((";") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 94) ((T_OBJECT_OPERATOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("[") reduce 94) (("^") reduce 94) (("{") reduce 94) (("|") reduce 94)) 3520 ((("%") reduce 501) (("*") reduce 501) (("+") reduce 501) ((",") reduce 501) (("-") reduce 501) ((".") reduce 501) (("/") reduce 501) ((";") reduce 501) (("<") reduce 501) ((">") reduce 501) (("?") reduce 501) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_BOOLEAN_AND) reduce 501) ((T_BOOLEAN_OR) reduce 501) ((T_COALESCE) reduce 501) ((T_DOUBLE_ARROW) reduce 501) ((T_INSTANCEOF) reduce 501) ((T_IS_EQUAL) reduce 501) ((T_IS_GREATER_OR_EQUAL) reduce 501) ((T_IS_IDENTICAL) reduce 501) ((T_IS_NOT_EQUAL) reduce 501) ((T_IS_NOT_IDENTICAL) reduce 501) ((T_IS_SMALLER_OR_EQUAL) reduce 501) ((T_LOGICAL_AND) reduce 501) ((T_LOGICAL_OR) reduce 501) ((T_LOGICAL_XOR) reduce 501) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 501) ((T_OBJECT_OPERATOR) reduce 501) ((T_POW) reduce 501) ((T_SL) reduce 501) ((T_SPACESHIP) reduce 501) ((T_SR) reduce 501) (("[") reduce 501) (("^") reduce 501) (("{") reduce 501) (("|") reduce 501)) 3528 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) ((",") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) ((";") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 91) ((T_OBJECT_OPERATOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("[") reduce 91) (("^") reduce 91) (("{") reduce 91) (("|") reduce 91)) 3531 ((("%") reduce 498) (("*") reduce 498) (("+") reduce 498) ((",") reduce 498) (("-") reduce 498) ((".") reduce 498) (("/") reduce 498) ((";") reduce 498) (("<") reduce 498) ((">") reduce 498) (("?") reduce 498) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_BOOLEAN_AND) reduce 498) ((T_BOOLEAN_OR) reduce 498) ((T_COALESCE) reduce 498) ((T_DOUBLE_ARROW) reduce 498) ((T_INSTANCEOF) reduce 498) ((T_IS_EQUAL) reduce 498) ((T_IS_GREATER_OR_EQUAL) reduce 498) ((T_IS_IDENTICAL) reduce 498) ((T_IS_NOT_EQUAL) reduce 498) ((T_IS_NOT_IDENTICAL) reduce 498) ((T_IS_SMALLER_OR_EQUAL) reduce 498) ((T_LOGICAL_AND) reduce 498) ((T_LOGICAL_OR) reduce 498) ((T_LOGICAL_XOR) reduce 498) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 498) ((T_OBJECT_OPERATOR) reduce 498) ((T_POW) reduce 498) ((T_SL) reduce 498) ((T_SPACESHIP) reduce 498) ((T_SR) reduce 498) (("[") reduce 498) (("^") reduce 498) (("{") reduce 498) (("|") reduce 498)) 3533 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) ((",") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) ((";") reduce 529) (("<") reduce 529) (("=") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AND_EQUAL) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_COALESCE_EQUAL) reduce 529) ((T_CONCAT_EQUAL) reduce 529) ((T_DEC) reduce 529) ((T_DIV_EQUAL) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INC) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_MINUS_EQUAL) reduce 529) ((T_MOD_EQUAL) reduce 529) ((T_MUL_EQUAL) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_OR_EQUAL) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_PLUS_EQUAL) reduce 529) ((T_POW) reduce 529) ((T_POW_EQUAL) reduce 529) ((T_SL) reduce 529) ((T_SL_EQUAL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) ((T_SR_EQUAL) reduce 529) ((T_XOR_EQUAL) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 3534 ((("!") shift) (("\"") shift) (("$") shift) (("%") reduce 440) (("(") shift) (("*") reduce 440) (("+") shift) ((",") reduce 440) (("-") shift) ((".") reduce 440) (("/") reduce 440) ((";") reduce 440) (("<") reduce 440) ((">") reduce 440) (("?") reduce 440) (("@") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOLEAN_AND) reduce 440) ((T_BOOLEAN_OR) reduce 440) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_COALESCE) reduce 440) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_ARROW) reduce 440) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INSTANCEOF) reduce 440) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_IS_EQUAL) reduce 440) ((T_IS_GREATER_OR_EQUAL) reduce 440) ((T_IS_IDENTICAL) reduce 440) ((T_IS_NOT_EQUAL) reduce 440) ((T_IS_NOT_IDENTICAL) reduce 440) ((T_IS_SMALLER_OR_EQUAL) reduce 440) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_LOGICAL_AND) reduce 440) ((T_LOGICAL_OR) reduce 440) ((T_LOGICAL_XOR) reduce 440) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_POW) reduce 440) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_SL) reduce 440) ((T_SPACESHIP) reduce 440) ((T_SR) reduce 440) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("^") reduce 440) (("`") shift) (("|") reduce 440) (("~") shift)) 3541 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) ((",") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) ((";") reduce 525) (("<") reduce 525) (("=") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AND_EQUAL) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_COALESCE_EQUAL) reduce 525) ((T_CONCAT_EQUAL) reduce 525) ((T_DEC) reduce 525) ((T_DIV_EQUAL) reduce 525) ((T_DOUBLE_ARROW) reduce 525) ((T_INC) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_MINUS_EQUAL) reduce 525) ((T_MOD_EQUAL) reduce 525) ((T_MUL_EQUAL) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_OR_EQUAL) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_PLUS_EQUAL) reduce 525) ((T_POW) reduce 525) ((T_POW_EQUAL) reduce 525) ((T_SL) reduce 525) ((T_SL_EQUAL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) ((T_SR_EQUAL) reduce 525) ((T_XOR_EQUAL) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 3542 ((("%") reduce 493) (("*") reduce 493) (("+") reduce 493) ((",") reduce 493) (("-") reduce 493) ((".") reduce 493) (("/") reduce 493) ((";") reduce 493) (("<") reduce 493) ((">") reduce 493) (("?") reduce 493) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_BOOLEAN_AND) reduce 493) ((T_BOOLEAN_OR) reduce 493) ((T_COALESCE) reduce 493) ((T_DOUBLE_ARROW) reduce 493) ((T_INSTANCEOF) reduce 493) ((T_IS_EQUAL) reduce 493) ((T_IS_GREATER_OR_EQUAL) reduce 493) ((T_IS_IDENTICAL) reduce 493) ((T_IS_NOT_EQUAL) reduce 493) ((T_IS_NOT_IDENTICAL) reduce 493) ((T_IS_SMALLER_OR_EQUAL) reduce 493) ((T_LOGICAL_AND) reduce 493) ((T_LOGICAL_OR) reduce 493) ((T_LOGICAL_XOR) reduce 493) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 513) ((T_OBJECT_OPERATOR) reduce 513) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 513) ((T_POW) reduce 493) ((T_SL) reduce 493) ((T_SPACESHIP) reduce 493) ((T_SR) reduce 493) (("[") reduce 513) (("^") reduce 493) (("{") reduce 513) (("|") reduce 493)) 3544 ((("%") reduce 492) (("*") reduce 492) (("+") reduce 492) ((",") reduce 492) (("-") reduce 492) ((".") reduce 492) (("/") reduce 492) ((";") reduce 492) (("<") reduce 492) ((">") reduce 492) (("?") reduce 492) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_BOOLEAN_AND) reduce 492) ((T_BOOLEAN_OR) reduce 492) ((T_COALESCE) reduce 492) ((T_DOUBLE_ARROW) reduce 492) ((T_INSTANCEOF) reduce 492) ((T_IS_EQUAL) reduce 492) ((T_IS_GREATER_OR_EQUAL) reduce 492) ((T_IS_IDENTICAL) reduce 492) ((T_IS_NOT_EQUAL) reduce 492) ((T_IS_NOT_IDENTICAL) reduce 492) ((T_IS_SMALLER_OR_EQUAL) reduce 492) ((T_LOGICAL_AND) reduce 492) ((T_LOGICAL_OR) reduce 492) ((T_LOGICAL_XOR) reduce 492) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 515) ((T_OBJECT_OPERATOR) reduce 515) ((T_POW) reduce 492) ((T_SL) reduce 492) ((T_SPACESHIP) reduce 492) ((T_SR) reduce 492) (("[") reduce 515) (("^") reduce 492) (("{") reduce 515) (("|") reduce 492)) 3545 ((("%") reduce 491) (("(") reduce 518) (("*") reduce 491) (("+") reduce 491) ((",") reduce 491) (("-") reduce 491) ((".") reduce 491) (("/") reduce 491) ((";") reduce 491) (("<") reduce 491) ((">") reduce 491) (("?") reduce 491) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_BOOLEAN_AND) reduce 491) ((T_BOOLEAN_OR) reduce 491) ((T_COALESCE) reduce 491) ((T_DOUBLE_ARROW) reduce 491) ((T_INSTANCEOF) reduce 491) ((T_IS_EQUAL) reduce 491) ((T_IS_GREATER_OR_EQUAL) reduce 491) ((T_IS_IDENTICAL) reduce 491) ((T_IS_NOT_EQUAL) reduce 491) ((T_IS_NOT_IDENTICAL) reduce 491) ((T_IS_SMALLER_OR_EQUAL) reduce 491) ((T_LOGICAL_AND) reduce 491) ((T_LOGICAL_OR) reduce 491) ((T_LOGICAL_XOR) reduce 491) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 512) ((T_OBJECT_OPERATOR) reduce 512) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 512) ((T_POW) reduce 491) ((T_SL) reduce 491) ((T_SPACESHIP) reduce 491) ((T_SR) reduce 491) (("[") reduce 512) (("^") reduce 491) (("{") reduce 512) (("|") reduce 491)) 3546 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 441) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 441) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 441) ((T_LOGICAL_OR) reduce 441) ((T_LOGICAL_XOR) reduce 441) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3549 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) ((",") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) ((";") reduce 524) (("<") reduce 524) (("=") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AND_EQUAL) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_COALESCE_EQUAL) reduce 524) ((T_CONCAT_EQUAL) reduce 524) ((T_DEC) reduce 524) ((T_DIV_EQUAL) reduce 524) ((T_DOUBLE_ARROW) reduce 524) ((T_INC) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_MINUS_EQUAL) reduce 524) ((T_MOD_EQUAL) reduce 524) ((T_MUL_EQUAL) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_OR_EQUAL) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_PLUS_EQUAL) reduce 524) ((T_POW) reduce 524) ((T_POW_EQUAL) reduce 524) ((T_SL) reduce 524) ((T_SL_EQUAL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) ((T_SR_EQUAL) reduce 524) ((T_XOR_EQUAL) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 3550 ((("%") reduce 445) (("*") reduce 445) (("+") reduce 445) ((",") reduce 445) (("-") reduce 445) ((".") reduce 445) (("/") reduce 445) ((";") reduce 445) (("<") reduce 445) ((">") reduce 445) (("?") reduce 445) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_BOOLEAN_AND) reduce 445) ((T_BOOLEAN_OR) reduce 445) ((T_COALESCE) reduce 445) ((T_DOUBLE_ARROW) reduce 445) ((T_INSTANCEOF) reduce 445) ((T_IS_EQUAL) reduce 445) ((T_IS_GREATER_OR_EQUAL) reduce 445) ((T_IS_IDENTICAL) reduce 445) ((T_IS_NOT_EQUAL) reduce 445) ((T_IS_NOT_IDENTICAL) reduce 445) ((T_IS_SMALLER_OR_EQUAL) reduce 445) ((T_LOGICAL_AND) reduce 445) ((T_LOGICAL_OR) reduce 445) ((T_LOGICAL_XOR) reduce 445) ((T_POW) reduce 445) ((T_SL) reduce 445) ((T_SPACESHIP) reduce 445) ((T_SR) reduce 445) (("^") reduce 445) (("|") reduce 445)) 3551 ((("%") reduce 427) (("*") reduce 427) (("+") reduce 427) ((",") reduce 427) (("-") reduce 427) ((".") reduce 427) (("/") reduce 427) ((";") reduce 427) (("<") reduce 427) ((">") reduce 427) (("?") reduce 427) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_BOOLEAN_AND) reduce 427) ((T_BOOLEAN_OR) reduce 427) ((T_COALESCE) reduce 427) ((T_DOUBLE_ARROW) reduce 427) ((T_INSTANCEOF) reduce 427) ((T_IS_EQUAL) reduce 427) ((T_IS_GREATER_OR_EQUAL) reduce 427) ((T_IS_IDENTICAL) reduce 427) ((T_IS_NOT_EQUAL) reduce 427) ((T_IS_NOT_IDENTICAL) reduce 427) ((T_IS_SMALLER_OR_EQUAL) reduce 427) ((T_LOGICAL_AND) reduce 427) ((T_LOGICAL_OR) reduce 427) ((T_LOGICAL_XOR) reduce 427) ((T_POW) reduce 427) ((T_SL) reduce 427) ((T_SPACESHIP) reduce 427) ((T_SR) reduce 427) (("^") reduce 427) (("|") reduce 427)) 3552 ((("%") reduce 449) (("*") reduce 449) (("+") reduce 449) ((",") reduce 449) (("-") reduce 449) ((".") reduce 449) (("/") reduce 449) ((";") reduce 449) (("<") reduce 449) ((">") reduce 449) (("?") reduce 449) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_BOOLEAN_AND) reduce 449) ((T_BOOLEAN_OR) reduce 449) ((T_COALESCE) reduce 449) ((T_DOUBLE_ARROW) reduce 449) ((T_INSTANCEOF) reduce 449) ((T_IS_EQUAL) reduce 449) ((T_IS_GREATER_OR_EQUAL) reduce 449) ((T_IS_IDENTICAL) reduce 449) ((T_IS_NOT_EQUAL) reduce 449) ((T_IS_NOT_IDENTICAL) reduce 449) ((T_IS_SMALLER_OR_EQUAL) reduce 449) ((T_LOGICAL_AND) reduce 449) ((T_LOGICAL_OR) reduce 449) ((T_LOGICAL_XOR) reduce 449) ((T_POW) reduce 449) ((T_SL) reduce 449) ((T_SPACESHIP) reduce 449) ((T_SR) reduce 449) (("^") reduce 449) (("|") reduce 449)) 3553 ((("%") reduce 494) (("(") shift) (("*") reduce 494) (("+") reduce 494) ((",") reduce 494) (("-") reduce 494) ((".") reduce 494) (("/") reduce 494) ((";") reduce 494) (("<") reduce 494) ((">") reduce 494) (("?") reduce 494) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_BOOLEAN_AND) reduce 494) ((T_BOOLEAN_OR) reduce 494) ((T_COALESCE) reduce 494) ((T_DOUBLE_ARROW) reduce 494) ((T_INSTANCEOF) reduce 494) ((T_IS_EQUAL) reduce 494) ((T_IS_GREATER_OR_EQUAL) reduce 494) ((T_IS_IDENTICAL) reduce 494) ((T_IS_NOT_EQUAL) reduce 494) ((T_IS_NOT_IDENTICAL) reduce 494) ((T_IS_SMALLER_OR_EQUAL) reduce 494) ((T_LOGICAL_AND) reduce 494) ((T_LOGICAL_OR) reduce 494) ((T_LOGICAL_XOR) reduce 494) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 494) ((T_OBJECT_OPERATOR) reduce 494) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 494) ((T_SL) reduce 494) ((T_SPACESHIP) reduce 494) ((T_SR) reduce 494) (("[") reduce 494) (("^") reduce 494) (("{") reduce 494) (("|") reduce 494)) 3554 ((("%") reduce 423) (("*") reduce 423) (("+") reduce 423) ((",") reduce 423) (("-") reduce 423) ((".") reduce 423) (("/") reduce 423) ((";") reduce 423) (("<") reduce 423) ((">") reduce 423) (("?") reduce 423) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_BOOLEAN_AND) reduce 423) ((T_BOOLEAN_OR) reduce 423) ((T_COALESCE) reduce 423) ((T_DOUBLE_ARROW) reduce 423) ((T_INSTANCEOF) reduce 423) ((T_IS_EQUAL) reduce 423) ((T_IS_GREATER_OR_EQUAL) reduce 423) ((T_IS_IDENTICAL) reduce 423) ((T_IS_NOT_EQUAL) reduce 423) ((T_IS_NOT_IDENTICAL) reduce 423) ((T_IS_SMALLER_OR_EQUAL) reduce 423) ((T_LOGICAL_AND) reduce 423) ((T_LOGICAL_OR) reduce 423) ((T_LOGICAL_XOR) reduce 423) ((T_POW) reduce 423) ((T_SL) reduce 423) ((T_SPACESHIP) reduce 423) ((T_SR) reduce 423) (("^") reduce 423) (("|") reduce 423)) 3555 ((("%") reduce 437) (("*") reduce 437) (("+") reduce 437) ((",") reduce 437) (("-") reduce 437) ((".") reduce 437) (("/") reduce 437) ((";") reduce 437) (("<") reduce 437) ((">") reduce 437) (("?") reduce 437) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_BOOLEAN_AND) reduce 437) ((T_BOOLEAN_OR) reduce 437) ((T_COALESCE) reduce 437) ((T_DOUBLE_ARROW) reduce 437) ((T_INSTANCEOF) reduce 437) ((T_IS_EQUAL) reduce 437) ((T_IS_GREATER_OR_EQUAL) reduce 437) ((T_IS_IDENTICAL) reduce 437) ((T_IS_NOT_EQUAL) reduce 437) ((T_IS_NOT_IDENTICAL) reduce 437) ((T_IS_SMALLER_OR_EQUAL) reduce 437) ((T_LOGICAL_AND) reduce 437) ((T_LOGICAL_OR) reduce 437) ((T_LOGICAL_XOR) reduce 437) ((T_POW) reduce 437) ((T_SL) reduce 437) ((T_SPACESHIP) reduce 437) ((T_SR) reduce 437) (("^") reduce 437) (("|") reduce 437)) 3556 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) ((",") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) ((";") reduce 519) (("<") reduce 519) (("=") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AND_EQUAL) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_COALESCE_EQUAL) reduce 519) ((T_CONCAT_EQUAL) reduce 519) ((T_DEC) reduce 519) ((T_DIV_EQUAL) reduce 519) ((T_DOUBLE_ARROW) reduce 519) ((T_INC) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_MINUS_EQUAL) reduce 519) ((T_MOD_EQUAL) reduce 519) ((T_MUL_EQUAL) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_OR_EQUAL) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_PLUS_EQUAL) reduce 519) ((T_POW) reduce 519) ((T_POW_EQUAL) reduce 519) ((T_SL) reduce 519) ((T_SL_EQUAL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) ((T_SR_EQUAL) reduce 519) ((T_XOR_EQUAL) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 3557 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) ((",") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) ((";") reduce 526) (("<") reduce 526) (("=") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AND_EQUAL) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_COALESCE_EQUAL) reduce 526) ((T_CONCAT_EQUAL) reduce 526) ((T_DEC) reduce 526) ((T_DIV_EQUAL) reduce 526) ((T_DOUBLE_ARROW) reduce 526) ((T_INC) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_MINUS_EQUAL) reduce 526) ((T_MOD_EQUAL) reduce 526) ((T_MUL_EQUAL) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_OR_EQUAL) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_PLUS_EQUAL) reduce 526) ((T_POW) reduce 526) ((T_POW_EQUAL) reduce 526) ((T_SL) reduce 526) ((T_SL_EQUAL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) ((T_SR_EQUAL) reduce 526) ((T_XOR_EQUAL) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 3558 ((("%") reduce 367) (("*") reduce 367) (("+") reduce 367) ((",") reduce 367) (("-") reduce 367) ((".") reduce 367) (("/") reduce 367) ((";") reduce 367) (("<") reduce 367) (("=") shift) ((">") reduce 367) (("?") reduce 367) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AND_EQUAL) shift) ((T_BOOLEAN_AND) reduce 367) ((T_BOOLEAN_OR) reduce 367) ((T_COALESCE) reduce 367) ((T_COALESCE_EQUAL) shift) ((T_CONCAT_EQUAL) shift) ((T_DEC) shift) ((T_DIV_EQUAL) shift) ((T_DOUBLE_ARROW) reduce 367) ((T_INC) shift) ((T_INSTANCEOF) reduce 367) ((T_IS_EQUAL) reduce 367) ((T_IS_GREATER_OR_EQUAL) reduce 367) ((T_IS_IDENTICAL) reduce 367) ((T_IS_NOT_EQUAL) reduce 367) ((T_IS_NOT_IDENTICAL) reduce 367) ((T_IS_SMALLER_OR_EQUAL) reduce 367) ((T_LOGICAL_AND) reduce 367) ((T_LOGICAL_OR) reduce 367) ((T_LOGICAL_XOR) reduce 367) ((T_MINUS_EQUAL) shift) ((T_MOD_EQUAL) shift) ((T_MUL_EQUAL) shift) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_OR_EQUAL) shift) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_PLUS_EQUAL) shift) ((T_POW) reduce 367) ((T_POW_EQUAL) shift) ((T_SL) reduce 367) ((T_SL_EQUAL) shift) ((T_SPACESHIP) reduce 367) ((T_SR) reduce 367) ((T_SR_EQUAL) shift) ((T_XOR_EQUAL) shift) (("[") reduce 510) (("^") reduce 367) (("{") reduce 510) (("|") reduce 367)) 3561 ((("%") reduce 411) (("*") reduce 411) (("+") reduce 411) ((",") reduce 411) (("-") reduce 411) ((".") reduce 411) (("/") reduce 411) ((";") reduce 411) (("<") reduce 411) ((">") reduce 411) (("?") reduce 411) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_BOOLEAN_AND) reduce 411) ((T_BOOLEAN_OR) reduce 411) ((T_COALESCE) reduce 411) ((T_DOUBLE_ARROW) reduce 411) ((T_INSTANCEOF) reduce 411) ((T_IS_EQUAL) reduce 411) ((T_IS_GREATER_OR_EQUAL) reduce 411) ((T_IS_IDENTICAL) reduce 411) ((T_IS_NOT_EQUAL) reduce 411) ((T_IS_NOT_IDENTICAL) reduce 411) ((T_IS_SMALLER_OR_EQUAL) reduce 411) ((T_LOGICAL_AND) reduce 411) ((T_LOGICAL_OR) reduce 411) ((T_LOGICAL_XOR) reduce 411) ((T_POW) shift) ((T_SL) reduce 411) ((T_SPACESHIP) reduce 411) ((T_SR) reduce 411) (("^") reduce 411) (("|") reduce 411)) 3592 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 395) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 395) (("<") shift) ((">") shift) (("?") reduce 395) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 395) ((T_BOOLEAN_OR) reduce 395) ((T_COALESCE) reduce 395) ((T_DOUBLE_ARROW) reduce 395) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 395) ((T_LOGICAL_OR) reduce 395) ((T_LOGICAL_XOR) reduce 395) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") reduce 395)) 3593 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 398) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 398) (("<") shift) ((">") shift) (("?") reduce 398) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 398) ((T_BOOLEAN_OR) reduce 398) ((T_COALESCE) reduce 398) ((T_DOUBLE_ARROW) reduce 398) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 398) ((T_LOGICAL_OR) reduce 398) ((T_LOGICAL_XOR) reduce 398) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 398) (("|") reduce 398)) 3594 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 407) (("-") shift) ((".") reduce 407) (("/") shift) ((";") reduce 407) (("<") reduce 407) ((">") reduce 407) (("?") reduce 407) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_BOOLEAN_AND) reduce 407) ((T_BOOLEAN_OR) reduce 407) ((T_COALESCE) reduce 407) ((T_DOUBLE_ARROW) reduce 407) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 407) ((T_IS_GREATER_OR_EQUAL) reduce 407) ((T_IS_IDENTICAL) reduce 407) ((T_IS_NOT_EQUAL) reduce 407) ((T_IS_NOT_IDENTICAL) reduce 407) ((T_IS_SMALLER_OR_EQUAL) reduce 407) ((T_LOGICAL_AND) reduce 407) ((T_LOGICAL_OR) reduce 407) ((T_LOGICAL_XOR) reduce 407) ((T_POW) shift) ((T_SL) reduce 407) ((T_SPACESHIP) reduce 407) ((T_SR) reduce 407) (("^") reduce 407) (("|") reduce 407)) 3595 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 420) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 420) (("<") shift) ((">") shift) (("?") reduce 420) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_BOOLEAN_AND) reduce 420) ((T_BOOLEAN_OR) reduce 420) ((T_COALESCE) reduce 420) ((T_DOUBLE_ARROW) reduce 420) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 420) ((T_LOGICAL_OR) reduce 420) ((T_LOGICAL_XOR) reduce 420) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 420) (("|") reduce 420)) 3596 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 406) (("-") shift) ((".") reduce 406) (("/") shift) ((";") reduce 406) (("<") reduce 406) ((">") reduce 406) (("?") reduce 406) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_BOOLEAN_AND) reduce 406) ((T_BOOLEAN_OR) reduce 406) ((T_COALESCE) reduce 406) ((T_DOUBLE_ARROW) reduce 406) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 406) ((T_IS_GREATER_OR_EQUAL) reduce 406) ((T_IS_IDENTICAL) reduce 406) ((T_IS_NOT_EQUAL) reduce 406) ((T_IS_NOT_IDENTICAL) reduce 406) ((T_IS_SMALLER_OR_EQUAL) reduce 406) ((T_LOGICAL_AND) reduce 406) ((T_LOGICAL_OR) reduce 406) ((T_LOGICAL_XOR) reduce 406) ((T_POW) shift) ((T_SL) reduce 406) ((T_SPACESHIP) reduce 406) ((T_SR) reduce 406) (("^") reduce 406) (("|") reduce 406)) 3597 ((("%") reduce 403) (("*") reduce 403) (("+") reduce 403) ((",") reduce 403) (("-") reduce 403) ((".") reduce 403) (("/") reduce 403) ((";") reduce 403) (("<") reduce 403) ((">") reduce 403) (("?") reduce 403) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_BOOLEAN_AND) reduce 403) ((T_BOOLEAN_OR) reduce 403) ((T_COALESCE) reduce 403) ((T_DOUBLE_ARROW) reduce 403) ((T_INSTANCEOF) reduce 403) ((T_IS_EQUAL) reduce 403) ((T_IS_GREATER_OR_EQUAL) reduce 403) ((T_IS_IDENTICAL) reduce 403) ((T_IS_NOT_EQUAL) reduce 403) ((T_IS_NOT_IDENTICAL) reduce 403) ((T_IS_SMALLER_OR_EQUAL) reduce 403) ((T_LOGICAL_AND) reduce 403) ((T_LOGICAL_OR) reduce 403) ((T_LOGICAL_XOR) reduce 403) ((T_POW) shift) ((T_SL) reduce 403) ((T_SPACESHIP) reduce 403) ((T_SR) reduce 403) (("^") reduce 403) (("|") reduce 403)) 3598 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 394) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 394) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 394) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 394) ((T_LOGICAL_XOR) reduce 394) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3599 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 392) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 392) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 392) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 392) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3600 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 393) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 393) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 393) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 393) ((T_LOGICAL_OR) reduce 393) ((T_LOGICAL_XOR) reduce 393) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3601 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 417) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 417) (("<") shift) ((">") shift) (("?") reduce 417) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_BOOLEAN_AND) reduce 417) ((T_BOOLEAN_OR) reduce 417) ((T_COALESCE) reduce 417) ((T_DOUBLE_ARROW) reduce 417) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 417) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 417) ((T_IS_NOT_EQUAL) reduce 417) ((T_IS_NOT_IDENTICAL) reduce 417) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 417) ((T_LOGICAL_OR) reduce 417) ((T_LOGICAL_XOR) reduce 417) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 417) ((T_SR) shift) (("^") reduce 417) (("|") reduce 417)) 3602 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 413) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 413) (("<") shift) ((">") shift) (("?") reduce 413) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_BOOLEAN_AND) reduce 413) ((T_BOOLEAN_OR) reduce 413) ((T_COALESCE) reduce 413) ((T_DOUBLE_ARROW) reduce 413) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 413) ((T_LOGICAL_OR) reduce 413) ((T_LOGICAL_XOR) reduce 413) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 413) (("|") reduce 413)) 3603 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 415) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 415) (("<") shift) ((">") shift) (("?") reduce 415) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_BOOLEAN_AND) reduce 415) ((T_BOOLEAN_OR) reduce 415) ((T_COALESCE) reduce 415) ((T_DOUBLE_ARROW) reduce 415) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 415) ((T_LOGICAL_OR) reduce 415) ((T_LOGICAL_XOR) reduce 415) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 415) (("|") reduce 415)) 3604 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 412) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 412) (("<") shift) ((">") shift) (("?") reduce 412) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_BOOLEAN_AND) reduce 412) ((T_BOOLEAN_OR) reduce 412) ((T_COALESCE) reduce 412) ((T_DOUBLE_ARROW) reduce 412) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 412) ((T_LOGICAL_OR) reduce 412) ((T_LOGICAL_XOR) reduce 412) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 412) (("|") reduce 412)) 3605 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 419) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 419) (("<") shift) ((">") shift) (("?") reduce 419) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_BOOLEAN_AND) reduce 419) ((T_BOOLEAN_OR) reduce 419) ((T_COALESCE) reduce 419) ((T_DOUBLE_ARROW) reduce 419) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 419) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 419) ((T_IS_NOT_EQUAL) reduce 419) ((T_IS_NOT_IDENTICAL) reduce 419) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 419) ((T_LOGICAL_OR) reduce 419) ((T_LOGICAL_XOR) reduce 419) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 419) ((T_SR) shift) (("^") reduce 419) (("|") reduce 419)) 3606 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 414) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 414) (("<") shift) ((">") shift) (("?") reduce 414) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_BOOLEAN_AND) reduce 414) ((T_BOOLEAN_OR) reduce 414) ((T_COALESCE) reduce 414) ((T_DOUBLE_ARROW) reduce 414) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 414) ((T_LOGICAL_OR) reduce 414) ((T_LOGICAL_XOR) reduce 414) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 414) (("|") reduce 414)) 3609 ((("%") reduce 93) (("*") reduce 93) (("+") reduce 93) ((",") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) ((";") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93)) 3610 ((("%") reduce 92) (("*") reduce 92) (("+") reduce 92) ((",") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) ((";") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92)) 3611 ((("%") reduce 94) (("*") reduce 94) (("+") reduce 94) ((",") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) ((";") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94)) 3612 ((("%") reduce 470) (("*") reduce 470) (("+") reduce 470) ((",") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) ((";") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_DOUBLE_ARROW) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470)) 3613 ((("%") reduce 91) (("*") reduce 91) (("+") reduce 91) ((",") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) ((";") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91)) 3614 ((("%") reduce 529) (("*") reduce 529) (("+") reduce 529) ((",") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) ((";") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 3615 ((("%") reduce 472) (("*") reduce 472) (("+") reduce 472) ((",") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) ((";") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_DOUBLE_ARROW) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472)) 3616 ((("%") reduce 421) (("*") reduce 421) (("+") reduce 421) ((",") reduce 421) (("-") reduce 421) ((".") reduce 421) (("/") reduce 421) ((";") reduce 421) (("<") reduce 421) ((">") reduce 421) (("?") reduce 421) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_BOOLEAN_AND) reduce 421) ((T_BOOLEAN_OR) reduce 421) ((T_COALESCE) reduce 421) ((T_DOUBLE_ARROW) reduce 421) ((T_INSTANCEOF) reduce 421) ((T_IS_EQUAL) reduce 421) ((T_IS_GREATER_OR_EQUAL) reduce 421) ((T_IS_IDENTICAL) reduce 421) ((T_IS_NOT_EQUAL) reduce 421) ((T_IS_NOT_IDENTICAL) reduce 421) ((T_IS_SMALLER_OR_EQUAL) reduce 421) ((T_LOGICAL_AND) reduce 421) ((T_LOGICAL_OR) reduce 421) ((T_LOGICAL_XOR) reduce 421) ((T_POW) reduce 421) ((T_SL) reduce 421) ((T_SPACESHIP) reduce 421) ((T_SR) reduce 421) (("^") reduce 421) (("|") reduce 421)) 3617 ((("%") reduce 471) (("*") reduce 471) (("+") reduce 471) ((",") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) ((";") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_DOUBLE_ARROW) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471)) 3618 ((("%") reduce 473) (("*") reduce 473) (("+") reduce 473) ((",") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) ((";") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_DOUBLE_ARROW) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 3619 ((("%") reduce 534) (("*") reduce 534) (("+") reduce 534) ((",") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) ((";") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_DOUBLE_ARROW) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 3626 ((("%") reduce 536) (("*") reduce 536) (("+") reduce 536) ((",") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) ((";") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_DOUBLE_ARROW) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 3628 ((("%") reduce 535) (("*") reduce 535) (("+") reduce 535) ((",") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) ((";") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_DOUBLE_ARROW) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 3629 ((("%") reduce 540) (("*") reduce 540) (("+") reduce 540) ((",") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) ((";") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_DOUBLE_ARROW) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 3630 ((("%") reduce 544) (("*") reduce 544) (("+") reduce 544) ((",") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) ((";") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 3631 ((("%") reduce 537) (("*") reduce 537) (("+") reduce 537) ((",") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) ((";") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_DOUBLE_ARROW) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 3632 ((("%") reduce 546) (("*") reduce 546) (("+") reduce 546) ((",") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) ((";") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 3635 ((("%") reduce 545) (("*") reduce 545) (("+") reduce 545) ((",") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) ((";") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 3636 ((("%") reduce 538) (("*") reduce 538) (("+") reduce 538) ((",") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) ((";") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_DOUBLE_ARROW) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 3638 ((("%") reduce 539) (("*") reduce 539) (("+") reduce 539) ((",") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) ((";") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_DOUBLE_ARROW) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 3640 ((("%") reduce 474) (("*") reduce 474) (("+") reduce 474) ((",") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) ((";") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_DOUBLE_ARROW) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474)) 3641 ((("%") reduce 531) (("*") reduce 531) (("+") reduce 531) ((",") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) ((";") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 3644 ((("%") reduce 530) (("*") reduce 530) (("+") reduce 530) ((",") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) ((";") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 3645 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 426) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 426) (("<") shift) ((">") shift) (("?") reduce 426) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 426) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 426) ((T_LOGICAL_OR) reduce 426) ((T_LOGICAL_XOR) reduce 426) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3646 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 390) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 390) (("<") shift) ((">") shift) (("?") reduce 390) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) reduce 390) ((T_COALESCE) reduce 390) ((T_DOUBLE_ARROW) reduce 390) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 390) ((T_LOGICAL_OR) reduce 390) ((T_LOGICAL_XOR) reduce 390) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3647 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 391) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 391) (("<") shift) ((">") shift) (("?") reduce 391) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 391) ((T_BOOLEAN_OR) reduce 391) ((T_COALESCE) reduce 391) ((T_DOUBLE_ARROW) reduce 391) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 391) ((T_LOGICAL_OR) reduce 391) ((T_LOGICAL_XOR) reduce 391) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3648 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 396) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 396) (("<") shift) ((">") shift) (("?") reduce 396) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_BOOLEAN_AND) reduce 396) ((T_BOOLEAN_OR) reduce 396) ((T_COALESCE) reduce 396) ((T_DOUBLE_ARROW) reduce 396) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 396) ((T_LOGICAL_OR) reduce 396) ((T_LOGICAL_XOR) reduce 396) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 396) (("|") reduce 396)) 3649 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 397) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 397) (("<") shift) ((">") shift) (("?") reduce 397) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_BOOLEAN_AND) reduce 397) ((T_BOOLEAN_OR) reduce 397) ((T_COALESCE) reduce 397) ((T_DOUBLE_ARROW) reduce 397) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 397) ((T_LOGICAL_OR) reduce 397) ((T_LOGICAL_XOR) reduce 397) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 397) (("|") reduce 397)) 3653 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 424) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 424) (("<") shift) ((">") shift) (("?") reduce 424) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 424) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 424) ((T_LOGICAL_OR) reduce 424) ((T_LOGICAL_XOR) reduce 424) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3654 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 425) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 425) (("<") shift) ((">") shift) (("?") reduce 425) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 425) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 425) ((T_LOGICAL_OR) reduce 425) ((T_LOGICAL_XOR) reduce 425) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3655 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 418) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 418) (("<") shift) ((">") shift) (("?") reduce 418) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_BOOLEAN_AND) reduce 418) ((T_BOOLEAN_OR) reduce 418) ((T_COALESCE) reduce 418) ((T_DOUBLE_ARROW) reduce 418) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 418) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 418) ((T_IS_NOT_EQUAL) reduce 418) ((T_IS_NOT_IDENTICAL) reduce 418) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 418) ((T_LOGICAL_OR) reduce 418) ((T_LOGICAL_XOR) reduce 418) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 418) ((T_SR) shift) (("^") reduce 418) (("|") reduce 418)) 3656 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 416) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 416) (("<") shift) ((">") shift) (("?") reduce 416) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_BOOLEAN_AND) reduce 416) ((T_BOOLEAN_OR) reduce 416) ((T_COALESCE) reduce 416) ((T_DOUBLE_ARROW) reduce 416) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 416) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 416) ((T_IS_NOT_EQUAL) reduce 416) ((T_IS_NOT_IDENTICAL) reduce 416) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 416) ((T_LOGICAL_OR) reduce 416) ((T_LOGICAL_XOR) reduce 416) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 416) ((T_SR) shift) (("^") reduce 416) (("|") reduce 416)) 3657 ((("%") reduce 404) (("*") reduce 404) (("+") reduce 404) ((",") reduce 404) (("-") reduce 404) ((".") reduce 404) (("/") reduce 404) ((";") reduce 404) (("<") reduce 404) ((">") reduce 404) (("?") reduce 404) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_BOOLEAN_AND) reduce 404) ((T_BOOLEAN_OR) reduce 404) ((T_COALESCE) reduce 404) ((T_DOUBLE_ARROW) reduce 404) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 404) ((T_IS_GREATER_OR_EQUAL) reduce 404) ((T_IS_IDENTICAL) reduce 404) ((T_IS_NOT_EQUAL) reduce 404) ((T_IS_NOT_IDENTICAL) reduce 404) ((T_IS_SMALLER_OR_EQUAL) reduce 404) ((T_LOGICAL_AND) reduce 404) ((T_LOGICAL_OR) reduce 404) ((T_LOGICAL_XOR) reduce 404) ((T_POW) shift) ((T_SL) reduce 404) ((T_SPACESHIP) reduce 404) ((T_SR) reduce 404) (("^") reduce 404) (("|") reduce 404)) 3658 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 399) (("-") shift) ((".") reduce 399) (("/") shift) ((";") reduce 399) (("<") reduce 399) ((">") reduce 399) (("?") reduce 399) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_BOOLEAN_AND) reduce 399) ((T_BOOLEAN_OR) reduce 399) ((T_COALESCE) reduce 399) ((T_DOUBLE_ARROW) reduce 399) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 399) ((T_IS_GREATER_OR_EQUAL) reduce 399) ((T_IS_IDENTICAL) reduce 399) ((T_IS_NOT_EQUAL) reduce 399) ((T_IS_NOT_IDENTICAL) reduce 399) ((T_IS_SMALLER_OR_EQUAL) reduce 399) ((T_LOGICAL_AND) reduce 399) ((T_LOGICAL_OR) reduce 399) ((T_LOGICAL_XOR) reduce 399) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 399) ((T_SR) shift) (("^") reduce 399) (("|") reduce 399)) 3659 ((("%") shift) (("*") shift) (("+") reduce 401) ((",") reduce 401) (("-") reduce 401) ((".") reduce 401) (("/") shift) ((";") reduce 401) (("<") reduce 401) ((">") reduce 401) (("?") reduce 401) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_BOOLEAN_AND) reduce 401) ((T_BOOLEAN_OR) reduce 401) ((T_COALESCE) reduce 401) ((T_DOUBLE_ARROW) reduce 401) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 401) ((T_IS_GREATER_OR_EQUAL) reduce 401) ((T_IS_IDENTICAL) reduce 401) ((T_IS_NOT_EQUAL) reduce 401) ((T_IS_NOT_IDENTICAL) reduce 401) ((T_IS_SMALLER_OR_EQUAL) reduce 401) ((T_LOGICAL_AND) reduce 401) ((T_LOGICAL_OR) reduce 401) ((T_LOGICAL_XOR) reduce 401) ((T_POW) shift) ((T_SL) reduce 401) ((T_SPACESHIP) reduce 401) ((T_SR) reduce 401) (("^") reduce 401) (("|") reduce 401)) 3660 ((("%") shift) (("*") shift) (("+") reduce 400) ((",") reduce 400) (("-") reduce 400) ((".") reduce 400) (("/") shift) ((";") reduce 400) (("<") reduce 400) ((">") reduce 400) (("?") reduce 400) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_BOOLEAN_AND) reduce 400) ((T_BOOLEAN_OR) reduce 400) ((T_COALESCE) reduce 400) ((T_DOUBLE_ARROW) reduce 400) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 400) ((T_IS_GREATER_OR_EQUAL) reduce 400) ((T_IS_IDENTICAL) reduce 400) ((T_IS_NOT_EQUAL) reduce 400) ((T_IS_NOT_IDENTICAL) reduce 400) ((T_IS_SMALLER_OR_EQUAL) reduce 400) ((T_LOGICAL_AND) reduce 400) ((T_LOGICAL_OR) reduce 400) ((T_LOGICAL_XOR) reduce 400) ((T_POW) shift) ((T_SL) reduce 400) ((T_SPACESHIP) reduce 400) ((T_SR) reduce 400) (("^") reduce 400) (("|") reduce 400)) 3661 ((("%") reduce 402) (("*") reduce 402) (("+") reduce 402) ((",") reduce 402) (("-") reduce 402) ((".") reduce 402) (("/") reduce 402) ((";") reduce 402) (("<") reduce 402) ((">") reduce 402) (("?") reduce 402) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_BOOLEAN_AND) reduce 402) ((T_BOOLEAN_OR) reduce 402) ((T_COALESCE) reduce 402) ((T_DOUBLE_ARROW) reduce 402) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 402) ((T_IS_GREATER_OR_EQUAL) reduce 402) ((T_IS_IDENTICAL) reduce 402) ((T_IS_NOT_EQUAL) reduce 402) ((T_IS_NOT_IDENTICAL) reduce 402) ((T_IS_SMALLER_OR_EQUAL) reduce 402) ((T_LOGICAL_AND) reduce 402) ((T_LOGICAL_OR) reduce 402) ((T_LOGICAL_XOR) reduce 402) ((T_POW) shift) ((T_SL) reduce 402) ((T_SPACESHIP) reduce 402) ((T_SR) reduce 402) (("^") reduce 402) (("|") reduce 402)) 3662 ((("%") reduce 405) (("*") reduce 405) (("+") reduce 405) ((",") reduce 405) (("-") reduce 405) ((".") reduce 405) (("/") reduce 405) ((";") reduce 405) (("<") reduce 405) ((">") reduce 405) (("?") reduce 405) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_BOOLEAN_AND) reduce 405) ((T_BOOLEAN_OR) reduce 405) ((T_COALESCE) reduce 405) ((T_DOUBLE_ARROW) reduce 405) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 405) ((T_IS_GREATER_OR_EQUAL) reduce 405) ((T_IS_IDENTICAL) reduce 405) ((T_IS_NOT_EQUAL) reduce 405) ((T_IS_NOT_IDENTICAL) reduce 405) ((T_IS_SMALLER_OR_EQUAL) reduce 405) ((T_LOGICAL_AND) reduce 405) ((T_LOGICAL_OR) reduce 405) ((T_LOGICAL_XOR) reduce 405) ((T_POW) shift) ((T_SL) reduce 405) ((T_SPACESHIP) reduce 405) ((T_SR) reduce 405) (("^") reduce 405) (("|") reduce 405)) 3664 ((("%") reduce 73) (("(") reduce 73) (("*") reduce 73) (("+") reduce 73) ((",") reduce 73) (("-") reduce 73) ((".") reduce 73) (("/") reduce 73) ((";") reduce 73) (("<") reduce 73) ((">") reduce 73) (("?") reduce 73) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_BOOLEAN_AND) reduce 73) ((T_BOOLEAN_OR) reduce 73) ((T_COALESCE) reduce 73) ((T_DOUBLE_ARROW) reduce 73) ((T_INSTANCEOF) reduce 73) ((T_IS_EQUAL) reduce 73) ((T_IS_GREATER_OR_EQUAL) reduce 73) ((T_IS_IDENTICAL) reduce 73) ((T_IS_NOT_EQUAL) reduce 73) ((T_IS_NOT_IDENTICAL) reduce 73) ((T_IS_SMALLER_OR_EQUAL) reduce 73) ((T_LOGICAL_AND) reduce 73) ((T_LOGICAL_OR) reduce 73) ((T_LOGICAL_XOR) reduce 73) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 73) ((T_OBJECT_OPERATOR) reduce 73) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 73) ((T_POW) reduce 73) ((T_SL) reduce 73) ((T_SPACESHIP) reduce 73) ((T_SR) reduce 73) (("[") reduce 73) (("^") reduce 73) (("{") reduce 73) (("|") reduce 73)) 3665 ((("%") reduce 52) (("(") reduce 52) (("*") reduce 52) (("+") reduce 52) ((",") reduce 52) (("-") reduce 52) ((".") reduce 52) (("/") reduce 52) ((";") reduce 52) (("<") reduce 52) ((">") reduce 52) (("?") reduce 52) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_BOOLEAN_AND) reduce 52) ((T_BOOLEAN_OR) reduce 52) ((T_COALESCE) reduce 52) ((T_DOUBLE_ARROW) reduce 52) ((T_INSTANCEOF) reduce 52) ((T_IS_EQUAL) reduce 52) ((T_IS_GREATER_OR_EQUAL) reduce 52) ((T_IS_IDENTICAL) reduce 52) ((T_IS_NOT_EQUAL) reduce 52) ((T_IS_NOT_IDENTICAL) reduce 52) ((T_IS_SMALLER_OR_EQUAL) reduce 52) ((T_LOGICAL_AND) reduce 52) ((T_LOGICAL_OR) reduce 52) ((T_LOGICAL_XOR) reduce 52) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 52) ((T_OBJECT_OPERATOR) reduce 52) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 52) ((T_POW) reduce 52) ((T_SL) reduce 52) ((T_SPACESHIP) reduce 52) ((T_SR) reduce 52) (("[") reduce 52) (("^") reduce 52) (("{") reduce 52) (("|") reduce 52)) 3666 ((("%") reduce 27) (("(") reduce 27) (("*") reduce 27) (("+") reduce 27) ((",") reduce 27) (("-") reduce 27) ((".") reduce 27) (("/") reduce 27) ((";") reduce 27) (("<") reduce 27) ((">") reduce 27) (("?") reduce 27) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_BOOLEAN_AND) reduce 27) ((T_BOOLEAN_OR) reduce 27) ((T_COALESCE) reduce 27) ((T_DOUBLE_ARROW) reduce 27) ((T_INSTANCEOF) reduce 27) ((T_IS_EQUAL) reduce 27) ((T_IS_GREATER_OR_EQUAL) reduce 27) ((T_IS_IDENTICAL) reduce 27) ((T_IS_NOT_EQUAL) reduce 27) ((T_IS_NOT_IDENTICAL) reduce 27) ((T_IS_SMALLER_OR_EQUAL) reduce 27) ((T_LOGICAL_AND) reduce 27) ((T_LOGICAL_OR) reduce 27) ((T_LOGICAL_XOR) reduce 27) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 27) ((T_OBJECT_OPERATOR) reduce 27) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 27) ((T_POW) reduce 27) ((T_SL) reduce 27) ((T_SPACESHIP) reduce 27) ((T_SR) reduce 27) (("[") reduce 27) (("^") reduce 27) (("{") reduce 27) (("|") reduce 27)) 3667 ((("%") reduce 51) (("(") reduce 51) (("*") reduce 51) (("+") reduce 51) ((",") reduce 51) (("-") reduce 51) ((".") reduce 51) (("/") reduce 51) ((";") reduce 51) (("<") reduce 51) ((">") reduce 51) (("?") reduce 51) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_BOOLEAN_AND) reduce 51) ((T_BOOLEAN_OR) reduce 51) ((T_COALESCE) reduce 51) ((T_DOUBLE_ARROW) reduce 51) ((T_INSTANCEOF) reduce 51) ((T_IS_EQUAL) reduce 51) ((T_IS_GREATER_OR_EQUAL) reduce 51) ((T_IS_IDENTICAL) reduce 51) ((T_IS_NOT_EQUAL) reduce 51) ((T_IS_NOT_IDENTICAL) reduce 51) ((T_IS_SMALLER_OR_EQUAL) reduce 51) ((T_LOGICAL_AND) reduce 51) ((T_LOGICAL_OR) reduce 51) ((T_LOGICAL_XOR) reduce 51) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 51) ((T_OBJECT_OPERATOR) reduce 51) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 51) ((T_POW) reduce 51) ((T_SL) reduce 51) ((T_SPACESHIP) reduce 51) ((T_SR) reduce 51) (("[") reduce 51) (("^") reduce 51) (("{") reduce 51) (("|") reduce 51)) 3668 ((("%") reduce 53) (("(") reduce 53) (("*") reduce 53) (("+") reduce 53) ((",") reduce 53) (("-") reduce 53) ((".") reduce 53) (("/") reduce 53) ((";") reduce 53) (("<") reduce 53) ((">") reduce 53) (("?") reduce 53) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_BOOLEAN_AND) reduce 53) ((T_BOOLEAN_OR) reduce 53) ((T_COALESCE) reduce 53) ((T_DOUBLE_ARROW) reduce 53) ((T_INSTANCEOF) reduce 53) ((T_IS_EQUAL) reduce 53) ((T_IS_GREATER_OR_EQUAL) reduce 53) ((T_IS_IDENTICAL) reduce 53) ((T_IS_NOT_EQUAL) reduce 53) ((T_IS_NOT_IDENTICAL) reduce 53) ((T_IS_SMALLER_OR_EQUAL) reduce 53) ((T_LOGICAL_AND) reduce 53) ((T_LOGICAL_OR) reduce 53) ((T_LOGICAL_XOR) reduce 53) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 53) ((T_OBJECT_OPERATOR) reduce 53) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 53) ((T_POW) reduce 53) ((T_SL) reduce 53) ((T_SPACESHIP) reduce 53) ((T_SR) reduce 53) (("[") reduce 53) (("^") reduce 53) (("{") reduce 53) (("|") reduce 53)) 3669 ((("%") reduce 49) (("(") reduce 49) (("*") reduce 49) (("+") reduce 49) ((",") reduce 49) (("-") reduce 49) ((".") reduce 49) (("/") reduce 49) ((";") reduce 49) (("<") reduce 49) ((">") reduce 49) (("?") reduce 49) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_BOOLEAN_AND) reduce 49) ((T_BOOLEAN_OR) reduce 49) ((T_COALESCE) reduce 49) ((T_DOUBLE_ARROW) reduce 49) ((T_INSTANCEOF) reduce 49) ((T_IS_EQUAL) reduce 49) ((T_IS_GREATER_OR_EQUAL) reduce 49) ((T_IS_IDENTICAL) reduce 49) ((T_IS_NOT_EQUAL) reduce 49) ((T_IS_NOT_IDENTICAL) reduce 49) ((T_IS_SMALLER_OR_EQUAL) reduce 49) ((T_LOGICAL_AND) reduce 49) ((T_LOGICAL_OR) reduce 49) ((T_LOGICAL_XOR) reduce 49) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 49) ((T_OBJECT_OPERATOR) reduce 49) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 49) ((T_POW) reduce 49) ((T_SL) reduce 49) ((T_SPACESHIP) reduce 49) ((T_SR) reduce 49) (("[") reduce 49) (("^") reduce 49) (("{") reduce 49) (("|") reduce 49)) 3670 ((("%") reduce 29) (("(") reduce 29) (("*") reduce 29) (("+") reduce 29) ((",") reduce 29) (("-") reduce 29) ((".") reduce 29) (("/") reduce 29) ((";") reduce 29) (("<") reduce 29) ((">") reduce 29) (("?") reduce 29) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_BOOLEAN_AND) reduce 29) ((T_BOOLEAN_OR) reduce 29) ((T_COALESCE) reduce 29) ((T_DOUBLE_ARROW) reduce 29) ((T_INSTANCEOF) reduce 29) ((T_IS_EQUAL) reduce 29) ((T_IS_GREATER_OR_EQUAL) reduce 29) ((T_IS_IDENTICAL) reduce 29) ((T_IS_NOT_EQUAL) reduce 29) ((T_IS_NOT_IDENTICAL) reduce 29) ((T_IS_SMALLER_OR_EQUAL) reduce 29) ((T_LOGICAL_AND) reduce 29) ((T_LOGICAL_OR) reduce 29) ((T_LOGICAL_XOR) reduce 29) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 29) ((T_OBJECT_OPERATOR) reduce 29) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 29) ((T_POW) reduce 29) ((T_SL) reduce 29) ((T_SPACESHIP) reduce 29) ((T_SR) reduce 29) (("[") reduce 29) (("^") reduce 29) (("{") reduce 29) (("|") reduce 29)) 3671 ((("%") reduce 59) (("(") reduce 59) (("*") reduce 59) (("+") reduce 59) ((",") reduce 59) (("-") reduce 59) ((".") reduce 59) (("/") reduce 59) ((";") reduce 59) (("<") reduce 59) ((">") reduce 59) (("?") reduce 59) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_BOOLEAN_AND) reduce 59) ((T_BOOLEAN_OR) reduce 59) ((T_COALESCE) reduce 59) ((T_DOUBLE_ARROW) reduce 59) ((T_INSTANCEOF) reduce 59) ((T_IS_EQUAL) reduce 59) ((T_IS_GREATER_OR_EQUAL) reduce 59) ((T_IS_IDENTICAL) reduce 59) ((T_IS_NOT_EQUAL) reduce 59) ((T_IS_NOT_IDENTICAL) reduce 59) ((T_IS_SMALLER_OR_EQUAL) reduce 59) ((T_LOGICAL_AND) reduce 59) ((T_LOGICAL_OR) reduce 59) ((T_LOGICAL_XOR) reduce 59) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 59) ((T_OBJECT_OPERATOR) reduce 59) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 59) ((T_POW) reduce 59) ((T_SL) reduce 59) ((T_SPACESHIP) reduce 59) ((T_SR) reduce 59) (("[") reduce 59) (("^") reduce 59) (("{") reduce 59) (("|") reduce 59)) 3672 ((("%") reduce 60) (("(") reduce 60) (("*") reduce 60) (("+") reduce 60) ((",") reduce 60) (("-") reduce 60) ((".") reduce 60) (("/") reduce 60) ((";") reduce 60) (("<") reduce 60) ((">") reduce 60) (("?") reduce 60) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_BOOLEAN_AND) reduce 60) ((T_BOOLEAN_OR) reduce 60) ((T_COALESCE) reduce 60) ((T_DOUBLE_ARROW) reduce 60) ((T_INSTANCEOF) reduce 60) ((T_IS_EQUAL) reduce 60) ((T_IS_GREATER_OR_EQUAL) reduce 60) ((T_IS_IDENTICAL) reduce 60) ((T_IS_NOT_EQUAL) reduce 60) ((T_IS_NOT_IDENTICAL) reduce 60) ((T_IS_SMALLER_OR_EQUAL) reduce 60) ((T_LOGICAL_AND) reduce 60) ((T_LOGICAL_OR) reduce 60) ((T_LOGICAL_XOR) reduce 60) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 60) ((T_OBJECT_OPERATOR) reduce 60) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 60) ((T_POW) reduce 60) ((T_SL) reduce 60) ((T_SPACESHIP) reduce 60) ((T_SR) reduce 60) (("[") reduce 60) (("^") reduce 60) (("{") reduce 60) (("|") reduce 60)) 3673 ((("%") reduce 11) (("(") reduce 11) (("*") reduce 11) (("+") reduce 11) ((",") reduce 11) (("-") reduce 11) ((".") reduce 11) (("/") reduce 11) ((";") reduce 11) (("<") reduce 11) ((">") reduce 11) (("?") reduce 11) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_BOOLEAN_AND) reduce 11) ((T_BOOLEAN_OR) reduce 11) ((T_COALESCE) reduce 11) ((T_DOUBLE_ARROW) reduce 11) ((T_INSTANCEOF) reduce 11) ((T_IS_EQUAL) reduce 11) ((T_IS_GREATER_OR_EQUAL) reduce 11) ((T_IS_IDENTICAL) reduce 11) ((T_IS_NOT_EQUAL) reduce 11) ((T_IS_NOT_IDENTICAL) reduce 11) ((T_IS_SMALLER_OR_EQUAL) reduce 11) ((T_LOGICAL_AND) reduce 11) ((T_LOGICAL_OR) reduce 11) ((T_LOGICAL_XOR) reduce 11) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 11) ((T_OBJECT_OPERATOR) reduce 11) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 11) ((T_POW) reduce 11) ((T_SL) reduce 11) ((T_SPACESHIP) reduce 11) ((T_SR) reduce 11) (("[") reduce 11) (("^") reduce 11) (("{") reduce 11) (("|") reduce 11)) 3674 ((("%") reduce 42) (("(") reduce 42) (("*") reduce 42) (("+") reduce 42) ((",") reduce 42) (("-") reduce 42) ((".") reduce 42) (("/") reduce 42) ((";") reduce 42) (("<") reduce 42) ((">") reduce 42) (("?") reduce 42) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_BOOLEAN_AND) reduce 42) ((T_BOOLEAN_OR) reduce 42) ((T_COALESCE) reduce 42) ((T_DOUBLE_ARROW) reduce 42) ((T_INSTANCEOF) reduce 42) ((T_IS_EQUAL) reduce 42) ((T_IS_GREATER_OR_EQUAL) reduce 42) ((T_IS_IDENTICAL) reduce 42) ((T_IS_NOT_EQUAL) reduce 42) ((T_IS_NOT_IDENTICAL) reduce 42) ((T_IS_SMALLER_OR_EQUAL) reduce 42) ((T_LOGICAL_AND) reduce 42) ((T_LOGICAL_OR) reduce 42) ((T_LOGICAL_XOR) reduce 42) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 42) ((T_OBJECT_OPERATOR) reduce 42) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 42) ((T_POW) reduce 42) ((T_SL) reduce 42) ((T_SPACESHIP) reduce 42) ((T_SR) reduce 42) (("[") reduce 42) (("^") reduce 42) (("{") reduce 42) (("|") reduce 42)) 3675 ((("%") reduce 39) (("(") reduce 39) (("*") reduce 39) (("+") reduce 39) ((",") reduce 39) (("-") reduce 39) ((".") reduce 39) (("/") reduce 39) ((";") reduce 39) (("<") reduce 39) ((">") reduce 39) (("?") reduce 39) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_BOOLEAN_AND) reduce 39) ((T_BOOLEAN_OR) reduce 39) ((T_COALESCE) reduce 39) ((T_DOUBLE_ARROW) reduce 39) ((T_INSTANCEOF) reduce 39) ((T_IS_EQUAL) reduce 39) ((T_IS_GREATER_OR_EQUAL) reduce 39) ((T_IS_IDENTICAL) reduce 39) ((T_IS_NOT_EQUAL) reduce 39) ((T_IS_NOT_IDENTICAL) reduce 39) ((T_IS_SMALLER_OR_EQUAL) reduce 39) ((T_LOGICAL_AND) reduce 39) ((T_LOGICAL_OR) reduce 39) ((T_LOGICAL_XOR) reduce 39) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 39) ((T_OBJECT_OPERATOR) reduce 39) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 39) ((T_POW) reduce 39) ((T_SL) reduce 39) ((T_SPACESHIP) reduce 39) ((T_SR) reduce 39) (("[") reduce 39) (("^") reduce 39) (("{") reduce 39) (("|") reduce 39)) 3676 ((("%") reduce 25) (("(") reduce 25) (("*") reduce 25) (("+") reduce 25) ((",") reduce 25) (("-") reduce 25) ((".") reduce 25) (("/") reduce 25) ((";") reduce 25) (("<") reduce 25) ((">") reduce 25) (("?") reduce 25) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_BOOLEAN_AND) reduce 25) ((T_BOOLEAN_OR) reduce 25) ((T_COALESCE) reduce 25) ((T_DOUBLE_ARROW) reduce 25) ((T_INSTANCEOF) reduce 25) ((T_IS_EQUAL) reduce 25) ((T_IS_GREATER_OR_EQUAL) reduce 25) ((T_IS_IDENTICAL) reduce 25) ((T_IS_NOT_EQUAL) reduce 25) ((T_IS_NOT_IDENTICAL) reduce 25) ((T_IS_SMALLER_OR_EQUAL) reduce 25) ((T_LOGICAL_AND) reduce 25) ((T_LOGICAL_OR) reduce 25) ((T_LOGICAL_XOR) reduce 25) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 25) ((T_OBJECT_OPERATOR) reduce 25) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 25) ((T_POW) reduce 25) ((T_SL) reduce 25) ((T_SPACESHIP) reduce 25) ((T_SR) reduce 25) (("[") reduce 25) (("^") reduce 25) (("{") reduce 25) (("|") reduce 25)) 3677 ((("%") reduce 50) (("(") reduce 50) (("*") reduce 50) (("+") reduce 50) ((",") reduce 50) (("-") reduce 50) ((".") reduce 50) (("/") reduce 50) ((";") reduce 50) (("<") reduce 50) ((">") reduce 50) (("?") reduce 50) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_BOOLEAN_AND) reduce 50) ((T_BOOLEAN_OR) reduce 50) ((T_COALESCE) reduce 50) ((T_DOUBLE_ARROW) reduce 50) ((T_INSTANCEOF) reduce 50) ((T_IS_EQUAL) reduce 50) ((T_IS_GREATER_OR_EQUAL) reduce 50) ((T_IS_IDENTICAL) reduce 50) ((T_IS_NOT_EQUAL) reduce 50) ((T_IS_NOT_IDENTICAL) reduce 50) ((T_IS_SMALLER_OR_EQUAL) reduce 50) ((T_LOGICAL_AND) reduce 50) ((T_LOGICAL_OR) reduce 50) ((T_LOGICAL_XOR) reduce 50) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 50) ((T_OBJECT_OPERATOR) reduce 50) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 50) ((T_POW) reduce 50) ((T_SL) reduce 50) ((T_SPACESHIP) reduce 50) ((T_SR) reduce 50) (("[") reduce 50) (("^") reduce 50) (("{") reduce 50) (("|") reduce 50)) 3678 ((("%") reduce 66) (("(") reduce 66) (("*") reduce 66) (("+") reduce 66) ((",") reduce 66) (("-") reduce 66) ((".") reduce 66) (("/") reduce 66) ((";") reduce 66) (("<") reduce 66) ((">") reduce 66) (("?") reduce 66) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_BOOLEAN_AND) reduce 66) ((T_BOOLEAN_OR) reduce 66) ((T_COALESCE) reduce 66) ((T_DOUBLE_ARROW) reduce 66) ((T_INSTANCEOF) reduce 66) ((T_IS_EQUAL) reduce 66) ((T_IS_GREATER_OR_EQUAL) reduce 66) ((T_IS_IDENTICAL) reduce 66) ((T_IS_NOT_EQUAL) reduce 66) ((T_IS_NOT_IDENTICAL) reduce 66) ((T_IS_SMALLER_OR_EQUAL) reduce 66) ((T_LOGICAL_AND) reduce 66) ((T_LOGICAL_OR) reduce 66) ((T_LOGICAL_XOR) reduce 66) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 66) ((T_OBJECT_OPERATOR) reduce 66) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 66) ((T_POW) reduce 66) ((T_SL) reduce 66) ((T_SPACESHIP) reduce 66) ((T_SR) reduce 66) (("[") reduce 66) (("^") reduce 66) (("{") reduce 66) (("|") reduce 66)) 3679 ((("%") reduce 18) (("(") reduce 18) (("*") reduce 18) (("+") reduce 18) ((",") reduce 18) (("-") reduce 18) ((".") reduce 18) (("/") reduce 18) ((";") reduce 18) (("<") reduce 18) ((">") reduce 18) (("?") reduce 18) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_BOOLEAN_AND) reduce 18) ((T_BOOLEAN_OR) reduce 18) ((T_COALESCE) reduce 18) ((T_DOUBLE_ARROW) reduce 18) ((T_INSTANCEOF) reduce 18) ((T_IS_EQUAL) reduce 18) ((T_IS_GREATER_OR_EQUAL) reduce 18) ((T_IS_IDENTICAL) reduce 18) ((T_IS_NOT_EQUAL) reduce 18) ((T_IS_NOT_IDENTICAL) reduce 18) ((T_IS_SMALLER_OR_EQUAL) reduce 18) ((T_LOGICAL_AND) reduce 18) ((T_LOGICAL_OR) reduce 18) ((T_LOGICAL_XOR) reduce 18) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 18) ((T_OBJECT_OPERATOR) reduce 18) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 18) ((T_POW) reduce 18) ((T_SL) reduce 18) ((T_SPACESHIP) reduce 18) ((T_SR) reduce 18) (("[") reduce 18) (("^") reduce 18) (("{") reduce 18) (("|") reduce 18)) 3680 ((("%") reduce 17) (("(") reduce 17) (("*") reduce 17) (("+") reduce 17) ((",") reduce 17) (("-") reduce 17) ((".") reduce 17) (("/") reduce 17) ((";") reduce 17) (("<") reduce 17) ((">") reduce 17) (("?") reduce 17) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_BOOLEAN_AND) reduce 17) ((T_BOOLEAN_OR) reduce 17) ((T_COALESCE) reduce 17) ((T_DOUBLE_ARROW) reduce 17) ((T_INSTANCEOF) reduce 17) ((T_IS_EQUAL) reduce 17) ((T_IS_GREATER_OR_EQUAL) reduce 17) ((T_IS_IDENTICAL) reduce 17) ((T_IS_NOT_EQUAL) reduce 17) ((T_IS_NOT_IDENTICAL) reduce 17) ((T_IS_SMALLER_OR_EQUAL) reduce 17) ((T_LOGICAL_AND) reduce 17) ((T_LOGICAL_OR) reduce 17) ((T_LOGICAL_XOR) reduce 17) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 17) ((T_OBJECT_OPERATOR) reduce 17) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 17) ((T_POW) reduce 17) ((T_SL) reduce 17) ((T_SPACESHIP) reduce 17) ((T_SR) reduce 17) (("[") reduce 17) (("^") reduce 17) (("{") reduce 17) (("|") reduce 17)) 3681 ((("%") reduce 15) (("(") reduce 15) (("*") reduce 15) (("+") reduce 15) ((",") reduce 15) (("-") reduce 15) ((".") reduce 15) (("/") reduce 15) ((";") reduce 15) (("<") reduce 15) ((">") reduce 15) (("?") reduce 15) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_BOOLEAN_AND) reduce 15) ((T_BOOLEAN_OR) reduce 15) ((T_COALESCE) reduce 15) ((T_DOUBLE_ARROW) reduce 15) ((T_INSTANCEOF) reduce 15) ((T_IS_EQUAL) reduce 15) ((T_IS_GREATER_OR_EQUAL) reduce 15) ((T_IS_IDENTICAL) reduce 15) ((T_IS_NOT_EQUAL) reduce 15) ((T_IS_NOT_IDENTICAL) reduce 15) ((T_IS_SMALLER_OR_EQUAL) reduce 15) ((T_LOGICAL_AND) reduce 15) ((T_LOGICAL_OR) reduce 15) ((T_LOGICAL_XOR) reduce 15) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 15) ((T_OBJECT_OPERATOR) reduce 15) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 15) ((T_POW) reduce 15) ((T_SL) reduce 15) ((T_SPACESHIP) reduce 15) ((T_SR) reduce 15) (("[") reduce 15) (("^") reduce 15) (("{") reduce 15) (("|") reduce 15)) 3682 ((("%") reduce 14) (("(") reduce 14) (("*") reduce 14) (("+") reduce 14) ((",") reduce 14) (("-") reduce 14) ((".") reduce 14) (("/") reduce 14) ((";") reduce 14) (("<") reduce 14) ((">") reduce 14) (("?") reduce 14) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_BOOLEAN_AND) reduce 14) ((T_BOOLEAN_OR) reduce 14) ((T_COALESCE) reduce 14) ((T_DOUBLE_ARROW) reduce 14) ((T_INSTANCEOF) reduce 14) ((T_IS_EQUAL) reduce 14) ((T_IS_GREATER_OR_EQUAL) reduce 14) ((T_IS_IDENTICAL) reduce 14) ((T_IS_NOT_EQUAL) reduce 14) ((T_IS_NOT_IDENTICAL) reduce 14) ((T_IS_SMALLER_OR_EQUAL) reduce 14) ((T_LOGICAL_AND) reduce 14) ((T_LOGICAL_OR) reduce 14) ((T_LOGICAL_XOR) reduce 14) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 14) ((T_OBJECT_OPERATOR) reduce 14) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 14) ((T_POW) reduce 14) ((T_SL) reduce 14) ((T_SPACESHIP) reduce 14) ((T_SR) reduce 14) (("[") reduce 14) (("^") reduce 14) (("{") reduce 14) (("|") reduce 14)) 3683 ((("%") reduce 38) (("(") reduce 38) (("*") reduce 38) (("+") reduce 38) ((",") reduce 38) (("-") reduce 38) ((".") reduce 38) (("/") reduce 38) ((";") reduce 38) (("<") reduce 38) ((">") reduce 38) (("?") reduce 38) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_BOOLEAN_AND) reduce 38) ((T_BOOLEAN_OR) reduce 38) ((T_COALESCE) reduce 38) ((T_DOUBLE_ARROW) reduce 38) ((T_INSTANCEOF) reduce 38) ((T_IS_EQUAL) reduce 38) ((T_IS_GREATER_OR_EQUAL) reduce 38) ((T_IS_IDENTICAL) reduce 38) ((T_IS_NOT_EQUAL) reduce 38) ((T_IS_NOT_IDENTICAL) reduce 38) ((T_IS_SMALLER_OR_EQUAL) reduce 38) ((T_LOGICAL_AND) reduce 38) ((T_LOGICAL_OR) reduce 38) ((T_LOGICAL_XOR) reduce 38) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 38) ((T_OBJECT_OPERATOR) reduce 38) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 38) ((T_POW) reduce 38) ((T_SL) reduce 38) ((T_SPACESHIP) reduce 38) ((T_SR) reduce 38) (("[") reduce 38) (("^") reduce 38) (("{") reduce 38) (("|") reduce 38)) 3684 ((("%") reduce 26) (("(") reduce 26) (("*") reduce 26) (("+") reduce 26) ((",") reduce 26) (("-") reduce 26) ((".") reduce 26) (("/") reduce 26) ((";") reduce 26) (("<") reduce 26) ((">") reduce 26) (("?") reduce 26) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_BOOLEAN_AND) reduce 26) ((T_BOOLEAN_OR) reduce 26) ((T_COALESCE) reduce 26) ((T_DOUBLE_ARROW) reduce 26) ((T_INSTANCEOF) reduce 26) ((T_IS_EQUAL) reduce 26) ((T_IS_GREATER_OR_EQUAL) reduce 26) ((T_IS_IDENTICAL) reduce 26) ((T_IS_NOT_EQUAL) reduce 26) ((T_IS_NOT_IDENTICAL) reduce 26) ((T_IS_SMALLER_OR_EQUAL) reduce 26) ((T_LOGICAL_AND) reduce 26) ((T_LOGICAL_OR) reduce 26) ((T_LOGICAL_XOR) reduce 26) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 26) ((T_OBJECT_OPERATOR) reduce 26) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 26) ((T_POW) reduce 26) ((T_SL) reduce 26) ((T_SPACESHIP) reduce 26) ((T_SR) reduce 26) (("[") reduce 26) (("^") reduce 26) (("{") reduce 26) (("|") reduce 26)) 3685 ((("%") reduce 22) (("(") reduce 22) (("*") reduce 22) (("+") reduce 22) ((",") reduce 22) (("-") reduce 22) ((".") reduce 22) (("/") reduce 22) ((";") reduce 22) (("<") reduce 22) ((">") reduce 22) (("?") reduce 22) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_BOOLEAN_AND) reduce 22) ((T_BOOLEAN_OR) reduce 22) ((T_COALESCE) reduce 22) ((T_DOUBLE_ARROW) reduce 22) ((T_INSTANCEOF) reduce 22) ((T_IS_EQUAL) reduce 22) ((T_IS_GREATER_OR_EQUAL) reduce 22) ((T_IS_IDENTICAL) reduce 22) ((T_IS_NOT_EQUAL) reduce 22) ((T_IS_NOT_IDENTICAL) reduce 22) ((T_IS_SMALLER_OR_EQUAL) reduce 22) ((T_LOGICAL_AND) reduce 22) ((T_LOGICAL_OR) reduce 22) ((T_LOGICAL_XOR) reduce 22) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 22) ((T_OBJECT_OPERATOR) reduce 22) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 22) ((T_POW) reduce 22) ((T_SL) reduce 22) ((T_SPACESHIP) reduce 22) ((T_SR) reduce 22) (("[") reduce 22) (("^") reduce 22) (("{") reduce 22) (("|") reduce 22)) 3686 ((("%") reduce 24) (("(") reduce 24) (("*") reduce 24) (("+") reduce 24) ((",") reduce 24) (("-") reduce 24) ((".") reduce 24) (("/") reduce 24) ((";") reduce 24) (("<") reduce 24) ((">") reduce 24) (("?") reduce 24) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_BOOLEAN_AND) reduce 24) ((T_BOOLEAN_OR) reduce 24) ((T_COALESCE) reduce 24) ((T_DOUBLE_ARROW) reduce 24) ((T_INSTANCEOF) reduce 24) ((T_IS_EQUAL) reduce 24) ((T_IS_GREATER_OR_EQUAL) reduce 24) ((T_IS_IDENTICAL) reduce 24) ((T_IS_NOT_EQUAL) reduce 24) ((T_IS_NOT_IDENTICAL) reduce 24) ((T_IS_SMALLER_OR_EQUAL) reduce 24) ((T_LOGICAL_AND) reduce 24) ((T_LOGICAL_OR) reduce 24) ((T_LOGICAL_XOR) reduce 24) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 24) ((T_OBJECT_OPERATOR) reduce 24) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 24) ((T_POW) reduce 24) ((T_SL) reduce 24) ((T_SPACESHIP) reduce 24) ((T_SR) reduce 24) (("[") reduce 24) (("^") reduce 24) (("{") reduce 24) (("|") reduce 24)) 3687 ((("%") reduce 16) (("(") reduce 16) (("*") reduce 16) (("+") reduce 16) ((",") reduce 16) (("-") reduce 16) ((".") reduce 16) (("/") reduce 16) ((";") reduce 16) (("<") reduce 16) ((">") reduce 16) (("?") reduce 16) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_BOOLEAN_AND) reduce 16) ((T_BOOLEAN_OR) reduce 16) ((T_COALESCE) reduce 16) ((T_DOUBLE_ARROW) reduce 16) ((T_INSTANCEOF) reduce 16) ((T_IS_EQUAL) reduce 16) ((T_IS_GREATER_OR_EQUAL) reduce 16) ((T_IS_IDENTICAL) reduce 16) ((T_IS_NOT_EQUAL) reduce 16) ((T_IS_NOT_IDENTICAL) reduce 16) ((T_IS_SMALLER_OR_EQUAL) reduce 16) ((T_LOGICAL_AND) reduce 16) ((T_LOGICAL_OR) reduce 16) ((T_LOGICAL_XOR) reduce 16) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 16) ((T_OBJECT_OPERATOR) reduce 16) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 16) ((T_POW) reduce 16) ((T_SL) reduce 16) ((T_SPACESHIP) reduce 16) ((T_SR) reduce 16) (("[") reduce 16) (("^") reduce 16) (("{") reduce 16) (("|") reduce 16)) 3688 ((("%") reduce 48) (("(") reduce 48) (("*") reduce 48) (("+") reduce 48) ((",") reduce 48) (("-") reduce 48) ((".") reduce 48) (("/") reduce 48) ((";") reduce 48) (("<") reduce 48) ((">") reduce 48) (("?") reduce 48) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_BOOLEAN_AND) reduce 48) ((T_BOOLEAN_OR) reduce 48) ((T_COALESCE) reduce 48) ((T_DOUBLE_ARROW) reduce 48) ((T_INSTANCEOF) reduce 48) ((T_IS_EQUAL) reduce 48) ((T_IS_GREATER_OR_EQUAL) reduce 48) ((T_IS_IDENTICAL) reduce 48) ((T_IS_NOT_EQUAL) reduce 48) ((T_IS_NOT_IDENTICAL) reduce 48) ((T_IS_SMALLER_OR_EQUAL) reduce 48) ((T_LOGICAL_AND) reduce 48) ((T_LOGICAL_OR) reduce 48) ((T_LOGICAL_XOR) reduce 48) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 48) ((T_OBJECT_OPERATOR) reduce 48) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 48) ((T_POW) reduce 48) ((T_SL) reduce 48) ((T_SPACESHIP) reduce 48) ((T_SR) reduce 48) (("[") reduce 48) (("^") reduce 48) (("{") reduce 48) (("|") reduce 48)) 3689 ((("%") reduce 20) (("(") reduce 20) (("*") reduce 20) (("+") reduce 20) ((",") reduce 20) (("-") reduce 20) ((".") reduce 20) (("/") reduce 20) ((";") reduce 20) (("<") reduce 20) ((">") reduce 20) (("?") reduce 20) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_BOOLEAN_AND) reduce 20) ((T_BOOLEAN_OR) reduce 20) ((T_COALESCE) reduce 20) ((T_DOUBLE_ARROW) reduce 20) ((T_INSTANCEOF) reduce 20) ((T_IS_EQUAL) reduce 20) ((T_IS_GREATER_OR_EQUAL) reduce 20) ((T_IS_IDENTICAL) reduce 20) ((T_IS_NOT_EQUAL) reduce 20) ((T_IS_NOT_IDENTICAL) reduce 20) ((T_IS_SMALLER_OR_EQUAL) reduce 20) ((T_LOGICAL_AND) reduce 20) ((T_LOGICAL_OR) reduce 20) ((T_LOGICAL_XOR) reduce 20) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 20) ((T_OBJECT_OPERATOR) reduce 20) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 20) ((T_POW) reduce 20) ((T_SL) reduce 20) ((T_SPACESHIP) reduce 20) ((T_SR) reduce 20) (("[") reduce 20) (("^") reduce 20) (("{") reduce 20) (("|") reduce 20)) 3690 ((("%") reduce 70) (("(") reduce 70) (("*") reduce 70) (("+") reduce 70) ((",") reduce 70) (("-") reduce 70) ((".") reduce 70) (("/") reduce 70) ((";") reduce 70) (("<") reduce 70) ((">") reduce 70) (("?") reduce 70) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_BOOLEAN_AND) reduce 70) ((T_BOOLEAN_OR) reduce 70) ((T_COALESCE) reduce 70) ((T_DOUBLE_ARROW) reduce 70) ((T_INSTANCEOF) reduce 70) ((T_IS_EQUAL) reduce 70) ((T_IS_GREATER_OR_EQUAL) reduce 70) ((T_IS_IDENTICAL) reduce 70) ((T_IS_NOT_EQUAL) reduce 70) ((T_IS_NOT_IDENTICAL) reduce 70) ((T_IS_SMALLER_OR_EQUAL) reduce 70) ((T_LOGICAL_AND) reduce 70) ((T_LOGICAL_OR) reduce 70) ((T_LOGICAL_XOR) reduce 70) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 70) ((T_OBJECT_OPERATOR) reduce 70) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 70) ((T_POW) reduce 70) ((T_SL) reduce 70) ((T_SPACESHIP) reduce 70) ((T_SR) reduce 70) (("[") reduce 70) (("^") reduce 70) (("{") reduce 70) (("|") reduce 70)) 3691 ((("%") reduce 3) (("(") reduce 3) (("*") reduce 3) (("+") reduce 3) ((",") reduce 3) (("-") reduce 3) ((".") reduce 3) (("/") reduce 3) ((";") reduce 3) (("<") reduce 3) ((">") reduce 3) (("?") reduce 3) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_BOOLEAN_AND) reduce 3) ((T_BOOLEAN_OR) reduce 3) ((T_COALESCE) reduce 3) ((T_DOUBLE_ARROW) reduce 3) ((T_INSTANCEOF) reduce 3) ((T_IS_EQUAL) reduce 3) ((T_IS_GREATER_OR_EQUAL) reduce 3) ((T_IS_IDENTICAL) reduce 3) ((T_IS_NOT_EQUAL) reduce 3) ((T_IS_NOT_IDENTICAL) reduce 3) ((T_IS_SMALLER_OR_EQUAL) reduce 3) ((T_LOGICAL_AND) reduce 3) ((T_LOGICAL_OR) reduce 3) ((T_LOGICAL_XOR) reduce 3) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 3) ((T_OBJECT_OPERATOR) reduce 3) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 3) ((T_POW) reduce 3) ((T_SL) reduce 3) ((T_SPACESHIP) reduce 3) ((T_SR) reduce 3) (("[") reduce 3) (("^") reduce 3) (("{") reduce 3) (("|") reduce 3)) 3692 ((("%") reduce 12) (("(") reduce 12) (("*") reduce 12) (("+") reduce 12) ((",") reduce 12) (("-") reduce 12) ((".") reduce 12) (("/") reduce 12) ((";") reduce 12) (("<") reduce 12) ((">") reduce 12) (("?") reduce 12) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_BOOLEAN_AND) reduce 12) ((T_BOOLEAN_OR) reduce 12) ((T_COALESCE) reduce 12) ((T_DOUBLE_ARROW) reduce 12) ((T_INSTANCEOF) reduce 12) ((T_IS_EQUAL) reduce 12) ((T_IS_GREATER_OR_EQUAL) reduce 12) ((T_IS_IDENTICAL) reduce 12) ((T_IS_NOT_EQUAL) reduce 12) ((T_IS_NOT_IDENTICAL) reduce 12) ((T_IS_SMALLER_OR_EQUAL) reduce 12) ((T_LOGICAL_AND) reduce 12) ((T_LOGICAL_OR) reduce 12) ((T_LOGICAL_XOR) reduce 12) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 12) ((T_OBJECT_OPERATOR) reduce 12) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 12) ((T_POW) reduce 12) ((T_SL) reduce 12) ((T_SPACESHIP) reduce 12) ((T_SR) reduce 12) (("[") reduce 12) (("^") reduce 12) (("{") reduce 12) (("|") reduce 12)) 3693 ((("%") reduce 54) (("(") reduce 54) (("*") reduce 54) (("+") reduce 54) ((",") reduce 54) (("-") reduce 54) ((".") reduce 54) (("/") reduce 54) ((";") reduce 54) (("<") reduce 54) ((">") reduce 54) (("?") reduce 54) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_BOOLEAN_AND) reduce 54) ((T_BOOLEAN_OR) reduce 54) ((T_COALESCE) reduce 54) ((T_DOUBLE_ARROW) reduce 54) ((T_INSTANCEOF) reduce 54) ((T_IS_EQUAL) reduce 54) ((T_IS_GREATER_OR_EQUAL) reduce 54) ((T_IS_IDENTICAL) reduce 54) ((T_IS_NOT_EQUAL) reduce 54) ((T_IS_NOT_IDENTICAL) reduce 54) ((T_IS_SMALLER_OR_EQUAL) reduce 54) ((T_LOGICAL_AND) reduce 54) ((T_LOGICAL_OR) reduce 54) ((T_LOGICAL_XOR) reduce 54) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 54) ((T_OBJECT_OPERATOR) reduce 54) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 54) ((T_POW) reduce 54) ((T_SL) reduce 54) ((T_SPACESHIP) reduce 54) ((T_SR) reduce 54) (("[") reduce 54) (("^") reduce 54) (("{") reduce 54) (("|") reduce 54)) 3694 ((("%") reduce 65) (("(") reduce 65) (("*") reduce 65) (("+") reduce 65) ((",") reduce 65) (("-") reduce 65) ((".") reduce 65) (("/") reduce 65) ((";") reduce 65) (("<") reduce 65) ((">") reduce 65) (("?") reduce 65) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_BOOLEAN_AND) reduce 65) ((T_BOOLEAN_OR) reduce 65) ((T_COALESCE) reduce 65) ((T_DOUBLE_ARROW) reduce 65) ((T_INSTANCEOF) reduce 65) ((T_IS_EQUAL) reduce 65) ((T_IS_GREATER_OR_EQUAL) reduce 65) ((T_IS_IDENTICAL) reduce 65) ((T_IS_NOT_EQUAL) reduce 65) ((T_IS_NOT_IDENTICAL) reduce 65) ((T_IS_SMALLER_OR_EQUAL) reduce 65) ((T_LOGICAL_AND) reduce 65) ((T_LOGICAL_OR) reduce 65) ((T_LOGICAL_XOR) reduce 65) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 65) ((T_OBJECT_OPERATOR) reduce 65) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 65) ((T_POW) reduce 65) ((T_SL) reduce 65) ((T_SPACESHIP) reduce 65) ((T_SR) reduce 65) (("[") reduce 65) (("^") reduce 65) (("{") reduce 65) (("|") reduce 65)) 3695 ((("%") reduce 74) (("(") reduce 74) (("*") reduce 74) (("+") reduce 74) ((",") reduce 74) (("-") reduce 74) ((".") reduce 74) (("/") reduce 74) ((";") reduce 74) (("<") reduce 74) ((">") reduce 74) (("?") reduce 74) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_BOOLEAN_AND) reduce 74) ((T_BOOLEAN_OR) reduce 74) ((T_COALESCE) reduce 74) ((T_DOUBLE_ARROW) reduce 74) ((T_INSTANCEOF) reduce 74) ((T_IS_EQUAL) reduce 74) ((T_IS_GREATER_OR_EQUAL) reduce 74) ((T_IS_IDENTICAL) reduce 74) ((T_IS_NOT_EQUAL) reduce 74) ((T_IS_NOT_IDENTICAL) reduce 74) ((T_IS_SMALLER_OR_EQUAL) reduce 74) ((T_LOGICAL_AND) reduce 74) ((T_LOGICAL_OR) reduce 74) ((T_LOGICAL_XOR) reduce 74) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 74) ((T_OBJECT_OPERATOR) reduce 74) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 74) ((T_POW) reduce 74) ((T_SL) reduce 74) ((T_SPACESHIP) reduce 74) ((T_SR) reduce 74) (("[") reduce 74) (("^") reduce 74) (("{") reduce 74) (("|") reduce 74)) 3696 ((("%") reduce 30) (("(") reduce 30) (("*") reduce 30) (("+") reduce 30) ((",") reduce 30) (("-") reduce 30) ((".") reduce 30) (("/") reduce 30) ((";") reduce 30) (("<") reduce 30) ((">") reduce 30) (("?") reduce 30) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_BOOLEAN_AND) reduce 30) ((T_BOOLEAN_OR) reduce 30) ((T_COALESCE) reduce 30) ((T_DOUBLE_ARROW) reduce 30) ((T_INSTANCEOF) reduce 30) ((T_IS_EQUAL) reduce 30) ((T_IS_GREATER_OR_EQUAL) reduce 30) ((T_IS_IDENTICAL) reduce 30) ((T_IS_NOT_EQUAL) reduce 30) ((T_IS_NOT_IDENTICAL) reduce 30) ((T_IS_SMALLER_OR_EQUAL) reduce 30) ((T_LOGICAL_AND) reduce 30) ((T_LOGICAL_OR) reduce 30) ((T_LOGICAL_XOR) reduce 30) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 30) ((T_OBJECT_OPERATOR) reduce 30) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 30) ((T_POW) reduce 30) ((T_SL) reduce 30) ((T_SPACESHIP) reduce 30) ((T_SR) reduce 30) (("[") reduce 30) (("^") reduce 30) (("{") reduce 30) (("|") reduce 30)) 3697 ((("%") reduce 68) (("(") reduce 68) (("*") reduce 68) (("+") reduce 68) ((",") reduce 68) (("-") reduce 68) ((".") reduce 68) (("/") reduce 68) ((";") reduce 68) (("<") reduce 68) ((">") reduce 68) (("?") reduce 68) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_BOOLEAN_AND) reduce 68) ((T_BOOLEAN_OR) reduce 68) ((T_COALESCE) reduce 68) ((T_DOUBLE_ARROW) reduce 68) ((T_INSTANCEOF) reduce 68) ((T_IS_EQUAL) reduce 68) ((T_IS_GREATER_OR_EQUAL) reduce 68) ((T_IS_IDENTICAL) reduce 68) ((T_IS_NOT_EQUAL) reduce 68) ((T_IS_NOT_IDENTICAL) reduce 68) ((T_IS_SMALLER_OR_EQUAL) reduce 68) ((T_LOGICAL_AND) reduce 68) ((T_LOGICAL_OR) reduce 68) ((T_LOGICAL_XOR) reduce 68) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 68) ((T_OBJECT_OPERATOR) reduce 68) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 68) ((T_POW) reduce 68) ((T_SL) reduce 68) ((T_SPACESHIP) reduce 68) ((T_SR) reduce 68) (("[") reduce 68) (("^") reduce 68) (("{") reduce 68) (("|") reduce 68)) 3698 ((("%") reduce 21) (("(") reduce 21) (("*") reduce 21) (("+") reduce 21) ((",") reduce 21) (("-") reduce 21) ((".") reduce 21) (("/") reduce 21) ((";") reduce 21) (("<") reduce 21) ((">") reduce 21) (("?") reduce 21) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_BOOLEAN_AND) reduce 21) ((T_BOOLEAN_OR) reduce 21) ((T_COALESCE) reduce 21) ((T_DOUBLE_ARROW) reduce 21) ((T_INSTANCEOF) reduce 21) ((T_IS_EQUAL) reduce 21) ((T_IS_GREATER_OR_EQUAL) reduce 21) ((T_IS_IDENTICAL) reduce 21) ((T_IS_NOT_EQUAL) reduce 21) ((T_IS_NOT_IDENTICAL) reduce 21) ((T_IS_SMALLER_OR_EQUAL) reduce 21) ((T_LOGICAL_AND) reduce 21) ((T_LOGICAL_OR) reduce 21) ((T_LOGICAL_XOR) reduce 21) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 21) ((T_OBJECT_OPERATOR) reduce 21) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 21) ((T_POW) reduce 21) ((T_SL) reduce 21) ((T_SPACESHIP) reduce 21) ((T_SR) reduce 21) (("[") reduce 21) (("^") reduce 21) (("{") reduce 21) (("|") reduce 21)) 3699 ((("%") reduce 23) (("(") reduce 23) (("*") reduce 23) (("+") reduce 23) ((",") reduce 23) (("-") reduce 23) ((".") reduce 23) (("/") reduce 23) ((";") reduce 23) (("<") reduce 23) ((">") reduce 23) (("?") reduce 23) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_BOOLEAN_AND) reduce 23) ((T_BOOLEAN_OR) reduce 23) ((T_COALESCE) reduce 23) ((T_DOUBLE_ARROW) reduce 23) ((T_INSTANCEOF) reduce 23) ((T_IS_EQUAL) reduce 23) ((T_IS_GREATER_OR_EQUAL) reduce 23) ((T_IS_IDENTICAL) reduce 23) ((T_IS_NOT_EQUAL) reduce 23) ((T_IS_NOT_IDENTICAL) reduce 23) ((T_IS_SMALLER_OR_EQUAL) reduce 23) ((T_LOGICAL_AND) reduce 23) ((T_LOGICAL_OR) reduce 23) ((T_LOGICAL_XOR) reduce 23) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 23) ((T_OBJECT_OPERATOR) reduce 23) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 23) ((T_POW) reduce 23) ((T_SL) reduce 23) ((T_SPACESHIP) reduce 23) ((T_SR) reduce 23) (("[") reduce 23) (("^") reduce 23) (("{") reduce 23) (("|") reduce 23)) 3700 ((("%") reduce 41) (("(") reduce 41) (("*") reduce 41) (("+") reduce 41) ((",") reduce 41) (("-") reduce 41) ((".") reduce 41) (("/") reduce 41) ((";") reduce 41) (("<") reduce 41) ((">") reduce 41) (("?") reduce 41) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_BOOLEAN_AND) reduce 41) ((T_BOOLEAN_OR) reduce 41) ((T_COALESCE) reduce 41) ((T_DOUBLE_ARROW) reduce 41) ((T_INSTANCEOF) reduce 41) ((T_IS_EQUAL) reduce 41) ((T_IS_GREATER_OR_EQUAL) reduce 41) ((T_IS_IDENTICAL) reduce 41) ((T_IS_NOT_EQUAL) reduce 41) ((T_IS_NOT_IDENTICAL) reduce 41) ((T_IS_SMALLER_OR_EQUAL) reduce 41) ((T_LOGICAL_AND) reduce 41) ((T_LOGICAL_OR) reduce 41) ((T_LOGICAL_XOR) reduce 41) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 41) ((T_OBJECT_OPERATOR) reduce 41) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 41) ((T_POW) reduce 41) ((T_SL) reduce 41) ((T_SPACESHIP) reduce 41) ((T_SR) reduce 41) (("[") reduce 41) (("^") reduce 41) (("{") reduce 41) (("|") reduce 41)) 3701 ((("%") reduce 62) (("(") reduce 62) (("*") reduce 62) (("+") reduce 62) ((",") reduce 62) (("-") reduce 62) ((".") reduce 62) (("/") reduce 62) ((";") reduce 62) (("<") reduce 62) ((">") reduce 62) (("?") reduce 62) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_BOOLEAN_AND) reduce 62) ((T_BOOLEAN_OR) reduce 62) ((T_COALESCE) reduce 62) ((T_DOUBLE_ARROW) reduce 62) ((T_INSTANCEOF) reduce 62) ((T_IS_EQUAL) reduce 62) ((T_IS_GREATER_OR_EQUAL) reduce 62) ((T_IS_IDENTICAL) reduce 62) ((T_IS_NOT_EQUAL) reduce 62) ((T_IS_NOT_IDENTICAL) reduce 62) ((T_IS_SMALLER_OR_EQUAL) reduce 62) ((T_LOGICAL_AND) reduce 62) ((T_LOGICAL_OR) reduce 62) ((T_LOGICAL_XOR) reduce 62) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 62) ((T_OBJECT_OPERATOR) reduce 62) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 62) ((T_POW) reduce 62) ((T_SL) reduce 62) ((T_SPACESHIP) reduce 62) ((T_SR) reduce 62) (("[") reduce 62) (("^") reduce 62) (("{") reduce 62) (("|") reduce 62)) 3702 ((("%") reduce 34) (("(") reduce 34) (("*") reduce 34) (("+") reduce 34) ((",") reduce 34) (("-") reduce 34) ((".") reduce 34) (("/") reduce 34) ((";") reduce 34) (("<") reduce 34) ((">") reduce 34) (("?") reduce 34) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_BOOLEAN_AND) reduce 34) ((T_BOOLEAN_OR) reduce 34) ((T_COALESCE) reduce 34) ((T_DOUBLE_ARROW) reduce 34) ((T_INSTANCEOF) reduce 34) ((T_IS_EQUAL) reduce 34) ((T_IS_GREATER_OR_EQUAL) reduce 34) ((T_IS_IDENTICAL) reduce 34) ((T_IS_NOT_EQUAL) reduce 34) ((T_IS_NOT_IDENTICAL) reduce 34) ((T_IS_SMALLER_OR_EQUAL) reduce 34) ((T_LOGICAL_AND) reduce 34) ((T_LOGICAL_OR) reduce 34) ((T_LOGICAL_XOR) reduce 34) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 34) ((T_OBJECT_OPERATOR) reduce 34) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 34) ((T_POW) reduce 34) ((T_SL) reduce 34) ((T_SPACESHIP) reduce 34) ((T_SR) reduce 34) (("[") reduce 34) (("^") reduce 34) (("{") reduce 34) (("|") reduce 34)) 3703 ((("%") reduce 40) (("(") reduce 40) (("*") reduce 40) (("+") reduce 40) ((",") reduce 40) (("-") reduce 40) ((".") reduce 40) (("/") reduce 40) ((";") reduce 40) (("<") reduce 40) ((">") reduce 40) (("?") reduce 40) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_BOOLEAN_AND) reduce 40) ((T_BOOLEAN_OR) reduce 40) ((T_COALESCE) reduce 40) ((T_DOUBLE_ARROW) reduce 40) ((T_INSTANCEOF) reduce 40) ((T_IS_EQUAL) reduce 40) ((T_IS_GREATER_OR_EQUAL) reduce 40) ((T_IS_IDENTICAL) reduce 40) ((T_IS_NOT_EQUAL) reduce 40) ((T_IS_NOT_IDENTICAL) reduce 40) ((T_IS_SMALLER_OR_EQUAL) reduce 40) ((T_LOGICAL_AND) reduce 40) ((T_LOGICAL_OR) reduce 40) ((T_LOGICAL_XOR) reduce 40) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 40) ((T_OBJECT_OPERATOR) reduce 40) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 40) ((T_POW) reduce 40) ((T_SL) reduce 40) ((T_SPACESHIP) reduce 40) ((T_SR) reduce 40) (("[") reduce 40) (("^") reduce 40) (("{") reduce 40) (("|") reduce 40)) 3704 ((("%") reduce 13) (("(") reduce 13) (("*") reduce 13) (("+") reduce 13) ((",") reduce 13) (("-") reduce 13) ((".") reduce 13) (("/") reduce 13) ((";") reduce 13) (("<") reduce 13) ((">") reduce 13) (("?") reduce 13) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_BOOLEAN_AND) reduce 13) ((T_BOOLEAN_OR) reduce 13) ((T_COALESCE) reduce 13) ((T_DOUBLE_ARROW) reduce 13) ((T_INSTANCEOF) reduce 13) ((T_IS_EQUAL) reduce 13) ((T_IS_GREATER_OR_EQUAL) reduce 13) ((T_IS_IDENTICAL) reduce 13) ((T_IS_NOT_EQUAL) reduce 13) ((T_IS_NOT_IDENTICAL) reduce 13) ((T_IS_SMALLER_OR_EQUAL) reduce 13) ((T_LOGICAL_AND) reduce 13) ((T_LOGICAL_OR) reduce 13) ((T_LOGICAL_XOR) reduce 13) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 13) ((T_OBJECT_OPERATOR) reduce 13) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 13) ((T_POW) reduce 13) ((T_SL) reduce 13) ((T_SPACESHIP) reduce 13) ((T_SR) reduce 13) (("[") reduce 13) (("^") reduce 13) (("{") reduce 13) (("|") reduce 13)) 3705 ((("%") reduce 55) (("(") reduce 55) (("*") reduce 55) (("+") reduce 55) ((",") reduce 55) (("-") reduce 55) ((".") reduce 55) (("/") reduce 55) ((";") reduce 55) (("<") reduce 55) ((">") reduce 55) (("?") reduce 55) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_BOOLEAN_AND) reduce 55) ((T_BOOLEAN_OR) reduce 55) ((T_COALESCE) reduce 55) ((T_DOUBLE_ARROW) reduce 55) ((T_INSTANCEOF) reduce 55) ((T_IS_EQUAL) reduce 55) ((T_IS_GREATER_OR_EQUAL) reduce 55) ((T_IS_IDENTICAL) reduce 55) ((T_IS_NOT_EQUAL) reduce 55) ((T_IS_NOT_IDENTICAL) reduce 55) ((T_IS_SMALLER_OR_EQUAL) reduce 55) ((T_LOGICAL_AND) reduce 55) ((T_LOGICAL_OR) reduce 55) ((T_LOGICAL_XOR) reduce 55) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 55) ((T_OBJECT_OPERATOR) reduce 55) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 55) ((T_POW) reduce 55) ((T_SL) reduce 55) ((T_SPACESHIP) reduce 55) ((T_SR) reduce 55) (("[") reduce 55) (("^") reduce 55) (("{") reduce 55) (("|") reduce 55)) 3706 ((("%") reduce 1) (("(") reduce 1) (("*") reduce 1) (("+") reduce 1) ((",") reduce 1) (("-") reduce 1) ((".") reduce 1) (("/") reduce 1) ((";") reduce 1) (("<") reduce 1) ((">") reduce 1) (("?") reduce 1) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_BOOLEAN_AND) reduce 1) ((T_BOOLEAN_OR) reduce 1) ((T_COALESCE) reduce 1) ((T_DOUBLE_ARROW) reduce 1) ((T_INSTANCEOF) reduce 1) ((T_IS_EQUAL) reduce 1) ((T_IS_GREATER_OR_EQUAL) reduce 1) ((T_IS_IDENTICAL) reduce 1) ((T_IS_NOT_EQUAL) reduce 1) ((T_IS_NOT_IDENTICAL) reduce 1) ((T_IS_SMALLER_OR_EQUAL) reduce 1) ((T_LOGICAL_AND) reduce 1) ((T_LOGICAL_OR) reduce 1) ((T_LOGICAL_XOR) reduce 1) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 1) ((T_OBJECT_OPERATOR) reduce 1) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 1) ((T_POW) reduce 1) ((T_SL) reduce 1) ((T_SPACESHIP) reduce 1) ((T_SR) reduce 1) (("[") reduce 1) (("^") reduce 1) (("{") reduce 1) (("|") reduce 1)) 3707 ((("%") reduce 2) (("(") reduce 2) (("*") reduce 2) (("+") reduce 2) ((",") reduce 2) (("-") reduce 2) ((".") reduce 2) (("/") reduce 2) ((";") reduce 2) (("<") reduce 2) ((">") reduce 2) (("?") reduce 2) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_BOOLEAN_AND) reduce 2) ((T_BOOLEAN_OR) reduce 2) ((T_COALESCE) reduce 2) ((T_DOUBLE_ARROW) reduce 2) ((T_INSTANCEOF) reduce 2) ((T_IS_EQUAL) reduce 2) ((T_IS_GREATER_OR_EQUAL) reduce 2) ((T_IS_IDENTICAL) reduce 2) ((T_IS_NOT_EQUAL) reduce 2) ((T_IS_NOT_IDENTICAL) reduce 2) ((T_IS_SMALLER_OR_EQUAL) reduce 2) ((T_LOGICAL_AND) reduce 2) ((T_LOGICAL_OR) reduce 2) ((T_LOGICAL_XOR) reduce 2) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 2) ((T_OBJECT_OPERATOR) reduce 2) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 2) ((T_POW) reduce 2) ((T_SL) reduce 2) ((T_SPACESHIP) reduce 2) ((T_SR) reduce 2) (("[") reduce 2) (("^") reduce 2) (("{") reduce 2) (("|") reduce 2)) 3708 ((("%") reduce 9) (("(") reduce 9) (("*") reduce 9) (("+") reduce 9) ((",") reduce 9) (("-") reduce 9) ((".") reduce 9) (("/") reduce 9) ((";") reduce 9) (("<") reduce 9) ((">") reduce 9) (("?") reduce 9) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_BOOLEAN_AND) reduce 9) ((T_BOOLEAN_OR) reduce 9) ((T_COALESCE) reduce 9) ((T_DOUBLE_ARROW) reduce 9) ((T_INSTANCEOF) reduce 9) ((T_IS_EQUAL) reduce 9) ((T_IS_GREATER_OR_EQUAL) reduce 9) ((T_IS_IDENTICAL) reduce 9) ((T_IS_NOT_EQUAL) reduce 9) ((T_IS_NOT_IDENTICAL) reduce 9) ((T_IS_SMALLER_OR_EQUAL) reduce 9) ((T_LOGICAL_AND) reduce 9) ((T_LOGICAL_OR) reduce 9) ((T_LOGICAL_XOR) reduce 9) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 9) ((T_OBJECT_OPERATOR) reduce 9) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 9) ((T_POW) reduce 9) ((T_SL) reduce 9) ((T_SPACESHIP) reduce 9) ((T_SR) reduce 9) (("[") reduce 9) (("^") reduce 9) (("{") reduce 9) (("|") reduce 9)) 3709 ((("%") reduce 33) (("(") reduce 33) (("*") reduce 33) (("+") reduce 33) ((",") reduce 33) (("-") reduce 33) ((".") reduce 33) (("/") reduce 33) ((";") reduce 33) (("<") reduce 33) ((">") reduce 33) (("?") reduce 33) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_BOOLEAN_AND) reduce 33) ((T_BOOLEAN_OR) reduce 33) ((T_COALESCE) reduce 33) ((T_DOUBLE_ARROW) reduce 33) ((T_INSTANCEOF) reduce 33) ((T_IS_EQUAL) reduce 33) ((T_IS_GREATER_OR_EQUAL) reduce 33) ((T_IS_IDENTICAL) reduce 33) ((T_IS_NOT_EQUAL) reduce 33) ((T_IS_NOT_IDENTICAL) reduce 33) ((T_IS_SMALLER_OR_EQUAL) reduce 33) ((T_LOGICAL_AND) reduce 33) ((T_LOGICAL_OR) reduce 33) ((T_LOGICAL_XOR) reduce 33) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 33) ((T_OBJECT_OPERATOR) reduce 33) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 33) ((T_POW) reduce 33) ((T_SL) reduce 33) ((T_SPACESHIP) reduce 33) ((T_SR) reduce 33) (("[") reduce 33) (("^") reduce 33) (("{") reduce 33) (("|") reduce 33)) 3710 ((("%") reduce 58) (("(") reduce 58) (("*") reduce 58) (("+") reduce 58) ((",") reduce 58) (("-") reduce 58) ((".") reduce 58) (("/") reduce 58) ((";") reduce 58) (("<") reduce 58) ((">") reduce 58) (("?") reduce 58) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_BOOLEAN_AND) reduce 58) ((T_BOOLEAN_OR) reduce 58) ((T_COALESCE) reduce 58) ((T_DOUBLE_ARROW) reduce 58) ((T_INSTANCEOF) reduce 58) ((T_IS_EQUAL) reduce 58) ((T_IS_GREATER_OR_EQUAL) reduce 58) ((T_IS_IDENTICAL) reduce 58) ((T_IS_NOT_EQUAL) reduce 58) ((T_IS_NOT_IDENTICAL) reduce 58) ((T_IS_SMALLER_OR_EQUAL) reduce 58) ((T_LOGICAL_AND) reduce 58) ((T_LOGICAL_OR) reduce 58) ((T_LOGICAL_XOR) reduce 58) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 58) ((T_OBJECT_OPERATOR) reduce 58) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 58) ((T_POW) reduce 58) ((T_SL) reduce 58) ((T_SPACESHIP) reduce 58) ((T_SR) reduce 58) (("[") reduce 58) (("^") reduce 58) (("{") reduce 58) (("|") reduce 58)) 3711 ((("%") reduce 37) (("(") reduce 37) (("*") reduce 37) (("+") reduce 37) ((",") reduce 37) (("-") reduce 37) ((".") reduce 37) (("/") reduce 37) ((";") reduce 37) (("<") reduce 37) ((">") reduce 37) (("?") reduce 37) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_BOOLEAN_AND) reduce 37) ((T_BOOLEAN_OR) reduce 37) ((T_COALESCE) reduce 37) ((T_DOUBLE_ARROW) reduce 37) ((T_INSTANCEOF) reduce 37) ((T_IS_EQUAL) reduce 37) ((T_IS_GREATER_OR_EQUAL) reduce 37) ((T_IS_IDENTICAL) reduce 37) ((T_IS_NOT_EQUAL) reduce 37) ((T_IS_NOT_IDENTICAL) reduce 37) ((T_IS_SMALLER_OR_EQUAL) reduce 37) ((T_LOGICAL_AND) reduce 37) ((T_LOGICAL_OR) reduce 37) ((T_LOGICAL_XOR) reduce 37) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 37) ((T_OBJECT_OPERATOR) reduce 37) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 37) ((T_POW) reduce 37) ((T_SL) reduce 37) ((T_SPACESHIP) reduce 37) ((T_SR) reduce 37) (("[") reduce 37) (("^") reduce 37) (("{") reduce 37) (("|") reduce 37)) 3712 ((("%") reduce 64) (("(") reduce 64) (("*") reduce 64) (("+") reduce 64) ((",") reduce 64) (("-") reduce 64) ((".") reduce 64) (("/") reduce 64) ((";") reduce 64) (("<") reduce 64) ((">") reduce 64) (("?") reduce 64) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_BOOLEAN_AND) reduce 64) ((T_BOOLEAN_OR) reduce 64) ((T_COALESCE) reduce 64) ((T_DOUBLE_ARROW) reduce 64) ((T_INSTANCEOF) reduce 64) ((T_IS_EQUAL) reduce 64) ((T_IS_GREATER_OR_EQUAL) reduce 64) ((T_IS_IDENTICAL) reduce 64) ((T_IS_NOT_EQUAL) reduce 64) ((T_IS_NOT_IDENTICAL) reduce 64) ((T_IS_SMALLER_OR_EQUAL) reduce 64) ((T_LOGICAL_AND) reduce 64) ((T_LOGICAL_OR) reduce 64) ((T_LOGICAL_XOR) reduce 64) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 64) ((T_OBJECT_OPERATOR) reduce 64) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 64) ((T_POW) reduce 64) ((T_SL) reduce 64) ((T_SPACESHIP) reduce 64) ((T_SR) reduce 64) (("[") reduce 64) (("^") reduce 64) (("{") reduce 64) (("|") reduce 64)) 3713 ((("%") reduce 46) (("(") reduce 46) (("*") reduce 46) (("+") reduce 46) ((",") reduce 46) (("-") reduce 46) ((".") reduce 46) (("/") reduce 46) ((";") reduce 46) (("<") reduce 46) ((">") reduce 46) (("?") reduce 46) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_BOOLEAN_AND) reduce 46) ((T_BOOLEAN_OR) reduce 46) ((T_COALESCE) reduce 46) ((T_DOUBLE_ARROW) reduce 46) ((T_INSTANCEOF) reduce 46) ((T_IS_EQUAL) reduce 46) ((T_IS_GREATER_OR_EQUAL) reduce 46) ((T_IS_IDENTICAL) reduce 46) ((T_IS_NOT_EQUAL) reduce 46) ((T_IS_NOT_IDENTICAL) reduce 46) ((T_IS_SMALLER_OR_EQUAL) reduce 46) ((T_LOGICAL_AND) reduce 46) ((T_LOGICAL_OR) reduce 46) ((T_LOGICAL_XOR) reduce 46) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 46) ((T_OBJECT_OPERATOR) reduce 46) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 46) ((T_POW) reduce 46) ((T_SL) reduce 46) ((T_SPACESHIP) reduce 46) ((T_SR) reduce 46) (("[") reduce 46) (("^") reduce 46) (("{") reduce 46) (("|") reduce 46)) 3714 ((("%") reduce 8) (("(") reduce 8) (("*") reduce 8) (("+") reduce 8) ((",") reduce 8) (("-") reduce 8) ((".") reduce 8) (("/") reduce 8) ((";") reduce 8) (("<") reduce 8) ((">") reduce 8) (("?") reduce 8) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_BOOLEAN_AND) reduce 8) ((T_BOOLEAN_OR) reduce 8) ((T_COALESCE) reduce 8) ((T_DOUBLE_ARROW) reduce 8) ((T_INSTANCEOF) reduce 8) ((T_IS_EQUAL) reduce 8) ((T_IS_GREATER_OR_EQUAL) reduce 8) ((T_IS_IDENTICAL) reduce 8) ((T_IS_NOT_EQUAL) reduce 8) ((T_IS_NOT_IDENTICAL) reduce 8) ((T_IS_SMALLER_OR_EQUAL) reduce 8) ((T_LOGICAL_AND) reduce 8) ((T_LOGICAL_OR) reduce 8) ((T_LOGICAL_XOR) reduce 8) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 8) ((T_OBJECT_OPERATOR) reduce 8) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 8) ((T_POW) reduce 8) ((T_SL) reduce 8) ((T_SPACESHIP) reduce 8) ((T_SR) reduce 8) (("[") reduce 8) (("^") reduce 8) (("{") reduce 8) (("|") reduce 8)) 3715 ((("%") reduce 6) (("(") reduce 6) (("*") reduce 6) (("+") reduce 6) ((",") reduce 6) (("-") reduce 6) ((".") reduce 6) (("/") reduce 6) ((";") reduce 6) (("<") reduce 6) ((">") reduce 6) (("?") reduce 6) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_BOOLEAN_AND) reduce 6) ((T_BOOLEAN_OR) reduce 6) ((T_COALESCE) reduce 6) ((T_DOUBLE_ARROW) reduce 6) ((T_INSTANCEOF) reduce 6) ((T_IS_EQUAL) reduce 6) ((T_IS_GREATER_OR_EQUAL) reduce 6) ((T_IS_IDENTICAL) reduce 6) ((T_IS_NOT_EQUAL) reduce 6) ((T_IS_NOT_IDENTICAL) reduce 6) ((T_IS_SMALLER_OR_EQUAL) reduce 6) ((T_LOGICAL_AND) reduce 6) ((T_LOGICAL_OR) reduce 6) ((T_LOGICAL_XOR) reduce 6) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 6) ((T_OBJECT_OPERATOR) reduce 6) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 6) ((T_POW) reduce 6) ((T_SL) reduce 6) ((T_SPACESHIP) reduce 6) ((T_SR) reduce 6) (("[") reduce 6) (("^") reduce 6) (("{") reduce 6) (("|") reduce 6)) 3716 ((("%") reduce 7) (("(") reduce 7) (("*") reduce 7) (("+") reduce 7) ((",") reduce 7) (("-") reduce 7) ((".") reduce 7) (("/") reduce 7) ((";") reduce 7) (("<") reduce 7) ((">") reduce 7) (("?") reduce 7) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_BOOLEAN_AND) reduce 7) ((T_BOOLEAN_OR) reduce 7) ((T_COALESCE) reduce 7) ((T_DOUBLE_ARROW) reduce 7) ((T_INSTANCEOF) reduce 7) ((T_IS_EQUAL) reduce 7) ((T_IS_GREATER_OR_EQUAL) reduce 7) ((T_IS_IDENTICAL) reduce 7) ((T_IS_NOT_EQUAL) reduce 7) ((T_IS_NOT_IDENTICAL) reduce 7) ((T_IS_SMALLER_OR_EQUAL) reduce 7) ((T_LOGICAL_AND) reduce 7) ((T_LOGICAL_OR) reduce 7) ((T_LOGICAL_XOR) reduce 7) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 7) ((T_OBJECT_OPERATOR) reduce 7) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 7) ((T_POW) reduce 7) ((T_SL) reduce 7) ((T_SPACESHIP) reduce 7) ((T_SR) reduce 7) (("[") reduce 7) (("^") reduce 7) (("{") reduce 7) (("|") reduce 7)) 3717 ((("%") reduce 69) (("(") reduce 69) (("*") reduce 69) (("+") reduce 69) ((",") reduce 69) (("-") reduce 69) ((".") reduce 69) (("/") reduce 69) ((";") reduce 69) (("<") reduce 69) ((">") reduce 69) (("?") reduce 69) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_BOOLEAN_AND) reduce 69) ((T_BOOLEAN_OR) reduce 69) ((T_COALESCE) reduce 69) ((T_DOUBLE_ARROW) reduce 69) ((T_INSTANCEOF) reduce 69) ((T_IS_EQUAL) reduce 69) ((T_IS_GREATER_OR_EQUAL) reduce 69) ((T_IS_IDENTICAL) reduce 69) ((T_IS_NOT_EQUAL) reduce 69) ((T_IS_NOT_IDENTICAL) reduce 69) ((T_IS_SMALLER_OR_EQUAL) reduce 69) ((T_LOGICAL_AND) reduce 69) ((T_LOGICAL_OR) reduce 69) ((T_LOGICAL_XOR) reduce 69) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 69) ((T_OBJECT_OPERATOR) reduce 69) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 69) ((T_POW) reduce 69) ((T_SL) reduce 69) ((T_SPACESHIP) reduce 69) ((T_SR) reduce 69) (("[") reduce 69) (("^") reduce 69) (("{") reduce 69) (("|") reduce 69)) 3718 ((("%") reduce 63) (("(") reduce 63) (("*") reduce 63) (("+") reduce 63) ((",") reduce 63) (("-") reduce 63) ((".") reduce 63) (("/") reduce 63) ((";") reduce 63) (("<") reduce 63) ((">") reduce 63) (("?") reduce 63) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_BOOLEAN_AND) reduce 63) ((T_BOOLEAN_OR) reduce 63) ((T_COALESCE) reduce 63) ((T_DOUBLE_ARROW) reduce 63) ((T_INSTANCEOF) reduce 63) ((T_IS_EQUAL) reduce 63) ((T_IS_GREATER_OR_EQUAL) reduce 63) ((T_IS_IDENTICAL) reduce 63) ((T_IS_NOT_EQUAL) reduce 63) ((T_IS_NOT_IDENTICAL) reduce 63) ((T_IS_SMALLER_OR_EQUAL) reduce 63) ((T_LOGICAL_AND) reduce 63) ((T_LOGICAL_OR) reduce 63) ((T_LOGICAL_XOR) reduce 63) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 63) ((T_OBJECT_OPERATOR) reduce 63) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 63) ((T_POW) reduce 63) ((T_SL) reduce 63) ((T_SPACESHIP) reduce 63) ((T_SR) reduce 63) (("[") reduce 63) (("^") reduce 63) (("{") reduce 63) (("|") reduce 63)) 3719 ((("%") reduce 56) (("(") reduce 56) (("*") reduce 56) (("+") reduce 56) ((",") reduce 56) (("-") reduce 56) ((".") reduce 56) (("/") reduce 56) ((";") reduce 56) (("<") reduce 56) ((">") reduce 56) (("?") reduce 56) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_BOOLEAN_AND) reduce 56) ((T_BOOLEAN_OR) reduce 56) ((T_COALESCE) reduce 56) ((T_DOUBLE_ARROW) reduce 56) ((T_INSTANCEOF) reduce 56) ((T_IS_EQUAL) reduce 56) ((T_IS_GREATER_OR_EQUAL) reduce 56) ((T_IS_IDENTICAL) reduce 56) ((T_IS_NOT_EQUAL) reduce 56) ((T_IS_NOT_IDENTICAL) reduce 56) ((T_IS_SMALLER_OR_EQUAL) reduce 56) ((T_LOGICAL_AND) reduce 56) ((T_LOGICAL_OR) reduce 56) ((T_LOGICAL_XOR) reduce 56) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 56) ((T_OBJECT_OPERATOR) reduce 56) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 56) ((T_POW) reduce 56) ((T_SL) reduce 56) ((T_SPACESHIP) reduce 56) ((T_SR) reduce 56) (("[") reduce 56) (("^") reduce 56) (("{") reduce 56) (("|") reduce 56)) 3720 ((("%") reduce 10) (("(") reduce 10) (("*") reduce 10) (("+") reduce 10) ((",") reduce 10) (("-") reduce 10) ((".") reduce 10) (("/") reduce 10) ((";") reduce 10) (("<") reduce 10) ((">") reduce 10) (("?") reduce 10) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_BOOLEAN_AND) reduce 10) ((T_BOOLEAN_OR) reduce 10) ((T_COALESCE) reduce 10) ((T_DOUBLE_ARROW) reduce 10) ((T_INSTANCEOF) reduce 10) ((T_IS_EQUAL) reduce 10) ((T_IS_GREATER_OR_EQUAL) reduce 10) ((T_IS_IDENTICAL) reduce 10) ((T_IS_NOT_EQUAL) reduce 10) ((T_IS_NOT_IDENTICAL) reduce 10) ((T_IS_SMALLER_OR_EQUAL) reduce 10) ((T_LOGICAL_AND) reduce 10) ((T_LOGICAL_OR) reduce 10) ((T_LOGICAL_XOR) reduce 10) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 10) ((T_OBJECT_OPERATOR) reduce 10) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 10) ((T_POW) reduce 10) ((T_SL) reduce 10) ((T_SPACESHIP) reduce 10) ((T_SR) reduce 10) (("[") reduce 10) (("^") reduce 10) (("{") reduce 10) (("|") reduce 10)) 3721 ((("%") reduce 67) (("(") reduce 67) (("*") reduce 67) (("+") reduce 67) ((",") reduce 67) (("-") reduce 67) ((".") reduce 67) (("/") reduce 67) ((";") reduce 67) (("<") reduce 67) ((">") reduce 67) (("?") reduce 67) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_BOOLEAN_AND) reduce 67) ((T_BOOLEAN_OR) reduce 67) ((T_COALESCE) reduce 67) ((T_DOUBLE_ARROW) reduce 67) ((T_INSTANCEOF) reduce 67) ((T_IS_EQUAL) reduce 67) ((T_IS_GREATER_OR_EQUAL) reduce 67) ((T_IS_IDENTICAL) reduce 67) ((T_IS_NOT_EQUAL) reduce 67) ((T_IS_NOT_IDENTICAL) reduce 67) ((T_IS_SMALLER_OR_EQUAL) reduce 67) ((T_LOGICAL_AND) reduce 67) ((T_LOGICAL_OR) reduce 67) ((T_LOGICAL_XOR) reduce 67) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 67) ((T_OBJECT_OPERATOR) reduce 67) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 67) ((T_POW) reduce 67) ((T_SL) reduce 67) ((T_SPACESHIP) reduce 67) ((T_SR) reduce 67) (("[") reduce 67) (("^") reduce 67) (("{") reduce 67) (("|") reduce 67)) 3722 ((("%") reduce 44) (("(") reduce 44) (("*") reduce 44) (("+") reduce 44) ((",") reduce 44) (("-") reduce 44) ((".") reduce 44) (("/") reduce 44) ((";") reduce 44) (("<") reduce 44) ((">") reduce 44) (("?") reduce 44) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_BOOLEAN_AND) reduce 44) ((T_BOOLEAN_OR) reduce 44) ((T_COALESCE) reduce 44) ((T_DOUBLE_ARROW) reduce 44) ((T_INSTANCEOF) reduce 44) ((T_IS_EQUAL) reduce 44) ((T_IS_GREATER_OR_EQUAL) reduce 44) ((T_IS_IDENTICAL) reduce 44) ((T_IS_NOT_EQUAL) reduce 44) ((T_IS_NOT_IDENTICAL) reduce 44) ((T_IS_SMALLER_OR_EQUAL) reduce 44) ((T_LOGICAL_AND) reduce 44) ((T_LOGICAL_OR) reduce 44) ((T_LOGICAL_XOR) reduce 44) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 44) ((T_OBJECT_OPERATOR) reduce 44) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 44) ((T_POW) reduce 44) ((T_SL) reduce 44) ((T_SPACESHIP) reduce 44) ((T_SR) reduce 44) (("[") reduce 44) (("^") reduce 44) (("{") reduce 44) (("|") reduce 44)) 3723 ((("%") reduce 75) (("(") reduce 75) (("*") reduce 75) (("+") reduce 75) ((",") reduce 75) (("-") reduce 75) ((".") reduce 75) (("/") reduce 75) ((";") reduce 75) (("<") reduce 75) ((">") reduce 75) (("?") reduce 75) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_BOOLEAN_AND) reduce 75) ((T_BOOLEAN_OR) reduce 75) ((T_COALESCE) reduce 75) ((T_DOUBLE_ARROW) reduce 75) ((T_INSTANCEOF) reduce 75) ((T_IS_EQUAL) reduce 75) ((T_IS_GREATER_OR_EQUAL) reduce 75) ((T_IS_IDENTICAL) reduce 75) ((T_IS_NOT_EQUAL) reduce 75) ((T_IS_NOT_IDENTICAL) reduce 75) ((T_IS_SMALLER_OR_EQUAL) reduce 75) ((T_LOGICAL_AND) reduce 75) ((T_LOGICAL_OR) reduce 75) ((T_LOGICAL_XOR) reduce 75) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 75) ((T_OBJECT_OPERATOR) reduce 75) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 75) ((T_POW) reduce 75) ((T_SL) reduce 75) ((T_SPACESHIP) reduce 75) ((T_SR) reduce 75) (("[") reduce 75) (("^") reduce 75) (("{") reduce 75) (("|") reduce 75)) 3724 ((("%") reduce 76) (("(") reduce 76) (("*") reduce 76) (("+") reduce 76) ((",") reduce 76) (("-") reduce 76) ((".") reduce 76) (("/") reduce 76) ((";") reduce 76) (("<") reduce 76) ((">") reduce 76) (("?") reduce 76) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_BOOLEAN_AND) reduce 76) ((T_BOOLEAN_OR) reduce 76) ((T_COALESCE) reduce 76) ((T_DOUBLE_ARROW) reduce 76) ((T_INSTANCEOF) reduce 76) ((T_IS_EQUAL) reduce 76) ((T_IS_GREATER_OR_EQUAL) reduce 76) ((T_IS_IDENTICAL) reduce 76) ((T_IS_NOT_EQUAL) reduce 76) ((T_IS_NOT_IDENTICAL) reduce 76) ((T_IS_SMALLER_OR_EQUAL) reduce 76) ((T_LOGICAL_AND) reduce 76) ((T_LOGICAL_OR) reduce 76) ((T_LOGICAL_XOR) reduce 76) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 76) ((T_OBJECT_OPERATOR) reduce 76) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 76) ((T_POW) reduce 76) ((T_SL) reduce 76) ((T_SPACESHIP) reduce 76) ((T_SR) reduce 76) (("[") reduce 76) (("^") reduce 76) (("{") reduce 76) (("|") reduce 76)) 3725 ((("%") reduce 77) (("(") reduce 77) (("*") reduce 77) (("+") reduce 77) ((",") reduce 77) (("-") reduce 77) ((".") reduce 77) (("/") reduce 77) ((";") reduce 77) (("<") reduce 77) ((">") reduce 77) (("?") reduce 77) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_BOOLEAN_AND) reduce 77) ((T_BOOLEAN_OR) reduce 77) ((T_COALESCE) reduce 77) ((T_DOUBLE_ARROW) reduce 77) ((T_INSTANCEOF) reduce 77) ((T_IS_EQUAL) reduce 77) ((T_IS_GREATER_OR_EQUAL) reduce 77) ((T_IS_IDENTICAL) reduce 77) ((T_IS_NOT_EQUAL) reduce 77) ((T_IS_NOT_IDENTICAL) reduce 77) ((T_IS_SMALLER_OR_EQUAL) reduce 77) ((T_LOGICAL_AND) reduce 77) ((T_LOGICAL_OR) reduce 77) ((T_LOGICAL_XOR) reduce 77) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 77) ((T_OBJECT_OPERATOR) reduce 77) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 77) ((T_POW) reduce 77) ((T_SL) reduce 77) ((T_SPACESHIP) reduce 77) ((T_SR) reduce 77) (("[") reduce 77) (("^") reduce 77) (("{") reduce 77) (("|") reduce 77)) 3726 ((("%") reduce 78) (("(") reduce 78) (("*") reduce 78) (("+") reduce 78) ((",") reduce 78) (("-") reduce 78) ((".") reduce 78) (("/") reduce 78) ((";") reduce 78) (("<") reduce 78) ((">") reduce 78) (("?") reduce 78) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_BOOLEAN_AND) reduce 78) ((T_BOOLEAN_OR) reduce 78) ((T_COALESCE) reduce 78) ((T_DOUBLE_ARROW) reduce 78) ((T_INSTANCEOF) reduce 78) ((T_IS_EQUAL) reduce 78) ((T_IS_GREATER_OR_EQUAL) reduce 78) ((T_IS_IDENTICAL) reduce 78) ((T_IS_NOT_EQUAL) reduce 78) ((T_IS_NOT_IDENTICAL) reduce 78) ((T_IS_SMALLER_OR_EQUAL) reduce 78) ((T_LOGICAL_AND) reduce 78) ((T_LOGICAL_OR) reduce 78) ((T_LOGICAL_XOR) reduce 78) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 78) ((T_OBJECT_OPERATOR) reduce 78) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 78) ((T_POW) reduce 78) ((T_SL) reduce 78) ((T_SPACESHIP) reduce 78) ((T_SR) reduce 78) (("[") reduce 78) (("^") reduce 78) (("{") reduce 78) (("|") reduce 78)) 3727 ((("%") reduce 4) (("(") reduce 4) (("*") reduce 4) (("+") reduce 4) ((",") reduce 4) (("-") reduce 4) ((".") reduce 4) (("/") reduce 4) ((";") reduce 4) (("<") reduce 4) ((">") reduce 4) (("?") reduce 4) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_BOOLEAN_AND) reduce 4) ((T_BOOLEAN_OR) reduce 4) ((T_COALESCE) reduce 4) ((T_DOUBLE_ARROW) reduce 4) ((T_INSTANCEOF) reduce 4) ((T_IS_EQUAL) reduce 4) ((T_IS_GREATER_OR_EQUAL) reduce 4) ((T_IS_IDENTICAL) reduce 4) ((T_IS_NOT_EQUAL) reduce 4) ((T_IS_NOT_IDENTICAL) reduce 4) ((T_IS_SMALLER_OR_EQUAL) reduce 4) ((T_LOGICAL_AND) reduce 4) ((T_LOGICAL_OR) reduce 4) ((T_LOGICAL_XOR) reduce 4) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 4) ((T_OBJECT_OPERATOR) reduce 4) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 4) ((T_POW) reduce 4) ((T_SL) reduce 4) ((T_SPACESHIP) reduce 4) ((T_SR) reduce 4) (("[") reduce 4) (("^") reduce 4) (("{") reduce 4) (("|") reduce 4)) 3728 ((("%") reduce 5) (("(") reduce 5) (("*") reduce 5) (("+") reduce 5) ((",") reduce 5) (("-") reduce 5) ((".") reduce 5) (("/") reduce 5) ((";") reduce 5) (("<") reduce 5) ((">") reduce 5) (("?") reduce 5) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_BOOLEAN_AND) reduce 5) ((T_BOOLEAN_OR) reduce 5) ((T_COALESCE) reduce 5) ((T_DOUBLE_ARROW) reduce 5) ((T_INSTANCEOF) reduce 5) ((T_IS_EQUAL) reduce 5) ((T_IS_GREATER_OR_EQUAL) reduce 5) ((T_IS_IDENTICAL) reduce 5) ((T_IS_NOT_EQUAL) reduce 5) ((T_IS_NOT_IDENTICAL) reduce 5) ((T_IS_SMALLER_OR_EQUAL) reduce 5) ((T_LOGICAL_AND) reduce 5) ((T_LOGICAL_OR) reduce 5) ((T_LOGICAL_XOR) reduce 5) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 5) ((T_OBJECT_OPERATOR) reduce 5) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 5) ((T_POW) reduce 5) ((T_SL) reduce 5) ((T_SPACESHIP) reduce 5) ((T_SR) reduce 5) (("[") reduce 5) (("^") reduce 5) (("{") reduce 5) (("|") reduce 5)) 3729 ((("%") reduce 43) (("(") reduce 43) (("*") reduce 43) (("+") reduce 43) ((",") reduce 43) (("-") reduce 43) ((".") reduce 43) (("/") reduce 43) ((";") reduce 43) (("<") reduce 43) ((">") reduce 43) (("?") reduce 43) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_BOOLEAN_AND) reduce 43) ((T_BOOLEAN_OR) reduce 43) ((T_COALESCE) reduce 43) ((T_DOUBLE_ARROW) reduce 43) ((T_INSTANCEOF) reduce 43) ((T_IS_EQUAL) reduce 43) ((T_IS_GREATER_OR_EQUAL) reduce 43) ((T_IS_IDENTICAL) reduce 43) ((T_IS_NOT_EQUAL) reduce 43) ((T_IS_NOT_IDENTICAL) reduce 43) ((T_IS_SMALLER_OR_EQUAL) reduce 43) ((T_LOGICAL_AND) reduce 43) ((T_LOGICAL_OR) reduce 43) ((T_LOGICAL_XOR) reduce 43) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 43) ((T_OBJECT_OPERATOR) reduce 43) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 43) ((T_POW) reduce 43) ((T_SL) reduce 43) ((T_SPACESHIP) reduce 43) ((T_SR) reduce 43) (("[") reduce 43) (("^") reduce 43) (("{") reduce 43) (("|") reduce 43)) 3730 ((("%") reduce 72) (("(") reduce 72) (("*") reduce 72) (("+") reduce 72) ((",") reduce 72) (("-") reduce 72) ((".") reduce 72) (("/") reduce 72) ((";") reduce 72) (("<") reduce 72) ((">") reduce 72) (("?") reduce 72) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_BOOLEAN_AND) reduce 72) ((T_BOOLEAN_OR) reduce 72) ((T_COALESCE) reduce 72) ((T_DOUBLE_ARROW) reduce 72) ((T_INSTANCEOF) reduce 72) ((T_IS_EQUAL) reduce 72) ((T_IS_GREATER_OR_EQUAL) reduce 72) ((T_IS_IDENTICAL) reduce 72) ((T_IS_NOT_EQUAL) reduce 72) ((T_IS_NOT_IDENTICAL) reduce 72) ((T_IS_SMALLER_OR_EQUAL) reduce 72) ((T_LOGICAL_AND) reduce 72) ((T_LOGICAL_OR) reduce 72) ((T_LOGICAL_XOR) reduce 72) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 72) ((T_OBJECT_OPERATOR) reduce 72) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 72) ((T_POW) reduce 72) ((T_SL) reduce 72) ((T_SPACESHIP) reduce 72) ((T_SR) reduce 72) (("[") reduce 72) (("^") reduce 72) (("{") reduce 72) (("|") reduce 72)) 3731 ((("%") reduce 81) (("(") reduce 81) (("*") reduce 81) (("+") reduce 81) ((",") reduce 81) (("-") reduce 81) ((".") reduce 81) (("/") reduce 81) ((";") reduce 81) (("<") reduce 81) ((">") reduce 81) (("?") reduce 81) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_BOOLEAN_AND) reduce 81) ((T_BOOLEAN_OR) reduce 81) ((T_COALESCE) reduce 81) ((T_DOUBLE_ARROW) reduce 81) ((T_INSTANCEOF) reduce 81) ((T_IS_EQUAL) reduce 81) ((T_IS_GREATER_OR_EQUAL) reduce 81) ((T_IS_IDENTICAL) reduce 81) ((T_IS_NOT_EQUAL) reduce 81) ((T_IS_NOT_IDENTICAL) reduce 81) ((T_IS_SMALLER_OR_EQUAL) reduce 81) ((T_LOGICAL_AND) reduce 81) ((T_LOGICAL_OR) reduce 81) ((T_LOGICAL_XOR) reduce 81) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 81) ((T_OBJECT_OPERATOR) reduce 81) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 81) ((T_POW) reduce 81) ((T_SL) reduce 81) ((T_SPACESHIP) reduce 81) ((T_SR) reduce 81) (("[") reduce 81) (("^") reduce 81) (("{") reduce 81) (("|") reduce 81)) 3732 ((("%") reduce 47) (("(") reduce 47) (("*") reduce 47) (("+") reduce 47) ((",") reduce 47) (("-") reduce 47) ((".") reduce 47) (("/") reduce 47) ((";") reduce 47) (("<") reduce 47) ((">") reduce 47) (("?") reduce 47) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_BOOLEAN_AND) reduce 47) ((T_BOOLEAN_OR) reduce 47) ((T_COALESCE) reduce 47) ((T_DOUBLE_ARROW) reduce 47) ((T_INSTANCEOF) reduce 47) ((T_IS_EQUAL) reduce 47) ((T_IS_GREATER_OR_EQUAL) reduce 47) ((T_IS_IDENTICAL) reduce 47) ((T_IS_NOT_EQUAL) reduce 47) ((T_IS_NOT_IDENTICAL) reduce 47) ((T_IS_SMALLER_OR_EQUAL) reduce 47) ((T_LOGICAL_AND) reduce 47) ((T_LOGICAL_OR) reduce 47) ((T_LOGICAL_XOR) reduce 47) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 47) ((T_OBJECT_OPERATOR) reduce 47) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 47) ((T_POW) reduce 47) ((T_SL) reduce 47) ((T_SPACESHIP) reduce 47) ((T_SR) reduce 47) (("[") reduce 47) (("^") reduce 47) (("{") reduce 47) (("|") reduce 47)) 3733 ((("%") reduce 31) (("(") reduce 31) (("*") reduce 31) (("+") reduce 31) ((",") reduce 31) (("-") reduce 31) ((".") reduce 31) (("/") reduce 31) ((";") reduce 31) (("<") reduce 31) ((">") reduce 31) (("?") reduce 31) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_BOOLEAN_AND) reduce 31) ((T_BOOLEAN_OR) reduce 31) ((T_COALESCE) reduce 31) ((T_DOUBLE_ARROW) reduce 31) ((T_INSTANCEOF) reduce 31) ((T_IS_EQUAL) reduce 31) ((T_IS_GREATER_OR_EQUAL) reduce 31) ((T_IS_IDENTICAL) reduce 31) ((T_IS_NOT_EQUAL) reduce 31) ((T_IS_NOT_IDENTICAL) reduce 31) ((T_IS_SMALLER_OR_EQUAL) reduce 31) ((T_LOGICAL_AND) reduce 31) ((T_LOGICAL_OR) reduce 31) ((T_LOGICAL_XOR) reduce 31) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 31) ((T_OBJECT_OPERATOR) reduce 31) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 31) ((T_POW) reduce 31) ((T_SL) reduce 31) ((T_SPACESHIP) reduce 31) ((T_SR) reduce 31) (("[") reduce 31) (("^") reduce 31) (("{") reduce 31) (("|") reduce 31)) 3734 ((("%") reduce 57) (("(") reduce 57) (("*") reduce 57) (("+") reduce 57) ((",") reduce 57) (("-") reduce 57) ((".") reduce 57) (("/") reduce 57) ((";") reduce 57) (("<") reduce 57) ((">") reduce 57) (("?") reduce 57) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_BOOLEAN_AND) reduce 57) ((T_BOOLEAN_OR) reduce 57) ((T_COALESCE) reduce 57) ((T_DOUBLE_ARROW) reduce 57) ((T_INSTANCEOF) reduce 57) ((T_IS_EQUAL) reduce 57) ((T_IS_GREATER_OR_EQUAL) reduce 57) ((T_IS_IDENTICAL) reduce 57) ((T_IS_NOT_EQUAL) reduce 57) ((T_IS_NOT_IDENTICAL) reduce 57) ((T_IS_SMALLER_OR_EQUAL) reduce 57) ((T_LOGICAL_AND) reduce 57) ((T_LOGICAL_OR) reduce 57) ((T_LOGICAL_XOR) reduce 57) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 57) ((T_OBJECT_OPERATOR) reduce 57) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 57) ((T_POW) reduce 57) ((T_SL) reduce 57) ((T_SPACESHIP) reduce 57) ((T_SR) reduce 57) (("[") reduce 57) (("^") reduce 57) (("{") reduce 57) (("|") reduce 57)) 3735 ((("%") reduce 61) (("(") reduce 61) (("*") reduce 61) (("+") reduce 61) ((",") reduce 61) (("-") reduce 61) ((".") reduce 61) (("/") reduce 61) ((";") reduce 61) (("<") reduce 61) ((">") reduce 61) (("?") reduce 61) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_BOOLEAN_AND) reduce 61) ((T_BOOLEAN_OR) reduce 61) ((T_COALESCE) reduce 61) ((T_DOUBLE_ARROW) reduce 61) ((T_INSTANCEOF) reduce 61) ((T_IS_EQUAL) reduce 61) ((T_IS_GREATER_OR_EQUAL) reduce 61) ((T_IS_IDENTICAL) reduce 61) ((T_IS_NOT_EQUAL) reduce 61) ((T_IS_NOT_IDENTICAL) reduce 61) ((T_IS_SMALLER_OR_EQUAL) reduce 61) ((T_LOGICAL_AND) reduce 61) ((T_LOGICAL_OR) reduce 61) ((T_LOGICAL_XOR) reduce 61) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 61) ((T_OBJECT_OPERATOR) reduce 61) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 61) ((T_POW) reduce 61) ((T_SL) reduce 61) ((T_SPACESHIP) reduce 61) ((T_SR) reduce 61) (("[") reduce 61) (("^") reduce 61) (("{") reduce 61) (("|") reduce 61)) 3736 ((("%") reduce 28) (("(") reduce 28) (("*") reduce 28) (("+") reduce 28) ((",") reduce 28) (("-") reduce 28) ((".") reduce 28) (("/") reduce 28) ((";") reduce 28) (("<") reduce 28) ((">") reduce 28) (("?") reduce 28) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_BOOLEAN_AND) reduce 28) ((T_BOOLEAN_OR) reduce 28) ((T_COALESCE) reduce 28) ((T_DOUBLE_ARROW) reduce 28) ((T_INSTANCEOF) reduce 28) ((T_IS_EQUAL) reduce 28) ((T_IS_GREATER_OR_EQUAL) reduce 28) ((T_IS_IDENTICAL) reduce 28) ((T_IS_NOT_EQUAL) reduce 28) ((T_IS_NOT_IDENTICAL) reduce 28) ((T_IS_SMALLER_OR_EQUAL) reduce 28) ((T_LOGICAL_AND) reduce 28) ((T_LOGICAL_OR) reduce 28) ((T_LOGICAL_XOR) reduce 28) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 28) ((T_OBJECT_OPERATOR) reduce 28) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 28) ((T_POW) reduce 28) ((T_SL) reduce 28) ((T_SPACESHIP) reduce 28) ((T_SR) reduce 28) (("[") reduce 28) (("^") reduce 28) (("{") reduce 28) (("|") reduce 28)) 3737 ((("%") reduce 36) (("(") reduce 36) (("*") reduce 36) (("+") reduce 36) ((",") reduce 36) (("-") reduce 36) ((".") reduce 36) (("/") reduce 36) ((";") reduce 36) (("<") reduce 36) ((">") reduce 36) (("?") reduce 36) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_BOOLEAN_AND) reduce 36) ((T_BOOLEAN_OR) reduce 36) ((T_COALESCE) reduce 36) ((T_DOUBLE_ARROW) reduce 36) ((T_INSTANCEOF) reduce 36) ((T_IS_EQUAL) reduce 36) ((T_IS_GREATER_OR_EQUAL) reduce 36) ((T_IS_IDENTICAL) reduce 36) ((T_IS_NOT_EQUAL) reduce 36) ((T_IS_NOT_IDENTICAL) reduce 36) ((T_IS_SMALLER_OR_EQUAL) reduce 36) ((T_LOGICAL_AND) reduce 36) ((T_LOGICAL_OR) reduce 36) ((T_LOGICAL_XOR) reduce 36) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 36) ((T_OBJECT_OPERATOR) reduce 36) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 36) ((T_POW) reduce 36) ((T_SL) reduce 36) ((T_SPACESHIP) reduce 36) ((T_SR) reduce 36) (("[") reduce 36) (("^") reduce 36) (("{") reduce 36) (("|") reduce 36)) 3738 ((("%") reduce 32) (("(") reduce 32) (("*") reduce 32) (("+") reduce 32) ((",") reduce 32) (("-") reduce 32) ((".") reduce 32) (("/") reduce 32) ((";") reduce 32) (("<") reduce 32) ((">") reduce 32) (("?") reduce 32) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_BOOLEAN_AND) reduce 32) ((T_BOOLEAN_OR) reduce 32) ((T_COALESCE) reduce 32) ((T_DOUBLE_ARROW) reduce 32) ((T_INSTANCEOF) reduce 32) ((T_IS_EQUAL) reduce 32) ((T_IS_GREATER_OR_EQUAL) reduce 32) ((T_IS_IDENTICAL) reduce 32) ((T_IS_NOT_EQUAL) reduce 32) ((T_IS_NOT_IDENTICAL) reduce 32) ((T_IS_SMALLER_OR_EQUAL) reduce 32) ((T_LOGICAL_AND) reduce 32) ((T_LOGICAL_OR) reduce 32) ((T_LOGICAL_XOR) reduce 32) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 32) ((T_OBJECT_OPERATOR) reduce 32) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 32) ((T_POW) reduce 32) ((T_SL) reduce 32) ((T_SPACESHIP) reduce 32) ((T_SR) reduce 32) (("[") reduce 32) (("^") reduce 32) (("{") reduce 32) (("|") reduce 32)) 3739 ((("%") reduce 35) (("(") reduce 35) (("*") reduce 35) (("+") reduce 35) ((",") reduce 35) (("-") reduce 35) ((".") reduce 35) (("/") reduce 35) ((";") reduce 35) (("<") reduce 35) ((">") reduce 35) (("?") reduce 35) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_BOOLEAN_AND) reduce 35) ((T_BOOLEAN_OR) reduce 35) ((T_COALESCE) reduce 35) ((T_DOUBLE_ARROW) reduce 35) ((T_INSTANCEOF) reduce 35) ((T_IS_EQUAL) reduce 35) ((T_IS_GREATER_OR_EQUAL) reduce 35) ((T_IS_IDENTICAL) reduce 35) ((T_IS_NOT_EQUAL) reduce 35) ((T_IS_NOT_IDENTICAL) reduce 35) ((T_IS_SMALLER_OR_EQUAL) reduce 35) ((T_LOGICAL_AND) reduce 35) ((T_LOGICAL_OR) reduce 35) ((T_LOGICAL_XOR) reduce 35) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 35) ((T_OBJECT_OPERATOR) reduce 35) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 35) ((T_POW) reduce 35) ((T_SL) reduce 35) ((T_SPACESHIP) reduce 35) ((T_SR) reduce 35) (("[") reduce 35) (("^") reduce 35) (("{") reduce 35) (("|") reduce 35)) 3740 ((("%") reduce 19) (("(") reduce 19) (("*") reduce 19) (("+") reduce 19) ((",") reduce 19) (("-") reduce 19) ((".") reduce 19) (("/") reduce 19) ((";") reduce 19) (("<") reduce 19) ((">") reduce 19) (("?") reduce 19) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_BOOLEAN_AND) reduce 19) ((T_BOOLEAN_OR) reduce 19) ((T_COALESCE) reduce 19) ((T_DOUBLE_ARROW) reduce 19) ((T_INSTANCEOF) reduce 19) ((T_IS_EQUAL) reduce 19) ((T_IS_GREATER_OR_EQUAL) reduce 19) ((T_IS_IDENTICAL) reduce 19) ((T_IS_NOT_EQUAL) reduce 19) ((T_IS_NOT_IDENTICAL) reduce 19) ((T_IS_SMALLER_OR_EQUAL) reduce 19) ((T_LOGICAL_AND) reduce 19) ((T_LOGICAL_OR) reduce 19) ((T_LOGICAL_XOR) reduce 19) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 19) ((T_OBJECT_OPERATOR) reduce 19) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 19) ((T_POW) reduce 19) ((T_SL) reduce 19) ((T_SPACESHIP) reduce 19) ((T_SR) reduce 19) (("[") reduce 19) (("^") reduce 19) (("{") reduce 19) (("|") reduce 19)) 3741 ((("%") reduce 45) (("(") reduce 45) (("*") reduce 45) (("+") reduce 45) ((",") reduce 45) (("-") reduce 45) ((".") reduce 45) (("/") reduce 45) ((";") reduce 45) (("<") reduce 45) ((">") reduce 45) (("?") reduce 45) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_BOOLEAN_AND) reduce 45) ((T_BOOLEAN_OR) reduce 45) ((T_COALESCE) reduce 45) ((T_DOUBLE_ARROW) reduce 45) ((T_INSTANCEOF) reduce 45) ((T_IS_EQUAL) reduce 45) ((T_IS_GREATER_OR_EQUAL) reduce 45) ((T_IS_IDENTICAL) reduce 45) ((T_IS_NOT_EQUAL) reduce 45) ((T_IS_NOT_IDENTICAL) reduce 45) ((T_IS_SMALLER_OR_EQUAL) reduce 45) ((T_LOGICAL_AND) reduce 45) ((T_LOGICAL_OR) reduce 45) ((T_LOGICAL_XOR) reduce 45) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 45) ((T_OBJECT_OPERATOR) reduce 45) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 45) ((T_POW) reduce 45) ((T_SL) reduce 45) ((T_SPACESHIP) reduce 45) ((T_SR) reduce 45) (("[") reduce 45) (("^") reduce 45) (("{") reduce 45) (("|") reduce 45)) 3742 ((("%") reduce 504) (("(") reduce 541) (("*") reduce 504) (("+") reduce 504) ((",") reduce 504) (("-") reduce 504) ((".") reduce 504) (("/") reduce 504) ((";") reduce 504) (("<") reduce 504) ((">") reduce 504) (("?") reduce 504) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_BOOLEAN_AND) reduce 504) ((T_BOOLEAN_OR) reduce 504) ((T_COALESCE) reduce 504) ((T_DOUBLE_ARROW) reduce 504) ((T_INSTANCEOF) reduce 504) ((T_IS_EQUAL) reduce 504) ((T_IS_GREATER_OR_EQUAL) reduce 504) ((T_IS_IDENTICAL) reduce 504) ((T_IS_NOT_EQUAL) reduce 504) ((T_IS_NOT_IDENTICAL) reduce 504) ((T_IS_SMALLER_OR_EQUAL) reduce 504) ((T_LOGICAL_AND) reduce 504) ((T_LOGICAL_OR) reduce 504) ((T_LOGICAL_XOR) reduce 504) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 504) ((T_OBJECT_OPERATOR) reduce 504) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 504) ((T_POW) reduce 504) ((T_SL) reduce 504) ((T_SPACESHIP) reduce 504) ((T_SR) reduce 504) (("[") reduce 504) (("^") reduce 504) (("{") reduce 504) (("|") reduce 504)) 3744 ((("%") reduce 71) (("(") reduce 71) (("*") reduce 71) (("+") reduce 71) ((",") reduce 71) (("-") reduce 71) ((".") reduce 71) (("/") reduce 71) ((";") reduce 71) (("<") reduce 71) ((">") reduce 71) (("?") reduce 71) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_BOOLEAN_AND) reduce 71) ((T_BOOLEAN_OR) reduce 71) ((T_COALESCE) reduce 71) ((T_DOUBLE_ARROW) reduce 71) ((T_INSTANCEOF) reduce 71) ((T_IS_EQUAL) reduce 71) ((T_IS_GREATER_OR_EQUAL) reduce 71) ((T_IS_IDENTICAL) reduce 71) ((T_IS_NOT_EQUAL) reduce 71) ((T_IS_NOT_IDENTICAL) reduce 71) ((T_IS_SMALLER_OR_EQUAL) reduce 71) ((T_LOGICAL_AND) reduce 71) ((T_LOGICAL_OR) reduce 71) ((T_LOGICAL_XOR) reduce 71) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 71) ((T_OBJECT_OPERATOR) reduce 71) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 71) ((T_POW) reduce 71) ((T_SL) reduce 71) ((T_SPACESHIP) reduce 71) ((T_SR) reduce 71) (("[") reduce 71) (("^") reduce 71) (("{") reduce 71) (("|") reduce 71)) 3745 ((("%") reduce 82) (("(") reduce 82) (("*") reduce 82) (("+") reduce 82) ((",") reduce 82) (("-") reduce 82) ((".") reduce 82) (("/") reduce 82) ((";") reduce 82) (("<") reduce 82) ((">") reduce 82) (("?") reduce 82) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_BOOLEAN_AND) reduce 82) ((T_BOOLEAN_OR) reduce 82) ((T_COALESCE) reduce 82) ((T_DOUBLE_ARROW) reduce 82) ((T_INSTANCEOF) reduce 82) ((T_IS_EQUAL) reduce 82) ((T_IS_GREATER_OR_EQUAL) reduce 82) ((T_IS_IDENTICAL) reduce 82) ((T_IS_NOT_EQUAL) reduce 82) ((T_IS_NOT_IDENTICAL) reduce 82) ((T_IS_SMALLER_OR_EQUAL) reduce 82) ((T_LOGICAL_AND) reduce 82) ((T_LOGICAL_OR) reduce 82) ((T_LOGICAL_XOR) reduce 82) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 82) ((T_OBJECT_OPERATOR) reduce 82) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 82) ((T_POW) reduce 82) ((T_SL) reduce 82) ((T_SPACESHIP) reduce 82) ((T_SR) reduce 82) (("[") reduce 82) (("^") reduce 82) (("{") reduce 82) (("|") reduce 82)) 3746 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) ((",") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) ((";") reduce 533) (("<") reduce 533) (("=") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AND_EQUAL) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_COALESCE_EQUAL) reduce 533) ((T_CONCAT_EQUAL) reduce 533) ((T_DEC) reduce 533) ((T_DIV_EQUAL) reduce 533) ((T_DOUBLE_ARROW) reduce 533) ((T_INC) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_MINUS_EQUAL) reduce 533) ((T_MOD_EQUAL) reduce 533) ((T_MUL_EQUAL) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_OR_EQUAL) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_PLUS_EQUAL) reduce 533) ((T_POW) reduce 533) ((T_POW_EQUAL) reduce 533) ((T_SL) reduce 533) ((T_SL_EQUAL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) ((T_SR_EQUAL) reduce 533) ((T_XOR_EQUAL) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 3749 ((("%") reduce 506) (("(") reduce 542) (("*") reduce 506) (("+") reduce 506) ((",") reduce 506) (("-") reduce 506) ((".") reduce 506) (("/") reduce 506) ((";") reduce 506) (("<") reduce 506) ((">") reduce 506) (("?") reduce 506) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_BOOLEAN_AND) reduce 506) ((T_BOOLEAN_OR) reduce 506) ((T_COALESCE) reduce 506) ((T_DOUBLE_ARROW) reduce 506) ((T_INSTANCEOF) reduce 506) ((T_IS_EQUAL) reduce 506) ((T_IS_GREATER_OR_EQUAL) reduce 506) ((T_IS_IDENTICAL) reduce 506) ((T_IS_NOT_EQUAL) reduce 506) ((T_IS_NOT_IDENTICAL) reduce 506) ((T_IS_SMALLER_OR_EQUAL) reduce 506) ((T_LOGICAL_AND) reduce 506) ((T_LOGICAL_OR) reduce 506) ((T_LOGICAL_XOR) reduce 506) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 506) ((T_OBJECT_OPERATOR) reduce 506) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 506) ((T_POW) reduce 506) ((T_SL) reduce 506) ((T_SPACESHIP) reduce 506) ((T_SR) reduce 506) (("[") reduce 506) (("^") reduce 506) (("{") reduce 506) (("|") reduce 506)) 3751 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) ((",") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) ((";") reduce 468) (("<") reduce 468) (("=") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AND_EQUAL) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_COALESCE_EQUAL) reduce 468) ((T_CONCAT_EQUAL) reduce 468) ((T_DEC) reduce 468) ((T_DIV_EQUAL) reduce 468) ((T_DOUBLE_ARROW) reduce 468) ((T_INC) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_MINUS_EQUAL) reduce 468) ((T_MOD_EQUAL) reduce 468) ((T_MUL_EQUAL) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_OR_EQUAL) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_PLUS_EQUAL) reduce 468) ((T_POW) reduce 468) ((T_POW_EQUAL) reduce 468) ((T_SL) reduce 468) ((T_SL_EQUAL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) ((T_SR_EQUAL) reduce 468) ((T_XOR_EQUAL) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 3752 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) ((",") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) ((";") reduce 288) (("<") reduce 288) (("=") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AND_EQUAL) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_COALESCE_EQUAL) reduce 288) ((T_CONCAT_EQUAL) reduce 288) ((T_DEC) reduce 288) ((T_DIV_EQUAL) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INC) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_MINUS_EQUAL) reduce 288) ((T_MOD_EQUAL) reduce 288) ((T_MUL_EQUAL) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_OR_EQUAL) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_PLUS_EQUAL) reduce 288) ((T_POW) reduce 288) ((T_POW_EQUAL) reduce 288) ((T_SL) reduce 288) ((T_SL_EQUAL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) ((T_SR_EQUAL) reduce 288) ((T_XOR_EQUAL) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 3756 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) ((",") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) ((";") reduce 289) (("<") reduce 289) (("=") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AND_EQUAL) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_COALESCE_EQUAL) reduce 289) ((T_CONCAT_EQUAL) reduce 289) ((T_DEC) reduce 289) ((T_DIV_EQUAL) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INC) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_MINUS_EQUAL) reduce 289) ((T_MOD_EQUAL) reduce 289) ((T_MUL_EQUAL) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_OR_EQUAL) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_PLUS_EQUAL) reduce 289) ((T_POW) reduce 289) ((T_POW_EQUAL) reduce 289) ((T_SL) reduce 289) ((T_SL_EQUAL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) ((T_SR_EQUAL) reduce 289) ((T_XOR_EQUAL) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 3757 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) ((",") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) ((";") reduce 290) (("<") reduce 290) (("=") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AND_EQUAL) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_COALESCE_EQUAL) reduce 290) ((T_CONCAT_EQUAL) reduce 290) ((T_DEC) reduce 290) ((T_DIV_EQUAL) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INC) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_MINUS_EQUAL) reduce 290) ((T_MOD_EQUAL) reduce 290) ((T_MUL_EQUAL) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_OR_EQUAL) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_PLUS_EQUAL) reduce 290) ((T_POW) reduce 290) ((T_POW_EQUAL) reduce 290) ((T_SL) reduce 290) ((T_SL_EQUAL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) ((T_SR_EQUAL) reduce 290) ((T_XOR_EQUAL) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 3762 ((("%") reduce 388) (("*") reduce 388) (("+") reduce 388) ((",") reduce 388) (("-") reduce 388) ((".") reduce 388) (("/") reduce 388) ((";") reduce 388) (("<") reduce 388) ((">") reduce 388) (("?") reduce 388) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_BOOLEAN_AND) reduce 388) ((T_BOOLEAN_OR) reduce 388) ((T_COALESCE) reduce 388) ((T_DOUBLE_ARROW) reduce 388) ((T_INSTANCEOF) reduce 388) ((T_IS_EQUAL) reduce 388) ((T_IS_GREATER_OR_EQUAL) reduce 388) ((T_IS_IDENTICAL) reduce 388) ((T_IS_NOT_EQUAL) reduce 388) ((T_IS_NOT_IDENTICAL) reduce 388) ((T_IS_SMALLER_OR_EQUAL) reduce 388) ((T_LOGICAL_AND) reduce 388) ((T_LOGICAL_OR) reduce 388) ((T_LOGICAL_XOR) reduce 388) ((T_POW) reduce 388) ((T_SL) reduce 388) ((T_SPACESHIP) reduce 388) ((T_SR) reduce 388) (("^") reduce 388) (("|") reduce 388)) 3764 ((("%") reduce 386) (("*") reduce 386) (("+") reduce 386) ((",") reduce 386) (("-") reduce 386) ((".") reduce 386) (("/") reduce 386) ((";") reduce 386) (("<") reduce 386) ((">") reduce 386) (("?") reduce 386) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_BOOLEAN_AND) reduce 386) ((T_BOOLEAN_OR) reduce 386) ((T_COALESCE) reduce 386) ((T_DOUBLE_ARROW) reduce 386) ((T_INSTANCEOF) reduce 386) ((T_IS_EQUAL) reduce 386) ((T_IS_GREATER_OR_EQUAL) reduce 386) ((T_IS_IDENTICAL) reduce 386) ((T_IS_NOT_EQUAL) reduce 386) ((T_IS_NOT_IDENTICAL) reduce 386) ((T_IS_SMALLER_OR_EQUAL) reduce 386) ((T_LOGICAL_AND) reduce 386) ((T_LOGICAL_OR) reduce 386) ((T_LOGICAL_XOR) reduce 386) ((T_POW) reduce 386) ((T_SL) reduce 386) ((T_SPACESHIP) reduce 386) ((T_SR) reduce 386) (("^") reduce 386) (("|") reduce 386)) 3774 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 382) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 382) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 382) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 382) ((T_LOGICAL_OR) reduce 382) ((T_LOGICAL_XOR) reduce 382) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3775 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 384) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 384) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 384) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 384) ((T_LOGICAL_OR) reduce 384) ((T_LOGICAL_XOR) reduce 384) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3776 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 383) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 383) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 383) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 383) ((T_LOGICAL_OR) reduce 383) ((T_LOGICAL_XOR) reduce 383) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3777 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 376) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 376) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 376) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 376) ((T_LOGICAL_OR) reduce 376) ((T_LOGICAL_XOR) reduce 376) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3778 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 373) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 373) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 373) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 373) ((T_LOGICAL_OR) reduce 373) ((T_LOGICAL_XOR) reduce 373) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3779 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 381) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 381) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 381) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 381) ((T_LOGICAL_OR) reduce 381) ((T_LOGICAL_XOR) reduce 381) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3780 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 375) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 375) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 375) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 375) ((T_LOGICAL_OR) reduce 375) ((T_LOGICAL_XOR) reduce 375) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3781 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 379) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 379) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 379) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 379) ((T_LOGICAL_OR) reduce 379) ((T_LOGICAL_XOR) reduce 379) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3782 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 374) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 374) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 374) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 374) ((T_LOGICAL_OR) reduce 374) ((T_LOGICAL_XOR) reduce 374) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3783 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 377) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 377) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 377) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 377) ((T_LOGICAL_OR) reduce 377) ((T_LOGICAL_XOR) reduce 377) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3784 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 378) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 378) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 378) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 378) ((T_LOGICAL_OR) reduce 378) ((T_LOGICAL_XOR) reduce 378) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3785 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 385) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 385) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 385) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 385) ((T_LOGICAL_OR) reduce 385) ((T_LOGICAL_XOR) reduce 385) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3786 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 380) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 380) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 380) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 380) ((T_LOGICAL_OR) reduce 380) ((T_LOGICAL_XOR) reduce 380) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3788 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 370) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 370) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 370) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 370) ((T_LOGICAL_OR) reduce 370) ((T_LOGICAL_XOR) reduce 370) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3791 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) ((",") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) ((";") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 3794 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) ((",") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) ((";") reduce 525) (("<") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_DOUBLE_ARROW) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_POW) reduce 525) ((T_SL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 3796 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) ((",") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) ((";") reduce 524) (("<") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_DOUBLE_ARROW) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_POW) reduce 524) ((T_SL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 3798 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) ((",") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) ((";") reduce 519) (("<") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_DOUBLE_ARROW) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_POW) reduce 519) ((T_SL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 3799 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) ((",") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) ((";") reduce 526) (("<") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_DOUBLE_ARROW) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_POW) reduce 526) ((T_SL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 3800 ((("%") reduce 371) (("*") reduce 371) (("+") reduce 371) ((",") reduce 371) (("-") reduce 371) ((".") reduce 371) (("/") reduce 371) ((";") reduce 371) (("<") reduce 371) ((">") reduce 371) (("?") reduce 371) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_BOOLEAN_AND) reduce 371) ((T_BOOLEAN_OR) reduce 371) ((T_COALESCE) reduce 371) ((T_DOUBLE_ARROW) reduce 371) ((T_INSTANCEOF) reduce 371) ((T_IS_EQUAL) reduce 371) ((T_IS_GREATER_OR_EQUAL) reduce 371) ((T_IS_IDENTICAL) reduce 371) ((T_IS_NOT_EQUAL) reduce 371) ((T_IS_NOT_IDENTICAL) reduce 371) ((T_IS_SMALLER_OR_EQUAL) reduce 371) ((T_LOGICAL_AND) reduce 371) ((T_LOGICAL_OR) reduce 371) ((T_LOGICAL_XOR) reduce 371) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 371) ((T_SL) reduce 371) ((T_SPACESHIP) reduce 371) ((T_SR) reduce 371) (("[") reduce 510) (("^") reduce 371) (("{") reduce 510) (("|") reduce 371)) 3804 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) ((",") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) ((";") reduce 533) (("<") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_DOUBLE_ARROW) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_POW) reduce 533) ((T_SL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 3806 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) ((",") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) ((";") reduce 468) (("<") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_DOUBLE_ARROW) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_POW) reduce 468) ((T_SL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 3807 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) ((",") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) ((";") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 3811 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) ((",") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) ((";") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 3812 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) ((",") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) ((";") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 3813 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) ((",") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) ((";") reduce 465) (("<") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_DOUBLE_ARROW) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_POW) reduce 465) ((T_SL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 3816 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) ((",") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) ((";") reduce 532) (("<") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_DOUBLE_ARROW) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_POW) reduce 532) ((T_SL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 3817 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) ((",") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) ((";") reduce 467) (("<") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_DOUBLE_ARROW) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_POW) reduce 467) ((T_SL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 3818 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) ((",") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) ((";") reduce 469) (("<") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_DOUBLE_ARROW) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_POW) reduce 469) ((T_SL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 3824 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) ((",") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) ((";") reduce 521) (("<") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_DOUBLE_ARROW) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_POW) reduce 521) ((T_SL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 3826 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) ((",") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) ((";") reduce 520) (("<") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_DOUBLE_ARROW) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_POW) reduce 520) ((T_SL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 3827 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) ((",") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) ((";") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 3828 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) ((",") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) ((";") reduce 527) (("<") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_DOUBLE_ARROW) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_POW) reduce 527) ((T_SL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 3829 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) ((",") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) ((";") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 3832 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) ((",") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) ((";") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 3833 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) ((",") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) ((";") reduce 522) (("<") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_DOUBLE_ARROW) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_POW) reduce 522) ((T_SL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 3834 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) ((",") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) ((";") reduce 528) (("<") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_DOUBLE_ARROW) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_POW) reduce 528) ((T_SL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 3835 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) ((",") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) ((";") reduce 523) (("<") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_DOUBLE_ARROW) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_POW) reduce 523) ((T_SL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 3836 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) ((",") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) ((";") reduce 466) (("<") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_DOUBLE_ARROW) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_POW) reduce 466) ((T_SL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 3837 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) ((",") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) ((";") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 3840 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) ((",") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) ((";") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 3841 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) ((",") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) ((";") reduce 465) (("<") reduce 465) (("=") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AND_EQUAL) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_COALESCE_EQUAL) reduce 465) ((T_CONCAT_EQUAL) reduce 465) ((T_DEC) reduce 465) ((T_DIV_EQUAL) reduce 465) ((T_DOUBLE_ARROW) reduce 465) ((T_INC) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_MINUS_EQUAL) reduce 465) ((T_MOD_EQUAL) reduce 465) ((T_MUL_EQUAL) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_OR_EQUAL) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_PLUS_EQUAL) reduce 465) ((T_POW) reduce 465) ((T_POW_EQUAL) reduce 465) ((T_SL) reduce 465) ((T_SL_EQUAL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) ((T_SR_EQUAL) reduce 465) ((T_XOR_EQUAL) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 3852 ((("%") reduce 455) (("*") reduce 455) (("+") reduce 455) ((",") reduce 455) (("-") reduce 455) ((".") reduce 455) (("/") reduce 455) ((";") reduce 455) (("<") reduce 455) ((">") reduce 455) (("?") reduce 455) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_BOOLEAN_AND) reduce 455) ((T_BOOLEAN_OR) reduce 455) ((T_COALESCE) reduce 455) ((T_DOUBLE_ARROW) reduce 455) ((T_INSTANCEOF) reduce 455) ((T_IS_EQUAL) reduce 455) ((T_IS_GREATER_OR_EQUAL) reduce 455) ((T_IS_IDENTICAL) reduce 455) ((T_IS_NOT_EQUAL) reduce 455) ((T_IS_NOT_IDENTICAL) reduce 455) ((T_IS_SMALLER_OR_EQUAL) reduce 455) ((T_LOGICAL_AND) reduce 455) ((T_LOGICAL_OR) reduce 455) ((T_LOGICAL_XOR) reduce 455) ((T_POW) reduce 455) ((T_SL) reduce 455) ((T_SPACESHIP) reduce 455) ((T_SR) reduce 455) (("^") reduce 455) (("|") reduce 455)) 3853 ((("%") reduce 450) (("*") reduce 450) (("+") reduce 450) ((",") reduce 450) (("-") reduce 450) ((".") reduce 450) (("/") reduce 450) ((";") reduce 450) (("<") reduce 450) ((">") reduce 450) (("?") reduce 450) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_BOOLEAN_AND) reduce 450) ((T_BOOLEAN_OR) reduce 450) ((T_COALESCE) reduce 450) ((T_DOUBLE_ARROW) reduce 450) ((T_INSTANCEOF) reduce 450) ((T_IS_EQUAL) reduce 450) ((T_IS_GREATER_OR_EQUAL) reduce 450) ((T_IS_IDENTICAL) reduce 450) ((T_IS_NOT_EQUAL) reduce 450) ((T_IS_NOT_IDENTICAL) reduce 450) ((T_IS_SMALLER_OR_EQUAL) reduce 450) ((T_LOGICAL_AND) reduce 450) ((T_LOGICAL_OR) reduce 450) ((T_LOGICAL_XOR) reduce 450) ((T_POW) reduce 450) ((T_SL) reduce 450) ((T_SPACESHIP) reduce 450) ((T_SR) reduce 450) (("^") reduce 450) (("|") reduce 450)) 3863 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 455) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 455) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 455) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3864 ((("%") reduce 451) (("*") reduce 451) (("+") reduce 451) ((",") reduce 451) (("-") reduce 451) ((".") reduce 451) (("/") reduce 451) ((";") reduce 451) (("<") reduce 451) ((">") reduce 451) (("?") reduce 451) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_BOOLEAN_AND) reduce 451) ((T_BOOLEAN_OR) reduce 451) ((T_COALESCE) reduce 451) ((T_DOUBLE_ARROW) reduce 451) ((T_INSTANCEOF) reduce 451) ((T_IS_EQUAL) reduce 451) ((T_IS_GREATER_OR_EQUAL) reduce 451) ((T_IS_IDENTICAL) reduce 451) ((T_IS_NOT_EQUAL) reduce 451) ((T_IS_NOT_IDENTICAL) reduce 451) ((T_IS_SMALLER_OR_EQUAL) reduce 451) ((T_LOGICAL_AND) reduce 451) ((T_LOGICAL_OR) reduce 451) ((T_LOGICAL_XOR) reduce 451) ((T_POW) reduce 451) ((T_SL) reduce 451) ((T_SPACESHIP) reduce 451) ((T_SR) reduce 451) (("^") reduce 451) (("|") reduce 451)) 3866 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 442) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 442) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 442) ((T_LOGICAL_OR) reduce 442) ((T_LOGICAL_XOR) reduce 442) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3868 ((("%") reduce 503) (("(") reduce 541) (("*") reduce 503) (("+") reduce 503) ((",") reduce 503) (("-") reduce 503) ((".") reduce 503) (("/") reduce 503) ((";") reduce 503) (("<") reduce 503) ((">") reduce 503) (("?") reduce 503) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_BOOLEAN_AND) reduce 503) ((T_BOOLEAN_OR) reduce 503) ((T_COALESCE) reduce 503) ((T_DOUBLE_ARROW) reduce 503) ((T_INSTANCEOF) reduce 503) ((T_IS_EQUAL) reduce 503) ((T_IS_GREATER_OR_EQUAL) reduce 503) ((T_IS_IDENTICAL) reduce 503) ((T_IS_NOT_EQUAL) reduce 503) ((T_IS_NOT_IDENTICAL) reduce 503) ((T_IS_SMALLER_OR_EQUAL) reduce 503) ((T_LOGICAL_AND) reduce 503) ((T_LOGICAL_OR) reduce 503) ((T_LOGICAL_XOR) reduce 503) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 503) ((T_OBJECT_OPERATOR) reduce 503) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 503) ((T_POW) reduce 503) ((T_SL) reduce 503) ((T_SPACESHIP) reduce 503) ((T_SR) reduce 503) (("[") reduce 503) (("^") reduce 503) (("{") reduce 503) (("|") reduce 503)) 3870 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) ((",") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) ((";") reduce 532) (("<") reduce 532) (("=") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AND_EQUAL) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_COALESCE_EQUAL) reduce 532) ((T_CONCAT_EQUAL) reduce 532) ((T_DEC) reduce 532) ((T_DIV_EQUAL) reduce 532) ((T_DOUBLE_ARROW) reduce 532) ((T_INC) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_MINUS_EQUAL) reduce 532) ((T_MOD_EQUAL) reduce 532) ((T_MUL_EQUAL) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_OR_EQUAL) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_PLUS_EQUAL) reduce 532) ((T_POW) reduce 532) ((T_POW_EQUAL) reduce 532) ((T_SL) reduce 532) ((T_SL_EQUAL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) ((T_SR_EQUAL) reduce 532) ((T_XOR_EQUAL) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 3873 ((("%") reduce 505) (("(") reduce 542) (("*") reduce 505) (("+") reduce 505) ((",") reduce 505) (("-") reduce 505) ((".") reduce 505) (("/") reduce 505) ((";") reduce 505) (("<") reduce 505) ((">") reduce 505) (("?") reduce 505) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_BOOLEAN_AND) reduce 505) ((T_BOOLEAN_OR) reduce 505) ((T_COALESCE) reduce 505) ((T_DOUBLE_ARROW) reduce 505) ((T_INSTANCEOF) reduce 505) ((T_IS_EQUAL) reduce 505) ((T_IS_GREATER_OR_EQUAL) reduce 505) ((T_IS_IDENTICAL) reduce 505) ((T_IS_NOT_EQUAL) reduce 505) ((T_IS_NOT_IDENTICAL) reduce 505) ((T_IS_SMALLER_OR_EQUAL) reduce 505) ((T_LOGICAL_AND) reduce 505) ((T_LOGICAL_OR) reduce 505) ((T_LOGICAL_XOR) reduce 505) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 505) ((T_OBJECT_OPERATOR) reduce 505) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 505) ((T_POW) reduce 505) ((T_SL) reduce 505) ((T_SPACESHIP) reduce 505) ((T_SR) reduce 505) (("[") reduce 505) (("^") reduce 505) (("{") reduce 505) (("|") reduce 505)) 3874 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) ((",") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) ((";") reduce 467) (("<") reduce 467) (("=") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AND_EQUAL) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_COALESCE_EQUAL) reduce 467) ((T_CONCAT_EQUAL) reduce 467) ((T_DEC) reduce 467) ((T_DIV_EQUAL) reduce 467) ((T_DOUBLE_ARROW) reduce 467) ((T_INC) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_MINUS_EQUAL) reduce 467) ((T_MOD_EQUAL) reduce 467) ((T_MUL_EQUAL) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_OR_EQUAL) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_PLUS_EQUAL) reduce 467) ((T_POW) reduce 467) ((T_POW_EQUAL) reduce 467) ((T_SL) reduce 467) ((T_SL_EQUAL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) ((T_SR_EQUAL) reduce 467) ((T_XOR_EQUAL) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 3875 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) ((",") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) ((";") reduce 469) (("<") reduce 469) (("=") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AND_EQUAL) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_COALESCE_EQUAL) reduce 469) ((T_CONCAT_EQUAL) reduce 469) ((T_DEC) reduce 469) ((T_DIV_EQUAL) reduce 469) ((T_DOUBLE_ARROW) reduce 469) ((T_INC) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_MINUS_EQUAL) reduce 469) ((T_MOD_EQUAL) reduce 469) ((T_MUL_EQUAL) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_OR_EQUAL) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_PLUS_EQUAL) reduce 469) ((T_POW) reduce 469) ((T_POW_EQUAL) reduce 469) ((T_SL) reduce 469) ((T_SL_EQUAL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) ((T_SR_EQUAL) reduce 469) ((T_XOR_EQUAL) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 3877 ((("%") reduce 446) (("*") reduce 446) (("+") reduce 446) ((",") reduce 446) (("-") reduce 446) ((".") reduce 446) (("/") reduce 446) ((";") reduce 446) (("<") reduce 446) ((">") reduce 446) (("?") reduce 446) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_BOOLEAN_AND) reduce 446) ((T_BOOLEAN_OR) reduce 446) ((T_COALESCE) reduce 446) ((T_DOUBLE_ARROW) reduce 446) ((T_INSTANCEOF) reduce 446) ((T_IS_EQUAL) reduce 446) ((T_IS_GREATER_OR_EQUAL) reduce 446) ((T_IS_IDENTICAL) reduce 446) ((T_IS_NOT_EQUAL) reduce 446) ((T_IS_NOT_IDENTICAL) reduce 446) ((T_IS_SMALLER_OR_EQUAL) reduce 446) ((T_LOGICAL_AND) reduce 446) ((T_LOGICAL_OR) reduce 446) ((T_LOGICAL_XOR) reduce 446) ((T_POW) reduce 446) ((T_SL) reduce 446) ((T_SPACESHIP) reduce 446) ((T_SR) reduce 446) (("^") reduce 446) (("|") reduce 446)) 3878 ((("%") reduce 448) (("*") reduce 448) (("+") reduce 448) ((",") reduce 448) (("-") reduce 448) ((".") reduce 448) (("/") reduce 448) ((";") reduce 448) (("<") reduce 448) ((">") reduce 448) (("?") reduce 448) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_BOOLEAN_AND) reduce 448) ((T_BOOLEAN_OR) reduce 448) ((T_COALESCE) reduce 448) ((T_DOUBLE_ARROW) reduce 448) ((T_INSTANCEOF) reduce 448) ((T_IS_EQUAL) reduce 448) ((T_IS_GREATER_OR_EQUAL) reduce 448) ((T_IS_IDENTICAL) reduce 448) ((T_IS_NOT_EQUAL) reduce 448) ((T_IS_NOT_IDENTICAL) reduce 448) ((T_IS_SMALLER_OR_EQUAL) reduce 448) ((T_LOGICAL_AND) reduce 448) ((T_LOGICAL_OR) reduce 448) ((T_LOGICAL_XOR) reduce 448) ((T_POW) reduce 448) ((T_SL) reduce 448) ((T_SPACESHIP) reduce 448) ((T_SR) reduce 448) (("^") reduce 448) (("|") reduce 448)) 3884 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) ((",") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) ((";") reduce 521) (("<") reduce 521) (("=") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AND_EQUAL) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_COALESCE_EQUAL) reduce 521) ((T_CONCAT_EQUAL) reduce 521) ((T_DEC) reduce 521) ((T_DIV_EQUAL) reduce 521) ((T_DOUBLE_ARROW) reduce 521) ((T_INC) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_MINUS_EQUAL) reduce 521) ((T_MOD_EQUAL) reduce 521) ((T_MUL_EQUAL) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_OR_EQUAL) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_PLUS_EQUAL) reduce 521) ((T_POW) reduce 521) ((T_POW_EQUAL) reduce 521) ((T_SL) reduce 521) ((T_SL_EQUAL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) ((T_SR_EQUAL) reduce 521) ((T_XOR_EQUAL) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 3886 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) ((",") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) ((";") reduce 520) (("<") reduce 520) (("=") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AND_EQUAL) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_COALESCE_EQUAL) reduce 520) ((T_CONCAT_EQUAL) reduce 520) ((T_DEC) reduce 520) ((T_DIV_EQUAL) reduce 520) ((T_DOUBLE_ARROW) reduce 520) ((T_INC) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_MINUS_EQUAL) reduce 520) ((T_MOD_EQUAL) reduce 520) ((T_MUL_EQUAL) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_OR_EQUAL) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_PLUS_EQUAL) reduce 520) ((T_POW) reduce 520) ((T_POW_EQUAL) reduce 520) ((T_SL) reduce 520) ((T_SL_EQUAL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) ((T_SR_EQUAL) reduce 520) ((T_XOR_EQUAL) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 3887 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) ((",") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) ((";") reduce 544) (("<") reduce 544) (("=") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AND_EQUAL) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_COALESCE_EQUAL) reduce 544) ((T_CONCAT_EQUAL) reduce 544) ((T_DEC) reduce 544) ((T_DIV_EQUAL) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INC) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_MINUS_EQUAL) reduce 544) ((T_MOD_EQUAL) reduce 544) ((T_MUL_EQUAL) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_OR_EQUAL) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_PLUS_EQUAL) reduce 544) ((T_POW) reduce 544) ((T_POW_EQUAL) reduce 544) ((T_SL) reduce 544) ((T_SL_EQUAL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) ((T_SR_EQUAL) reduce 544) ((T_XOR_EQUAL) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 3888 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) ((",") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) ((";") reduce 527) (("<") reduce 527) (("=") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AND_EQUAL) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_COALESCE_EQUAL) reduce 527) ((T_CONCAT_EQUAL) reduce 527) ((T_DEC) reduce 527) ((T_DIV_EQUAL) reduce 527) ((T_DOUBLE_ARROW) reduce 527) ((T_INC) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_MINUS_EQUAL) reduce 527) ((T_MOD_EQUAL) reduce 527) ((T_MUL_EQUAL) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_OR_EQUAL) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_PLUS_EQUAL) reduce 527) ((T_POW) reduce 527) ((T_POW_EQUAL) reduce 527) ((T_SL) reduce 527) ((T_SL_EQUAL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) ((T_SR_EQUAL) reduce 527) ((T_XOR_EQUAL) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 3889 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) ((",") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) ((";") reduce 546) (("<") reduce 546) (("=") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AND_EQUAL) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_COALESCE_EQUAL) reduce 546) ((T_CONCAT_EQUAL) reduce 546) ((T_DEC) reduce 546) ((T_DIV_EQUAL) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INC) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_MINUS_EQUAL) reduce 546) ((T_MOD_EQUAL) reduce 546) ((T_MUL_EQUAL) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_OR_EQUAL) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_PLUS_EQUAL) reduce 546) ((T_POW) reduce 546) ((T_POW_EQUAL) reduce 546) ((T_SL) reduce 546) ((T_SL_EQUAL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) ((T_SR_EQUAL) reduce 546) ((T_XOR_EQUAL) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 3892 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) ((",") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) ((";") reduce 545) (("<") reduce 545) (("=") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AND_EQUAL) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_COALESCE_EQUAL) reduce 545) ((T_CONCAT_EQUAL) reduce 545) ((T_DEC) reduce 545) ((T_DIV_EQUAL) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INC) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_MINUS_EQUAL) reduce 545) ((T_MOD_EQUAL) reduce 545) ((T_MUL_EQUAL) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_OR_EQUAL) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_PLUS_EQUAL) reduce 545) ((T_POW) reduce 545) ((T_POW_EQUAL) reduce 545) ((T_SL) reduce 545) ((T_SL_EQUAL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) ((T_SR_EQUAL) reduce 545) ((T_XOR_EQUAL) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 3893 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) ((",") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) ((";") reduce 522) (("<") reduce 522) (("=") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AND_EQUAL) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_COALESCE_EQUAL) reduce 522) ((T_CONCAT_EQUAL) reduce 522) ((T_DEC) reduce 522) ((T_DIV_EQUAL) reduce 522) ((T_DOUBLE_ARROW) reduce 522) ((T_INC) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_MINUS_EQUAL) reduce 522) ((T_MOD_EQUAL) reduce 522) ((T_MUL_EQUAL) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_OR_EQUAL) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_PLUS_EQUAL) reduce 522) ((T_POW) reduce 522) ((T_POW_EQUAL) reduce 522) ((T_SL) reduce 522) ((T_SL_EQUAL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) ((T_SR_EQUAL) reduce 522) ((T_XOR_EQUAL) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 3894 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) ((",") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) ((";") reduce 528) (("<") reduce 528) (("=") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AND_EQUAL) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_COALESCE_EQUAL) reduce 528) ((T_CONCAT_EQUAL) reduce 528) ((T_DEC) reduce 528) ((T_DIV_EQUAL) reduce 528) ((T_DOUBLE_ARROW) reduce 528) ((T_INC) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_MINUS_EQUAL) reduce 528) ((T_MOD_EQUAL) reduce 528) ((T_MUL_EQUAL) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_OR_EQUAL) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_PLUS_EQUAL) reduce 528) ((T_POW) reduce 528) ((T_POW_EQUAL) reduce 528) ((T_SL) reduce 528) ((T_SL_EQUAL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) ((T_SR_EQUAL) reduce 528) ((T_XOR_EQUAL) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 3895 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) ((",") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) ((";") reduce 523) (("<") reduce 523) (("=") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AND_EQUAL) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_COALESCE_EQUAL) reduce 523) ((T_CONCAT_EQUAL) reduce 523) ((T_DEC) reduce 523) ((T_DIV_EQUAL) reduce 523) ((T_DOUBLE_ARROW) reduce 523) ((T_INC) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_MINUS_EQUAL) reduce 523) ((T_MOD_EQUAL) reduce 523) ((T_MUL_EQUAL) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_OR_EQUAL) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_PLUS_EQUAL) reduce 523) ((T_POW) reduce 523) ((T_POW_EQUAL) reduce 523) ((T_SL) reduce 523) ((T_SL_EQUAL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) ((T_SR_EQUAL) reduce 523) ((T_XOR_EQUAL) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 3897 ((("%") reduce 438) (("*") reduce 438) (("+") reduce 438) ((",") reduce 438) (("-") reduce 438) ((".") reduce 438) (("/") reduce 438) ((";") reduce 438) (("<") reduce 438) ((">") reduce 438) (("?") reduce 438) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_BOOLEAN_AND) reduce 438) ((T_BOOLEAN_OR) reduce 438) ((T_COALESCE) reduce 438) ((T_DOUBLE_ARROW) reduce 438) ((T_INSTANCEOF) reduce 438) ((T_IS_EQUAL) reduce 438) ((T_IS_GREATER_OR_EQUAL) reduce 438) ((T_IS_IDENTICAL) reduce 438) ((T_IS_NOT_EQUAL) reduce 438) ((T_IS_NOT_IDENTICAL) reduce 438) ((T_IS_SMALLER_OR_EQUAL) reduce 438) ((T_LOGICAL_AND) reduce 438) ((T_LOGICAL_OR) reduce 438) ((T_LOGICAL_XOR) reduce 438) ((T_POW) reduce 438) ((T_SL) reduce 438) ((T_SPACESHIP) reduce 438) ((T_SR) reduce 438) (("^") reduce 438) (("|") reduce 438)) 3899 ((("%") reduce 483) (("(") reduce 483) (("*") reduce 483) (("+") reduce 483) ((",") reduce 483) (("-") reduce 483) ((".") reduce 483) (("/") reduce 483) ((";") reduce 483) (("<") reduce 483) (("=") shift) ((">") reduce 483) (("?") reduce 483) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_BOOLEAN_AND) reduce 483) ((T_BOOLEAN_OR) reduce 483) ((T_COALESCE) reduce 483) ((T_DOUBLE_ARROW) reduce 483) ((T_INSTANCEOF) reduce 483) ((T_IS_EQUAL) reduce 483) ((T_IS_GREATER_OR_EQUAL) reduce 483) ((T_IS_IDENTICAL) reduce 483) ((T_IS_NOT_EQUAL) reduce 483) ((T_IS_NOT_IDENTICAL) reduce 483) ((T_IS_SMALLER_OR_EQUAL) reduce 483) ((T_LOGICAL_AND) reduce 483) ((T_LOGICAL_OR) reduce 483) ((T_LOGICAL_XOR) reduce 483) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 483) ((T_OBJECT_OPERATOR) reduce 483) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 483) ((T_POW) reduce 483) ((T_SL) reduce 483) ((T_SPACESHIP) reduce 483) ((T_SR) reduce 483) (("[") reduce 483) (("^") reduce 483) (("{") reduce 483) (("|") reduce 483)) 3901 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 369) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 369) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 369) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 369) ((T_LOGICAL_OR) reduce 369) ((T_LOGICAL_XOR) reduce 369) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3902 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 443) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 443) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 443) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 443) ((T_LOGICAL_OR) reduce 443) ((T_LOGICAL_XOR) reduce 443) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3905 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 442) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 442) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 442) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 442) ((T_LOGICAL_OR) reduce 442) ((T_LOGICAL_XOR) reduce 442) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3906 ((("%") reduce 434) (("*") reduce 434) (("+") reduce 434) ((",") reduce 434) (("-") reduce 434) ((".") reduce 434) (("/") reduce 434) ((";") reduce 434) (("<") reduce 434) ((">") reduce 434) (("?") reduce 434) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_BOOLEAN_AND) reduce 434) ((T_BOOLEAN_OR) reduce 434) ((T_COALESCE) reduce 434) ((T_DOUBLE_ARROW) reduce 434) ((T_INSTANCEOF) reduce 434) ((T_IS_EQUAL) reduce 434) ((T_IS_GREATER_OR_EQUAL) reduce 434) ((T_IS_IDENTICAL) reduce 434) ((T_IS_NOT_EQUAL) reduce 434) ((T_IS_NOT_IDENTICAL) reduce 434) ((T_IS_SMALLER_OR_EQUAL) reduce 434) ((T_LOGICAL_AND) reduce 434) ((T_LOGICAL_OR) reduce 434) ((T_LOGICAL_XOR) reduce 434) ((T_POW) shift) ((T_SL) reduce 434) ((T_SPACESHIP) reduce 434) ((T_SR) reduce 434) (("^") reduce 434) (("|") reduce 434)) 3907 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 444) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 444) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 444) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3908 ((("%") reduce 430) (("*") reduce 430) (("+") reduce 430) ((",") reduce 430) (("-") reduce 430) ((".") reduce 430) (("/") reduce 430) ((";") reduce 430) (("<") reduce 430) ((">") reduce 430) (("?") reduce 430) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_BOOLEAN_AND) reduce 430) ((T_BOOLEAN_OR) reduce 430) ((T_COALESCE) reduce 430) ((T_DOUBLE_ARROW) reduce 430) ((T_INSTANCEOF) reduce 430) ((T_IS_EQUAL) reduce 430) ((T_IS_GREATER_OR_EQUAL) reduce 430) ((T_IS_IDENTICAL) reduce 430) ((T_IS_NOT_EQUAL) reduce 430) ((T_IS_NOT_IDENTICAL) reduce 430) ((T_IS_SMALLER_OR_EQUAL) reduce 430) ((T_LOGICAL_AND) reduce 430) ((T_LOGICAL_OR) reduce 430) ((T_LOGICAL_XOR) reduce 430) ((T_POW) shift) ((T_SL) reduce 430) ((T_SPACESHIP) reduce 430) ((T_SR) reduce 430) (("^") reduce 430) (("|") reduce 430)) 3909 ((("%") reduce 447) (("*") reduce 447) (("+") reduce 447) ((",") reduce 447) (("-") reduce 447) ((".") reduce 447) (("/") reduce 447) ((";") reduce 447) (("<") reduce 447) ((">") reduce 447) (("?") reduce 447) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_BOOLEAN_AND) reduce 447) ((T_BOOLEAN_OR) reduce 447) ((T_COALESCE) reduce 447) ((T_DOUBLE_ARROW) reduce 447) ((T_INSTANCEOF) reduce 447) ((T_IS_EQUAL) reduce 447) ((T_IS_GREATER_OR_EQUAL) reduce 447) ((T_IS_IDENTICAL) reduce 447) ((T_IS_NOT_EQUAL) reduce 447) ((T_IS_NOT_IDENTICAL) reduce 447) ((T_IS_SMALLER_OR_EQUAL) reduce 447) ((T_LOGICAL_AND) reduce 447) ((T_LOGICAL_OR) reduce 447) ((T_LOGICAL_XOR) reduce 447) ((T_POW) reduce 447) ((T_SL) reduce 447) ((T_SPACESHIP) reduce 447) ((T_SR) reduce 447) (("^") reduce 447) (("|") reduce 447)) 3911 ((("%") reduce 489) (("*") reduce 489) (("+") reduce 489) ((",") reduce 489) (("-") reduce 489) ((".") reduce 489) (("/") reduce 489) ((";") reduce 489) (("<") reduce 489) ((">") reduce 489) (("?") reduce 489) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_BOOLEAN_AND) reduce 489) ((T_BOOLEAN_OR) reduce 489) ((T_COALESCE) reduce 489) ((T_DOUBLE_ARROW) reduce 489) ((T_INSTANCEOF) reduce 489) ((T_IS_EQUAL) reduce 489) ((T_IS_GREATER_OR_EQUAL) reduce 489) ((T_IS_IDENTICAL) reduce 489) ((T_IS_NOT_EQUAL) reduce 489) ((T_IS_NOT_IDENTICAL) reduce 489) ((T_IS_SMALLER_OR_EQUAL) reduce 489) ((T_LOGICAL_AND) reduce 489) ((T_LOGICAL_OR) reduce 489) ((T_LOGICAL_XOR) reduce 489) ((T_POW) reduce 489) ((T_SL) reduce 489) ((T_SPACESHIP) reduce 489) ((T_SR) reduce 489) (("^") reduce 489) (("|") reduce 489)) 3913 ((("%") reduce 490) (("*") reduce 490) (("+") reduce 490) ((",") reduce 490) (("-") reduce 490) ((".") reduce 490) (("/") reduce 490) ((";") reduce 490) (("<") reduce 490) ((">") reduce 490) (("?") reduce 490) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_BOOLEAN_AND) reduce 490) ((T_BOOLEAN_OR) reduce 490) ((T_COALESCE) reduce 490) ((T_DOUBLE_ARROW) reduce 490) ((T_INSTANCEOF) reduce 490) ((T_IS_EQUAL) reduce 490) ((T_IS_GREATER_OR_EQUAL) reduce 490) ((T_IS_IDENTICAL) reduce 490) ((T_IS_NOT_EQUAL) reduce 490) ((T_IS_NOT_IDENTICAL) reduce 490) ((T_IS_SMALLER_OR_EQUAL) reduce 490) ((T_LOGICAL_AND) reduce 490) ((T_LOGICAL_OR) reduce 490) ((T_LOGICAL_XOR) reduce 490) ((T_POW) reduce 490) ((T_SL) reduce 490) ((T_SPACESHIP) reduce 490) ((T_SR) reduce 490) (("^") reduce 490) (("|") reduce 490)) 3914 ((("%") reduce 488) (("*") reduce 488) (("+") reduce 488) ((",") reduce 488) (("-") reduce 488) ((".") reduce 488) (("/") reduce 488) ((";") reduce 488) (("<") reduce 488) ((">") reduce 488) (("?") reduce 488) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_BOOLEAN_AND) reduce 488) ((T_BOOLEAN_OR) reduce 488) ((T_COALESCE) reduce 488) ((T_DOUBLE_ARROW) reduce 488) ((T_INSTANCEOF) reduce 488) ((T_IS_EQUAL) reduce 488) ((T_IS_GREATER_OR_EQUAL) reduce 488) ((T_IS_IDENTICAL) reduce 488) ((T_IS_NOT_EQUAL) reduce 488) ((T_IS_NOT_IDENTICAL) reduce 488) ((T_IS_SMALLER_OR_EQUAL) reduce 488) ((T_LOGICAL_AND) reduce 488) ((T_LOGICAL_OR) reduce 488) ((T_LOGICAL_XOR) reduce 488) ((T_POW) reduce 488) ((T_SL) reduce 488) ((T_SPACESHIP) reduce 488) ((T_SR) reduce 488) (("^") reduce 488) (("|") reduce 488)) 3915 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 581) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 581) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 581) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3916 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 580) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 580) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 580) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3917 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) ((",") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) ((";") reduce 466) (("<") reduce 466) (("=") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AND_EQUAL) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_COALESCE_EQUAL) reduce 466) ((T_CONCAT_EQUAL) reduce 466) ((T_DEC) reduce 466) ((T_DIV_EQUAL) reduce 466) ((T_DOUBLE_ARROW) reduce 466) ((T_INC) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_MINUS_EQUAL) reduce 466) ((T_MOD_EQUAL) reduce 466) ((T_MUL_EQUAL) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_OR_EQUAL) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_PLUS_EQUAL) reduce 466) ((T_POW) reduce 466) ((T_POW_EQUAL) reduce 466) ((T_SL) reduce 466) ((T_SL_EQUAL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) ((T_SR_EQUAL) reduce 466) ((T_XOR_EQUAL) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 3918 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 439) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 439) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 439) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 439) ((T_LOGICAL_OR) reduce 439) ((T_LOGICAL_XOR) reduce 439) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 3919 ((("%") reduce 432) (("*") reduce 432) (("+") reduce 432) ((",") reduce 432) (("-") reduce 432) ((".") reduce 432) (("/") reduce 432) ((";") reduce 432) (("<") reduce 432) ((">") reduce 432) (("?") reduce 432) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_BOOLEAN_AND) reduce 432) ((T_BOOLEAN_OR) reduce 432) ((T_COALESCE) reduce 432) ((T_DOUBLE_ARROW) reduce 432) ((T_INSTANCEOF) reduce 432) ((T_IS_EQUAL) reduce 432) ((T_IS_GREATER_OR_EQUAL) reduce 432) ((T_IS_IDENTICAL) reduce 432) ((T_IS_NOT_EQUAL) reduce 432) ((T_IS_NOT_IDENTICAL) reduce 432) ((T_IS_SMALLER_OR_EQUAL) reduce 432) ((T_LOGICAL_AND) reduce 432) ((T_LOGICAL_OR) reduce 432) ((T_LOGICAL_XOR) reduce 432) ((T_POW) shift) ((T_SL) reduce 432) ((T_SPACESHIP) reduce 432) ((T_SR) reduce 432) (("^") reduce 432) (("|") reduce 432)) 3921 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) ((",") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) ((";") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93)) 3922 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) ((",") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) ((";") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92)) 3923 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) ((",") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) ((";") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94)) 3924 ((("%") reduce 470) (("(") reduce 470) (("*") reduce 470) (("+") reduce 470) ((",") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) ((";") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_DOUBLE_ARROW) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470)) 3925 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) ((",") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) ((";") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91)) 3926 ((("%") reduce 365) (("*") reduce 365) (("+") reduce 365) ((",") reduce 365) (("-") reduce 365) ((".") reduce 365) (("/") reduce 365) ((";") reduce 365) (("<") reduce 365) ((">") reduce 365) (("?") reduce 365) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_BOOLEAN_AND) reduce 365) ((T_BOOLEAN_OR) reduce 365) ((T_COALESCE) reduce 365) ((T_DOUBLE_ARROW) reduce 365) ((T_INSTANCEOF) reduce 365) ((T_IS_EQUAL) reduce 365) ((T_IS_GREATER_OR_EQUAL) reduce 365) ((T_IS_IDENTICAL) reduce 365) ((T_IS_NOT_EQUAL) reduce 365) ((T_IS_NOT_IDENTICAL) reduce 365) ((T_IS_SMALLER_OR_EQUAL) reduce 365) ((T_LOGICAL_AND) reduce 365) ((T_LOGICAL_OR) reduce 365) ((T_LOGICAL_XOR) reduce 365) ((T_POW) reduce 365) ((T_SL) reduce 365) ((T_SPACESHIP) reduce 365) ((T_SR) reduce 365) (("^") reduce 365) (("|") reduce 365)) 3929 ((("%") reduce 472) (("(") reduce 472) (("*") reduce 472) (("+") reduce 472) ((",") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) ((";") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_DOUBLE_ARROW) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472)) 3930 ((("%") reduce 480) (("(") shift) (("*") reduce 480) (("+") reduce 480) ((",") reduce 480) (("-") reduce 480) ((".") reduce 480) (("/") reduce 480) ((";") reduce 480) (("<") reduce 480) ((">") reduce 480) (("?") reduce 480) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_BOOLEAN_AND) reduce 480) ((T_BOOLEAN_OR) reduce 480) ((T_COALESCE) reduce 480) ((T_DOUBLE_ARROW) reduce 480) ((T_INSTANCEOF) reduce 480) ((T_IS_EQUAL) reduce 480) ((T_IS_GREATER_OR_EQUAL) reduce 480) ((T_IS_IDENTICAL) reduce 480) ((T_IS_NOT_EQUAL) reduce 480) ((T_IS_NOT_IDENTICAL) reduce 480) ((T_IS_SMALLER_OR_EQUAL) reduce 480) ((T_LOGICAL_AND) reduce 480) ((T_LOGICAL_OR) reduce 480) ((T_LOGICAL_XOR) reduce 480) ((T_POW) reduce 480) ((T_SL) reduce 480) ((T_SPACESHIP) reduce 480) ((T_SR) reduce 480) (("^") reduce 480) (("|") reduce 480)) 3931 ((("%") reduce 471) (("(") reduce 471) (("*") reduce 471) (("+") reduce 471) ((",") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) ((";") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_DOUBLE_ARROW) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471)) 3932 ((("%") reduce 473) (("(") reduce 473) (("*") reduce 473) (("+") reduce 473) ((",") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) ((";") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_DOUBLE_ARROW) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 3933 ((("%") reduce 534) (("(") reduce 534) (("*") reduce 534) (("+") reduce 534) ((",") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) ((";") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_DOUBLE_ARROW) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 3940 ((("%") reduce 536) (("(") reduce 536) (("*") reduce 536) (("+") reduce 536) ((",") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) ((";") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_DOUBLE_ARROW) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 3942 ((("%") reduce 535) (("(") reduce 535) (("*") reduce 535) (("+") reduce 535) ((",") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) ((";") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_DOUBLE_ARROW) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 3943 ((("%") reduce 540) (("(") reduce 540) (("*") reduce 540) (("+") reduce 540) ((",") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) ((";") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_DOUBLE_ARROW) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 3944 ((("%") reduce 537) (("(") reduce 537) (("*") reduce 537) (("+") reduce 537) ((",") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) ((";") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_DOUBLE_ARROW) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 3945 ((("%") reduce 538) (("(") reduce 538) (("*") reduce 538) (("+") reduce 538) ((",") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) ((";") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_DOUBLE_ARROW) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 3947 ((("%") reduce 481) (("*") reduce 481) (("+") reduce 481) ((",") reduce 481) (("-") reduce 481) ((".") reduce 481) (("/") reduce 481) ((";") reduce 481) (("<") reduce 481) ((">") reduce 481) (("?") reduce 481) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_BOOLEAN_AND) reduce 481) ((T_BOOLEAN_OR) reduce 481) ((T_COALESCE) reduce 481) ((T_DOUBLE_ARROW) reduce 481) ((T_INSTANCEOF) reduce 481) ((T_IS_EQUAL) reduce 481) ((T_IS_GREATER_OR_EQUAL) reduce 481) ((T_IS_IDENTICAL) reduce 481) ((T_IS_NOT_EQUAL) reduce 481) ((T_IS_NOT_IDENTICAL) reduce 481) ((T_IS_SMALLER_OR_EQUAL) reduce 481) ((T_LOGICAL_AND) reduce 481) ((T_LOGICAL_OR) reduce 481) ((T_LOGICAL_XOR) reduce 481) ((T_POW) reduce 481) ((T_SL) reduce 481) ((T_SPACESHIP) reduce 481) ((T_SR) reduce 481) (("^") reduce 481) (("|") reduce 481)) 3948 ((("%") reduce 364) (("*") reduce 364) (("+") reduce 364) ((",") reduce 364) (("-") reduce 364) ((".") reduce 364) (("/") reduce 364) ((";") reduce 364) (("<") reduce 364) ((">") reduce 364) (("?") reduce 364) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_BOOLEAN_AND) reduce 364) ((T_BOOLEAN_OR) reduce 364) ((T_COALESCE) reduce 364) ((T_DOUBLE_ARROW) reduce 364) ((T_INSTANCEOF) reduce 364) ((T_IS_EQUAL) reduce 364) ((T_IS_GREATER_OR_EQUAL) reduce 364) ((T_IS_IDENTICAL) reduce 364) ((T_IS_NOT_EQUAL) reduce 364) ((T_IS_NOT_IDENTICAL) reduce 364) ((T_IS_SMALLER_OR_EQUAL) reduce 364) ((T_LOGICAL_AND) reduce 364) ((T_LOGICAL_OR) reduce 364) ((T_LOGICAL_XOR) reduce 364) ((T_POW) reduce 364) ((T_SL) reduce 364) ((T_SPACESHIP) reduce 364) ((T_SR) reduce 364) (("^") reduce 364) (("|") reduce 364)) 3949 ((("%") reduce 288) (("*") reduce 288) (("+") reduce 288) ((",") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) ((";") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("^") reduce 288) (("|") reduce 288)) 3953 ((("%") reduce 289) (("*") reduce 289) (("+") reduce 289) ((",") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) ((";") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("^") reduce 289) (("|") reduce 289)) 3954 ((("%") reduce 290) (("*") reduce 290) (("+") reduce 290) ((",") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) ((";") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("^") reduce 290) (("|") reduce 290)) 3956 ((("%") reduce 539) (("(") reduce 539) (("*") reduce 539) (("+") reduce 539) ((",") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) ((";") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_DOUBLE_ARROW) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 3957 ((("%") reduce 366) (("*") reduce 366) (("+") reduce 366) ((",") reduce 366) (("-") reduce 366) ((".") reduce 366) (("/") reduce 366) ((";") reduce 366) (("<") reduce 366) ((">") reduce 366) (("?") reduce 366) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_BOOLEAN_AND) reduce 366) ((T_BOOLEAN_OR) reduce 366) ((T_COALESCE) reduce 366) ((T_DOUBLE_ARROW) reduce 366) ((T_INSTANCEOF) reduce 366) ((T_IS_EQUAL) reduce 366) ((T_IS_GREATER_OR_EQUAL) reduce 366) ((T_IS_IDENTICAL) reduce 366) ((T_IS_NOT_EQUAL) reduce 366) ((T_IS_NOT_IDENTICAL) reduce 366) ((T_IS_SMALLER_OR_EQUAL) reduce 366) ((T_LOGICAL_AND) reduce 366) ((T_LOGICAL_OR) reduce 366) ((T_LOGICAL_XOR) reduce 366) ((T_POW) reduce 366) ((T_SL) reduce 366) ((T_SPACESHIP) reduce 366) ((T_SR) reduce 366) (("^") reduce 366) (("|") reduce 366)) 3965 ((("%") reduce 363) (("*") reduce 363) (("+") reduce 363) ((",") reduce 363) (("-") reduce 363) ((".") reduce 363) (("/") reduce 363) ((";") reduce 363) (("<") reduce 363) ((">") reduce 363) (("?") reduce 363) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_BOOLEAN_AND) reduce 363) ((T_BOOLEAN_OR) reduce 363) ((T_COALESCE) reduce 363) ((T_DOUBLE_ARROW) reduce 363) ((T_INSTANCEOF) reduce 363) ((T_IS_EQUAL) reduce 363) ((T_IS_GREATER_OR_EQUAL) reduce 363) ((T_IS_IDENTICAL) reduce 363) ((T_IS_NOT_EQUAL) reduce 363) ((T_IS_NOT_IDENTICAL) reduce 363) ((T_IS_SMALLER_OR_EQUAL) reduce 363) ((T_LOGICAL_AND) reduce 363) ((T_LOGICAL_OR) reduce 363) ((T_LOGICAL_XOR) reduce 363) ((T_POW) reduce 363) ((T_SL) reduce 363) ((T_SPACESHIP) reduce 363) ((T_SR) reduce 363) (("^") reduce 363) (("|") reduce 363)) 3967 ((("%") reduce 474) (("(") reduce 474) (("*") reduce 474) (("+") reduce 474) ((",") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) ((";") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_DOUBLE_ARROW) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474)) 3971 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) (("+") shift) (("-") shift) (("@") shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DEFAULT) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("}") reduce 231) (("~") shift)) 3982 ((("%") reduce 502) (("*") reduce 502) (("+") reduce 502) ((",") reduce 502) (("-") reduce 502) ((".") reduce 502) (("/") reduce 502) (("<") reduce 502) ((">") reduce 502) (("?") reduce 502) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_BOOLEAN_AND) reduce 502) ((T_BOOLEAN_OR) reduce 502) ((T_COALESCE) reduce 502) ((T_DOUBLE_ARROW) reduce 502) ((T_INSTANCEOF) reduce 502) ((T_IS_EQUAL) reduce 502) ((T_IS_GREATER_OR_EQUAL) reduce 502) ((T_IS_IDENTICAL) reduce 502) ((T_IS_NOT_EQUAL) reduce 502) ((T_IS_NOT_IDENTICAL) reduce 502) ((T_IS_SMALLER_OR_EQUAL) reduce 502) ((T_LOGICAL_AND) reduce 502) ((T_LOGICAL_OR) reduce 502) ((T_LOGICAL_XOR) reduce 502) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 502) ((T_OBJECT_OPERATOR) reduce 502) ((T_POW) reduce 502) ((T_SL) reduce 502) ((T_SPACESHIP) reduce 502) ((T_SR) reduce 502) (("[") reduce 502) (("^") reduce 502) (("{") reduce 502) (("|") reduce 502)) 3984 ((("%") reduce 484) (("(") reduce 484) (("*") reduce 484) (("+") reduce 484) ((",") reduce 484) (("-") reduce 484) ((".") reduce 484) (("/") reduce 484) (("<") reduce 484) ((">") reduce 484) (("?") reduce 484) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_BOOLEAN_AND) reduce 484) ((T_BOOLEAN_OR) reduce 484) ((T_COALESCE) reduce 484) ((T_DOUBLE_ARROW) reduce 484) ((T_INSTANCEOF) reduce 484) ((T_IS_EQUAL) reduce 484) ((T_IS_GREATER_OR_EQUAL) reduce 484) ((T_IS_IDENTICAL) reduce 484) ((T_IS_NOT_EQUAL) reduce 484) ((T_IS_NOT_IDENTICAL) reduce 484) ((T_IS_SMALLER_OR_EQUAL) reduce 484) ((T_LOGICAL_AND) reduce 484) ((T_LOGICAL_OR) reduce 484) ((T_LOGICAL_XOR) reduce 484) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 484) ((T_OBJECT_OPERATOR) reduce 484) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 484) ((T_POW) reduce 484) ((T_SL) reduce 484) ((T_SPACESHIP) reduce 484) ((T_SR) reduce 484) (("[") reduce 484) (("^") reduce 484) (("{") reduce 484) (("|") reduce 484)) 3986 (((",") shift) ((T_DOUBLE_ARROW) reduce 123)) 3987 ((("%") reduce 497) (("*") reduce 497) (("+") reduce 497) ((",") reduce 497) (("-") reduce 497) ((".") reduce 497) (("/") reduce 497) (("<") reduce 497) ((">") reduce 497) (("?") reduce 497) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_BOOLEAN_AND) reduce 497) ((T_BOOLEAN_OR) reduce 497) ((T_COALESCE) reduce 497) ((T_DOUBLE_ARROW) reduce 497) ((T_INSTANCEOF) reduce 497) ((T_IS_EQUAL) reduce 497) ((T_IS_GREATER_OR_EQUAL) reduce 497) ((T_IS_IDENTICAL) reduce 497) ((T_IS_NOT_EQUAL) reduce 497) ((T_IS_NOT_IDENTICAL) reduce 497) ((T_IS_SMALLER_OR_EQUAL) reduce 497) ((T_LOGICAL_AND) reduce 497) ((T_LOGICAL_OR) reduce 497) ((T_LOGICAL_XOR) reduce 497) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 497) ((T_OBJECT_OPERATOR) reduce 497) ((T_POW) reduce 497) ((T_SL) reduce 497) ((T_SPACESHIP) reduce 497) ((T_SR) reduce 497) (("[") reduce 497) (("^") reduce 497) (("{") reduce 497) (("|") reduce 497)) 3988 ((("%") reduce 487) (("*") reduce 487) (("+") reduce 487) ((",") reduce 487) (("-") reduce 487) ((".") reduce 487) (("/") reduce 487) (("<") reduce 487) ((">") reduce 487) (("?") reduce 487) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_BOOLEAN_AND) reduce 487) ((T_BOOLEAN_OR) reduce 487) ((T_COALESCE) reduce 487) ((T_DOUBLE_ARROW) reduce 487) ((T_INSTANCEOF) reduce 487) ((T_IS_EQUAL) reduce 487) ((T_IS_GREATER_OR_EQUAL) reduce 487) ((T_IS_IDENTICAL) reduce 487) ((T_IS_NOT_EQUAL) reduce 487) ((T_IS_NOT_IDENTICAL) reduce 487) ((T_IS_SMALLER_OR_EQUAL) reduce 487) ((T_LOGICAL_AND) reduce 487) ((T_LOGICAL_OR) reduce 487) ((T_LOGICAL_XOR) reduce 487) ((T_POW) reduce 487) ((T_SL) reduce 487) ((T_SPACESHIP) reduce 487) ((T_SR) reduce 487) (("^") reduce 487) (("|") reduce 487)) 3992 ((("%") reduce 475) (("(") shift) (("*") reduce 475) (("+") reduce 475) ((",") reduce 475) (("-") reduce 475) ((".") reduce 475) (("/") reduce 475) (("<") reduce 475) ((">") reduce 475) (("?") reduce 475) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_BOOLEAN_AND) reduce 475) ((T_BOOLEAN_OR) reduce 475) ((T_COALESCE) reduce 475) ((T_DOUBLE_ARROW) reduce 475) ((T_INSTANCEOF) reduce 475) ((T_IS_EQUAL) reduce 475) ((T_IS_GREATER_OR_EQUAL) reduce 475) ((T_IS_IDENTICAL) reduce 475) ((T_IS_NOT_EQUAL) reduce 475) ((T_IS_NOT_IDENTICAL) reduce 475) ((T_IS_SMALLER_OR_EQUAL) reduce 475) ((T_LOGICAL_AND) reduce 475) ((T_LOGICAL_OR) reduce 475) ((T_LOGICAL_XOR) reduce 475) ((T_POW) reduce 475) ((T_SL) reduce 475) ((T_SPACESHIP) reduce 475) ((T_SR) reduce 475) (("^") reduce 475) (("|") reduce 475)) 3993 ((("%") reduce 496) (("*") reduce 496) (("+") reduce 496) ((",") reduce 496) (("-") reduce 496) ((".") reduce 496) (("/") reduce 496) (("<") reduce 496) ((">") reduce 496) (("?") reduce 496) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_BOOLEAN_AND) reduce 496) ((T_BOOLEAN_OR) reduce 496) ((T_COALESCE) reduce 496) ((T_DOUBLE_ARROW) reduce 496) ((T_INSTANCEOF) reduce 496) ((T_IS_EQUAL) reduce 496) ((T_IS_GREATER_OR_EQUAL) reduce 496) ((T_IS_IDENTICAL) reduce 496) ((T_IS_NOT_EQUAL) reduce 496) ((T_IS_NOT_IDENTICAL) reduce 496) ((T_IS_SMALLER_OR_EQUAL) reduce 496) ((T_LOGICAL_AND) reduce 496) ((T_LOGICAL_OR) reduce 496) ((T_LOGICAL_XOR) reduce 496) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 496) ((T_OBJECT_OPERATOR) reduce 496) ((T_POW) reduce 496) ((T_SL) reduce 496) ((T_SPACESHIP) reduce 496) ((T_SR) reduce 496) (("[") reduce 496) (("^") reduce 496) (("{") reduce 496) (("|") reduce 496)) 3994 ((("%") reduce 500) (("*") reduce 500) (("+") reduce 500) ((",") reduce 500) (("-") reduce 500) ((".") reduce 500) (("/") reduce 500) (("<") reduce 500) ((">") reduce 500) (("?") reduce 500) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_BOOLEAN_AND) reduce 500) ((T_BOOLEAN_OR) reduce 500) ((T_COALESCE) reduce 500) ((T_DOUBLE_ARROW) reduce 500) ((T_INSTANCEOF) reduce 500) ((T_IS_EQUAL) reduce 500) ((T_IS_GREATER_OR_EQUAL) reduce 500) ((T_IS_IDENTICAL) reduce 500) ((T_IS_NOT_EQUAL) reduce 500) ((T_IS_NOT_IDENTICAL) reduce 500) ((T_IS_SMALLER_OR_EQUAL) reduce 500) ((T_LOGICAL_AND) reduce 500) ((T_LOGICAL_OR) reduce 500) ((T_LOGICAL_XOR) reduce 500) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 500) ((T_OBJECT_OPERATOR) reduce 500) ((T_POW) reduce 500) ((T_SL) reduce 500) ((T_SPACESHIP) reduce 500) ((T_SR) reduce 500) (("[") reduce 500) (("^") reduce 500) (("{") reduce 500) (("|") reduce 500)) 4000 ((("%") reduce 495) (("*") reduce 495) (("+") reduce 495) ((",") reduce 495) (("-") reduce 495) ((".") reduce 495) (("/") reduce 495) (("<") reduce 495) ((">") reduce 495) (("?") reduce 495) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_BOOLEAN_AND) reduce 495) ((T_BOOLEAN_OR) reduce 495) ((T_COALESCE) reduce 495) ((T_DOUBLE_ARROW) reduce 495) ((T_INSTANCEOF) reduce 495) ((T_IS_EQUAL) reduce 495) ((T_IS_GREATER_OR_EQUAL) reduce 495) ((T_IS_IDENTICAL) reduce 495) ((T_IS_NOT_EQUAL) reduce 495) ((T_IS_NOT_IDENTICAL) reduce 495) ((T_IS_SMALLER_OR_EQUAL) reduce 495) ((T_LOGICAL_AND) reduce 495) ((T_LOGICAL_OR) reduce 495) ((T_LOGICAL_XOR) reduce 495) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 495) ((T_OBJECT_OPERATOR) reduce 495) ((T_POW) reduce 495) ((T_SL) reduce 495) ((T_SPACESHIP) reduce 495) ((T_SR) reduce 495) (("[") reduce 495) (("^") reduce 495) (("{") reduce 495) (("|") reduce 495)) 4002 ((("%") reduce 486) (("*") reduce 486) (("+") reduce 486) ((",") reduce 486) (("-") reduce 486) ((".") reduce 486) (("/") reduce 486) (("<") reduce 486) ((">") reduce 486) (("?") reduce 486) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_BOOLEAN_AND) reduce 486) ((T_BOOLEAN_OR) reduce 486) ((T_COALESCE) reduce 486) ((T_DOUBLE_ARROW) reduce 486) ((T_INSTANCEOF) reduce 486) ((T_IS_EQUAL) reduce 486) ((T_IS_GREATER_OR_EQUAL) reduce 486) ((T_IS_IDENTICAL) reduce 486) ((T_IS_NOT_EQUAL) reduce 486) ((T_IS_NOT_IDENTICAL) reduce 486) ((T_IS_SMALLER_OR_EQUAL) reduce 486) ((T_LOGICAL_AND) reduce 486) ((T_LOGICAL_OR) reduce 486) ((T_LOGICAL_XOR) reduce 486) ((T_POW) reduce 486) ((T_SL) reduce 486) ((T_SPACESHIP) reduce 486) ((T_SR) reduce 486) (("^") reduce 486) (("|") reduce 486)) 4004 ((("%") reduce 499) (("*") reduce 499) (("+") reduce 499) ((",") reduce 499) (("-") reduce 499) ((".") reduce 499) (("/") reduce 499) (("<") reduce 499) ((">") reduce 499) (("?") reduce 499) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_BOOLEAN_AND) reduce 499) ((T_BOOLEAN_OR) reduce 499) ((T_COALESCE) reduce 499) ((T_DOUBLE_ARROW) reduce 499) ((T_INSTANCEOF) reduce 499) ((T_IS_EQUAL) reduce 499) ((T_IS_GREATER_OR_EQUAL) reduce 499) ((T_IS_IDENTICAL) reduce 499) ((T_IS_NOT_EQUAL) reduce 499) ((T_IS_NOT_IDENTICAL) reduce 499) ((T_IS_SMALLER_OR_EQUAL) reduce 499) ((T_LOGICAL_AND) reduce 499) ((T_LOGICAL_OR) reduce 499) ((T_LOGICAL_XOR) reduce 499) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 499) ((T_OBJECT_OPERATOR) reduce 499) ((T_POW) reduce 499) ((T_SL) reduce 499) ((T_SPACESHIP) reduce 499) ((T_SR) reduce 499) (("[") reduce 499) (("^") reduce 499) (("{") reduce 499) (("|") reduce 499)) 4005 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) ((",") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 93) ((T_OBJECT_OPERATOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("[") reduce 93) (("^") reduce 93) (("{") reduce 93) (("|") reduce 93)) 4006 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) ((",") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 92) ((T_OBJECT_OPERATOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("[") reduce 92) (("^") reduce 92) (("{") reduce 92) (("|") reduce 92)) 4007 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) ((",") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 94) ((T_OBJECT_OPERATOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("[") reduce 94) (("^") reduce 94) (("{") reduce 94) (("|") reduce 94)) 4009 ((("%") reduce 501) (("*") reduce 501) (("+") reduce 501) ((",") reduce 501) (("-") reduce 501) ((".") reduce 501) (("/") reduce 501) (("<") reduce 501) ((">") reduce 501) (("?") reduce 501) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_BOOLEAN_AND) reduce 501) ((T_BOOLEAN_OR) reduce 501) ((T_COALESCE) reduce 501) ((T_DOUBLE_ARROW) reduce 501) ((T_INSTANCEOF) reduce 501) ((T_IS_EQUAL) reduce 501) ((T_IS_GREATER_OR_EQUAL) reduce 501) ((T_IS_IDENTICAL) reduce 501) ((T_IS_NOT_EQUAL) reduce 501) ((T_IS_NOT_IDENTICAL) reduce 501) ((T_IS_SMALLER_OR_EQUAL) reduce 501) ((T_LOGICAL_AND) reduce 501) ((T_LOGICAL_OR) reduce 501) ((T_LOGICAL_XOR) reduce 501) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 501) ((T_OBJECT_OPERATOR) reduce 501) ((T_POW) reduce 501) ((T_SL) reduce 501) ((T_SPACESHIP) reduce 501) ((T_SR) reduce 501) (("[") reduce 501) (("^") reduce 501) (("{") reduce 501) (("|") reduce 501)) 4017 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) ((",") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 91) ((T_OBJECT_OPERATOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("[") reduce 91) (("^") reduce 91) (("{") reduce 91) (("|") reduce 91)) 4020 ((("%") reduce 498) (("*") reduce 498) (("+") reduce 498) ((",") reduce 498) (("-") reduce 498) ((".") reduce 498) (("/") reduce 498) (("<") reduce 498) ((">") reduce 498) (("?") reduce 498) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_BOOLEAN_AND) reduce 498) ((T_BOOLEAN_OR) reduce 498) ((T_COALESCE) reduce 498) ((T_DOUBLE_ARROW) reduce 498) ((T_INSTANCEOF) reduce 498) ((T_IS_EQUAL) reduce 498) ((T_IS_GREATER_OR_EQUAL) reduce 498) ((T_IS_IDENTICAL) reduce 498) ((T_IS_NOT_EQUAL) reduce 498) ((T_IS_NOT_IDENTICAL) reduce 498) ((T_IS_SMALLER_OR_EQUAL) reduce 498) ((T_LOGICAL_AND) reduce 498) ((T_LOGICAL_OR) reduce 498) ((T_LOGICAL_XOR) reduce 498) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 498) ((T_OBJECT_OPERATOR) reduce 498) ((T_POW) reduce 498) ((T_SL) reduce 498) ((T_SPACESHIP) reduce 498) ((T_SR) reduce 498) (("[") reduce 498) (("^") reduce 498) (("{") reduce 498) (("|") reduce 498)) 4022 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) ((",") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) (("=") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AND_EQUAL) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_COALESCE_EQUAL) reduce 529) ((T_CONCAT_EQUAL) reduce 529) ((T_DEC) reduce 529) ((T_DIV_EQUAL) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INC) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_MINUS_EQUAL) reduce 529) ((T_MOD_EQUAL) reduce 529) ((T_MUL_EQUAL) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_OR_EQUAL) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_PLUS_EQUAL) reduce 529) ((T_POW) reduce 529) ((T_POW_EQUAL) reduce 529) ((T_SL) reduce 529) ((T_SL_EQUAL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) ((T_SR_EQUAL) reduce 529) ((T_XOR_EQUAL) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 4023 ((("!") shift) (("\"") shift) (("$") shift) (("%") reduce 440) (("(") shift) (("*") reduce 440) (("+") shift) ((",") reduce 440) (("-") shift) ((".") reduce 440) (("/") reduce 440) (("<") reduce 440) ((">") reduce 440) (("?") reduce 440) (("@") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOLEAN_AND) reduce 440) ((T_BOOLEAN_OR) reduce 440) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_COALESCE) reduce 440) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_ARROW) reduce 440) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INSTANCEOF) reduce 440) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_IS_EQUAL) reduce 440) ((T_IS_GREATER_OR_EQUAL) reduce 440) ((T_IS_IDENTICAL) reduce 440) ((T_IS_NOT_EQUAL) reduce 440) ((T_IS_NOT_IDENTICAL) reduce 440) ((T_IS_SMALLER_OR_EQUAL) reduce 440) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_LOGICAL_AND) reduce 440) ((T_LOGICAL_OR) reduce 440) ((T_LOGICAL_XOR) reduce 440) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_POW) reduce 440) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_SL) reduce 440) ((T_SPACESHIP) reduce 440) ((T_SR) reduce 440) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("^") reduce 440) (("`") shift) (("|") reduce 440) (("~") shift)) 4030 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) ((",") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) (("<") reduce 525) (("=") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AND_EQUAL) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_COALESCE_EQUAL) reduce 525) ((T_CONCAT_EQUAL) reduce 525) ((T_DEC) reduce 525) ((T_DIV_EQUAL) reduce 525) ((T_DOUBLE_ARROW) reduce 525) ((T_INC) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_MINUS_EQUAL) reduce 525) ((T_MOD_EQUAL) reduce 525) ((T_MUL_EQUAL) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_OR_EQUAL) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_PLUS_EQUAL) reduce 525) ((T_POW) reduce 525) ((T_POW_EQUAL) reduce 525) ((T_SL) reduce 525) ((T_SL_EQUAL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) ((T_SR_EQUAL) reduce 525) ((T_XOR_EQUAL) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 4031 ((("%") reduce 493) (("*") reduce 493) (("+") reduce 493) ((",") reduce 493) (("-") reduce 493) ((".") reduce 493) (("/") reduce 493) (("<") reduce 493) ((">") reduce 493) (("?") reduce 493) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_BOOLEAN_AND) reduce 493) ((T_BOOLEAN_OR) reduce 493) ((T_COALESCE) reduce 493) ((T_DOUBLE_ARROW) reduce 493) ((T_INSTANCEOF) reduce 493) ((T_IS_EQUAL) reduce 493) ((T_IS_GREATER_OR_EQUAL) reduce 493) ((T_IS_IDENTICAL) reduce 493) ((T_IS_NOT_EQUAL) reduce 493) ((T_IS_NOT_IDENTICAL) reduce 493) ((T_IS_SMALLER_OR_EQUAL) reduce 493) ((T_LOGICAL_AND) reduce 493) ((T_LOGICAL_OR) reduce 493) ((T_LOGICAL_XOR) reduce 493) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 513) ((T_OBJECT_OPERATOR) reduce 513) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 513) ((T_POW) reduce 493) ((T_SL) reduce 493) ((T_SPACESHIP) reduce 493) ((T_SR) reduce 493) (("[") reduce 513) (("^") reduce 493) (("{") reduce 513) (("|") reduce 493)) 4033 ((("%") reduce 492) (("*") reduce 492) (("+") reduce 492) ((",") reduce 492) (("-") reduce 492) ((".") reduce 492) (("/") reduce 492) (("<") reduce 492) ((">") reduce 492) (("?") reduce 492) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_BOOLEAN_AND) reduce 492) ((T_BOOLEAN_OR) reduce 492) ((T_COALESCE) reduce 492) ((T_DOUBLE_ARROW) reduce 492) ((T_INSTANCEOF) reduce 492) ((T_IS_EQUAL) reduce 492) ((T_IS_GREATER_OR_EQUAL) reduce 492) ((T_IS_IDENTICAL) reduce 492) ((T_IS_NOT_EQUAL) reduce 492) ((T_IS_NOT_IDENTICAL) reduce 492) ((T_IS_SMALLER_OR_EQUAL) reduce 492) ((T_LOGICAL_AND) reduce 492) ((T_LOGICAL_OR) reduce 492) ((T_LOGICAL_XOR) reduce 492) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 515) ((T_OBJECT_OPERATOR) reduce 515) ((T_POW) reduce 492) ((T_SL) reduce 492) ((T_SPACESHIP) reduce 492) ((T_SR) reduce 492) (("[") reduce 515) (("^") reduce 492) (("{") reduce 515) (("|") reduce 492)) 4034 ((("%") reduce 491) (("(") reduce 518) (("*") reduce 491) (("+") reduce 491) ((",") reduce 491) (("-") reduce 491) ((".") reduce 491) (("/") reduce 491) (("<") reduce 491) ((">") reduce 491) (("?") reduce 491) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_BOOLEAN_AND) reduce 491) ((T_BOOLEAN_OR) reduce 491) ((T_COALESCE) reduce 491) ((T_DOUBLE_ARROW) reduce 491) ((T_INSTANCEOF) reduce 491) ((T_IS_EQUAL) reduce 491) ((T_IS_GREATER_OR_EQUAL) reduce 491) ((T_IS_IDENTICAL) reduce 491) ((T_IS_NOT_EQUAL) reduce 491) ((T_IS_NOT_IDENTICAL) reduce 491) ((T_IS_SMALLER_OR_EQUAL) reduce 491) ((T_LOGICAL_AND) reduce 491) ((T_LOGICAL_OR) reduce 491) ((T_LOGICAL_XOR) reduce 491) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 512) ((T_OBJECT_OPERATOR) reduce 512) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 512) ((T_POW) reduce 491) ((T_SL) reduce 491) ((T_SPACESHIP) reduce 491) ((T_SR) reduce 491) (("[") reduce 512) (("^") reduce 491) (("{") reduce 512) (("|") reduce 491)) 4035 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 237) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 237) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 4038 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) ((",") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) (("<") reduce 524) (("=") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AND_EQUAL) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_COALESCE_EQUAL) reduce 524) ((T_CONCAT_EQUAL) reduce 524) ((T_DEC) reduce 524) ((T_DIV_EQUAL) reduce 524) ((T_DOUBLE_ARROW) reduce 524) ((T_INC) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_MINUS_EQUAL) reduce 524) ((T_MOD_EQUAL) reduce 524) ((T_MUL_EQUAL) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_OR_EQUAL) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_PLUS_EQUAL) reduce 524) ((T_POW) reduce 524) ((T_POW_EQUAL) reduce 524) ((T_SL) reduce 524) ((T_SL_EQUAL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) ((T_SR_EQUAL) reduce 524) ((T_XOR_EQUAL) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 4039 ((("%") reduce 445) (("*") reduce 445) (("+") reduce 445) ((",") reduce 445) (("-") reduce 445) ((".") reduce 445) (("/") reduce 445) (("<") reduce 445) ((">") reduce 445) (("?") reduce 445) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_BOOLEAN_AND) reduce 445) ((T_BOOLEAN_OR) reduce 445) ((T_COALESCE) reduce 445) ((T_DOUBLE_ARROW) reduce 445) ((T_INSTANCEOF) reduce 445) ((T_IS_EQUAL) reduce 445) ((T_IS_GREATER_OR_EQUAL) reduce 445) ((T_IS_IDENTICAL) reduce 445) ((T_IS_NOT_EQUAL) reduce 445) ((T_IS_NOT_IDENTICAL) reduce 445) ((T_IS_SMALLER_OR_EQUAL) reduce 445) ((T_LOGICAL_AND) reduce 445) ((T_LOGICAL_OR) reduce 445) ((T_LOGICAL_XOR) reduce 445) ((T_POW) reduce 445) ((T_SL) reduce 445) ((T_SPACESHIP) reduce 445) ((T_SR) reduce 445) (("^") reduce 445) (("|") reduce 445)) 4040 ((("%") reduce 427) (("*") reduce 427) (("+") reduce 427) ((",") reduce 427) (("-") reduce 427) ((".") reduce 427) (("/") reduce 427) (("<") reduce 427) ((">") reduce 427) (("?") reduce 427) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_BOOLEAN_AND) reduce 427) ((T_BOOLEAN_OR) reduce 427) ((T_COALESCE) reduce 427) ((T_DOUBLE_ARROW) reduce 427) ((T_INSTANCEOF) reduce 427) ((T_IS_EQUAL) reduce 427) ((T_IS_GREATER_OR_EQUAL) reduce 427) ((T_IS_IDENTICAL) reduce 427) ((T_IS_NOT_EQUAL) reduce 427) ((T_IS_NOT_IDENTICAL) reduce 427) ((T_IS_SMALLER_OR_EQUAL) reduce 427) ((T_LOGICAL_AND) reduce 427) ((T_LOGICAL_OR) reduce 427) ((T_LOGICAL_XOR) reduce 427) ((T_POW) reduce 427) ((T_SL) reduce 427) ((T_SPACESHIP) reduce 427) ((T_SR) reduce 427) (("^") reduce 427) (("|") reduce 427)) 4041 ((("%") reduce 449) (("*") reduce 449) (("+") reduce 449) ((",") reduce 449) (("-") reduce 449) ((".") reduce 449) (("/") reduce 449) (("<") reduce 449) ((">") reduce 449) (("?") reduce 449) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_BOOLEAN_AND) reduce 449) ((T_BOOLEAN_OR) reduce 449) ((T_COALESCE) reduce 449) ((T_DOUBLE_ARROW) reduce 449) ((T_INSTANCEOF) reduce 449) ((T_IS_EQUAL) reduce 449) ((T_IS_GREATER_OR_EQUAL) reduce 449) ((T_IS_IDENTICAL) reduce 449) ((T_IS_NOT_EQUAL) reduce 449) ((T_IS_NOT_IDENTICAL) reduce 449) ((T_IS_SMALLER_OR_EQUAL) reduce 449) ((T_LOGICAL_AND) reduce 449) ((T_LOGICAL_OR) reduce 449) ((T_LOGICAL_XOR) reduce 449) ((T_POW) reduce 449) ((T_SL) reduce 449) ((T_SPACESHIP) reduce 449) ((T_SR) reduce 449) (("^") reduce 449) (("|") reduce 449)) 4042 (((",") reduce 233) (("}") reduce 233)) 4045 ((("%") reduce 494) (("(") shift) (("*") reduce 494) (("+") reduce 494) ((",") reduce 494) (("-") reduce 494) ((".") reduce 494) (("/") reduce 494) (("<") reduce 494) ((">") reduce 494) (("?") reduce 494) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_BOOLEAN_AND) reduce 494) ((T_BOOLEAN_OR) reduce 494) ((T_COALESCE) reduce 494) ((T_DOUBLE_ARROW) reduce 494) ((T_INSTANCEOF) reduce 494) ((T_IS_EQUAL) reduce 494) ((T_IS_GREATER_OR_EQUAL) reduce 494) ((T_IS_IDENTICAL) reduce 494) ((T_IS_NOT_EQUAL) reduce 494) ((T_IS_NOT_IDENTICAL) reduce 494) ((T_IS_SMALLER_OR_EQUAL) reduce 494) ((T_LOGICAL_AND) reduce 494) ((T_LOGICAL_OR) reduce 494) ((T_LOGICAL_XOR) reduce 494) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 494) ((T_OBJECT_OPERATOR) reduce 494) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 494) ((T_SL) reduce 494) ((T_SPACESHIP) reduce 494) ((T_SR) reduce 494) (("[") reduce 494) (("^") reduce 494) (("{") reduce 494) (("|") reduce 494)) 4046 ((("%") reduce 423) (("*") reduce 423) (("+") reduce 423) ((",") reduce 423) (("-") reduce 423) ((".") reduce 423) (("/") reduce 423) (("<") reduce 423) ((">") reduce 423) (("?") reduce 423) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_BOOLEAN_AND) reduce 423) ((T_BOOLEAN_OR) reduce 423) ((T_COALESCE) reduce 423) ((T_DOUBLE_ARROW) reduce 423) ((T_INSTANCEOF) reduce 423) ((T_IS_EQUAL) reduce 423) ((T_IS_GREATER_OR_EQUAL) reduce 423) ((T_IS_IDENTICAL) reduce 423) ((T_IS_NOT_EQUAL) reduce 423) ((T_IS_NOT_IDENTICAL) reduce 423) ((T_IS_SMALLER_OR_EQUAL) reduce 423) ((T_LOGICAL_AND) reduce 423) ((T_LOGICAL_OR) reduce 423) ((T_LOGICAL_XOR) reduce 423) ((T_POW) reduce 423) ((T_SL) reduce 423) ((T_SPACESHIP) reduce 423) ((T_SR) reduce 423) (("^") reduce 423) (("|") reduce 423)) 4047 (((",") shift) (("}") reduce 123)) 4048 ((("%") reduce 437) (("*") reduce 437) (("+") reduce 437) ((",") reduce 437) (("-") reduce 437) ((".") reduce 437) (("/") reduce 437) (("<") reduce 437) ((">") reduce 437) (("?") reduce 437) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_BOOLEAN_AND) reduce 437) ((T_BOOLEAN_OR) reduce 437) ((T_COALESCE) reduce 437) ((T_DOUBLE_ARROW) reduce 437) ((T_INSTANCEOF) reduce 437) ((T_IS_EQUAL) reduce 437) ((T_IS_GREATER_OR_EQUAL) reduce 437) ((T_IS_IDENTICAL) reduce 437) ((T_IS_NOT_EQUAL) reduce 437) ((T_IS_NOT_IDENTICAL) reduce 437) ((T_IS_SMALLER_OR_EQUAL) reduce 437) ((T_LOGICAL_AND) reduce 437) ((T_LOGICAL_OR) reduce 437) ((T_LOGICAL_XOR) reduce 437) ((T_POW) reduce 437) ((T_SL) reduce 437) ((T_SPACESHIP) reduce 437) ((T_SR) reduce 437) (("^") reduce 437) (("|") reduce 437)) 4049 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) ((",") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) (("<") reduce 519) (("=") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AND_EQUAL) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_COALESCE_EQUAL) reduce 519) ((T_CONCAT_EQUAL) reduce 519) ((T_DEC) reduce 519) ((T_DIV_EQUAL) reduce 519) ((T_DOUBLE_ARROW) reduce 519) ((T_INC) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_MINUS_EQUAL) reduce 519) ((T_MOD_EQUAL) reduce 519) ((T_MUL_EQUAL) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_OR_EQUAL) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_PLUS_EQUAL) reduce 519) ((T_POW) reduce 519) ((T_POW_EQUAL) reduce 519) ((T_SL) reduce 519) ((T_SL_EQUAL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) ((T_SR_EQUAL) reduce 519) ((T_XOR_EQUAL) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 4050 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) ((",") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) (("<") reduce 526) (("=") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AND_EQUAL) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_COALESCE_EQUAL) reduce 526) ((T_CONCAT_EQUAL) reduce 526) ((T_DEC) reduce 526) ((T_DIV_EQUAL) reduce 526) ((T_DOUBLE_ARROW) reduce 526) ((T_INC) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_MINUS_EQUAL) reduce 526) ((T_MOD_EQUAL) reduce 526) ((T_MUL_EQUAL) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_OR_EQUAL) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_PLUS_EQUAL) reduce 526) ((T_POW) reduce 526) ((T_POW_EQUAL) reduce 526) ((T_SL) reduce 526) ((T_SL_EQUAL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) ((T_SR_EQUAL) reduce 526) ((T_XOR_EQUAL) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 4051 ((("%") reduce 367) (("*") reduce 367) (("+") reduce 367) ((",") reduce 367) (("-") reduce 367) ((".") reduce 367) (("/") reduce 367) (("<") reduce 367) (("=") shift) ((">") reduce 367) (("?") reduce 367) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AND_EQUAL) shift) ((T_BOOLEAN_AND) reduce 367) ((T_BOOLEAN_OR) reduce 367) ((T_COALESCE) reduce 367) ((T_COALESCE_EQUAL) shift) ((T_CONCAT_EQUAL) shift) ((T_DEC) shift) ((T_DIV_EQUAL) shift) ((T_DOUBLE_ARROW) reduce 367) ((T_INC) shift) ((T_INSTANCEOF) reduce 367) ((T_IS_EQUAL) reduce 367) ((T_IS_GREATER_OR_EQUAL) reduce 367) ((T_IS_IDENTICAL) reduce 367) ((T_IS_NOT_EQUAL) reduce 367) ((T_IS_NOT_IDENTICAL) reduce 367) ((T_IS_SMALLER_OR_EQUAL) reduce 367) ((T_LOGICAL_AND) reduce 367) ((T_LOGICAL_OR) reduce 367) ((T_LOGICAL_XOR) reduce 367) ((T_MINUS_EQUAL) shift) ((T_MOD_EQUAL) shift) ((T_MUL_EQUAL) shift) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_OR_EQUAL) shift) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_PLUS_EQUAL) shift) ((T_POW) reduce 367) ((T_POW_EQUAL) shift) ((T_SL) reduce 367) ((T_SL_EQUAL) shift) ((T_SPACESHIP) reduce 367) ((T_SR) reduce 367) ((T_SR_EQUAL) shift) ((T_XOR_EQUAL) shift) (("[") reduce 510) (("^") reduce 367) (("{") reduce 510) (("|") reduce 367)) 4054 ((("%") reduce 411) (("*") reduce 411) (("+") reduce 411) ((",") reduce 411) (("-") reduce 411) ((".") reduce 411) (("/") reduce 411) (("<") reduce 411) ((">") reduce 411) (("?") reduce 411) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_BOOLEAN_AND) reduce 411) ((T_BOOLEAN_OR) reduce 411) ((T_COALESCE) reduce 411) ((T_DOUBLE_ARROW) reduce 411) ((T_INSTANCEOF) reduce 411) ((T_IS_EQUAL) reduce 411) ((T_IS_GREATER_OR_EQUAL) reduce 411) ((T_IS_IDENTICAL) reduce 411) ((T_IS_NOT_EQUAL) reduce 411) ((T_IS_NOT_IDENTICAL) reduce 411) ((T_IS_SMALLER_OR_EQUAL) reduce 411) ((T_LOGICAL_AND) reduce 411) ((T_LOGICAL_OR) reduce 411) ((T_LOGICAL_XOR) reduce 411) ((T_POW) shift) ((T_SL) reduce 411) ((T_SPACESHIP) reduce 411) ((T_SR) reduce 411) (("^") reduce 411) (("|") reduce 411)) 4085 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 395) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 395) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 395) ((T_BOOLEAN_OR) reduce 395) ((T_COALESCE) reduce 395) ((T_DOUBLE_ARROW) reduce 395) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 395) ((T_LOGICAL_OR) reduce 395) ((T_LOGICAL_XOR) reduce 395) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") reduce 395)) 4086 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 398) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 398) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 398) ((T_BOOLEAN_OR) reduce 398) ((T_COALESCE) reduce 398) ((T_DOUBLE_ARROW) reduce 398) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 398) ((T_LOGICAL_OR) reduce 398) ((T_LOGICAL_XOR) reduce 398) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 398) (("|") reduce 398)) 4087 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 407) (("-") shift) ((".") reduce 407) (("/") shift) (("<") reduce 407) ((">") reduce 407) (("?") reduce 407) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_BOOLEAN_AND) reduce 407) ((T_BOOLEAN_OR) reduce 407) ((T_COALESCE) reduce 407) ((T_DOUBLE_ARROW) reduce 407) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 407) ((T_IS_GREATER_OR_EQUAL) reduce 407) ((T_IS_IDENTICAL) reduce 407) ((T_IS_NOT_EQUAL) reduce 407) ((T_IS_NOT_IDENTICAL) reduce 407) ((T_IS_SMALLER_OR_EQUAL) reduce 407) ((T_LOGICAL_AND) reduce 407) ((T_LOGICAL_OR) reduce 407) ((T_LOGICAL_XOR) reduce 407) ((T_POW) shift) ((T_SL) reduce 407) ((T_SPACESHIP) reduce 407) ((T_SR) reduce 407) (("^") reduce 407) (("|") reduce 407)) 4088 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 420) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 420) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_BOOLEAN_AND) reduce 420) ((T_BOOLEAN_OR) reduce 420) ((T_COALESCE) reduce 420) ((T_DOUBLE_ARROW) reduce 420) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 420) ((T_LOGICAL_OR) reduce 420) ((T_LOGICAL_XOR) reduce 420) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 420) (("|") reduce 420)) 4089 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 406) (("-") shift) ((".") reduce 406) (("/") shift) (("<") reduce 406) ((">") reduce 406) (("?") reduce 406) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_BOOLEAN_AND) reduce 406) ((T_BOOLEAN_OR) reduce 406) ((T_COALESCE) reduce 406) ((T_DOUBLE_ARROW) reduce 406) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 406) ((T_IS_GREATER_OR_EQUAL) reduce 406) ((T_IS_IDENTICAL) reduce 406) ((T_IS_NOT_EQUAL) reduce 406) ((T_IS_NOT_IDENTICAL) reduce 406) ((T_IS_SMALLER_OR_EQUAL) reduce 406) ((T_LOGICAL_AND) reduce 406) ((T_LOGICAL_OR) reduce 406) ((T_LOGICAL_XOR) reduce 406) ((T_POW) shift) ((T_SL) reduce 406) ((T_SPACESHIP) reduce 406) ((T_SR) reduce 406) (("^") reduce 406) (("|") reduce 406)) 4090 ((("%") reduce 403) (("*") reduce 403) (("+") reduce 403) ((",") reduce 403) (("-") reduce 403) ((".") reduce 403) (("/") reduce 403) (("<") reduce 403) ((">") reduce 403) (("?") reduce 403) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_BOOLEAN_AND) reduce 403) ((T_BOOLEAN_OR) reduce 403) ((T_COALESCE) reduce 403) ((T_DOUBLE_ARROW) reduce 403) ((T_INSTANCEOF) reduce 403) ((T_IS_EQUAL) reduce 403) ((T_IS_GREATER_OR_EQUAL) reduce 403) ((T_IS_IDENTICAL) reduce 403) ((T_IS_NOT_EQUAL) reduce 403) ((T_IS_NOT_IDENTICAL) reduce 403) ((T_IS_SMALLER_OR_EQUAL) reduce 403) ((T_LOGICAL_AND) reduce 403) ((T_LOGICAL_OR) reduce 403) ((T_LOGICAL_XOR) reduce 403) ((T_POW) shift) ((T_SL) reduce 403) ((T_SPACESHIP) reduce 403) ((T_SR) reduce 403) (("^") reduce 403) (("|") reduce 403)) 4091 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 394) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 394) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 394) ((T_LOGICAL_XOR) reduce 394) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 4092 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 392) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 392) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 392) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 4093 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 393) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 393) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 393) ((T_LOGICAL_OR) reduce 393) ((T_LOGICAL_XOR) reduce 393) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 4094 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 417) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 417) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_BOOLEAN_AND) reduce 417) ((T_BOOLEAN_OR) reduce 417) ((T_COALESCE) reduce 417) ((T_DOUBLE_ARROW) reduce 417) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 417) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 417) ((T_IS_NOT_EQUAL) reduce 417) ((T_IS_NOT_IDENTICAL) reduce 417) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 417) ((T_LOGICAL_OR) reduce 417) ((T_LOGICAL_XOR) reduce 417) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 417) ((T_SR) shift) (("^") reduce 417) (("|") reduce 417)) 4095 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 413) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 413) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_BOOLEAN_AND) reduce 413) ((T_BOOLEAN_OR) reduce 413) ((T_COALESCE) reduce 413) ((T_DOUBLE_ARROW) reduce 413) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 413) ((T_LOGICAL_OR) reduce 413) ((T_LOGICAL_XOR) reduce 413) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 413) (("|") reduce 413)) 4096 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 415) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 415) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_BOOLEAN_AND) reduce 415) ((T_BOOLEAN_OR) reduce 415) ((T_COALESCE) reduce 415) ((T_DOUBLE_ARROW) reduce 415) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 415) ((T_LOGICAL_OR) reduce 415) ((T_LOGICAL_XOR) reduce 415) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 415) (("|") reduce 415)) 4097 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 412) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 412) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_BOOLEAN_AND) reduce 412) ((T_BOOLEAN_OR) reduce 412) ((T_COALESCE) reduce 412) ((T_DOUBLE_ARROW) reduce 412) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 412) ((T_LOGICAL_OR) reduce 412) ((T_LOGICAL_XOR) reduce 412) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 412) (("|") reduce 412)) 4098 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 419) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 419) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_BOOLEAN_AND) reduce 419) ((T_BOOLEAN_OR) reduce 419) ((T_COALESCE) reduce 419) ((T_DOUBLE_ARROW) reduce 419) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 419) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 419) ((T_IS_NOT_EQUAL) reduce 419) ((T_IS_NOT_IDENTICAL) reduce 419) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 419) ((T_LOGICAL_OR) reduce 419) ((T_LOGICAL_XOR) reduce 419) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 419) ((T_SR) shift) (("^") reduce 419) (("|") reduce 419)) 4099 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 414) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 414) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_BOOLEAN_AND) reduce 414) ((T_BOOLEAN_OR) reduce 414) ((T_COALESCE) reduce 414) ((T_DOUBLE_ARROW) reduce 414) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 414) ((T_LOGICAL_OR) reduce 414) ((T_LOGICAL_XOR) reduce 414) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 414) (("|") reduce 414)) 4102 ((("%") reduce 93) (("*") reduce 93) (("+") reduce 93) ((",") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93)) 4103 ((("%") reduce 92) (("*") reduce 92) (("+") reduce 92) ((",") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92)) 4104 ((("%") reduce 94) (("*") reduce 94) (("+") reduce 94) ((",") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94)) 4105 ((("%") reduce 470) (("*") reduce 470) (("+") reduce 470) ((",") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_DOUBLE_ARROW) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470)) 4106 ((("%") reduce 91) (("*") reduce 91) (("+") reduce 91) ((",") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91)) 4107 ((("%") reduce 529) (("*") reduce 529) (("+") reduce 529) ((",") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 4108 ((("%") reduce 472) (("*") reduce 472) (("+") reduce 472) ((",") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_DOUBLE_ARROW) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472)) 4109 ((("%") reduce 421) (("*") reduce 421) (("+") reduce 421) ((",") reduce 421) (("-") reduce 421) ((".") reduce 421) (("/") reduce 421) (("<") reduce 421) ((">") reduce 421) (("?") reduce 421) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_BOOLEAN_AND) reduce 421) ((T_BOOLEAN_OR) reduce 421) ((T_COALESCE) reduce 421) ((T_DOUBLE_ARROW) reduce 421) ((T_INSTANCEOF) reduce 421) ((T_IS_EQUAL) reduce 421) ((T_IS_GREATER_OR_EQUAL) reduce 421) ((T_IS_IDENTICAL) reduce 421) ((T_IS_NOT_EQUAL) reduce 421) ((T_IS_NOT_IDENTICAL) reduce 421) ((T_IS_SMALLER_OR_EQUAL) reduce 421) ((T_LOGICAL_AND) reduce 421) ((T_LOGICAL_OR) reduce 421) ((T_LOGICAL_XOR) reduce 421) ((T_POW) reduce 421) ((T_SL) reduce 421) ((T_SPACESHIP) reduce 421) ((T_SR) reduce 421) (("^") reduce 421) (("|") reduce 421)) 4110 ((("%") reduce 471) (("*") reduce 471) (("+") reduce 471) ((",") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_DOUBLE_ARROW) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471)) 4111 ((("%") reduce 473) (("*") reduce 473) (("+") reduce 473) ((",") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_DOUBLE_ARROW) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 4112 ((("%") reduce 534) (("*") reduce 534) (("+") reduce 534) ((",") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_DOUBLE_ARROW) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 4119 ((("%") reduce 536) (("*") reduce 536) (("+") reduce 536) ((",") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_DOUBLE_ARROW) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 4121 ((("%") reduce 535) (("*") reduce 535) (("+") reduce 535) ((",") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_DOUBLE_ARROW) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 4122 ((("%") reduce 540) (("*") reduce 540) (("+") reduce 540) ((",") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_DOUBLE_ARROW) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 4123 ((("%") reduce 544) (("*") reduce 544) (("+") reduce 544) ((",") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 4124 ((("%") reduce 537) (("*") reduce 537) (("+") reduce 537) ((",") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_DOUBLE_ARROW) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 4125 ((("%") reduce 546) (("*") reduce 546) (("+") reduce 546) ((",") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 4128 ((("%") reduce 545) (("*") reduce 545) (("+") reduce 545) ((",") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 4129 ((("%") reduce 538) (("*") reduce 538) (("+") reduce 538) ((",") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_DOUBLE_ARROW) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 4131 ((("%") reduce 539) (("*") reduce 539) (("+") reduce 539) ((",") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_DOUBLE_ARROW) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 4133 ((("%") reduce 474) (("*") reduce 474) (("+") reduce 474) ((",") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_DOUBLE_ARROW) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474)) 4134 ((("%") reduce 531) (("*") reduce 531) (("+") reduce 531) ((",") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 4137 ((("%") reduce 530) (("*") reduce 530) (("+") reduce 530) ((",") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 4138 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 426) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 426) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 426) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 426) ((T_LOGICAL_OR) reduce 426) ((T_LOGICAL_XOR) reduce 426) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 4139 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 390) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 390) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) reduce 390) ((T_COALESCE) reduce 390) ((T_DOUBLE_ARROW) reduce 390) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 390) ((T_LOGICAL_OR) reduce 390) ((T_LOGICAL_XOR) reduce 390) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 4140 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 391) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 391) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 391) ((T_BOOLEAN_OR) reduce 391) ((T_COALESCE) reduce 391) ((T_DOUBLE_ARROW) reduce 391) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 391) ((T_LOGICAL_OR) reduce 391) ((T_LOGICAL_XOR) reduce 391) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 4141 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 396) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 396) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_BOOLEAN_AND) reduce 396) ((T_BOOLEAN_OR) reduce 396) ((T_COALESCE) reduce 396) ((T_DOUBLE_ARROW) reduce 396) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 396) ((T_LOGICAL_OR) reduce 396) ((T_LOGICAL_XOR) reduce 396) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 396) (("|") reduce 396)) 4142 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 397) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 397) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_BOOLEAN_AND) reduce 397) ((T_BOOLEAN_OR) reduce 397) ((T_COALESCE) reduce 397) ((T_DOUBLE_ARROW) reduce 397) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 397) ((T_LOGICAL_OR) reduce 397) ((T_LOGICAL_XOR) reduce 397) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 397) (("|") reduce 397)) 4146 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 424) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 424) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 424) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 424) ((T_LOGICAL_OR) reduce 424) ((T_LOGICAL_XOR) reduce 424) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 4147 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 425) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 425) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 425) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 425) ((T_LOGICAL_OR) reduce 425) ((T_LOGICAL_XOR) reduce 425) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 4148 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 418) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 418) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_BOOLEAN_AND) reduce 418) ((T_BOOLEAN_OR) reduce 418) ((T_COALESCE) reduce 418) ((T_DOUBLE_ARROW) reduce 418) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 418) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 418) ((T_IS_NOT_EQUAL) reduce 418) ((T_IS_NOT_IDENTICAL) reduce 418) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 418) ((T_LOGICAL_OR) reduce 418) ((T_LOGICAL_XOR) reduce 418) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 418) ((T_SR) shift) (("^") reduce 418) (("|") reduce 418)) 4149 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 416) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 416) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_BOOLEAN_AND) reduce 416) ((T_BOOLEAN_OR) reduce 416) ((T_COALESCE) reduce 416) ((T_DOUBLE_ARROW) reduce 416) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 416) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 416) ((T_IS_NOT_EQUAL) reduce 416) ((T_IS_NOT_IDENTICAL) reduce 416) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 416) ((T_LOGICAL_OR) reduce 416) ((T_LOGICAL_XOR) reduce 416) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 416) ((T_SR) shift) (("^") reduce 416) (("|") reduce 416)) 4150 ((("%") reduce 404) (("*") reduce 404) (("+") reduce 404) ((",") reduce 404) (("-") reduce 404) ((".") reduce 404) (("/") reduce 404) (("<") reduce 404) ((">") reduce 404) (("?") reduce 404) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_BOOLEAN_AND) reduce 404) ((T_BOOLEAN_OR) reduce 404) ((T_COALESCE) reduce 404) ((T_DOUBLE_ARROW) reduce 404) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 404) ((T_IS_GREATER_OR_EQUAL) reduce 404) ((T_IS_IDENTICAL) reduce 404) ((T_IS_NOT_EQUAL) reduce 404) ((T_IS_NOT_IDENTICAL) reduce 404) ((T_IS_SMALLER_OR_EQUAL) reduce 404) ((T_LOGICAL_AND) reduce 404) ((T_LOGICAL_OR) reduce 404) ((T_LOGICAL_XOR) reduce 404) ((T_POW) shift) ((T_SL) reduce 404) ((T_SPACESHIP) reduce 404) ((T_SR) reduce 404) (("^") reduce 404) (("|") reduce 404)) 4151 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 399) (("-") shift) ((".") reduce 399) (("/") shift) (("<") reduce 399) ((">") reduce 399) (("?") reduce 399) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_BOOLEAN_AND) reduce 399) ((T_BOOLEAN_OR) reduce 399) ((T_COALESCE) reduce 399) ((T_DOUBLE_ARROW) reduce 399) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 399) ((T_IS_GREATER_OR_EQUAL) reduce 399) ((T_IS_IDENTICAL) reduce 399) ((T_IS_NOT_EQUAL) reduce 399) ((T_IS_NOT_IDENTICAL) reduce 399) ((T_IS_SMALLER_OR_EQUAL) reduce 399) ((T_LOGICAL_AND) reduce 399) ((T_LOGICAL_OR) reduce 399) ((T_LOGICAL_XOR) reduce 399) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 399) ((T_SR) shift) (("^") reduce 399) (("|") reduce 399)) 4152 ((("%") shift) (("*") shift) (("+") reduce 401) ((",") reduce 401) (("-") reduce 401) ((".") reduce 401) (("/") shift) (("<") reduce 401) ((">") reduce 401) (("?") reduce 401) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_BOOLEAN_AND) reduce 401) ((T_BOOLEAN_OR) reduce 401) ((T_COALESCE) reduce 401) ((T_DOUBLE_ARROW) reduce 401) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 401) ((T_IS_GREATER_OR_EQUAL) reduce 401) ((T_IS_IDENTICAL) reduce 401) ((T_IS_NOT_EQUAL) reduce 401) ((T_IS_NOT_IDENTICAL) reduce 401) ((T_IS_SMALLER_OR_EQUAL) reduce 401) ((T_LOGICAL_AND) reduce 401) ((T_LOGICAL_OR) reduce 401) ((T_LOGICAL_XOR) reduce 401) ((T_POW) shift) ((T_SL) reduce 401) ((T_SPACESHIP) reduce 401) ((T_SR) reduce 401) (("^") reduce 401) (("|") reduce 401)) 4153 ((("%") shift) (("*") shift) (("+") reduce 400) ((",") reduce 400) (("-") reduce 400) ((".") reduce 400) (("/") shift) (("<") reduce 400) ((">") reduce 400) (("?") reduce 400) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_BOOLEAN_AND) reduce 400) ((T_BOOLEAN_OR) reduce 400) ((T_COALESCE) reduce 400) ((T_DOUBLE_ARROW) reduce 400) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 400) ((T_IS_GREATER_OR_EQUAL) reduce 400) ((T_IS_IDENTICAL) reduce 400) ((T_IS_NOT_EQUAL) reduce 400) ((T_IS_NOT_IDENTICAL) reduce 400) ((T_IS_SMALLER_OR_EQUAL) reduce 400) ((T_LOGICAL_AND) reduce 400) ((T_LOGICAL_OR) reduce 400) ((T_LOGICAL_XOR) reduce 400) ((T_POW) shift) ((T_SL) reduce 400) ((T_SPACESHIP) reduce 400) ((T_SR) reduce 400) (("^") reduce 400) (("|") reduce 400)) 4154 ((("%") reduce 402) (("*") reduce 402) (("+") reduce 402) ((",") reduce 402) (("-") reduce 402) ((".") reduce 402) (("/") reduce 402) (("<") reduce 402) ((">") reduce 402) (("?") reduce 402) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_BOOLEAN_AND) reduce 402) ((T_BOOLEAN_OR) reduce 402) ((T_COALESCE) reduce 402) ((T_DOUBLE_ARROW) reduce 402) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 402) ((T_IS_GREATER_OR_EQUAL) reduce 402) ((T_IS_IDENTICAL) reduce 402) ((T_IS_NOT_EQUAL) reduce 402) ((T_IS_NOT_IDENTICAL) reduce 402) ((T_IS_SMALLER_OR_EQUAL) reduce 402) ((T_LOGICAL_AND) reduce 402) ((T_LOGICAL_OR) reduce 402) ((T_LOGICAL_XOR) reduce 402) ((T_POW) shift) ((T_SL) reduce 402) ((T_SPACESHIP) reduce 402) ((T_SR) reduce 402) (("^") reduce 402) (("|") reduce 402)) 4155 ((("%") reduce 405) (("*") reduce 405) (("+") reduce 405) ((",") reduce 405) (("-") reduce 405) ((".") reduce 405) (("/") reduce 405) (("<") reduce 405) ((">") reduce 405) (("?") reduce 405) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_BOOLEAN_AND) reduce 405) ((T_BOOLEAN_OR) reduce 405) ((T_COALESCE) reduce 405) ((T_DOUBLE_ARROW) reduce 405) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 405) ((T_IS_GREATER_OR_EQUAL) reduce 405) ((T_IS_IDENTICAL) reduce 405) ((T_IS_NOT_EQUAL) reduce 405) ((T_IS_NOT_IDENTICAL) reduce 405) ((T_IS_SMALLER_OR_EQUAL) reduce 405) ((T_LOGICAL_AND) reduce 405) ((T_LOGICAL_OR) reduce 405) ((T_LOGICAL_XOR) reduce 405) ((T_POW) shift) ((T_SL) reduce 405) ((T_SPACESHIP) reduce 405) ((T_SR) reduce 405) (("^") reduce 405) (("|") reduce 405)) 4157 ((("%") reduce 73) (("(") reduce 73) (("*") reduce 73) (("+") reduce 73) ((",") reduce 73) (("-") reduce 73) ((".") reduce 73) (("/") reduce 73) (("<") reduce 73) ((">") reduce 73) (("?") reduce 73) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_BOOLEAN_AND) reduce 73) ((T_BOOLEAN_OR) reduce 73) ((T_COALESCE) reduce 73) ((T_DOUBLE_ARROW) reduce 73) ((T_INSTANCEOF) reduce 73) ((T_IS_EQUAL) reduce 73) ((T_IS_GREATER_OR_EQUAL) reduce 73) ((T_IS_IDENTICAL) reduce 73) ((T_IS_NOT_EQUAL) reduce 73) ((T_IS_NOT_IDENTICAL) reduce 73) ((T_IS_SMALLER_OR_EQUAL) reduce 73) ((T_LOGICAL_AND) reduce 73) ((T_LOGICAL_OR) reduce 73) ((T_LOGICAL_XOR) reduce 73) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 73) ((T_OBJECT_OPERATOR) reduce 73) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 73) ((T_POW) reduce 73) ((T_SL) reduce 73) ((T_SPACESHIP) reduce 73) ((T_SR) reduce 73) (("[") reduce 73) (("^") reduce 73) (("{") reduce 73) (("|") reduce 73)) 4158 ((("%") reduce 52) (("(") reduce 52) (("*") reduce 52) (("+") reduce 52) ((",") reduce 52) (("-") reduce 52) ((".") reduce 52) (("/") reduce 52) (("<") reduce 52) ((">") reduce 52) (("?") reduce 52) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_BOOLEAN_AND) reduce 52) ((T_BOOLEAN_OR) reduce 52) ((T_COALESCE) reduce 52) ((T_DOUBLE_ARROW) reduce 52) ((T_INSTANCEOF) reduce 52) ((T_IS_EQUAL) reduce 52) ((T_IS_GREATER_OR_EQUAL) reduce 52) ((T_IS_IDENTICAL) reduce 52) ((T_IS_NOT_EQUAL) reduce 52) ((T_IS_NOT_IDENTICAL) reduce 52) ((T_IS_SMALLER_OR_EQUAL) reduce 52) ((T_LOGICAL_AND) reduce 52) ((T_LOGICAL_OR) reduce 52) ((T_LOGICAL_XOR) reduce 52) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 52) ((T_OBJECT_OPERATOR) reduce 52) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 52) ((T_POW) reduce 52) ((T_SL) reduce 52) ((T_SPACESHIP) reduce 52) ((T_SR) reduce 52) (("[") reduce 52) (("^") reduce 52) (("{") reduce 52) (("|") reduce 52)) 4159 ((("%") reduce 27) (("(") reduce 27) (("*") reduce 27) (("+") reduce 27) ((",") reduce 27) (("-") reduce 27) ((".") reduce 27) (("/") reduce 27) (("<") reduce 27) ((">") reduce 27) (("?") reduce 27) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_BOOLEAN_AND) reduce 27) ((T_BOOLEAN_OR) reduce 27) ((T_COALESCE) reduce 27) ((T_DOUBLE_ARROW) reduce 27) ((T_INSTANCEOF) reduce 27) ((T_IS_EQUAL) reduce 27) ((T_IS_GREATER_OR_EQUAL) reduce 27) ((T_IS_IDENTICAL) reduce 27) ((T_IS_NOT_EQUAL) reduce 27) ((T_IS_NOT_IDENTICAL) reduce 27) ((T_IS_SMALLER_OR_EQUAL) reduce 27) ((T_LOGICAL_AND) reduce 27) ((T_LOGICAL_OR) reduce 27) ((T_LOGICAL_XOR) reduce 27) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 27) ((T_OBJECT_OPERATOR) reduce 27) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 27) ((T_POW) reduce 27) ((T_SL) reduce 27) ((T_SPACESHIP) reduce 27) ((T_SR) reduce 27) (("[") reduce 27) (("^") reduce 27) (("{") reduce 27) (("|") reduce 27)) 4160 ((("%") reduce 51) (("(") reduce 51) (("*") reduce 51) (("+") reduce 51) ((",") reduce 51) (("-") reduce 51) ((".") reduce 51) (("/") reduce 51) (("<") reduce 51) ((">") reduce 51) (("?") reduce 51) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_BOOLEAN_AND) reduce 51) ((T_BOOLEAN_OR) reduce 51) ((T_COALESCE) reduce 51) ((T_DOUBLE_ARROW) reduce 51) ((T_INSTANCEOF) reduce 51) ((T_IS_EQUAL) reduce 51) ((T_IS_GREATER_OR_EQUAL) reduce 51) ((T_IS_IDENTICAL) reduce 51) ((T_IS_NOT_EQUAL) reduce 51) ((T_IS_NOT_IDENTICAL) reduce 51) ((T_IS_SMALLER_OR_EQUAL) reduce 51) ((T_LOGICAL_AND) reduce 51) ((T_LOGICAL_OR) reduce 51) ((T_LOGICAL_XOR) reduce 51) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 51) ((T_OBJECT_OPERATOR) reduce 51) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 51) ((T_POW) reduce 51) ((T_SL) reduce 51) ((T_SPACESHIP) reduce 51) ((T_SR) reduce 51) (("[") reduce 51) (("^") reduce 51) (("{") reduce 51) (("|") reduce 51)) 4161 ((("%") reduce 53) (("(") reduce 53) (("*") reduce 53) (("+") reduce 53) ((",") reduce 53) (("-") reduce 53) ((".") reduce 53) (("/") reduce 53) (("<") reduce 53) ((">") reduce 53) (("?") reduce 53) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_BOOLEAN_AND) reduce 53) ((T_BOOLEAN_OR) reduce 53) ((T_COALESCE) reduce 53) ((T_DOUBLE_ARROW) reduce 53) ((T_INSTANCEOF) reduce 53) ((T_IS_EQUAL) reduce 53) ((T_IS_GREATER_OR_EQUAL) reduce 53) ((T_IS_IDENTICAL) reduce 53) ((T_IS_NOT_EQUAL) reduce 53) ((T_IS_NOT_IDENTICAL) reduce 53) ((T_IS_SMALLER_OR_EQUAL) reduce 53) ((T_LOGICAL_AND) reduce 53) ((T_LOGICAL_OR) reduce 53) ((T_LOGICAL_XOR) reduce 53) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 53) ((T_OBJECT_OPERATOR) reduce 53) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 53) ((T_POW) reduce 53) ((T_SL) reduce 53) ((T_SPACESHIP) reduce 53) ((T_SR) reduce 53) (("[") reduce 53) (("^") reduce 53) (("{") reduce 53) (("|") reduce 53)) 4162 ((("%") reduce 49) (("(") reduce 49) (("*") reduce 49) (("+") reduce 49) ((",") reduce 49) (("-") reduce 49) ((".") reduce 49) (("/") reduce 49) (("<") reduce 49) ((">") reduce 49) (("?") reduce 49) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_BOOLEAN_AND) reduce 49) ((T_BOOLEAN_OR) reduce 49) ((T_COALESCE) reduce 49) ((T_DOUBLE_ARROW) reduce 49) ((T_INSTANCEOF) reduce 49) ((T_IS_EQUAL) reduce 49) ((T_IS_GREATER_OR_EQUAL) reduce 49) ((T_IS_IDENTICAL) reduce 49) ((T_IS_NOT_EQUAL) reduce 49) ((T_IS_NOT_IDENTICAL) reduce 49) ((T_IS_SMALLER_OR_EQUAL) reduce 49) ((T_LOGICAL_AND) reduce 49) ((T_LOGICAL_OR) reduce 49) ((T_LOGICAL_XOR) reduce 49) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 49) ((T_OBJECT_OPERATOR) reduce 49) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 49) ((T_POW) reduce 49) ((T_SL) reduce 49) ((T_SPACESHIP) reduce 49) ((T_SR) reduce 49) (("[") reduce 49) (("^") reduce 49) (("{") reduce 49) (("|") reduce 49)) 4163 ((("%") reduce 29) (("(") reduce 29) (("*") reduce 29) (("+") reduce 29) ((",") reduce 29) (("-") reduce 29) ((".") reduce 29) (("/") reduce 29) (("<") reduce 29) ((">") reduce 29) (("?") reduce 29) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_BOOLEAN_AND) reduce 29) ((T_BOOLEAN_OR) reduce 29) ((T_COALESCE) reduce 29) ((T_DOUBLE_ARROW) reduce 29) ((T_INSTANCEOF) reduce 29) ((T_IS_EQUAL) reduce 29) ((T_IS_GREATER_OR_EQUAL) reduce 29) ((T_IS_IDENTICAL) reduce 29) ((T_IS_NOT_EQUAL) reduce 29) ((T_IS_NOT_IDENTICAL) reduce 29) ((T_IS_SMALLER_OR_EQUAL) reduce 29) ((T_LOGICAL_AND) reduce 29) ((T_LOGICAL_OR) reduce 29) ((T_LOGICAL_XOR) reduce 29) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 29) ((T_OBJECT_OPERATOR) reduce 29) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 29) ((T_POW) reduce 29) ((T_SL) reduce 29) ((T_SPACESHIP) reduce 29) ((T_SR) reduce 29) (("[") reduce 29) (("^") reduce 29) (("{") reduce 29) (("|") reduce 29)) 4164 ((("%") reduce 59) (("(") reduce 59) (("*") reduce 59) (("+") reduce 59) ((",") reduce 59) (("-") reduce 59) ((".") reduce 59) (("/") reduce 59) (("<") reduce 59) ((">") reduce 59) (("?") reduce 59) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_BOOLEAN_AND) reduce 59) ((T_BOOLEAN_OR) reduce 59) ((T_COALESCE) reduce 59) ((T_DOUBLE_ARROW) reduce 59) ((T_INSTANCEOF) reduce 59) ((T_IS_EQUAL) reduce 59) ((T_IS_GREATER_OR_EQUAL) reduce 59) ((T_IS_IDENTICAL) reduce 59) ((T_IS_NOT_EQUAL) reduce 59) ((T_IS_NOT_IDENTICAL) reduce 59) ((T_IS_SMALLER_OR_EQUAL) reduce 59) ((T_LOGICAL_AND) reduce 59) ((T_LOGICAL_OR) reduce 59) ((T_LOGICAL_XOR) reduce 59) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 59) ((T_OBJECT_OPERATOR) reduce 59) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 59) ((T_POW) reduce 59) ((T_SL) reduce 59) ((T_SPACESHIP) reduce 59) ((T_SR) reduce 59) (("[") reduce 59) (("^") reduce 59) (("{") reduce 59) (("|") reduce 59)) 4165 ((("%") reduce 60) (("(") reduce 60) (("*") reduce 60) (("+") reduce 60) ((",") reduce 60) (("-") reduce 60) ((".") reduce 60) (("/") reduce 60) (("<") reduce 60) ((">") reduce 60) (("?") reduce 60) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_BOOLEAN_AND) reduce 60) ((T_BOOLEAN_OR) reduce 60) ((T_COALESCE) reduce 60) ((T_DOUBLE_ARROW) reduce 60) ((T_INSTANCEOF) reduce 60) ((T_IS_EQUAL) reduce 60) ((T_IS_GREATER_OR_EQUAL) reduce 60) ((T_IS_IDENTICAL) reduce 60) ((T_IS_NOT_EQUAL) reduce 60) ((T_IS_NOT_IDENTICAL) reduce 60) ((T_IS_SMALLER_OR_EQUAL) reduce 60) ((T_LOGICAL_AND) reduce 60) ((T_LOGICAL_OR) reduce 60) ((T_LOGICAL_XOR) reduce 60) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 60) ((T_OBJECT_OPERATOR) reduce 60) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 60) ((T_POW) reduce 60) ((T_SL) reduce 60) ((T_SPACESHIP) reduce 60) ((T_SR) reduce 60) (("[") reduce 60) (("^") reduce 60) (("{") reduce 60) (("|") reduce 60)) 4166 ((("%") reduce 11) (("(") reduce 11) (("*") reduce 11) (("+") reduce 11) ((",") reduce 11) (("-") reduce 11) ((".") reduce 11) (("/") reduce 11) (("<") reduce 11) ((">") reduce 11) (("?") reduce 11) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_BOOLEAN_AND) reduce 11) ((T_BOOLEAN_OR) reduce 11) ((T_COALESCE) reduce 11) ((T_DOUBLE_ARROW) reduce 11) ((T_INSTANCEOF) reduce 11) ((T_IS_EQUAL) reduce 11) ((T_IS_GREATER_OR_EQUAL) reduce 11) ((T_IS_IDENTICAL) reduce 11) ((T_IS_NOT_EQUAL) reduce 11) ((T_IS_NOT_IDENTICAL) reduce 11) ((T_IS_SMALLER_OR_EQUAL) reduce 11) ((T_LOGICAL_AND) reduce 11) ((T_LOGICAL_OR) reduce 11) ((T_LOGICAL_XOR) reduce 11) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 11) ((T_OBJECT_OPERATOR) reduce 11) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 11) ((T_POW) reduce 11) ((T_SL) reduce 11) ((T_SPACESHIP) reduce 11) ((T_SR) reduce 11) (("[") reduce 11) (("^") reduce 11) (("{") reduce 11) (("|") reduce 11)) 4167 ((("%") reduce 42) (("(") reduce 42) (("*") reduce 42) (("+") reduce 42) ((",") reduce 42) (("-") reduce 42) ((".") reduce 42) (("/") reduce 42) (("<") reduce 42) ((">") reduce 42) (("?") reduce 42) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_BOOLEAN_AND) reduce 42) ((T_BOOLEAN_OR) reduce 42) ((T_COALESCE) reduce 42) ((T_DOUBLE_ARROW) reduce 42) ((T_INSTANCEOF) reduce 42) ((T_IS_EQUAL) reduce 42) ((T_IS_GREATER_OR_EQUAL) reduce 42) ((T_IS_IDENTICAL) reduce 42) ((T_IS_NOT_EQUAL) reduce 42) ((T_IS_NOT_IDENTICAL) reduce 42) ((T_IS_SMALLER_OR_EQUAL) reduce 42) ((T_LOGICAL_AND) reduce 42) ((T_LOGICAL_OR) reduce 42) ((T_LOGICAL_XOR) reduce 42) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 42) ((T_OBJECT_OPERATOR) reduce 42) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 42) ((T_POW) reduce 42) ((T_SL) reduce 42) ((T_SPACESHIP) reduce 42) ((T_SR) reduce 42) (("[") reduce 42) (("^") reduce 42) (("{") reduce 42) (("|") reduce 42)) 4168 ((("%") reduce 39) (("(") reduce 39) (("*") reduce 39) (("+") reduce 39) ((",") reduce 39) (("-") reduce 39) ((".") reduce 39) (("/") reduce 39) (("<") reduce 39) ((">") reduce 39) (("?") reduce 39) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_BOOLEAN_AND) reduce 39) ((T_BOOLEAN_OR) reduce 39) ((T_COALESCE) reduce 39) ((T_DOUBLE_ARROW) reduce 39) ((T_INSTANCEOF) reduce 39) ((T_IS_EQUAL) reduce 39) ((T_IS_GREATER_OR_EQUAL) reduce 39) ((T_IS_IDENTICAL) reduce 39) ((T_IS_NOT_EQUAL) reduce 39) ((T_IS_NOT_IDENTICAL) reduce 39) ((T_IS_SMALLER_OR_EQUAL) reduce 39) ((T_LOGICAL_AND) reduce 39) ((T_LOGICAL_OR) reduce 39) ((T_LOGICAL_XOR) reduce 39) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 39) ((T_OBJECT_OPERATOR) reduce 39) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 39) ((T_POW) reduce 39) ((T_SL) reduce 39) ((T_SPACESHIP) reduce 39) ((T_SR) reduce 39) (("[") reduce 39) (("^") reduce 39) (("{") reduce 39) (("|") reduce 39)) 4169 ((("%") reduce 25) (("(") reduce 25) (("*") reduce 25) (("+") reduce 25) ((",") reduce 25) (("-") reduce 25) ((".") reduce 25) (("/") reduce 25) (("<") reduce 25) ((">") reduce 25) (("?") reduce 25) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_BOOLEAN_AND) reduce 25) ((T_BOOLEAN_OR) reduce 25) ((T_COALESCE) reduce 25) ((T_DOUBLE_ARROW) reduce 25) ((T_INSTANCEOF) reduce 25) ((T_IS_EQUAL) reduce 25) ((T_IS_GREATER_OR_EQUAL) reduce 25) ((T_IS_IDENTICAL) reduce 25) ((T_IS_NOT_EQUAL) reduce 25) ((T_IS_NOT_IDENTICAL) reduce 25) ((T_IS_SMALLER_OR_EQUAL) reduce 25) ((T_LOGICAL_AND) reduce 25) ((T_LOGICAL_OR) reduce 25) ((T_LOGICAL_XOR) reduce 25) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 25) ((T_OBJECT_OPERATOR) reduce 25) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 25) ((T_POW) reduce 25) ((T_SL) reduce 25) ((T_SPACESHIP) reduce 25) ((T_SR) reduce 25) (("[") reduce 25) (("^") reduce 25) (("{") reduce 25) (("|") reduce 25)) 4170 ((("%") reduce 50) (("(") reduce 50) (("*") reduce 50) (("+") reduce 50) ((",") reduce 50) (("-") reduce 50) ((".") reduce 50) (("/") reduce 50) (("<") reduce 50) ((">") reduce 50) (("?") reduce 50) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_BOOLEAN_AND) reduce 50) ((T_BOOLEAN_OR) reduce 50) ((T_COALESCE) reduce 50) ((T_DOUBLE_ARROW) reduce 50) ((T_INSTANCEOF) reduce 50) ((T_IS_EQUAL) reduce 50) ((T_IS_GREATER_OR_EQUAL) reduce 50) ((T_IS_IDENTICAL) reduce 50) ((T_IS_NOT_EQUAL) reduce 50) ((T_IS_NOT_IDENTICAL) reduce 50) ((T_IS_SMALLER_OR_EQUAL) reduce 50) ((T_LOGICAL_AND) reduce 50) ((T_LOGICAL_OR) reduce 50) ((T_LOGICAL_XOR) reduce 50) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 50) ((T_OBJECT_OPERATOR) reduce 50) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 50) ((T_POW) reduce 50) ((T_SL) reduce 50) ((T_SPACESHIP) reduce 50) ((T_SR) reduce 50) (("[") reduce 50) (("^") reduce 50) (("{") reduce 50) (("|") reduce 50)) 4171 ((("%") reduce 66) (("(") reduce 66) (("*") reduce 66) (("+") reduce 66) ((",") reduce 66) (("-") reduce 66) ((".") reduce 66) (("/") reduce 66) (("<") reduce 66) ((">") reduce 66) (("?") reduce 66) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_BOOLEAN_AND) reduce 66) ((T_BOOLEAN_OR) reduce 66) ((T_COALESCE) reduce 66) ((T_DOUBLE_ARROW) reduce 66) ((T_INSTANCEOF) reduce 66) ((T_IS_EQUAL) reduce 66) ((T_IS_GREATER_OR_EQUAL) reduce 66) ((T_IS_IDENTICAL) reduce 66) ((T_IS_NOT_EQUAL) reduce 66) ((T_IS_NOT_IDENTICAL) reduce 66) ((T_IS_SMALLER_OR_EQUAL) reduce 66) ((T_LOGICAL_AND) reduce 66) ((T_LOGICAL_OR) reduce 66) ((T_LOGICAL_XOR) reduce 66) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 66) ((T_OBJECT_OPERATOR) reduce 66) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 66) ((T_POW) reduce 66) ((T_SL) reduce 66) ((T_SPACESHIP) reduce 66) ((T_SR) reduce 66) (("[") reduce 66) (("^") reduce 66) (("{") reduce 66) (("|") reduce 66)) 4172 ((("%") reduce 18) (("(") reduce 18) (("*") reduce 18) (("+") reduce 18) ((",") reduce 18) (("-") reduce 18) ((".") reduce 18) (("/") reduce 18) (("<") reduce 18) ((">") reduce 18) (("?") reduce 18) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_BOOLEAN_AND) reduce 18) ((T_BOOLEAN_OR) reduce 18) ((T_COALESCE) reduce 18) ((T_DOUBLE_ARROW) reduce 18) ((T_INSTANCEOF) reduce 18) ((T_IS_EQUAL) reduce 18) ((T_IS_GREATER_OR_EQUAL) reduce 18) ((T_IS_IDENTICAL) reduce 18) ((T_IS_NOT_EQUAL) reduce 18) ((T_IS_NOT_IDENTICAL) reduce 18) ((T_IS_SMALLER_OR_EQUAL) reduce 18) ((T_LOGICAL_AND) reduce 18) ((T_LOGICAL_OR) reduce 18) ((T_LOGICAL_XOR) reduce 18) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 18) ((T_OBJECT_OPERATOR) reduce 18) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 18) ((T_POW) reduce 18) ((T_SL) reduce 18) ((T_SPACESHIP) reduce 18) ((T_SR) reduce 18) (("[") reduce 18) (("^") reduce 18) (("{") reduce 18) (("|") reduce 18)) 4173 ((("%") reduce 17) (("(") reduce 17) (("*") reduce 17) (("+") reduce 17) ((",") reduce 17) (("-") reduce 17) ((".") reduce 17) (("/") reduce 17) (("<") reduce 17) ((">") reduce 17) (("?") reduce 17) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_BOOLEAN_AND) reduce 17) ((T_BOOLEAN_OR) reduce 17) ((T_COALESCE) reduce 17) ((T_DOUBLE_ARROW) reduce 17) ((T_INSTANCEOF) reduce 17) ((T_IS_EQUAL) reduce 17) ((T_IS_GREATER_OR_EQUAL) reduce 17) ((T_IS_IDENTICAL) reduce 17) ((T_IS_NOT_EQUAL) reduce 17) ((T_IS_NOT_IDENTICAL) reduce 17) ((T_IS_SMALLER_OR_EQUAL) reduce 17) ((T_LOGICAL_AND) reduce 17) ((T_LOGICAL_OR) reduce 17) ((T_LOGICAL_XOR) reduce 17) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 17) ((T_OBJECT_OPERATOR) reduce 17) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 17) ((T_POW) reduce 17) ((T_SL) reduce 17) ((T_SPACESHIP) reduce 17) ((T_SR) reduce 17) (("[") reduce 17) (("^") reduce 17) (("{") reduce 17) (("|") reduce 17)) 4174 ((("%") reduce 15) (("(") reduce 15) (("*") reduce 15) (("+") reduce 15) ((",") reduce 15) (("-") reduce 15) ((".") reduce 15) (("/") reduce 15) (("<") reduce 15) ((">") reduce 15) (("?") reduce 15) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_BOOLEAN_AND) reduce 15) ((T_BOOLEAN_OR) reduce 15) ((T_COALESCE) reduce 15) ((T_DOUBLE_ARROW) reduce 15) ((T_INSTANCEOF) reduce 15) ((T_IS_EQUAL) reduce 15) ((T_IS_GREATER_OR_EQUAL) reduce 15) ((T_IS_IDENTICAL) reduce 15) ((T_IS_NOT_EQUAL) reduce 15) ((T_IS_NOT_IDENTICAL) reduce 15) ((T_IS_SMALLER_OR_EQUAL) reduce 15) ((T_LOGICAL_AND) reduce 15) ((T_LOGICAL_OR) reduce 15) ((T_LOGICAL_XOR) reduce 15) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 15) ((T_OBJECT_OPERATOR) reduce 15) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 15) ((T_POW) reduce 15) ((T_SL) reduce 15) ((T_SPACESHIP) reduce 15) ((T_SR) reduce 15) (("[") reduce 15) (("^") reduce 15) (("{") reduce 15) (("|") reduce 15)) 4175 ((("%") reduce 14) (("(") reduce 14) (("*") reduce 14) (("+") reduce 14) ((",") reduce 14) (("-") reduce 14) ((".") reduce 14) (("/") reduce 14) (("<") reduce 14) ((">") reduce 14) (("?") reduce 14) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_BOOLEAN_AND) reduce 14) ((T_BOOLEAN_OR) reduce 14) ((T_COALESCE) reduce 14) ((T_DOUBLE_ARROW) reduce 14) ((T_INSTANCEOF) reduce 14) ((T_IS_EQUAL) reduce 14) ((T_IS_GREATER_OR_EQUAL) reduce 14) ((T_IS_IDENTICAL) reduce 14) ((T_IS_NOT_EQUAL) reduce 14) ((T_IS_NOT_IDENTICAL) reduce 14) ((T_IS_SMALLER_OR_EQUAL) reduce 14) ((T_LOGICAL_AND) reduce 14) ((T_LOGICAL_OR) reduce 14) ((T_LOGICAL_XOR) reduce 14) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 14) ((T_OBJECT_OPERATOR) reduce 14) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 14) ((T_POW) reduce 14) ((T_SL) reduce 14) ((T_SPACESHIP) reduce 14) ((T_SR) reduce 14) (("[") reduce 14) (("^") reduce 14) (("{") reduce 14) (("|") reduce 14)) 4176 ((("%") reduce 38) (("(") reduce 38) (("*") reduce 38) (("+") reduce 38) ((",") reduce 38) (("-") reduce 38) ((".") reduce 38) (("/") reduce 38) (("<") reduce 38) ((">") reduce 38) (("?") reduce 38) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_BOOLEAN_AND) reduce 38) ((T_BOOLEAN_OR) reduce 38) ((T_COALESCE) reduce 38) ((T_DOUBLE_ARROW) reduce 38) ((T_INSTANCEOF) reduce 38) ((T_IS_EQUAL) reduce 38) ((T_IS_GREATER_OR_EQUAL) reduce 38) ((T_IS_IDENTICAL) reduce 38) ((T_IS_NOT_EQUAL) reduce 38) ((T_IS_NOT_IDENTICAL) reduce 38) ((T_IS_SMALLER_OR_EQUAL) reduce 38) ((T_LOGICAL_AND) reduce 38) ((T_LOGICAL_OR) reduce 38) ((T_LOGICAL_XOR) reduce 38) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 38) ((T_OBJECT_OPERATOR) reduce 38) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 38) ((T_POW) reduce 38) ((T_SL) reduce 38) ((T_SPACESHIP) reduce 38) ((T_SR) reduce 38) (("[") reduce 38) (("^") reduce 38) (("{") reduce 38) (("|") reduce 38)) 4177 ((("%") reduce 26) (("(") reduce 26) (("*") reduce 26) (("+") reduce 26) ((",") reduce 26) (("-") reduce 26) ((".") reduce 26) (("/") reduce 26) (("<") reduce 26) ((">") reduce 26) (("?") reduce 26) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_BOOLEAN_AND) reduce 26) ((T_BOOLEAN_OR) reduce 26) ((T_COALESCE) reduce 26) ((T_DOUBLE_ARROW) reduce 26) ((T_INSTANCEOF) reduce 26) ((T_IS_EQUAL) reduce 26) ((T_IS_GREATER_OR_EQUAL) reduce 26) ((T_IS_IDENTICAL) reduce 26) ((T_IS_NOT_EQUAL) reduce 26) ((T_IS_NOT_IDENTICAL) reduce 26) ((T_IS_SMALLER_OR_EQUAL) reduce 26) ((T_LOGICAL_AND) reduce 26) ((T_LOGICAL_OR) reduce 26) ((T_LOGICAL_XOR) reduce 26) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 26) ((T_OBJECT_OPERATOR) reduce 26) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 26) ((T_POW) reduce 26) ((T_SL) reduce 26) ((T_SPACESHIP) reduce 26) ((T_SR) reduce 26) (("[") reduce 26) (("^") reduce 26) (("{") reduce 26) (("|") reduce 26)) 4178 ((("%") reduce 22) (("(") reduce 22) (("*") reduce 22) (("+") reduce 22) ((",") reduce 22) (("-") reduce 22) ((".") reduce 22) (("/") reduce 22) (("<") reduce 22) ((">") reduce 22) (("?") reduce 22) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_BOOLEAN_AND) reduce 22) ((T_BOOLEAN_OR) reduce 22) ((T_COALESCE) reduce 22) ((T_DOUBLE_ARROW) reduce 22) ((T_INSTANCEOF) reduce 22) ((T_IS_EQUAL) reduce 22) ((T_IS_GREATER_OR_EQUAL) reduce 22) ((T_IS_IDENTICAL) reduce 22) ((T_IS_NOT_EQUAL) reduce 22) ((T_IS_NOT_IDENTICAL) reduce 22) ((T_IS_SMALLER_OR_EQUAL) reduce 22) ((T_LOGICAL_AND) reduce 22) ((T_LOGICAL_OR) reduce 22) ((T_LOGICAL_XOR) reduce 22) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 22) ((T_OBJECT_OPERATOR) reduce 22) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 22) ((T_POW) reduce 22) ((T_SL) reduce 22) ((T_SPACESHIP) reduce 22) ((T_SR) reduce 22) (("[") reduce 22) (("^") reduce 22) (("{") reduce 22) (("|") reduce 22)) 4179 ((("%") reduce 24) (("(") reduce 24) (("*") reduce 24) (("+") reduce 24) ((",") reduce 24) (("-") reduce 24) ((".") reduce 24) (("/") reduce 24) (("<") reduce 24) ((">") reduce 24) (("?") reduce 24) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_BOOLEAN_AND) reduce 24) ((T_BOOLEAN_OR) reduce 24) ((T_COALESCE) reduce 24) ((T_DOUBLE_ARROW) reduce 24) ((T_INSTANCEOF) reduce 24) ((T_IS_EQUAL) reduce 24) ((T_IS_GREATER_OR_EQUAL) reduce 24) ((T_IS_IDENTICAL) reduce 24) ((T_IS_NOT_EQUAL) reduce 24) ((T_IS_NOT_IDENTICAL) reduce 24) ((T_IS_SMALLER_OR_EQUAL) reduce 24) ((T_LOGICAL_AND) reduce 24) ((T_LOGICAL_OR) reduce 24) ((T_LOGICAL_XOR) reduce 24) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 24) ((T_OBJECT_OPERATOR) reduce 24) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 24) ((T_POW) reduce 24) ((T_SL) reduce 24) ((T_SPACESHIP) reduce 24) ((T_SR) reduce 24) (("[") reduce 24) (("^") reduce 24) (("{") reduce 24) (("|") reduce 24)) 4180 ((("%") reduce 16) (("(") reduce 16) (("*") reduce 16) (("+") reduce 16) ((",") reduce 16) (("-") reduce 16) ((".") reduce 16) (("/") reduce 16) (("<") reduce 16) ((">") reduce 16) (("?") reduce 16) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_BOOLEAN_AND) reduce 16) ((T_BOOLEAN_OR) reduce 16) ((T_COALESCE) reduce 16) ((T_DOUBLE_ARROW) reduce 16) ((T_INSTANCEOF) reduce 16) ((T_IS_EQUAL) reduce 16) ((T_IS_GREATER_OR_EQUAL) reduce 16) ((T_IS_IDENTICAL) reduce 16) ((T_IS_NOT_EQUAL) reduce 16) ((T_IS_NOT_IDENTICAL) reduce 16) ((T_IS_SMALLER_OR_EQUAL) reduce 16) ((T_LOGICAL_AND) reduce 16) ((T_LOGICAL_OR) reduce 16) ((T_LOGICAL_XOR) reduce 16) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 16) ((T_OBJECT_OPERATOR) reduce 16) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 16) ((T_POW) reduce 16) ((T_SL) reduce 16) ((T_SPACESHIP) reduce 16) ((T_SR) reduce 16) (("[") reduce 16) (("^") reduce 16) (("{") reduce 16) (("|") reduce 16)) 4181 ((("%") reduce 48) (("(") reduce 48) (("*") reduce 48) (("+") reduce 48) ((",") reduce 48) (("-") reduce 48) ((".") reduce 48) (("/") reduce 48) (("<") reduce 48) ((">") reduce 48) (("?") reduce 48) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_BOOLEAN_AND) reduce 48) ((T_BOOLEAN_OR) reduce 48) ((T_COALESCE) reduce 48) ((T_DOUBLE_ARROW) reduce 48) ((T_INSTANCEOF) reduce 48) ((T_IS_EQUAL) reduce 48) ((T_IS_GREATER_OR_EQUAL) reduce 48) ((T_IS_IDENTICAL) reduce 48) ((T_IS_NOT_EQUAL) reduce 48) ((T_IS_NOT_IDENTICAL) reduce 48) ((T_IS_SMALLER_OR_EQUAL) reduce 48) ((T_LOGICAL_AND) reduce 48) ((T_LOGICAL_OR) reduce 48) ((T_LOGICAL_XOR) reduce 48) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 48) ((T_OBJECT_OPERATOR) reduce 48) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 48) ((T_POW) reduce 48) ((T_SL) reduce 48) ((T_SPACESHIP) reduce 48) ((T_SR) reduce 48) (("[") reduce 48) (("^") reduce 48) (("{") reduce 48) (("|") reduce 48)) 4182 ((("%") reduce 20) (("(") reduce 20) (("*") reduce 20) (("+") reduce 20) ((",") reduce 20) (("-") reduce 20) ((".") reduce 20) (("/") reduce 20) (("<") reduce 20) ((">") reduce 20) (("?") reduce 20) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_BOOLEAN_AND) reduce 20) ((T_BOOLEAN_OR) reduce 20) ((T_COALESCE) reduce 20) ((T_DOUBLE_ARROW) reduce 20) ((T_INSTANCEOF) reduce 20) ((T_IS_EQUAL) reduce 20) ((T_IS_GREATER_OR_EQUAL) reduce 20) ((T_IS_IDENTICAL) reduce 20) ((T_IS_NOT_EQUAL) reduce 20) ((T_IS_NOT_IDENTICAL) reduce 20) ((T_IS_SMALLER_OR_EQUAL) reduce 20) ((T_LOGICAL_AND) reduce 20) ((T_LOGICAL_OR) reduce 20) ((T_LOGICAL_XOR) reduce 20) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 20) ((T_OBJECT_OPERATOR) reduce 20) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 20) ((T_POW) reduce 20) ((T_SL) reduce 20) ((T_SPACESHIP) reduce 20) ((T_SR) reduce 20) (("[") reduce 20) (("^") reduce 20) (("{") reduce 20) (("|") reduce 20)) 4183 ((("%") reduce 70) (("(") reduce 70) (("*") reduce 70) (("+") reduce 70) ((",") reduce 70) (("-") reduce 70) ((".") reduce 70) (("/") reduce 70) (("<") reduce 70) ((">") reduce 70) (("?") reduce 70) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_BOOLEAN_AND) reduce 70) ((T_BOOLEAN_OR) reduce 70) ((T_COALESCE) reduce 70) ((T_DOUBLE_ARROW) reduce 70) ((T_INSTANCEOF) reduce 70) ((T_IS_EQUAL) reduce 70) ((T_IS_GREATER_OR_EQUAL) reduce 70) ((T_IS_IDENTICAL) reduce 70) ((T_IS_NOT_EQUAL) reduce 70) ((T_IS_NOT_IDENTICAL) reduce 70) ((T_IS_SMALLER_OR_EQUAL) reduce 70) ((T_LOGICAL_AND) reduce 70) ((T_LOGICAL_OR) reduce 70) ((T_LOGICAL_XOR) reduce 70) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 70) ((T_OBJECT_OPERATOR) reduce 70) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 70) ((T_POW) reduce 70) ((T_SL) reduce 70) ((T_SPACESHIP) reduce 70) ((T_SR) reduce 70) (("[") reduce 70) (("^") reduce 70) (("{") reduce 70) (("|") reduce 70)) 4184 ((("%") reduce 3) (("(") reduce 3) (("*") reduce 3) (("+") reduce 3) ((",") reduce 3) (("-") reduce 3) ((".") reduce 3) (("/") reduce 3) (("<") reduce 3) ((">") reduce 3) (("?") reduce 3) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_BOOLEAN_AND) reduce 3) ((T_BOOLEAN_OR) reduce 3) ((T_COALESCE) reduce 3) ((T_DOUBLE_ARROW) reduce 3) ((T_INSTANCEOF) reduce 3) ((T_IS_EQUAL) reduce 3) ((T_IS_GREATER_OR_EQUAL) reduce 3) ((T_IS_IDENTICAL) reduce 3) ((T_IS_NOT_EQUAL) reduce 3) ((T_IS_NOT_IDENTICAL) reduce 3) ((T_IS_SMALLER_OR_EQUAL) reduce 3) ((T_LOGICAL_AND) reduce 3) ((T_LOGICAL_OR) reduce 3) ((T_LOGICAL_XOR) reduce 3) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 3) ((T_OBJECT_OPERATOR) reduce 3) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 3) ((T_POW) reduce 3) ((T_SL) reduce 3) ((T_SPACESHIP) reduce 3) ((T_SR) reduce 3) (("[") reduce 3) (("^") reduce 3) (("{") reduce 3) (("|") reduce 3)) 4185 ((("%") reduce 12) (("(") reduce 12) (("*") reduce 12) (("+") reduce 12) ((",") reduce 12) (("-") reduce 12) ((".") reduce 12) (("/") reduce 12) (("<") reduce 12) ((">") reduce 12) (("?") reduce 12) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_BOOLEAN_AND) reduce 12) ((T_BOOLEAN_OR) reduce 12) ((T_COALESCE) reduce 12) ((T_DOUBLE_ARROW) reduce 12) ((T_INSTANCEOF) reduce 12) ((T_IS_EQUAL) reduce 12) ((T_IS_GREATER_OR_EQUAL) reduce 12) ((T_IS_IDENTICAL) reduce 12) ((T_IS_NOT_EQUAL) reduce 12) ((T_IS_NOT_IDENTICAL) reduce 12) ((T_IS_SMALLER_OR_EQUAL) reduce 12) ((T_LOGICAL_AND) reduce 12) ((T_LOGICAL_OR) reduce 12) ((T_LOGICAL_XOR) reduce 12) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 12) ((T_OBJECT_OPERATOR) reduce 12) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 12) ((T_POW) reduce 12) ((T_SL) reduce 12) ((T_SPACESHIP) reduce 12) ((T_SR) reduce 12) (("[") reduce 12) (("^") reduce 12) (("{") reduce 12) (("|") reduce 12)) 4186 ((("%") reduce 54) (("(") reduce 54) (("*") reduce 54) (("+") reduce 54) ((",") reduce 54) (("-") reduce 54) ((".") reduce 54) (("/") reduce 54) (("<") reduce 54) ((">") reduce 54) (("?") reduce 54) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_BOOLEAN_AND) reduce 54) ((T_BOOLEAN_OR) reduce 54) ((T_COALESCE) reduce 54) ((T_DOUBLE_ARROW) reduce 54) ((T_INSTANCEOF) reduce 54) ((T_IS_EQUAL) reduce 54) ((T_IS_GREATER_OR_EQUAL) reduce 54) ((T_IS_IDENTICAL) reduce 54) ((T_IS_NOT_EQUAL) reduce 54) ((T_IS_NOT_IDENTICAL) reduce 54) ((T_IS_SMALLER_OR_EQUAL) reduce 54) ((T_LOGICAL_AND) reduce 54) ((T_LOGICAL_OR) reduce 54) ((T_LOGICAL_XOR) reduce 54) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 54) ((T_OBJECT_OPERATOR) reduce 54) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 54) ((T_POW) reduce 54) ((T_SL) reduce 54) ((T_SPACESHIP) reduce 54) ((T_SR) reduce 54) (("[") reduce 54) (("^") reduce 54) (("{") reduce 54) (("|") reduce 54)) 4187 ((("%") reduce 65) (("(") reduce 65) (("*") reduce 65) (("+") reduce 65) ((",") reduce 65) (("-") reduce 65) ((".") reduce 65) (("/") reduce 65) (("<") reduce 65) ((">") reduce 65) (("?") reduce 65) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_BOOLEAN_AND) reduce 65) ((T_BOOLEAN_OR) reduce 65) ((T_COALESCE) reduce 65) ((T_DOUBLE_ARROW) reduce 65) ((T_INSTANCEOF) reduce 65) ((T_IS_EQUAL) reduce 65) ((T_IS_GREATER_OR_EQUAL) reduce 65) ((T_IS_IDENTICAL) reduce 65) ((T_IS_NOT_EQUAL) reduce 65) ((T_IS_NOT_IDENTICAL) reduce 65) ((T_IS_SMALLER_OR_EQUAL) reduce 65) ((T_LOGICAL_AND) reduce 65) ((T_LOGICAL_OR) reduce 65) ((T_LOGICAL_XOR) reduce 65) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 65) ((T_OBJECT_OPERATOR) reduce 65) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 65) ((T_POW) reduce 65) ((T_SL) reduce 65) ((T_SPACESHIP) reduce 65) ((T_SR) reduce 65) (("[") reduce 65) (("^") reduce 65) (("{") reduce 65) (("|") reduce 65)) 4188 ((("%") reduce 74) (("(") reduce 74) (("*") reduce 74) (("+") reduce 74) ((",") reduce 74) (("-") reduce 74) ((".") reduce 74) (("/") reduce 74) (("<") reduce 74) ((">") reduce 74) (("?") reduce 74) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_BOOLEAN_AND) reduce 74) ((T_BOOLEAN_OR) reduce 74) ((T_COALESCE) reduce 74) ((T_DOUBLE_ARROW) reduce 74) ((T_INSTANCEOF) reduce 74) ((T_IS_EQUAL) reduce 74) ((T_IS_GREATER_OR_EQUAL) reduce 74) ((T_IS_IDENTICAL) reduce 74) ((T_IS_NOT_EQUAL) reduce 74) ((T_IS_NOT_IDENTICAL) reduce 74) ((T_IS_SMALLER_OR_EQUAL) reduce 74) ((T_LOGICAL_AND) reduce 74) ((T_LOGICAL_OR) reduce 74) ((T_LOGICAL_XOR) reduce 74) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 74) ((T_OBJECT_OPERATOR) reduce 74) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 74) ((T_POW) reduce 74) ((T_SL) reduce 74) ((T_SPACESHIP) reduce 74) ((T_SR) reduce 74) (("[") reduce 74) (("^") reduce 74) (("{") reduce 74) (("|") reduce 74)) 4189 ((("%") reduce 30) (("(") reduce 30) (("*") reduce 30) (("+") reduce 30) ((",") reduce 30) (("-") reduce 30) ((".") reduce 30) (("/") reduce 30) (("<") reduce 30) ((">") reduce 30) (("?") reduce 30) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_BOOLEAN_AND) reduce 30) ((T_BOOLEAN_OR) reduce 30) ((T_COALESCE) reduce 30) ((T_DOUBLE_ARROW) reduce 30) ((T_INSTANCEOF) reduce 30) ((T_IS_EQUAL) reduce 30) ((T_IS_GREATER_OR_EQUAL) reduce 30) ((T_IS_IDENTICAL) reduce 30) ((T_IS_NOT_EQUAL) reduce 30) ((T_IS_NOT_IDENTICAL) reduce 30) ((T_IS_SMALLER_OR_EQUAL) reduce 30) ((T_LOGICAL_AND) reduce 30) ((T_LOGICAL_OR) reduce 30) ((T_LOGICAL_XOR) reduce 30) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 30) ((T_OBJECT_OPERATOR) reduce 30) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 30) ((T_POW) reduce 30) ((T_SL) reduce 30) ((T_SPACESHIP) reduce 30) ((T_SR) reduce 30) (("[") reduce 30) (("^") reduce 30) (("{") reduce 30) (("|") reduce 30)) 4190 ((("%") reduce 68) (("(") reduce 68) (("*") reduce 68) (("+") reduce 68) ((",") reduce 68) (("-") reduce 68) ((".") reduce 68) (("/") reduce 68) (("<") reduce 68) ((">") reduce 68) (("?") reduce 68) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_BOOLEAN_AND) reduce 68) ((T_BOOLEAN_OR) reduce 68) ((T_COALESCE) reduce 68) ((T_DOUBLE_ARROW) reduce 68) ((T_INSTANCEOF) reduce 68) ((T_IS_EQUAL) reduce 68) ((T_IS_GREATER_OR_EQUAL) reduce 68) ((T_IS_IDENTICAL) reduce 68) ((T_IS_NOT_EQUAL) reduce 68) ((T_IS_NOT_IDENTICAL) reduce 68) ((T_IS_SMALLER_OR_EQUAL) reduce 68) ((T_LOGICAL_AND) reduce 68) ((T_LOGICAL_OR) reduce 68) ((T_LOGICAL_XOR) reduce 68) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 68) ((T_OBJECT_OPERATOR) reduce 68) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 68) ((T_POW) reduce 68) ((T_SL) reduce 68) ((T_SPACESHIP) reduce 68) ((T_SR) reduce 68) (("[") reduce 68) (("^") reduce 68) (("{") reduce 68) (("|") reduce 68)) 4191 ((("%") reduce 21) (("(") reduce 21) (("*") reduce 21) (("+") reduce 21) ((",") reduce 21) (("-") reduce 21) ((".") reduce 21) (("/") reduce 21) (("<") reduce 21) ((">") reduce 21) (("?") reduce 21) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_BOOLEAN_AND) reduce 21) ((T_BOOLEAN_OR) reduce 21) ((T_COALESCE) reduce 21) ((T_DOUBLE_ARROW) reduce 21) ((T_INSTANCEOF) reduce 21) ((T_IS_EQUAL) reduce 21) ((T_IS_GREATER_OR_EQUAL) reduce 21) ((T_IS_IDENTICAL) reduce 21) ((T_IS_NOT_EQUAL) reduce 21) ((T_IS_NOT_IDENTICAL) reduce 21) ((T_IS_SMALLER_OR_EQUAL) reduce 21) ((T_LOGICAL_AND) reduce 21) ((T_LOGICAL_OR) reduce 21) ((T_LOGICAL_XOR) reduce 21) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 21) ((T_OBJECT_OPERATOR) reduce 21) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 21) ((T_POW) reduce 21) ((T_SL) reduce 21) ((T_SPACESHIP) reduce 21) ((T_SR) reduce 21) (("[") reduce 21) (("^") reduce 21) (("{") reduce 21) (("|") reduce 21)) 4192 ((("%") reduce 23) (("(") reduce 23) (("*") reduce 23) (("+") reduce 23) ((",") reduce 23) (("-") reduce 23) ((".") reduce 23) (("/") reduce 23) (("<") reduce 23) ((">") reduce 23) (("?") reduce 23) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_BOOLEAN_AND) reduce 23) ((T_BOOLEAN_OR) reduce 23) ((T_COALESCE) reduce 23) ((T_DOUBLE_ARROW) reduce 23) ((T_INSTANCEOF) reduce 23) ((T_IS_EQUAL) reduce 23) ((T_IS_GREATER_OR_EQUAL) reduce 23) ((T_IS_IDENTICAL) reduce 23) ((T_IS_NOT_EQUAL) reduce 23) ((T_IS_NOT_IDENTICAL) reduce 23) ((T_IS_SMALLER_OR_EQUAL) reduce 23) ((T_LOGICAL_AND) reduce 23) ((T_LOGICAL_OR) reduce 23) ((T_LOGICAL_XOR) reduce 23) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 23) ((T_OBJECT_OPERATOR) reduce 23) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 23) ((T_POW) reduce 23) ((T_SL) reduce 23) ((T_SPACESHIP) reduce 23) ((T_SR) reduce 23) (("[") reduce 23) (("^") reduce 23) (("{") reduce 23) (("|") reduce 23)) 4193 ((("%") reduce 41) (("(") reduce 41) (("*") reduce 41) (("+") reduce 41) ((",") reduce 41) (("-") reduce 41) ((".") reduce 41) (("/") reduce 41) (("<") reduce 41) ((">") reduce 41) (("?") reduce 41) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_BOOLEAN_AND) reduce 41) ((T_BOOLEAN_OR) reduce 41) ((T_COALESCE) reduce 41) ((T_DOUBLE_ARROW) reduce 41) ((T_INSTANCEOF) reduce 41) ((T_IS_EQUAL) reduce 41) ((T_IS_GREATER_OR_EQUAL) reduce 41) ((T_IS_IDENTICAL) reduce 41) ((T_IS_NOT_EQUAL) reduce 41) ((T_IS_NOT_IDENTICAL) reduce 41) ((T_IS_SMALLER_OR_EQUAL) reduce 41) ((T_LOGICAL_AND) reduce 41) ((T_LOGICAL_OR) reduce 41) ((T_LOGICAL_XOR) reduce 41) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 41) ((T_OBJECT_OPERATOR) reduce 41) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 41) ((T_POW) reduce 41) ((T_SL) reduce 41) ((T_SPACESHIP) reduce 41) ((T_SR) reduce 41) (("[") reduce 41) (("^") reduce 41) (("{") reduce 41) (("|") reduce 41)) 4194 ((("%") reduce 62) (("(") reduce 62) (("*") reduce 62) (("+") reduce 62) ((",") reduce 62) (("-") reduce 62) ((".") reduce 62) (("/") reduce 62) (("<") reduce 62) ((">") reduce 62) (("?") reduce 62) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_BOOLEAN_AND) reduce 62) ((T_BOOLEAN_OR) reduce 62) ((T_COALESCE) reduce 62) ((T_DOUBLE_ARROW) reduce 62) ((T_INSTANCEOF) reduce 62) ((T_IS_EQUAL) reduce 62) ((T_IS_GREATER_OR_EQUAL) reduce 62) ((T_IS_IDENTICAL) reduce 62) ((T_IS_NOT_EQUAL) reduce 62) ((T_IS_NOT_IDENTICAL) reduce 62) ((T_IS_SMALLER_OR_EQUAL) reduce 62) ((T_LOGICAL_AND) reduce 62) ((T_LOGICAL_OR) reduce 62) ((T_LOGICAL_XOR) reduce 62) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 62) ((T_OBJECT_OPERATOR) reduce 62) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 62) ((T_POW) reduce 62) ((T_SL) reduce 62) ((T_SPACESHIP) reduce 62) ((T_SR) reduce 62) (("[") reduce 62) (("^") reduce 62) (("{") reduce 62) (("|") reduce 62)) 4195 ((("%") reduce 34) (("(") reduce 34) (("*") reduce 34) (("+") reduce 34) ((",") reduce 34) (("-") reduce 34) ((".") reduce 34) (("/") reduce 34) (("<") reduce 34) ((">") reduce 34) (("?") reduce 34) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_BOOLEAN_AND) reduce 34) ((T_BOOLEAN_OR) reduce 34) ((T_COALESCE) reduce 34) ((T_DOUBLE_ARROW) reduce 34) ((T_INSTANCEOF) reduce 34) ((T_IS_EQUAL) reduce 34) ((T_IS_GREATER_OR_EQUAL) reduce 34) ((T_IS_IDENTICAL) reduce 34) ((T_IS_NOT_EQUAL) reduce 34) ((T_IS_NOT_IDENTICAL) reduce 34) ((T_IS_SMALLER_OR_EQUAL) reduce 34) ((T_LOGICAL_AND) reduce 34) ((T_LOGICAL_OR) reduce 34) ((T_LOGICAL_XOR) reduce 34) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 34) ((T_OBJECT_OPERATOR) reduce 34) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 34) ((T_POW) reduce 34) ((T_SL) reduce 34) ((T_SPACESHIP) reduce 34) ((T_SR) reduce 34) (("[") reduce 34) (("^") reduce 34) (("{") reduce 34) (("|") reduce 34)) 4196 ((("%") reduce 40) (("(") reduce 40) (("*") reduce 40) (("+") reduce 40) ((",") reduce 40) (("-") reduce 40) ((".") reduce 40) (("/") reduce 40) (("<") reduce 40) ((">") reduce 40) (("?") reduce 40) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_BOOLEAN_AND) reduce 40) ((T_BOOLEAN_OR) reduce 40) ((T_COALESCE) reduce 40) ((T_DOUBLE_ARROW) reduce 40) ((T_INSTANCEOF) reduce 40) ((T_IS_EQUAL) reduce 40) ((T_IS_GREATER_OR_EQUAL) reduce 40) ((T_IS_IDENTICAL) reduce 40) ((T_IS_NOT_EQUAL) reduce 40) ((T_IS_NOT_IDENTICAL) reduce 40) ((T_IS_SMALLER_OR_EQUAL) reduce 40) ((T_LOGICAL_AND) reduce 40) ((T_LOGICAL_OR) reduce 40) ((T_LOGICAL_XOR) reduce 40) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 40) ((T_OBJECT_OPERATOR) reduce 40) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 40) ((T_POW) reduce 40) ((T_SL) reduce 40) ((T_SPACESHIP) reduce 40) ((T_SR) reduce 40) (("[") reduce 40) (("^") reduce 40) (("{") reduce 40) (("|") reduce 40)) 4197 ((("%") reduce 13) (("(") reduce 13) (("*") reduce 13) (("+") reduce 13) ((",") reduce 13) (("-") reduce 13) ((".") reduce 13) (("/") reduce 13) (("<") reduce 13) ((">") reduce 13) (("?") reduce 13) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_BOOLEAN_AND) reduce 13) ((T_BOOLEAN_OR) reduce 13) ((T_COALESCE) reduce 13) ((T_DOUBLE_ARROW) reduce 13) ((T_INSTANCEOF) reduce 13) ((T_IS_EQUAL) reduce 13) ((T_IS_GREATER_OR_EQUAL) reduce 13) ((T_IS_IDENTICAL) reduce 13) ((T_IS_NOT_EQUAL) reduce 13) ((T_IS_NOT_IDENTICAL) reduce 13) ((T_IS_SMALLER_OR_EQUAL) reduce 13) ((T_LOGICAL_AND) reduce 13) ((T_LOGICAL_OR) reduce 13) ((T_LOGICAL_XOR) reduce 13) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 13) ((T_OBJECT_OPERATOR) reduce 13) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 13) ((T_POW) reduce 13) ((T_SL) reduce 13) ((T_SPACESHIP) reduce 13) ((T_SR) reduce 13) (("[") reduce 13) (("^") reduce 13) (("{") reduce 13) (("|") reduce 13)) 4198 ((("%") reduce 55) (("(") reduce 55) (("*") reduce 55) (("+") reduce 55) ((",") reduce 55) (("-") reduce 55) ((".") reduce 55) (("/") reduce 55) (("<") reduce 55) ((">") reduce 55) (("?") reduce 55) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_BOOLEAN_AND) reduce 55) ((T_BOOLEAN_OR) reduce 55) ((T_COALESCE) reduce 55) ((T_DOUBLE_ARROW) reduce 55) ((T_INSTANCEOF) reduce 55) ((T_IS_EQUAL) reduce 55) ((T_IS_GREATER_OR_EQUAL) reduce 55) ((T_IS_IDENTICAL) reduce 55) ((T_IS_NOT_EQUAL) reduce 55) ((T_IS_NOT_IDENTICAL) reduce 55) ((T_IS_SMALLER_OR_EQUAL) reduce 55) ((T_LOGICAL_AND) reduce 55) ((T_LOGICAL_OR) reduce 55) ((T_LOGICAL_XOR) reduce 55) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 55) ((T_OBJECT_OPERATOR) reduce 55) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 55) ((T_POW) reduce 55) ((T_SL) reduce 55) ((T_SPACESHIP) reduce 55) ((T_SR) reduce 55) (("[") reduce 55) (("^") reduce 55) (("{") reduce 55) (("|") reduce 55)) 4199 ((("%") reduce 1) (("(") reduce 1) (("*") reduce 1) (("+") reduce 1) ((",") reduce 1) (("-") reduce 1) ((".") reduce 1) (("/") reduce 1) (("<") reduce 1) ((">") reduce 1) (("?") reduce 1) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_BOOLEAN_AND) reduce 1) ((T_BOOLEAN_OR) reduce 1) ((T_COALESCE) reduce 1) ((T_DOUBLE_ARROW) reduce 1) ((T_INSTANCEOF) reduce 1) ((T_IS_EQUAL) reduce 1) ((T_IS_GREATER_OR_EQUAL) reduce 1) ((T_IS_IDENTICAL) reduce 1) ((T_IS_NOT_EQUAL) reduce 1) ((T_IS_NOT_IDENTICAL) reduce 1) ((T_IS_SMALLER_OR_EQUAL) reduce 1) ((T_LOGICAL_AND) reduce 1) ((T_LOGICAL_OR) reduce 1) ((T_LOGICAL_XOR) reduce 1) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 1) ((T_OBJECT_OPERATOR) reduce 1) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 1) ((T_POW) reduce 1) ((T_SL) reduce 1) ((T_SPACESHIP) reduce 1) ((T_SR) reduce 1) (("[") reduce 1) (("^") reduce 1) (("{") reduce 1) (("|") reduce 1)) 4200 ((("%") reduce 2) (("(") reduce 2) (("*") reduce 2) (("+") reduce 2) ((",") reduce 2) (("-") reduce 2) ((".") reduce 2) (("/") reduce 2) (("<") reduce 2) ((">") reduce 2) (("?") reduce 2) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_BOOLEAN_AND) reduce 2) ((T_BOOLEAN_OR) reduce 2) ((T_COALESCE) reduce 2) ((T_DOUBLE_ARROW) reduce 2) ((T_INSTANCEOF) reduce 2) ((T_IS_EQUAL) reduce 2) ((T_IS_GREATER_OR_EQUAL) reduce 2) ((T_IS_IDENTICAL) reduce 2) ((T_IS_NOT_EQUAL) reduce 2) ((T_IS_NOT_IDENTICAL) reduce 2) ((T_IS_SMALLER_OR_EQUAL) reduce 2) ((T_LOGICAL_AND) reduce 2) ((T_LOGICAL_OR) reduce 2) ((T_LOGICAL_XOR) reduce 2) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 2) ((T_OBJECT_OPERATOR) reduce 2) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 2) ((T_POW) reduce 2) ((T_SL) reduce 2) ((T_SPACESHIP) reduce 2) ((T_SR) reduce 2) (("[") reduce 2) (("^") reduce 2) (("{") reduce 2) (("|") reduce 2)) 4201 ((("%") reduce 9) (("(") reduce 9) (("*") reduce 9) (("+") reduce 9) ((",") reduce 9) (("-") reduce 9) ((".") reduce 9) (("/") reduce 9) (("<") reduce 9) ((">") reduce 9) (("?") reduce 9) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_BOOLEAN_AND) reduce 9) ((T_BOOLEAN_OR) reduce 9) ((T_COALESCE) reduce 9) ((T_DOUBLE_ARROW) reduce 9) ((T_INSTANCEOF) reduce 9) ((T_IS_EQUAL) reduce 9) ((T_IS_GREATER_OR_EQUAL) reduce 9) ((T_IS_IDENTICAL) reduce 9) ((T_IS_NOT_EQUAL) reduce 9) ((T_IS_NOT_IDENTICAL) reduce 9) ((T_IS_SMALLER_OR_EQUAL) reduce 9) ((T_LOGICAL_AND) reduce 9) ((T_LOGICAL_OR) reduce 9) ((T_LOGICAL_XOR) reduce 9) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 9) ((T_OBJECT_OPERATOR) reduce 9) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 9) ((T_POW) reduce 9) ((T_SL) reduce 9) ((T_SPACESHIP) reduce 9) ((T_SR) reduce 9) (("[") reduce 9) (("^") reduce 9) (("{") reduce 9) (("|") reduce 9)) 4202 ((("%") reduce 33) (("(") reduce 33) (("*") reduce 33) (("+") reduce 33) ((",") reduce 33) (("-") reduce 33) ((".") reduce 33) (("/") reduce 33) (("<") reduce 33) ((">") reduce 33) (("?") reduce 33) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_BOOLEAN_AND) reduce 33) ((T_BOOLEAN_OR) reduce 33) ((T_COALESCE) reduce 33) ((T_DOUBLE_ARROW) reduce 33) ((T_INSTANCEOF) reduce 33) ((T_IS_EQUAL) reduce 33) ((T_IS_GREATER_OR_EQUAL) reduce 33) ((T_IS_IDENTICAL) reduce 33) ((T_IS_NOT_EQUAL) reduce 33) ((T_IS_NOT_IDENTICAL) reduce 33) ((T_IS_SMALLER_OR_EQUAL) reduce 33) ((T_LOGICAL_AND) reduce 33) ((T_LOGICAL_OR) reduce 33) ((T_LOGICAL_XOR) reduce 33) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 33) ((T_OBJECT_OPERATOR) reduce 33) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 33) ((T_POW) reduce 33) ((T_SL) reduce 33) ((T_SPACESHIP) reduce 33) ((T_SR) reduce 33) (("[") reduce 33) (("^") reduce 33) (("{") reduce 33) (("|") reduce 33)) 4203 ((("%") reduce 58) (("(") reduce 58) (("*") reduce 58) (("+") reduce 58) ((",") reduce 58) (("-") reduce 58) ((".") reduce 58) (("/") reduce 58) (("<") reduce 58) ((">") reduce 58) (("?") reduce 58) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_BOOLEAN_AND) reduce 58) ((T_BOOLEAN_OR) reduce 58) ((T_COALESCE) reduce 58) ((T_DOUBLE_ARROW) reduce 58) ((T_INSTANCEOF) reduce 58) ((T_IS_EQUAL) reduce 58) ((T_IS_GREATER_OR_EQUAL) reduce 58) ((T_IS_IDENTICAL) reduce 58) ((T_IS_NOT_EQUAL) reduce 58) ((T_IS_NOT_IDENTICAL) reduce 58) ((T_IS_SMALLER_OR_EQUAL) reduce 58) ((T_LOGICAL_AND) reduce 58) ((T_LOGICAL_OR) reduce 58) ((T_LOGICAL_XOR) reduce 58) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 58) ((T_OBJECT_OPERATOR) reduce 58) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 58) ((T_POW) reduce 58) ((T_SL) reduce 58) ((T_SPACESHIP) reduce 58) ((T_SR) reduce 58) (("[") reduce 58) (("^") reduce 58) (("{") reduce 58) (("|") reduce 58)) 4204 ((("%") reduce 37) (("(") reduce 37) (("*") reduce 37) (("+") reduce 37) ((",") reduce 37) (("-") reduce 37) ((".") reduce 37) (("/") reduce 37) (("<") reduce 37) ((">") reduce 37) (("?") reduce 37) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_BOOLEAN_AND) reduce 37) ((T_BOOLEAN_OR) reduce 37) ((T_COALESCE) reduce 37) ((T_DOUBLE_ARROW) reduce 37) ((T_INSTANCEOF) reduce 37) ((T_IS_EQUAL) reduce 37) ((T_IS_GREATER_OR_EQUAL) reduce 37) ((T_IS_IDENTICAL) reduce 37) ((T_IS_NOT_EQUAL) reduce 37) ((T_IS_NOT_IDENTICAL) reduce 37) ((T_IS_SMALLER_OR_EQUAL) reduce 37) ((T_LOGICAL_AND) reduce 37) ((T_LOGICAL_OR) reduce 37) ((T_LOGICAL_XOR) reduce 37) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 37) ((T_OBJECT_OPERATOR) reduce 37) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 37) ((T_POW) reduce 37) ((T_SL) reduce 37) ((T_SPACESHIP) reduce 37) ((T_SR) reduce 37) (("[") reduce 37) (("^") reduce 37) (("{") reduce 37) (("|") reduce 37)) 4205 ((("%") reduce 64) (("(") reduce 64) (("*") reduce 64) (("+") reduce 64) ((",") reduce 64) (("-") reduce 64) ((".") reduce 64) (("/") reduce 64) (("<") reduce 64) ((">") reduce 64) (("?") reduce 64) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_BOOLEAN_AND) reduce 64) ((T_BOOLEAN_OR) reduce 64) ((T_COALESCE) reduce 64) ((T_DOUBLE_ARROW) reduce 64) ((T_INSTANCEOF) reduce 64) ((T_IS_EQUAL) reduce 64) ((T_IS_GREATER_OR_EQUAL) reduce 64) ((T_IS_IDENTICAL) reduce 64) ((T_IS_NOT_EQUAL) reduce 64) ((T_IS_NOT_IDENTICAL) reduce 64) ((T_IS_SMALLER_OR_EQUAL) reduce 64) ((T_LOGICAL_AND) reduce 64) ((T_LOGICAL_OR) reduce 64) ((T_LOGICAL_XOR) reduce 64) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 64) ((T_OBJECT_OPERATOR) reduce 64) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 64) ((T_POW) reduce 64) ((T_SL) reduce 64) ((T_SPACESHIP) reduce 64) ((T_SR) reduce 64) (("[") reduce 64) (("^") reduce 64) (("{") reduce 64) (("|") reduce 64)) 4206 ((("%") reduce 46) (("(") reduce 46) (("*") reduce 46) (("+") reduce 46) ((",") reduce 46) (("-") reduce 46) ((".") reduce 46) (("/") reduce 46) (("<") reduce 46) ((">") reduce 46) (("?") reduce 46) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_BOOLEAN_AND) reduce 46) ((T_BOOLEAN_OR) reduce 46) ((T_COALESCE) reduce 46) ((T_DOUBLE_ARROW) reduce 46) ((T_INSTANCEOF) reduce 46) ((T_IS_EQUAL) reduce 46) ((T_IS_GREATER_OR_EQUAL) reduce 46) ((T_IS_IDENTICAL) reduce 46) ((T_IS_NOT_EQUAL) reduce 46) ((T_IS_NOT_IDENTICAL) reduce 46) ((T_IS_SMALLER_OR_EQUAL) reduce 46) ((T_LOGICAL_AND) reduce 46) ((T_LOGICAL_OR) reduce 46) ((T_LOGICAL_XOR) reduce 46) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 46) ((T_OBJECT_OPERATOR) reduce 46) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 46) ((T_POW) reduce 46) ((T_SL) reduce 46) ((T_SPACESHIP) reduce 46) ((T_SR) reduce 46) (("[") reduce 46) (("^") reduce 46) (("{") reduce 46) (("|") reduce 46)) 4207 ((("%") reduce 8) (("(") reduce 8) (("*") reduce 8) (("+") reduce 8) ((",") reduce 8) (("-") reduce 8) ((".") reduce 8) (("/") reduce 8) (("<") reduce 8) ((">") reduce 8) (("?") reduce 8) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_BOOLEAN_AND) reduce 8) ((T_BOOLEAN_OR) reduce 8) ((T_COALESCE) reduce 8) ((T_DOUBLE_ARROW) reduce 8) ((T_INSTANCEOF) reduce 8) ((T_IS_EQUAL) reduce 8) ((T_IS_GREATER_OR_EQUAL) reduce 8) ((T_IS_IDENTICAL) reduce 8) ((T_IS_NOT_EQUAL) reduce 8) ((T_IS_NOT_IDENTICAL) reduce 8) ((T_IS_SMALLER_OR_EQUAL) reduce 8) ((T_LOGICAL_AND) reduce 8) ((T_LOGICAL_OR) reduce 8) ((T_LOGICAL_XOR) reduce 8) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 8) ((T_OBJECT_OPERATOR) reduce 8) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 8) ((T_POW) reduce 8) ((T_SL) reduce 8) ((T_SPACESHIP) reduce 8) ((T_SR) reduce 8) (("[") reduce 8) (("^") reduce 8) (("{") reduce 8) (("|") reduce 8)) 4208 ((("%") reduce 6) (("(") reduce 6) (("*") reduce 6) (("+") reduce 6) ((",") reduce 6) (("-") reduce 6) ((".") reduce 6) (("/") reduce 6) (("<") reduce 6) ((">") reduce 6) (("?") reduce 6) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_BOOLEAN_AND) reduce 6) ((T_BOOLEAN_OR) reduce 6) ((T_COALESCE) reduce 6) ((T_DOUBLE_ARROW) reduce 6) ((T_INSTANCEOF) reduce 6) ((T_IS_EQUAL) reduce 6) ((T_IS_GREATER_OR_EQUAL) reduce 6) ((T_IS_IDENTICAL) reduce 6) ((T_IS_NOT_EQUAL) reduce 6) ((T_IS_NOT_IDENTICAL) reduce 6) ((T_IS_SMALLER_OR_EQUAL) reduce 6) ((T_LOGICAL_AND) reduce 6) ((T_LOGICAL_OR) reduce 6) ((T_LOGICAL_XOR) reduce 6) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 6) ((T_OBJECT_OPERATOR) reduce 6) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 6) ((T_POW) reduce 6) ((T_SL) reduce 6) ((T_SPACESHIP) reduce 6) ((T_SR) reduce 6) (("[") reduce 6) (("^") reduce 6) (("{") reduce 6) (("|") reduce 6)) 4209 ((("%") reduce 7) (("(") reduce 7) (("*") reduce 7) (("+") reduce 7) ((",") reduce 7) (("-") reduce 7) ((".") reduce 7) (("/") reduce 7) (("<") reduce 7) ((">") reduce 7) (("?") reduce 7) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_BOOLEAN_AND) reduce 7) ((T_BOOLEAN_OR) reduce 7) ((T_COALESCE) reduce 7) ((T_DOUBLE_ARROW) reduce 7) ((T_INSTANCEOF) reduce 7) ((T_IS_EQUAL) reduce 7) ((T_IS_GREATER_OR_EQUAL) reduce 7) ((T_IS_IDENTICAL) reduce 7) ((T_IS_NOT_EQUAL) reduce 7) ((T_IS_NOT_IDENTICAL) reduce 7) ((T_IS_SMALLER_OR_EQUAL) reduce 7) ((T_LOGICAL_AND) reduce 7) ((T_LOGICAL_OR) reduce 7) ((T_LOGICAL_XOR) reduce 7) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 7) ((T_OBJECT_OPERATOR) reduce 7) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 7) ((T_POW) reduce 7) ((T_SL) reduce 7) ((T_SPACESHIP) reduce 7) ((T_SR) reduce 7) (("[") reduce 7) (("^") reduce 7) (("{") reduce 7) (("|") reduce 7)) 4210 ((("%") reduce 69) (("(") reduce 69) (("*") reduce 69) (("+") reduce 69) ((",") reduce 69) (("-") reduce 69) ((".") reduce 69) (("/") reduce 69) (("<") reduce 69) ((">") reduce 69) (("?") reduce 69) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_BOOLEAN_AND) reduce 69) ((T_BOOLEAN_OR) reduce 69) ((T_COALESCE) reduce 69) ((T_DOUBLE_ARROW) reduce 69) ((T_INSTANCEOF) reduce 69) ((T_IS_EQUAL) reduce 69) ((T_IS_GREATER_OR_EQUAL) reduce 69) ((T_IS_IDENTICAL) reduce 69) ((T_IS_NOT_EQUAL) reduce 69) ((T_IS_NOT_IDENTICAL) reduce 69) ((T_IS_SMALLER_OR_EQUAL) reduce 69) ((T_LOGICAL_AND) reduce 69) ((T_LOGICAL_OR) reduce 69) ((T_LOGICAL_XOR) reduce 69) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 69) ((T_OBJECT_OPERATOR) reduce 69) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 69) ((T_POW) reduce 69) ((T_SL) reduce 69) ((T_SPACESHIP) reduce 69) ((T_SR) reduce 69) (("[") reduce 69) (("^") reduce 69) (("{") reduce 69) (("|") reduce 69)) 4211 ((("%") reduce 63) (("(") reduce 63) (("*") reduce 63) (("+") reduce 63) ((",") reduce 63) (("-") reduce 63) ((".") reduce 63) (("/") reduce 63) (("<") reduce 63) ((">") reduce 63) (("?") reduce 63) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_BOOLEAN_AND) reduce 63) ((T_BOOLEAN_OR) reduce 63) ((T_COALESCE) reduce 63) ((T_DOUBLE_ARROW) reduce 63) ((T_INSTANCEOF) reduce 63) ((T_IS_EQUAL) reduce 63) ((T_IS_GREATER_OR_EQUAL) reduce 63) ((T_IS_IDENTICAL) reduce 63) ((T_IS_NOT_EQUAL) reduce 63) ((T_IS_NOT_IDENTICAL) reduce 63) ((T_IS_SMALLER_OR_EQUAL) reduce 63) ((T_LOGICAL_AND) reduce 63) ((T_LOGICAL_OR) reduce 63) ((T_LOGICAL_XOR) reduce 63) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 63) ((T_OBJECT_OPERATOR) reduce 63) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 63) ((T_POW) reduce 63) ((T_SL) reduce 63) ((T_SPACESHIP) reduce 63) ((T_SR) reduce 63) (("[") reduce 63) (("^") reduce 63) (("{") reduce 63) (("|") reduce 63)) 4212 ((("%") reduce 56) (("(") reduce 56) (("*") reduce 56) (("+") reduce 56) ((",") reduce 56) (("-") reduce 56) ((".") reduce 56) (("/") reduce 56) (("<") reduce 56) ((">") reduce 56) (("?") reduce 56) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_BOOLEAN_AND) reduce 56) ((T_BOOLEAN_OR) reduce 56) ((T_COALESCE) reduce 56) ((T_DOUBLE_ARROW) reduce 56) ((T_INSTANCEOF) reduce 56) ((T_IS_EQUAL) reduce 56) ((T_IS_GREATER_OR_EQUAL) reduce 56) ((T_IS_IDENTICAL) reduce 56) ((T_IS_NOT_EQUAL) reduce 56) ((T_IS_NOT_IDENTICAL) reduce 56) ((T_IS_SMALLER_OR_EQUAL) reduce 56) ((T_LOGICAL_AND) reduce 56) ((T_LOGICAL_OR) reduce 56) ((T_LOGICAL_XOR) reduce 56) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 56) ((T_OBJECT_OPERATOR) reduce 56) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 56) ((T_POW) reduce 56) ((T_SL) reduce 56) ((T_SPACESHIP) reduce 56) ((T_SR) reduce 56) (("[") reduce 56) (("^") reduce 56) (("{") reduce 56) (("|") reduce 56)) 4213 ((("%") reduce 10) (("(") reduce 10) (("*") reduce 10) (("+") reduce 10) ((",") reduce 10) (("-") reduce 10) ((".") reduce 10) (("/") reduce 10) (("<") reduce 10) ((">") reduce 10) (("?") reduce 10) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_BOOLEAN_AND) reduce 10) ((T_BOOLEAN_OR) reduce 10) ((T_COALESCE) reduce 10) ((T_DOUBLE_ARROW) reduce 10) ((T_INSTANCEOF) reduce 10) ((T_IS_EQUAL) reduce 10) ((T_IS_GREATER_OR_EQUAL) reduce 10) ((T_IS_IDENTICAL) reduce 10) ((T_IS_NOT_EQUAL) reduce 10) ((T_IS_NOT_IDENTICAL) reduce 10) ((T_IS_SMALLER_OR_EQUAL) reduce 10) ((T_LOGICAL_AND) reduce 10) ((T_LOGICAL_OR) reduce 10) ((T_LOGICAL_XOR) reduce 10) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 10) ((T_OBJECT_OPERATOR) reduce 10) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 10) ((T_POW) reduce 10) ((T_SL) reduce 10) ((T_SPACESHIP) reduce 10) ((T_SR) reduce 10) (("[") reduce 10) (("^") reduce 10) (("{") reduce 10) (("|") reduce 10)) 4214 ((("%") reduce 67) (("(") reduce 67) (("*") reduce 67) (("+") reduce 67) ((",") reduce 67) (("-") reduce 67) ((".") reduce 67) (("/") reduce 67) (("<") reduce 67) ((">") reduce 67) (("?") reduce 67) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_BOOLEAN_AND) reduce 67) ((T_BOOLEAN_OR) reduce 67) ((T_COALESCE) reduce 67) ((T_DOUBLE_ARROW) reduce 67) ((T_INSTANCEOF) reduce 67) ((T_IS_EQUAL) reduce 67) ((T_IS_GREATER_OR_EQUAL) reduce 67) ((T_IS_IDENTICAL) reduce 67) ((T_IS_NOT_EQUAL) reduce 67) ((T_IS_NOT_IDENTICAL) reduce 67) ((T_IS_SMALLER_OR_EQUAL) reduce 67) ((T_LOGICAL_AND) reduce 67) ((T_LOGICAL_OR) reduce 67) ((T_LOGICAL_XOR) reduce 67) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 67) ((T_OBJECT_OPERATOR) reduce 67) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 67) ((T_POW) reduce 67) ((T_SL) reduce 67) ((T_SPACESHIP) reduce 67) ((T_SR) reduce 67) (("[") reduce 67) (("^") reduce 67) (("{") reduce 67) (("|") reduce 67)) 4215 ((("%") reduce 44) (("(") reduce 44) (("*") reduce 44) (("+") reduce 44) ((",") reduce 44) (("-") reduce 44) ((".") reduce 44) (("/") reduce 44) (("<") reduce 44) ((">") reduce 44) (("?") reduce 44) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_BOOLEAN_AND) reduce 44) ((T_BOOLEAN_OR) reduce 44) ((T_COALESCE) reduce 44) ((T_DOUBLE_ARROW) reduce 44) ((T_INSTANCEOF) reduce 44) ((T_IS_EQUAL) reduce 44) ((T_IS_GREATER_OR_EQUAL) reduce 44) ((T_IS_IDENTICAL) reduce 44) ((T_IS_NOT_EQUAL) reduce 44) ((T_IS_NOT_IDENTICAL) reduce 44) ((T_IS_SMALLER_OR_EQUAL) reduce 44) ((T_LOGICAL_AND) reduce 44) ((T_LOGICAL_OR) reduce 44) ((T_LOGICAL_XOR) reduce 44) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 44) ((T_OBJECT_OPERATOR) reduce 44) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 44) ((T_POW) reduce 44) ((T_SL) reduce 44) ((T_SPACESHIP) reduce 44) ((T_SR) reduce 44) (("[") reduce 44) (("^") reduce 44) (("{") reduce 44) (("|") reduce 44)) 4216 ((("%") reduce 75) (("(") reduce 75) (("*") reduce 75) (("+") reduce 75) ((",") reduce 75) (("-") reduce 75) ((".") reduce 75) (("/") reduce 75) (("<") reduce 75) ((">") reduce 75) (("?") reduce 75) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_BOOLEAN_AND) reduce 75) ((T_BOOLEAN_OR) reduce 75) ((T_COALESCE) reduce 75) ((T_DOUBLE_ARROW) reduce 75) ((T_INSTANCEOF) reduce 75) ((T_IS_EQUAL) reduce 75) ((T_IS_GREATER_OR_EQUAL) reduce 75) ((T_IS_IDENTICAL) reduce 75) ((T_IS_NOT_EQUAL) reduce 75) ((T_IS_NOT_IDENTICAL) reduce 75) ((T_IS_SMALLER_OR_EQUAL) reduce 75) ((T_LOGICAL_AND) reduce 75) ((T_LOGICAL_OR) reduce 75) ((T_LOGICAL_XOR) reduce 75) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 75) ((T_OBJECT_OPERATOR) reduce 75) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 75) ((T_POW) reduce 75) ((T_SL) reduce 75) ((T_SPACESHIP) reduce 75) ((T_SR) reduce 75) (("[") reduce 75) (("^") reduce 75) (("{") reduce 75) (("|") reduce 75)) 4217 ((("%") reduce 76) (("(") reduce 76) (("*") reduce 76) (("+") reduce 76) ((",") reduce 76) (("-") reduce 76) ((".") reduce 76) (("/") reduce 76) (("<") reduce 76) ((">") reduce 76) (("?") reduce 76) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_BOOLEAN_AND) reduce 76) ((T_BOOLEAN_OR) reduce 76) ((T_COALESCE) reduce 76) ((T_DOUBLE_ARROW) reduce 76) ((T_INSTANCEOF) reduce 76) ((T_IS_EQUAL) reduce 76) ((T_IS_GREATER_OR_EQUAL) reduce 76) ((T_IS_IDENTICAL) reduce 76) ((T_IS_NOT_EQUAL) reduce 76) ((T_IS_NOT_IDENTICAL) reduce 76) ((T_IS_SMALLER_OR_EQUAL) reduce 76) ((T_LOGICAL_AND) reduce 76) ((T_LOGICAL_OR) reduce 76) ((T_LOGICAL_XOR) reduce 76) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 76) ((T_OBJECT_OPERATOR) reduce 76) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 76) ((T_POW) reduce 76) ((T_SL) reduce 76) ((T_SPACESHIP) reduce 76) ((T_SR) reduce 76) (("[") reduce 76) (("^") reduce 76) (("{") reduce 76) (("|") reduce 76)) 4218 ((("%") reduce 77) (("(") reduce 77) (("*") reduce 77) (("+") reduce 77) ((",") reduce 77) (("-") reduce 77) ((".") reduce 77) (("/") reduce 77) (("<") reduce 77) ((">") reduce 77) (("?") reduce 77) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_BOOLEAN_AND) reduce 77) ((T_BOOLEAN_OR) reduce 77) ((T_COALESCE) reduce 77) ((T_DOUBLE_ARROW) reduce 77) ((T_INSTANCEOF) reduce 77) ((T_IS_EQUAL) reduce 77) ((T_IS_GREATER_OR_EQUAL) reduce 77) ((T_IS_IDENTICAL) reduce 77) ((T_IS_NOT_EQUAL) reduce 77) ((T_IS_NOT_IDENTICAL) reduce 77) ((T_IS_SMALLER_OR_EQUAL) reduce 77) ((T_LOGICAL_AND) reduce 77) ((T_LOGICAL_OR) reduce 77) ((T_LOGICAL_XOR) reduce 77) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 77) ((T_OBJECT_OPERATOR) reduce 77) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 77) ((T_POW) reduce 77) ((T_SL) reduce 77) ((T_SPACESHIP) reduce 77) ((T_SR) reduce 77) (("[") reduce 77) (("^") reduce 77) (("{") reduce 77) (("|") reduce 77)) 4219 ((("%") reduce 78) (("(") reduce 78) (("*") reduce 78) (("+") reduce 78) ((",") reduce 78) (("-") reduce 78) ((".") reduce 78) (("/") reduce 78) (("<") reduce 78) ((">") reduce 78) (("?") reduce 78) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_BOOLEAN_AND) reduce 78) ((T_BOOLEAN_OR) reduce 78) ((T_COALESCE) reduce 78) ((T_DOUBLE_ARROW) reduce 78) ((T_INSTANCEOF) reduce 78) ((T_IS_EQUAL) reduce 78) ((T_IS_GREATER_OR_EQUAL) reduce 78) ((T_IS_IDENTICAL) reduce 78) ((T_IS_NOT_EQUAL) reduce 78) ((T_IS_NOT_IDENTICAL) reduce 78) ((T_IS_SMALLER_OR_EQUAL) reduce 78) ((T_LOGICAL_AND) reduce 78) ((T_LOGICAL_OR) reduce 78) ((T_LOGICAL_XOR) reduce 78) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 78) ((T_OBJECT_OPERATOR) reduce 78) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 78) ((T_POW) reduce 78) ((T_SL) reduce 78) ((T_SPACESHIP) reduce 78) ((T_SR) reduce 78) (("[") reduce 78) (("^") reduce 78) (("{") reduce 78) (("|") reduce 78)) 4220 ((("%") reduce 4) (("(") reduce 4) (("*") reduce 4) (("+") reduce 4) ((",") reduce 4) (("-") reduce 4) ((".") reduce 4) (("/") reduce 4) (("<") reduce 4) ((">") reduce 4) (("?") reduce 4) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_BOOLEAN_AND) reduce 4) ((T_BOOLEAN_OR) reduce 4) ((T_COALESCE) reduce 4) ((T_DOUBLE_ARROW) reduce 4) ((T_INSTANCEOF) reduce 4) ((T_IS_EQUAL) reduce 4) ((T_IS_GREATER_OR_EQUAL) reduce 4) ((T_IS_IDENTICAL) reduce 4) ((T_IS_NOT_EQUAL) reduce 4) ((T_IS_NOT_IDENTICAL) reduce 4) ((T_IS_SMALLER_OR_EQUAL) reduce 4) ((T_LOGICAL_AND) reduce 4) ((T_LOGICAL_OR) reduce 4) ((T_LOGICAL_XOR) reduce 4) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 4) ((T_OBJECT_OPERATOR) reduce 4) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 4) ((T_POW) reduce 4) ((T_SL) reduce 4) ((T_SPACESHIP) reduce 4) ((T_SR) reduce 4) (("[") reduce 4) (("^") reduce 4) (("{") reduce 4) (("|") reduce 4)) 4221 ((("%") reduce 5) (("(") reduce 5) (("*") reduce 5) (("+") reduce 5) ((",") reduce 5) (("-") reduce 5) ((".") reduce 5) (("/") reduce 5) (("<") reduce 5) ((">") reduce 5) (("?") reduce 5) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_BOOLEAN_AND) reduce 5) ((T_BOOLEAN_OR) reduce 5) ((T_COALESCE) reduce 5) ((T_DOUBLE_ARROW) reduce 5) ((T_INSTANCEOF) reduce 5) ((T_IS_EQUAL) reduce 5) ((T_IS_GREATER_OR_EQUAL) reduce 5) ((T_IS_IDENTICAL) reduce 5) ((T_IS_NOT_EQUAL) reduce 5) ((T_IS_NOT_IDENTICAL) reduce 5) ((T_IS_SMALLER_OR_EQUAL) reduce 5) ((T_LOGICAL_AND) reduce 5) ((T_LOGICAL_OR) reduce 5) ((T_LOGICAL_XOR) reduce 5) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 5) ((T_OBJECT_OPERATOR) reduce 5) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 5) ((T_POW) reduce 5) ((T_SL) reduce 5) ((T_SPACESHIP) reduce 5) ((T_SR) reduce 5) (("[") reduce 5) (("^") reduce 5) (("{") reduce 5) (("|") reduce 5)) 4222 ((("%") reduce 43) (("(") reduce 43) (("*") reduce 43) (("+") reduce 43) ((",") reduce 43) (("-") reduce 43) ((".") reduce 43) (("/") reduce 43) (("<") reduce 43) ((">") reduce 43) (("?") reduce 43) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_BOOLEAN_AND) reduce 43) ((T_BOOLEAN_OR) reduce 43) ((T_COALESCE) reduce 43) ((T_DOUBLE_ARROW) reduce 43) ((T_INSTANCEOF) reduce 43) ((T_IS_EQUAL) reduce 43) ((T_IS_GREATER_OR_EQUAL) reduce 43) ((T_IS_IDENTICAL) reduce 43) ((T_IS_NOT_EQUAL) reduce 43) ((T_IS_NOT_IDENTICAL) reduce 43) ((T_IS_SMALLER_OR_EQUAL) reduce 43) ((T_LOGICAL_AND) reduce 43) ((T_LOGICAL_OR) reduce 43) ((T_LOGICAL_XOR) reduce 43) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 43) ((T_OBJECT_OPERATOR) reduce 43) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 43) ((T_POW) reduce 43) ((T_SL) reduce 43) ((T_SPACESHIP) reduce 43) ((T_SR) reduce 43) (("[") reduce 43) (("^") reduce 43) (("{") reduce 43) (("|") reduce 43)) 4223 ((("%") reduce 72) (("(") reduce 72) (("*") reduce 72) (("+") reduce 72) ((",") reduce 72) (("-") reduce 72) ((".") reduce 72) (("/") reduce 72) (("<") reduce 72) ((">") reduce 72) (("?") reduce 72) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_BOOLEAN_AND) reduce 72) ((T_BOOLEAN_OR) reduce 72) ((T_COALESCE) reduce 72) ((T_DOUBLE_ARROW) reduce 72) ((T_INSTANCEOF) reduce 72) ((T_IS_EQUAL) reduce 72) ((T_IS_GREATER_OR_EQUAL) reduce 72) ((T_IS_IDENTICAL) reduce 72) ((T_IS_NOT_EQUAL) reduce 72) ((T_IS_NOT_IDENTICAL) reduce 72) ((T_IS_SMALLER_OR_EQUAL) reduce 72) ((T_LOGICAL_AND) reduce 72) ((T_LOGICAL_OR) reduce 72) ((T_LOGICAL_XOR) reduce 72) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 72) ((T_OBJECT_OPERATOR) reduce 72) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 72) ((T_POW) reduce 72) ((T_SL) reduce 72) ((T_SPACESHIP) reduce 72) ((T_SR) reduce 72) (("[") reduce 72) (("^") reduce 72) (("{") reduce 72) (("|") reduce 72)) 4224 ((("%") reduce 81) (("(") reduce 81) (("*") reduce 81) (("+") reduce 81) ((",") reduce 81) (("-") reduce 81) ((".") reduce 81) (("/") reduce 81) (("<") reduce 81) ((">") reduce 81) (("?") reduce 81) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_BOOLEAN_AND) reduce 81) ((T_BOOLEAN_OR) reduce 81) ((T_COALESCE) reduce 81) ((T_DOUBLE_ARROW) reduce 81) ((T_INSTANCEOF) reduce 81) ((T_IS_EQUAL) reduce 81) ((T_IS_GREATER_OR_EQUAL) reduce 81) ((T_IS_IDENTICAL) reduce 81) ((T_IS_NOT_EQUAL) reduce 81) ((T_IS_NOT_IDENTICAL) reduce 81) ((T_IS_SMALLER_OR_EQUAL) reduce 81) ((T_LOGICAL_AND) reduce 81) ((T_LOGICAL_OR) reduce 81) ((T_LOGICAL_XOR) reduce 81) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 81) ((T_OBJECT_OPERATOR) reduce 81) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 81) ((T_POW) reduce 81) ((T_SL) reduce 81) ((T_SPACESHIP) reduce 81) ((T_SR) reduce 81) (("[") reduce 81) (("^") reduce 81) (("{") reduce 81) (("|") reduce 81)) 4225 ((("%") reduce 47) (("(") reduce 47) (("*") reduce 47) (("+") reduce 47) ((",") reduce 47) (("-") reduce 47) ((".") reduce 47) (("/") reduce 47) (("<") reduce 47) ((">") reduce 47) (("?") reduce 47) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_BOOLEAN_AND) reduce 47) ((T_BOOLEAN_OR) reduce 47) ((T_COALESCE) reduce 47) ((T_DOUBLE_ARROW) reduce 47) ((T_INSTANCEOF) reduce 47) ((T_IS_EQUAL) reduce 47) ((T_IS_GREATER_OR_EQUAL) reduce 47) ((T_IS_IDENTICAL) reduce 47) ((T_IS_NOT_EQUAL) reduce 47) ((T_IS_NOT_IDENTICAL) reduce 47) ((T_IS_SMALLER_OR_EQUAL) reduce 47) ((T_LOGICAL_AND) reduce 47) ((T_LOGICAL_OR) reduce 47) ((T_LOGICAL_XOR) reduce 47) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 47) ((T_OBJECT_OPERATOR) reduce 47) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 47) ((T_POW) reduce 47) ((T_SL) reduce 47) ((T_SPACESHIP) reduce 47) ((T_SR) reduce 47) (("[") reduce 47) (("^") reduce 47) (("{") reduce 47) (("|") reduce 47)) 4226 ((("%") reduce 31) (("(") reduce 31) (("*") reduce 31) (("+") reduce 31) ((",") reduce 31) (("-") reduce 31) ((".") reduce 31) (("/") reduce 31) (("<") reduce 31) ((">") reduce 31) (("?") reduce 31) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_BOOLEAN_AND) reduce 31) ((T_BOOLEAN_OR) reduce 31) ((T_COALESCE) reduce 31) ((T_DOUBLE_ARROW) reduce 31) ((T_INSTANCEOF) reduce 31) ((T_IS_EQUAL) reduce 31) ((T_IS_GREATER_OR_EQUAL) reduce 31) ((T_IS_IDENTICAL) reduce 31) ((T_IS_NOT_EQUAL) reduce 31) ((T_IS_NOT_IDENTICAL) reduce 31) ((T_IS_SMALLER_OR_EQUAL) reduce 31) ((T_LOGICAL_AND) reduce 31) ((T_LOGICAL_OR) reduce 31) ((T_LOGICAL_XOR) reduce 31) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 31) ((T_OBJECT_OPERATOR) reduce 31) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 31) ((T_POW) reduce 31) ((T_SL) reduce 31) ((T_SPACESHIP) reduce 31) ((T_SR) reduce 31) (("[") reduce 31) (("^") reduce 31) (("{") reduce 31) (("|") reduce 31)) 4227 ((("%") reduce 57) (("(") reduce 57) (("*") reduce 57) (("+") reduce 57) ((",") reduce 57) (("-") reduce 57) ((".") reduce 57) (("/") reduce 57) (("<") reduce 57) ((">") reduce 57) (("?") reduce 57) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_BOOLEAN_AND) reduce 57) ((T_BOOLEAN_OR) reduce 57) ((T_COALESCE) reduce 57) ((T_DOUBLE_ARROW) reduce 57) ((T_INSTANCEOF) reduce 57) ((T_IS_EQUAL) reduce 57) ((T_IS_GREATER_OR_EQUAL) reduce 57) ((T_IS_IDENTICAL) reduce 57) ((T_IS_NOT_EQUAL) reduce 57) ((T_IS_NOT_IDENTICAL) reduce 57) ((T_IS_SMALLER_OR_EQUAL) reduce 57) ((T_LOGICAL_AND) reduce 57) ((T_LOGICAL_OR) reduce 57) ((T_LOGICAL_XOR) reduce 57) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 57) ((T_OBJECT_OPERATOR) reduce 57) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 57) ((T_POW) reduce 57) ((T_SL) reduce 57) ((T_SPACESHIP) reduce 57) ((T_SR) reduce 57) (("[") reduce 57) (("^") reduce 57) (("{") reduce 57) (("|") reduce 57)) 4228 ((("%") reduce 61) (("(") reduce 61) (("*") reduce 61) (("+") reduce 61) ((",") reduce 61) (("-") reduce 61) ((".") reduce 61) (("/") reduce 61) (("<") reduce 61) ((">") reduce 61) (("?") reduce 61) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_BOOLEAN_AND) reduce 61) ((T_BOOLEAN_OR) reduce 61) ((T_COALESCE) reduce 61) ((T_DOUBLE_ARROW) reduce 61) ((T_INSTANCEOF) reduce 61) ((T_IS_EQUAL) reduce 61) ((T_IS_GREATER_OR_EQUAL) reduce 61) ((T_IS_IDENTICAL) reduce 61) ((T_IS_NOT_EQUAL) reduce 61) ((T_IS_NOT_IDENTICAL) reduce 61) ((T_IS_SMALLER_OR_EQUAL) reduce 61) ((T_LOGICAL_AND) reduce 61) ((T_LOGICAL_OR) reduce 61) ((T_LOGICAL_XOR) reduce 61) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 61) ((T_OBJECT_OPERATOR) reduce 61) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 61) ((T_POW) reduce 61) ((T_SL) reduce 61) ((T_SPACESHIP) reduce 61) ((T_SR) reduce 61) (("[") reduce 61) (("^") reduce 61) (("{") reduce 61) (("|") reduce 61)) 4229 ((("%") reduce 28) (("(") reduce 28) (("*") reduce 28) (("+") reduce 28) ((",") reduce 28) (("-") reduce 28) ((".") reduce 28) (("/") reduce 28) (("<") reduce 28) ((">") reduce 28) (("?") reduce 28) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_BOOLEAN_AND) reduce 28) ((T_BOOLEAN_OR) reduce 28) ((T_COALESCE) reduce 28) ((T_DOUBLE_ARROW) reduce 28) ((T_INSTANCEOF) reduce 28) ((T_IS_EQUAL) reduce 28) ((T_IS_GREATER_OR_EQUAL) reduce 28) ((T_IS_IDENTICAL) reduce 28) ((T_IS_NOT_EQUAL) reduce 28) ((T_IS_NOT_IDENTICAL) reduce 28) ((T_IS_SMALLER_OR_EQUAL) reduce 28) ((T_LOGICAL_AND) reduce 28) ((T_LOGICAL_OR) reduce 28) ((T_LOGICAL_XOR) reduce 28) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 28) ((T_OBJECT_OPERATOR) reduce 28) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 28) ((T_POW) reduce 28) ((T_SL) reduce 28) ((T_SPACESHIP) reduce 28) ((T_SR) reduce 28) (("[") reduce 28) (("^") reduce 28) (("{") reduce 28) (("|") reduce 28)) 4230 ((("%") reduce 36) (("(") reduce 36) (("*") reduce 36) (("+") reduce 36) ((",") reduce 36) (("-") reduce 36) ((".") reduce 36) (("/") reduce 36) (("<") reduce 36) ((">") reduce 36) (("?") reduce 36) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_BOOLEAN_AND) reduce 36) ((T_BOOLEAN_OR) reduce 36) ((T_COALESCE) reduce 36) ((T_DOUBLE_ARROW) reduce 36) ((T_INSTANCEOF) reduce 36) ((T_IS_EQUAL) reduce 36) ((T_IS_GREATER_OR_EQUAL) reduce 36) ((T_IS_IDENTICAL) reduce 36) ((T_IS_NOT_EQUAL) reduce 36) ((T_IS_NOT_IDENTICAL) reduce 36) ((T_IS_SMALLER_OR_EQUAL) reduce 36) ((T_LOGICAL_AND) reduce 36) ((T_LOGICAL_OR) reduce 36) ((T_LOGICAL_XOR) reduce 36) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 36) ((T_OBJECT_OPERATOR) reduce 36) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 36) ((T_POW) reduce 36) ((T_SL) reduce 36) ((T_SPACESHIP) reduce 36) ((T_SR) reduce 36) (("[") reduce 36) (("^") reduce 36) (("{") reduce 36) (("|") reduce 36)) 4231 ((("%") reduce 32) (("(") reduce 32) (("*") reduce 32) (("+") reduce 32) ((",") reduce 32) (("-") reduce 32) ((".") reduce 32) (("/") reduce 32) (("<") reduce 32) ((">") reduce 32) (("?") reduce 32) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_BOOLEAN_AND) reduce 32) ((T_BOOLEAN_OR) reduce 32) ((T_COALESCE) reduce 32) ((T_DOUBLE_ARROW) reduce 32) ((T_INSTANCEOF) reduce 32) ((T_IS_EQUAL) reduce 32) ((T_IS_GREATER_OR_EQUAL) reduce 32) ((T_IS_IDENTICAL) reduce 32) ((T_IS_NOT_EQUAL) reduce 32) ((T_IS_NOT_IDENTICAL) reduce 32) ((T_IS_SMALLER_OR_EQUAL) reduce 32) ((T_LOGICAL_AND) reduce 32) ((T_LOGICAL_OR) reduce 32) ((T_LOGICAL_XOR) reduce 32) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 32) ((T_OBJECT_OPERATOR) reduce 32) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 32) ((T_POW) reduce 32) ((T_SL) reduce 32) ((T_SPACESHIP) reduce 32) ((T_SR) reduce 32) (("[") reduce 32) (("^") reduce 32) (("{") reduce 32) (("|") reduce 32)) 4232 ((("%") reduce 35) (("(") reduce 35) (("*") reduce 35) (("+") reduce 35) ((",") reduce 35) (("-") reduce 35) ((".") reduce 35) (("/") reduce 35) (("<") reduce 35) ((">") reduce 35) (("?") reduce 35) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_BOOLEAN_AND) reduce 35) ((T_BOOLEAN_OR) reduce 35) ((T_COALESCE) reduce 35) ((T_DOUBLE_ARROW) reduce 35) ((T_INSTANCEOF) reduce 35) ((T_IS_EQUAL) reduce 35) ((T_IS_GREATER_OR_EQUAL) reduce 35) ((T_IS_IDENTICAL) reduce 35) ((T_IS_NOT_EQUAL) reduce 35) ((T_IS_NOT_IDENTICAL) reduce 35) ((T_IS_SMALLER_OR_EQUAL) reduce 35) ((T_LOGICAL_AND) reduce 35) ((T_LOGICAL_OR) reduce 35) ((T_LOGICAL_XOR) reduce 35) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 35) ((T_OBJECT_OPERATOR) reduce 35) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 35) ((T_POW) reduce 35) ((T_SL) reduce 35) ((T_SPACESHIP) reduce 35) ((T_SR) reduce 35) (("[") reduce 35) (("^") reduce 35) (("{") reduce 35) (("|") reduce 35)) 4233 ((("%") reduce 19) (("(") reduce 19) (("*") reduce 19) (("+") reduce 19) ((",") reduce 19) (("-") reduce 19) ((".") reduce 19) (("/") reduce 19) (("<") reduce 19) ((">") reduce 19) (("?") reduce 19) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_BOOLEAN_AND) reduce 19) ((T_BOOLEAN_OR) reduce 19) ((T_COALESCE) reduce 19) ((T_DOUBLE_ARROW) reduce 19) ((T_INSTANCEOF) reduce 19) ((T_IS_EQUAL) reduce 19) ((T_IS_GREATER_OR_EQUAL) reduce 19) ((T_IS_IDENTICAL) reduce 19) ((T_IS_NOT_EQUAL) reduce 19) ((T_IS_NOT_IDENTICAL) reduce 19) ((T_IS_SMALLER_OR_EQUAL) reduce 19) ((T_LOGICAL_AND) reduce 19) ((T_LOGICAL_OR) reduce 19) ((T_LOGICAL_XOR) reduce 19) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 19) ((T_OBJECT_OPERATOR) reduce 19) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 19) ((T_POW) reduce 19) ((T_SL) reduce 19) ((T_SPACESHIP) reduce 19) ((T_SR) reduce 19) (("[") reduce 19) (("^") reduce 19) (("{") reduce 19) (("|") reduce 19)) 4234 ((("%") reduce 45) (("(") reduce 45) (("*") reduce 45) (("+") reduce 45) ((",") reduce 45) (("-") reduce 45) ((".") reduce 45) (("/") reduce 45) (("<") reduce 45) ((">") reduce 45) (("?") reduce 45) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_BOOLEAN_AND) reduce 45) ((T_BOOLEAN_OR) reduce 45) ((T_COALESCE) reduce 45) ((T_DOUBLE_ARROW) reduce 45) ((T_INSTANCEOF) reduce 45) ((T_IS_EQUAL) reduce 45) ((T_IS_GREATER_OR_EQUAL) reduce 45) ((T_IS_IDENTICAL) reduce 45) ((T_IS_NOT_EQUAL) reduce 45) ((T_IS_NOT_IDENTICAL) reduce 45) ((T_IS_SMALLER_OR_EQUAL) reduce 45) ((T_LOGICAL_AND) reduce 45) ((T_LOGICAL_OR) reduce 45) ((T_LOGICAL_XOR) reduce 45) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 45) ((T_OBJECT_OPERATOR) reduce 45) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 45) ((T_POW) reduce 45) ((T_SL) reduce 45) ((T_SPACESHIP) reduce 45) ((T_SR) reduce 45) (("[") reduce 45) (("^") reduce 45) (("{") reduce 45) (("|") reduce 45)) 4235 ((("%") reduce 504) (("(") reduce 541) (("*") reduce 504) (("+") reduce 504) ((",") reduce 504) (("-") reduce 504) ((".") reduce 504) (("/") reduce 504) (("<") reduce 504) ((">") reduce 504) (("?") reduce 504) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_BOOLEAN_AND) reduce 504) ((T_BOOLEAN_OR) reduce 504) ((T_COALESCE) reduce 504) ((T_DOUBLE_ARROW) reduce 504) ((T_INSTANCEOF) reduce 504) ((T_IS_EQUAL) reduce 504) ((T_IS_GREATER_OR_EQUAL) reduce 504) ((T_IS_IDENTICAL) reduce 504) ((T_IS_NOT_EQUAL) reduce 504) ((T_IS_NOT_IDENTICAL) reduce 504) ((T_IS_SMALLER_OR_EQUAL) reduce 504) ((T_LOGICAL_AND) reduce 504) ((T_LOGICAL_OR) reduce 504) ((T_LOGICAL_XOR) reduce 504) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 504) ((T_OBJECT_OPERATOR) reduce 504) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 504) ((T_POW) reduce 504) ((T_SL) reduce 504) ((T_SPACESHIP) reduce 504) ((T_SR) reduce 504) (("[") reduce 504) (("^") reduce 504) (("{") reduce 504) (("|") reduce 504)) 4237 ((("%") reduce 71) (("(") reduce 71) (("*") reduce 71) (("+") reduce 71) ((",") reduce 71) (("-") reduce 71) ((".") reduce 71) (("/") reduce 71) (("<") reduce 71) ((">") reduce 71) (("?") reduce 71) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_BOOLEAN_AND) reduce 71) ((T_BOOLEAN_OR) reduce 71) ((T_COALESCE) reduce 71) ((T_DOUBLE_ARROW) reduce 71) ((T_INSTANCEOF) reduce 71) ((T_IS_EQUAL) reduce 71) ((T_IS_GREATER_OR_EQUAL) reduce 71) ((T_IS_IDENTICAL) reduce 71) ((T_IS_NOT_EQUAL) reduce 71) ((T_IS_NOT_IDENTICAL) reduce 71) ((T_IS_SMALLER_OR_EQUAL) reduce 71) ((T_LOGICAL_AND) reduce 71) ((T_LOGICAL_OR) reduce 71) ((T_LOGICAL_XOR) reduce 71) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 71) ((T_OBJECT_OPERATOR) reduce 71) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 71) ((T_POW) reduce 71) ((T_SL) reduce 71) ((T_SPACESHIP) reduce 71) ((T_SR) reduce 71) (("[") reduce 71) (("^") reduce 71) (("{") reduce 71) (("|") reduce 71)) 4238 ((("%") reduce 82) (("(") reduce 82) (("*") reduce 82) (("+") reduce 82) ((",") reduce 82) (("-") reduce 82) ((".") reduce 82) (("/") reduce 82) (("<") reduce 82) ((">") reduce 82) (("?") reduce 82) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_BOOLEAN_AND) reduce 82) ((T_BOOLEAN_OR) reduce 82) ((T_COALESCE) reduce 82) ((T_DOUBLE_ARROW) reduce 82) ((T_INSTANCEOF) reduce 82) ((T_IS_EQUAL) reduce 82) ((T_IS_GREATER_OR_EQUAL) reduce 82) ((T_IS_IDENTICAL) reduce 82) ((T_IS_NOT_EQUAL) reduce 82) ((T_IS_NOT_IDENTICAL) reduce 82) ((T_IS_SMALLER_OR_EQUAL) reduce 82) ((T_LOGICAL_AND) reduce 82) ((T_LOGICAL_OR) reduce 82) ((T_LOGICAL_XOR) reduce 82) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 82) ((T_OBJECT_OPERATOR) reduce 82) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 82) ((T_POW) reduce 82) ((T_SL) reduce 82) ((T_SPACESHIP) reduce 82) ((T_SR) reduce 82) (("[") reduce 82) (("^") reduce 82) (("{") reduce 82) (("|") reduce 82)) 4239 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) ((",") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) (("<") reduce 533) (("=") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AND_EQUAL) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_COALESCE_EQUAL) reduce 533) ((T_CONCAT_EQUAL) reduce 533) ((T_DEC) reduce 533) ((T_DIV_EQUAL) reduce 533) ((T_DOUBLE_ARROW) reduce 533) ((T_INC) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_MINUS_EQUAL) reduce 533) ((T_MOD_EQUAL) reduce 533) ((T_MUL_EQUAL) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_OR_EQUAL) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_PLUS_EQUAL) reduce 533) ((T_POW) reduce 533) ((T_POW_EQUAL) reduce 533) ((T_SL) reduce 533) ((T_SL_EQUAL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) ((T_SR_EQUAL) reduce 533) ((T_XOR_EQUAL) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 4242 ((("%") reduce 506) (("(") reduce 542) (("*") reduce 506) (("+") reduce 506) ((",") reduce 506) (("-") reduce 506) ((".") reduce 506) (("/") reduce 506) (("<") reduce 506) ((">") reduce 506) (("?") reduce 506) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_BOOLEAN_AND) reduce 506) ((T_BOOLEAN_OR) reduce 506) ((T_COALESCE) reduce 506) ((T_DOUBLE_ARROW) reduce 506) ((T_INSTANCEOF) reduce 506) ((T_IS_EQUAL) reduce 506) ((T_IS_GREATER_OR_EQUAL) reduce 506) ((T_IS_IDENTICAL) reduce 506) ((T_IS_NOT_EQUAL) reduce 506) ((T_IS_NOT_IDENTICAL) reduce 506) ((T_IS_SMALLER_OR_EQUAL) reduce 506) ((T_LOGICAL_AND) reduce 506) ((T_LOGICAL_OR) reduce 506) ((T_LOGICAL_XOR) reduce 506) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 506) ((T_OBJECT_OPERATOR) reduce 506) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 506) ((T_POW) reduce 506) ((T_SL) reduce 506) ((T_SPACESHIP) reduce 506) ((T_SR) reduce 506) (("[") reduce 506) (("^") reduce 506) (("{") reduce 506) (("|") reduce 506)) 4244 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) ((",") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) (("<") reduce 468) (("=") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AND_EQUAL) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_COALESCE_EQUAL) reduce 468) ((T_CONCAT_EQUAL) reduce 468) ((T_DEC) reduce 468) ((T_DIV_EQUAL) reduce 468) ((T_DOUBLE_ARROW) reduce 468) ((T_INC) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_MINUS_EQUAL) reduce 468) ((T_MOD_EQUAL) reduce 468) ((T_MUL_EQUAL) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_OR_EQUAL) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_PLUS_EQUAL) reduce 468) ((T_POW) reduce 468) ((T_POW_EQUAL) reduce 468) ((T_SL) reduce 468) ((T_SL_EQUAL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) ((T_SR_EQUAL) reduce 468) ((T_XOR_EQUAL) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 4245 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) ((",") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) (("=") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AND_EQUAL) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_COALESCE_EQUAL) reduce 288) ((T_CONCAT_EQUAL) reduce 288) ((T_DEC) reduce 288) ((T_DIV_EQUAL) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INC) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_MINUS_EQUAL) reduce 288) ((T_MOD_EQUAL) reduce 288) ((T_MUL_EQUAL) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_OR_EQUAL) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_PLUS_EQUAL) reduce 288) ((T_POW) reduce 288) ((T_POW_EQUAL) reduce 288) ((T_SL) reduce 288) ((T_SL_EQUAL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) ((T_SR_EQUAL) reduce 288) ((T_XOR_EQUAL) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 4249 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) ((",") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) (("=") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AND_EQUAL) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_COALESCE_EQUAL) reduce 289) ((T_CONCAT_EQUAL) reduce 289) ((T_DEC) reduce 289) ((T_DIV_EQUAL) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INC) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_MINUS_EQUAL) reduce 289) ((T_MOD_EQUAL) reduce 289) ((T_MUL_EQUAL) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_OR_EQUAL) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_PLUS_EQUAL) reduce 289) ((T_POW) reduce 289) ((T_POW_EQUAL) reduce 289) ((T_SL) reduce 289) ((T_SL_EQUAL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) ((T_SR_EQUAL) reduce 289) ((T_XOR_EQUAL) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 4250 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) ((",") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) (("=") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AND_EQUAL) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_COALESCE_EQUAL) reduce 290) ((T_CONCAT_EQUAL) reduce 290) ((T_DEC) reduce 290) ((T_DIV_EQUAL) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INC) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_MINUS_EQUAL) reduce 290) ((T_MOD_EQUAL) reduce 290) ((T_MUL_EQUAL) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_OR_EQUAL) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_PLUS_EQUAL) reduce 290) ((T_POW) reduce 290) ((T_POW_EQUAL) reduce 290) ((T_SL) reduce 290) ((T_SL_EQUAL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) ((T_SR_EQUAL) reduce 290) ((T_XOR_EQUAL) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 4255 ((("%") reduce 388) (("*") reduce 388) (("+") reduce 388) ((",") reduce 388) (("-") reduce 388) ((".") reduce 388) (("/") reduce 388) (("<") reduce 388) ((">") reduce 388) (("?") reduce 388) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_BOOLEAN_AND) reduce 388) ((T_BOOLEAN_OR) reduce 388) ((T_COALESCE) reduce 388) ((T_DOUBLE_ARROW) reduce 388) ((T_INSTANCEOF) reduce 388) ((T_IS_EQUAL) reduce 388) ((T_IS_GREATER_OR_EQUAL) reduce 388) ((T_IS_IDENTICAL) reduce 388) ((T_IS_NOT_EQUAL) reduce 388) ((T_IS_NOT_IDENTICAL) reduce 388) ((T_IS_SMALLER_OR_EQUAL) reduce 388) ((T_LOGICAL_AND) reduce 388) ((T_LOGICAL_OR) reduce 388) ((T_LOGICAL_XOR) reduce 388) ((T_POW) reduce 388) ((T_SL) reduce 388) ((T_SPACESHIP) reduce 388) ((T_SR) reduce 388) (("^") reduce 388) (("|") reduce 388)) 4257 ((("%") reduce 386) (("*") reduce 386) (("+") reduce 386) ((",") reduce 386) (("-") reduce 386) ((".") reduce 386) (("/") reduce 386) (("<") reduce 386) ((">") reduce 386) (("?") reduce 386) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_BOOLEAN_AND) reduce 386) ((T_BOOLEAN_OR) reduce 386) ((T_COALESCE) reduce 386) ((T_DOUBLE_ARROW) reduce 386) ((T_INSTANCEOF) reduce 386) ((T_IS_EQUAL) reduce 386) ((T_IS_GREATER_OR_EQUAL) reduce 386) ((T_IS_IDENTICAL) reduce 386) ((T_IS_NOT_EQUAL) reduce 386) ((T_IS_NOT_IDENTICAL) reduce 386) ((T_IS_SMALLER_OR_EQUAL) reduce 386) ((T_LOGICAL_AND) reduce 386) ((T_LOGICAL_OR) reduce 386) ((T_LOGICAL_XOR) reduce 386) ((T_POW) reduce 386) ((T_SL) reduce 386) ((T_SPACESHIP) reduce 386) ((T_SR) reduce 386) (("^") reduce 386) (("|") reduce 386)) 4267 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 382) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 382) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 382) ((T_LOGICAL_OR) reduce 382) ((T_LOGICAL_XOR) reduce 382) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 4268 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 384) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 384) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 384) ((T_LOGICAL_OR) reduce 384) ((T_LOGICAL_XOR) reduce 384) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 4269 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 383) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 383) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 383) ((T_LOGICAL_OR) reduce 383) ((T_LOGICAL_XOR) reduce 383) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 4270 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 376) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 376) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 376) ((T_LOGICAL_OR) reduce 376) ((T_LOGICAL_XOR) reduce 376) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 4271 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 373) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 373) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 373) ((T_LOGICAL_OR) reduce 373) ((T_LOGICAL_XOR) reduce 373) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 4272 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 381) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 381) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 381) ((T_LOGICAL_OR) reduce 381) ((T_LOGICAL_XOR) reduce 381) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 4273 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 375) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 375) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 375) ((T_LOGICAL_OR) reduce 375) ((T_LOGICAL_XOR) reduce 375) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 4274 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 379) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 379) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 379) ((T_LOGICAL_OR) reduce 379) ((T_LOGICAL_XOR) reduce 379) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 4275 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 374) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 374) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 374) ((T_LOGICAL_OR) reduce 374) ((T_LOGICAL_XOR) reduce 374) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 4276 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 377) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 377) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 377) ((T_LOGICAL_OR) reduce 377) ((T_LOGICAL_XOR) reduce 377) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 4277 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 378) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 378) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 378) ((T_LOGICAL_OR) reduce 378) ((T_LOGICAL_XOR) reduce 378) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 4278 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 385) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 385) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 385) ((T_LOGICAL_OR) reduce 385) ((T_LOGICAL_XOR) reduce 385) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 4279 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 380) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 380) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 380) ((T_LOGICAL_OR) reduce 380) ((T_LOGICAL_XOR) reduce 380) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 4281 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 370) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 370) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 370) ((T_LOGICAL_OR) reduce 370) ((T_LOGICAL_XOR) reduce 370) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 4284 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) ((",") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 4287 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) ((",") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) (("<") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_DOUBLE_ARROW) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_POW) reduce 525) ((T_SL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 4289 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) ((",") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) (("<") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_DOUBLE_ARROW) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_POW) reduce 524) ((T_SL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 4291 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) ((",") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) (("<") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_DOUBLE_ARROW) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_POW) reduce 519) ((T_SL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 4292 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) ((",") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) (("<") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_DOUBLE_ARROW) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_POW) reduce 526) ((T_SL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 4293 ((("%") reduce 371) (("*") reduce 371) (("+") reduce 371) ((",") reduce 371) (("-") reduce 371) ((".") reduce 371) (("/") reduce 371) (("<") reduce 371) ((">") reduce 371) (("?") reduce 371) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_BOOLEAN_AND) reduce 371) ((T_BOOLEAN_OR) reduce 371) ((T_COALESCE) reduce 371) ((T_DOUBLE_ARROW) reduce 371) ((T_INSTANCEOF) reduce 371) ((T_IS_EQUAL) reduce 371) ((T_IS_GREATER_OR_EQUAL) reduce 371) ((T_IS_IDENTICAL) reduce 371) ((T_IS_NOT_EQUAL) reduce 371) ((T_IS_NOT_IDENTICAL) reduce 371) ((T_IS_SMALLER_OR_EQUAL) reduce 371) ((T_LOGICAL_AND) reduce 371) ((T_LOGICAL_OR) reduce 371) ((T_LOGICAL_XOR) reduce 371) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 371) ((T_SL) reduce 371) ((T_SPACESHIP) reduce 371) ((T_SR) reduce 371) (("[") reduce 510) (("^") reduce 371) (("{") reduce 510) (("|") reduce 371)) 4297 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) ((",") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) (("<") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_DOUBLE_ARROW) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_POW) reduce 533) ((T_SL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 4299 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) ((",") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) (("<") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_DOUBLE_ARROW) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_POW) reduce 468) ((T_SL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 4300 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) ((",") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 4304 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) ((",") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 4305 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) ((",") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 4306 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) ((",") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) (("<") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_DOUBLE_ARROW) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_POW) reduce 465) ((T_SL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 4309 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) ((",") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) (("<") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_DOUBLE_ARROW) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_POW) reduce 532) ((T_SL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 4310 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) ((",") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) (("<") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_DOUBLE_ARROW) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_POW) reduce 467) ((T_SL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 4311 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) ((",") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) (("<") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_DOUBLE_ARROW) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_POW) reduce 469) ((T_SL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 4317 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) ((",") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) (("<") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_DOUBLE_ARROW) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_POW) reduce 521) ((T_SL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 4319 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) ((",") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) (("<") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_DOUBLE_ARROW) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_POW) reduce 520) ((T_SL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 4320 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) ((",") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 4321 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) ((",") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) (("<") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_DOUBLE_ARROW) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_POW) reduce 527) ((T_SL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 4322 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) ((",") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 4325 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) ((",") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 4326 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) ((",") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) (("<") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_DOUBLE_ARROW) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_POW) reduce 522) ((T_SL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 4327 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) ((",") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) (("<") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_DOUBLE_ARROW) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_POW) reduce 528) ((T_SL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 4328 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) ((",") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) (("<") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_DOUBLE_ARROW) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_POW) reduce 523) ((T_SL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 4329 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) ((",") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) (("<") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_DOUBLE_ARROW) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_POW) reduce 466) ((T_SL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 4330 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) ((",") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 4333 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) ((",") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 4334 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) (("+") shift) (("-") shift) (("@") shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DEFAULT) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("}") reduce 124) (("~") shift)) 4335 ((("}") reduce 232)) 4336 (((",") reduce 234) (("}") reduce 234)) 4337 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) ((",") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) (("<") reduce 465) (("=") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AND_EQUAL) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_COALESCE_EQUAL) reduce 465) ((T_CONCAT_EQUAL) reduce 465) ((T_DEC) reduce 465) ((T_DIV_EQUAL) reduce 465) ((T_DOUBLE_ARROW) reduce 465) ((T_INC) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_MINUS_EQUAL) reduce 465) ((T_MOD_EQUAL) reduce 465) ((T_MUL_EQUAL) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_OR_EQUAL) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_PLUS_EQUAL) reduce 465) ((T_POW) reduce 465) ((T_POW_EQUAL) reduce 465) ((T_SL) reduce 465) ((T_SL_EQUAL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) ((T_SR_EQUAL) reduce 465) ((T_XOR_EQUAL) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 4338 ((("%") reduce 230) (("*") reduce 230) (("+") reduce 230) ((",") reduce 230) (("-") reduce 230) ((".") reduce 230) (("/") reduce 230) ((";") reduce 230) (("<") reduce 230) ((">") reduce 230) (("?") reduce 230) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_BOOLEAN_AND) reduce 230) ((T_BOOLEAN_OR) reduce 230) ((T_COALESCE) reduce 230) ((T_DOUBLE_ARROW) reduce 230) ((T_INSTANCEOF) reduce 230) ((T_IS_EQUAL) reduce 230) ((T_IS_GREATER_OR_EQUAL) reduce 230) ((T_IS_IDENTICAL) reduce 230) ((T_IS_NOT_EQUAL) reduce 230) ((T_IS_NOT_IDENTICAL) reduce 230) ((T_IS_SMALLER_OR_EQUAL) reduce 230) ((T_LOGICAL_AND) reduce 230) ((T_LOGICAL_OR) reduce 230) ((T_LOGICAL_XOR) reduce 230) ((T_POW) reduce 230) ((T_SL) reduce 230) ((T_SPACESHIP) reduce 230) ((T_SR) reduce 230) (("^") reduce 230) (("|") reduce 230)) 4339 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) (("+") shift) (("-") shift) (("@") shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_ARROW) reduce 124) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("~") shift)) 4352 ((("%") reduce 502) (("*") reduce 502) (("+") reduce 502) ((",") reduce 502) (("-") reduce 502) ((".") reduce 502) (("/") reduce 502) (("<") reduce 502) ((">") reduce 502) (("?") reduce 502) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_BOOLEAN_AND) reduce 502) ((T_BOOLEAN_OR) reduce 502) ((T_COALESCE) reduce 502) ((T_INSTANCEOF) reduce 502) ((T_IS_EQUAL) reduce 502) ((T_IS_GREATER_OR_EQUAL) reduce 502) ((T_IS_IDENTICAL) reduce 502) ((T_IS_NOT_EQUAL) reduce 502) ((T_IS_NOT_IDENTICAL) reduce 502) ((T_IS_SMALLER_OR_EQUAL) reduce 502) ((T_LOGICAL_AND) reduce 502) ((T_LOGICAL_OR) reduce 502) ((T_LOGICAL_XOR) reduce 502) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 502) ((T_OBJECT_OPERATOR) reduce 502) ((T_POW) reduce 502) ((T_SL) reduce 502) ((T_SPACESHIP) reduce 502) ((T_SR) reduce 502) (("[") reduce 502) (("^") reduce 502) (("{") reduce 502) (("|") reduce 502) (("}") reduce 502)) 4354 ((("%") reduce 484) (("(") reduce 484) (("*") reduce 484) (("+") reduce 484) ((",") reduce 484) (("-") reduce 484) ((".") reduce 484) (("/") reduce 484) (("<") reduce 484) ((">") reduce 484) (("?") reduce 484) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_BOOLEAN_AND) reduce 484) ((T_BOOLEAN_OR) reduce 484) ((T_COALESCE) reduce 484) ((T_INSTANCEOF) reduce 484) ((T_IS_EQUAL) reduce 484) ((T_IS_GREATER_OR_EQUAL) reduce 484) ((T_IS_IDENTICAL) reduce 484) ((T_IS_NOT_EQUAL) reduce 484) ((T_IS_NOT_IDENTICAL) reduce 484) ((T_IS_SMALLER_OR_EQUAL) reduce 484) ((T_LOGICAL_AND) reduce 484) ((T_LOGICAL_OR) reduce 484) ((T_LOGICAL_XOR) reduce 484) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 484) ((T_OBJECT_OPERATOR) reduce 484) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 484) ((T_POW) reduce 484) ((T_SL) reduce 484) ((T_SPACESHIP) reduce 484) ((T_SR) reduce 484) (("[") reduce 484) (("^") reduce 484) (("{") reduce 484) (("|") reduce 484) (("}") reduce 484)) 4356 ((("%") reduce 497) (("*") reduce 497) (("+") reduce 497) ((",") reduce 497) (("-") reduce 497) ((".") reduce 497) (("/") reduce 497) (("<") reduce 497) ((">") reduce 497) (("?") reduce 497) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_BOOLEAN_AND) reduce 497) ((T_BOOLEAN_OR) reduce 497) ((T_COALESCE) reduce 497) ((T_INSTANCEOF) reduce 497) ((T_IS_EQUAL) reduce 497) ((T_IS_GREATER_OR_EQUAL) reduce 497) ((T_IS_IDENTICAL) reduce 497) ((T_IS_NOT_EQUAL) reduce 497) ((T_IS_NOT_IDENTICAL) reduce 497) ((T_IS_SMALLER_OR_EQUAL) reduce 497) ((T_LOGICAL_AND) reduce 497) ((T_LOGICAL_OR) reduce 497) ((T_LOGICAL_XOR) reduce 497) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 497) ((T_OBJECT_OPERATOR) reduce 497) ((T_POW) reduce 497) ((T_SL) reduce 497) ((T_SPACESHIP) reduce 497) ((T_SR) reduce 497) (("[") reduce 497) (("^") reduce 497) (("{") reduce 497) (("|") reduce 497) (("}") reduce 497)) 4357 ((("%") reduce 487) (("*") reduce 487) (("+") reduce 487) ((",") reduce 487) (("-") reduce 487) ((".") reduce 487) (("/") reduce 487) (("<") reduce 487) ((">") reduce 487) (("?") reduce 487) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_BOOLEAN_AND) reduce 487) ((T_BOOLEAN_OR) reduce 487) ((T_COALESCE) reduce 487) ((T_INSTANCEOF) reduce 487) ((T_IS_EQUAL) reduce 487) ((T_IS_GREATER_OR_EQUAL) reduce 487) ((T_IS_IDENTICAL) reduce 487) ((T_IS_NOT_EQUAL) reduce 487) ((T_IS_NOT_IDENTICAL) reduce 487) ((T_IS_SMALLER_OR_EQUAL) reduce 487) ((T_LOGICAL_AND) reduce 487) ((T_LOGICAL_OR) reduce 487) ((T_LOGICAL_XOR) reduce 487) ((T_POW) reduce 487) ((T_SL) reduce 487) ((T_SPACESHIP) reduce 487) ((T_SR) reduce 487) (("^") reduce 487) (("|") reduce 487) (("}") reduce 487)) 4361 ((("%") reduce 475) (("(") shift) (("*") reduce 475) (("+") reduce 475) ((",") reduce 475) (("-") reduce 475) ((".") reduce 475) (("/") reduce 475) (("<") reduce 475) ((">") reduce 475) (("?") reduce 475) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_BOOLEAN_AND) reduce 475) ((T_BOOLEAN_OR) reduce 475) ((T_COALESCE) reduce 475) ((T_INSTANCEOF) reduce 475) ((T_IS_EQUAL) reduce 475) ((T_IS_GREATER_OR_EQUAL) reduce 475) ((T_IS_IDENTICAL) reduce 475) ((T_IS_NOT_EQUAL) reduce 475) ((T_IS_NOT_IDENTICAL) reduce 475) ((T_IS_SMALLER_OR_EQUAL) reduce 475) ((T_LOGICAL_AND) reduce 475) ((T_LOGICAL_OR) reduce 475) ((T_LOGICAL_XOR) reduce 475) ((T_POW) reduce 475) ((T_SL) reduce 475) ((T_SPACESHIP) reduce 475) ((T_SR) reduce 475) (("^") reduce 475) (("|") reduce 475) (("}") reduce 475)) 4362 ((("%") reduce 496) (("*") reduce 496) (("+") reduce 496) ((",") reduce 496) (("-") reduce 496) ((".") reduce 496) (("/") reduce 496) (("<") reduce 496) ((">") reduce 496) (("?") reduce 496) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_BOOLEAN_AND) reduce 496) ((T_BOOLEAN_OR) reduce 496) ((T_COALESCE) reduce 496) ((T_INSTANCEOF) reduce 496) ((T_IS_EQUAL) reduce 496) ((T_IS_GREATER_OR_EQUAL) reduce 496) ((T_IS_IDENTICAL) reduce 496) ((T_IS_NOT_EQUAL) reduce 496) ((T_IS_NOT_IDENTICAL) reduce 496) ((T_IS_SMALLER_OR_EQUAL) reduce 496) ((T_LOGICAL_AND) reduce 496) ((T_LOGICAL_OR) reduce 496) ((T_LOGICAL_XOR) reduce 496) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 496) ((T_OBJECT_OPERATOR) reduce 496) ((T_POW) reduce 496) ((T_SL) reduce 496) ((T_SPACESHIP) reduce 496) ((T_SR) reduce 496) (("[") reduce 496) (("^") reduce 496) (("{") reduce 496) (("|") reduce 496) (("}") reduce 496)) 4363 ((("%") reduce 500) (("*") reduce 500) (("+") reduce 500) ((",") reduce 500) (("-") reduce 500) ((".") reduce 500) (("/") reduce 500) (("<") reduce 500) ((">") reduce 500) (("?") reduce 500) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_BOOLEAN_AND) reduce 500) ((T_BOOLEAN_OR) reduce 500) ((T_COALESCE) reduce 500) ((T_INSTANCEOF) reduce 500) ((T_IS_EQUAL) reduce 500) ((T_IS_GREATER_OR_EQUAL) reduce 500) ((T_IS_IDENTICAL) reduce 500) ((T_IS_NOT_EQUAL) reduce 500) ((T_IS_NOT_IDENTICAL) reduce 500) ((T_IS_SMALLER_OR_EQUAL) reduce 500) ((T_LOGICAL_AND) reduce 500) ((T_LOGICAL_OR) reduce 500) ((T_LOGICAL_XOR) reduce 500) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 500) ((T_OBJECT_OPERATOR) reduce 500) ((T_POW) reduce 500) ((T_SL) reduce 500) ((T_SPACESHIP) reduce 500) ((T_SR) reduce 500) (("[") reduce 500) (("^") reduce 500) (("{") reduce 500) (("|") reduce 500) (("}") reduce 500)) 4369 ((("%") reduce 495) (("*") reduce 495) (("+") reduce 495) ((",") reduce 495) (("-") reduce 495) ((".") reduce 495) (("/") reduce 495) (("<") reduce 495) ((">") reduce 495) (("?") reduce 495) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_BOOLEAN_AND) reduce 495) ((T_BOOLEAN_OR) reduce 495) ((T_COALESCE) reduce 495) ((T_INSTANCEOF) reduce 495) ((T_IS_EQUAL) reduce 495) ((T_IS_GREATER_OR_EQUAL) reduce 495) ((T_IS_IDENTICAL) reduce 495) ((T_IS_NOT_EQUAL) reduce 495) ((T_IS_NOT_IDENTICAL) reduce 495) ((T_IS_SMALLER_OR_EQUAL) reduce 495) ((T_LOGICAL_AND) reduce 495) ((T_LOGICAL_OR) reduce 495) ((T_LOGICAL_XOR) reduce 495) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 495) ((T_OBJECT_OPERATOR) reduce 495) ((T_POW) reduce 495) ((T_SL) reduce 495) ((T_SPACESHIP) reduce 495) ((T_SR) reduce 495) (("[") reduce 495) (("^") reduce 495) (("{") reduce 495) (("|") reduce 495) (("}") reduce 495)) 4371 ((("%") reduce 486) (("*") reduce 486) (("+") reduce 486) ((",") reduce 486) (("-") reduce 486) ((".") reduce 486) (("/") reduce 486) (("<") reduce 486) ((">") reduce 486) (("?") reduce 486) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_BOOLEAN_AND) reduce 486) ((T_BOOLEAN_OR) reduce 486) ((T_COALESCE) reduce 486) ((T_INSTANCEOF) reduce 486) ((T_IS_EQUAL) reduce 486) ((T_IS_GREATER_OR_EQUAL) reduce 486) ((T_IS_IDENTICAL) reduce 486) ((T_IS_NOT_EQUAL) reduce 486) ((T_IS_NOT_IDENTICAL) reduce 486) ((T_IS_SMALLER_OR_EQUAL) reduce 486) ((T_LOGICAL_AND) reduce 486) ((T_LOGICAL_OR) reduce 486) ((T_LOGICAL_XOR) reduce 486) ((T_POW) reduce 486) ((T_SL) reduce 486) ((T_SPACESHIP) reduce 486) ((T_SR) reduce 486) (("^") reduce 486) (("|") reduce 486) (("}") reduce 486)) 4373 ((("%") reduce 499) (("*") reduce 499) (("+") reduce 499) ((",") reduce 499) (("-") reduce 499) ((".") reduce 499) (("/") reduce 499) (("<") reduce 499) ((">") reduce 499) (("?") reduce 499) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_BOOLEAN_AND) reduce 499) ((T_BOOLEAN_OR) reduce 499) ((T_COALESCE) reduce 499) ((T_INSTANCEOF) reduce 499) ((T_IS_EQUAL) reduce 499) ((T_IS_GREATER_OR_EQUAL) reduce 499) ((T_IS_IDENTICAL) reduce 499) ((T_IS_NOT_EQUAL) reduce 499) ((T_IS_NOT_IDENTICAL) reduce 499) ((T_IS_SMALLER_OR_EQUAL) reduce 499) ((T_LOGICAL_AND) reduce 499) ((T_LOGICAL_OR) reduce 499) ((T_LOGICAL_XOR) reduce 499) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 499) ((T_OBJECT_OPERATOR) reduce 499) ((T_POW) reduce 499) ((T_SL) reduce 499) ((T_SPACESHIP) reduce 499) ((T_SR) reduce 499) (("[") reduce 499) (("^") reduce 499) (("{") reduce 499) (("|") reduce 499) (("}") reduce 499)) 4374 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) ((",") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 93) ((T_OBJECT_OPERATOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("[") reduce 93) (("^") reduce 93) (("{") reduce 93) (("|") reduce 93) (("}") reduce 93)) 4375 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) ((",") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 92) ((T_OBJECT_OPERATOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("[") reduce 92) (("^") reduce 92) (("{") reduce 92) (("|") reduce 92) (("}") reduce 92)) 4376 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) ((",") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 94) ((T_OBJECT_OPERATOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("[") reduce 94) (("^") reduce 94) (("{") reduce 94) (("|") reduce 94) (("}") reduce 94)) 4378 ((("%") reduce 501) (("*") reduce 501) (("+") reduce 501) ((",") reduce 501) (("-") reduce 501) ((".") reduce 501) (("/") reduce 501) (("<") reduce 501) ((">") reduce 501) (("?") reduce 501) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_BOOLEAN_AND) reduce 501) ((T_BOOLEAN_OR) reduce 501) ((T_COALESCE) reduce 501) ((T_INSTANCEOF) reduce 501) ((T_IS_EQUAL) reduce 501) ((T_IS_GREATER_OR_EQUAL) reduce 501) ((T_IS_IDENTICAL) reduce 501) ((T_IS_NOT_EQUAL) reduce 501) ((T_IS_NOT_IDENTICAL) reduce 501) ((T_IS_SMALLER_OR_EQUAL) reduce 501) ((T_LOGICAL_AND) reduce 501) ((T_LOGICAL_OR) reduce 501) ((T_LOGICAL_XOR) reduce 501) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 501) ((T_OBJECT_OPERATOR) reduce 501) ((T_POW) reduce 501) ((T_SL) reduce 501) ((T_SPACESHIP) reduce 501) ((T_SR) reduce 501) (("[") reduce 501) (("^") reduce 501) (("{") reduce 501) (("|") reduce 501) (("}") reduce 501)) 4386 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) ((",") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 91) ((T_OBJECT_OPERATOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("[") reduce 91) (("^") reduce 91) (("{") reduce 91) (("|") reduce 91) (("}") reduce 91)) 4389 ((("%") reduce 498) (("*") reduce 498) (("+") reduce 498) ((",") reduce 498) (("-") reduce 498) ((".") reduce 498) (("/") reduce 498) (("<") reduce 498) ((">") reduce 498) (("?") reduce 498) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_BOOLEAN_AND) reduce 498) ((T_BOOLEAN_OR) reduce 498) ((T_COALESCE) reduce 498) ((T_INSTANCEOF) reduce 498) ((T_IS_EQUAL) reduce 498) ((T_IS_GREATER_OR_EQUAL) reduce 498) ((T_IS_IDENTICAL) reduce 498) ((T_IS_NOT_EQUAL) reduce 498) ((T_IS_NOT_IDENTICAL) reduce 498) ((T_IS_SMALLER_OR_EQUAL) reduce 498) ((T_LOGICAL_AND) reduce 498) ((T_LOGICAL_OR) reduce 498) ((T_LOGICAL_XOR) reduce 498) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 498) ((T_OBJECT_OPERATOR) reduce 498) ((T_POW) reduce 498) ((T_SL) reduce 498) ((T_SPACESHIP) reduce 498) ((T_SR) reduce 498) (("[") reduce 498) (("^") reduce 498) (("{") reduce 498) (("|") reduce 498) (("}") reduce 498)) 4391 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) ((",") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) (("=") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AND_EQUAL) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_COALESCE_EQUAL) reduce 529) ((T_CONCAT_EQUAL) reduce 529) ((T_DEC) reduce 529) ((T_DIV_EQUAL) reduce 529) ((T_INC) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_MINUS_EQUAL) reduce 529) ((T_MOD_EQUAL) reduce 529) ((T_MUL_EQUAL) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_OR_EQUAL) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_PLUS_EQUAL) reduce 529) ((T_POW) reduce 529) ((T_POW_EQUAL) reduce 529) ((T_SL) reduce 529) ((T_SL_EQUAL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) ((T_SR_EQUAL) reduce 529) ((T_XOR_EQUAL) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529) (("}") reduce 529)) 4392 ((("!") shift) (("\"") shift) (("$") shift) (("%") reduce 440) (("(") shift) (("*") reduce 440) (("+") shift) ((",") reduce 440) (("-") shift) ((".") reduce 440) (("/") reduce 440) (("<") reduce 440) ((">") reduce 440) (("?") reduce 440) (("@") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOLEAN_AND) reduce 440) ((T_BOOLEAN_OR) reduce 440) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_COALESCE) reduce 440) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INSTANCEOF) reduce 440) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_IS_EQUAL) reduce 440) ((T_IS_GREATER_OR_EQUAL) reduce 440) ((T_IS_IDENTICAL) reduce 440) ((T_IS_NOT_EQUAL) reduce 440) ((T_IS_NOT_IDENTICAL) reduce 440) ((T_IS_SMALLER_OR_EQUAL) reduce 440) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_LOGICAL_AND) reduce 440) ((T_LOGICAL_OR) reduce 440) ((T_LOGICAL_XOR) reduce 440) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_POW) reduce 440) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_SL) reduce 440) ((T_SPACESHIP) reduce 440) ((T_SR) reduce 440) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("^") reduce 440) (("`") shift) (("|") reduce 440) (("}") reduce 440) (("~") shift)) 4399 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) ((",") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) (("<") reduce 525) (("=") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AND_EQUAL) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_COALESCE_EQUAL) reduce 525) ((T_CONCAT_EQUAL) reduce 525) ((T_DEC) reduce 525) ((T_DIV_EQUAL) reduce 525) ((T_INC) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_MINUS_EQUAL) reduce 525) ((T_MOD_EQUAL) reduce 525) ((T_MUL_EQUAL) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_OR_EQUAL) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_PLUS_EQUAL) reduce 525) ((T_POW) reduce 525) ((T_POW_EQUAL) reduce 525) ((T_SL) reduce 525) ((T_SL_EQUAL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) ((T_SR_EQUAL) reduce 525) ((T_XOR_EQUAL) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525) (("}") reduce 525)) 4400 ((("%") reduce 493) (("*") reduce 493) (("+") reduce 493) ((",") reduce 493) (("-") reduce 493) ((".") reduce 493) (("/") reduce 493) (("<") reduce 493) ((">") reduce 493) (("?") reduce 493) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_BOOLEAN_AND) reduce 493) ((T_BOOLEAN_OR) reduce 493) ((T_COALESCE) reduce 493) ((T_INSTANCEOF) reduce 493) ((T_IS_EQUAL) reduce 493) ((T_IS_GREATER_OR_EQUAL) reduce 493) ((T_IS_IDENTICAL) reduce 493) ((T_IS_NOT_EQUAL) reduce 493) ((T_IS_NOT_IDENTICAL) reduce 493) ((T_IS_SMALLER_OR_EQUAL) reduce 493) ((T_LOGICAL_AND) reduce 493) ((T_LOGICAL_OR) reduce 493) ((T_LOGICAL_XOR) reduce 493) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 513) ((T_OBJECT_OPERATOR) reduce 513) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 513) ((T_POW) reduce 493) ((T_SL) reduce 493) ((T_SPACESHIP) reduce 493) ((T_SR) reduce 493) (("[") reduce 513) (("^") reduce 493) (("{") reduce 513) (("|") reduce 493) (("}") reduce 493)) 4402 ((("%") reduce 492) (("*") reduce 492) (("+") reduce 492) ((",") reduce 492) (("-") reduce 492) ((".") reduce 492) (("/") reduce 492) (("<") reduce 492) ((">") reduce 492) (("?") reduce 492) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_BOOLEAN_AND) reduce 492) ((T_BOOLEAN_OR) reduce 492) ((T_COALESCE) reduce 492) ((T_INSTANCEOF) reduce 492) ((T_IS_EQUAL) reduce 492) ((T_IS_GREATER_OR_EQUAL) reduce 492) ((T_IS_IDENTICAL) reduce 492) ((T_IS_NOT_EQUAL) reduce 492) ((T_IS_NOT_IDENTICAL) reduce 492) ((T_IS_SMALLER_OR_EQUAL) reduce 492) ((T_LOGICAL_AND) reduce 492) ((T_LOGICAL_OR) reduce 492) ((T_LOGICAL_XOR) reduce 492) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 515) ((T_OBJECT_OPERATOR) reduce 515) ((T_POW) reduce 492) ((T_SL) reduce 492) ((T_SPACESHIP) reduce 492) ((T_SR) reduce 492) (("[") reduce 515) (("^") reduce 492) (("{") reduce 515) (("|") reduce 492) (("}") reduce 492)) 4403 ((("%") reduce 491) (("(") reduce 518) (("*") reduce 491) (("+") reduce 491) ((",") reduce 491) (("-") reduce 491) ((".") reduce 491) (("/") reduce 491) (("<") reduce 491) ((">") reduce 491) (("?") reduce 491) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_BOOLEAN_AND) reduce 491) ((T_BOOLEAN_OR) reduce 491) ((T_COALESCE) reduce 491) ((T_INSTANCEOF) reduce 491) ((T_IS_EQUAL) reduce 491) ((T_IS_GREATER_OR_EQUAL) reduce 491) ((T_IS_IDENTICAL) reduce 491) ((T_IS_NOT_EQUAL) reduce 491) ((T_IS_NOT_IDENTICAL) reduce 491) ((T_IS_SMALLER_OR_EQUAL) reduce 491) ((T_LOGICAL_AND) reduce 491) ((T_LOGICAL_OR) reduce 491) ((T_LOGICAL_XOR) reduce 491) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 512) ((T_OBJECT_OPERATOR) reduce 512) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 512) ((T_POW) reduce 491) ((T_SL) reduce 491) ((T_SPACESHIP) reduce 491) ((T_SR) reduce 491) (("[") reduce 512) (("^") reduce 491) (("{") reduce 512) (("|") reduce 491) (("}") reduce 491)) 4404 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 235) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 235)) 4407 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) ((",") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) (("<") reduce 524) (("=") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AND_EQUAL) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_COALESCE_EQUAL) reduce 524) ((T_CONCAT_EQUAL) reduce 524) ((T_DEC) reduce 524) ((T_DIV_EQUAL) reduce 524) ((T_INC) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_MINUS_EQUAL) reduce 524) ((T_MOD_EQUAL) reduce 524) ((T_MUL_EQUAL) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_OR_EQUAL) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_PLUS_EQUAL) reduce 524) ((T_POW) reduce 524) ((T_POW_EQUAL) reduce 524) ((T_SL) reduce 524) ((T_SL_EQUAL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) ((T_SR_EQUAL) reduce 524) ((T_XOR_EQUAL) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524) (("}") reduce 524)) 4408 ((("%") reduce 445) (("*") reduce 445) (("+") reduce 445) ((",") reduce 445) (("-") reduce 445) ((".") reduce 445) (("/") reduce 445) (("<") reduce 445) ((">") reduce 445) (("?") reduce 445) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_BOOLEAN_AND) reduce 445) ((T_BOOLEAN_OR) reduce 445) ((T_COALESCE) reduce 445) ((T_INSTANCEOF) reduce 445) ((T_IS_EQUAL) reduce 445) ((T_IS_GREATER_OR_EQUAL) reduce 445) ((T_IS_IDENTICAL) reduce 445) ((T_IS_NOT_EQUAL) reduce 445) ((T_IS_NOT_IDENTICAL) reduce 445) ((T_IS_SMALLER_OR_EQUAL) reduce 445) ((T_LOGICAL_AND) reduce 445) ((T_LOGICAL_OR) reduce 445) ((T_LOGICAL_XOR) reduce 445) ((T_POW) reduce 445) ((T_SL) reduce 445) ((T_SPACESHIP) reduce 445) ((T_SR) reduce 445) (("^") reduce 445) (("|") reduce 445) (("}") reduce 445)) 4409 ((("%") reduce 427) (("*") reduce 427) (("+") reduce 427) ((",") reduce 427) (("-") reduce 427) ((".") reduce 427) (("/") reduce 427) (("<") reduce 427) ((">") reduce 427) (("?") reduce 427) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_BOOLEAN_AND) reduce 427) ((T_BOOLEAN_OR) reduce 427) ((T_COALESCE) reduce 427) ((T_INSTANCEOF) reduce 427) ((T_IS_EQUAL) reduce 427) ((T_IS_GREATER_OR_EQUAL) reduce 427) ((T_IS_IDENTICAL) reduce 427) ((T_IS_NOT_EQUAL) reduce 427) ((T_IS_NOT_IDENTICAL) reduce 427) ((T_IS_SMALLER_OR_EQUAL) reduce 427) ((T_LOGICAL_AND) reduce 427) ((T_LOGICAL_OR) reduce 427) ((T_LOGICAL_XOR) reduce 427) ((T_POW) reduce 427) ((T_SL) reduce 427) ((T_SPACESHIP) reduce 427) ((T_SR) reduce 427) (("^") reduce 427) (("|") reduce 427) (("}") reduce 427)) 4410 ((("%") reduce 449) (("*") reduce 449) (("+") reduce 449) ((",") reduce 449) (("-") reduce 449) ((".") reduce 449) (("/") reduce 449) (("<") reduce 449) ((">") reduce 449) (("?") reduce 449) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_BOOLEAN_AND) reduce 449) ((T_BOOLEAN_OR) reduce 449) ((T_COALESCE) reduce 449) ((T_INSTANCEOF) reduce 449) ((T_IS_EQUAL) reduce 449) ((T_IS_GREATER_OR_EQUAL) reduce 449) ((T_IS_IDENTICAL) reduce 449) ((T_IS_NOT_EQUAL) reduce 449) ((T_IS_NOT_IDENTICAL) reduce 449) ((T_IS_SMALLER_OR_EQUAL) reduce 449) ((T_LOGICAL_AND) reduce 449) ((T_LOGICAL_OR) reduce 449) ((T_LOGICAL_XOR) reduce 449) ((T_POW) reduce 449) ((T_SL) reduce 449) ((T_SPACESHIP) reduce 449) ((T_SR) reduce 449) (("^") reduce 449) (("|") reduce 449) (("}") reduce 449)) 4411 ((("%") reduce 494) (("(") shift) (("*") reduce 494) (("+") reduce 494) ((",") reduce 494) (("-") reduce 494) ((".") reduce 494) (("/") reduce 494) (("<") reduce 494) ((">") reduce 494) (("?") reduce 494) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_BOOLEAN_AND) reduce 494) ((T_BOOLEAN_OR) reduce 494) ((T_COALESCE) reduce 494) ((T_INSTANCEOF) reduce 494) ((T_IS_EQUAL) reduce 494) ((T_IS_GREATER_OR_EQUAL) reduce 494) ((T_IS_IDENTICAL) reduce 494) ((T_IS_NOT_EQUAL) reduce 494) ((T_IS_NOT_IDENTICAL) reduce 494) ((T_IS_SMALLER_OR_EQUAL) reduce 494) ((T_LOGICAL_AND) reduce 494) ((T_LOGICAL_OR) reduce 494) ((T_LOGICAL_XOR) reduce 494) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 494) ((T_OBJECT_OPERATOR) reduce 494) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 494) ((T_SL) reduce 494) ((T_SPACESHIP) reduce 494) ((T_SR) reduce 494) (("[") reduce 494) (("^") reduce 494) (("{") reduce 494) (("|") reduce 494) (("}") reduce 494)) 4412 ((("%") reduce 423) (("*") reduce 423) (("+") reduce 423) ((",") reduce 423) (("-") reduce 423) ((".") reduce 423) (("/") reduce 423) (("<") reduce 423) ((">") reduce 423) (("?") reduce 423) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_BOOLEAN_AND) reduce 423) ((T_BOOLEAN_OR) reduce 423) ((T_COALESCE) reduce 423) ((T_INSTANCEOF) reduce 423) ((T_IS_EQUAL) reduce 423) ((T_IS_GREATER_OR_EQUAL) reduce 423) ((T_IS_IDENTICAL) reduce 423) ((T_IS_NOT_EQUAL) reduce 423) ((T_IS_NOT_IDENTICAL) reduce 423) ((T_IS_SMALLER_OR_EQUAL) reduce 423) ((T_LOGICAL_AND) reduce 423) ((T_LOGICAL_OR) reduce 423) ((T_LOGICAL_XOR) reduce 423) ((T_POW) reduce 423) ((T_SL) reduce 423) ((T_SPACESHIP) reduce 423) ((T_SR) reduce 423) (("^") reduce 423) (("|") reduce 423) (("}") reduce 423)) 4413 ((("%") reduce 437) (("*") reduce 437) (("+") reduce 437) ((",") reduce 437) (("-") reduce 437) ((".") reduce 437) (("/") reduce 437) (("<") reduce 437) ((">") reduce 437) (("?") reduce 437) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_BOOLEAN_AND) reduce 437) ((T_BOOLEAN_OR) reduce 437) ((T_COALESCE) reduce 437) ((T_INSTANCEOF) reduce 437) ((T_IS_EQUAL) reduce 437) ((T_IS_GREATER_OR_EQUAL) reduce 437) ((T_IS_IDENTICAL) reduce 437) ((T_IS_NOT_EQUAL) reduce 437) ((T_IS_NOT_IDENTICAL) reduce 437) ((T_IS_SMALLER_OR_EQUAL) reduce 437) ((T_LOGICAL_AND) reduce 437) ((T_LOGICAL_OR) reduce 437) ((T_LOGICAL_XOR) reduce 437) ((T_POW) reduce 437) ((T_SL) reduce 437) ((T_SPACESHIP) reduce 437) ((T_SR) reduce 437) (("^") reduce 437) (("|") reduce 437) (("}") reduce 437)) 4414 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) ((",") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) (("<") reduce 519) (("=") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AND_EQUAL) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_COALESCE_EQUAL) reduce 519) ((T_CONCAT_EQUAL) reduce 519) ((T_DEC) reduce 519) ((T_DIV_EQUAL) reduce 519) ((T_INC) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_MINUS_EQUAL) reduce 519) ((T_MOD_EQUAL) reduce 519) ((T_MUL_EQUAL) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_OR_EQUAL) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_PLUS_EQUAL) reduce 519) ((T_POW) reduce 519) ((T_POW_EQUAL) reduce 519) ((T_SL) reduce 519) ((T_SL_EQUAL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) ((T_SR_EQUAL) reduce 519) ((T_XOR_EQUAL) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519) (("}") reduce 519)) 4415 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) ((",") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) (("<") reduce 526) (("=") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AND_EQUAL) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_COALESCE_EQUAL) reduce 526) ((T_CONCAT_EQUAL) reduce 526) ((T_DEC) reduce 526) ((T_DIV_EQUAL) reduce 526) ((T_INC) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_MINUS_EQUAL) reduce 526) ((T_MOD_EQUAL) reduce 526) ((T_MUL_EQUAL) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_OR_EQUAL) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_PLUS_EQUAL) reduce 526) ((T_POW) reduce 526) ((T_POW_EQUAL) reduce 526) ((T_SL) reduce 526) ((T_SL_EQUAL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) ((T_SR_EQUAL) reduce 526) ((T_XOR_EQUAL) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526) (("}") reduce 526)) 4416 ((("%") reduce 367) (("*") reduce 367) (("+") reduce 367) ((",") reduce 367) (("-") reduce 367) ((".") reduce 367) (("/") reduce 367) (("<") reduce 367) (("=") shift) ((">") reduce 367) (("?") reduce 367) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AND_EQUAL) shift) ((T_BOOLEAN_AND) reduce 367) ((T_BOOLEAN_OR) reduce 367) ((T_COALESCE) reduce 367) ((T_COALESCE_EQUAL) shift) ((T_CONCAT_EQUAL) shift) ((T_DEC) shift) ((T_DIV_EQUAL) shift) ((T_INC) shift) ((T_INSTANCEOF) reduce 367) ((T_IS_EQUAL) reduce 367) ((T_IS_GREATER_OR_EQUAL) reduce 367) ((T_IS_IDENTICAL) reduce 367) ((T_IS_NOT_EQUAL) reduce 367) ((T_IS_NOT_IDENTICAL) reduce 367) ((T_IS_SMALLER_OR_EQUAL) reduce 367) ((T_LOGICAL_AND) reduce 367) ((T_LOGICAL_OR) reduce 367) ((T_LOGICAL_XOR) reduce 367) ((T_MINUS_EQUAL) shift) ((T_MOD_EQUAL) shift) ((T_MUL_EQUAL) shift) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_OR_EQUAL) shift) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_PLUS_EQUAL) shift) ((T_POW) reduce 367) ((T_POW_EQUAL) shift) ((T_SL) reduce 367) ((T_SL_EQUAL) shift) ((T_SPACESHIP) reduce 367) ((T_SR) reduce 367) ((T_SR_EQUAL) shift) ((T_XOR_EQUAL) shift) (("[") reduce 510) (("^") reduce 367) (("{") reduce 510) (("|") reduce 367) (("}") reduce 367)) 4419 ((("%") reduce 411) (("*") reduce 411) (("+") reduce 411) ((",") reduce 411) (("-") reduce 411) ((".") reduce 411) (("/") reduce 411) (("<") reduce 411) ((">") reduce 411) (("?") reduce 411) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_BOOLEAN_AND) reduce 411) ((T_BOOLEAN_OR) reduce 411) ((T_COALESCE) reduce 411) ((T_INSTANCEOF) reduce 411) ((T_IS_EQUAL) reduce 411) ((T_IS_GREATER_OR_EQUAL) reduce 411) ((T_IS_IDENTICAL) reduce 411) ((T_IS_NOT_EQUAL) reduce 411) ((T_IS_NOT_IDENTICAL) reduce 411) ((T_IS_SMALLER_OR_EQUAL) reduce 411) ((T_LOGICAL_AND) reduce 411) ((T_LOGICAL_OR) reduce 411) ((T_LOGICAL_XOR) reduce 411) ((T_POW) shift) ((T_SL) reduce 411) ((T_SPACESHIP) reduce 411) ((T_SR) reduce 411) (("^") reduce 411) (("|") reduce 411) (("}") reduce 411)) 4450 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 395) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 395) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 395) ((T_BOOLEAN_OR) reduce 395) ((T_COALESCE) reduce 395) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 395) ((T_LOGICAL_OR) reduce 395) ((T_LOGICAL_XOR) reduce 395) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") reduce 395) (("}") reduce 395)) 4451 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 398) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 398) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 398) ((T_BOOLEAN_OR) reduce 398) ((T_COALESCE) reduce 398) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 398) ((T_LOGICAL_OR) reduce 398) ((T_LOGICAL_XOR) reduce 398) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 398) (("|") reduce 398) (("}") reduce 398)) 4452 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 407) (("-") shift) ((".") reduce 407) (("/") shift) (("<") reduce 407) ((">") reduce 407) (("?") reduce 407) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_BOOLEAN_AND) reduce 407) ((T_BOOLEAN_OR) reduce 407) ((T_COALESCE) reduce 407) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 407) ((T_IS_GREATER_OR_EQUAL) reduce 407) ((T_IS_IDENTICAL) reduce 407) ((T_IS_NOT_EQUAL) reduce 407) ((T_IS_NOT_IDENTICAL) reduce 407) ((T_IS_SMALLER_OR_EQUAL) reduce 407) ((T_LOGICAL_AND) reduce 407) ((T_LOGICAL_OR) reduce 407) ((T_LOGICAL_XOR) reduce 407) ((T_POW) shift) ((T_SL) reduce 407) ((T_SPACESHIP) reduce 407) ((T_SR) reduce 407) (("^") reduce 407) (("|") reduce 407) (("}") reduce 407)) 4453 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 420) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 420) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_BOOLEAN_AND) reduce 420) ((T_BOOLEAN_OR) reduce 420) ((T_COALESCE) reduce 420) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 420) ((T_LOGICAL_OR) reduce 420) ((T_LOGICAL_XOR) reduce 420) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 420) (("|") reduce 420) (("}") reduce 420)) 4454 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 406) (("-") shift) ((".") reduce 406) (("/") shift) (("<") reduce 406) ((">") reduce 406) (("?") reduce 406) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_BOOLEAN_AND) reduce 406) ((T_BOOLEAN_OR) reduce 406) ((T_COALESCE) reduce 406) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 406) ((T_IS_GREATER_OR_EQUAL) reduce 406) ((T_IS_IDENTICAL) reduce 406) ((T_IS_NOT_EQUAL) reduce 406) ((T_IS_NOT_IDENTICAL) reduce 406) ((T_IS_SMALLER_OR_EQUAL) reduce 406) ((T_LOGICAL_AND) reduce 406) ((T_LOGICAL_OR) reduce 406) ((T_LOGICAL_XOR) reduce 406) ((T_POW) shift) ((T_SL) reduce 406) ((T_SPACESHIP) reduce 406) ((T_SR) reduce 406) (("^") reduce 406) (("|") reduce 406) (("}") reduce 406)) 4455 ((("%") reduce 403) (("*") reduce 403) (("+") reduce 403) ((",") reduce 403) (("-") reduce 403) ((".") reduce 403) (("/") reduce 403) (("<") reduce 403) ((">") reduce 403) (("?") reduce 403) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_BOOLEAN_AND) reduce 403) ((T_BOOLEAN_OR) reduce 403) ((T_COALESCE) reduce 403) ((T_INSTANCEOF) reduce 403) ((T_IS_EQUAL) reduce 403) ((T_IS_GREATER_OR_EQUAL) reduce 403) ((T_IS_IDENTICAL) reduce 403) ((T_IS_NOT_EQUAL) reduce 403) ((T_IS_NOT_IDENTICAL) reduce 403) ((T_IS_SMALLER_OR_EQUAL) reduce 403) ((T_LOGICAL_AND) reduce 403) ((T_LOGICAL_OR) reduce 403) ((T_LOGICAL_XOR) reduce 403) ((T_POW) shift) ((T_SL) reduce 403) ((T_SPACESHIP) reduce 403) ((T_SR) reduce 403) (("^") reduce 403) (("|") reduce 403) (("}") reduce 403)) 4456 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 394) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 394) ((T_LOGICAL_XOR) reduce 394) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 394)) 4457 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 392) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 392) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 392)) 4458 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 393) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 393) ((T_LOGICAL_OR) reduce 393) ((T_LOGICAL_XOR) reduce 393) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 393)) 4459 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 417) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 417) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_BOOLEAN_AND) reduce 417) ((T_BOOLEAN_OR) reduce 417) ((T_COALESCE) reduce 417) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 417) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 417) ((T_IS_NOT_EQUAL) reduce 417) ((T_IS_NOT_IDENTICAL) reduce 417) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 417) ((T_LOGICAL_OR) reduce 417) ((T_LOGICAL_XOR) reduce 417) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 417) ((T_SR) shift) (("^") reduce 417) (("|") reduce 417) (("}") reduce 417)) 4460 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 413) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 413) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_BOOLEAN_AND) reduce 413) ((T_BOOLEAN_OR) reduce 413) ((T_COALESCE) reduce 413) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 413) ((T_LOGICAL_OR) reduce 413) ((T_LOGICAL_XOR) reduce 413) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 413) (("|") reduce 413) (("}") reduce 413)) 4461 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 415) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 415) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_BOOLEAN_AND) reduce 415) ((T_BOOLEAN_OR) reduce 415) ((T_COALESCE) reduce 415) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 415) ((T_LOGICAL_OR) reduce 415) ((T_LOGICAL_XOR) reduce 415) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 415) (("|") reduce 415) (("}") reduce 415)) 4462 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 412) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 412) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_BOOLEAN_AND) reduce 412) ((T_BOOLEAN_OR) reduce 412) ((T_COALESCE) reduce 412) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 412) ((T_LOGICAL_OR) reduce 412) ((T_LOGICAL_XOR) reduce 412) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 412) (("|") reduce 412) (("}") reduce 412)) 4463 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 419) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 419) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_BOOLEAN_AND) reduce 419) ((T_BOOLEAN_OR) reduce 419) ((T_COALESCE) reduce 419) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 419) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 419) ((T_IS_NOT_EQUAL) reduce 419) ((T_IS_NOT_IDENTICAL) reduce 419) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 419) ((T_LOGICAL_OR) reduce 419) ((T_LOGICAL_XOR) reduce 419) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 419) ((T_SR) shift) (("^") reduce 419) (("|") reduce 419) (("}") reduce 419)) 4464 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 414) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 414) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_BOOLEAN_AND) reduce 414) ((T_BOOLEAN_OR) reduce 414) ((T_COALESCE) reduce 414) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 414) ((T_LOGICAL_OR) reduce 414) ((T_LOGICAL_XOR) reduce 414) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 414) (("|") reduce 414) (("}") reduce 414)) 4467 ((("%") reduce 93) (("*") reduce 93) (("+") reduce 93) ((",") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93) (("}") reduce 93)) 4468 ((("%") reduce 92) (("*") reduce 92) (("+") reduce 92) ((",") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92) (("}") reduce 92)) 4469 ((("%") reduce 94) (("*") reduce 94) (("+") reduce 94) ((",") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94) (("}") reduce 94)) 4470 ((("%") reduce 470) (("*") reduce 470) (("+") reduce 470) ((",") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470) (("}") reduce 470)) 4471 ((("%") reduce 91) (("*") reduce 91) (("+") reduce 91) ((",") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91) (("}") reduce 91)) 4472 ((("%") reduce 529) (("*") reduce 529) (("+") reduce 529) ((",") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529) (("}") reduce 529)) 4473 ((("%") reduce 472) (("*") reduce 472) (("+") reduce 472) ((",") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472) (("}") reduce 472)) 4474 ((("%") reduce 421) (("*") reduce 421) (("+") reduce 421) ((",") reduce 421) (("-") reduce 421) ((".") reduce 421) (("/") reduce 421) (("<") reduce 421) ((">") reduce 421) (("?") reduce 421) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_BOOLEAN_AND) reduce 421) ((T_BOOLEAN_OR) reduce 421) ((T_COALESCE) reduce 421) ((T_INSTANCEOF) reduce 421) ((T_IS_EQUAL) reduce 421) ((T_IS_GREATER_OR_EQUAL) reduce 421) ((T_IS_IDENTICAL) reduce 421) ((T_IS_NOT_EQUAL) reduce 421) ((T_IS_NOT_IDENTICAL) reduce 421) ((T_IS_SMALLER_OR_EQUAL) reduce 421) ((T_LOGICAL_AND) reduce 421) ((T_LOGICAL_OR) reduce 421) ((T_LOGICAL_XOR) reduce 421) ((T_POW) reduce 421) ((T_SL) reduce 421) ((T_SPACESHIP) reduce 421) ((T_SR) reduce 421) (("^") reduce 421) (("|") reduce 421) (("}") reduce 421)) 4475 ((("%") reduce 471) (("*") reduce 471) (("+") reduce 471) ((",") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471) (("}") reduce 471)) 4476 ((("%") reduce 473) (("*") reduce 473) (("+") reduce 473) ((",") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473) (("}") reduce 473)) 4477 ((("%") reduce 534) (("*") reduce 534) (("+") reduce 534) ((",") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534) (("}") reduce 534)) 4484 ((("%") reduce 536) (("*") reduce 536) (("+") reduce 536) ((",") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536) (("}") reduce 536)) 4486 ((("%") reduce 535) (("*") reduce 535) (("+") reduce 535) ((",") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535) (("}") reduce 535)) 4487 ((("%") reduce 540) (("*") reduce 540) (("+") reduce 540) ((",") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540) (("}") reduce 540)) 4488 ((("%") reduce 544) (("*") reduce 544) (("+") reduce 544) ((",") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544) (("}") reduce 544)) 4489 ((("%") reduce 537) (("*") reduce 537) (("+") reduce 537) ((",") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537) (("}") reduce 537)) 4490 ((("%") reduce 546) (("*") reduce 546) (("+") reduce 546) ((",") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546) (("}") reduce 546)) 4493 ((("%") reduce 545) (("*") reduce 545) (("+") reduce 545) ((",") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545) (("}") reduce 545)) 4494 ((("%") reduce 538) (("*") reduce 538) (("+") reduce 538) ((",") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538) (("}") reduce 538)) 4496 ((("%") reduce 539) (("*") reduce 539) (("+") reduce 539) ((",") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539) (("}") reduce 539)) 4498 ((("%") reduce 474) (("*") reduce 474) (("+") reduce 474) ((",") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474) (("}") reduce 474)) 4499 ((("%") reduce 531) (("*") reduce 531) (("+") reduce 531) ((",") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531) (("}") reduce 531)) 4502 ((("%") reduce 530) (("*") reduce 530) (("+") reduce 530) ((",") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530) (("}") reduce 530)) 4503 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 426) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 426) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 426) ((T_LOGICAL_OR) reduce 426) ((T_LOGICAL_XOR) reduce 426) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 426)) 4504 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 390) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 390) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) reduce 390) ((T_COALESCE) reduce 390) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 390) ((T_LOGICAL_OR) reduce 390) ((T_LOGICAL_XOR) reduce 390) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 390)) 4505 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 391) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 391) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 391) ((T_BOOLEAN_OR) reduce 391) ((T_COALESCE) reduce 391) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 391) ((T_LOGICAL_OR) reduce 391) ((T_LOGICAL_XOR) reduce 391) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 391)) 4506 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 396) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 396) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_BOOLEAN_AND) reduce 396) ((T_BOOLEAN_OR) reduce 396) ((T_COALESCE) reduce 396) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 396) ((T_LOGICAL_OR) reduce 396) ((T_LOGICAL_XOR) reduce 396) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 396) (("|") reduce 396) (("}") reduce 396)) 4507 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 397) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 397) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_BOOLEAN_AND) reduce 397) ((T_BOOLEAN_OR) reduce 397) ((T_COALESCE) reduce 397) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 397) ((T_LOGICAL_OR) reduce 397) ((T_LOGICAL_XOR) reduce 397) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 397) (("|") reduce 397) (("}") reduce 397)) 4511 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 424) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 424) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 424) ((T_LOGICAL_OR) reduce 424) ((T_LOGICAL_XOR) reduce 424) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 424)) 4512 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 425) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 425) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 425) ((T_LOGICAL_OR) reduce 425) ((T_LOGICAL_XOR) reduce 425) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 425)) 4513 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 418) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 418) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_BOOLEAN_AND) reduce 418) ((T_BOOLEAN_OR) reduce 418) ((T_COALESCE) reduce 418) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 418) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 418) ((T_IS_NOT_EQUAL) reduce 418) ((T_IS_NOT_IDENTICAL) reduce 418) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 418) ((T_LOGICAL_OR) reduce 418) ((T_LOGICAL_XOR) reduce 418) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 418) ((T_SR) shift) (("^") reduce 418) (("|") reduce 418) (("}") reduce 418)) 4514 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 416) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 416) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_BOOLEAN_AND) reduce 416) ((T_BOOLEAN_OR) reduce 416) ((T_COALESCE) reduce 416) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 416) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 416) ((T_IS_NOT_EQUAL) reduce 416) ((T_IS_NOT_IDENTICAL) reduce 416) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 416) ((T_LOGICAL_OR) reduce 416) ((T_LOGICAL_XOR) reduce 416) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 416) ((T_SR) shift) (("^") reduce 416) (("|") reduce 416) (("}") reduce 416)) 4515 ((("%") reduce 404) (("*") reduce 404) (("+") reduce 404) ((",") reduce 404) (("-") reduce 404) ((".") reduce 404) (("/") reduce 404) (("<") reduce 404) ((">") reduce 404) (("?") reduce 404) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_BOOLEAN_AND) reduce 404) ((T_BOOLEAN_OR) reduce 404) ((T_COALESCE) reduce 404) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 404) ((T_IS_GREATER_OR_EQUAL) reduce 404) ((T_IS_IDENTICAL) reduce 404) ((T_IS_NOT_EQUAL) reduce 404) ((T_IS_NOT_IDENTICAL) reduce 404) ((T_IS_SMALLER_OR_EQUAL) reduce 404) ((T_LOGICAL_AND) reduce 404) ((T_LOGICAL_OR) reduce 404) ((T_LOGICAL_XOR) reduce 404) ((T_POW) shift) ((T_SL) reduce 404) ((T_SPACESHIP) reduce 404) ((T_SR) reduce 404) (("^") reduce 404) (("|") reduce 404) (("}") reduce 404)) 4516 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 399) (("-") shift) ((".") reduce 399) (("/") shift) (("<") reduce 399) ((">") reduce 399) (("?") reduce 399) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_BOOLEAN_AND) reduce 399) ((T_BOOLEAN_OR) reduce 399) ((T_COALESCE) reduce 399) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 399) ((T_IS_GREATER_OR_EQUAL) reduce 399) ((T_IS_IDENTICAL) reduce 399) ((T_IS_NOT_EQUAL) reduce 399) ((T_IS_NOT_IDENTICAL) reduce 399) ((T_IS_SMALLER_OR_EQUAL) reduce 399) ((T_LOGICAL_AND) reduce 399) ((T_LOGICAL_OR) reduce 399) ((T_LOGICAL_XOR) reduce 399) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 399) ((T_SR) shift) (("^") reduce 399) (("|") reduce 399) (("}") reduce 399)) 4517 ((("%") shift) (("*") shift) (("+") reduce 401) ((",") reduce 401) (("-") reduce 401) ((".") reduce 401) (("/") shift) (("<") reduce 401) ((">") reduce 401) (("?") reduce 401) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_BOOLEAN_AND) reduce 401) ((T_BOOLEAN_OR) reduce 401) ((T_COALESCE) reduce 401) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 401) ((T_IS_GREATER_OR_EQUAL) reduce 401) ((T_IS_IDENTICAL) reduce 401) ((T_IS_NOT_EQUAL) reduce 401) ((T_IS_NOT_IDENTICAL) reduce 401) ((T_IS_SMALLER_OR_EQUAL) reduce 401) ((T_LOGICAL_AND) reduce 401) ((T_LOGICAL_OR) reduce 401) ((T_LOGICAL_XOR) reduce 401) ((T_POW) shift) ((T_SL) reduce 401) ((T_SPACESHIP) reduce 401) ((T_SR) reduce 401) (("^") reduce 401) (("|") reduce 401) (("}") reduce 401)) 4518 ((("%") shift) (("*") shift) (("+") reduce 400) ((",") reduce 400) (("-") reduce 400) ((".") reduce 400) (("/") shift) (("<") reduce 400) ((">") reduce 400) (("?") reduce 400) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_BOOLEAN_AND) reduce 400) ((T_BOOLEAN_OR) reduce 400) ((T_COALESCE) reduce 400) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 400) ((T_IS_GREATER_OR_EQUAL) reduce 400) ((T_IS_IDENTICAL) reduce 400) ((T_IS_NOT_EQUAL) reduce 400) ((T_IS_NOT_IDENTICAL) reduce 400) ((T_IS_SMALLER_OR_EQUAL) reduce 400) ((T_LOGICAL_AND) reduce 400) ((T_LOGICAL_OR) reduce 400) ((T_LOGICAL_XOR) reduce 400) ((T_POW) shift) ((T_SL) reduce 400) ((T_SPACESHIP) reduce 400) ((T_SR) reduce 400) (("^") reduce 400) (("|") reduce 400) (("}") reduce 400)) 4519 ((("%") reduce 402) (("*") reduce 402) (("+") reduce 402) ((",") reduce 402) (("-") reduce 402) ((".") reduce 402) (("/") reduce 402) (("<") reduce 402) ((">") reduce 402) (("?") reduce 402) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_BOOLEAN_AND) reduce 402) ((T_BOOLEAN_OR) reduce 402) ((T_COALESCE) reduce 402) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 402) ((T_IS_GREATER_OR_EQUAL) reduce 402) ((T_IS_IDENTICAL) reduce 402) ((T_IS_NOT_EQUAL) reduce 402) ((T_IS_NOT_IDENTICAL) reduce 402) ((T_IS_SMALLER_OR_EQUAL) reduce 402) ((T_LOGICAL_AND) reduce 402) ((T_LOGICAL_OR) reduce 402) ((T_LOGICAL_XOR) reduce 402) ((T_POW) shift) ((T_SL) reduce 402) ((T_SPACESHIP) reduce 402) ((T_SR) reduce 402) (("^") reduce 402) (("|") reduce 402) (("}") reduce 402)) 4520 ((("%") reduce 405) (("*") reduce 405) (("+") reduce 405) ((",") reduce 405) (("-") reduce 405) ((".") reduce 405) (("/") reduce 405) (("<") reduce 405) ((">") reduce 405) (("?") reduce 405) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_BOOLEAN_AND) reduce 405) ((T_BOOLEAN_OR) reduce 405) ((T_COALESCE) reduce 405) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 405) ((T_IS_GREATER_OR_EQUAL) reduce 405) ((T_IS_IDENTICAL) reduce 405) ((T_IS_NOT_EQUAL) reduce 405) ((T_IS_NOT_IDENTICAL) reduce 405) ((T_IS_SMALLER_OR_EQUAL) reduce 405) ((T_LOGICAL_AND) reduce 405) ((T_LOGICAL_OR) reduce 405) ((T_LOGICAL_XOR) reduce 405) ((T_POW) shift) ((T_SL) reduce 405) ((T_SPACESHIP) reduce 405) ((T_SR) reduce 405) (("^") reduce 405) (("|") reduce 405) (("}") reduce 405)) 4522 ((("%") reduce 73) (("(") reduce 73) (("*") reduce 73) (("+") reduce 73) ((",") reduce 73) (("-") reduce 73) ((".") reduce 73) (("/") reduce 73) (("<") reduce 73) ((">") reduce 73) (("?") reduce 73) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_BOOLEAN_AND) reduce 73) ((T_BOOLEAN_OR) reduce 73) ((T_COALESCE) reduce 73) ((T_INSTANCEOF) reduce 73) ((T_IS_EQUAL) reduce 73) ((T_IS_GREATER_OR_EQUAL) reduce 73) ((T_IS_IDENTICAL) reduce 73) ((T_IS_NOT_EQUAL) reduce 73) ((T_IS_NOT_IDENTICAL) reduce 73) ((T_IS_SMALLER_OR_EQUAL) reduce 73) ((T_LOGICAL_AND) reduce 73) ((T_LOGICAL_OR) reduce 73) ((T_LOGICAL_XOR) reduce 73) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 73) ((T_OBJECT_OPERATOR) reduce 73) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 73) ((T_POW) reduce 73) ((T_SL) reduce 73) ((T_SPACESHIP) reduce 73) ((T_SR) reduce 73) (("[") reduce 73) (("^") reduce 73) (("{") reduce 73) (("|") reduce 73) (("}") reduce 73)) 4523 ((("%") reduce 52) (("(") reduce 52) (("*") reduce 52) (("+") reduce 52) ((",") reduce 52) (("-") reduce 52) ((".") reduce 52) (("/") reduce 52) (("<") reduce 52) ((">") reduce 52) (("?") reduce 52) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_BOOLEAN_AND) reduce 52) ((T_BOOLEAN_OR) reduce 52) ((T_COALESCE) reduce 52) ((T_INSTANCEOF) reduce 52) ((T_IS_EQUAL) reduce 52) ((T_IS_GREATER_OR_EQUAL) reduce 52) ((T_IS_IDENTICAL) reduce 52) ((T_IS_NOT_EQUAL) reduce 52) ((T_IS_NOT_IDENTICAL) reduce 52) ((T_IS_SMALLER_OR_EQUAL) reduce 52) ((T_LOGICAL_AND) reduce 52) ((T_LOGICAL_OR) reduce 52) ((T_LOGICAL_XOR) reduce 52) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 52) ((T_OBJECT_OPERATOR) reduce 52) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 52) ((T_POW) reduce 52) ((T_SL) reduce 52) ((T_SPACESHIP) reduce 52) ((T_SR) reduce 52) (("[") reduce 52) (("^") reduce 52) (("{") reduce 52) (("|") reduce 52) (("}") reduce 52)) 4524 ((("%") reduce 27) (("(") reduce 27) (("*") reduce 27) (("+") reduce 27) ((",") reduce 27) (("-") reduce 27) ((".") reduce 27) (("/") reduce 27) (("<") reduce 27) ((">") reduce 27) (("?") reduce 27) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_BOOLEAN_AND) reduce 27) ((T_BOOLEAN_OR) reduce 27) ((T_COALESCE) reduce 27) ((T_INSTANCEOF) reduce 27) ((T_IS_EQUAL) reduce 27) ((T_IS_GREATER_OR_EQUAL) reduce 27) ((T_IS_IDENTICAL) reduce 27) ((T_IS_NOT_EQUAL) reduce 27) ((T_IS_NOT_IDENTICAL) reduce 27) ((T_IS_SMALLER_OR_EQUAL) reduce 27) ((T_LOGICAL_AND) reduce 27) ((T_LOGICAL_OR) reduce 27) ((T_LOGICAL_XOR) reduce 27) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 27) ((T_OBJECT_OPERATOR) reduce 27) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 27) ((T_POW) reduce 27) ((T_SL) reduce 27) ((T_SPACESHIP) reduce 27) ((T_SR) reduce 27) (("[") reduce 27) (("^") reduce 27) (("{") reduce 27) (("|") reduce 27) (("}") reduce 27)) 4525 ((("%") reduce 51) (("(") reduce 51) (("*") reduce 51) (("+") reduce 51) ((",") reduce 51) (("-") reduce 51) ((".") reduce 51) (("/") reduce 51) (("<") reduce 51) ((">") reduce 51) (("?") reduce 51) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_BOOLEAN_AND) reduce 51) ((T_BOOLEAN_OR) reduce 51) ((T_COALESCE) reduce 51) ((T_INSTANCEOF) reduce 51) ((T_IS_EQUAL) reduce 51) ((T_IS_GREATER_OR_EQUAL) reduce 51) ((T_IS_IDENTICAL) reduce 51) ((T_IS_NOT_EQUAL) reduce 51) ((T_IS_NOT_IDENTICAL) reduce 51) ((T_IS_SMALLER_OR_EQUAL) reduce 51) ((T_LOGICAL_AND) reduce 51) ((T_LOGICAL_OR) reduce 51) ((T_LOGICAL_XOR) reduce 51) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 51) ((T_OBJECT_OPERATOR) reduce 51) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 51) ((T_POW) reduce 51) ((T_SL) reduce 51) ((T_SPACESHIP) reduce 51) ((T_SR) reduce 51) (("[") reduce 51) (("^") reduce 51) (("{") reduce 51) (("|") reduce 51) (("}") reduce 51)) 4526 ((("%") reduce 53) (("(") reduce 53) (("*") reduce 53) (("+") reduce 53) ((",") reduce 53) (("-") reduce 53) ((".") reduce 53) (("/") reduce 53) (("<") reduce 53) ((">") reduce 53) (("?") reduce 53) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_BOOLEAN_AND) reduce 53) ((T_BOOLEAN_OR) reduce 53) ((T_COALESCE) reduce 53) ((T_INSTANCEOF) reduce 53) ((T_IS_EQUAL) reduce 53) ((T_IS_GREATER_OR_EQUAL) reduce 53) ((T_IS_IDENTICAL) reduce 53) ((T_IS_NOT_EQUAL) reduce 53) ((T_IS_NOT_IDENTICAL) reduce 53) ((T_IS_SMALLER_OR_EQUAL) reduce 53) ((T_LOGICAL_AND) reduce 53) ((T_LOGICAL_OR) reduce 53) ((T_LOGICAL_XOR) reduce 53) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 53) ((T_OBJECT_OPERATOR) reduce 53) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 53) ((T_POW) reduce 53) ((T_SL) reduce 53) ((T_SPACESHIP) reduce 53) ((T_SR) reduce 53) (("[") reduce 53) (("^") reduce 53) (("{") reduce 53) (("|") reduce 53) (("}") reduce 53)) 4527 ((("%") reduce 49) (("(") reduce 49) (("*") reduce 49) (("+") reduce 49) ((",") reduce 49) (("-") reduce 49) ((".") reduce 49) (("/") reduce 49) (("<") reduce 49) ((">") reduce 49) (("?") reduce 49) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_BOOLEAN_AND) reduce 49) ((T_BOOLEAN_OR) reduce 49) ((T_COALESCE) reduce 49) ((T_INSTANCEOF) reduce 49) ((T_IS_EQUAL) reduce 49) ((T_IS_GREATER_OR_EQUAL) reduce 49) ((T_IS_IDENTICAL) reduce 49) ((T_IS_NOT_EQUAL) reduce 49) ((T_IS_NOT_IDENTICAL) reduce 49) ((T_IS_SMALLER_OR_EQUAL) reduce 49) ((T_LOGICAL_AND) reduce 49) ((T_LOGICAL_OR) reduce 49) ((T_LOGICAL_XOR) reduce 49) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 49) ((T_OBJECT_OPERATOR) reduce 49) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 49) ((T_POW) reduce 49) ((T_SL) reduce 49) ((T_SPACESHIP) reduce 49) ((T_SR) reduce 49) (("[") reduce 49) (("^") reduce 49) (("{") reduce 49) (("|") reduce 49) (("}") reduce 49)) 4528 ((("%") reduce 29) (("(") reduce 29) (("*") reduce 29) (("+") reduce 29) ((",") reduce 29) (("-") reduce 29) ((".") reduce 29) (("/") reduce 29) (("<") reduce 29) ((">") reduce 29) (("?") reduce 29) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_BOOLEAN_AND) reduce 29) ((T_BOOLEAN_OR) reduce 29) ((T_COALESCE) reduce 29) ((T_INSTANCEOF) reduce 29) ((T_IS_EQUAL) reduce 29) ((T_IS_GREATER_OR_EQUAL) reduce 29) ((T_IS_IDENTICAL) reduce 29) ((T_IS_NOT_EQUAL) reduce 29) ((T_IS_NOT_IDENTICAL) reduce 29) ((T_IS_SMALLER_OR_EQUAL) reduce 29) ((T_LOGICAL_AND) reduce 29) ((T_LOGICAL_OR) reduce 29) ((T_LOGICAL_XOR) reduce 29) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 29) ((T_OBJECT_OPERATOR) reduce 29) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 29) ((T_POW) reduce 29) ((T_SL) reduce 29) ((T_SPACESHIP) reduce 29) ((T_SR) reduce 29) (("[") reduce 29) (("^") reduce 29) (("{") reduce 29) (("|") reduce 29) (("}") reduce 29)) 4529 ((("%") reduce 59) (("(") reduce 59) (("*") reduce 59) (("+") reduce 59) ((",") reduce 59) (("-") reduce 59) ((".") reduce 59) (("/") reduce 59) (("<") reduce 59) ((">") reduce 59) (("?") reduce 59) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_BOOLEAN_AND) reduce 59) ((T_BOOLEAN_OR) reduce 59) ((T_COALESCE) reduce 59) ((T_INSTANCEOF) reduce 59) ((T_IS_EQUAL) reduce 59) ((T_IS_GREATER_OR_EQUAL) reduce 59) ((T_IS_IDENTICAL) reduce 59) ((T_IS_NOT_EQUAL) reduce 59) ((T_IS_NOT_IDENTICAL) reduce 59) ((T_IS_SMALLER_OR_EQUAL) reduce 59) ((T_LOGICAL_AND) reduce 59) ((T_LOGICAL_OR) reduce 59) ((T_LOGICAL_XOR) reduce 59) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 59) ((T_OBJECT_OPERATOR) reduce 59) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 59) ((T_POW) reduce 59) ((T_SL) reduce 59) ((T_SPACESHIP) reduce 59) ((T_SR) reduce 59) (("[") reduce 59) (("^") reduce 59) (("{") reduce 59) (("|") reduce 59) (("}") reduce 59)) 4530 ((("%") reduce 60) (("(") reduce 60) (("*") reduce 60) (("+") reduce 60) ((",") reduce 60) (("-") reduce 60) ((".") reduce 60) (("/") reduce 60) (("<") reduce 60) ((">") reduce 60) (("?") reduce 60) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_BOOLEAN_AND) reduce 60) ((T_BOOLEAN_OR) reduce 60) ((T_COALESCE) reduce 60) ((T_INSTANCEOF) reduce 60) ((T_IS_EQUAL) reduce 60) ((T_IS_GREATER_OR_EQUAL) reduce 60) ((T_IS_IDENTICAL) reduce 60) ((T_IS_NOT_EQUAL) reduce 60) ((T_IS_NOT_IDENTICAL) reduce 60) ((T_IS_SMALLER_OR_EQUAL) reduce 60) ((T_LOGICAL_AND) reduce 60) ((T_LOGICAL_OR) reduce 60) ((T_LOGICAL_XOR) reduce 60) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 60) ((T_OBJECT_OPERATOR) reduce 60) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 60) ((T_POW) reduce 60) ((T_SL) reduce 60) ((T_SPACESHIP) reduce 60) ((T_SR) reduce 60) (("[") reduce 60) (("^") reduce 60) (("{") reduce 60) (("|") reduce 60) (("}") reduce 60)) 4531 ((("%") reduce 11) (("(") reduce 11) (("*") reduce 11) (("+") reduce 11) ((",") reduce 11) (("-") reduce 11) ((".") reduce 11) (("/") reduce 11) (("<") reduce 11) ((">") reduce 11) (("?") reduce 11) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_BOOLEAN_AND) reduce 11) ((T_BOOLEAN_OR) reduce 11) ((T_COALESCE) reduce 11) ((T_INSTANCEOF) reduce 11) ((T_IS_EQUAL) reduce 11) ((T_IS_GREATER_OR_EQUAL) reduce 11) ((T_IS_IDENTICAL) reduce 11) ((T_IS_NOT_EQUAL) reduce 11) ((T_IS_NOT_IDENTICAL) reduce 11) ((T_IS_SMALLER_OR_EQUAL) reduce 11) ((T_LOGICAL_AND) reduce 11) ((T_LOGICAL_OR) reduce 11) ((T_LOGICAL_XOR) reduce 11) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 11) ((T_OBJECT_OPERATOR) reduce 11) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 11) ((T_POW) reduce 11) ((T_SL) reduce 11) ((T_SPACESHIP) reduce 11) ((T_SR) reduce 11) (("[") reduce 11) (("^") reduce 11) (("{") reduce 11) (("|") reduce 11) (("}") reduce 11)) 4532 ((("%") reduce 42) (("(") reduce 42) (("*") reduce 42) (("+") reduce 42) ((",") reduce 42) (("-") reduce 42) ((".") reduce 42) (("/") reduce 42) (("<") reduce 42) ((">") reduce 42) (("?") reduce 42) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_BOOLEAN_AND) reduce 42) ((T_BOOLEAN_OR) reduce 42) ((T_COALESCE) reduce 42) ((T_INSTANCEOF) reduce 42) ((T_IS_EQUAL) reduce 42) ((T_IS_GREATER_OR_EQUAL) reduce 42) ((T_IS_IDENTICAL) reduce 42) ((T_IS_NOT_EQUAL) reduce 42) ((T_IS_NOT_IDENTICAL) reduce 42) ((T_IS_SMALLER_OR_EQUAL) reduce 42) ((T_LOGICAL_AND) reduce 42) ((T_LOGICAL_OR) reduce 42) ((T_LOGICAL_XOR) reduce 42) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 42) ((T_OBJECT_OPERATOR) reduce 42) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 42) ((T_POW) reduce 42) ((T_SL) reduce 42) ((T_SPACESHIP) reduce 42) ((T_SR) reduce 42) (("[") reduce 42) (("^") reduce 42) (("{") reduce 42) (("|") reduce 42) (("}") reduce 42)) 4533 ((("%") reduce 39) (("(") reduce 39) (("*") reduce 39) (("+") reduce 39) ((",") reduce 39) (("-") reduce 39) ((".") reduce 39) (("/") reduce 39) (("<") reduce 39) ((">") reduce 39) (("?") reduce 39) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_BOOLEAN_AND) reduce 39) ((T_BOOLEAN_OR) reduce 39) ((T_COALESCE) reduce 39) ((T_INSTANCEOF) reduce 39) ((T_IS_EQUAL) reduce 39) ((T_IS_GREATER_OR_EQUAL) reduce 39) ((T_IS_IDENTICAL) reduce 39) ((T_IS_NOT_EQUAL) reduce 39) ((T_IS_NOT_IDENTICAL) reduce 39) ((T_IS_SMALLER_OR_EQUAL) reduce 39) ((T_LOGICAL_AND) reduce 39) ((T_LOGICAL_OR) reduce 39) ((T_LOGICAL_XOR) reduce 39) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 39) ((T_OBJECT_OPERATOR) reduce 39) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 39) ((T_POW) reduce 39) ((T_SL) reduce 39) ((T_SPACESHIP) reduce 39) ((T_SR) reduce 39) (("[") reduce 39) (("^") reduce 39) (("{") reduce 39) (("|") reduce 39) (("}") reduce 39)) 4534 ((("%") reduce 25) (("(") reduce 25) (("*") reduce 25) (("+") reduce 25) ((",") reduce 25) (("-") reduce 25) ((".") reduce 25) (("/") reduce 25) (("<") reduce 25) ((">") reduce 25) (("?") reduce 25) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_BOOLEAN_AND) reduce 25) ((T_BOOLEAN_OR) reduce 25) ((T_COALESCE) reduce 25) ((T_INSTANCEOF) reduce 25) ((T_IS_EQUAL) reduce 25) ((T_IS_GREATER_OR_EQUAL) reduce 25) ((T_IS_IDENTICAL) reduce 25) ((T_IS_NOT_EQUAL) reduce 25) ((T_IS_NOT_IDENTICAL) reduce 25) ((T_IS_SMALLER_OR_EQUAL) reduce 25) ((T_LOGICAL_AND) reduce 25) ((T_LOGICAL_OR) reduce 25) ((T_LOGICAL_XOR) reduce 25) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 25) ((T_OBJECT_OPERATOR) reduce 25) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 25) ((T_POW) reduce 25) ((T_SL) reduce 25) ((T_SPACESHIP) reduce 25) ((T_SR) reduce 25) (("[") reduce 25) (("^") reduce 25) (("{") reduce 25) (("|") reduce 25) (("}") reduce 25)) 4535 ((("%") reduce 50) (("(") reduce 50) (("*") reduce 50) (("+") reduce 50) ((",") reduce 50) (("-") reduce 50) ((".") reduce 50) (("/") reduce 50) (("<") reduce 50) ((">") reduce 50) (("?") reduce 50) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_BOOLEAN_AND) reduce 50) ((T_BOOLEAN_OR) reduce 50) ((T_COALESCE) reduce 50) ((T_INSTANCEOF) reduce 50) ((T_IS_EQUAL) reduce 50) ((T_IS_GREATER_OR_EQUAL) reduce 50) ((T_IS_IDENTICAL) reduce 50) ((T_IS_NOT_EQUAL) reduce 50) ((T_IS_NOT_IDENTICAL) reduce 50) ((T_IS_SMALLER_OR_EQUAL) reduce 50) ((T_LOGICAL_AND) reduce 50) ((T_LOGICAL_OR) reduce 50) ((T_LOGICAL_XOR) reduce 50) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 50) ((T_OBJECT_OPERATOR) reduce 50) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 50) ((T_POW) reduce 50) ((T_SL) reduce 50) ((T_SPACESHIP) reduce 50) ((T_SR) reduce 50) (("[") reduce 50) (("^") reduce 50) (("{") reduce 50) (("|") reduce 50) (("}") reduce 50)) 4536 ((("%") reduce 66) (("(") reduce 66) (("*") reduce 66) (("+") reduce 66) ((",") reduce 66) (("-") reduce 66) ((".") reduce 66) (("/") reduce 66) (("<") reduce 66) ((">") reduce 66) (("?") reduce 66) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_BOOLEAN_AND) reduce 66) ((T_BOOLEAN_OR) reduce 66) ((T_COALESCE) reduce 66) ((T_INSTANCEOF) reduce 66) ((T_IS_EQUAL) reduce 66) ((T_IS_GREATER_OR_EQUAL) reduce 66) ((T_IS_IDENTICAL) reduce 66) ((T_IS_NOT_EQUAL) reduce 66) ((T_IS_NOT_IDENTICAL) reduce 66) ((T_IS_SMALLER_OR_EQUAL) reduce 66) ((T_LOGICAL_AND) reduce 66) ((T_LOGICAL_OR) reduce 66) ((T_LOGICAL_XOR) reduce 66) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 66) ((T_OBJECT_OPERATOR) reduce 66) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 66) ((T_POW) reduce 66) ((T_SL) reduce 66) ((T_SPACESHIP) reduce 66) ((T_SR) reduce 66) (("[") reduce 66) (("^") reduce 66) (("{") reduce 66) (("|") reduce 66) (("}") reduce 66)) 4537 ((("%") reduce 18) (("(") reduce 18) (("*") reduce 18) (("+") reduce 18) ((",") reduce 18) (("-") reduce 18) ((".") reduce 18) (("/") reduce 18) (("<") reduce 18) ((">") reduce 18) (("?") reduce 18) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_BOOLEAN_AND) reduce 18) ((T_BOOLEAN_OR) reduce 18) ((T_COALESCE) reduce 18) ((T_INSTANCEOF) reduce 18) ((T_IS_EQUAL) reduce 18) ((T_IS_GREATER_OR_EQUAL) reduce 18) ((T_IS_IDENTICAL) reduce 18) ((T_IS_NOT_EQUAL) reduce 18) ((T_IS_NOT_IDENTICAL) reduce 18) ((T_IS_SMALLER_OR_EQUAL) reduce 18) ((T_LOGICAL_AND) reduce 18) ((T_LOGICAL_OR) reduce 18) ((T_LOGICAL_XOR) reduce 18) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 18) ((T_OBJECT_OPERATOR) reduce 18) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 18) ((T_POW) reduce 18) ((T_SL) reduce 18) ((T_SPACESHIP) reduce 18) ((T_SR) reduce 18) (("[") reduce 18) (("^") reduce 18) (("{") reduce 18) (("|") reduce 18) (("}") reduce 18)) 4538 ((("%") reduce 17) (("(") reduce 17) (("*") reduce 17) (("+") reduce 17) ((",") reduce 17) (("-") reduce 17) ((".") reduce 17) (("/") reduce 17) (("<") reduce 17) ((">") reduce 17) (("?") reduce 17) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_BOOLEAN_AND) reduce 17) ((T_BOOLEAN_OR) reduce 17) ((T_COALESCE) reduce 17) ((T_INSTANCEOF) reduce 17) ((T_IS_EQUAL) reduce 17) ((T_IS_GREATER_OR_EQUAL) reduce 17) ((T_IS_IDENTICAL) reduce 17) ((T_IS_NOT_EQUAL) reduce 17) ((T_IS_NOT_IDENTICAL) reduce 17) ((T_IS_SMALLER_OR_EQUAL) reduce 17) ((T_LOGICAL_AND) reduce 17) ((T_LOGICAL_OR) reduce 17) ((T_LOGICAL_XOR) reduce 17) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 17) ((T_OBJECT_OPERATOR) reduce 17) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 17) ((T_POW) reduce 17) ((T_SL) reduce 17) ((T_SPACESHIP) reduce 17) ((T_SR) reduce 17) (("[") reduce 17) (("^") reduce 17) (("{") reduce 17) (("|") reduce 17) (("}") reduce 17)) 4539 ((("%") reduce 15) (("(") reduce 15) (("*") reduce 15) (("+") reduce 15) ((",") reduce 15) (("-") reduce 15) ((".") reduce 15) (("/") reduce 15) (("<") reduce 15) ((">") reduce 15) (("?") reduce 15) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_BOOLEAN_AND) reduce 15) ((T_BOOLEAN_OR) reduce 15) ((T_COALESCE) reduce 15) ((T_INSTANCEOF) reduce 15) ((T_IS_EQUAL) reduce 15) ((T_IS_GREATER_OR_EQUAL) reduce 15) ((T_IS_IDENTICAL) reduce 15) ((T_IS_NOT_EQUAL) reduce 15) ((T_IS_NOT_IDENTICAL) reduce 15) ((T_IS_SMALLER_OR_EQUAL) reduce 15) ((T_LOGICAL_AND) reduce 15) ((T_LOGICAL_OR) reduce 15) ((T_LOGICAL_XOR) reduce 15) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 15) ((T_OBJECT_OPERATOR) reduce 15) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 15) ((T_POW) reduce 15) ((T_SL) reduce 15) ((T_SPACESHIP) reduce 15) ((T_SR) reduce 15) (("[") reduce 15) (("^") reduce 15) (("{") reduce 15) (("|") reduce 15) (("}") reduce 15)) 4540 ((("%") reduce 14) (("(") reduce 14) (("*") reduce 14) (("+") reduce 14) ((",") reduce 14) (("-") reduce 14) ((".") reduce 14) (("/") reduce 14) (("<") reduce 14) ((">") reduce 14) (("?") reduce 14) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_BOOLEAN_AND) reduce 14) ((T_BOOLEAN_OR) reduce 14) ((T_COALESCE) reduce 14) ((T_INSTANCEOF) reduce 14) ((T_IS_EQUAL) reduce 14) ((T_IS_GREATER_OR_EQUAL) reduce 14) ((T_IS_IDENTICAL) reduce 14) ((T_IS_NOT_EQUAL) reduce 14) ((T_IS_NOT_IDENTICAL) reduce 14) ((T_IS_SMALLER_OR_EQUAL) reduce 14) ((T_LOGICAL_AND) reduce 14) ((T_LOGICAL_OR) reduce 14) ((T_LOGICAL_XOR) reduce 14) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 14) ((T_OBJECT_OPERATOR) reduce 14) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 14) ((T_POW) reduce 14) ((T_SL) reduce 14) ((T_SPACESHIP) reduce 14) ((T_SR) reduce 14) (("[") reduce 14) (("^") reduce 14) (("{") reduce 14) (("|") reduce 14) (("}") reduce 14)) 4541 ((("%") reduce 38) (("(") reduce 38) (("*") reduce 38) (("+") reduce 38) ((",") reduce 38) (("-") reduce 38) ((".") reduce 38) (("/") reduce 38) (("<") reduce 38) ((">") reduce 38) (("?") reduce 38) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_BOOLEAN_AND) reduce 38) ((T_BOOLEAN_OR) reduce 38) ((T_COALESCE) reduce 38) ((T_INSTANCEOF) reduce 38) ((T_IS_EQUAL) reduce 38) ((T_IS_GREATER_OR_EQUAL) reduce 38) ((T_IS_IDENTICAL) reduce 38) ((T_IS_NOT_EQUAL) reduce 38) ((T_IS_NOT_IDENTICAL) reduce 38) ((T_IS_SMALLER_OR_EQUAL) reduce 38) ((T_LOGICAL_AND) reduce 38) ((T_LOGICAL_OR) reduce 38) ((T_LOGICAL_XOR) reduce 38) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 38) ((T_OBJECT_OPERATOR) reduce 38) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 38) ((T_POW) reduce 38) ((T_SL) reduce 38) ((T_SPACESHIP) reduce 38) ((T_SR) reduce 38) (("[") reduce 38) (("^") reduce 38) (("{") reduce 38) (("|") reduce 38) (("}") reduce 38)) 4542 ((("%") reduce 26) (("(") reduce 26) (("*") reduce 26) (("+") reduce 26) ((",") reduce 26) (("-") reduce 26) ((".") reduce 26) (("/") reduce 26) (("<") reduce 26) ((">") reduce 26) (("?") reduce 26) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_BOOLEAN_AND) reduce 26) ((T_BOOLEAN_OR) reduce 26) ((T_COALESCE) reduce 26) ((T_INSTANCEOF) reduce 26) ((T_IS_EQUAL) reduce 26) ((T_IS_GREATER_OR_EQUAL) reduce 26) ((T_IS_IDENTICAL) reduce 26) ((T_IS_NOT_EQUAL) reduce 26) ((T_IS_NOT_IDENTICAL) reduce 26) ((T_IS_SMALLER_OR_EQUAL) reduce 26) ((T_LOGICAL_AND) reduce 26) ((T_LOGICAL_OR) reduce 26) ((T_LOGICAL_XOR) reduce 26) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 26) ((T_OBJECT_OPERATOR) reduce 26) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 26) ((T_POW) reduce 26) ((T_SL) reduce 26) ((T_SPACESHIP) reduce 26) ((T_SR) reduce 26) (("[") reduce 26) (("^") reduce 26) (("{") reduce 26) (("|") reduce 26) (("}") reduce 26)) 4543 ((("%") reduce 22) (("(") reduce 22) (("*") reduce 22) (("+") reduce 22) ((",") reduce 22) (("-") reduce 22) ((".") reduce 22) (("/") reduce 22) (("<") reduce 22) ((">") reduce 22) (("?") reduce 22) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_BOOLEAN_AND) reduce 22) ((T_BOOLEAN_OR) reduce 22) ((T_COALESCE) reduce 22) ((T_INSTANCEOF) reduce 22) ((T_IS_EQUAL) reduce 22) ((T_IS_GREATER_OR_EQUAL) reduce 22) ((T_IS_IDENTICAL) reduce 22) ((T_IS_NOT_EQUAL) reduce 22) ((T_IS_NOT_IDENTICAL) reduce 22) ((T_IS_SMALLER_OR_EQUAL) reduce 22) ((T_LOGICAL_AND) reduce 22) ((T_LOGICAL_OR) reduce 22) ((T_LOGICAL_XOR) reduce 22) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 22) ((T_OBJECT_OPERATOR) reduce 22) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 22) ((T_POW) reduce 22) ((T_SL) reduce 22) ((T_SPACESHIP) reduce 22) ((T_SR) reduce 22) (("[") reduce 22) (("^") reduce 22) (("{") reduce 22) (("|") reduce 22) (("}") reduce 22)) 4544 ((("%") reduce 24) (("(") reduce 24) (("*") reduce 24) (("+") reduce 24) ((",") reduce 24) (("-") reduce 24) ((".") reduce 24) (("/") reduce 24) (("<") reduce 24) ((">") reduce 24) (("?") reduce 24) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_BOOLEAN_AND) reduce 24) ((T_BOOLEAN_OR) reduce 24) ((T_COALESCE) reduce 24) ((T_INSTANCEOF) reduce 24) ((T_IS_EQUAL) reduce 24) ((T_IS_GREATER_OR_EQUAL) reduce 24) ((T_IS_IDENTICAL) reduce 24) ((T_IS_NOT_EQUAL) reduce 24) ((T_IS_NOT_IDENTICAL) reduce 24) ((T_IS_SMALLER_OR_EQUAL) reduce 24) ((T_LOGICAL_AND) reduce 24) ((T_LOGICAL_OR) reduce 24) ((T_LOGICAL_XOR) reduce 24) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 24) ((T_OBJECT_OPERATOR) reduce 24) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 24) ((T_POW) reduce 24) ((T_SL) reduce 24) ((T_SPACESHIP) reduce 24) ((T_SR) reduce 24) (("[") reduce 24) (("^") reduce 24) (("{") reduce 24) (("|") reduce 24) (("}") reduce 24)) 4545 ((("%") reduce 16) (("(") reduce 16) (("*") reduce 16) (("+") reduce 16) ((",") reduce 16) (("-") reduce 16) ((".") reduce 16) (("/") reduce 16) (("<") reduce 16) ((">") reduce 16) (("?") reduce 16) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_BOOLEAN_AND) reduce 16) ((T_BOOLEAN_OR) reduce 16) ((T_COALESCE) reduce 16) ((T_INSTANCEOF) reduce 16) ((T_IS_EQUAL) reduce 16) ((T_IS_GREATER_OR_EQUAL) reduce 16) ((T_IS_IDENTICAL) reduce 16) ((T_IS_NOT_EQUAL) reduce 16) ((T_IS_NOT_IDENTICAL) reduce 16) ((T_IS_SMALLER_OR_EQUAL) reduce 16) ((T_LOGICAL_AND) reduce 16) ((T_LOGICAL_OR) reduce 16) ((T_LOGICAL_XOR) reduce 16) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 16) ((T_OBJECT_OPERATOR) reduce 16) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 16) ((T_POW) reduce 16) ((T_SL) reduce 16) ((T_SPACESHIP) reduce 16) ((T_SR) reduce 16) (("[") reduce 16) (("^") reduce 16) (("{") reduce 16) (("|") reduce 16) (("}") reduce 16)) 4546 ((("%") reduce 48) (("(") reduce 48) (("*") reduce 48) (("+") reduce 48) ((",") reduce 48) (("-") reduce 48) ((".") reduce 48) (("/") reduce 48) (("<") reduce 48) ((">") reduce 48) (("?") reduce 48) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_BOOLEAN_AND) reduce 48) ((T_BOOLEAN_OR) reduce 48) ((T_COALESCE) reduce 48) ((T_INSTANCEOF) reduce 48) ((T_IS_EQUAL) reduce 48) ((T_IS_GREATER_OR_EQUAL) reduce 48) ((T_IS_IDENTICAL) reduce 48) ((T_IS_NOT_EQUAL) reduce 48) ((T_IS_NOT_IDENTICAL) reduce 48) ((T_IS_SMALLER_OR_EQUAL) reduce 48) ((T_LOGICAL_AND) reduce 48) ((T_LOGICAL_OR) reduce 48) ((T_LOGICAL_XOR) reduce 48) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 48) ((T_OBJECT_OPERATOR) reduce 48) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 48) ((T_POW) reduce 48) ((T_SL) reduce 48) ((T_SPACESHIP) reduce 48) ((T_SR) reduce 48) (("[") reduce 48) (("^") reduce 48) (("{") reduce 48) (("|") reduce 48) (("}") reduce 48)) 4547 ((("%") reduce 20) (("(") reduce 20) (("*") reduce 20) (("+") reduce 20) ((",") reduce 20) (("-") reduce 20) ((".") reduce 20) (("/") reduce 20) (("<") reduce 20) ((">") reduce 20) (("?") reduce 20) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_BOOLEAN_AND) reduce 20) ((T_BOOLEAN_OR) reduce 20) ((T_COALESCE) reduce 20) ((T_INSTANCEOF) reduce 20) ((T_IS_EQUAL) reduce 20) ((T_IS_GREATER_OR_EQUAL) reduce 20) ((T_IS_IDENTICAL) reduce 20) ((T_IS_NOT_EQUAL) reduce 20) ((T_IS_NOT_IDENTICAL) reduce 20) ((T_IS_SMALLER_OR_EQUAL) reduce 20) ((T_LOGICAL_AND) reduce 20) ((T_LOGICAL_OR) reduce 20) ((T_LOGICAL_XOR) reduce 20) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 20) ((T_OBJECT_OPERATOR) reduce 20) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 20) ((T_POW) reduce 20) ((T_SL) reduce 20) ((T_SPACESHIP) reduce 20) ((T_SR) reduce 20) (("[") reduce 20) (("^") reduce 20) (("{") reduce 20) (("|") reduce 20) (("}") reduce 20)) 4548 ((("%") reduce 70) (("(") reduce 70) (("*") reduce 70) (("+") reduce 70) ((",") reduce 70) (("-") reduce 70) ((".") reduce 70) (("/") reduce 70) (("<") reduce 70) ((">") reduce 70) (("?") reduce 70) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_BOOLEAN_AND) reduce 70) ((T_BOOLEAN_OR) reduce 70) ((T_COALESCE) reduce 70) ((T_INSTANCEOF) reduce 70) ((T_IS_EQUAL) reduce 70) ((T_IS_GREATER_OR_EQUAL) reduce 70) ((T_IS_IDENTICAL) reduce 70) ((T_IS_NOT_EQUAL) reduce 70) ((T_IS_NOT_IDENTICAL) reduce 70) ((T_IS_SMALLER_OR_EQUAL) reduce 70) ((T_LOGICAL_AND) reduce 70) ((T_LOGICAL_OR) reduce 70) ((T_LOGICAL_XOR) reduce 70) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 70) ((T_OBJECT_OPERATOR) reduce 70) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 70) ((T_POW) reduce 70) ((T_SL) reduce 70) ((T_SPACESHIP) reduce 70) ((T_SR) reduce 70) (("[") reduce 70) (("^") reduce 70) (("{") reduce 70) (("|") reduce 70) (("}") reduce 70)) 4549 ((("%") reduce 3) (("(") reduce 3) (("*") reduce 3) (("+") reduce 3) ((",") reduce 3) (("-") reduce 3) ((".") reduce 3) (("/") reduce 3) (("<") reduce 3) ((">") reduce 3) (("?") reduce 3) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_BOOLEAN_AND) reduce 3) ((T_BOOLEAN_OR) reduce 3) ((T_COALESCE) reduce 3) ((T_INSTANCEOF) reduce 3) ((T_IS_EQUAL) reduce 3) ((T_IS_GREATER_OR_EQUAL) reduce 3) ((T_IS_IDENTICAL) reduce 3) ((T_IS_NOT_EQUAL) reduce 3) ((T_IS_NOT_IDENTICAL) reduce 3) ((T_IS_SMALLER_OR_EQUAL) reduce 3) ((T_LOGICAL_AND) reduce 3) ((T_LOGICAL_OR) reduce 3) ((T_LOGICAL_XOR) reduce 3) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 3) ((T_OBJECT_OPERATOR) reduce 3) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 3) ((T_POW) reduce 3) ((T_SL) reduce 3) ((T_SPACESHIP) reduce 3) ((T_SR) reduce 3) (("[") reduce 3) (("^") reduce 3) (("{") reduce 3) (("|") reduce 3) (("}") reduce 3)) 4550 ((("%") reduce 12) (("(") reduce 12) (("*") reduce 12) (("+") reduce 12) ((",") reduce 12) (("-") reduce 12) ((".") reduce 12) (("/") reduce 12) (("<") reduce 12) ((">") reduce 12) (("?") reduce 12) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_BOOLEAN_AND) reduce 12) ((T_BOOLEAN_OR) reduce 12) ((T_COALESCE) reduce 12) ((T_INSTANCEOF) reduce 12) ((T_IS_EQUAL) reduce 12) ((T_IS_GREATER_OR_EQUAL) reduce 12) ((T_IS_IDENTICAL) reduce 12) ((T_IS_NOT_EQUAL) reduce 12) ((T_IS_NOT_IDENTICAL) reduce 12) ((T_IS_SMALLER_OR_EQUAL) reduce 12) ((T_LOGICAL_AND) reduce 12) ((T_LOGICAL_OR) reduce 12) ((T_LOGICAL_XOR) reduce 12) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 12) ((T_OBJECT_OPERATOR) reduce 12) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 12) ((T_POW) reduce 12) ((T_SL) reduce 12) ((T_SPACESHIP) reduce 12) ((T_SR) reduce 12) (("[") reduce 12) (("^") reduce 12) (("{") reduce 12) (("|") reduce 12) (("}") reduce 12)) 4551 ((("%") reduce 54) (("(") reduce 54) (("*") reduce 54) (("+") reduce 54) ((",") reduce 54) (("-") reduce 54) ((".") reduce 54) (("/") reduce 54) (("<") reduce 54) ((">") reduce 54) (("?") reduce 54) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_BOOLEAN_AND) reduce 54) ((T_BOOLEAN_OR) reduce 54) ((T_COALESCE) reduce 54) ((T_INSTANCEOF) reduce 54) ((T_IS_EQUAL) reduce 54) ((T_IS_GREATER_OR_EQUAL) reduce 54) ((T_IS_IDENTICAL) reduce 54) ((T_IS_NOT_EQUAL) reduce 54) ((T_IS_NOT_IDENTICAL) reduce 54) ((T_IS_SMALLER_OR_EQUAL) reduce 54) ((T_LOGICAL_AND) reduce 54) ((T_LOGICAL_OR) reduce 54) ((T_LOGICAL_XOR) reduce 54) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 54) ((T_OBJECT_OPERATOR) reduce 54) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 54) ((T_POW) reduce 54) ((T_SL) reduce 54) ((T_SPACESHIP) reduce 54) ((T_SR) reduce 54) (("[") reduce 54) (("^") reduce 54) (("{") reduce 54) (("|") reduce 54) (("}") reduce 54)) 4552 ((("%") reduce 65) (("(") reduce 65) (("*") reduce 65) (("+") reduce 65) ((",") reduce 65) (("-") reduce 65) ((".") reduce 65) (("/") reduce 65) (("<") reduce 65) ((">") reduce 65) (("?") reduce 65) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_BOOLEAN_AND) reduce 65) ((T_BOOLEAN_OR) reduce 65) ((T_COALESCE) reduce 65) ((T_INSTANCEOF) reduce 65) ((T_IS_EQUAL) reduce 65) ((T_IS_GREATER_OR_EQUAL) reduce 65) ((T_IS_IDENTICAL) reduce 65) ((T_IS_NOT_EQUAL) reduce 65) ((T_IS_NOT_IDENTICAL) reduce 65) ((T_IS_SMALLER_OR_EQUAL) reduce 65) ((T_LOGICAL_AND) reduce 65) ((T_LOGICAL_OR) reduce 65) ((T_LOGICAL_XOR) reduce 65) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 65) ((T_OBJECT_OPERATOR) reduce 65) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 65) ((T_POW) reduce 65) ((T_SL) reduce 65) ((T_SPACESHIP) reduce 65) ((T_SR) reduce 65) (("[") reduce 65) (("^") reduce 65) (("{") reduce 65) (("|") reduce 65) (("}") reduce 65)) 4553 ((("%") reduce 74) (("(") reduce 74) (("*") reduce 74) (("+") reduce 74) ((",") reduce 74) (("-") reduce 74) ((".") reduce 74) (("/") reduce 74) (("<") reduce 74) ((">") reduce 74) (("?") reduce 74) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_BOOLEAN_AND) reduce 74) ((T_BOOLEAN_OR) reduce 74) ((T_COALESCE) reduce 74) ((T_INSTANCEOF) reduce 74) ((T_IS_EQUAL) reduce 74) ((T_IS_GREATER_OR_EQUAL) reduce 74) ((T_IS_IDENTICAL) reduce 74) ((T_IS_NOT_EQUAL) reduce 74) ((T_IS_NOT_IDENTICAL) reduce 74) ((T_IS_SMALLER_OR_EQUAL) reduce 74) ((T_LOGICAL_AND) reduce 74) ((T_LOGICAL_OR) reduce 74) ((T_LOGICAL_XOR) reduce 74) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 74) ((T_OBJECT_OPERATOR) reduce 74) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 74) ((T_POW) reduce 74) ((T_SL) reduce 74) ((T_SPACESHIP) reduce 74) ((T_SR) reduce 74) (("[") reduce 74) (("^") reduce 74) (("{") reduce 74) (("|") reduce 74) (("}") reduce 74)) 4554 ((("%") reduce 30) (("(") reduce 30) (("*") reduce 30) (("+") reduce 30) ((",") reduce 30) (("-") reduce 30) ((".") reduce 30) (("/") reduce 30) (("<") reduce 30) ((">") reduce 30) (("?") reduce 30) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_BOOLEAN_AND) reduce 30) ((T_BOOLEAN_OR) reduce 30) ((T_COALESCE) reduce 30) ((T_INSTANCEOF) reduce 30) ((T_IS_EQUAL) reduce 30) ((T_IS_GREATER_OR_EQUAL) reduce 30) ((T_IS_IDENTICAL) reduce 30) ((T_IS_NOT_EQUAL) reduce 30) ((T_IS_NOT_IDENTICAL) reduce 30) ((T_IS_SMALLER_OR_EQUAL) reduce 30) ((T_LOGICAL_AND) reduce 30) ((T_LOGICAL_OR) reduce 30) ((T_LOGICAL_XOR) reduce 30) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 30) ((T_OBJECT_OPERATOR) reduce 30) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 30) ((T_POW) reduce 30) ((T_SL) reduce 30) ((T_SPACESHIP) reduce 30) ((T_SR) reduce 30) (("[") reduce 30) (("^") reduce 30) (("{") reduce 30) (("|") reduce 30) (("}") reduce 30)) 4555 ((("%") reduce 68) (("(") reduce 68) (("*") reduce 68) (("+") reduce 68) ((",") reduce 68) (("-") reduce 68) ((".") reduce 68) (("/") reduce 68) (("<") reduce 68) ((">") reduce 68) (("?") reduce 68) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_BOOLEAN_AND) reduce 68) ((T_BOOLEAN_OR) reduce 68) ((T_COALESCE) reduce 68) ((T_INSTANCEOF) reduce 68) ((T_IS_EQUAL) reduce 68) ((T_IS_GREATER_OR_EQUAL) reduce 68) ((T_IS_IDENTICAL) reduce 68) ((T_IS_NOT_EQUAL) reduce 68) ((T_IS_NOT_IDENTICAL) reduce 68) ((T_IS_SMALLER_OR_EQUAL) reduce 68) ((T_LOGICAL_AND) reduce 68) ((T_LOGICAL_OR) reduce 68) ((T_LOGICAL_XOR) reduce 68) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 68) ((T_OBJECT_OPERATOR) reduce 68) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 68) ((T_POW) reduce 68) ((T_SL) reduce 68) ((T_SPACESHIP) reduce 68) ((T_SR) reduce 68) (("[") reduce 68) (("^") reduce 68) (("{") reduce 68) (("|") reduce 68) (("}") reduce 68)) 4556 ((("%") reduce 21) (("(") reduce 21) (("*") reduce 21) (("+") reduce 21) ((",") reduce 21) (("-") reduce 21) ((".") reduce 21) (("/") reduce 21) (("<") reduce 21) ((">") reduce 21) (("?") reduce 21) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_BOOLEAN_AND) reduce 21) ((T_BOOLEAN_OR) reduce 21) ((T_COALESCE) reduce 21) ((T_INSTANCEOF) reduce 21) ((T_IS_EQUAL) reduce 21) ((T_IS_GREATER_OR_EQUAL) reduce 21) ((T_IS_IDENTICAL) reduce 21) ((T_IS_NOT_EQUAL) reduce 21) ((T_IS_NOT_IDENTICAL) reduce 21) ((T_IS_SMALLER_OR_EQUAL) reduce 21) ((T_LOGICAL_AND) reduce 21) ((T_LOGICAL_OR) reduce 21) ((T_LOGICAL_XOR) reduce 21) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 21) ((T_OBJECT_OPERATOR) reduce 21) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 21) ((T_POW) reduce 21) ((T_SL) reduce 21) ((T_SPACESHIP) reduce 21) ((T_SR) reduce 21) (("[") reduce 21) (("^") reduce 21) (("{") reduce 21) (("|") reduce 21) (("}") reduce 21)) 4557 ((("%") reduce 23) (("(") reduce 23) (("*") reduce 23) (("+") reduce 23) ((",") reduce 23) (("-") reduce 23) ((".") reduce 23) (("/") reduce 23) (("<") reduce 23) ((">") reduce 23) (("?") reduce 23) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_BOOLEAN_AND) reduce 23) ((T_BOOLEAN_OR) reduce 23) ((T_COALESCE) reduce 23) ((T_INSTANCEOF) reduce 23) ((T_IS_EQUAL) reduce 23) ((T_IS_GREATER_OR_EQUAL) reduce 23) ((T_IS_IDENTICAL) reduce 23) ((T_IS_NOT_EQUAL) reduce 23) ((T_IS_NOT_IDENTICAL) reduce 23) ((T_IS_SMALLER_OR_EQUAL) reduce 23) ((T_LOGICAL_AND) reduce 23) ((T_LOGICAL_OR) reduce 23) ((T_LOGICAL_XOR) reduce 23) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 23) ((T_OBJECT_OPERATOR) reduce 23) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 23) ((T_POW) reduce 23) ((T_SL) reduce 23) ((T_SPACESHIP) reduce 23) ((T_SR) reduce 23) (("[") reduce 23) (("^") reduce 23) (("{") reduce 23) (("|") reduce 23) (("}") reduce 23)) 4558 ((("%") reduce 41) (("(") reduce 41) (("*") reduce 41) (("+") reduce 41) ((",") reduce 41) (("-") reduce 41) ((".") reduce 41) (("/") reduce 41) (("<") reduce 41) ((">") reduce 41) (("?") reduce 41) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_BOOLEAN_AND) reduce 41) ((T_BOOLEAN_OR) reduce 41) ((T_COALESCE) reduce 41) ((T_INSTANCEOF) reduce 41) ((T_IS_EQUAL) reduce 41) ((T_IS_GREATER_OR_EQUAL) reduce 41) ((T_IS_IDENTICAL) reduce 41) ((T_IS_NOT_EQUAL) reduce 41) ((T_IS_NOT_IDENTICAL) reduce 41) ((T_IS_SMALLER_OR_EQUAL) reduce 41) ((T_LOGICAL_AND) reduce 41) ((T_LOGICAL_OR) reduce 41) ((T_LOGICAL_XOR) reduce 41) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 41) ((T_OBJECT_OPERATOR) reduce 41) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 41) ((T_POW) reduce 41) ((T_SL) reduce 41) ((T_SPACESHIP) reduce 41) ((T_SR) reduce 41) (("[") reduce 41) (("^") reduce 41) (("{") reduce 41) (("|") reduce 41) (("}") reduce 41)) 4559 ((("%") reduce 62) (("(") reduce 62) (("*") reduce 62) (("+") reduce 62) ((",") reduce 62) (("-") reduce 62) ((".") reduce 62) (("/") reduce 62) (("<") reduce 62) ((">") reduce 62) (("?") reduce 62) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_BOOLEAN_AND) reduce 62) ((T_BOOLEAN_OR) reduce 62) ((T_COALESCE) reduce 62) ((T_INSTANCEOF) reduce 62) ((T_IS_EQUAL) reduce 62) ((T_IS_GREATER_OR_EQUAL) reduce 62) ((T_IS_IDENTICAL) reduce 62) ((T_IS_NOT_EQUAL) reduce 62) ((T_IS_NOT_IDENTICAL) reduce 62) ((T_IS_SMALLER_OR_EQUAL) reduce 62) ((T_LOGICAL_AND) reduce 62) ((T_LOGICAL_OR) reduce 62) ((T_LOGICAL_XOR) reduce 62) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 62) ((T_OBJECT_OPERATOR) reduce 62) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 62) ((T_POW) reduce 62) ((T_SL) reduce 62) ((T_SPACESHIP) reduce 62) ((T_SR) reduce 62) (("[") reduce 62) (("^") reduce 62) (("{") reduce 62) (("|") reduce 62) (("}") reduce 62)) 4560 ((("%") reduce 34) (("(") reduce 34) (("*") reduce 34) (("+") reduce 34) ((",") reduce 34) (("-") reduce 34) ((".") reduce 34) (("/") reduce 34) (("<") reduce 34) ((">") reduce 34) (("?") reduce 34) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_BOOLEAN_AND) reduce 34) ((T_BOOLEAN_OR) reduce 34) ((T_COALESCE) reduce 34) ((T_INSTANCEOF) reduce 34) ((T_IS_EQUAL) reduce 34) ((T_IS_GREATER_OR_EQUAL) reduce 34) ((T_IS_IDENTICAL) reduce 34) ((T_IS_NOT_EQUAL) reduce 34) ((T_IS_NOT_IDENTICAL) reduce 34) ((T_IS_SMALLER_OR_EQUAL) reduce 34) ((T_LOGICAL_AND) reduce 34) ((T_LOGICAL_OR) reduce 34) ((T_LOGICAL_XOR) reduce 34) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 34) ((T_OBJECT_OPERATOR) reduce 34) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 34) ((T_POW) reduce 34) ((T_SL) reduce 34) ((T_SPACESHIP) reduce 34) ((T_SR) reduce 34) (("[") reduce 34) (("^") reduce 34) (("{") reduce 34) (("|") reduce 34) (("}") reduce 34)) 4561 ((("%") reduce 40) (("(") reduce 40) (("*") reduce 40) (("+") reduce 40) ((",") reduce 40) (("-") reduce 40) ((".") reduce 40) (("/") reduce 40) (("<") reduce 40) ((">") reduce 40) (("?") reduce 40) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_BOOLEAN_AND) reduce 40) ((T_BOOLEAN_OR) reduce 40) ((T_COALESCE) reduce 40) ((T_INSTANCEOF) reduce 40) ((T_IS_EQUAL) reduce 40) ((T_IS_GREATER_OR_EQUAL) reduce 40) ((T_IS_IDENTICAL) reduce 40) ((T_IS_NOT_EQUAL) reduce 40) ((T_IS_NOT_IDENTICAL) reduce 40) ((T_IS_SMALLER_OR_EQUAL) reduce 40) ((T_LOGICAL_AND) reduce 40) ((T_LOGICAL_OR) reduce 40) ((T_LOGICAL_XOR) reduce 40) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 40) ((T_OBJECT_OPERATOR) reduce 40) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 40) ((T_POW) reduce 40) ((T_SL) reduce 40) ((T_SPACESHIP) reduce 40) ((T_SR) reduce 40) (("[") reduce 40) (("^") reduce 40) (("{") reduce 40) (("|") reduce 40) (("}") reduce 40)) 4562 ((("%") reduce 13) (("(") reduce 13) (("*") reduce 13) (("+") reduce 13) ((",") reduce 13) (("-") reduce 13) ((".") reduce 13) (("/") reduce 13) (("<") reduce 13) ((">") reduce 13) (("?") reduce 13) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_BOOLEAN_AND) reduce 13) ((T_BOOLEAN_OR) reduce 13) ((T_COALESCE) reduce 13) ((T_INSTANCEOF) reduce 13) ((T_IS_EQUAL) reduce 13) ((T_IS_GREATER_OR_EQUAL) reduce 13) ((T_IS_IDENTICAL) reduce 13) ((T_IS_NOT_EQUAL) reduce 13) ((T_IS_NOT_IDENTICAL) reduce 13) ((T_IS_SMALLER_OR_EQUAL) reduce 13) ((T_LOGICAL_AND) reduce 13) ((T_LOGICAL_OR) reduce 13) ((T_LOGICAL_XOR) reduce 13) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 13) ((T_OBJECT_OPERATOR) reduce 13) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 13) ((T_POW) reduce 13) ((T_SL) reduce 13) ((T_SPACESHIP) reduce 13) ((T_SR) reduce 13) (("[") reduce 13) (("^") reduce 13) (("{") reduce 13) (("|") reduce 13) (("}") reduce 13)) 4563 ((("%") reduce 55) (("(") reduce 55) (("*") reduce 55) (("+") reduce 55) ((",") reduce 55) (("-") reduce 55) ((".") reduce 55) (("/") reduce 55) (("<") reduce 55) ((">") reduce 55) (("?") reduce 55) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_BOOLEAN_AND) reduce 55) ((T_BOOLEAN_OR) reduce 55) ((T_COALESCE) reduce 55) ((T_INSTANCEOF) reduce 55) ((T_IS_EQUAL) reduce 55) ((T_IS_GREATER_OR_EQUAL) reduce 55) ((T_IS_IDENTICAL) reduce 55) ((T_IS_NOT_EQUAL) reduce 55) ((T_IS_NOT_IDENTICAL) reduce 55) ((T_IS_SMALLER_OR_EQUAL) reduce 55) ((T_LOGICAL_AND) reduce 55) ((T_LOGICAL_OR) reduce 55) ((T_LOGICAL_XOR) reduce 55) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 55) ((T_OBJECT_OPERATOR) reduce 55) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 55) ((T_POW) reduce 55) ((T_SL) reduce 55) ((T_SPACESHIP) reduce 55) ((T_SR) reduce 55) (("[") reduce 55) (("^") reduce 55) (("{") reduce 55) (("|") reduce 55) (("}") reduce 55)) 4564 ((("%") reduce 1) (("(") reduce 1) (("*") reduce 1) (("+") reduce 1) ((",") reduce 1) (("-") reduce 1) ((".") reduce 1) (("/") reduce 1) (("<") reduce 1) ((">") reduce 1) (("?") reduce 1) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_BOOLEAN_AND) reduce 1) ((T_BOOLEAN_OR) reduce 1) ((T_COALESCE) reduce 1) ((T_INSTANCEOF) reduce 1) ((T_IS_EQUAL) reduce 1) ((T_IS_GREATER_OR_EQUAL) reduce 1) ((T_IS_IDENTICAL) reduce 1) ((T_IS_NOT_EQUAL) reduce 1) ((T_IS_NOT_IDENTICAL) reduce 1) ((T_IS_SMALLER_OR_EQUAL) reduce 1) ((T_LOGICAL_AND) reduce 1) ((T_LOGICAL_OR) reduce 1) ((T_LOGICAL_XOR) reduce 1) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 1) ((T_OBJECT_OPERATOR) reduce 1) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 1) ((T_POW) reduce 1) ((T_SL) reduce 1) ((T_SPACESHIP) reduce 1) ((T_SR) reduce 1) (("[") reduce 1) (("^") reduce 1) (("{") reduce 1) (("|") reduce 1) (("}") reduce 1)) 4565 ((("%") reduce 2) (("(") reduce 2) (("*") reduce 2) (("+") reduce 2) ((",") reduce 2) (("-") reduce 2) ((".") reduce 2) (("/") reduce 2) (("<") reduce 2) ((">") reduce 2) (("?") reduce 2) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_BOOLEAN_AND) reduce 2) ((T_BOOLEAN_OR) reduce 2) ((T_COALESCE) reduce 2) ((T_INSTANCEOF) reduce 2) ((T_IS_EQUAL) reduce 2) ((T_IS_GREATER_OR_EQUAL) reduce 2) ((T_IS_IDENTICAL) reduce 2) ((T_IS_NOT_EQUAL) reduce 2) ((T_IS_NOT_IDENTICAL) reduce 2) ((T_IS_SMALLER_OR_EQUAL) reduce 2) ((T_LOGICAL_AND) reduce 2) ((T_LOGICAL_OR) reduce 2) ((T_LOGICAL_XOR) reduce 2) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 2) ((T_OBJECT_OPERATOR) reduce 2) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 2) ((T_POW) reduce 2) ((T_SL) reduce 2) ((T_SPACESHIP) reduce 2) ((T_SR) reduce 2) (("[") reduce 2) (("^") reduce 2) (("{") reduce 2) (("|") reduce 2) (("}") reduce 2)) 4566 ((("%") reduce 9) (("(") reduce 9) (("*") reduce 9) (("+") reduce 9) ((",") reduce 9) (("-") reduce 9) ((".") reduce 9) (("/") reduce 9) (("<") reduce 9) ((">") reduce 9) (("?") reduce 9) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_BOOLEAN_AND) reduce 9) ((T_BOOLEAN_OR) reduce 9) ((T_COALESCE) reduce 9) ((T_INSTANCEOF) reduce 9) ((T_IS_EQUAL) reduce 9) ((T_IS_GREATER_OR_EQUAL) reduce 9) ((T_IS_IDENTICAL) reduce 9) ((T_IS_NOT_EQUAL) reduce 9) ((T_IS_NOT_IDENTICAL) reduce 9) ((T_IS_SMALLER_OR_EQUAL) reduce 9) ((T_LOGICAL_AND) reduce 9) ((T_LOGICAL_OR) reduce 9) ((T_LOGICAL_XOR) reduce 9) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 9) ((T_OBJECT_OPERATOR) reduce 9) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 9) ((T_POW) reduce 9) ((T_SL) reduce 9) ((T_SPACESHIP) reduce 9) ((T_SR) reduce 9) (("[") reduce 9) (("^") reduce 9) (("{") reduce 9) (("|") reduce 9) (("}") reduce 9)) 4567 ((("%") reduce 33) (("(") reduce 33) (("*") reduce 33) (("+") reduce 33) ((",") reduce 33) (("-") reduce 33) ((".") reduce 33) (("/") reduce 33) (("<") reduce 33) ((">") reduce 33) (("?") reduce 33) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_BOOLEAN_AND) reduce 33) ((T_BOOLEAN_OR) reduce 33) ((T_COALESCE) reduce 33) ((T_INSTANCEOF) reduce 33) ((T_IS_EQUAL) reduce 33) ((T_IS_GREATER_OR_EQUAL) reduce 33) ((T_IS_IDENTICAL) reduce 33) ((T_IS_NOT_EQUAL) reduce 33) ((T_IS_NOT_IDENTICAL) reduce 33) ((T_IS_SMALLER_OR_EQUAL) reduce 33) ((T_LOGICAL_AND) reduce 33) ((T_LOGICAL_OR) reduce 33) ((T_LOGICAL_XOR) reduce 33) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 33) ((T_OBJECT_OPERATOR) reduce 33) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 33) ((T_POW) reduce 33) ((T_SL) reduce 33) ((T_SPACESHIP) reduce 33) ((T_SR) reduce 33) (("[") reduce 33) (("^") reduce 33) (("{") reduce 33) (("|") reduce 33) (("}") reduce 33)) 4568 ((("%") reduce 58) (("(") reduce 58) (("*") reduce 58) (("+") reduce 58) ((",") reduce 58) (("-") reduce 58) ((".") reduce 58) (("/") reduce 58) (("<") reduce 58) ((">") reduce 58) (("?") reduce 58) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_BOOLEAN_AND) reduce 58) ((T_BOOLEAN_OR) reduce 58) ((T_COALESCE) reduce 58) ((T_INSTANCEOF) reduce 58) ((T_IS_EQUAL) reduce 58) ((T_IS_GREATER_OR_EQUAL) reduce 58) ((T_IS_IDENTICAL) reduce 58) ((T_IS_NOT_EQUAL) reduce 58) ((T_IS_NOT_IDENTICAL) reduce 58) ((T_IS_SMALLER_OR_EQUAL) reduce 58) ((T_LOGICAL_AND) reduce 58) ((T_LOGICAL_OR) reduce 58) ((T_LOGICAL_XOR) reduce 58) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 58) ((T_OBJECT_OPERATOR) reduce 58) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 58) ((T_POW) reduce 58) ((T_SL) reduce 58) ((T_SPACESHIP) reduce 58) ((T_SR) reduce 58) (("[") reduce 58) (("^") reduce 58) (("{") reduce 58) (("|") reduce 58) (("}") reduce 58)) 4569 ((("%") reduce 37) (("(") reduce 37) (("*") reduce 37) (("+") reduce 37) ((",") reduce 37) (("-") reduce 37) ((".") reduce 37) (("/") reduce 37) (("<") reduce 37) ((">") reduce 37) (("?") reduce 37) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_BOOLEAN_AND) reduce 37) ((T_BOOLEAN_OR) reduce 37) ((T_COALESCE) reduce 37) ((T_INSTANCEOF) reduce 37) ((T_IS_EQUAL) reduce 37) ((T_IS_GREATER_OR_EQUAL) reduce 37) ((T_IS_IDENTICAL) reduce 37) ((T_IS_NOT_EQUAL) reduce 37) ((T_IS_NOT_IDENTICAL) reduce 37) ((T_IS_SMALLER_OR_EQUAL) reduce 37) ((T_LOGICAL_AND) reduce 37) ((T_LOGICAL_OR) reduce 37) ((T_LOGICAL_XOR) reduce 37) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 37) ((T_OBJECT_OPERATOR) reduce 37) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 37) ((T_POW) reduce 37) ((T_SL) reduce 37) ((T_SPACESHIP) reduce 37) ((T_SR) reduce 37) (("[") reduce 37) (("^") reduce 37) (("{") reduce 37) (("|") reduce 37) (("}") reduce 37)) 4570 ((("%") reduce 64) (("(") reduce 64) (("*") reduce 64) (("+") reduce 64) ((",") reduce 64) (("-") reduce 64) ((".") reduce 64) (("/") reduce 64) (("<") reduce 64) ((">") reduce 64) (("?") reduce 64) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_BOOLEAN_AND) reduce 64) ((T_BOOLEAN_OR) reduce 64) ((T_COALESCE) reduce 64) ((T_INSTANCEOF) reduce 64) ((T_IS_EQUAL) reduce 64) ((T_IS_GREATER_OR_EQUAL) reduce 64) ((T_IS_IDENTICAL) reduce 64) ((T_IS_NOT_EQUAL) reduce 64) ((T_IS_NOT_IDENTICAL) reduce 64) ((T_IS_SMALLER_OR_EQUAL) reduce 64) ((T_LOGICAL_AND) reduce 64) ((T_LOGICAL_OR) reduce 64) ((T_LOGICAL_XOR) reduce 64) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 64) ((T_OBJECT_OPERATOR) reduce 64) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 64) ((T_POW) reduce 64) ((T_SL) reduce 64) ((T_SPACESHIP) reduce 64) ((T_SR) reduce 64) (("[") reduce 64) (("^") reduce 64) (("{") reduce 64) (("|") reduce 64) (("}") reduce 64)) 4571 ((("%") reduce 46) (("(") reduce 46) (("*") reduce 46) (("+") reduce 46) ((",") reduce 46) (("-") reduce 46) ((".") reduce 46) (("/") reduce 46) (("<") reduce 46) ((">") reduce 46) (("?") reduce 46) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_BOOLEAN_AND) reduce 46) ((T_BOOLEAN_OR) reduce 46) ((T_COALESCE) reduce 46) ((T_INSTANCEOF) reduce 46) ((T_IS_EQUAL) reduce 46) ((T_IS_GREATER_OR_EQUAL) reduce 46) ((T_IS_IDENTICAL) reduce 46) ((T_IS_NOT_EQUAL) reduce 46) ((T_IS_NOT_IDENTICAL) reduce 46) ((T_IS_SMALLER_OR_EQUAL) reduce 46) ((T_LOGICAL_AND) reduce 46) ((T_LOGICAL_OR) reduce 46) ((T_LOGICAL_XOR) reduce 46) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 46) ((T_OBJECT_OPERATOR) reduce 46) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 46) ((T_POW) reduce 46) ((T_SL) reduce 46) ((T_SPACESHIP) reduce 46) ((T_SR) reduce 46) (("[") reduce 46) (("^") reduce 46) (("{") reduce 46) (("|") reduce 46) (("}") reduce 46)) 4572 ((("%") reduce 8) (("(") reduce 8) (("*") reduce 8) (("+") reduce 8) ((",") reduce 8) (("-") reduce 8) ((".") reduce 8) (("/") reduce 8) (("<") reduce 8) ((">") reduce 8) (("?") reduce 8) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_BOOLEAN_AND) reduce 8) ((T_BOOLEAN_OR) reduce 8) ((T_COALESCE) reduce 8) ((T_INSTANCEOF) reduce 8) ((T_IS_EQUAL) reduce 8) ((T_IS_GREATER_OR_EQUAL) reduce 8) ((T_IS_IDENTICAL) reduce 8) ((T_IS_NOT_EQUAL) reduce 8) ((T_IS_NOT_IDENTICAL) reduce 8) ((T_IS_SMALLER_OR_EQUAL) reduce 8) ((T_LOGICAL_AND) reduce 8) ((T_LOGICAL_OR) reduce 8) ((T_LOGICAL_XOR) reduce 8) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 8) ((T_OBJECT_OPERATOR) reduce 8) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 8) ((T_POW) reduce 8) ((T_SL) reduce 8) ((T_SPACESHIP) reduce 8) ((T_SR) reduce 8) (("[") reduce 8) (("^") reduce 8) (("{") reduce 8) (("|") reduce 8) (("}") reduce 8)) 4573 ((("%") reduce 6) (("(") reduce 6) (("*") reduce 6) (("+") reduce 6) ((",") reduce 6) (("-") reduce 6) ((".") reduce 6) (("/") reduce 6) (("<") reduce 6) ((">") reduce 6) (("?") reduce 6) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_BOOLEAN_AND) reduce 6) ((T_BOOLEAN_OR) reduce 6) ((T_COALESCE) reduce 6) ((T_INSTANCEOF) reduce 6) ((T_IS_EQUAL) reduce 6) ((T_IS_GREATER_OR_EQUAL) reduce 6) ((T_IS_IDENTICAL) reduce 6) ((T_IS_NOT_EQUAL) reduce 6) ((T_IS_NOT_IDENTICAL) reduce 6) ((T_IS_SMALLER_OR_EQUAL) reduce 6) ((T_LOGICAL_AND) reduce 6) ((T_LOGICAL_OR) reduce 6) ((T_LOGICAL_XOR) reduce 6) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 6) ((T_OBJECT_OPERATOR) reduce 6) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 6) ((T_POW) reduce 6) ((T_SL) reduce 6) ((T_SPACESHIP) reduce 6) ((T_SR) reduce 6) (("[") reduce 6) (("^") reduce 6) (("{") reduce 6) (("|") reduce 6) (("}") reduce 6)) 4574 ((("%") reduce 7) (("(") reduce 7) (("*") reduce 7) (("+") reduce 7) ((",") reduce 7) (("-") reduce 7) ((".") reduce 7) (("/") reduce 7) (("<") reduce 7) ((">") reduce 7) (("?") reduce 7) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_BOOLEAN_AND) reduce 7) ((T_BOOLEAN_OR) reduce 7) ((T_COALESCE) reduce 7) ((T_INSTANCEOF) reduce 7) ((T_IS_EQUAL) reduce 7) ((T_IS_GREATER_OR_EQUAL) reduce 7) ((T_IS_IDENTICAL) reduce 7) ((T_IS_NOT_EQUAL) reduce 7) ((T_IS_NOT_IDENTICAL) reduce 7) ((T_IS_SMALLER_OR_EQUAL) reduce 7) ((T_LOGICAL_AND) reduce 7) ((T_LOGICAL_OR) reduce 7) ((T_LOGICAL_XOR) reduce 7) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 7) ((T_OBJECT_OPERATOR) reduce 7) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 7) ((T_POW) reduce 7) ((T_SL) reduce 7) ((T_SPACESHIP) reduce 7) ((T_SR) reduce 7) (("[") reduce 7) (("^") reduce 7) (("{") reduce 7) (("|") reduce 7) (("}") reduce 7)) 4575 ((("%") reduce 69) (("(") reduce 69) (("*") reduce 69) (("+") reduce 69) ((",") reduce 69) (("-") reduce 69) ((".") reduce 69) (("/") reduce 69) (("<") reduce 69) ((">") reduce 69) (("?") reduce 69) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_BOOLEAN_AND) reduce 69) ((T_BOOLEAN_OR) reduce 69) ((T_COALESCE) reduce 69) ((T_INSTANCEOF) reduce 69) ((T_IS_EQUAL) reduce 69) ((T_IS_GREATER_OR_EQUAL) reduce 69) ((T_IS_IDENTICAL) reduce 69) ((T_IS_NOT_EQUAL) reduce 69) ((T_IS_NOT_IDENTICAL) reduce 69) ((T_IS_SMALLER_OR_EQUAL) reduce 69) ((T_LOGICAL_AND) reduce 69) ((T_LOGICAL_OR) reduce 69) ((T_LOGICAL_XOR) reduce 69) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 69) ((T_OBJECT_OPERATOR) reduce 69) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 69) ((T_POW) reduce 69) ((T_SL) reduce 69) ((T_SPACESHIP) reduce 69) ((T_SR) reduce 69) (("[") reduce 69) (("^") reduce 69) (("{") reduce 69) (("|") reduce 69) (("}") reduce 69)) 4576 ((("%") reduce 63) (("(") reduce 63) (("*") reduce 63) (("+") reduce 63) ((",") reduce 63) (("-") reduce 63) ((".") reduce 63) (("/") reduce 63) (("<") reduce 63) ((">") reduce 63) (("?") reduce 63) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_BOOLEAN_AND) reduce 63) ((T_BOOLEAN_OR) reduce 63) ((T_COALESCE) reduce 63) ((T_INSTANCEOF) reduce 63) ((T_IS_EQUAL) reduce 63) ((T_IS_GREATER_OR_EQUAL) reduce 63) ((T_IS_IDENTICAL) reduce 63) ((T_IS_NOT_EQUAL) reduce 63) ((T_IS_NOT_IDENTICAL) reduce 63) ((T_IS_SMALLER_OR_EQUAL) reduce 63) ((T_LOGICAL_AND) reduce 63) ((T_LOGICAL_OR) reduce 63) ((T_LOGICAL_XOR) reduce 63) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 63) ((T_OBJECT_OPERATOR) reduce 63) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 63) ((T_POW) reduce 63) ((T_SL) reduce 63) ((T_SPACESHIP) reduce 63) ((T_SR) reduce 63) (("[") reduce 63) (("^") reduce 63) (("{") reduce 63) (("|") reduce 63) (("}") reduce 63)) 4577 ((("%") reduce 56) (("(") reduce 56) (("*") reduce 56) (("+") reduce 56) ((",") reduce 56) (("-") reduce 56) ((".") reduce 56) (("/") reduce 56) (("<") reduce 56) ((">") reduce 56) (("?") reduce 56) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_BOOLEAN_AND) reduce 56) ((T_BOOLEAN_OR) reduce 56) ((T_COALESCE) reduce 56) ((T_INSTANCEOF) reduce 56) ((T_IS_EQUAL) reduce 56) ((T_IS_GREATER_OR_EQUAL) reduce 56) ((T_IS_IDENTICAL) reduce 56) ((T_IS_NOT_EQUAL) reduce 56) ((T_IS_NOT_IDENTICAL) reduce 56) ((T_IS_SMALLER_OR_EQUAL) reduce 56) ((T_LOGICAL_AND) reduce 56) ((T_LOGICAL_OR) reduce 56) ((T_LOGICAL_XOR) reduce 56) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 56) ((T_OBJECT_OPERATOR) reduce 56) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 56) ((T_POW) reduce 56) ((T_SL) reduce 56) ((T_SPACESHIP) reduce 56) ((T_SR) reduce 56) (("[") reduce 56) (("^") reduce 56) (("{") reduce 56) (("|") reduce 56) (("}") reduce 56)) 4578 ((("%") reduce 10) (("(") reduce 10) (("*") reduce 10) (("+") reduce 10) ((",") reduce 10) (("-") reduce 10) ((".") reduce 10) (("/") reduce 10) (("<") reduce 10) ((">") reduce 10) (("?") reduce 10) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_BOOLEAN_AND) reduce 10) ((T_BOOLEAN_OR) reduce 10) ((T_COALESCE) reduce 10) ((T_INSTANCEOF) reduce 10) ((T_IS_EQUAL) reduce 10) ((T_IS_GREATER_OR_EQUAL) reduce 10) ((T_IS_IDENTICAL) reduce 10) ((T_IS_NOT_EQUAL) reduce 10) ((T_IS_NOT_IDENTICAL) reduce 10) ((T_IS_SMALLER_OR_EQUAL) reduce 10) ((T_LOGICAL_AND) reduce 10) ((T_LOGICAL_OR) reduce 10) ((T_LOGICAL_XOR) reduce 10) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 10) ((T_OBJECT_OPERATOR) reduce 10) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 10) ((T_POW) reduce 10) ((T_SL) reduce 10) ((T_SPACESHIP) reduce 10) ((T_SR) reduce 10) (("[") reduce 10) (("^") reduce 10) (("{") reduce 10) (("|") reduce 10) (("}") reduce 10)) 4579 ((("%") reduce 67) (("(") reduce 67) (("*") reduce 67) (("+") reduce 67) ((",") reduce 67) (("-") reduce 67) ((".") reduce 67) (("/") reduce 67) (("<") reduce 67) ((">") reduce 67) (("?") reduce 67) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_BOOLEAN_AND) reduce 67) ((T_BOOLEAN_OR) reduce 67) ((T_COALESCE) reduce 67) ((T_INSTANCEOF) reduce 67) ((T_IS_EQUAL) reduce 67) ((T_IS_GREATER_OR_EQUAL) reduce 67) ((T_IS_IDENTICAL) reduce 67) ((T_IS_NOT_EQUAL) reduce 67) ((T_IS_NOT_IDENTICAL) reduce 67) ((T_IS_SMALLER_OR_EQUAL) reduce 67) ((T_LOGICAL_AND) reduce 67) ((T_LOGICAL_OR) reduce 67) ((T_LOGICAL_XOR) reduce 67) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 67) ((T_OBJECT_OPERATOR) reduce 67) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 67) ((T_POW) reduce 67) ((T_SL) reduce 67) ((T_SPACESHIP) reduce 67) ((T_SR) reduce 67) (("[") reduce 67) (("^") reduce 67) (("{") reduce 67) (("|") reduce 67) (("}") reduce 67)) 4580 ((("%") reduce 44) (("(") reduce 44) (("*") reduce 44) (("+") reduce 44) ((",") reduce 44) (("-") reduce 44) ((".") reduce 44) (("/") reduce 44) (("<") reduce 44) ((">") reduce 44) (("?") reduce 44) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_BOOLEAN_AND) reduce 44) ((T_BOOLEAN_OR) reduce 44) ((T_COALESCE) reduce 44) ((T_INSTANCEOF) reduce 44) ((T_IS_EQUAL) reduce 44) ((T_IS_GREATER_OR_EQUAL) reduce 44) ((T_IS_IDENTICAL) reduce 44) ((T_IS_NOT_EQUAL) reduce 44) ((T_IS_NOT_IDENTICAL) reduce 44) ((T_IS_SMALLER_OR_EQUAL) reduce 44) ((T_LOGICAL_AND) reduce 44) ((T_LOGICAL_OR) reduce 44) ((T_LOGICAL_XOR) reduce 44) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 44) ((T_OBJECT_OPERATOR) reduce 44) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 44) ((T_POW) reduce 44) ((T_SL) reduce 44) ((T_SPACESHIP) reduce 44) ((T_SR) reduce 44) (("[") reduce 44) (("^") reduce 44) (("{") reduce 44) (("|") reduce 44) (("}") reduce 44)) 4581 ((("%") reduce 75) (("(") reduce 75) (("*") reduce 75) (("+") reduce 75) ((",") reduce 75) (("-") reduce 75) ((".") reduce 75) (("/") reduce 75) (("<") reduce 75) ((">") reduce 75) (("?") reduce 75) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_BOOLEAN_AND) reduce 75) ((T_BOOLEAN_OR) reduce 75) ((T_COALESCE) reduce 75) ((T_INSTANCEOF) reduce 75) ((T_IS_EQUAL) reduce 75) ((T_IS_GREATER_OR_EQUAL) reduce 75) ((T_IS_IDENTICAL) reduce 75) ((T_IS_NOT_EQUAL) reduce 75) ((T_IS_NOT_IDENTICAL) reduce 75) ((T_IS_SMALLER_OR_EQUAL) reduce 75) ((T_LOGICAL_AND) reduce 75) ((T_LOGICAL_OR) reduce 75) ((T_LOGICAL_XOR) reduce 75) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 75) ((T_OBJECT_OPERATOR) reduce 75) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 75) ((T_POW) reduce 75) ((T_SL) reduce 75) ((T_SPACESHIP) reduce 75) ((T_SR) reduce 75) (("[") reduce 75) (("^") reduce 75) (("{") reduce 75) (("|") reduce 75) (("}") reduce 75)) 4582 ((("%") reduce 76) (("(") reduce 76) (("*") reduce 76) (("+") reduce 76) ((",") reduce 76) (("-") reduce 76) ((".") reduce 76) (("/") reduce 76) (("<") reduce 76) ((">") reduce 76) (("?") reduce 76) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_BOOLEAN_AND) reduce 76) ((T_BOOLEAN_OR) reduce 76) ((T_COALESCE) reduce 76) ((T_INSTANCEOF) reduce 76) ((T_IS_EQUAL) reduce 76) ((T_IS_GREATER_OR_EQUAL) reduce 76) ((T_IS_IDENTICAL) reduce 76) ((T_IS_NOT_EQUAL) reduce 76) ((T_IS_NOT_IDENTICAL) reduce 76) ((T_IS_SMALLER_OR_EQUAL) reduce 76) ((T_LOGICAL_AND) reduce 76) ((T_LOGICAL_OR) reduce 76) ((T_LOGICAL_XOR) reduce 76) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 76) ((T_OBJECT_OPERATOR) reduce 76) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 76) ((T_POW) reduce 76) ((T_SL) reduce 76) ((T_SPACESHIP) reduce 76) ((T_SR) reduce 76) (("[") reduce 76) (("^") reduce 76) (("{") reduce 76) (("|") reduce 76) (("}") reduce 76)) 4583 ((("%") reduce 77) (("(") reduce 77) (("*") reduce 77) (("+") reduce 77) ((",") reduce 77) (("-") reduce 77) ((".") reduce 77) (("/") reduce 77) (("<") reduce 77) ((">") reduce 77) (("?") reduce 77) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_BOOLEAN_AND) reduce 77) ((T_BOOLEAN_OR) reduce 77) ((T_COALESCE) reduce 77) ((T_INSTANCEOF) reduce 77) ((T_IS_EQUAL) reduce 77) ((T_IS_GREATER_OR_EQUAL) reduce 77) ((T_IS_IDENTICAL) reduce 77) ((T_IS_NOT_EQUAL) reduce 77) ((T_IS_NOT_IDENTICAL) reduce 77) ((T_IS_SMALLER_OR_EQUAL) reduce 77) ((T_LOGICAL_AND) reduce 77) ((T_LOGICAL_OR) reduce 77) ((T_LOGICAL_XOR) reduce 77) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 77) ((T_OBJECT_OPERATOR) reduce 77) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 77) ((T_POW) reduce 77) ((T_SL) reduce 77) ((T_SPACESHIP) reduce 77) ((T_SR) reduce 77) (("[") reduce 77) (("^") reduce 77) (("{") reduce 77) (("|") reduce 77) (("}") reduce 77)) 4584 ((("%") reduce 78) (("(") reduce 78) (("*") reduce 78) (("+") reduce 78) ((",") reduce 78) (("-") reduce 78) ((".") reduce 78) (("/") reduce 78) (("<") reduce 78) ((">") reduce 78) (("?") reduce 78) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_BOOLEAN_AND) reduce 78) ((T_BOOLEAN_OR) reduce 78) ((T_COALESCE) reduce 78) ((T_INSTANCEOF) reduce 78) ((T_IS_EQUAL) reduce 78) ((T_IS_GREATER_OR_EQUAL) reduce 78) ((T_IS_IDENTICAL) reduce 78) ((T_IS_NOT_EQUAL) reduce 78) ((T_IS_NOT_IDENTICAL) reduce 78) ((T_IS_SMALLER_OR_EQUAL) reduce 78) ((T_LOGICAL_AND) reduce 78) ((T_LOGICAL_OR) reduce 78) ((T_LOGICAL_XOR) reduce 78) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 78) ((T_OBJECT_OPERATOR) reduce 78) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 78) ((T_POW) reduce 78) ((T_SL) reduce 78) ((T_SPACESHIP) reduce 78) ((T_SR) reduce 78) (("[") reduce 78) (("^") reduce 78) (("{") reduce 78) (("|") reduce 78) (("}") reduce 78)) 4585 ((("%") reduce 4) (("(") reduce 4) (("*") reduce 4) (("+") reduce 4) ((",") reduce 4) (("-") reduce 4) ((".") reduce 4) (("/") reduce 4) (("<") reduce 4) ((">") reduce 4) (("?") reduce 4) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_BOOLEAN_AND) reduce 4) ((T_BOOLEAN_OR) reduce 4) ((T_COALESCE) reduce 4) ((T_INSTANCEOF) reduce 4) ((T_IS_EQUAL) reduce 4) ((T_IS_GREATER_OR_EQUAL) reduce 4) ((T_IS_IDENTICAL) reduce 4) ((T_IS_NOT_EQUAL) reduce 4) ((T_IS_NOT_IDENTICAL) reduce 4) ((T_IS_SMALLER_OR_EQUAL) reduce 4) ((T_LOGICAL_AND) reduce 4) ((T_LOGICAL_OR) reduce 4) ((T_LOGICAL_XOR) reduce 4) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 4) ((T_OBJECT_OPERATOR) reduce 4) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 4) ((T_POW) reduce 4) ((T_SL) reduce 4) ((T_SPACESHIP) reduce 4) ((T_SR) reduce 4) (("[") reduce 4) (("^") reduce 4) (("{") reduce 4) (("|") reduce 4) (("}") reduce 4)) 4586 ((("%") reduce 5) (("(") reduce 5) (("*") reduce 5) (("+") reduce 5) ((",") reduce 5) (("-") reduce 5) ((".") reduce 5) (("/") reduce 5) (("<") reduce 5) ((">") reduce 5) (("?") reduce 5) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_BOOLEAN_AND) reduce 5) ((T_BOOLEAN_OR) reduce 5) ((T_COALESCE) reduce 5) ((T_INSTANCEOF) reduce 5) ((T_IS_EQUAL) reduce 5) ((T_IS_GREATER_OR_EQUAL) reduce 5) ((T_IS_IDENTICAL) reduce 5) ((T_IS_NOT_EQUAL) reduce 5) ((T_IS_NOT_IDENTICAL) reduce 5) ((T_IS_SMALLER_OR_EQUAL) reduce 5) ((T_LOGICAL_AND) reduce 5) ((T_LOGICAL_OR) reduce 5) ((T_LOGICAL_XOR) reduce 5) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 5) ((T_OBJECT_OPERATOR) reduce 5) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 5) ((T_POW) reduce 5) ((T_SL) reduce 5) ((T_SPACESHIP) reduce 5) ((T_SR) reduce 5) (("[") reduce 5) (("^") reduce 5) (("{") reduce 5) (("|") reduce 5) (("}") reduce 5)) 4587 ((("%") reduce 43) (("(") reduce 43) (("*") reduce 43) (("+") reduce 43) ((",") reduce 43) (("-") reduce 43) ((".") reduce 43) (("/") reduce 43) (("<") reduce 43) ((">") reduce 43) (("?") reduce 43) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_BOOLEAN_AND) reduce 43) ((T_BOOLEAN_OR) reduce 43) ((T_COALESCE) reduce 43) ((T_INSTANCEOF) reduce 43) ((T_IS_EQUAL) reduce 43) ((T_IS_GREATER_OR_EQUAL) reduce 43) ((T_IS_IDENTICAL) reduce 43) ((T_IS_NOT_EQUAL) reduce 43) ((T_IS_NOT_IDENTICAL) reduce 43) ((T_IS_SMALLER_OR_EQUAL) reduce 43) ((T_LOGICAL_AND) reduce 43) ((T_LOGICAL_OR) reduce 43) ((T_LOGICAL_XOR) reduce 43) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 43) ((T_OBJECT_OPERATOR) reduce 43) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 43) ((T_POW) reduce 43) ((T_SL) reduce 43) ((T_SPACESHIP) reduce 43) ((T_SR) reduce 43) (("[") reduce 43) (("^") reduce 43) (("{") reduce 43) (("|") reduce 43) (("}") reduce 43)) 4588 ((("%") reduce 72) (("(") reduce 72) (("*") reduce 72) (("+") reduce 72) ((",") reduce 72) (("-") reduce 72) ((".") reduce 72) (("/") reduce 72) (("<") reduce 72) ((">") reduce 72) (("?") reduce 72) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_BOOLEAN_AND) reduce 72) ((T_BOOLEAN_OR) reduce 72) ((T_COALESCE) reduce 72) ((T_INSTANCEOF) reduce 72) ((T_IS_EQUAL) reduce 72) ((T_IS_GREATER_OR_EQUAL) reduce 72) ((T_IS_IDENTICAL) reduce 72) ((T_IS_NOT_EQUAL) reduce 72) ((T_IS_NOT_IDENTICAL) reduce 72) ((T_IS_SMALLER_OR_EQUAL) reduce 72) ((T_LOGICAL_AND) reduce 72) ((T_LOGICAL_OR) reduce 72) ((T_LOGICAL_XOR) reduce 72) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 72) ((T_OBJECT_OPERATOR) reduce 72) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 72) ((T_POW) reduce 72) ((T_SL) reduce 72) ((T_SPACESHIP) reduce 72) ((T_SR) reduce 72) (("[") reduce 72) (("^") reduce 72) (("{") reduce 72) (("|") reduce 72) (("}") reduce 72)) 4589 ((("%") reduce 81) (("(") reduce 81) (("*") reduce 81) (("+") reduce 81) ((",") reduce 81) (("-") reduce 81) ((".") reduce 81) (("/") reduce 81) (("<") reduce 81) ((">") reduce 81) (("?") reduce 81) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_BOOLEAN_AND) reduce 81) ((T_BOOLEAN_OR) reduce 81) ((T_COALESCE) reduce 81) ((T_INSTANCEOF) reduce 81) ((T_IS_EQUAL) reduce 81) ((T_IS_GREATER_OR_EQUAL) reduce 81) ((T_IS_IDENTICAL) reduce 81) ((T_IS_NOT_EQUAL) reduce 81) ((T_IS_NOT_IDENTICAL) reduce 81) ((T_IS_SMALLER_OR_EQUAL) reduce 81) ((T_LOGICAL_AND) reduce 81) ((T_LOGICAL_OR) reduce 81) ((T_LOGICAL_XOR) reduce 81) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 81) ((T_OBJECT_OPERATOR) reduce 81) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 81) ((T_POW) reduce 81) ((T_SL) reduce 81) ((T_SPACESHIP) reduce 81) ((T_SR) reduce 81) (("[") reduce 81) (("^") reduce 81) (("{") reduce 81) (("|") reduce 81) (("}") reduce 81)) 4590 ((("%") reduce 47) (("(") reduce 47) (("*") reduce 47) (("+") reduce 47) ((",") reduce 47) (("-") reduce 47) ((".") reduce 47) (("/") reduce 47) (("<") reduce 47) ((">") reduce 47) (("?") reduce 47) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_BOOLEAN_AND) reduce 47) ((T_BOOLEAN_OR) reduce 47) ((T_COALESCE) reduce 47) ((T_INSTANCEOF) reduce 47) ((T_IS_EQUAL) reduce 47) ((T_IS_GREATER_OR_EQUAL) reduce 47) ((T_IS_IDENTICAL) reduce 47) ((T_IS_NOT_EQUAL) reduce 47) ((T_IS_NOT_IDENTICAL) reduce 47) ((T_IS_SMALLER_OR_EQUAL) reduce 47) ((T_LOGICAL_AND) reduce 47) ((T_LOGICAL_OR) reduce 47) ((T_LOGICAL_XOR) reduce 47) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 47) ((T_OBJECT_OPERATOR) reduce 47) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 47) ((T_POW) reduce 47) ((T_SL) reduce 47) ((T_SPACESHIP) reduce 47) ((T_SR) reduce 47) (("[") reduce 47) (("^") reduce 47) (("{") reduce 47) (("|") reduce 47) (("}") reduce 47)) 4591 ((("%") reduce 31) (("(") reduce 31) (("*") reduce 31) (("+") reduce 31) ((",") reduce 31) (("-") reduce 31) ((".") reduce 31) (("/") reduce 31) (("<") reduce 31) ((">") reduce 31) (("?") reduce 31) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_BOOLEAN_AND) reduce 31) ((T_BOOLEAN_OR) reduce 31) ((T_COALESCE) reduce 31) ((T_INSTANCEOF) reduce 31) ((T_IS_EQUAL) reduce 31) ((T_IS_GREATER_OR_EQUAL) reduce 31) ((T_IS_IDENTICAL) reduce 31) ((T_IS_NOT_EQUAL) reduce 31) ((T_IS_NOT_IDENTICAL) reduce 31) ((T_IS_SMALLER_OR_EQUAL) reduce 31) ((T_LOGICAL_AND) reduce 31) ((T_LOGICAL_OR) reduce 31) ((T_LOGICAL_XOR) reduce 31) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 31) ((T_OBJECT_OPERATOR) reduce 31) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 31) ((T_POW) reduce 31) ((T_SL) reduce 31) ((T_SPACESHIP) reduce 31) ((T_SR) reduce 31) (("[") reduce 31) (("^") reduce 31) (("{") reduce 31) (("|") reduce 31) (("}") reduce 31)) 4592 ((("%") reduce 57) (("(") reduce 57) (("*") reduce 57) (("+") reduce 57) ((",") reduce 57) (("-") reduce 57) ((".") reduce 57) (("/") reduce 57) (("<") reduce 57) ((">") reduce 57) (("?") reduce 57) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_BOOLEAN_AND) reduce 57) ((T_BOOLEAN_OR) reduce 57) ((T_COALESCE) reduce 57) ((T_INSTANCEOF) reduce 57) ((T_IS_EQUAL) reduce 57) ((T_IS_GREATER_OR_EQUAL) reduce 57) ((T_IS_IDENTICAL) reduce 57) ((T_IS_NOT_EQUAL) reduce 57) ((T_IS_NOT_IDENTICAL) reduce 57) ((T_IS_SMALLER_OR_EQUAL) reduce 57) ((T_LOGICAL_AND) reduce 57) ((T_LOGICAL_OR) reduce 57) ((T_LOGICAL_XOR) reduce 57) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 57) ((T_OBJECT_OPERATOR) reduce 57) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 57) ((T_POW) reduce 57) ((T_SL) reduce 57) ((T_SPACESHIP) reduce 57) ((T_SR) reduce 57) (("[") reduce 57) (("^") reduce 57) (("{") reduce 57) (("|") reduce 57) (("}") reduce 57)) 4593 ((("%") reduce 61) (("(") reduce 61) (("*") reduce 61) (("+") reduce 61) ((",") reduce 61) (("-") reduce 61) ((".") reduce 61) (("/") reduce 61) (("<") reduce 61) ((">") reduce 61) (("?") reduce 61) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_BOOLEAN_AND) reduce 61) ((T_BOOLEAN_OR) reduce 61) ((T_COALESCE) reduce 61) ((T_INSTANCEOF) reduce 61) ((T_IS_EQUAL) reduce 61) ((T_IS_GREATER_OR_EQUAL) reduce 61) ((T_IS_IDENTICAL) reduce 61) ((T_IS_NOT_EQUAL) reduce 61) ((T_IS_NOT_IDENTICAL) reduce 61) ((T_IS_SMALLER_OR_EQUAL) reduce 61) ((T_LOGICAL_AND) reduce 61) ((T_LOGICAL_OR) reduce 61) ((T_LOGICAL_XOR) reduce 61) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 61) ((T_OBJECT_OPERATOR) reduce 61) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 61) ((T_POW) reduce 61) ((T_SL) reduce 61) ((T_SPACESHIP) reduce 61) ((T_SR) reduce 61) (("[") reduce 61) (("^") reduce 61) (("{") reduce 61) (("|") reduce 61) (("}") reduce 61)) 4594 ((("%") reduce 28) (("(") reduce 28) (("*") reduce 28) (("+") reduce 28) ((",") reduce 28) (("-") reduce 28) ((".") reduce 28) (("/") reduce 28) (("<") reduce 28) ((">") reduce 28) (("?") reduce 28) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_BOOLEAN_AND) reduce 28) ((T_BOOLEAN_OR) reduce 28) ((T_COALESCE) reduce 28) ((T_INSTANCEOF) reduce 28) ((T_IS_EQUAL) reduce 28) ((T_IS_GREATER_OR_EQUAL) reduce 28) ((T_IS_IDENTICAL) reduce 28) ((T_IS_NOT_EQUAL) reduce 28) ((T_IS_NOT_IDENTICAL) reduce 28) ((T_IS_SMALLER_OR_EQUAL) reduce 28) ((T_LOGICAL_AND) reduce 28) ((T_LOGICAL_OR) reduce 28) ((T_LOGICAL_XOR) reduce 28) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 28) ((T_OBJECT_OPERATOR) reduce 28) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 28) ((T_POW) reduce 28) ((T_SL) reduce 28) ((T_SPACESHIP) reduce 28) ((T_SR) reduce 28) (("[") reduce 28) (("^") reduce 28) (("{") reduce 28) (("|") reduce 28) (("}") reduce 28)) 4595 ((("%") reduce 36) (("(") reduce 36) (("*") reduce 36) (("+") reduce 36) ((",") reduce 36) (("-") reduce 36) ((".") reduce 36) (("/") reduce 36) (("<") reduce 36) ((">") reduce 36) (("?") reduce 36) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_BOOLEAN_AND) reduce 36) ((T_BOOLEAN_OR) reduce 36) ((T_COALESCE) reduce 36) ((T_INSTANCEOF) reduce 36) ((T_IS_EQUAL) reduce 36) ((T_IS_GREATER_OR_EQUAL) reduce 36) ((T_IS_IDENTICAL) reduce 36) ((T_IS_NOT_EQUAL) reduce 36) ((T_IS_NOT_IDENTICAL) reduce 36) ((T_IS_SMALLER_OR_EQUAL) reduce 36) ((T_LOGICAL_AND) reduce 36) ((T_LOGICAL_OR) reduce 36) ((T_LOGICAL_XOR) reduce 36) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 36) ((T_OBJECT_OPERATOR) reduce 36) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 36) ((T_POW) reduce 36) ((T_SL) reduce 36) ((T_SPACESHIP) reduce 36) ((T_SR) reduce 36) (("[") reduce 36) (("^") reduce 36) (("{") reduce 36) (("|") reduce 36) (("}") reduce 36)) 4596 ((("%") reduce 32) (("(") reduce 32) (("*") reduce 32) (("+") reduce 32) ((",") reduce 32) (("-") reduce 32) ((".") reduce 32) (("/") reduce 32) (("<") reduce 32) ((">") reduce 32) (("?") reduce 32) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_BOOLEAN_AND) reduce 32) ((T_BOOLEAN_OR) reduce 32) ((T_COALESCE) reduce 32) ((T_INSTANCEOF) reduce 32) ((T_IS_EQUAL) reduce 32) ((T_IS_GREATER_OR_EQUAL) reduce 32) ((T_IS_IDENTICAL) reduce 32) ((T_IS_NOT_EQUAL) reduce 32) ((T_IS_NOT_IDENTICAL) reduce 32) ((T_IS_SMALLER_OR_EQUAL) reduce 32) ((T_LOGICAL_AND) reduce 32) ((T_LOGICAL_OR) reduce 32) ((T_LOGICAL_XOR) reduce 32) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 32) ((T_OBJECT_OPERATOR) reduce 32) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 32) ((T_POW) reduce 32) ((T_SL) reduce 32) ((T_SPACESHIP) reduce 32) ((T_SR) reduce 32) (("[") reduce 32) (("^") reduce 32) (("{") reduce 32) (("|") reduce 32) (("}") reduce 32)) 4597 ((("%") reduce 35) (("(") reduce 35) (("*") reduce 35) (("+") reduce 35) ((",") reduce 35) (("-") reduce 35) ((".") reduce 35) (("/") reduce 35) (("<") reduce 35) ((">") reduce 35) (("?") reduce 35) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_BOOLEAN_AND) reduce 35) ((T_BOOLEAN_OR) reduce 35) ((T_COALESCE) reduce 35) ((T_INSTANCEOF) reduce 35) ((T_IS_EQUAL) reduce 35) ((T_IS_GREATER_OR_EQUAL) reduce 35) ((T_IS_IDENTICAL) reduce 35) ((T_IS_NOT_EQUAL) reduce 35) ((T_IS_NOT_IDENTICAL) reduce 35) ((T_IS_SMALLER_OR_EQUAL) reduce 35) ((T_LOGICAL_AND) reduce 35) ((T_LOGICAL_OR) reduce 35) ((T_LOGICAL_XOR) reduce 35) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 35) ((T_OBJECT_OPERATOR) reduce 35) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 35) ((T_POW) reduce 35) ((T_SL) reduce 35) ((T_SPACESHIP) reduce 35) ((T_SR) reduce 35) (("[") reduce 35) (("^") reduce 35) (("{") reduce 35) (("|") reduce 35) (("}") reduce 35)) 4598 ((("%") reduce 19) (("(") reduce 19) (("*") reduce 19) (("+") reduce 19) ((",") reduce 19) (("-") reduce 19) ((".") reduce 19) (("/") reduce 19) (("<") reduce 19) ((">") reduce 19) (("?") reduce 19) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_BOOLEAN_AND) reduce 19) ((T_BOOLEAN_OR) reduce 19) ((T_COALESCE) reduce 19) ((T_INSTANCEOF) reduce 19) ((T_IS_EQUAL) reduce 19) ((T_IS_GREATER_OR_EQUAL) reduce 19) ((T_IS_IDENTICAL) reduce 19) ((T_IS_NOT_EQUAL) reduce 19) ((T_IS_NOT_IDENTICAL) reduce 19) ((T_IS_SMALLER_OR_EQUAL) reduce 19) ((T_LOGICAL_AND) reduce 19) ((T_LOGICAL_OR) reduce 19) ((T_LOGICAL_XOR) reduce 19) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 19) ((T_OBJECT_OPERATOR) reduce 19) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 19) ((T_POW) reduce 19) ((T_SL) reduce 19) ((T_SPACESHIP) reduce 19) ((T_SR) reduce 19) (("[") reduce 19) (("^") reduce 19) (("{") reduce 19) (("|") reduce 19) (("}") reduce 19)) 4599 ((("%") reduce 45) (("(") reduce 45) (("*") reduce 45) (("+") reduce 45) ((",") reduce 45) (("-") reduce 45) ((".") reduce 45) (("/") reduce 45) (("<") reduce 45) ((">") reduce 45) (("?") reduce 45) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_BOOLEAN_AND) reduce 45) ((T_BOOLEAN_OR) reduce 45) ((T_COALESCE) reduce 45) ((T_INSTANCEOF) reduce 45) ((T_IS_EQUAL) reduce 45) ((T_IS_GREATER_OR_EQUAL) reduce 45) ((T_IS_IDENTICAL) reduce 45) ((T_IS_NOT_EQUAL) reduce 45) ((T_IS_NOT_IDENTICAL) reduce 45) ((T_IS_SMALLER_OR_EQUAL) reduce 45) ((T_LOGICAL_AND) reduce 45) ((T_LOGICAL_OR) reduce 45) ((T_LOGICAL_XOR) reduce 45) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 45) ((T_OBJECT_OPERATOR) reduce 45) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 45) ((T_POW) reduce 45) ((T_SL) reduce 45) ((T_SPACESHIP) reduce 45) ((T_SR) reduce 45) (("[") reduce 45) (("^") reduce 45) (("{") reduce 45) (("|") reduce 45) (("}") reduce 45)) 4600 ((("%") reduce 504) (("(") reduce 541) (("*") reduce 504) (("+") reduce 504) ((",") reduce 504) (("-") reduce 504) ((".") reduce 504) (("/") reduce 504) (("<") reduce 504) ((">") reduce 504) (("?") reduce 504) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_BOOLEAN_AND) reduce 504) ((T_BOOLEAN_OR) reduce 504) ((T_COALESCE) reduce 504) ((T_INSTANCEOF) reduce 504) ((T_IS_EQUAL) reduce 504) ((T_IS_GREATER_OR_EQUAL) reduce 504) ((T_IS_IDENTICAL) reduce 504) ((T_IS_NOT_EQUAL) reduce 504) ((T_IS_NOT_IDENTICAL) reduce 504) ((T_IS_SMALLER_OR_EQUAL) reduce 504) ((T_LOGICAL_AND) reduce 504) ((T_LOGICAL_OR) reduce 504) ((T_LOGICAL_XOR) reduce 504) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 504) ((T_OBJECT_OPERATOR) reduce 504) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 504) ((T_POW) reduce 504) ((T_SL) reduce 504) ((T_SPACESHIP) reduce 504) ((T_SR) reduce 504) (("[") reduce 504) (("^") reduce 504) (("{") reduce 504) (("|") reduce 504) (("}") reduce 504)) 4602 ((("%") reduce 71) (("(") reduce 71) (("*") reduce 71) (("+") reduce 71) ((",") reduce 71) (("-") reduce 71) ((".") reduce 71) (("/") reduce 71) (("<") reduce 71) ((">") reduce 71) (("?") reduce 71) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_BOOLEAN_AND) reduce 71) ((T_BOOLEAN_OR) reduce 71) ((T_COALESCE) reduce 71) ((T_INSTANCEOF) reduce 71) ((T_IS_EQUAL) reduce 71) ((T_IS_GREATER_OR_EQUAL) reduce 71) ((T_IS_IDENTICAL) reduce 71) ((T_IS_NOT_EQUAL) reduce 71) ((T_IS_NOT_IDENTICAL) reduce 71) ((T_IS_SMALLER_OR_EQUAL) reduce 71) ((T_LOGICAL_AND) reduce 71) ((T_LOGICAL_OR) reduce 71) ((T_LOGICAL_XOR) reduce 71) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 71) ((T_OBJECT_OPERATOR) reduce 71) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 71) ((T_POW) reduce 71) ((T_SL) reduce 71) ((T_SPACESHIP) reduce 71) ((T_SR) reduce 71) (("[") reduce 71) (("^") reduce 71) (("{") reduce 71) (("|") reduce 71) (("}") reduce 71)) 4603 ((("%") reduce 82) (("(") reduce 82) (("*") reduce 82) (("+") reduce 82) ((",") reduce 82) (("-") reduce 82) ((".") reduce 82) (("/") reduce 82) (("<") reduce 82) ((">") reduce 82) (("?") reduce 82) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_BOOLEAN_AND) reduce 82) ((T_BOOLEAN_OR) reduce 82) ((T_COALESCE) reduce 82) ((T_INSTANCEOF) reduce 82) ((T_IS_EQUAL) reduce 82) ((T_IS_GREATER_OR_EQUAL) reduce 82) ((T_IS_IDENTICAL) reduce 82) ((T_IS_NOT_EQUAL) reduce 82) ((T_IS_NOT_IDENTICAL) reduce 82) ((T_IS_SMALLER_OR_EQUAL) reduce 82) ((T_LOGICAL_AND) reduce 82) ((T_LOGICAL_OR) reduce 82) ((T_LOGICAL_XOR) reduce 82) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 82) ((T_OBJECT_OPERATOR) reduce 82) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 82) ((T_POW) reduce 82) ((T_SL) reduce 82) ((T_SPACESHIP) reduce 82) ((T_SR) reduce 82) (("[") reduce 82) (("^") reduce 82) (("{") reduce 82) (("|") reduce 82) (("}") reduce 82)) 4604 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) ((",") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) (("<") reduce 533) (("=") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AND_EQUAL) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_COALESCE_EQUAL) reduce 533) ((T_CONCAT_EQUAL) reduce 533) ((T_DEC) reduce 533) ((T_DIV_EQUAL) reduce 533) ((T_INC) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_MINUS_EQUAL) reduce 533) ((T_MOD_EQUAL) reduce 533) ((T_MUL_EQUAL) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_OR_EQUAL) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_PLUS_EQUAL) reduce 533) ((T_POW) reduce 533) ((T_POW_EQUAL) reduce 533) ((T_SL) reduce 533) ((T_SL_EQUAL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) ((T_SR_EQUAL) reduce 533) ((T_XOR_EQUAL) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533) (("}") reduce 533)) 4607 ((("%") reduce 506) (("(") reduce 542) (("*") reduce 506) (("+") reduce 506) ((",") reduce 506) (("-") reduce 506) ((".") reduce 506) (("/") reduce 506) (("<") reduce 506) ((">") reduce 506) (("?") reduce 506) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_BOOLEAN_AND) reduce 506) ((T_BOOLEAN_OR) reduce 506) ((T_COALESCE) reduce 506) ((T_INSTANCEOF) reduce 506) ((T_IS_EQUAL) reduce 506) ((T_IS_GREATER_OR_EQUAL) reduce 506) ((T_IS_IDENTICAL) reduce 506) ((T_IS_NOT_EQUAL) reduce 506) ((T_IS_NOT_IDENTICAL) reduce 506) ((T_IS_SMALLER_OR_EQUAL) reduce 506) ((T_LOGICAL_AND) reduce 506) ((T_LOGICAL_OR) reduce 506) ((T_LOGICAL_XOR) reduce 506) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 506) ((T_OBJECT_OPERATOR) reduce 506) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 506) ((T_POW) reduce 506) ((T_SL) reduce 506) ((T_SPACESHIP) reduce 506) ((T_SR) reduce 506) (("[") reduce 506) (("^") reduce 506) (("{") reduce 506) (("|") reduce 506) (("}") reduce 506)) 4609 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) ((",") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) (("<") reduce 468) (("=") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AND_EQUAL) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_COALESCE_EQUAL) reduce 468) ((T_CONCAT_EQUAL) reduce 468) ((T_DEC) reduce 468) ((T_DIV_EQUAL) reduce 468) ((T_INC) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_MINUS_EQUAL) reduce 468) ((T_MOD_EQUAL) reduce 468) ((T_MUL_EQUAL) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_OR_EQUAL) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_PLUS_EQUAL) reduce 468) ((T_POW) reduce 468) ((T_POW_EQUAL) reduce 468) ((T_SL) reduce 468) ((T_SL_EQUAL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) ((T_SR_EQUAL) reduce 468) ((T_XOR_EQUAL) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468) (("}") reduce 468)) 4610 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) ((",") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) (("=") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AND_EQUAL) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_COALESCE_EQUAL) reduce 288) ((T_CONCAT_EQUAL) reduce 288) ((T_DEC) reduce 288) ((T_DIV_EQUAL) reduce 288) ((T_INC) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_MINUS_EQUAL) reduce 288) ((T_MOD_EQUAL) reduce 288) ((T_MUL_EQUAL) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_OR_EQUAL) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_PLUS_EQUAL) reduce 288) ((T_POW) reduce 288) ((T_POW_EQUAL) reduce 288) ((T_SL) reduce 288) ((T_SL_EQUAL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) ((T_SR_EQUAL) reduce 288) ((T_XOR_EQUAL) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288) (("}") reduce 288)) 4614 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) ((",") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) (("=") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AND_EQUAL) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_COALESCE_EQUAL) reduce 289) ((T_CONCAT_EQUAL) reduce 289) ((T_DEC) reduce 289) ((T_DIV_EQUAL) reduce 289) ((T_INC) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_MINUS_EQUAL) reduce 289) ((T_MOD_EQUAL) reduce 289) ((T_MUL_EQUAL) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_OR_EQUAL) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_PLUS_EQUAL) reduce 289) ((T_POW) reduce 289) ((T_POW_EQUAL) reduce 289) ((T_SL) reduce 289) ((T_SL_EQUAL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) ((T_SR_EQUAL) reduce 289) ((T_XOR_EQUAL) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289) (("}") reduce 289)) 4615 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) ((",") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) (("=") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AND_EQUAL) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_COALESCE_EQUAL) reduce 290) ((T_CONCAT_EQUAL) reduce 290) ((T_DEC) reduce 290) ((T_DIV_EQUAL) reduce 290) ((T_INC) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_MINUS_EQUAL) reduce 290) ((T_MOD_EQUAL) reduce 290) ((T_MUL_EQUAL) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_OR_EQUAL) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_PLUS_EQUAL) reduce 290) ((T_POW) reduce 290) ((T_POW_EQUAL) reduce 290) ((T_SL) reduce 290) ((T_SL_EQUAL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) ((T_SR_EQUAL) reduce 290) ((T_XOR_EQUAL) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290) (("}") reduce 290)) 4620 ((("%") reduce 388) (("*") reduce 388) (("+") reduce 388) ((",") reduce 388) (("-") reduce 388) ((".") reduce 388) (("/") reduce 388) (("<") reduce 388) ((">") reduce 388) (("?") reduce 388) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_BOOLEAN_AND) reduce 388) ((T_BOOLEAN_OR) reduce 388) ((T_COALESCE) reduce 388) ((T_INSTANCEOF) reduce 388) ((T_IS_EQUAL) reduce 388) ((T_IS_GREATER_OR_EQUAL) reduce 388) ((T_IS_IDENTICAL) reduce 388) ((T_IS_NOT_EQUAL) reduce 388) ((T_IS_NOT_IDENTICAL) reduce 388) ((T_IS_SMALLER_OR_EQUAL) reduce 388) ((T_LOGICAL_AND) reduce 388) ((T_LOGICAL_OR) reduce 388) ((T_LOGICAL_XOR) reduce 388) ((T_POW) reduce 388) ((T_SL) reduce 388) ((T_SPACESHIP) reduce 388) ((T_SR) reduce 388) (("^") reduce 388) (("|") reduce 388) (("}") reduce 388)) 4622 ((("%") reduce 386) (("*") reduce 386) (("+") reduce 386) ((",") reduce 386) (("-") reduce 386) ((".") reduce 386) (("/") reduce 386) (("<") reduce 386) ((">") reduce 386) (("?") reduce 386) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_BOOLEAN_AND) reduce 386) ((T_BOOLEAN_OR) reduce 386) ((T_COALESCE) reduce 386) ((T_INSTANCEOF) reduce 386) ((T_IS_EQUAL) reduce 386) ((T_IS_GREATER_OR_EQUAL) reduce 386) ((T_IS_IDENTICAL) reduce 386) ((T_IS_NOT_EQUAL) reduce 386) ((T_IS_NOT_IDENTICAL) reduce 386) ((T_IS_SMALLER_OR_EQUAL) reduce 386) ((T_LOGICAL_AND) reduce 386) ((T_LOGICAL_OR) reduce 386) ((T_LOGICAL_XOR) reduce 386) ((T_POW) reduce 386) ((T_SL) reduce 386) ((T_SPACESHIP) reduce 386) ((T_SR) reduce 386) (("^") reduce 386) (("|") reduce 386) (("}") reduce 386)) 4632 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 382) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 382) ((T_LOGICAL_OR) reduce 382) ((T_LOGICAL_XOR) reduce 382) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 382)) 4633 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 384) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 384) ((T_LOGICAL_OR) reduce 384) ((T_LOGICAL_XOR) reduce 384) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 384)) 4634 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 383) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 383) ((T_LOGICAL_OR) reduce 383) ((T_LOGICAL_XOR) reduce 383) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 383)) 4635 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 376) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 376) ((T_LOGICAL_OR) reduce 376) ((T_LOGICAL_XOR) reduce 376) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 376)) 4636 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 373) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 373) ((T_LOGICAL_OR) reduce 373) ((T_LOGICAL_XOR) reduce 373) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 373)) 4637 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 381) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 381) ((T_LOGICAL_OR) reduce 381) ((T_LOGICAL_XOR) reduce 381) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 381)) 4638 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 375) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 375) ((T_LOGICAL_OR) reduce 375) ((T_LOGICAL_XOR) reduce 375) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 375)) 4639 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 379) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 379) ((T_LOGICAL_OR) reduce 379) ((T_LOGICAL_XOR) reduce 379) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 379)) 4640 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 374) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 374) ((T_LOGICAL_OR) reduce 374) ((T_LOGICAL_XOR) reduce 374) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 374)) 4641 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 377) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 377) ((T_LOGICAL_OR) reduce 377) ((T_LOGICAL_XOR) reduce 377) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 377)) 4642 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 378) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 378) ((T_LOGICAL_OR) reduce 378) ((T_LOGICAL_XOR) reduce 378) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 378)) 4643 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 385) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 385) ((T_LOGICAL_OR) reduce 385) ((T_LOGICAL_XOR) reduce 385) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 385)) 4644 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 380) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 380) ((T_LOGICAL_OR) reduce 380) ((T_LOGICAL_XOR) reduce 380) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 380)) 4646 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 370) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 370) ((T_LOGICAL_OR) reduce 370) ((T_LOGICAL_XOR) reduce 370) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 370)) 4649 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) ((",") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529) (("}") reduce 529)) 4652 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) ((",") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) (("<") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_POW) reduce 525) ((T_SL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525) (("}") reduce 525)) 4654 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) ((",") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) (("<") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_POW) reduce 524) ((T_SL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524) (("}") reduce 524)) 4656 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) ((",") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) (("<") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_POW) reduce 519) ((T_SL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519) (("}") reduce 519)) 4657 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) ((",") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) (("<") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_POW) reduce 526) ((T_SL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526) (("}") reduce 526)) 4658 ((("%") reduce 371) (("*") reduce 371) (("+") reduce 371) ((",") reduce 371) (("-") reduce 371) ((".") reduce 371) (("/") reduce 371) (("<") reduce 371) ((">") reduce 371) (("?") reduce 371) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_BOOLEAN_AND) reduce 371) ((T_BOOLEAN_OR) reduce 371) ((T_COALESCE) reduce 371) ((T_INSTANCEOF) reduce 371) ((T_IS_EQUAL) reduce 371) ((T_IS_GREATER_OR_EQUAL) reduce 371) ((T_IS_IDENTICAL) reduce 371) ((T_IS_NOT_EQUAL) reduce 371) ((T_IS_NOT_IDENTICAL) reduce 371) ((T_IS_SMALLER_OR_EQUAL) reduce 371) ((T_LOGICAL_AND) reduce 371) ((T_LOGICAL_OR) reduce 371) ((T_LOGICAL_XOR) reduce 371) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 371) ((T_SL) reduce 371) ((T_SPACESHIP) reduce 371) ((T_SR) reduce 371) (("[") reduce 510) (("^") reduce 371) (("{") reduce 510) (("|") reduce 371) (("}") reduce 371)) 4662 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) ((",") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) (("<") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_POW) reduce 533) ((T_SL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533) (("}") reduce 533)) 4664 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) ((",") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) (("<") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_POW) reduce 468) ((T_SL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468) (("}") reduce 468)) 4665 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) ((",") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288) (("}") reduce 288)) 4669 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) ((",") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289) (("}") reduce 289)) 4670 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) ((",") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290) (("}") reduce 290)) 4671 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) ((",") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) (("<") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_POW) reduce 465) ((T_SL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465) (("}") reduce 465)) 4674 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) ((",") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) (("<") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_POW) reduce 532) ((T_SL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532) (("}") reduce 532)) 4675 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) ((",") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) (("<") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_POW) reduce 467) ((T_SL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467) (("}") reduce 467)) 4676 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) ((",") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) (("<") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_POW) reduce 469) ((T_SL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469) (("}") reduce 469)) 4682 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) ((",") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) (("<") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_POW) reduce 521) ((T_SL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521) (("}") reduce 521)) 4684 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) ((",") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) (("<") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_POW) reduce 520) ((T_SL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520) (("}") reduce 520)) 4685 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) ((",") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544) (("}") reduce 544)) 4686 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) ((",") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) (("<") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_POW) reduce 527) ((T_SL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527) (("}") reduce 527)) 4687 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) ((",") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546) (("}") reduce 546)) 4690 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) ((",") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545) (("}") reduce 545)) 4691 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) ((",") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) (("<") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_POW) reduce 522) ((T_SL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522) (("}") reduce 522)) 4692 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) ((",") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) (("<") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_POW) reduce 528) ((T_SL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528) (("}") reduce 528)) 4693 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) ((",") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) (("<") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_POW) reduce 523) ((T_SL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523) (("}") reduce 523)) 4694 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) ((",") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) (("<") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_POW) reduce 466) ((T_SL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466) (("}") reduce 466)) 4695 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) ((",") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531) (("}") reduce 531)) 4698 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) ((",") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530) (("}") reduce 530)) 4699 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) ((",") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) (("<") reduce 465) (("=") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AND_EQUAL) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_COALESCE_EQUAL) reduce 465) ((T_CONCAT_EQUAL) reduce 465) ((T_DEC) reduce 465) ((T_DIV_EQUAL) reduce 465) ((T_INC) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_MINUS_EQUAL) reduce 465) ((T_MOD_EQUAL) reduce 465) ((T_MUL_EQUAL) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_OR_EQUAL) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_PLUS_EQUAL) reduce 465) ((T_POW) reduce 465) ((T_POW_EQUAL) reduce 465) ((T_SL) reduce 465) ((T_SL_EQUAL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) ((T_SR_EQUAL) reduce 465) ((T_XOR_EQUAL) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465) (("}") reduce 465)) 4710 ((("%") reduce 455) (("*") reduce 455) (("+") reduce 455) ((",") reduce 455) (("-") reduce 455) ((".") reduce 455) (("/") reduce 455) (("<") reduce 455) ((">") reduce 455) (("?") reduce 455) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_BOOLEAN_AND) reduce 455) ((T_BOOLEAN_OR) reduce 455) ((T_COALESCE) reduce 455) ((T_INSTANCEOF) reduce 455) ((T_IS_EQUAL) reduce 455) ((T_IS_GREATER_OR_EQUAL) reduce 455) ((T_IS_IDENTICAL) reduce 455) ((T_IS_NOT_EQUAL) reduce 455) ((T_IS_NOT_IDENTICAL) reduce 455) ((T_IS_SMALLER_OR_EQUAL) reduce 455) ((T_LOGICAL_AND) reduce 455) ((T_LOGICAL_OR) reduce 455) ((T_LOGICAL_XOR) reduce 455) ((T_POW) reduce 455) ((T_SL) reduce 455) ((T_SPACESHIP) reduce 455) ((T_SR) reduce 455) (("^") reduce 455) (("|") reduce 455) (("}") reduce 455)) 4711 ((("%") reduce 450) (("*") reduce 450) (("+") reduce 450) ((",") reduce 450) (("-") reduce 450) ((".") reduce 450) (("/") reduce 450) (("<") reduce 450) ((">") reduce 450) (("?") reduce 450) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_BOOLEAN_AND) reduce 450) ((T_BOOLEAN_OR) reduce 450) ((T_COALESCE) reduce 450) ((T_INSTANCEOF) reduce 450) ((T_IS_EQUAL) reduce 450) ((T_IS_GREATER_OR_EQUAL) reduce 450) ((T_IS_IDENTICAL) reduce 450) ((T_IS_NOT_EQUAL) reduce 450) ((T_IS_NOT_IDENTICAL) reduce 450) ((T_IS_SMALLER_OR_EQUAL) reduce 450) ((T_LOGICAL_AND) reduce 450) ((T_LOGICAL_OR) reduce 450) ((T_LOGICAL_XOR) reduce 450) ((T_POW) reduce 450) ((T_SL) reduce 450) ((T_SPACESHIP) reduce 450) ((T_SR) reduce 450) (("^") reduce 450) (("|") reduce 450) (("}") reduce 450)) 4721 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 455) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 455)) 4722 ((("%") reduce 451) (("*") reduce 451) (("+") reduce 451) ((",") reduce 451) (("-") reduce 451) ((".") reduce 451) (("/") reduce 451) (("<") reduce 451) ((">") reduce 451) (("?") reduce 451) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_BOOLEAN_AND) reduce 451) ((T_BOOLEAN_OR) reduce 451) ((T_COALESCE) reduce 451) ((T_INSTANCEOF) reduce 451) ((T_IS_EQUAL) reduce 451) ((T_IS_GREATER_OR_EQUAL) reduce 451) ((T_IS_IDENTICAL) reduce 451) ((T_IS_NOT_EQUAL) reduce 451) ((T_IS_NOT_IDENTICAL) reduce 451) ((T_IS_SMALLER_OR_EQUAL) reduce 451) ((T_LOGICAL_AND) reduce 451) ((T_LOGICAL_OR) reduce 451) ((T_LOGICAL_XOR) reduce 451) ((T_POW) reduce 451) ((T_SL) reduce 451) ((T_SPACESHIP) reduce 451) ((T_SR) reduce 451) (("^") reduce 451) (("|") reduce 451) (("}") reduce 451)) 4724 ((("%") reduce 503) (("(") reduce 541) (("*") reduce 503) (("+") reduce 503) ((",") reduce 503) (("-") reduce 503) ((".") reduce 503) (("/") reduce 503) (("<") reduce 503) ((">") reduce 503) (("?") reduce 503) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_BOOLEAN_AND) reduce 503) ((T_BOOLEAN_OR) reduce 503) ((T_COALESCE) reduce 503) ((T_INSTANCEOF) reduce 503) ((T_IS_EQUAL) reduce 503) ((T_IS_GREATER_OR_EQUAL) reduce 503) ((T_IS_IDENTICAL) reduce 503) ((T_IS_NOT_EQUAL) reduce 503) ((T_IS_NOT_IDENTICAL) reduce 503) ((T_IS_SMALLER_OR_EQUAL) reduce 503) ((T_LOGICAL_AND) reduce 503) ((T_LOGICAL_OR) reduce 503) ((T_LOGICAL_XOR) reduce 503) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 503) ((T_OBJECT_OPERATOR) reduce 503) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 503) ((T_POW) reduce 503) ((T_SL) reduce 503) ((T_SPACESHIP) reduce 503) ((T_SR) reduce 503) (("[") reduce 503) (("^") reduce 503) (("{") reduce 503) (("|") reduce 503) (("}") reduce 503)) 4726 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) ((",") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) (("<") reduce 532) (("=") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AND_EQUAL) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_COALESCE_EQUAL) reduce 532) ((T_CONCAT_EQUAL) reduce 532) ((T_DEC) reduce 532) ((T_DIV_EQUAL) reduce 532) ((T_INC) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_MINUS_EQUAL) reduce 532) ((T_MOD_EQUAL) reduce 532) ((T_MUL_EQUAL) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_OR_EQUAL) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_PLUS_EQUAL) reduce 532) ((T_POW) reduce 532) ((T_POW_EQUAL) reduce 532) ((T_SL) reduce 532) ((T_SL_EQUAL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) ((T_SR_EQUAL) reduce 532) ((T_XOR_EQUAL) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532) (("}") reduce 532)) 4729 ((("%") reduce 505) (("(") reduce 542) (("*") reduce 505) (("+") reduce 505) ((",") reduce 505) (("-") reduce 505) ((".") reduce 505) (("/") reduce 505) (("<") reduce 505) ((">") reduce 505) (("?") reduce 505) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_BOOLEAN_AND) reduce 505) ((T_BOOLEAN_OR) reduce 505) ((T_COALESCE) reduce 505) ((T_INSTANCEOF) reduce 505) ((T_IS_EQUAL) reduce 505) ((T_IS_GREATER_OR_EQUAL) reduce 505) ((T_IS_IDENTICAL) reduce 505) ((T_IS_NOT_EQUAL) reduce 505) ((T_IS_NOT_IDENTICAL) reduce 505) ((T_IS_SMALLER_OR_EQUAL) reduce 505) ((T_LOGICAL_AND) reduce 505) ((T_LOGICAL_OR) reduce 505) ((T_LOGICAL_XOR) reduce 505) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 505) ((T_OBJECT_OPERATOR) reduce 505) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 505) ((T_POW) reduce 505) ((T_SL) reduce 505) ((T_SPACESHIP) reduce 505) ((T_SR) reduce 505) (("[") reduce 505) (("^") reduce 505) (("{") reduce 505) (("|") reduce 505) (("}") reduce 505)) 4730 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) ((",") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) (("<") reduce 467) (("=") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AND_EQUAL) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_COALESCE_EQUAL) reduce 467) ((T_CONCAT_EQUAL) reduce 467) ((T_DEC) reduce 467) ((T_DIV_EQUAL) reduce 467) ((T_INC) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_MINUS_EQUAL) reduce 467) ((T_MOD_EQUAL) reduce 467) ((T_MUL_EQUAL) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_OR_EQUAL) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_PLUS_EQUAL) reduce 467) ((T_POW) reduce 467) ((T_POW_EQUAL) reduce 467) ((T_SL) reduce 467) ((T_SL_EQUAL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) ((T_SR_EQUAL) reduce 467) ((T_XOR_EQUAL) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467) (("}") reduce 467)) 4731 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) ((",") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) (("<") reduce 469) (("=") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AND_EQUAL) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_COALESCE_EQUAL) reduce 469) ((T_CONCAT_EQUAL) reduce 469) ((T_DEC) reduce 469) ((T_DIV_EQUAL) reduce 469) ((T_INC) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_MINUS_EQUAL) reduce 469) ((T_MOD_EQUAL) reduce 469) ((T_MUL_EQUAL) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_OR_EQUAL) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_PLUS_EQUAL) reduce 469) ((T_POW) reduce 469) ((T_POW_EQUAL) reduce 469) ((T_SL) reduce 469) ((T_SL_EQUAL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) ((T_SR_EQUAL) reduce 469) ((T_XOR_EQUAL) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469) (("}") reduce 469)) 4733 ((("%") reduce 446) (("*") reduce 446) (("+") reduce 446) ((",") reduce 446) (("-") reduce 446) ((".") reduce 446) (("/") reduce 446) (("<") reduce 446) ((">") reduce 446) (("?") reduce 446) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_BOOLEAN_AND) reduce 446) ((T_BOOLEAN_OR) reduce 446) ((T_COALESCE) reduce 446) ((T_INSTANCEOF) reduce 446) ((T_IS_EQUAL) reduce 446) ((T_IS_GREATER_OR_EQUAL) reduce 446) ((T_IS_IDENTICAL) reduce 446) ((T_IS_NOT_EQUAL) reduce 446) ((T_IS_NOT_IDENTICAL) reduce 446) ((T_IS_SMALLER_OR_EQUAL) reduce 446) ((T_LOGICAL_AND) reduce 446) ((T_LOGICAL_OR) reduce 446) ((T_LOGICAL_XOR) reduce 446) ((T_POW) reduce 446) ((T_SL) reduce 446) ((T_SPACESHIP) reduce 446) ((T_SR) reduce 446) (("^") reduce 446) (("|") reduce 446) (("}") reduce 446)) 4734 ((("%") reduce 448) (("*") reduce 448) (("+") reduce 448) ((",") reduce 448) (("-") reduce 448) ((".") reduce 448) (("/") reduce 448) (("<") reduce 448) ((">") reduce 448) (("?") reduce 448) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_BOOLEAN_AND) reduce 448) ((T_BOOLEAN_OR) reduce 448) ((T_COALESCE) reduce 448) ((T_INSTANCEOF) reduce 448) ((T_IS_EQUAL) reduce 448) ((T_IS_GREATER_OR_EQUAL) reduce 448) ((T_IS_IDENTICAL) reduce 448) ((T_IS_NOT_EQUAL) reduce 448) ((T_IS_NOT_IDENTICAL) reduce 448) ((T_IS_SMALLER_OR_EQUAL) reduce 448) ((T_LOGICAL_AND) reduce 448) ((T_LOGICAL_OR) reduce 448) ((T_LOGICAL_XOR) reduce 448) ((T_POW) reduce 448) ((T_SL) reduce 448) ((T_SPACESHIP) reduce 448) ((T_SR) reduce 448) (("^") reduce 448) (("|") reduce 448) (("}") reduce 448)) 4740 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) ((",") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) (("<") reduce 521) (("=") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AND_EQUAL) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_COALESCE_EQUAL) reduce 521) ((T_CONCAT_EQUAL) reduce 521) ((T_DEC) reduce 521) ((T_DIV_EQUAL) reduce 521) ((T_INC) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_MINUS_EQUAL) reduce 521) ((T_MOD_EQUAL) reduce 521) ((T_MUL_EQUAL) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_OR_EQUAL) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_PLUS_EQUAL) reduce 521) ((T_POW) reduce 521) ((T_POW_EQUAL) reduce 521) ((T_SL) reduce 521) ((T_SL_EQUAL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) ((T_SR_EQUAL) reduce 521) ((T_XOR_EQUAL) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521) (("}") reduce 521)) 4742 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) ((",") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) (("<") reduce 520) (("=") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AND_EQUAL) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_COALESCE_EQUAL) reduce 520) ((T_CONCAT_EQUAL) reduce 520) ((T_DEC) reduce 520) ((T_DIV_EQUAL) reduce 520) ((T_INC) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_MINUS_EQUAL) reduce 520) ((T_MOD_EQUAL) reduce 520) ((T_MUL_EQUAL) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_OR_EQUAL) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_PLUS_EQUAL) reduce 520) ((T_POW) reduce 520) ((T_POW_EQUAL) reduce 520) ((T_SL) reduce 520) ((T_SL_EQUAL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) ((T_SR_EQUAL) reduce 520) ((T_XOR_EQUAL) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520) (("}") reduce 520)) 4743 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) ((",") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) (("=") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AND_EQUAL) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_COALESCE_EQUAL) reduce 544) ((T_CONCAT_EQUAL) reduce 544) ((T_DEC) reduce 544) ((T_DIV_EQUAL) reduce 544) ((T_INC) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_MINUS_EQUAL) reduce 544) ((T_MOD_EQUAL) reduce 544) ((T_MUL_EQUAL) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_OR_EQUAL) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_PLUS_EQUAL) reduce 544) ((T_POW) reduce 544) ((T_POW_EQUAL) reduce 544) ((T_SL) reduce 544) ((T_SL_EQUAL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) ((T_SR_EQUAL) reduce 544) ((T_XOR_EQUAL) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544) (("}") reduce 544)) 4744 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) ((",") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) (("<") reduce 527) (("=") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AND_EQUAL) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_COALESCE_EQUAL) reduce 527) ((T_CONCAT_EQUAL) reduce 527) ((T_DEC) reduce 527) ((T_DIV_EQUAL) reduce 527) ((T_INC) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_MINUS_EQUAL) reduce 527) ((T_MOD_EQUAL) reduce 527) ((T_MUL_EQUAL) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_OR_EQUAL) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_PLUS_EQUAL) reduce 527) ((T_POW) reduce 527) ((T_POW_EQUAL) reduce 527) ((T_SL) reduce 527) ((T_SL_EQUAL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) ((T_SR_EQUAL) reduce 527) ((T_XOR_EQUAL) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527) (("}") reduce 527)) 4745 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) ((",") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) (("=") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AND_EQUAL) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_COALESCE_EQUAL) reduce 546) ((T_CONCAT_EQUAL) reduce 546) ((T_DEC) reduce 546) ((T_DIV_EQUAL) reduce 546) ((T_INC) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_MINUS_EQUAL) reduce 546) ((T_MOD_EQUAL) reduce 546) ((T_MUL_EQUAL) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_OR_EQUAL) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_PLUS_EQUAL) reduce 546) ((T_POW) reduce 546) ((T_POW_EQUAL) reduce 546) ((T_SL) reduce 546) ((T_SL_EQUAL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) ((T_SR_EQUAL) reduce 546) ((T_XOR_EQUAL) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546) (("}") reduce 546)) 4748 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) ((",") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) (("=") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AND_EQUAL) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_COALESCE_EQUAL) reduce 545) ((T_CONCAT_EQUAL) reduce 545) ((T_DEC) reduce 545) ((T_DIV_EQUAL) reduce 545) ((T_INC) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_MINUS_EQUAL) reduce 545) ((T_MOD_EQUAL) reduce 545) ((T_MUL_EQUAL) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_OR_EQUAL) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_PLUS_EQUAL) reduce 545) ((T_POW) reduce 545) ((T_POW_EQUAL) reduce 545) ((T_SL) reduce 545) ((T_SL_EQUAL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) ((T_SR_EQUAL) reduce 545) ((T_XOR_EQUAL) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545) (("}") reduce 545)) 4749 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) ((",") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) (("<") reduce 522) (("=") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AND_EQUAL) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_COALESCE_EQUAL) reduce 522) ((T_CONCAT_EQUAL) reduce 522) ((T_DEC) reduce 522) ((T_DIV_EQUAL) reduce 522) ((T_INC) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_MINUS_EQUAL) reduce 522) ((T_MOD_EQUAL) reduce 522) ((T_MUL_EQUAL) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_OR_EQUAL) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_PLUS_EQUAL) reduce 522) ((T_POW) reduce 522) ((T_POW_EQUAL) reduce 522) ((T_SL) reduce 522) ((T_SL_EQUAL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) ((T_SR_EQUAL) reduce 522) ((T_XOR_EQUAL) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522) (("}") reduce 522)) 4750 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) ((",") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) (("<") reduce 528) (("=") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AND_EQUAL) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_COALESCE_EQUAL) reduce 528) ((T_CONCAT_EQUAL) reduce 528) ((T_DEC) reduce 528) ((T_DIV_EQUAL) reduce 528) ((T_INC) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_MINUS_EQUAL) reduce 528) ((T_MOD_EQUAL) reduce 528) ((T_MUL_EQUAL) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_OR_EQUAL) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_PLUS_EQUAL) reduce 528) ((T_POW) reduce 528) ((T_POW_EQUAL) reduce 528) ((T_SL) reduce 528) ((T_SL_EQUAL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) ((T_SR_EQUAL) reduce 528) ((T_XOR_EQUAL) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528) (("}") reduce 528)) 4751 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) ((",") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) (("<") reduce 523) (("=") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AND_EQUAL) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_COALESCE_EQUAL) reduce 523) ((T_CONCAT_EQUAL) reduce 523) ((T_DEC) reduce 523) ((T_DIV_EQUAL) reduce 523) ((T_INC) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_MINUS_EQUAL) reduce 523) ((T_MOD_EQUAL) reduce 523) ((T_MUL_EQUAL) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_OR_EQUAL) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_PLUS_EQUAL) reduce 523) ((T_POW) reduce 523) ((T_POW_EQUAL) reduce 523) ((T_SL) reduce 523) ((T_SL_EQUAL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) ((T_SR_EQUAL) reduce 523) ((T_XOR_EQUAL) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523) (("}") reduce 523)) 4753 ((("%") reduce 438) (("*") reduce 438) (("+") reduce 438) ((",") reduce 438) (("-") reduce 438) ((".") reduce 438) (("/") reduce 438) (("<") reduce 438) ((">") reduce 438) (("?") reduce 438) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_BOOLEAN_AND) reduce 438) ((T_BOOLEAN_OR) reduce 438) ((T_COALESCE) reduce 438) ((T_INSTANCEOF) reduce 438) ((T_IS_EQUAL) reduce 438) ((T_IS_GREATER_OR_EQUAL) reduce 438) ((T_IS_IDENTICAL) reduce 438) ((T_IS_NOT_EQUAL) reduce 438) ((T_IS_NOT_IDENTICAL) reduce 438) ((T_IS_SMALLER_OR_EQUAL) reduce 438) ((T_LOGICAL_AND) reduce 438) ((T_LOGICAL_OR) reduce 438) ((T_LOGICAL_XOR) reduce 438) ((T_POW) reduce 438) ((T_SL) reduce 438) ((T_SPACESHIP) reduce 438) ((T_SR) reduce 438) (("^") reduce 438) (("|") reduce 438) (("}") reduce 438)) 4755 ((("%") reduce 483) (("(") reduce 483) (("*") reduce 483) (("+") reduce 483) ((",") reduce 483) (("-") reduce 483) ((".") reduce 483) (("/") reduce 483) (("<") reduce 483) (("=") shift) ((">") reduce 483) (("?") reduce 483) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_BOOLEAN_AND) reduce 483) ((T_BOOLEAN_OR) reduce 483) ((T_COALESCE) reduce 483) ((T_INSTANCEOF) reduce 483) ((T_IS_EQUAL) reduce 483) ((T_IS_GREATER_OR_EQUAL) reduce 483) ((T_IS_IDENTICAL) reduce 483) ((T_IS_NOT_EQUAL) reduce 483) ((T_IS_NOT_IDENTICAL) reduce 483) ((T_IS_SMALLER_OR_EQUAL) reduce 483) ((T_LOGICAL_AND) reduce 483) ((T_LOGICAL_OR) reduce 483) ((T_LOGICAL_XOR) reduce 483) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 483) ((T_OBJECT_OPERATOR) reduce 483) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 483) ((T_POW) reduce 483) ((T_SL) reduce 483) ((T_SPACESHIP) reduce 483) ((T_SR) reduce 483) (("[") reduce 483) (("^") reduce 483) (("{") reduce 483) (("|") reduce 483) (("}") reduce 483)) 4757 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 369) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 369) ((T_LOGICAL_OR) reduce 369) ((T_LOGICAL_XOR) reduce 369) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 369)) 4758 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 443) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 443) ((T_LOGICAL_OR) reduce 443) ((T_LOGICAL_XOR) reduce 443) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 443)) 4769 ((("%") reduce 502) (("*") reduce 502) (("+") reduce 502) ((",") reduce 502) (("-") reduce 502) ((".") reduce 502) (("/") reduce 502) (("<") reduce 502) ((">") reduce 502) (("?") reduce 502) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_BOOLEAN_AND) reduce 502) ((T_BOOLEAN_OR) reduce 502) ((T_COALESCE) reduce 502) ((T_DOUBLE_ARROW) reduce 502) ((T_INSTANCEOF) reduce 502) ((T_IS_EQUAL) reduce 502) ((T_IS_GREATER_OR_EQUAL) reduce 502) ((T_IS_IDENTICAL) reduce 502) ((T_IS_NOT_EQUAL) reduce 502) ((T_IS_NOT_IDENTICAL) reduce 502) ((T_IS_SMALLER_OR_EQUAL) reduce 502) ((T_LOGICAL_AND) reduce 502) ((T_LOGICAL_OR) reduce 502) ((T_LOGICAL_XOR) reduce 502) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 502) ((T_OBJECT_OPERATOR) reduce 502) ((T_POW) reduce 502) ((T_SL) reduce 502) ((T_SPACESHIP) reduce 502) ((T_SR) reduce 502) (("[") reduce 502) (("^") reduce 502) (("{") reduce 502) (("|") reduce 502) (("}") reduce 502)) 4771 ((("%") reduce 484) (("(") reduce 484) (("*") reduce 484) (("+") reduce 484) ((",") reduce 484) (("-") reduce 484) ((".") reduce 484) (("/") reduce 484) (("<") reduce 484) ((">") reduce 484) (("?") reduce 484) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_BOOLEAN_AND) reduce 484) ((T_BOOLEAN_OR) reduce 484) ((T_COALESCE) reduce 484) ((T_DOUBLE_ARROW) reduce 484) ((T_INSTANCEOF) reduce 484) ((T_IS_EQUAL) reduce 484) ((T_IS_GREATER_OR_EQUAL) reduce 484) ((T_IS_IDENTICAL) reduce 484) ((T_IS_NOT_EQUAL) reduce 484) ((T_IS_NOT_IDENTICAL) reduce 484) ((T_IS_SMALLER_OR_EQUAL) reduce 484) ((T_LOGICAL_AND) reduce 484) ((T_LOGICAL_OR) reduce 484) ((T_LOGICAL_XOR) reduce 484) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 484) ((T_OBJECT_OPERATOR) reduce 484) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 484) ((T_POW) reduce 484) ((T_SL) reduce 484) ((T_SPACESHIP) reduce 484) ((T_SR) reduce 484) (("[") reduce 484) (("^") reduce 484) (("{") reduce 484) (("|") reduce 484) (("}") reduce 484)) 4773 ((("%") reduce 497) (("*") reduce 497) (("+") reduce 497) ((",") reduce 497) (("-") reduce 497) ((".") reduce 497) (("/") reduce 497) (("<") reduce 497) ((">") reduce 497) (("?") reduce 497) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_BOOLEAN_AND) reduce 497) ((T_BOOLEAN_OR) reduce 497) ((T_COALESCE) reduce 497) ((T_DOUBLE_ARROW) reduce 497) ((T_INSTANCEOF) reduce 497) ((T_IS_EQUAL) reduce 497) ((T_IS_GREATER_OR_EQUAL) reduce 497) ((T_IS_IDENTICAL) reduce 497) ((T_IS_NOT_EQUAL) reduce 497) ((T_IS_NOT_IDENTICAL) reduce 497) ((T_IS_SMALLER_OR_EQUAL) reduce 497) ((T_LOGICAL_AND) reduce 497) ((T_LOGICAL_OR) reduce 497) ((T_LOGICAL_XOR) reduce 497) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 497) ((T_OBJECT_OPERATOR) reduce 497) ((T_POW) reduce 497) ((T_SL) reduce 497) ((T_SPACESHIP) reduce 497) ((T_SR) reduce 497) (("[") reduce 497) (("^") reduce 497) (("{") reduce 497) (("|") reduce 497) (("}") reduce 497)) 4774 ((("%") reduce 487) (("*") reduce 487) (("+") reduce 487) ((",") reduce 487) (("-") reduce 487) ((".") reduce 487) (("/") reduce 487) (("<") reduce 487) ((">") reduce 487) (("?") reduce 487) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_BOOLEAN_AND) reduce 487) ((T_BOOLEAN_OR) reduce 487) ((T_COALESCE) reduce 487) ((T_DOUBLE_ARROW) reduce 487) ((T_INSTANCEOF) reduce 487) ((T_IS_EQUAL) reduce 487) ((T_IS_GREATER_OR_EQUAL) reduce 487) ((T_IS_IDENTICAL) reduce 487) ((T_IS_NOT_EQUAL) reduce 487) ((T_IS_NOT_IDENTICAL) reduce 487) ((T_IS_SMALLER_OR_EQUAL) reduce 487) ((T_LOGICAL_AND) reduce 487) ((T_LOGICAL_OR) reduce 487) ((T_LOGICAL_XOR) reduce 487) ((T_POW) reduce 487) ((T_SL) reduce 487) ((T_SPACESHIP) reduce 487) ((T_SR) reduce 487) (("^") reduce 487) (("|") reduce 487) (("}") reduce 487)) 4778 ((("%") reduce 475) (("(") shift) (("*") reduce 475) (("+") reduce 475) ((",") reduce 475) (("-") reduce 475) ((".") reduce 475) (("/") reduce 475) (("<") reduce 475) ((">") reduce 475) (("?") reduce 475) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_BOOLEAN_AND) reduce 475) ((T_BOOLEAN_OR) reduce 475) ((T_COALESCE) reduce 475) ((T_DOUBLE_ARROW) reduce 475) ((T_INSTANCEOF) reduce 475) ((T_IS_EQUAL) reduce 475) ((T_IS_GREATER_OR_EQUAL) reduce 475) ((T_IS_IDENTICAL) reduce 475) ((T_IS_NOT_EQUAL) reduce 475) ((T_IS_NOT_IDENTICAL) reduce 475) ((T_IS_SMALLER_OR_EQUAL) reduce 475) ((T_LOGICAL_AND) reduce 475) ((T_LOGICAL_OR) reduce 475) ((T_LOGICAL_XOR) reduce 475) ((T_POW) reduce 475) ((T_SL) reduce 475) ((T_SPACESHIP) reduce 475) ((T_SR) reduce 475) (("^") reduce 475) (("|") reduce 475) (("}") reduce 475)) 4779 ((("%") reduce 496) (("*") reduce 496) (("+") reduce 496) ((",") reduce 496) (("-") reduce 496) ((".") reduce 496) (("/") reduce 496) (("<") reduce 496) ((">") reduce 496) (("?") reduce 496) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_BOOLEAN_AND) reduce 496) ((T_BOOLEAN_OR) reduce 496) ((T_COALESCE) reduce 496) ((T_DOUBLE_ARROW) reduce 496) ((T_INSTANCEOF) reduce 496) ((T_IS_EQUAL) reduce 496) ((T_IS_GREATER_OR_EQUAL) reduce 496) ((T_IS_IDENTICAL) reduce 496) ((T_IS_NOT_EQUAL) reduce 496) ((T_IS_NOT_IDENTICAL) reduce 496) ((T_IS_SMALLER_OR_EQUAL) reduce 496) ((T_LOGICAL_AND) reduce 496) ((T_LOGICAL_OR) reduce 496) ((T_LOGICAL_XOR) reduce 496) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 496) ((T_OBJECT_OPERATOR) reduce 496) ((T_POW) reduce 496) ((T_SL) reduce 496) ((T_SPACESHIP) reduce 496) ((T_SR) reduce 496) (("[") reduce 496) (("^") reduce 496) (("{") reduce 496) (("|") reduce 496) (("}") reduce 496)) 4780 ((("%") reduce 500) (("*") reduce 500) (("+") reduce 500) ((",") reduce 500) (("-") reduce 500) ((".") reduce 500) (("/") reduce 500) (("<") reduce 500) ((">") reduce 500) (("?") reduce 500) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_BOOLEAN_AND) reduce 500) ((T_BOOLEAN_OR) reduce 500) ((T_COALESCE) reduce 500) ((T_DOUBLE_ARROW) reduce 500) ((T_INSTANCEOF) reduce 500) ((T_IS_EQUAL) reduce 500) ((T_IS_GREATER_OR_EQUAL) reduce 500) ((T_IS_IDENTICAL) reduce 500) ((T_IS_NOT_EQUAL) reduce 500) ((T_IS_NOT_IDENTICAL) reduce 500) ((T_IS_SMALLER_OR_EQUAL) reduce 500) ((T_LOGICAL_AND) reduce 500) ((T_LOGICAL_OR) reduce 500) ((T_LOGICAL_XOR) reduce 500) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 500) ((T_OBJECT_OPERATOR) reduce 500) ((T_POW) reduce 500) ((T_SL) reduce 500) ((T_SPACESHIP) reduce 500) ((T_SR) reduce 500) (("[") reduce 500) (("^") reduce 500) (("{") reduce 500) (("|") reduce 500) (("}") reduce 500)) 4786 ((("%") reduce 495) (("*") reduce 495) (("+") reduce 495) ((",") reduce 495) (("-") reduce 495) ((".") reduce 495) (("/") reduce 495) (("<") reduce 495) ((">") reduce 495) (("?") reduce 495) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_BOOLEAN_AND) reduce 495) ((T_BOOLEAN_OR) reduce 495) ((T_COALESCE) reduce 495) ((T_DOUBLE_ARROW) reduce 495) ((T_INSTANCEOF) reduce 495) ((T_IS_EQUAL) reduce 495) ((T_IS_GREATER_OR_EQUAL) reduce 495) ((T_IS_IDENTICAL) reduce 495) ((T_IS_NOT_EQUAL) reduce 495) ((T_IS_NOT_IDENTICAL) reduce 495) ((T_IS_SMALLER_OR_EQUAL) reduce 495) ((T_LOGICAL_AND) reduce 495) ((T_LOGICAL_OR) reduce 495) ((T_LOGICAL_XOR) reduce 495) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 495) ((T_OBJECT_OPERATOR) reduce 495) ((T_POW) reduce 495) ((T_SL) reduce 495) ((T_SPACESHIP) reduce 495) ((T_SR) reduce 495) (("[") reduce 495) (("^") reduce 495) (("{") reduce 495) (("|") reduce 495) (("}") reduce 495)) 4788 ((("%") reduce 486) (("*") reduce 486) (("+") reduce 486) ((",") reduce 486) (("-") reduce 486) ((".") reduce 486) (("/") reduce 486) (("<") reduce 486) ((">") reduce 486) (("?") reduce 486) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_BOOLEAN_AND) reduce 486) ((T_BOOLEAN_OR) reduce 486) ((T_COALESCE) reduce 486) ((T_DOUBLE_ARROW) reduce 486) ((T_INSTANCEOF) reduce 486) ((T_IS_EQUAL) reduce 486) ((T_IS_GREATER_OR_EQUAL) reduce 486) ((T_IS_IDENTICAL) reduce 486) ((T_IS_NOT_EQUAL) reduce 486) ((T_IS_NOT_IDENTICAL) reduce 486) ((T_IS_SMALLER_OR_EQUAL) reduce 486) ((T_LOGICAL_AND) reduce 486) ((T_LOGICAL_OR) reduce 486) ((T_LOGICAL_XOR) reduce 486) ((T_POW) reduce 486) ((T_SL) reduce 486) ((T_SPACESHIP) reduce 486) ((T_SR) reduce 486) (("^") reduce 486) (("|") reduce 486) (("}") reduce 486)) 4790 ((("%") reduce 499) (("*") reduce 499) (("+") reduce 499) ((",") reduce 499) (("-") reduce 499) ((".") reduce 499) (("/") reduce 499) (("<") reduce 499) ((">") reduce 499) (("?") reduce 499) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_BOOLEAN_AND) reduce 499) ((T_BOOLEAN_OR) reduce 499) ((T_COALESCE) reduce 499) ((T_DOUBLE_ARROW) reduce 499) ((T_INSTANCEOF) reduce 499) ((T_IS_EQUAL) reduce 499) ((T_IS_GREATER_OR_EQUAL) reduce 499) ((T_IS_IDENTICAL) reduce 499) ((T_IS_NOT_EQUAL) reduce 499) ((T_IS_NOT_IDENTICAL) reduce 499) ((T_IS_SMALLER_OR_EQUAL) reduce 499) ((T_LOGICAL_AND) reduce 499) ((T_LOGICAL_OR) reduce 499) ((T_LOGICAL_XOR) reduce 499) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 499) ((T_OBJECT_OPERATOR) reduce 499) ((T_POW) reduce 499) ((T_SL) reduce 499) ((T_SPACESHIP) reduce 499) ((T_SR) reduce 499) (("[") reduce 499) (("^") reduce 499) (("{") reduce 499) (("|") reduce 499) (("}") reduce 499)) 4791 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) ((",") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 93) ((T_OBJECT_OPERATOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("[") reduce 93) (("^") reduce 93) (("{") reduce 93) (("|") reduce 93) (("}") reduce 93)) 4792 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) ((",") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 92) ((T_OBJECT_OPERATOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("[") reduce 92) (("^") reduce 92) (("{") reduce 92) (("|") reduce 92) (("}") reduce 92)) 4793 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) ((",") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 94) ((T_OBJECT_OPERATOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("[") reduce 94) (("^") reduce 94) (("{") reduce 94) (("|") reduce 94) (("}") reduce 94)) 4795 ((("%") reduce 501) (("*") reduce 501) (("+") reduce 501) ((",") reduce 501) (("-") reduce 501) ((".") reduce 501) (("/") reduce 501) (("<") reduce 501) ((">") reduce 501) (("?") reduce 501) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_BOOLEAN_AND) reduce 501) ((T_BOOLEAN_OR) reduce 501) ((T_COALESCE) reduce 501) ((T_DOUBLE_ARROW) reduce 501) ((T_INSTANCEOF) reduce 501) ((T_IS_EQUAL) reduce 501) ((T_IS_GREATER_OR_EQUAL) reduce 501) ((T_IS_IDENTICAL) reduce 501) ((T_IS_NOT_EQUAL) reduce 501) ((T_IS_NOT_IDENTICAL) reduce 501) ((T_IS_SMALLER_OR_EQUAL) reduce 501) ((T_LOGICAL_AND) reduce 501) ((T_LOGICAL_OR) reduce 501) ((T_LOGICAL_XOR) reduce 501) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 501) ((T_OBJECT_OPERATOR) reduce 501) ((T_POW) reduce 501) ((T_SL) reduce 501) ((T_SPACESHIP) reduce 501) ((T_SR) reduce 501) (("[") reduce 501) (("^") reduce 501) (("{") reduce 501) (("|") reduce 501) (("}") reduce 501)) 4803 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) ((",") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 91) ((T_OBJECT_OPERATOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("[") reduce 91) (("^") reduce 91) (("{") reduce 91) (("|") reduce 91) (("}") reduce 91)) 4806 ((("%") reduce 498) (("*") reduce 498) (("+") reduce 498) ((",") reduce 498) (("-") reduce 498) ((".") reduce 498) (("/") reduce 498) (("<") reduce 498) ((">") reduce 498) (("?") reduce 498) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_BOOLEAN_AND) reduce 498) ((T_BOOLEAN_OR) reduce 498) ((T_COALESCE) reduce 498) ((T_DOUBLE_ARROW) reduce 498) ((T_INSTANCEOF) reduce 498) ((T_IS_EQUAL) reduce 498) ((T_IS_GREATER_OR_EQUAL) reduce 498) ((T_IS_IDENTICAL) reduce 498) ((T_IS_NOT_EQUAL) reduce 498) ((T_IS_NOT_IDENTICAL) reduce 498) ((T_IS_SMALLER_OR_EQUAL) reduce 498) ((T_LOGICAL_AND) reduce 498) ((T_LOGICAL_OR) reduce 498) ((T_LOGICAL_XOR) reduce 498) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 498) ((T_OBJECT_OPERATOR) reduce 498) ((T_POW) reduce 498) ((T_SL) reduce 498) ((T_SPACESHIP) reduce 498) ((T_SR) reduce 498) (("[") reduce 498) (("^") reduce 498) (("{") reduce 498) (("|") reduce 498) (("}") reduce 498)) 4808 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) ((",") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) (("=") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AND_EQUAL) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_COALESCE_EQUAL) reduce 529) ((T_CONCAT_EQUAL) reduce 529) ((T_DEC) reduce 529) ((T_DIV_EQUAL) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INC) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_MINUS_EQUAL) reduce 529) ((T_MOD_EQUAL) reduce 529) ((T_MUL_EQUAL) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_OR_EQUAL) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_PLUS_EQUAL) reduce 529) ((T_POW) reduce 529) ((T_POW_EQUAL) reduce 529) ((T_SL) reduce 529) ((T_SL_EQUAL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) ((T_SR_EQUAL) reduce 529) ((T_XOR_EQUAL) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529) (("}") reduce 529)) 4809 ((("!") shift) (("\"") shift) (("$") shift) (("%") reduce 440) (("(") shift) (("*") reduce 440) (("+") shift) ((",") reduce 440) (("-") shift) ((".") reduce 440) (("/") reduce 440) (("<") reduce 440) ((">") reduce 440) (("?") reduce 440) (("@") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOLEAN_AND) reduce 440) ((T_BOOLEAN_OR) reduce 440) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_COALESCE) reduce 440) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_ARROW) reduce 440) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INSTANCEOF) reduce 440) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_IS_EQUAL) reduce 440) ((T_IS_GREATER_OR_EQUAL) reduce 440) ((T_IS_IDENTICAL) reduce 440) ((T_IS_NOT_EQUAL) reduce 440) ((T_IS_NOT_IDENTICAL) reduce 440) ((T_IS_SMALLER_OR_EQUAL) reduce 440) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_LOGICAL_AND) reduce 440) ((T_LOGICAL_OR) reduce 440) ((T_LOGICAL_XOR) reduce 440) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_POW) reduce 440) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_SL) reduce 440) ((T_SPACESHIP) reduce 440) ((T_SR) reduce 440) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("^") reduce 440) (("`") shift) (("|") reduce 440) (("}") reduce 440) (("~") shift)) 4816 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) ((",") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) (("<") reduce 525) (("=") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AND_EQUAL) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_COALESCE_EQUAL) reduce 525) ((T_CONCAT_EQUAL) reduce 525) ((T_DEC) reduce 525) ((T_DIV_EQUAL) reduce 525) ((T_DOUBLE_ARROW) reduce 525) ((T_INC) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_MINUS_EQUAL) reduce 525) ((T_MOD_EQUAL) reduce 525) ((T_MUL_EQUAL) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_OR_EQUAL) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_PLUS_EQUAL) reduce 525) ((T_POW) reduce 525) ((T_POW_EQUAL) reduce 525) ((T_SL) reduce 525) ((T_SL_EQUAL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) ((T_SR_EQUAL) reduce 525) ((T_XOR_EQUAL) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525) (("}") reduce 525)) 4817 ((("%") reduce 493) (("*") reduce 493) (("+") reduce 493) ((",") reduce 493) (("-") reduce 493) ((".") reduce 493) (("/") reduce 493) (("<") reduce 493) ((">") reduce 493) (("?") reduce 493) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_BOOLEAN_AND) reduce 493) ((T_BOOLEAN_OR) reduce 493) ((T_COALESCE) reduce 493) ((T_DOUBLE_ARROW) reduce 493) ((T_INSTANCEOF) reduce 493) ((T_IS_EQUAL) reduce 493) ((T_IS_GREATER_OR_EQUAL) reduce 493) ((T_IS_IDENTICAL) reduce 493) ((T_IS_NOT_EQUAL) reduce 493) ((T_IS_NOT_IDENTICAL) reduce 493) ((T_IS_SMALLER_OR_EQUAL) reduce 493) ((T_LOGICAL_AND) reduce 493) ((T_LOGICAL_OR) reduce 493) ((T_LOGICAL_XOR) reduce 493) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 513) ((T_OBJECT_OPERATOR) reduce 513) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 513) ((T_POW) reduce 493) ((T_SL) reduce 493) ((T_SPACESHIP) reduce 493) ((T_SR) reduce 493) (("[") reduce 513) (("^") reduce 493) (("{") reduce 513) (("|") reduce 493) (("}") reduce 493)) 4819 ((("%") reduce 492) (("*") reduce 492) (("+") reduce 492) ((",") reduce 492) (("-") reduce 492) ((".") reduce 492) (("/") reduce 492) (("<") reduce 492) ((">") reduce 492) (("?") reduce 492) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_BOOLEAN_AND) reduce 492) ((T_BOOLEAN_OR) reduce 492) ((T_COALESCE) reduce 492) ((T_DOUBLE_ARROW) reduce 492) ((T_INSTANCEOF) reduce 492) ((T_IS_EQUAL) reduce 492) ((T_IS_GREATER_OR_EQUAL) reduce 492) ((T_IS_IDENTICAL) reduce 492) ((T_IS_NOT_EQUAL) reduce 492) ((T_IS_NOT_IDENTICAL) reduce 492) ((T_IS_SMALLER_OR_EQUAL) reduce 492) ((T_LOGICAL_AND) reduce 492) ((T_LOGICAL_OR) reduce 492) ((T_LOGICAL_XOR) reduce 492) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 515) ((T_OBJECT_OPERATOR) reduce 515) ((T_POW) reduce 492) ((T_SL) reduce 492) ((T_SPACESHIP) reduce 492) ((T_SR) reduce 492) (("[") reduce 515) (("^") reduce 492) (("{") reduce 515) (("|") reduce 492) (("}") reduce 492)) 4820 ((("%") reduce 491) (("(") reduce 518) (("*") reduce 491) (("+") reduce 491) ((",") reduce 491) (("-") reduce 491) ((".") reduce 491) (("/") reduce 491) (("<") reduce 491) ((">") reduce 491) (("?") reduce 491) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_BOOLEAN_AND) reduce 491) ((T_BOOLEAN_OR) reduce 491) ((T_COALESCE) reduce 491) ((T_DOUBLE_ARROW) reduce 491) ((T_INSTANCEOF) reduce 491) ((T_IS_EQUAL) reduce 491) ((T_IS_GREATER_OR_EQUAL) reduce 491) ((T_IS_IDENTICAL) reduce 491) ((T_IS_NOT_EQUAL) reduce 491) ((T_IS_NOT_IDENTICAL) reduce 491) ((T_IS_SMALLER_OR_EQUAL) reduce 491) ((T_LOGICAL_AND) reduce 491) ((T_LOGICAL_OR) reduce 491) ((T_LOGICAL_XOR) reduce 491) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 512) ((T_OBJECT_OPERATOR) reduce 512) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 512) ((T_POW) reduce 491) ((T_SL) reduce 491) ((T_SPACESHIP) reduce 491) ((T_SR) reduce 491) (("[") reduce 512) (("^") reduce 491) (("{") reduce 512) (("|") reduce 491) (("}") reduce 491)) 4821 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 441) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 441) ((T_LOGICAL_OR) reduce 441) ((T_LOGICAL_XOR) reduce 441) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 441)) 4824 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) ((",") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) (("<") reduce 524) (("=") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AND_EQUAL) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_COALESCE_EQUAL) reduce 524) ((T_CONCAT_EQUAL) reduce 524) ((T_DEC) reduce 524) ((T_DIV_EQUAL) reduce 524) ((T_DOUBLE_ARROW) reduce 524) ((T_INC) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_MINUS_EQUAL) reduce 524) ((T_MOD_EQUAL) reduce 524) ((T_MUL_EQUAL) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_OR_EQUAL) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_PLUS_EQUAL) reduce 524) ((T_POW) reduce 524) ((T_POW_EQUAL) reduce 524) ((T_SL) reduce 524) ((T_SL_EQUAL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) ((T_SR_EQUAL) reduce 524) ((T_XOR_EQUAL) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524) (("}") reduce 524)) 4825 ((("%") reduce 445) (("*") reduce 445) (("+") reduce 445) ((",") reduce 445) (("-") reduce 445) ((".") reduce 445) (("/") reduce 445) (("<") reduce 445) ((">") reduce 445) (("?") reduce 445) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_BOOLEAN_AND) reduce 445) ((T_BOOLEAN_OR) reduce 445) ((T_COALESCE) reduce 445) ((T_DOUBLE_ARROW) reduce 445) ((T_INSTANCEOF) reduce 445) ((T_IS_EQUAL) reduce 445) ((T_IS_GREATER_OR_EQUAL) reduce 445) ((T_IS_IDENTICAL) reduce 445) ((T_IS_NOT_EQUAL) reduce 445) ((T_IS_NOT_IDENTICAL) reduce 445) ((T_IS_SMALLER_OR_EQUAL) reduce 445) ((T_LOGICAL_AND) reduce 445) ((T_LOGICAL_OR) reduce 445) ((T_LOGICAL_XOR) reduce 445) ((T_POW) reduce 445) ((T_SL) reduce 445) ((T_SPACESHIP) reduce 445) ((T_SR) reduce 445) (("^") reduce 445) (("|") reduce 445) (("}") reduce 445)) 4826 ((("%") reduce 427) (("*") reduce 427) (("+") reduce 427) ((",") reduce 427) (("-") reduce 427) ((".") reduce 427) (("/") reduce 427) (("<") reduce 427) ((">") reduce 427) (("?") reduce 427) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_BOOLEAN_AND) reduce 427) ((T_BOOLEAN_OR) reduce 427) ((T_COALESCE) reduce 427) ((T_DOUBLE_ARROW) reduce 427) ((T_INSTANCEOF) reduce 427) ((T_IS_EQUAL) reduce 427) ((T_IS_GREATER_OR_EQUAL) reduce 427) ((T_IS_IDENTICAL) reduce 427) ((T_IS_NOT_EQUAL) reduce 427) ((T_IS_NOT_IDENTICAL) reduce 427) ((T_IS_SMALLER_OR_EQUAL) reduce 427) ((T_LOGICAL_AND) reduce 427) ((T_LOGICAL_OR) reduce 427) ((T_LOGICAL_XOR) reduce 427) ((T_POW) reduce 427) ((T_SL) reduce 427) ((T_SPACESHIP) reduce 427) ((T_SR) reduce 427) (("^") reduce 427) (("|") reduce 427) (("}") reduce 427)) 4827 ((("%") reduce 449) (("*") reduce 449) (("+") reduce 449) ((",") reduce 449) (("-") reduce 449) ((".") reduce 449) (("/") reduce 449) (("<") reduce 449) ((">") reduce 449) (("?") reduce 449) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_BOOLEAN_AND) reduce 449) ((T_BOOLEAN_OR) reduce 449) ((T_COALESCE) reduce 449) ((T_DOUBLE_ARROW) reduce 449) ((T_INSTANCEOF) reduce 449) ((T_IS_EQUAL) reduce 449) ((T_IS_GREATER_OR_EQUAL) reduce 449) ((T_IS_IDENTICAL) reduce 449) ((T_IS_NOT_EQUAL) reduce 449) ((T_IS_NOT_IDENTICAL) reduce 449) ((T_IS_SMALLER_OR_EQUAL) reduce 449) ((T_LOGICAL_AND) reduce 449) ((T_LOGICAL_OR) reduce 449) ((T_LOGICAL_XOR) reduce 449) ((T_POW) reduce 449) ((T_SL) reduce 449) ((T_SPACESHIP) reduce 449) ((T_SR) reduce 449) (("^") reduce 449) (("|") reduce 449) (("}") reduce 449)) 4828 ((("%") reduce 494) (("(") shift) (("*") reduce 494) (("+") reduce 494) ((",") reduce 494) (("-") reduce 494) ((".") reduce 494) (("/") reduce 494) (("<") reduce 494) ((">") reduce 494) (("?") reduce 494) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_BOOLEAN_AND) reduce 494) ((T_BOOLEAN_OR) reduce 494) ((T_COALESCE) reduce 494) ((T_DOUBLE_ARROW) reduce 494) ((T_INSTANCEOF) reduce 494) ((T_IS_EQUAL) reduce 494) ((T_IS_GREATER_OR_EQUAL) reduce 494) ((T_IS_IDENTICAL) reduce 494) ((T_IS_NOT_EQUAL) reduce 494) ((T_IS_NOT_IDENTICAL) reduce 494) ((T_IS_SMALLER_OR_EQUAL) reduce 494) ((T_LOGICAL_AND) reduce 494) ((T_LOGICAL_OR) reduce 494) ((T_LOGICAL_XOR) reduce 494) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 494) ((T_OBJECT_OPERATOR) reduce 494) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 494) ((T_SL) reduce 494) ((T_SPACESHIP) reduce 494) ((T_SR) reduce 494) (("[") reduce 494) (("^") reduce 494) (("{") reduce 494) (("|") reduce 494) (("}") reduce 494)) 4829 ((("%") reduce 423) (("*") reduce 423) (("+") reduce 423) ((",") reduce 423) (("-") reduce 423) ((".") reduce 423) (("/") reduce 423) (("<") reduce 423) ((">") reduce 423) (("?") reduce 423) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_BOOLEAN_AND) reduce 423) ((T_BOOLEAN_OR) reduce 423) ((T_COALESCE) reduce 423) ((T_DOUBLE_ARROW) reduce 423) ((T_INSTANCEOF) reduce 423) ((T_IS_EQUAL) reduce 423) ((T_IS_GREATER_OR_EQUAL) reduce 423) ((T_IS_IDENTICAL) reduce 423) ((T_IS_NOT_EQUAL) reduce 423) ((T_IS_NOT_IDENTICAL) reduce 423) ((T_IS_SMALLER_OR_EQUAL) reduce 423) ((T_LOGICAL_AND) reduce 423) ((T_LOGICAL_OR) reduce 423) ((T_LOGICAL_XOR) reduce 423) ((T_POW) reduce 423) ((T_SL) reduce 423) ((T_SPACESHIP) reduce 423) ((T_SR) reduce 423) (("^") reduce 423) (("|") reduce 423) (("}") reduce 423)) 4830 ((("%") reduce 437) (("*") reduce 437) (("+") reduce 437) ((",") reduce 437) (("-") reduce 437) ((".") reduce 437) (("/") reduce 437) (("<") reduce 437) ((">") reduce 437) (("?") reduce 437) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_BOOLEAN_AND) reduce 437) ((T_BOOLEAN_OR) reduce 437) ((T_COALESCE) reduce 437) ((T_DOUBLE_ARROW) reduce 437) ((T_INSTANCEOF) reduce 437) ((T_IS_EQUAL) reduce 437) ((T_IS_GREATER_OR_EQUAL) reduce 437) ((T_IS_IDENTICAL) reduce 437) ((T_IS_NOT_EQUAL) reduce 437) ((T_IS_NOT_IDENTICAL) reduce 437) ((T_IS_SMALLER_OR_EQUAL) reduce 437) ((T_LOGICAL_AND) reduce 437) ((T_LOGICAL_OR) reduce 437) ((T_LOGICAL_XOR) reduce 437) ((T_POW) reduce 437) ((T_SL) reduce 437) ((T_SPACESHIP) reduce 437) ((T_SR) reduce 437) (("^") reduce 437) (("|") reduce 437) (("}") reduce 437)) 4831 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) ((",") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) (("<") reduce 519) (("=") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AND_EQUAL) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_COALESCE_EQUAL) reduce 519) ((T_CONCAT_EQUAL) reduce 519) ((T_DEC) reduce 519) ((T_DIV_EQUAL) reduce 519) ((T_DOUBLE_ARROW) reduce 519) ((T_INC) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_MINUS_EQUAL) reduce 519) ((T_MOD_EQUAL) reduce 519) ((T_MUL_EQUAL) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_OR_EQUAL) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_PLUS_EQUAL) reduce 519) ((T_POW) reduce 519) ((T_POW_EQUAL) reduce 519) ((T_SL) reduce 519) ((T_SL_EQUAL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) ((T_SR_EQUAL) reduce 519) ((T_XOR_EQUAL) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519) (("}") reduce 519)) 4832 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) ((",") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) (("<") reduce 526) (("=") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AND_EQUAL) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_COALESCE_EQUAL) reduce 526) ((T_CONCAT_EQUAL) reduce 526) ((T_DEC) reduce 526) ((T_DIV_EQUAL) reduce 526) ((T_DOUBLE_ARROW) reduce 526) ((T_INC) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_MINUS_EQUAL) reduce 526) ((T_MOD_EQUAL) reduce 526) ((T_MUL_EQUAL) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_OR_EQUAL) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_PLUS_EQUAL) reduce 526) ((T_POW) reduce 526) ((T_POW_EQUAL) reduce 526) ((T_SL) reduce 526) ((T_SL_EQUAL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) ((T_SR_EQUAL) reduce 526) ((T_XOR_EQUAL) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526) (("}") reduce 526)) 4833 ((("%") reduce 367) (("*") reduce 367) (("+") reduce 367) ((",") reduce 367) (("-") reduce 367) ((".") reduce 367) (("/") reduce 367) (("<") reduce 367) (("=") shift) ((">") reduce 367) (("?") reduce 367) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AND_EQUAL) shift) ((T_BOOLEAN_AND) reduce 367) ((T_BOOLEAN_OR) reduce 367) ((T_COALESCE) reduce 367) ((T_COALESCE_EQUAL) shift) ((T_CONCAT_EQUAL) shift) ((T_DEC) shift) ((T_DIV_EQUAL) shift) ((T_DOUBLE_ARROW) reduce 367) ((T_INC) shift) ((T_INSTANCEOF) reduce 367) ((T_IS_EQUAL) reduce 367) ((T_IS_GREATER_OR_EQUAL) reduce 367) ((T_IS_IDENTICAL) reduce 367) ((T_IS_NOT_EQUAL) reduce 367) ((T_IS_NOT_IDENTICAL) reduce 367) ((T_IS_SMALLER_OR_EQUAL) reduce 367) ((T_LOGICAL_AND) reduce 367) ((T_LOGICAL_OR) reduce 367) ((T_LOGICAL_XOR) reduce 367) ((T_MINUS_EQUAL) shift) ((T_MOD_EQUAL) shift) ((T_MUL_EQUAL) shift) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_OR_EQUAL) shift) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_PLUS_EQUAL) shift) ((T_POW) reduce 367) ((T_POW_EQUAL) shift) ((T_SL) reduce 367) ((T_SL_EQUAL) shift) ((T_SPACESHIP) reduce 367) ((T_SR) reduce 367) ((T_SR_EQUAL) shift) ((T_XOR_EQUAL) shift) (("[") reduce 510) (("^") reduce 367) (("{") reduce 510) (("|") reduce 367) (("}") reduce 367)) 4836 ((("%") reduce 411) (("*") reduce 411) (("+") reduce 411) ((",") reduce 411) (("-") reduce 411) ((".") reduce 411) (("/") reduce 411) (("<") reduce 411) ((">") reduce 411) (("?") reduce 411) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_BOOLEAN_AND) reduce 411) ((T_BOOLEAN_OR) reduce 411) ((T_COALESCE) reduce 411) ((T_DOUBLE_ARROW) reduce 411) ((T_INSTANCEOF) reduce 411) ((T_IS_EQUAL) reduce 411) ((T_IS_GREATER_OR_EQUAL) reduce 411) ((T_IS_IDENTICAL) reduce 411) ((T_IS_NOT_EQUAL) reduce 411) ((T_IS_NOT_IDENTICAL) reduce 411) ((T_IS_SMALLER_OR_EQUAL) reduce 411) ((T_LOGICAL_AND) reduce 411) ((T_LOGICAL_OR) reduce 411) ((T_LOGICAL_XOR) reduce 411) ((T_POW) shift) ((T_SL) reduce 411) ((T_SPACESHIP) reduce 411) ((T_SR) reduce 411) (("^") reduce 411) (("|") reduce 411) (("}") reduce 411)) 4867 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 395) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 395) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 395) ((T_BOOLEAN_OR) reduce 395) ((T_COALESCE) reduce 395) ((T_DOUBLE_ARROW) reduce 395) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 395) ((T_LOGICAL_OR) reduce 395) ((T_LOGICAL_XOR) reduce 395) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") reduce 395) (("}") reduce 395)) 4868 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 398) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 398) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 398) ((T_BOOLEAN_OR) reduce 398) ((T_COALESCE) reduce 398) ((T_DOUBLE_ARROW) reduce 398) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 398) ((T_LOGICAL_OR) reduce 398) ((T_LOGICAL_XOR) reduce 398) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 398) (("|") reduce 398) (("}") reduce 398)) 4869 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 407) (("-") shift) ((".") reduce 407) (("/") shift) (("<") reduce 407) ((">") reduce 407) (("?") reduce 407) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_BOOLEAN_AND) reduce 407) ((T_BOOLEAN_OR) reduce 407) ((T_COALESCE) reduce 407) ((T_DOUBLE_ARROW) reduce 407) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 407) ((T_IS_GREATER_OR_EQUAL) reduce 407) ((T_IS_IDENTICAL) reduce 407) ((T_IS_NOT_EQUAL) reduce 407) ((T_IS_NOT_IDENTICAL) reduce 407) ((T_IS_SMALLER_OR_EQUAL) reduce 407) ((T_LOGICAL_AND) reduce 407) ((T_LOGICAL_OR) reduce 407) ((T_LOGICAL_XOR) reduce 407) ((T_POW) shift) ((T_SL) reduce 407) ((T_SPACESHIP) reduce 407) ((T_SR) reduce 407) (("^") reduce 407) (("|") reduce 407) (("}") reduce 407)) 4870 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 420) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 420) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_BOOLEAN_AND) reduce 420) ((T_BOOLEAN_OR) reduce 420) ((T_COALESCE) reduce 420) ((T_DOUBLE_ARROW) reduce 420) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 420) ((T_LOGICAL_OR) reduce 420) ((T_LOGICAL_XOR) reduce 420) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 420) (("|") reduce 420) (("}") reduce 420)) 4871 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 406) (("-") shift) ((".") reduce 406) (("/") shift) (("<") reduce 406) ((">") reduce 406) (("?") reduce 406) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_BOOLEAN_AND) reduce 406) ((T_BOOLEAN_OR) reduce 406) ((T_COALESCE) reduce 406) ((T_DOUBLE_ARROW) reduce 406) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 406) ((T_IS_GREATER_OR_EQUAL) reduce 406) ((T_IS_IDENTICAL) reduce 406) ((T_IS_NOT_EQUAL) reduce 406) ((T_IS_NOT_IDENTICAL) reduce 406) ((T_IS_SMALLER_OR_EQUAL) reduce 406) ((T_LOGICAL_AND) reduce 406) ((T_LOGICAL_OR) reduce 406) ((T_LOGICAL_XOR) reduce 406) ((T_POW) shift) ((T_SL) reduce 406) ((T_SPACESHIP) reduce 406) ((T_SR) reduce 406) (("^") reduce 406) (("|") reduce 406) (("}") reduce 406)) 4872 ((("%") reduce 403) (("*") reduce 403) (("+") reduce 403) ((",") reduce 403) (("-") reduce 403) ((".") reduce 403) (("/") reduce 403) (("<") reduce 403) ((">") reduce 403) (("?") reduce 403) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_BOOLEAN_AND) reduce 403) ((T_BOOLEAN_OR) reduce 403) ((T_COALESCE) reduce 403) ((T_DOUBLE_ARROW) reduce 403) ((T_INSTANCEOF) reduce 403) ((T_IS_EQUAL) reduce 403) ((T_IS_GREATER_OR_EQUAL) reduce 403) ((T_IS_IDENTICAL) reduce 403) ((T_IS_NOT_EQUAL) reduce 403) ((T_IS_NOT_IDENTICAL) reduce 403) ((T_IS_SMALLER_OR_EQUAL) reduce 403) ((T_LOGICAL_AND) reduce 403) ((T_LOGICAL_OR) reduce 403) ((T_LOGICAL_XOR) reduce 403) ((T_POW) shift) ((T_SL) reduce 403) ((T_SPACESHIP) reduce 403) ((T_SR) reduce 403) (("^") reduce 403) (("|") reduce 403) (("}") reduce 403)) 4873 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 394) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 394) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 394) ((T_LOGICAL_XOR) reduce 394) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 394)) 4874 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 392) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 392) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 392) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 392)) 4875 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 393) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 393) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 393) ((T_LOGICAL_OR) reduce 393) ((T_LOGICAL_XOR) reduce 393) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 393)) 4876 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 417) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 417) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_BOOLEAN_AND) reduce 417) ((T_BOOLEAN_OR) reduce 417) ((T_COALESCE) reduce 417) ((T_DOUBLE_ARROW) reduce 417) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 417) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 417) ((T_IS_NOT_EQUAL) reduce 417) ((T_IS_NOT_IDENTICAL) reduce 417) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 417) ((T_LOGICAL_OR) reduce 417) ((T_LOGICAL_XOR) reduce 417) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 417) ((T_SR) shift) (("^") reduce 417) (("|") reduce 417) (("}") reduce 417)) 4877 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 413) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 413) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_BOOLEAN_AND) reduce 413) ((T_BOOLEAN_OR) reduce 413) ((T_COALESCE) reduce 413) ((T_DOUBLE_ARROW) reduce 413) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 413) ((T_LOGICAL_OR) reduce 413) ((T_LOGICAL_XOR) reduce 413) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 413) (("|") reduce 413) (("}") reduce 413)) 4878 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 415) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 415) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_BOOLEAN_AND) reduce 415) ((T_BOOLEAN_OR) reduce 415) ((T_COALESCE) reduce 415) ((T_DOUBLE_ARROW) reduce 415) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 415) ((T_LOGICAL_OR) reduce 415) ((T_LOGICAL_XOR) reduce 415) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 415) (("|") reduce 415) (("}") reduce 415)) 4879 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 412) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 412) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_BOOLEAN_AND) reduce 412) ((T_BOOLEAN_OR) reduce 412) ((T_COALESCE) reduce 412) ((T_DOUBLE_ARROW) reduce 412) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 412) ((T_LOGICAL_OR) reduce 412) ((T_LOGICAL_XOR) reduce 412) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 412) (("|") reduce 412) (("}") reduce 412)) 4880 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 419) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 419) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_BOOLEAN_AND) reduce 419) ((T_BOOLEAN_OR) reduce 419) ((T_COALESCE) reduce 419) ((T_DOUBLE_ARROW) reduce 419) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 419) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 419) ((T_IS_NOT_EQUAL) reduce 419) ((T_IS_NOT_IDENTICAL) reduce 419) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 419) ((T_LOGICAL_OR) reduce 419) ((T_LOGICAL_XOR) reduce 419) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 419) ((T_SR) shift) (("^") reduce 419) (("|") reduce 419) (("}") reduce 419)) 4881 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 414) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 414) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_BOOLEAN_AND) reduce 414) ((T_BOOLEAN_OR) reduce 414) ((T_COALESCE) reduce 414) ((T_DOUBLE_ARROW) reduce 414) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 414) ((T_LOGICAL_OR) reduce 414) ((T_LOGICAL_XOR) reduce 414) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 414) (("|") reduce 414) (("}") reduce 414)) 4884 ((("%") reduce 93) (("*") reduce 93) (("+") reduce 93) ((",") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93) (("}") reduce 93)) 4885 ((("%") reduce 92) (("*") reduce 92) (("+") reduce 92) ((",") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92) (("}") reduce 92)) 4886 ((("%") reduce 94) (("*") reduce 94) (("+") reduce 94) ((",") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94) (("}") reduce 94)) 4887 ((("%") reduce 470) (("*") reduce 470) (("+") reduce 470) ((",") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_DOUBLE_ARROW) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470) (("}") reduce 470)) 4888 ((("%") reduce 91) (("*") reduce 91) (("+") reduce 91) ((",") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91) (("}") reduce 91)) 4889 ((("%") reduce 529) (("*") reduce 529) (("+") reduce 529) ((",") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529) (("}") reduce 529)) 4890 ((("%") reduce 472) (("*") reduce 472) (("+") reduce 472) ((",") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_DOUBLE_ARROW) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472) (("}") reduce 472)) 4891 ((("%") reduce 421) (("*") reduce 421) (("+") reduce 421) ((",") reduce 421) (("-") reduce 421) ((".") reduce 421) (("/") reduce 421) (("<") reduce 421) ((">") reduce 421) (("?") reduce 421) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_BOOLEAN_AND) reduce 421) ((T_BOOLEAN_OR) reduce 421) ((T_COALESCE) reduce 421) ((T_DOUBLE_ARROW) reduce 421) ((T_INSTANCEOF) reduce 421) ((T_IS_EQUAL) reduce 421) ((T_IS_GREATER_OR_EQUAL) reduce 421) ((T_IS_IDENTICAL) reduce 421) ((T_IS_NOT_EQUAL) reduce 421) ((T_IS_NOT_IDENTICAL) reduce 421) ((T_IS_SMALLER_OR_EQUAL) reduce 421) ((T_LOGICAL_AND) reduce 421) ((T_LOGICAL_OR) reduce 421) ((T_LOGICAL_XOR) reduce 421) ((T_POW) reduce 421) ((T_SL) reduce 421) ((T_SPACESHIP) reduce 421) ((T_SR) reduce 421) (("^") reduce 421) (("|") reduce 421) (("}") reduce 421)) 4892 ((("%") reduce 471) (("*") reduce 471) (("+") reduce 471) ((",") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_DOUBLE_ARROW) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471) (("}") reduce 471)) 4893 ((("%") reduce 473) (("*") reduce 473) (("+") reduce 473) ((",") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_DOUBLE_ARROW) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473) (("}") reduce 473)) 4894 ((("%") reduce 534) (("*") reduce 534) (("+") reduce 534) ((",") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_DOUBLE_ARROW) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534) (("}") reduce 534)) 4901 ((("%") reduce 536) (("*") reduce 536) (("+") reduce 536) ((",") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_DOUBLE_ARROW) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536) (("}") reduce 536)) 4903 ((("%") reduce 535) (("*") reduce 535) (("+") reduce 535) ((",") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_DOUBLE_ARROW) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535) (("}") reduce 535)) 4904 ((("%") reduce 540) (("*") reduce 540) (("+") reduce 540) ((",") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_DOUBLE_ARROW) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540) (("}") reduce 540)) 4905 ((("%") reduce 544) (("*") reduce 544) (("+") reduce 544) ((",") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544) (("}") reduce 544)) 4906 ((("%") reduce 537) (("*") reduce 537) (("+") reduce 537) ((",") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_DOUBLE_ARROW) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537) (("}") reduce 537)) 4907 ((("%") reduce 546) (("*") reduce 546) (("+") reduce 546) ((",") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546) (("}") reduce 546)) 4910 ((("%") reduce 545) (("*") reduce 545) (("+") reduce 545) ((",") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545) (("}") reduce 545)) 4911 ((("%") reduce 538) (("*") reduce 538) (("+") reduce 538) ((",") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_DOUBLE_ARROW) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538) (("}") reduce 538)) 4913 ((("%") reduce 539) (("*") reduce 539) (("+") reduce 539) ((",") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_DOUBLE_ARROW) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539) (("}") reduce 539)) 4915 ((("%") reduce 474) (("*") reduce 474) (("+") reduce 474) ((",") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_DOUBLE_ARROW) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474) (("}") reduce 474)) 4916 ((("%") reduce 531) (("*") reduce 531) (("+") reduce 531) ((",") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531) (("}") reduce 531)) 4919 ((("%") reduce 530) (("*") reduce 530) (("+") reduce 530) ((",") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530) (("}") reduce 530)) 4920 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 426) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 426) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 426) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 426) ((T_LOGICAL_OR) reduce 426) ((T_LOGICAL_XOR) reduce 426) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 426)) 4921 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 390) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 390) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) reduce 390) ((T_COALESCE) reduce 390) ((T_DOUBLE_ARROW) reduce 390) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 390) ((T_LOGICAL_OR) reduce 390) ((T_LOGICAL_XOR) reduce 390) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 390)) 4922 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 391) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 391) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 391) ((T_BOOLEAN_OR) reduce 391) ((T_COALESCE) reduce 391) ((T_DOUBLE_ARROW) reduce 391) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 391) ((T_LOGICAL_OR) reduce 391) ((T_LOGICAL_XOR) reduce 391) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 391)) 4923 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 396) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 396) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_BOOLEAN_AND) reduce 396) ((T_BOOLEAN_OR) reduce 396) ((T_COALESCE) reduce 396) ((T_DOUBLE_ARROW) reduce 396) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 396) ((T_LOGICAL_OR) reduce 396) ((T_LOGICAL_XOR) reduce 396) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 396) (("|") reduce 396) (("}") reduce 396)) 4924 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 397) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 397) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_BOOLEAN_AND) reduce 397) ((T_BOOLEAN_OR) reduce 397) ((T_COALESCE) reduce 397) ((T_DOUBLE_ARROW) reduce 397) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 397) ((T_LOGICAL_OR) reduce 397) ((T_LOGICAL_XOR) reduce 397) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 397) (("|") reduce 397) (("}") reduce 397)) 4928 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 424) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 424) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 424) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 424) ((T_LOGICAL_OR) reduce 424) ((T_LOGICAL_XOR) reduce 424) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 424)) 4929 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 425) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 425) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 425) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 425) ((T_LOGICAL_OR) reduce 425) ((T_LOGICAL_XOR) reduce 425) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 425)) 4930 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 418) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 418) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_BOOLEAN_AND) reduce 418) ((T_BOOLEAN_OR) reduce 418) ((T_COALESCE) reduce 418) ((T_DOUBLE_ARROW) reduce 418) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 418) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 418) ((T_IS_NOT_EQUAL) reduce 418) ((T_IS_NOT_IDENTICAL) reduce 418) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 418) ((T_LOGICAL_OR) reduce 418) ((T_LOGICAL_XOR) reduce 418) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 418) ((T_SR) shift) (("^") reduce 418) (("|") reduce 418) (("}") reduce 418)) 4931 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 416) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 416) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_BOOLEAN_AND) reduce 416) ((T_BOOLEAN_OR) reduce 416) ((T_COALESCE) reduce 416) ((T_DOUBLE_ARROW) reduce 416) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 416) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 416) ((T_IS_NOT_EQUAL) reduce 416) ((T_IS_NOT_IDENTICAL) reduce 416) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 416) ((T_LOGICAL_OR) reduce 416) ((T_LOGICAL_XOR) reduce 416) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 416) ((T_SR) shift) (("^") reduce 416) (("|") reduce 416) (("}") reduce 416)) 4932 ((("%") reduce 404) (("*") reduce 404) (("+") reduce 404) ((",") reduce 404) (("-") reduce 404) ((".") reduce 404) (("/") reduce 404) (("<") reduce 404) ((">") reduce 404) (("?") reduce 404) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_BOOLEAN_AND) reduce 404) ((T_BOOLEAN_OR) reduce 404) ((T_COALESCE) reduce 404) ((T_DOUBLE_ARROW) reduce 404) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 404) ((T_IS_GREATER_OR_EQUAL) reduce 404) ((T_IS_IDENTICAL) reduce 404) ((T_IS_NOT_EQUAL) reduce 404) ((T_IS_NOT_IDENTICAL) reduce 404) ((T_IS_SMALLER_OR_EQUAL) reduce 404) ((T_LOGICAL_AND) reduce 404) ((T_LOGICAL_OR) reduce 404) ((T_LOGICAL_XOR) reduce 404) ((T_POW) shift) ((T_SL) reduce 404) ((T_SPACESHIP) reduce 404) ((T_SR) reduce 404) (("^") reduce 404) (("|") reduce 404) (("}") reduce 404)) 4933 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 399) (("-") shift) ((".") reduce 399) (("/") shift) (("<") reduce 399) ((">") reduce 399) (("?") reduce 399) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_BOOLEAN_AND) reduce 399) ((T_BOOLEAN_OR) reduce 399) ((T_COALESCE) reduce 399) ((T_DOUBLE_ARROW) reduce 399) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 399) ((T_IS_GREATER_OR_EQUAL) reduce 399) ((T_IS_IDENTICAL) reduce 399) ((T_IS_NOT_EQUAL) reduce 399) ((T_IS_NOT_IDENTICAL) reduce 399) ((T_IS_SMALLER_OR_EQUAL) reduce 399) ((T_LOGICAL_AND) reduce 399) ((T_LOGICAL_OR) reduce 399) ((T_LOGICAL_XOR) reduce 399) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 399) ((T_SR) shift) (("^") reduce 399) (("|") reduce 399) (("}") reduce 399)) 4934 ((("%") shift) (("*") shift) (("+") reduce 401) ((",") reduce 401) (("-") reduce 401) ((".") reduce 401) (("/") shift) (("<") reduce 401) ((">") reduce 401) (("?") reduce 401) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_BOOLEAN_AND) reduce 401) ((T_BOOLEAN_OR) reduce 401) ((T_COALESCE) reduce 401) ((T_DOUBLE_ARROW) reduce 401) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 401) ((T_IS_GREATER_OR_EQUAL) reduce 401) ((T_IS_IDENTICAL) reduce 401) ((T_IS_NOT_EQUAL) reduce 401) ((T_IS_NOT_IDENTICAL) reduce 401) ((T_IS_SMALLER_OR_EQUAL) reduce 401) ((T_LOGICAL_AND) reduce 401) ((T_LOGICAL_OR) reduce 401) ((T_LOGICAL_XOR) reduce 401) ((T_POW) shift) ((T_SL) reduce 401) ((T_SPACESHIP) reduce 401) ((T_SR) reduce 401) (("^") reduce 401) (("|") reduce 401) (("}") reduce 401)) 4935 ((("%") shift) (("*") shift) (("+") reduce 400) ((",") reduce 400) (("-") reduce 400) ((".") reduce 400) (("/") shift) (("<") reduce 400) ((">") reduce 400) (("?") reduce 400) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_BOOLEAN_AND) reduce 400) ((T_BOOLEAN_OR) reduce 400) ((T_COALESCE) reduce 400) ((T_DOUBLE_ARROW) reduce 400) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 400) ((T_IS_GREATER_OR_EQUAL) reduce 400) ((T_IS_IDENTICAL) reduce 400) ((T_IS_NOT_EQUAL) reduce 400) ((T_IS_NOT_IDENTICAL) reduce 400) ((T_IS_SMALLER_OR_EQUAL) reduce 400) ((T_LOGICAL_AND) reduce 400) ((T_LOGICAL_OR) reduce 400) ((T_LOGICAL_XOR) reduce 400) ((T_POW) shift) ((T_SL) reduce 400) ((T_SPACESHIP) reduce 400) ((T_SR) reduce 400) (("^") reduce 400) (("|") reduce 400) (("}") reduce 400)) 4936 ((("%") reduce 402) (("*") reduce 402) (("+") reduce 402) ((",") reduce 402) (("-") reduce 402) ((".") reduce 402) (("/") reduce 402) (("<") reduce 402) ((">") reduce 402) (("?") reduce 402) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_BOOLEAN_AND) reduce 402) ((T_BOOLEAN_OR) reduce 402) ((T_COALESCE) reduce 402) ((T_DOUBLE_ARROW) reduce 402) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 402) ((T_IS_GREATER_OR_EQUAL) reduce 402) ((T_IS_IDENTICAL) reduce 402) ((T_IS_NOT_EQUAL) reduce 402) ((T_IS_NOT_IDENTICAL) reduce 402) ((T_IS_SMALLER_OR_EQUAL) reduce 402) ((T_LOGICAL_AND) reduce 402) ((T_LOGICAL_OR) reduce 402) ((T_LOGICAL_XOR) reduce 402) ((T_POW) shift) ((T_SL) reduce 402) ((T_SPACESHIP) reduce 402) ((T_SR) reduce 402) (("^") reduce 402) (("|") reduce 402) (("}") reduce 402)) 4937 ((("%") reduce 405) (("*") reduce 405) (("+") reduce 405) ((",") reduce 405) (("-") reduce 405) ((".") reduce 405) (("/") reduce 405) (("<") reduce 405) ((">") reduce 405) (("?") reduce 405) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_BOOLEAN_AND) reduce 405) ((T_BOOLEAN_OR) reduce 405) ((T_COALESCE) reduce 405) ((T_DOUBLE_ARROW) reduce 405) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 405) ((T_IS_GREATER_OR_EQUAL) reduce 405) ((T_IS_IDENTICAL) reduce 405) ((T_IS_NOT_EQUAL) reduce 405) ((T_IS_NOT_IDENTICAL) reduce 405) ((T_IS_SMALLER_OR_EQUAL) reduce 405) ((T_LOGICAL_AND) reduce 405) ((T_LOGICAL_OR) reduce 405) ((T_LOGICAL_XOR) reduce 405) ((T_POW) shift) ((T_SL) reduce 405) ((T_SPACESHIP) reduce 405) ((T_SR) reduce 405) (("^") reduce 405) (("|") reduce 405) (("}") reduce 405)) 4939 ((("%") reduce 73) (("(") reduce 73) (("*") reduce 73) (("+") reduce 73) ((",") reduce 73) (("-") reduce 73) ((".") reduce 73) (("/") reduce 73) (("<") reduce 73) ((">") reduce 73) (("?") reduce 73) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_BOOLEAN_AND) reduce 73) ((T_BOOLEAN_OR) reduce 73) ((T_COALESCE) reduce 73) ((T_DOUBLE_ARROW) reduce 73) ((T_INSTANCEOF) reduce 73) ((T_IS_EQUAL) reduce 73) ((T_IS_GREATER_OR_EQUAL) reduce 73) ((T_IS_IDENTICAL) reduce 73) ((T_IS_NOT_EQUAL) reduce 73) ((T_IS_NOT_IDENTICAL) reduce 73) ((T_IS_SMALLER_OR_EQUAL) reduce 73) ((T_LOGICAL_AND) reduce 73) ((T_LOGICAL_OR) reduce 73) ((T_LOGICAL_XOR) reduce 73) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 73) ((T_OBJECT_OPERATOR) reduce 73) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 73) ((T_POW) reduce 73) ((T_SL) reduce 73) ((T_SPACESHIP) reduce 73) ((T_SR) reduce 73) (("[") reduce 73) (("^") reduce 73) (("{") reduce 73) (("|") reduce 73) (("}") reduce 73)) 4940 ((("%") reduce 52) (("(") reduce 52) (("*") reduce 52) (("+") reduce 52) ((",") reduce 52) (("-") reduce 52) ((".") reduce 52) (("/") reduce 52) (("<") reduce 52) ((">") reduce 52) (("?") reduce 52) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_BOOLEAN_AND) reduce 52) ((T_BOOLEAN_OR) reduce 52) ((T_COALESCE) reduce 52) ((T_DOUBLE_ARROW) reduce 52) ((T_INSTANCEOF) reduce 52) ((T_IS_EQUAL) reduce 52) ((T_IS_GREATER_OR_EQUAL) reduce 52) ((T_IS_IDENTICAL) reduce 52) ((T_IS_NOT_EQUAL) reduce 52) ((T_IS_NOT_IDENTICAL) reduce 52) ((T_IS_SMALLER_OR_EQUAL) reduce 52) ((T_LOGICAL_AND) reduce 52) ((T_LOGICAL_OR) reduce 52) ((T_LOGICAL_XOR) reduce 52) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 52) ((T_OBJECT_OPERATOR) reduce 52) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 52) ((T_POW) reduce 52) ((T_SL) reduce 52) ((T_SPACESHIP) reduce 52) ((T_SR) reduce 52) (("[") reduce 52) (("^") reduce 52) (("{") reduce 52) (("|") reduce 52) (("}") reduce 52)) 4941 ((("%") reduce 27) (("(") reduce 27) (("*") reduce 27) (("+") reduce 27) ((",") reduce 27) (("-") reduce 27) ((".") reduce 27) (("/") reduce 27) (("<") reduce 27) ((">") reduce 27) (("?") reduce 27) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_BOOLEAN_AND) reduce 27) ((T_BOOLEAN_OR) reduce 27) ((T_COALESCE) reduce 27) ((T_DOUBLE_ARROW) reduce 27) ((T_INSTANCEOF) reduce 27) ((T_IS_EQUAL) reduce 27) ((T_IS_GREATER_OR_EQUAL) reduce 27) ((T_IS_IDENTICAL) reduce 27) ((T_IS_NOT_EQUAL) reduce 27) ((T_IS_NOT_IDENTICAL) reduce 27) ((T_IS_SMALLER_OR_EQUAL) reduce 27) ((T_LOGICAL_AND) reduce 27) ((T_LOGICAL_OR) reduce 27) ((T_LOGICAL_XOR) reduce 27) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 27) ((T_OBJECT_OPERATOR) reduce 27) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 27) ((T_POW) reduce 27) ((T_SL) reduce 27) ((T_SPACESHIP) reduce 27) ((T_SR) reduce 27) (("[") reduce 27) (("^") reduce 27) (("{") reduce 27) (("|") reduce 27) (("}") reduce 27)) 4942 ((("%") reduce 51) (("(") reduce 51) (("*") reduce 51) (("+") reduce 51) ((",") reduce 51) (("-") reduce 51) ((".") reduce 51) (("/") reduce 51) (("<") reduce 51) ((">") reduce 51) (("?") reduce 51) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_BOOLEAN_AND) reduce 51) ((T_BOOLEAN_OR) reduce 51) ((T_COALESCE) reduce 51) ((T_DOUBLE_ARROW) reduce 51) ((T_INSTANCEOF) reduce 51) ((T_IS_EQUAL) reduce 51) ((T_IS_GREATER_OR_EQUAL) reduce 51) ((T_IS_IDENTICAL) reduce 51) ((T_IS_NOT_EQUAL) reduce 51) ((T_IS_NOT_IDENTICAL) reduce 51) ((T_IS_SMALLER_OR_EQUAL) reduce 51) ((T_LOGICAL_AND) reduce 51) ((T_LOGICAL_OR) reduce 51) ((T_LOGICAL_XOR) reduce 51) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 51) ((T_OBJECT_OPERATOR) reduce 51) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 51) ((T_POW) reduce 51) ((T_SL) reduce 51) ((T_SPACESHIP) reduce 51) ((T_SR) reduce 51) (("[") reduce 51) (("^") reduce 51) (("{") reduce 51) (("|") reduce 51) (("}") reduce 51)) 4943 ((("%") reduce 53) (("(") reduce 53) (("*") reduce 53) (("+") reduce 53) ((",") reduce 53) (("-") reduce 53) ((".") reduce 53) (("/") reduce 53) (("<") reduce 53) ((">") reduce 53) (("?") reduce 53) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_BOOLEAN_AND) reduce 53) ((T_BOOLEAN_OR) reduce 53) ((T_COALESCE) reduce 53) ((T_DOUBLE_ARROW) reduce 53) ((T_INSTANCEOF) reduce 53) ((T_IS_EQUAL) reduce 53) ((T_IS_GREATER_OR_EQUAL) reduce 53) ((T_IS_IDENTICAL) reduce 53) ((T_IS_NOT_EQUAL) reduce 53) ((T_IS_NOT_IDENTICAL) reduce 53) ((T_IS_SMALLER_OR_EQUAL) reduce 53) ((T_LOGICAL_AND) reduce 53) ((T_LOGICAL_OR) reduce 53) ((T_LOGICAL_XOR) reduce 53) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 53) ((T_OBJECT_OPERATOR) reduce 53) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 53) ((T_POW) reduce 53) ((T_SL) reduce 53) ((T_SPACESHIP) reduce 53) ((T_SR) reduce 53) (("[") reduce 53) (("^") reduce 53) (("{") reduce 53) (("|") reduce 53) (("}") reduce 53)) 4944 ((("%") reduce 49) (("(") reduce 49) (("*") reduce 49) (("+") reduce 49) ((",") reduce 49) (("-") reduce 49) ((".") reduce 49) (("/") reduce 49) (("<") reduce 49) ((">") reduce 49) (("?") reduce 49) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_BOOLEAN_AND) reduce 49) ((T_BOOLEAN_OR) reduce 49) ((T_COALESCE) reduce 49) ((T_DOUBLE_ARROW) reduce 49) ((T_INSTANCEOF) reduce 49) ((T_IS_EQUAL) reduce 49) ((T_IS_GREATER_OR_EQUAL) reduce 49) ((T_IS_IDENTICAL) reduce 49) ((T_IS_NOT_EQUAL) reduce 49) ((T_IS_NOT_IDENTICAL) reduce 49) ((T_IS_SMALLER_OR_EQUAL) reduce 49) ((T_LOGICAL_AND) reduce 49) ((T_LOGICAL_OR) reduce 49) ((T_LOGICAL_XOR) reduce 49) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 49) ((T_OBJECT_OPERATOR) reduce 49) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 49) ((T_POW) reduce 49) ((T_SL) reduce 49) ((T_SPACESHIP) reduce 49) ((T_SR) reduce 49) (("[") reduce 49) (("^") reduce 49) (("{") reduce 49) (("|") reduce 49) (("}") reduce 49)) 4945 ((("%") reduce 29) (("(") reduce 29) (("*") reduce 29) (("+") reduce 29) ((",") reduce 29) (("-") reduce 29) ((".") reduce 29) (("/") reduce 29) (("<") reduce 29) ((">") reduce 29) (("?") reduce 29) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_BOOLEAN_AND) reduce 29) ((T_BOOLEAN_OR) reduce 29) ((T_COALESCE) reduce 29) ((T_DOUBLE_ARROW) reduce 29) ((T_INSTANCEOF) reduce 29) ((T_IS_EQUAL) reduce 29) ((T_IS_GREATER_OR_EQUAL) reduce 29) ((T_IS_IDENTICAL) reduce 29) ((T_IS_NOT_EQUAL) reduce 29) ((T_IS_NOT_IDENTICAL) reduce 29) ((T_IS_SMALLER_OR_EQUAL) reduce 29) ((T_LOGICAL_AND) reduce 29) ((T_LOGICAL_OR) reduce 29) ((T_LOGICAL_XOR) reduce 29) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 29) ((T_OBJECT_OPERATOR) reduce 29) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 29) ((T_POW) reduce 29) ((T_SL) reduce 29) ((T_SPACESHIP) reduce 29) ((T_SR) reduce 29) (("[") reduce 29) (("^") reduce 29) (("{") reduce 29) (("|") reduce 29) (("}") reduce 29)) 4946 ((("%") reduce 59) (("(") reduce 59) (("*") reduce 59) (("+") reduce 59) ((",") reduce 59) (("-") reduce 59) ((".") reduce 59) (("/") reduce 59) (("<") reduce 59) ((">") reduce 59) (("?") reduce 59) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_BOOLEAN_AND) reduce 59) ((T_BOOLEAN_OR) reduce 59) ((T_COALESCE) reduce 59) ((T_DOUBLE_ARROW) reduce 59) ((T_INSTANCEOF) reduce 59) ((T_IS_EQUAL) reduce 59) ((T_IS_GREATER_OR_EQUAL) reduce 59) ((T_IS_IDENTICAL) reduce 59) ((T_IS_NOT_EQUAL) reduce 59) ((T_IS_NOT_IDENTICAL) reduce 59) ((T_IS_SMALLER_OR_EQUAL) reduce 59) ((T_LOGICAL_AND) reduce 59) ((T_LOGICAL_OR) reduce 59) ((T_LOGICAL_XOR) reduce 59) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 59) ((T_OBJECT_OPERATOR) reduce 59) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 59) ((T_POW) reduce 59) ((T_SL) reduce 59) ((T_SPACESHIP) reduce 59) ((T_SR) reduce 59) (("[") reduce 59) (("^") reduce 59) (("{") reduce 59) (("|") reduce 59) (("}") reduce 59)) 4947 ((("%") reduce 60) (("(") reduce 60) (("*") reduce 60) (("+") reduce 60) ((",") reduce 60) (("-") reduce 60) ((".") reduce 60) (("/") reduce 60) (("<") reduce 60) ((">") reduce 60) (("?") reduce 60) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_BOOLEAN_AND) reduce 60) ((T_BOOLEAN_OR) reduce 60) ((T_COALESCE) reduce 60) ((T_DOUBLE_ARROW) reduce 60) ((T_INSTANCEOF) reduce 60) ((T_IS_EQUAL) reduce 60) ((T_IS_GREATER_OR_EQUAL) reduce 60) ((T_IS_IDENTICAL) reduce 60) ((T_IS_NOT_EQUAL) reduce 60) ((T_IS_NOT_IDENTICAL) reduce 60) ((T_IS_SMALLER_OR_EQUAL) reduce 60) ((T_LOGICAL_AND) reduce 60) ((T_LOGICAL_OR) reduce 60) ((T_LOGICAL_XOR) reduce 60) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 60) ((T_OBJECT_OPERATOR) reduce 60) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 60) ((T_POW) reduce 60) ((T_SL) reduce 60) ((T_SPACESHIP) reduce 60) ((T_SR) reduce 60) (("[") reduce 60) (("^") reduce 60) (("{") reduce 60) (("|") reduce 60) (("}") reduce 60)) 4948 ((("%") reduce 11) (("(") reduce 11) (("*") reduce 11) (("+") reduce 11) ((",") reduce 11) (("-") reduce 11) ((".") reduce 11) (("/") reduce 11) (("<") reduce 11) ((">") reduce 11) (("?") reduce 11) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_BOOLEAN_AND) reduce 11) ((T_BOOLEAN_OR) reduce 11) ((T_COALESCE) reduce 11) ((T_DOUBLE_ARROW) reduce 11) ((T_INSTANCEOF) reduce 11) ((T_IS_EQUAL) reduce 11) ((T_IS_GREATER_OR_EQUAL) reduce 11) ((T_IS_IDENTICAL) reduce 11) ((T_IS_NOT_EQUAL) reduce 11) ((T_IS_NOT_IDENTICAL) reduce 11) ((T_IS_SMALLER_OR_EQUAL) reduce 11) ((T_LOGICAL_AND) reduce 11) ((T_LOGICAL_OR) reduce 11) ((T_LOGICAL_XOR) reduce 11) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 11) ((T_OBJECT_OPERATOR) reduce 11) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 11) ((T_POW) reduce 11) ((T_SL) reduce 11) ((T_SPACESHIP) reduce 11) ((T_SR) reduce 11) (("[") reduce 11) (("^") reduce 11) (("{") reduce 11) (("|") reduce 11) (("}") reduce 11)) 4949 ((("%") reduce 42) (("(") reduce 42) (("*") reduce 42) (("+") reduce 42) ((",") reduce 42) (("-") reduce 42) ((".") reduce 42) (("/") reduce 42) (("<") reduce 42) ((">") reduce 42) (("?") reduce 42) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_BOOLEAN_AND) reduce 42) ((T_BOOLEAN_OR) reduce 42) ((T_COALESCE) reduce 42) ((T_DOUBLE_ARROW) reduce 42) ((T_INSTANCEOF) reduce 42) ((T_IS_EQUAL) reduce 42) ((T_IS_GREATER_OR_EQUAL) reduce 42) ((T_IS_IDENTICAL) reduce 42) ((T_IS_NOT_EQUAL) reduce 42) ((T_IS_NOT_IDENTICAL) reduce 42) ((T_IS_SMALLER_OR_EQUAL) reduce 42) ((T_LOGICAL_AND) reduce 42) ((T_LOGICAL_OR) reduce 42) ((T_LOGICAL_XOR) reduce 42) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 42) ((T_OBJECT_OPERATOR) reduce 42) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 42) ((T_POW) reduce 42) ((T_SL) reduce 42) ((T_SPACESHIP) reduce 42) ((T_SR) reduce 42) (("[") reduce 42) (("^") reduce 42) (("{") reduce 42) (("|") reduce 42) (("}") reduce 42)) 4950 ((("%") reduce 39) (("(") reduce 39) (("*") reduce 39) (("+") reduce 39) ((",") reduce 39) (("-") reduce 39) ((".") reduce 39) (("/") reduce 39) (("<") reduce 39) ((">") reduce 39) (("?") reduce 39) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_BOOLEAN_AND) reduce 39) ((T_BOOLEAN_OR) reduce 39) ((T_COALESCE) reduce 39) ((T_DOUBLE_ARROW) reduce 39) ((T_INSTANCEOF) reduce 39) ((T_IS_EQUAL) reduce 39) ((T_IS_GREATER_OR_EQUAL) reduce 39) ((T_IS_IDENTICAL) reduce 39) ((T_IS_NOT_EQUAL) reduce 39) ((T_IS_NOT_IDENTICAL) reduce 39) ((T_IS_SMALLER_OR_EQUAL) reduce 39) ((T_LOGICAL_AND) reduce 39) ((T_LOGICAL_OR) reduce 39) ((T_LOGICAL_XOR) reduce 39) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 39) ((T_OBJECT_OPERATOR) reduce 39) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 39) ((T_POW) reduce 39) ((T_SL) reduce 39) ((T_SPACESHIP) reduce 39) ((T_SR) reduce 39) (("[") reduce 39) (("^") reduce 39) (("{") reduce 39) (("|") reduce 39) (("}") reduce 39)) 4951 ((("%") reduce 25) (("(") reduce 25) (("*") reduce 25) (("+") reduce 25) ((",") reduce 25) (("-") reduce 25) ((".") reduce 25) (("/") reduce 25) (("<") reduce 25) ((">") reduce 25) (("?") reduce 25) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_BOOLEAN_AND) reduce 25) ((T_BOOLEAN_OR) reduce 25) ((T_COALESCE) reduce 25) ((T_DOUBLE_ARROW) reduce 25) ((T_INSTANCEOF) reduce 25) ((T_IS_EQUAL) reduce 25) ((T_IS_GREATER_OR_EQUAL) reduce 25) ((T_IS_IDENTICAL) reduce 25) ((T_IS_NOT_EQUAL) reduce 25) ((T_IS_NOT_IDENTICAL) reduce 25) ((T_IS_SMALLER_OR_EQUAL) reduce 25) ((T_LOGICAL_AND) reduce 25) ((T_LOGICAL_OR) reduce 25) ((T_LOGICAL_XOR) reduce 25) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 25) ((T_OBJECT_OPERATOR) reduce 25) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 25) ((T_POW) reduce 25) ((T_SL) reduce 25) ((T_SPACESHIP) reduce 25) ((T_SR) reduce 25) (("[") reduce 25) (("^") reduce 25) (("{") reduce 25) (("|") reduce 25) (("}") reduce 25)) 4952 ((("%") reduce 50) (("(") reduce 50) (("*") reduce 50) (("+") reduce 50) ((",") reduce 50) (("-") reduce 50) ((".") reduce 50) (("/") reduce 50) (("<") reduce 50) ((">") reduce 50) (("?") reduce 50) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_BOOLEAN_AND) reduce 50) ((T_BOOLEAN_OR) reduce 50) ((T_COALESCE) reduce 50) ((T_DOUBLE_ARROW) reduce 50) ((T_INSTANCEOF) reduce 50) ((T_IS_EQUAL) reduce 50) ((T_IS_GREATER_OR_EQUAL) reduce 50) ((T_IS_IDENTICAL) reduce 50) ((T_IS_NOT_EQUAL) reduce 50) ((T_IS_NOT_IDENTICAL) reduce 50) ((T_IS_SMALLER_OR_EQUAL) reduce 50) ((T_LOGICAL_AND) reduce 50) ((T_LOGICAL_OR) reduce 50) ((T_LOGICAL_XOR) reduce 50) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 50) ((T_OBJECT_OPERATOR) reduce 50) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 50) ((T_POW) reduce 50) ((T_SL) reduce 50) ((T_SPACESHIP) reduce 50) ((T_SR) reduce 50) (("[") reduce 50) (("^") reduce 50) (("{") reduce 50) (("|") reduce 50) (("}") reduce 50)) 4953 ((("%") reduce 66) (("(") reduce 66) (("*") reduce 66) (("+") reduce 66) ((",") reduce 66) (("-") reduce 66) ((".") reduce 66) (("/") reduce 66) (("<") reduce 66) ((">") reduce 66) (("?") reduce 66) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_BOOLEAN_AND) reduce 66) ((T_BOOLEAN_OR) reduce 66) ((T_COALESCE) reduce 66) ((T_DOUBLE_ARROW) reduce 66) ((T_INSTANCEOF) reduce 66) ((T_IS_EQUAL) reduce 66) ((T_IS_GREATER_OR_EQUAL) reduce 66) ((T_IS_IDENTICAL) reduce 66) ((T_IS_NOT_EQUAL) reduce 66) ((T_IS_NOT_IDENTICAL) reduce 66) ((T_IS_SMALLER_OR_EQUAL) reduce 66) ((T_LOGICAL_AND) reduce 66) ((T_LOGICAL_OR) reduce 66) ((T_LOGICAL_XOR) reduce 66) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 66) ((T_OBJECT_OPERATOR) reduce 66) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 66) ((T_POW) reduce 66) ((T_SL) reduce 66) ((T_SPACESHIP) reduce 66) ((T_SR) reduce 66) (("[") reduce 66) (("^") reduce 66) (("{") reduce 66) (("|") reduce 66) (("}") reduce 66)) 4954 ((("%") reduce 18) (("(") reduce 18) (("*") reduce 18) (("+") reduce 18) ((",") reduce 18) (("-") reduce 18) ((".") reduce 18) (("/") reduce 18) (("<") reduce 18) ((">") reduce 18) (("?") reduce 18) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_BOOLEAN_AND) reduce 18) ((T_BOOLEAN_OR) reduce 18) ((T_COALESCE) reduce 18) ((T_DOUBLE_ARROW) reduce 18) ((T_INSTANCEOF) reduce 18) ((T_IS_EQUAL) reduce 18) ((T_IS_GREATER_OR_EQUAL) reduce 18) ((T_IS_IDENTICAL) reduce 18) ((T_IS_NOT_EQUAL) reduce 18) ((T_IS_NOT_IDENTICAL) reduce 18) ((T_IS_SMALLER_OR_EQUAL) reduce 18) ((T_LOGICAL_AND) reduce 18) ((T_LOGICAL_OR) reduce 18) ((T_LOGICAL_XOR) reduce 18) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 18) ((T_OBJECT_OPERATOR) reduce 18) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 18) ((T_POW) reduce 18) ((T_SL) reduce 18) ((T_SPACESHIP) reduce 18) ((T_SR) reduce 18) (("[") reduce 18) (("^") reduce 18) (("{") reduce 18) (("|") reduce 18) (("}") reduce 18)) 4955 ((("%") reduce 17) (("(") reduce 17) (("*") reduce 17) (("+") reduce 17) ((",") reduce 17) (("-") reduce 17) ((".") reduce 17) (("/") reduce 17) (("<") reduce 17) ((">") reduce 17) (("?") reduce 17) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_BOOLEAN_AND) reduce 17) ((T_BOOLEAN_OR) reduce 17) ((T_COALESCE) reduce 17) ((T_DOUBLE_ARROW) reduce 17) ((T_INSTANCEOF) reduce 17) ((T_IS_EQUAL) reduce 17) ((T_IS_GREATER_OR_EQUAL) reduce 17) ((T_IS_IDENTICAL) reduce 17) ((T_IS_NOT_EQUAL) reduce 17) ((T_IS_NOT_IDENTICAL) reduce 17) ((T_IS_SMALLER_OR_EQUAL) reduce 17) ((T_LOGICAL_AND) reduce 17) ((T_LOGICAL_OR) reduce 17) ((T_LOGICAL_XOR) reduce 17) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 17) ((T_OBJECT_OPERATOR) reduce 17) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 17) ((T_POW) reduce 17) ((T_SL) reduce 17) ((T_SPACESHIP) reduce 17) ((T_SR) reduce 17) (("[") reduce 17) (("^") reduce 17) (("{") reduce 17) (("|") reduce 17) (("}") reduce 17)) 4956 ((("%") reduce 15) (("(") reduce 15) (("*") reduce 15) (("+") reduce 15) ((",") reduce 15) (("-") reduce 15) ((".") reduce 15) (("/") reduce 15) (("<") reduce 15) ((">") reduce 15) (("?") reduce 15) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_BOOLEAN_AND) reduce 15) ((T_BOOLEAN_OR) reduce 15) ((T_COALESCE) reduce 15) ((T_DOUBLE_ARROW) reduce 15) ((T_INSTANCEOF) reduce 15) ((T_IS_EQUAL) reduce 15) ((T_IS_GREATER_OR_EQUAL) reduce 15) ((T_IS_IDENTICAL) reduce 15) ((T_IS_NOT_EQUAL) reduce 15) ((T_IS_NOT_IDENTICAL) reduce 15) ((T_IS_SMALLER_OR_EQUAL) reduce 15) ((T_LOGICAL_AND) reduce 15) ((T_LOGICAL_OR) reduce 15) ((T_LOGICAL_XOR) reduce 15) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 15) ((T_OBJECT_OPERATOR) reduce 15) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 15) ((T_POW) reduce 15) ((T_SL) reduce 15) ((T_SPACESHIP) reduce 15) ((T_SR) reduce 15) (("[") reduce 15) (("^") reduce 15) (("{") reduce 15) (("|") reduce 15) (("}") reduce 15)) 4957 ((("%") reduce 14) (("(") reduce 14) (("*") reduce 14) (("+") reduce 14) ((",") reduce 14) (("-") reduce 14) ((".") reduce 14) (("/") reduce 14) (("<") reduce 14) ((">") reduce 14) (("?") reduce 14) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_BOOLEAN_AND) reduce 14) ((T_BOOLEAN_OR) reduce 14) ((T_COALESCE) reduce 14) ((T_DOUBLE_ARROW) reduce 14) ((T_INSTANCEOF) reduce 14) ((T_IS_EQUAL) reduce 14) ((T_IS_GREATER_OR_EQUAL) reduce 14) ((T_IS_IDENTICAL) reduce 14) ((T_IS_NOT_EQUAL) reduce 14) ((T_IS_NOT_IDENTICAL) reduce 14) ((T_IS_SMALLER_OR_EQUAL) reduce 14) ((T_LOGICAL_AND) reduce 14) ((T_LOGICAL_OR) reduce 14) ((T_LOGICAL_XOR) reduce 14) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 14) ((T_OBJECT_OPERATOR) reduce 14) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 14) ((T_POW) reduce 14) ((T_SL) reduce 14) ((T_SPACESHIP) reduce 14) ((T_SR) reduce 14) (("[") reduce 14) (("^") reduce 14) (("{") reduce 14) (("|") reduce 14) (("}") reduce 14)) 4958 ((("%") reduce 38) (("(") reduce 38) (("*") reduce 38) (("+") reduce 38) ((",") reduce 38) (("-") reduce 38) ((".") reduce 38) (("/") reduce 38) (("<") reduce 38) ((">") reduce 38) (("?") reduce 38) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_BOOLEAN_AND) reduce 38) ((T_BOOLEAN_OR) reduce 38) ((T_COALESCE) reduce 38) ((T_DOUBLE_ARROW) reduce 38) ((T_INSTANCEOF) reduce 38) ((T_IS_EQUAL) reduce 38) ((T_IS_GREATER_OR_EQUAL) reduce 38) ((T_IS_IDENTICAL) reduce 38) ((T_IS_NOT_EQUAL) reduce 38) ((T_IS_NOT_IDENTICAL) reduce 38) ((T_IS_SMALLER_OR_EQUAL) reduce 38) ((T_LOGICAL_AND) reduce 38) ((T_LOGICAL_OR) reduce 38) ((T_LOGICAL_XOR) reduce 38) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 38) ((T_OBJECT_OPERATOR) reduce 38) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 38) ((T_POW) reduce 38) ((T_SL) reduce 38) ((T_SPACESHIP) reduce 38) ((T_SR) reduce 38) (("[") reduce 38) (("^") reduce 38) (("{") reduce 38) (("|") reduce 38) (("}") reduce 38)) 4959 ((("%") reduce 26) (("(") reduce 26) (("*") reduce 26) (("+") reduce 26) ((",") reduce 26) (("-") reduce 26) ((".") reduce 26) (("/") reduce 26) (("<") reduce 26) ((">") reduce 26) (("?") reduce 26) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_BOOLEAN_AND) reduce 26) ((T_BOOLEAN_OR) reduce 26) ((T_COALESCE) reduce 26) ((T_DOUBLE_ARROW) reduce 26) ((T_INSTANCEOF) reduce 26) ((T_IS_EQUAL) reduce 26) ((T_IS_GREATER_OR_EQUAL) reduce 26) ((T_IS_IDENTICAL) reduce 26) ((T_IS_NOT_EQUAL) reduce 26) ((T_IS_NOT_IDENTICAL) reduce 26) ((T_IS_SMALLER_OR_EQUAL) reduce 26) ((T_LOGICAL_AND) reduce 26) ((T_LOGICAL_OR) reduce 26) ((T_LOGICAL_XOR) reduce 26) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 26) ((T_OBJECT_OPERATOR) reduce 26) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 26) ((T_POW) reduce 26) ((T_SL) reduce 26) ((T_SPACESHIP) reduce 26) ((T_SR) reduce 26) (("[") reduce 26) (("^") reduce 26) (("{") reduce 26) (("|") reduce 26) (("}") reduce 26)) 4960 ((("%") reduce 22) (("(") reduce 22) (("*") reduce 22) (("+") reduce 22) ((",") reduce 22) (("-") reduce 22) ((".") reduce 22) (("/") reduce 22) (("<") reduce 22) ((">") reduce 22) (("?") reduce 22) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_BOOLEAN_AND) reduce 22) ((T_BOOLEAN_OR) reduce 22) ((T_COALESCE) reduce 22) ((T_DOUBLE_ARROW) reduce 22) ((T_INSTANCEOF) reduce 22) ((T_IS_EQUAL) reduce 22) ((T_IS_GREATER_OR_EQUAL) reduce 22) ((T_IS_IDENTICAL) reduce 22) ((T_IS_NOT_EQUAL) reduce 22) ((T_IS_NOT_IDENTICAL) reduce 22) ((T_IS_SMALLER_OR_EQUAL) reduce 22) ((T_LOGICAL_AND) reduce 22) ((T_LOGICAL_OR) reduce 22) ((T_LOGICAL_XOR) reduce 22) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 22) ((T_OBJECT_OPERATOR) reduce 22) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 22) ((T_POW) reduce 22) ((T_SL) reduce 22) ((T_SPACESHIP) reduce 22) ((T_SR) reduce 22) (("[") reduce 22) (("^") reduce 22) (("{") reduce 22) (("|") reduce 22) (("}") reduce 22)) 4961 ((("%") reduce 24) (("(") reduce 24) (("*") reduce 24) (("+") reduce 24) ((",") reduce 24) (("-") reduce 24) ((".") reduce 24) (("/") reduce 24) (("<") reduce 24) ((">") reduce 24) (("?") reduce 24) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_BOOLEAN_AND) reduce 24) ((T_BOOLEAN_OR) reduce 24) ((T_COALESCE) reduce 24) ((T_DOUBLE_ARROW) reduce 24) ((T_INSTANCEOF) reduce 24) ((T_IS_EQUAL) reduce 24) ((T_IS_GREATER_OR_EQUAL) reduce 24) ((T_IS_IDENTICAL) reduce 24) ((T_IS_NOT_EQUAL) reduce 24) ((T_IS_NOT_IDENTICAL) reduce 24) ((T_IS_SMALLER_OR_EQUAL) reduce 24) ((T_LOGICAL_AND) reduce 24) ((T_LOGICAL_OR) reduce 24) ((T_LOGICAL_XOR) reduce 24) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 24) ((T_OBJECT_OPERATOR) reduce 24) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 24) ((T_POW) reduce 24) ((T_SL) reduce 24) ((T_SPACESHIP) reduce 24) ((T_SR) reduce 24) (("[") reduce 24) (("^") reduce 24) (("{") reduce 24) (("|") reduce 24) (("}") reduce 24)) 4962 ((("%") reduce 16) (("(") reduce 16) (("*") reduce 16) (("+") reduce 16) ((",") reduce 16) (("-") reduce 16) ((".") reduce 16) (("/") reduce 16) (("<") reduce 16) ((">") reduce 16) (("?") reduce 16) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_BOOLEAN_AND) reduce 16) ((T_BOOLEAN_OR) reduce 16) ((T_COALESCE) reduce 16) ((T_DOUBLE_ARROW) reduce 16) ((T_INSTANCEOF) reduce 16) ((T_IS_EQUAL) reduce 16) ((T_IS_GREATER_OR_EQUAL) reduce 16) ((T_IS_IDENTICAL) reduce 16) ((T_IS_NOT_EQUAL) reduce 16) ((T_IS_NOT_IDENTICAL) reduce 16) ((T_IS_SMALLER_OR_EQUAL) reduce 16) ((T_LOGICAL_AND) reduce 16) ((T_LOGICAL_OR) reduce 16) ((T_LOGICAL_XOR) reduce 16) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 16) ((T_OBJECT_OPERATOR) reduce 16) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 16) ((T_POW) reduce 16) ((T_SL) reduce 16) ((T_SPACESHIP) reduce 16) ((T_SR) reduce 16) (("[") reduce 16) (("^") reduce 16) (("{") reduce 16) (("|") reduce 16) (("}") reduce 16)) 4963 ((("%") reduce 48) (("(") reduce 48) (("*") reduce 48) (("+") reduce 48) ((",") reduce 48) (("-") reduce 48) ((".") reduce 48) (("/") reduce 48) (("<") reduce 48) ((">") reduce 48) (("?") reduce 48) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_BOOLEAN_AND) reduce 48) ((T_BOOLEAN_OR) reduce 48) ((T_COALESCE) reduce 48) ((T_DOUBLE_ARROW) reduce 48) ((T_INSTANCEOF) reduce 48) ((T_IS_EQUAL) reduce 48) ((T_IS_GREATER_OR_EQUAL) reduce 48) ((T_IS_IDENTICAL) reduce 48) ((T_IS_NOT_EQUAL) reduce 48) ((T_IS_NOT_IDENTICAL) reduce 48) ((T_IS_SMALLER_OR_EQUAL) reduce 48) ((T_LOGICAL_AND) reduce 48) ((T_LOGICAL_OR) reduce 48) ((T_LOGICAL_XOR) reduce 48) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 48) ((T_OBJECT_OPERATOR) reduce 48) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 48) ((T_POW) reduce 48) ((T_SL) reduce 48) ((T_SPACESHIP) reduce 48) ((T_SR) reduce 48) (("[") reduce 48) (("^") reduce 48) (("{") reduce 48) (("|") reduce 48) (("}") reduce 48)) 4964 ((("%") reduce 20) (("(") reduce 20) (("*") reduce 20) (("+") reduce 20) ((",") reduce 20) (("-") reduce 20) ((".") reduce 20) (("/") reduce 20) (("<") reduce 20) ((">") reduce 20) (("?") reduce 20) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_BOOLEAN_AND) reduce 20) ((T_BOOLEAN_OR) reduce 20) ((T_COALESCE) reduce 20) ((T_DOUBLE_ARROW) reduce 20) ((T_INSTANCEOF) reduce 20) ((T_IS_EQUAL) reduce 20) ((T_IS_GREATER_OR_EQUAL) reduce 20) ((T_IS_IDENTICAL) reduce 20) ((T_IS_NOT_EQUAL) reduce 20) ((T_IS_NOT_IDENTICAL) reduce 20) ((T_IS_SMALLER_OR_EQUAL) reduce 20) ((T_LOGICAL_AND) reduce 20) ((T_LOGICAL_OR) reduce 20) ((T_LOGICAL_XOR) reduce 20) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 20) ((T_OBJECT_OPERATOR) reduce 20) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 20) ((T_POW) reduce 20) ((T_SL) reduce 20) ((T_SPACESHIP) reduce 20) ((T_SR) reduce 20) (("[") reduce 20) (("^") reduce 20) (("{") reduce 20) (("|") reduce 20) (("}") reduce 20)) 4965 ((("%") reduce 70) (("(") reduce 70) (("*") reduce 70) (("+") reduce 70) ((",") reduce 70) (("-") reduce 70) ((".") reduce 70) (("/") reduce 70) (("<") reduce 70) ((">") reduce 70) (("?") reduce 70) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_BOOLEAN_AND) reduce 70) ((T_BOOLEAN_OR) reduce 70) ((T_COALESCE) reduce 70) ((T_DOUBLE_ARROW) reduce 70) ((T_INSTANCEOF) reduce 70) ((T_IS_EQUAL) reduce 70) ((T_IS_GREATER_OR_EQUAL) reduce 70) ((T_IS_IDENTICAL) reduce 70) ((T_IS_NOT_EQUAL) reduce 70) ((T_IS_NOT_IDENTICAL) reduce 70) ((T_IS_SMALLER_OR_EQUAL) reduce 70) ((T_LOGICAL_AND) reduce 70) ((T_LOGICAL_OR) reduce 70) ((T_LOGICAL_XOR) reduce 70) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 70) ((T_OBJECT_OPERATOR) reduce 70) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 70) ((T_POW) reduce 70) ((T_SL) reduce 70) ((T_SPACESHIP) reduce 70) ((T_SR) reduce 70) (("[") reduce 70) (("^") reduce 70) (("{") reduce 70) (("|") reduce 70) (("}") reduce 70)) 4966 ((("%") reduce 3) (("(") reduce 3) (("*") reduce 3) (("+") reduce 3) ((",") reduce 3) (("-") reduce 3) ((".") reduce 3) (("/") reduce 3) (("<") reduce 3) ((">") reduce 3) (("?") reduce 3) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_BOOLEAN_AND) reduce 3) ((T_BOOLEAN_OR) reduce 3) ((T_COALESCE) reduce 3) ((T_DOUBLE_ARROW) reduce 3) ((T_INSTANCEOF) reduce 3) ((T_IS_EQUAL) reduce 3) ((T_IS_GREATER_OR_EQUAL) reduce 3) ((T_IS_IDENTICAL) reduce 3) ((T_IS_NOT_EQUAL) reduce 3) ((T_IS_NOT_IDENTICAL) reduce 3) ((T_IS_SMALLER_OR_EQUAL) reduce 3) ((T_LOGICAL_AND) reduce 3) ((T_LOGICAL_OR) reduce 3) ((T_LOGICAL_XOR) reduce 3) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 3) ((T_OBJECT_OPERATOR) reduce 3) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 3) ((T_POW) reduce 3) ((T_SL) reduce 3) ((T_SPACESHIP) reduce 3) ((T_SR) reduce 3) (("[") reduce 3) (("^") reduce 3) (("{") reduce 3) (("|") reduce 3) (("}") reduce 3)) 4967 ((("%") reduce 12) (("(") reduce 12) (("*") reduce 12) (("+") reduce 12) ((",") reduce 12) (("-") reduce 12) ((".") reduce 12) (("/") reduce 12) (("<") reduce 12) ((">") reduce 12) (("?") reduce 12) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_BOOLEAN_AND) reduce 12) ((T_BOOLEAN_OR) reduce 12) ((T_COALESCE) reduce 12) ((T_DOUBLE_ARROW) reduce 12) ((T_INSTANCEOF) reduce 12) ((T_IS_EQUAL) reduce 12) ((T_IS_GREATER_OR_EQUAL) reduce 12) ((T_IS_IDENTICAL) reduce 12) ((T_IS_NOT_EQUAL) reduce 12) ((T_IS_NOT_IDENTICAL) reduce 12) ((T_IS_SMALLER_OR_EQUAL) reduce 12) ((T_LOGICAL_AND) reduce 12) ((T_LOGICAL_OR) reduce 12) ((T_LOGICAL_XOR) reduce 12) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 12) ((T_OBJECT_OPERATOR) reduce 12) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 12) ((T_POW) reduce 12) ((T_SL) reduce 12) ((T_SPACESHIP) reduce 12) ((T_SR) reduce 12) (("[") reduce 12) (("^") reduce 12) (("{") reduce 12) (("|") reduce 12) (("}") reduce 12)) 4968 ((("%") reduce 54) (("(") reduce 54) (("*") reduce 54) (("+") reduce 54) ((",") reduce 54) (("-") reduce 54) ((".") reduce 54) (("/") reduce 54) (("<") reduce 54) ((">") reduce 54) (("?") reduce 54) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_BOOLEAN_AND) reduce 54) ((T_BOOLEAN_OR) reduce 54) ((T_COALESCE) reduce 54) ((T_DOUBLE_ARROW) reduce 54) ((T_INSTANCEOF) reduce 54) ((T_IS_EQUAL) reduce 54) ((T_IS_GREATER_OR_EQUAL) reduce 54) ((T_IS_IDENTICAL) reduce 54) ((T_IS_NOT_EQUAL) reduce 54) ((T_IS_NOT_IDENTICAL) reduce 54) ((T_IS_SMALLER_OR_EQUAL) reduce 54) ((T_LOGICAL_AND) reduce 54) ((T_LOGICAL_OR) reduce 54) ((T_LOGICAL_XOR) reduce 54) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 54) ((T_OBJECT_OPERATOR) reduce 54) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 54) ((T_POW) reduce 54) ((T_SL) reduce 54) ((T_SPACESHIP) reduce 54) ((T_SR) reduce 54) (("[") reduce 54) (("^") reduce 54) (("{") reduce 54) (("|") reduce 54) (("}") reduce 54)) 4969 ((("%") reduce 65) (("(") reduce 65) (("*") reduce 65) (("+") reduce 65) ((",") reduce 65) (("-") reduce 65) ((".") reduce 65) (("/") reduce 65) (("<") reduce 65) ((">") reduce 65) (("?") reduce 65) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_BOOLEAN_AND) reduce 65) ((T_BOOLEAN_OR) reduce 65) ((T_COALESCE) reduce 65) ((T_DOUBLE_ARROW) reduce 65) ((T_INSTANCEOF) reduce 65) ((T_IS_EQUAL) reduce 65) ((T_IS_GREATER_OR_EQUAL) reduce 65) ((T_IS_IDENTICAL) reduce 65) ((T_IS_NOT_EQUAL) reduce 65) ((T_IS_NOT_IDENTICAL) reduce 65) ((T_IS_SMALLER_OR_EQUAL) reduce 65) ((T_LOGICAL_AND) reduce 65) ((T_LOGICAL_OR) reduce 65) ((T_LOGICAL_XOR) reduce 65) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 65) ((T_OBJECT_OPERATOR) reduce 65) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 65) ((T_POW) reduce 65) ((T_SL) reduce 65) ((T_SPACESHIP) reduce 65) ((T_SR) reduce 65) (("[") reduce 65) (("^") reduce 65) (("{") reduce 65) (("|") reduce 65) (("}") reduce 65)) 4970 ((("%") reduce 74) (("(") reduce 74) (("*") reduce 74) (("+") reduce 74) ((",") reduce 74) (("-") reduce 74) ((".") reduce 74) (("/") reduce 74) (("<") reduce 74) ((">") reduce 74) (("?") reduce 74) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_BOOLEAN_AND) reduce 74) ((T_BOOLEAN_OR) reduce 74) ((T_COALESCE) reduce 74) ((T_DOUBLE_ARROW) reduce 74) ((T_INSTANCEOF) reduce 74) ((T_IS_EQUAL) reduce 74) ((T_IS_GREATER_OR_EQUAL) reduce 74) ((T_IS_IDENTICAL) reduce 74) ((T_IS_NOT_EQUAL) reduce 74) ((T_IS_NOT_IDENTICAL) reduce 74) ((T_IS_SMALLER_OR_EQUAL) reduce 74) ((T_LOGICAL_AND) reduce 74) ((T_LOGICAL_OR) reduce 74) ((T_LOGICAL_XOR) reduce 74) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 74) ((T_OBJECT_OPERATOR) reduce 74) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 74) ((T_POW) reduce 74) ((T_SL) reduce 74) ((T_SPACESHIP) reduce 74) ((T_SR) reduce 74) (("[") reduce 74) (("^") reduce 74) (("{") reduce 74) (("|") reduce 74) (("}") reduce 74)) 4971 ((("%") reduce 30) (("(") reduce 30) (("*") reduce 30) (("+") reduce 30) ((",") reduce 30) (("-") reduce 30) ((".") reduce 30) (("/") reduce 30) (("<") reduce 30) ((">") reduce 30) (("?") reduce 30) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_BOOLEAN_AND) reduce 30) ((T_BOOLEAN_OR) reduce 30) ((T_COALESCE) reduce 30) ((T_DOUBLE_ARROW) reduce 30) ((T_INSTANCEOF) reduce 30) ((T_IS_EQUAL) reduce 30) ((T_IS_GREATER_OR_EQUAL) reduce 30) ((T_IS_IDENTICAL) reduce 30) ((T_IS_NOT_EQUAL) reduce 30) ((T_IS_NOT_IDENTICAL) reduce 30) ((T_IS_SMALLER_OR_EQUAL) reduce 30) ((T_LOGICAL_AND) reduce 30) ((T_LOGICAL_OR) reduce 30) ((T_LOGICAL_XOR) reduce 30) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 30) ((T_OBJECT_OPERATOR) reduce 30) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 30) ((T_POW) reduce 30) ((T_SL) reduce 30) ((T_SPACESHIP) reduce 30) ((T_SR) reduce 30) (("[") reduce 30) (("^") reduce 30) (("{") reduce 30) (("|") reduce 30) (("}") reduce 30)) 4972 ((("%") reduce 68) (("(") reduce 68) (("*") reduce 68) (("+") reduce 68) ((",") reduce 68) (("-") reduce 68) ((".") reduce 68) (("/") reduce 68) (("<") reduce 68) ((">") reduce 68) (("?") reduce 68) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_BOOLEAN_AND) reduce 68) ((T_BOOLEAN_OR) reduce 68) ((T_COALESCE) reduce 68) ((T_DOUBLE_ARROW) reduce 68) ((T_INSTANCEOF) reduce 68) ((T_IS_EQUAL) reduce 68) ((T_IS_GREATER_OR_EQUAL) reduce 68) ((T_IS_IDENTICAL) reduce 68) ((T_IS_NOT_EQUAL) reduce 68) ((T_IS_NOT_IDENTICAL) reduce 68) ((T_IS_SMALLER_OR_EQUAL) reduce 68) ((T_LOGICAL_AND) reduce 68) ((T_LOGICAL_OR) reduce 68) ((T_LOGICAL_XOR) reduce 68) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 68) ((T_OBJECT_OPERATOR) reduce 68) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 68) ((T_POW) reduce 68) ((T_SL) reduce 68) ((T_SPACESHIP) reduce 68) ((T_SR) reduce 68) (("[") reduce 68) (("^") reduce 68) (("{") reduce 68) (("|") reduce 68) (("}") reduce 68)) 4973 ((("%") reduce 21) (("(") reduce 21) (("*") reduce 21) (("+") reduce 21) ((",") reduce 21) (("-") reduce 21) ((".") reduce 21) (("/") reduce 21) (("<") reduce 21) ((">") reduce 21) (("?") reduce 21) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_BOOLEAN_AND) reduce 21) ((T_BOOLEAN_OR) reduce 21) ((T_COALESCE) reduce 21) ((T_DOUBLE_ARROW) reduce 21) ((T_INSTANCEOF) reduce 21) ((T_IS_EQUAL) reduce 21) ((T_IS_GREATER_OR_EQUAL) reduce 21) ((T_IS_IDENTICAL) reduce 21) ((T_IS_NOT_EQUAL) reduce 21) ((T_IS_NOT_IDENTICAL) reduce 21) ((T_IS_SMALLER_OR_EQUAL) reduce 21) ((T_LOGICAL_AND) reduce 21) ((T_LOGICAL_OR) reduce 21) ((T_LOGICAL_XOR) reduce 21) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 21) ((T_OBJECT_OPERATOR) reduce 21) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 21) ((T_POW) reduce 21) ((T_SL) reduce 21) ((T_SPACESHIP) reduce 21) ((T_SR) reduce 21) (("[") reduce 21) (("^") reduce 21) (("{") reduce 21) (("|") reduce 21) (("}") reduce 21)) 4974 ((("%") reduce 23) (("(") reduce 23) (("*") reduce 23) (("+") reduce 23) ((",") reduce 23) (("-") reduce 23) ((".") reduce 23) (("/") reduce 23) (("<") reduce 23) ((">") reduce 23) (("?") reduce 23) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_BOOLEAN_AND) reduce 23) ((T_BOOLEAN_OR) reduce 23) ((T_COALESCE) reduce 23) ((T_DOUBLE_ARROW) reduce 23) ((T_INSTANCEOF) reduce 23) ((T_IS_EQUAL) reduce 23) ((T_IS_GREATER_OR_EQUAL) reduce 23) ((T_IS_IDENTICAL) reduce 23) ((T_IS_NOT_EQUAL) reduce 23) ((T_IS_NOT_IDENTICAL) reduce 23) ((T_IS_SMALLER_OR_EQUAL) reduce 23) ((T_LOGICAL_AND) reduce 23) ((T_LOGICAL_OR) reduce 23) ((T_LOGICAL_XOR) reduce 23) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 23) ((T_OBJECT_OPERATOR) reduce 23) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 23) ((T_POW) reduce 23) ((T_SL) reduce 23) ((T_SPACESHIP) reduce 23) ((T_SR) reduce 23) (("[") reduce 23) (("^") reduce 23) (("{") reduce 23) (("|") reduce 23) (("}") reduce 23)) 4975 ((("%") reduce 41) (("(") reduce 41) (("*") reduce 41) (("+") reduce 41) ((",") reduce 41) (("-") reduce 41) ((".") reduce 41) (("/") reduce 41) (("<") reduce 41) ((">") reduce 41) (("?") reduce 41) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_BOOLEAN_AND) reduce 41) ((T_BOOLEAN_OR) reduce 41) ((T_COALESCE) reduce 41) ((T_DOUBLE_ARROW) reduce 41) ((T_INSTANCEOF) reduce 41) ((T_IS_EQUAL) reduce 41) ((T_IS_GREATER_OR_EQUAL) reduce 41) ((T_IS_IDENTICAL) reduce 41) ((T_IS_NOT_EQUAL) reduce 41) ((T_IS_NOT_IDENTICAL) reduce 41) ((T_IS_SMALLER_OR_EQUAL) reduce 41) ((T_LOGICAL_AND) reduce 41) ((T_LOGICAL_OR) reduce 41) ((T_LOGICAL_XOR) reduce 41) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 41) ((T_OBJECT_OPERATOR) reduce 41) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 41) ((T_POW) reduce 41) ((T_SL) reduce 41) ((T_SPACESHIP) reduce 41) ((T_SR) reduce 41) (("[") reduce 41) (("^") reduce 41) (("{") reduce 41) (("|") reduce 41) (("}") reduce 41)) 4976 ((("%") reduce 62) (("(") reduce 62) (("*") reduce 62) (("+") reduce 62) ((",") reduce 62) (("-") reduce 62) ((".") reduce 62) (("/") reduce 62) (("<") reduce 62) ((">") reduce 62) (("?") reduce 62) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_BOOLEAN_AND) reduce 62) ((T_BOOLEAN_OR) reduce 62) ((T_COALESCE) reduce 62) ((T_DOUBLE_ARROW) reduce 62) ((T_INSTANCEOF) reduce 62) ((T_IS_EQUAL) reduce 62) ((T_IS_GREATER_OR_EQUAL) reduce 62) ((T_IS_IDENTICAL) reduce 62) ((T_IS_NOT_EQUAL) reduce 62) ((T_IS_NOT_IDENTICAL) reduce 62) ((T_IS_SMALLER_OR_EQUAL) reduce 62) ((T_LOGICAL_AND) reduce 62) ((T_LOGICAL_OR) reduce 62) ((T_LOGICAL_XOR) reduce 62) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 62) ((T_OBJECT_OPERATOR) reduce 62) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 62) ((T_POW) reduce 62) ((T_SL) reduce 62) ((T_SPACESHIP) reduce 62) ((T_SR) reduce 62) (("[") reduce 62) (("^") reduce 62) (("{") reduce 62) (("|") reduce 62) (("}") reduce 62)) 4977 ((("%") reduce 34) (("(") reduce 34) (("*") reduce 34) (("+") reduce 34) ((",") reduce 34) (("-") reduce 34) ((".") reduce 34) (("/") reduce 34) (("<") reduce 34) ((">") reduce 34) (("?") reduce 34) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_BOOLEAN_AND) reduce 34) ((T_BOOLEAN_OR) reduce 34) ((T_COALESCE) reduce 34) ((T_DOUBLE_ARROW) reduce 34) ((T_INSTANCEOF) reduce 34) ((T_IS_EQUAL) reduce 34) ((T_IS_GREATER_OR_EQUAL) reduce 34) ((T_IS_IDENTICAL) reduce 34) ((T_IS_NOT_EQUAL) reduce 34) ((T_IS_NOT_IDENTICAL) reduce 34) ((T_IS_SMALLER_OR_EQUAL) reduce 34) ((T_LOGICAL_AND) reduce 34) ((T_LOGICAL_OR) reduce 34) ((T_LOGICAL_XOR) reduce 34) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 34) ((T_OBJECT_OPERATOR) reduce 34) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 34) ((T_POW) reduce 34) ((T_SL) reduce 34) ((T_SPACESHIP) reduce 34) ((T_SR) reduce 34) (("[") reduce 34) (("^") reduce 34) (("{") reduce 34) (("|") reduce 34) (("}") reduce 34)) 4978 ((("%") reduce 40) (("(") reduce 40) (("*") reduce 40) (("+") reduce 40) ((",") reduce 40) (("-") reduce 40) ((".") reduce 40) (("/") reduce 40) (("<") reduce 40) ((">") reduce 40) (("?") reduce 40) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_BOOLEAN_AND) reduce 40) ((T_BOOLEAN_OR) reduce 40) ((T_COALESCE) reduce 40) ((T_DOUBLE_ARROW) reduce 40) ((T_INSTANCEOF) reduce 40) ((T_IS_EQUAL) reduce 40) ((T_IS_GREATER_OR_EQUAL) reduce 40) ((T_IS_IDENTICAL) reduce 40) ((T_IS_NOT_EQUAL) reduce 40) ((T_IS_NOT_IDENTICAL) reduce 40) ((T_IS_SMALLER_OR_EQUAL) reduce 40) ((T_LOGICAL_AND) reduce 40) ((T_LOGICAL_OR) reduce 40) ((T_LOGICAL_XOR) reduce 40) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 40) ((T_OBJECT_OPERATOR) reduce 40) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 40) ((T_POW) reduce 40) ((T_SL) reduce 40) ((T_SPACESHIP) reduce 40) ((T_SR) reduce 40) (("[") reduce 40) (("^") reduce 40) (("{") reduce 40) (("|") reduce 40) (("}") reduce 40)) 4979 ((("%") reduce 13) (("(") reduce 13) (("*") reduce 13) (("+") reduce 13) ((",") reduce 13) (("-") reduce 13) ((".") reduce 13) (("/") reduce 13) (("<") reduce 13) ((">") reduce 13) (("?") reduce 13) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_BOOLEAN_AND) reduce 13) ((T_BOOLEAN_OR) reduce 13) ((T_COALESCE) reduce 13) ((T_DOUBLE_ARROW) reduce 13) ((T_INSTANCEOF) reduce 13) ((T_IS_EQUAL) reduce 13) ((T_IS_GREATER_OR_EQUAL) reduce 13) ((T_IS_IDENTICAL) reduce 13) ((T_IS_NOT_EQUAL) reduce 13) ((T_IS_NOT_IDENTICAL) reduce 13) ((T_IS_SMALLER_OR_EQUAL) reduce 13) ((T_LOGICAL_AND) reduce 13) ((T_LOGICAL_OR) reduce 13) ((T_LOGICAL_XOR) reduce 13) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 13) ((T_OBJECT_OPERATOR) reduce 13) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 13) ((T_POW) reduce 13) ((T_SL) reduce 13) ((T_SPACESHIP) reduce 13) ((T_SR) reduce 13) (("[") reduce 13) (("^") reduce 13) (("{") reduce 13) (("|") reduce 13) (("}") reduce 13)) 4980 ((("%") reduce 55) (("(") reduce 55) (("*") reduce 55) (("+") reduce 55) ((",") reduce 55) (("-") reduce 55) ((".") reduce 55) (("/") reduce 55) (("<") reduce 55) ((">") reduce 55) (("?") reduce 55) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_BOOLEAN_AND) reduce 55) ((T_BOOLEAN_OR) reduce 55) ((T_COALESCE) reduce 55) ((T_DOUBLE_ARROW) reduce 55) ((T_INSTANCEOF) reduce 55) ((T_IS_EQUAL) reduce 55) ((T_IS_GREATER_OR_EQUAL) reduce 55) ((T_IS_IDENTICAL) reduce 55) ((T_IS_NOT_EQUAL) reduce 55) ((T_IS_NOT_IDENTICAL) reduce 55) ((T_IS_SMALLER_OR_EQUAL) reduce 55) ((T_LOGICAL_AND) reduce 55) ((T_LOGICAL_OR) reduce 55) ((T_LOGICAL_XOR) reduce 55) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 55) ((T_OBJECT_OPERATOR) reduce 55) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 55) ((T_POW) reduce 55) ((T_SL) reduce 55) ((T_SPACESHIP) reduce 55) ((T_SR) reduce 55) (("[") reduce 55) (("^") reduce 55) (("{") reduce 55) (("|") reduce 55) (("}") reduce 55)) 4981 ((("%") reduce 1) (("(") reduce 1) (("*") reduce 1) (("+") reduce 1) ((",") reduce 1) (("-") reduce 1) ((".") reduce 1) (("/") reduce 1) (("<") reduce 1) ((">") reduce 1) (("?") reduce 1) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_BOOLEAN_AND) reduce 1) ((T_BOOLEAN_OR) reduce 1) ((T_COALESCE) reduce 1) ((T_DOUBLE_ARROW) reduce 1) ((T_INSTANCEOF) reduce 1) ((T_IS_EQUAL) reduce 1) ((T_IS_GREATER_OR_EQUAL) reduce 1) ((T_IS_IDENTICAL) reduce 1) ((T_IS_NOT_EQUAL) reduce 1) ((T_IS_NOT_IDENTICAL) reduce 1) ((T_IS_SMALLER_OR_EQUAL) reduce 1) ((T_LOGICAL_AND) reduce 1) ((T_LOGICAL_OR) reduce 1) ((T_LOGICAL_XOR) reduce 1) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 1) ((T_OBJECT_OPERATOR) reduce 1) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 1) ((T_POW) reduce 1) ((T_SL) reduce 1) ((T_SPACESHIP) reduce 1) ((T_SR) reduce 1) (("[") reduce 1) (("^") reduce 1) (("{") reduce 1) (("|") reduce 1) (("}") reduce 1)) 4982 ((("%") reduce 2) (("(") reduce 2) (("*") reduce 2) (("+") reduce 2) ((",") reduce 2) (("-") reduce 2) ((".") reduce 2) (("/") reduce 2) (("<") reduce 2) ((">") reduce 2) (("?") reduce 2) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_BOOLEAN_AND) reduce 2) ((T_BOOLEAN_OR) reduce 2) ((T_COALESCE) reduce 2) ((T_DOUBLE_ARROW) reduce 2) ((T_INSTANCEOF) reduce 2) ((T_IS_EQUAL) reduce 2) ((T_IS_GREATER_OR_EQUAL) reduce 2) ((T_IS_IDENTICAL) reduce 2) ((T_IS_NOT_EQUAL) reduce 2) ((T_IS_NOT_IDENTICAL) reduce 2) ((T_IS_SMALLER_OR_EQUAL) reduce 2) ((T_LOGICAL_AND) reduce 2) ((T_LOGICAL_OR) reduce 2) ((T_LOGICAL_XOR) reduce 2) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 2) ((T_OBJECT_OPERATOR) reduce 2) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 2) ((T_POW) reduce 2) ((T_SL) reduce 2) ((T_SPACESHIP) reduce 2) ((T_SR) reduce 2) (("[") reduce 2) (("^") reduce 2) (("{") reduce 2) (("|") reduce 2) (("}") reduce 2)) 4983 ((("%") reduce 9) (("(") reduce 9) (("*") reduce 9) (("+") reduce 9) ((",") reduce 9) (("-") reduce 9) ((".") reduce 9) (("/") reduce 9) (("<") reduce 9) ((">") reduce 9) (("?") reduce 9) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_BOOLEAN_AND) reduce 9) ((T_BOOLEAN_OR) reduce 9) ((T_COALESCE) reduce 9) ((T_DOUBLE_ARROW) reduce 9) ((T_INSTANCEOF) reduce 9) ((T_IS_EQUAL) reduce 9) ((T_IS_GREATER_OR_EQUAL) reduce 9) ((T_IS_IDENTICAL) reduce 9) ((T_IS_NOT_EQUAL) reduce 9) ((T_IS_NOT_IDENTICAL) reduce 9) ((T_IS_SMALLER_OR_EQUAL) reduce 9) ((T_LOGICAL_AND) reduce 9) ((T_LOGICAL_OR) reduce 9) ((T_LOGICAL_XOR) reduce 9) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 9) ((T_OBJECT_OPERATOR) reduce 9) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 9) ((T_POW) reduce 9) ((T_SL) reduce 9) ((T_SPACESHIP) reduce 9) ((T_SR) reduce 9) (("[") reduce 9) (("^") reduce 9) (("{") reduce 9) (("|") reduce 9) (("}") reduce 9)) 4984 ((("%") reduce 33) (("(") reduce 33) (("*") reduce 33) (("+") reduce 33) ((",") reduce 33) (("-") reduce 33) ((".") reduce 33) (("/") reduce 33) (("<") reduce 33) ((">") reduce 33) (("?") reduce 33) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_BOOLEAN_AND) reduce 33) ((T_BOOLEAN_OR) reduce 33) ((T_COALESCE) reduce 33) ((T_DOUBLE_ARROW) reduce 33) ((T_INSTANCEOF) reduce 33) ((T_IS_EQUAL) reduce 33) ((T_IS_GREATER_OR_EQUAL) reduce 33) ((T_IS_IDENTICAL) reduce 33) ((T_IS_NOT_EQUAL) reduce 33) ((T_IS_NOT_IDENTICAL) reduce 33) ((T_IS_SMALLER_OR_EQUAL) reduce 33) ((T_LOGICAL_AND) reduce 33) ((T_LOGICAL_OR) reduce 33) ((T_LOGICAL_XOR) reduce 33) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 33) ((T_OBJECT_OPERATOR) reduce 33) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 33) ((T_POW) reduce 33) ((T_SL) reduce 33) ((T_SPACESHIP) reduce 33) ((T_SR) reduce 33) (("[") reduce 33) (("^") reduce 33) (("{") reduce 33) (("|") reduce 33) (("}") reduce 33)) 4985 ((("%") reduce 58) (("(") reduce 58) (("*") reduce 58) (("+") reduce 58) ((",") reduce 58) (("-") reduce 58) ((".") reduce 58) (("/") reduce 58) (("<") reduce 58) ((">") reduce 58) (("?") reduce 58) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_BOOLEAN_AND) reduce 58) ((T_BOOLEAN_OR) reduce 58) ((T_COALESCE) reduce 58) ((T_DOUBLE_ARROW) reduce 58) ((T_INSTANCEOF) reduce 58) ((T_IS_EQUAL) reduce 58) ((T_IS_GREATER_OR_EQUAL) reduce 58) ((T_IS_IDENTICAL) reduce 58) ((T_IS_NOT_EQUAL) reduce 58) ((T_IS_NOT_IDENTICAL) reduce 58) ((T_IS_SMALLER_OR_EQUAL) reduce 58) ((T_LOGICAL_AND) reduce 58) ((T_LOGICAL_OR) reduce 58) ((T_LOGICAL_XOR) reduce 58) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 58) ((T_OBJECT_OPERATOR) reduce 58) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 58) ((T_POW) reduce 58) ((T_SL) reduce 58) ((T_SPACESHIP) reduce 58) ((T_SR) reduce 58) (("[") reduce 58) (("^") reduce 58) (("{") reduce 58) (("|") reduce 58) (("}") reduce 58)) 4986 ((("%") reduce 37) (("(") reduce 37) (("*") reduce 37) (("+") reduce 37) ((",") reduce 37) (("-") reduce 37) ((".") reduce 37) (("/") reduce 37) (("<") reduce 37) ((">") reduce 37) (("?") reduce 37) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_BOOLEAN_AND) reduce 37) ((T_BOOLEAN_OR) reduce 37) ((T_COALESCE) reduce 37) ((T_DOUBLE_ARROW) reduce 37) ((T_INSTANCEOF) reduce 37) ((T_IS_EQUAL) reduce 37) ((T_IS_GREATER_OR_EQUAL) reduce 37) ((T_IS_IDENTICAL) reduce 37) ((T_IS_NOT_EQUAL) reduce 37) ((T_IS_NOT_IDENTICAL) reduce 37) ((T_IS_SMALLER_OR_EQUAL) reduce 37) ((T_LOGICAL_AND) reduce 37) ((T_LOGICAL_OR) reduce 37) ((T_LOGICAL_XOR) reduce 37) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 37) ((T_OBJECT_OPERATOR) reduce 37) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 37) ((T_POW) reduce 37) ((T_SL) reduce 37) ((T_SPACESHIP) reduce 37) ((T_SR) reduce 37) (("[") reduce 37) (("^") reduce 37) (("{") reduce 37) (("|") reduce 37) (("}") reduce 37)) 4987 ((("%") reduce 64) (("(") reduce 64) (("*") reduce 64) (("+") reduce 64) ((",") reduce 64) (("-") reduce 64) ((".") reduce 64) (("/") reduce 64) (("<") reduce 64) ((">") reduce 64) (("?") reduce 64) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_BOOLEAN_AND) reduce 64) ((T_BOOLEAN_OR) reduce 64) ((T_COALESCE) reduce 64) ((T_DOUBLE_ARROW) reduce 64) ((T_INSTANCEOF) reduce 64) ((T_IS_EQUAL) reduce 64) ((T_IS_GREATER_OR_EQUAL) reduce 64) ((T_IS_IDENTICAL) reduce 64) ((T_IS_NOT_EQUAL) reduce 64) ((T_IS_NOT_IDENTICAL) reduce 64) ((T_IS_SMALLER_OR_EQUAL) reduce 64) ((T_LOGICAL_AND) reduce 64) ((T_LOGICAL_OR) reduce 64) ((T_LOGICAL_XOR) reduce 64) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 64) ((T_OBJECT_OPERATOR) reduce 64) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 64) ((T_POW) reduce 64) ((T_SL) reduce 64) ((T_SPACESHIP) reduce 64) ((T_SR) reduce 64) (("[") reduce 64) (("^") reduce 64) (("{") reduce 64) (("|") reduce 64) (("}") reduce 64)) 4988 ((("%") reduce 46) (("(") reduce 46) (("*") reduce 46) (("+") reduce 46) ((",") reduce 46) (("-") reduce 46) ((".") reduce 46) (("/") reduce 46) (("<") reduce 46) ((">") reduce 46) (("?") reduce 46) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_BOOLEAN_AND) reduce 46) ((T_BOOLEAN_OR) reduce 46) ((T_COALESCE) reduce 46) ((T_DOUBLE_ARROW) reduce 46) ((T_INSTANCEOF) reduce 46) ((T_IS_EQUAL) reduce 46) ((T_IS_GREATER_OR_EQUAL) reduce 46) ((T_IS_IDENTICAL) reduce 46) ((T_IS_NOT_EQUAL) reduce 46) ((T_IS_NOT_IDENTICAL) reduce 46) ((T_IS_SMALLER_OR_EQUAL) reduce 46) ((T_LOGICAL_AND) reduce 46) ((T_LOGICAL_OR) reduce 46) ((T_LOGICAL_XOR) reduce 46) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 46) ((T_OBJECT_OPERATOR) reduce 46) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 46) ((T_POW) reduce 46) ((T_SL) reduce 46) ((T_SPACESHIP) reduce 46) ((T_SR) reduce 46) (("[") reduce 46) (("^") reduce 46) (("{") reduce 46) (("|") reduce 46) (("}") reduce 46)) 4989 ((("%") reduce 8) (("(") reduce 8) (("*") reduce 8) (("+") reduce 8) ((",") reduce 8) (("-") reduce 8) ((".") reduce 8) (("/") reduce 8) (("<") reduce 8) ((">") reduce 8) (("?") reduce 8) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_BOOLEAN_AND) reduce 8) ((T_BOOLEAN_OR) reduce 8) ((T_COALESCE) reduce 8) ((T_DOUBLE_ARROW) reduce 8) ((T_INSTANCEOF) reduce 8) ((T_IS_EQUAL) reduce 8) ((T_IS_GREATER_OR_EQUAL) reduce 8) ((T_IS_IDENTICAL) reduce 8) ((T_IS_NOT_EQUAL) reduce 8) ((T_IS_NOT_IDENTICAL) reduce 8) ((T_IS_SMALLER_OR_EQUAL) reduce 8) ((T_LOGICAL_AND) reduce 8) ((T_LOGICAL_OR) reduce 8) ((T_LOGICAL_XOR) reduce 8) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 8) ((T_OBJECT_OPERATOR) reduce 8) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 8) ((T_POW) reduce 8) ((T_SL) reduce 8) ((T_SPACESHIP) reduce 8) ((T_SR) reduce 8) (("[") reduce 8) (("^") reduce 8) (("{") reduce 8) (("|") reduce 8) (("}") reduce 8)) 4990 ((("%") reduce 6) (("(") reduce 6) (("*") reduce 6) (("+") reduce 6) ((",") reduce 6) (("-") reduce 6) ((".") reduce 6) (("/") reduce 6) (("<") reduce 6) ((">") reduce 6) (("?") reduce 6) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_BOOLEAN_AND) reduce 6) ((T_BOOLEAN_OR) reduce 6) ((T_COALESCE) reduce 6) ((T_DOUBLE_ARROW) reduce 6) ((T_INSTANCEOF) reduce 6) ((T_IS_EQUAL) reduce 6) ((T_IS_GREATER_OR_EQUAL) reduce 6) ((T_IS_IDENTICAL) reduce 6) ((T_IS_NOT_EQUAL) reduce 6) ((T_IS_NOT_IDENTICAL) reduce 6) ((T_IS_SMALLER_OR_EQUAL) reduce 6) ((T_LOGICAL_AND) reduce 6) ((T_LOGICAL_OR) reduce 6) ((T_LOGICAL_XOR) reduce 6) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 6) ((T_OBJECT_OPERATOR) reduce 6) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 6) ((T_POW) reduce 6) ((T_SL) reduce 6) ((T_SPACESHIP) reduce 6) ((T_SR) reduce 6) (("[") reduce 6) (("^") reduce 6) (("{") reduce 6) (("|") reduce 6) (("}") reduce 6)) 4991 ((("%") reduce 7) (("(") reduce 7) (("*") reduce 7) (("+") reduce 7) ((",") reduce 7) (("-") reduce 7) ((".") reduce 7) (("/") reduce 7) (("<") reduce 7) ((">") reduce 7) (("?") reduce 7) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_BOOLEAN_AND) reduce 7) ((T_BOOLEAN_OR) reduce 7) ((T_COALESCE) reduce 7) ((T_DOUBLE_ARROW) reduce 7) ((T_INSTANCEOF) reduce 7) ((T_IS_EQUAL) reduce 7) ((T_IS_GREATER_OR_EQUAL) reduce 7) ((T_IS_IDENTICAL) reduce 7) ((T_IS_NOT_EQUAL) reduce 7) ((T_IS_NOT_IDENTICAL) reduce 7) ((T_IS_SMALLER_OR_EQUAL) reduce 7) ((T_LOGICAL_AND) reduce 7) ((T_LOGICAL_OR) reduce 7) ((T_LOGICAL_XOR) reduce 7) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 7) ((T_OBJECT_OPERATOR) reduce 7) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 7) ((T_POW) reduce 7) ((T_SL) reduce 7) ((T_SPACESHIP) reduce 7) ((T_SR) reduce 7) (("[") reduce 7) (("^") reduce 7) (("{") reduce 7) (("|") reduce 7) (("}") reduce 7)) 4992 ((("%") reduce 69) (("(") reduce 69) (("*") reduce 69) (("+") reduce 69) ((",") reduce 69) (("-") reduce 69) ((".") reduce 69) (("/") reduce 69) (("<") reduce 69) ((">") reduce 69) (("?") reduce 69) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_BOOLEAN_AND) reduce 69) ((T_BOOLEAN_OR) reduce 69) ((T_COALESCE) reduce 69) ((T_DOUBLE_ARROW) reduce 69) ((T_INSTANCEOF) reduce 69) ((T_IS_EQUAL) reduce 69) ((T_IS_GREATER_OR_EQUAL) reduce 69) ((T_IS_IDENTICAL) reduce 69) ((T_IS_NOT_EQUAL) reduce 69) ((T_IS_NOT_IDENTICAL) reduce 69) ((T_IS_SMALLER_OR_EQUAL) reduce 69) ((T_LOGICAL_AND) reduce 69) ((T_LOGICAL_OR) reduce 69) ((T_LOGICAL_XOR) reduce 69) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 69) ((T_OBJECT_OPERATOR) reduce 69) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 69) ((T_POW) reduce 69) ((T_SL) reduce 69) ((T_SPACESHIP) reduce 69) ((T_SR) reduce 69) (("[") reduce 69) (("^") reduce 69) (("{") reduce 69) (("|") reduce 69) (("}") reduce 69)) 4993 ((("%") reduce 63) (("(") reduce 63) (("*") reduce 63) (("+") reduce 63) ((",") reduce 63) (("-") reduce 63) ((".") reduce 63) (("/") reduce 63) (("<") reduce 63) ((">") reduce 63) (("?") reduce 63) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_BOOLEAN_AND) reduce 63) ((T_BOOLEAN_OR) reduce 63) ((T_COALESCE) reduce 63) ((T_DOUBLE_ARROW) reduce 63) ((T_INSTANCEOF) reduce 63) ((T_IS_EQUAL) reduce 63) ((T_IS_GREATER_OR_EQUAL) reduce 63) ((T_IS_IDENTICAL) reduce 63) ((T_IS_NOT_EQUAL) reduce 63) ((T_IS_NOT_IDENTICAL) reduce 63) ((T_IS_SMALLER_OR_EQUAL) reduce 63) ((T_LOGICAL_AND) reduce 63) ((T_LOGICAL_OR) reduce 63) ((T_LOGICAL_XOR) reduce 63) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 63) ((T_OBJECT_OPERATOR) reduce 63) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 63) ((T_POW) reduce 63) ((T_SL) reduce 63) ((T_SPACESHIP) reduce 63) ((T_SR) reduce 63) (("[") reduce 63) (("^") reduce 63) (("{") reduce 63) (("|") reduce 63) (("}") reduce 63)) 4994 ((("%") reduce 56) (("(") reduce 56) (("*") reduce 56) (("+") reduce 56) ((",") reduce 56) (("-") reduce 56) ((".") reduce 56) (("/") reduce 56) (("<") reduce 56) ((">") reduce 56) (("?") reduce 56) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_BOOLEAN_AND) reduce 56) ((T_BOOLEAN_OR) reduce 56) ((T_COALESCE) reduce 56) ((T_DOUBLE_ARROW) reduce 56) ((T_INSTANCEOF) reduce 56) ((T_IS_EQUAL) reduce 56) ((T_IS_GREATER_OR_EQUAL) reduce 56) ((T_IS_IDENTICAL) reduce 56) ((T_IS_NOT_EQUAL) reduce 56) ((T_IS_NOT_IDENTICAL) reduce 56) ((T_IS_SMALLER_OR_EQUAL) reduce 56) ((T_LOGICAL_AND) reduce 56) ((T_LOGICAL_OR) reduce 56) ((T_LOGICAL_XOR) reduce 56) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 56) ((T_OBJECT_OPERATOR) reduce 56) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 56) ((T_POW) reduce 56) ((T_SL) reduce 56) ((T_SPACESHIP) reduce 56) ((T_SR) reduce 56) (("[") reduce 56) (("^") reduce 56) (("{") reduce 56) (("|") reduce 56) (("}") reduce 56)) 4995 ((("%") reduce 10) (("(") reduce 10) (("*") reduce 10) (("+") reduce 10) ((",") reduce 10) (("-") reduce 10) ((".") reduce 10) (("/") reduce 10) (("<") reduce 10) ((">") reduce 10) (("?") reduce 10) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_BOOLEAN_AND) reduce 10) ((T_BOOLEAN_OR) reduce 10) ((T_COALESCE) reduce 10) ((T_DOUBLE_ARROW) reduce 10) ((T_INSTANCEOF) reduce 10) ((T_IS_EQUAL) reduce 10) ((T_IS_GREATER_OR_EQUAL) reduce 10) ((T_IS_IDENTICAL) reduce 10) ((T_IS_NOT_EQUAL) reduce 10) ((T_IS_NOT_IDENTICAL) reduce 10) ((T_IS_SMALLER_OR_EQUAL) reduce 10) ((T_LOGICAL_AND) reduce 10) ((T_LOGICAL_OR) reduce 10) ((T_LOGICAL_XOR) reduce 10) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 10) ((T_OBJECT_OPERATOR) reduce 10) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 10) ((T_POW) reduce 10) ((T_SL) reduce 10) ((T_SPACESHIP) reduce 10) ((T_SR) reduce 10) (("[") reduce 10) (("^") reduce 10) (("{") reduce 10) (("|") reduce 10) (("}") reduce 10)) 4996 ((("%") reduce 67) (("(") reduce 67) (("*") reduce 67) (("+") reduce 67) ((",") reduce 67) (("-") reduce 67) ((".") reduce 67) (("/") reduce 67) (("<") reduce 67) ((">") reduce 67) (("?") reduce 67) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_BOOLEAN_AND) reduce 67) ((T_BOOLEAN_OR) reduce 67) ((T_COALESCE) reduce 67) ((T_DOUBLE_ARROW) reduce 67) ((T_INSTANCEOF) reduce 67) ((T_IS_EQUAL) reduce 67) ((T_IS_GREATER_OR_EQUAL) reduce 67) ((T_IS_IDENTICAL) reduce 67) ((T_IS_NOT_EQUAL) reduce 67) ((T_IS_NOT_IDENTICAL) reduce 67) ((T_IS_SMALLER_OR_EQUAL) reduce 67) ((T_LOGICAL_AND) reduce 67) ((T_LOGICAL_OR) reduce 67) ((T_LOGICAL_XOR) reduce 67) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 67) ((T_OBJECT_OPERATOR) reduce 67) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 67) ((T_POW) reduce 67) ((T_SL) reduce 67) ((T_SPACESHIP) reduce 67) ((T_SR) reduce 67) (("[") reduce 67) (("^") reduce 67) (("{") reduce 67) (("|") reduce 67) (("}") reduce 67)) 4997 ((("%") reduce 44) (("(") reduce 44) (("*") reduce 44) (("+") reduce 44) ((",") reduce 44) (("-") reduce 44) ((".") reduce 44) (("/") reduce 44) (("<") reduce 44) ((">") reduce 44) (("?") reduce 44) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_BOOLEAN_AND) reduce 44) ((T_BOOLEAN_OR) reduce 44) ((T_COALESCE) reduce 44) ((T_DOUBLE_ARROW) reduce 44) ((T_INSTANCEOF) reduce 44) ((T_IS_EQUAL) reduce 44) ((T_IS_GREATER_OR_EQUAL) reduce 44) ((T_IS_IDENTICAL) reduce 44) ((T_IS_NOT_EQUAL) reduce 44) ((T_IS_NOT_IDENTICAL) reduce 44) ((T_IS_SMALLER_OR_EQUAL) reduce 44) ((T_LOGICAL_AND) reduce 44) ((T_LOGICAL_OR) reduce 44) ((T_LOGICAL_XOR) reduce 44) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 44) ((T_OBJECT_OPERATOR) reduce 44) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 44) ((T_POW) reduce 44) ((T_SL) reduce 44) ((T_SPACESHIP) reduce 44) ((T_SR) reduce 44) (("[") reduce 44) (("^") reduce 44) (("{") reduce 44) (("|") reduce 44) (("}") reduce 44)) 4998 ((("%") reduce 75) (("(") reduce 75) (("*") reduce 75) (("+") reduce 75) ((",") reduce 75) (("-") reduce 75) ((".") reduce 75) (("/") reduce 75) (("<") reduce 75) ((">") reduce 75) (("?") reduce 75) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_BOOLEAN_AND) reduce 75) ((T_BOOLEAN_OR) reduce 75) ((T_COALESCE) reduce 75) ((T_DOUBLE_ARROW) reduce 75) ((T_INSTANCEOF) reduce 75) ((T_IS_EQUAL) reduce 75) ((T_IS_GREATER_OR_EQUAL) reduce 75) ((T_IS_IDENTICAL) reduce 75) ((T_IS_NOT_EQUAL) reduce 75) ((T_IS_NOT_IDENTICAL) reduce 75) ((T_IS_SMALLER_OR_EQUAL) reduce 75) ((T_LOGICAL_AND) reduce 75) ((T_LOGICAL_OR) reduce 75) ((T_LOGICAL_XOR) reduce 75) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 75) ((T_OBJECT_OPERATOR) reduce 75) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 75) ((T_POW) reduce 75) ((T_SL) reduce 75) ((T_SPACESHIP) reduce 75) ((T_SR) reduce 75) (("[") reduce 75) (("^") reduce 75) (("{") reduce 75) (("|") reduce 75) (("}") reduce 75)) 4999 ((("%") reduce 76) (("(") reduce 76) (("*") reduce 76) (("+") reduce 76) ((",") reduce 76) (("-") reduce 76) ((".") reduce 76) (("/") reduce 76) (("<") reduce 76) ((">") reduce 76) (("?") reduce 76) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_BOOLEAN_AND) reduce 76) ((T_BOOLEAN_OR) reduce 76) ((T_COALESCE) reduce 76) ((T_DOUBLE_ARROW) reduce 76) ((T_INSTANCEOF) reduce 76) ((T_IS_EQUAL) reduce 76) ((T_IS_GREATER_OR_EQUAL) reduce 76) ((T_IS_IDENTICAL) reduce 76) ((T_IS_NOT_EQUAL) reduce 76) ((T_IS_NOT_IDENTICAL) reduce 76) ((T_IS_SMALLER_OR_EQUAL) reduce 76) ((T_LOGICAL_AND) reduce 76) ((T_LOGICAL_OR) reduce 76) ((T_LOGICAL_XOR) reduce 76) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 76) ((T_OBJECT_OPERATOR) reduce 76) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 76) ((T_POW) reduce 76) ((T_SL) reduce 76) ((T_SPACESHIP) reduce 76) ((T_SR) reduce 76) (("[") reduce 76) (("^") reduce 76) (("{") reduce 76) (("|") reduce 76) (("}") reduce 76)) 5000 ((("%") reduce 77) (("(") reduce 77) (("*") reduce 77) (("+") reduce 77) ((",") reduce 77) (("-") reduce 77) ((".") reduce 77) (("/") reduce 77) (("<") reduce 77) ((">") reduce 77) (("?") reduce 77) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_BOOLEAN_AND) reduce 77) ((T_BOOLEAN_OR) reduce 77) ((T_COALESCE) reduce 77) ((T_DOUBLE_ARROW) reduce 77) ((T_INSTANCEOF) reduce 77) ((T_IS_EQUAL) reduce 77) ((T_IS_GREATER_OR_EQUAL) reduce 77) ((T_IS_IDENTICAL) reduce 77) ((T_IS_NOT_EQUAL) reduce 77) ((T_IS_NOT_IDENTICAL) reduce 77) ((T_IS_SMALLER_OR_EQUAL) reduce 77) ((T_LOGICAL_AND) reduce 77) ((T_LOGICAL_OR) reduce 77) ((T_LOGICAL_XOR) reduce 77) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 77) ((T_OBJECT_OPERATOR) reduce 77) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 77) ((T_POW) reduce 77) ((T_SL) reduce 77) ((T_SPACESHIP) reduce 77) ((T_SR) reduce 77) (("[") reduce 77) (("^") reduce 77) (("{") reduce 77) (("|") reduce 77) (("}") reduce 77)) 5001 ((("%") reduce 78) (("(") reduce 78) (("*") reduce 78) (("+") reduce 78) ((",") reduce 78) (("-") reduce 78) ((".") reduce 78) (("/") reduce 78) (("<") reduce 78) ((">") reduce 78) (("?") reduce 78) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_BOOLEAN_AND) reduce 78) ((T_BOOLEAN_OR) reduce 78) ((T_COALESCE) reduce 78) ((T_DOUBLE_ARROW) reduce 78) ((T_INSTANCEOF) reduce 78) ((T_IS_EQUAL) reduce 78) ((T_IS_GREATER_OR_EQUAL) reduce 78) ((T_IS_IDENTICAL) reduce 78) ((T_IS_NOT_EQUAL) reduce 78) ((T_IS_NOT_IDENTICAL) reduce 78) ((T_IS_SMALLER_OR_EQUAL) reduce 78) ((T_LOGICAL_AND) reduce 78) ((T_LOGICAL_OR) reduce 78) ((T_LOGICAL_XOR) reduce 78) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 78) ((T_OBJECT_OPERATOR) reduce 78) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 78) ((T_POW) reduce 78) ((T_SL) reduce 78) ((T_SPACESHIP) reduce 78) ((T_SR) reduce 78) (("[") reduce 78) (("^") reduce 78) (("{") reduce 78) (("|") reduce 78) (("}") reduce 78)) 5002 ((("%") reduce 4) (("(") reduce 4) (("*") reduce 4) (("+") reduce 4) ((",") reduce 4) (("-") reduce 4) ((".") reduce 4) (("/") reduce 4) (("<") reduce 4) ((">") reduce 4) (("?") reduce 4) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_BOOLEAN_AND) reduce 4) ((T_BOOLEAN_OR) reduce 4) ((T_COALESCE) reduce 4) ((T_DOUBLE_ARROW) reduce 4) ((T_INSTANCEOF) reduce 4) ((T_IS_EQUAL) reduce 4) ((T_IS_GREATER_OR_EQUAL) reduce 4) ((T_IS_IDENTICAL) reduce 4) ((T_IS_NOT_EQUAL) reduce 4) ((T_IS_NOT_IDENTICAL) reduce 4) ((T_IS_SMALLER_OR_EQUAL) reduce 4) ((T_LOGICAL_AND) reduce 4) ((T_LOGICAL_OR) reduce 4) ((T_LOGICAL_XOR) reduce 4) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 4) ((T_OBJECT_OPERATOR) reduce 4) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 4) ((T_POW) reduce 4) ((T_SL) reduce 4) ((T_SPACESHIP) reduce 4) ((T_SR) reduce 4) (("[") reduce 4) (("^") reduce 4) (("{") reduce 4) (("|") reduce 4) (("}") reduce 4)) 5003 ((("%") reduce 5) (("(") reduce 5) (("*") reduce 5) (("+") reduce 5) ((",") reduce 5) (("-") reduce 5) ((".") reduce 5) (("/") reduce 5) (("<") reduce 5) ((">") reduce 5) (("?") reduce 5) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_BOOLEAN_AND) reduce 5) ((T_BOOLEAN_OR) reduce 5) ((T_COALESCE) reduce 5) ((T_DOUBLE_ARROW) reduce 5) ((T_INSTANCEOF) reduce 5) ((T_IS_EQUAL) reduce 5) ((T_IS_GREATER_OR_EQUAL) reduce 5) ((T_IS_IDENTICAL) reduce 5) ((T_IS_NOT_EQUAL) reduce 5) ((T_IS_NOT_IDENTICAL) reduce 5) ((T_IS_SMALLER_OR_EQUAL) reduce 5) ((T_LOGICAL_AND) reduce 5) ((T_LOGICAL_OR) reduce 5) ((T_LOGICAL_XOR) reduce 5) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 5) ((T_OBJECT_OPERATOR) reduce 5) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 5) ((T_POW) reduce 5) ((T_SL) reduce 5) ((T_SPACESHIP) reduce 5) ((T_SR) reduce 5) (("[") reduce 5) (("^") reduce 5) (("{") reduce 5) (("|") reduce 5) (("}") reduce 5)) 5004 ((("%") reduce 43) (("(") reduce 43) (("*") reduce 43) (("+") reduce 43) ((",") reduce 43) (("-") reduce 43) ((".") reduce 43) (("/") reduce 43) (("<") reduce 43) ((">") reduce 43) (("?") reduce 43) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_BOOLEAN_AND) reduce 43) ((T_BOOLEAN_OR) reduce 43) ((T_COALESCE) reduce 43) ((T_DOUBLE_ARROW) reduce 43) ((T_INSTANCEOF) reduce 43) ((T_IS_EQUAL) reduce 43) ((T_IS_GREATER_OR_EQUAL) reduce 43) ((T_IS_IDENTICAL) reduce 43) ((T_IS_NOT_EQUAL) reduce 43) ((T_IS_NOT_IDENTICAL) reduce 43) ((T_IS_SMALLER_OR_EQUAL) reduce 43) ((T_LOGICAL_AND) reduce 43) ((T_LOGICAL_OR) reduce 43) ((T_LOGICAL_XOR) reduce 43) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 43) ((T_OBJECT_OPERATOR) reduce 43) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 43) ((T_POW) reduce 43) ((T_SL) reduce 43) ((T_SPACESHIP) reduce 43) ((T_SR) reduce 43) (("[") reduce 43) (("^") reduce 43) (("{") reduce 43) (("|") reduce 43) (("}") reduce 43)) 5005 ((("%") reduce 72) (("(") reduce 72) (("*") reduce 72) (("+") reduce 72) ((",") reduce 72) (("-") reduce 72) ((".") reduce 72) (("/") reduce 72) (("<") reduce 72) ((">") reduce 72) (("?") reduce 72) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_BOOLEAN_AND) reduce 72) ((T_BOOLEAN_OR) reduce 72) ((T_COALESCE) reduce 72) ((T_DOUBLE_ARROW) reduce 72) ((T_INSTANCEOF) reduce 72) ((T_IS_EQUAL) reduce 72) ((T_IS_GREATER_OR_EQUAL) reduce 72) ((T_IS_IDENTICAL) reduce 72) ((T_IS_NOT_EQUAL) reduce 72) ((T_IS_NOT_IDENTICAL) reduce 72) ((T_IS_SMALLER_OR_EQUAL) reduce 72) ((T_LOGICAL_AND) reduce 72) ((T_LOGICAL_OR) reduce 72) ((T_LOGICAL_XOR) reduce 72) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 72) ((T_OBJECT_OPERATOR) reduce 72) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 72) ((T_POW) reduce 72) ((T_SL) reduce 72) ((T_SPACESHIP) reduce 72) ((T_SR) reduce 72) (("[") reduce 72) (("^") reduce 72) (("{") reduce 72) (("|") reduce 72) (("}") reduce 72)) 5006 ((("%") reduce 81) (("(") reduce 81) (("*") reduce 81) (("+") reduce 81) ((",") reduce 81) (("-") reduce 81) ((".") reduce 81) (("/") reduce 81) (("<") reduce 81) ((">") reduce 81) (("?") reduce 81) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_BOOLEAN_AND) reduce 81) ((T_BOOLEAN_OR) reduce 81) ((T_COALESCE) reduce 81) ((T_DOUBLE_ARROW) reduce 81) ((T_INSTANCEOF) reduce 81) ((T_IS_EQUAL) reduce 81) ((T_IS_GREATER_OR_EQUAL) reduce 81) ((T_IS_IDENTICAL) reduce 81) ((T_IS_NOT_EQUAL) reduce 81) ((T_IS_NOT_IDENTICAL) reduce 81) ((T_IS_SMALLER_OR_EQUAL) reduce 81) ((T_LOGICAL_AND) reduce 81) ((T_LOGICAL_OR) reduce 81) ((T_LOGICAL_XOR) reduce 81) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 81) ((T_OBJECT_OPERATOR) reduce 81) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 81) ((T_POW) reduce 81) ((T_SL) reduce 81) ((T_SPACESHIP) reduce 81) ((T_SR) reduce 81) (("[") reduce 81) (("^") reduce 81) (("{") reduce 81) (("|") reduce 81) (("}") reduce 81)) 5007 ((("%") reduce 47) (("(") reduce 47) (("*") reduce 47) (("+") reduce 47) ((",") reduce 47) (("-") reduce 47) ((".") reduce 47) (("/") reduce 47) (("<") reduce 47) ((">") reduce 47) (("?") reduce 47) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_BOOLEAN_AND) reduce 47) ((T_BOOLEAN_OR) reduce 47) ((T_COALESCE) reduce 47) ((T_DOUBLE_ARROW) reduce 47) ((T_INSTANCEOF) reduce 47) ((T_IS_EQUAL) reduce 47) ((T_IS_GREATER_OR_EQUAL) reduce 47) ((T_IS_IDENTICAL) reduce 47) ((T_IS_NOT_EQUAL) reduce 47) ((T_IS_NOT_IDENTICAL) reduce 47) ((T_IS_SMALLER_OR_EQUAL) reduce 47) ((T_LOGICAL_AND) reduce 47) ((T_LOGICAL_OR) reduce 47) ((T_LOGICAL_XOR) reduce 47) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 47) ((T_OBJECT_OPERATOR) reduce 47) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 47) ((T_POW) reduce 47) ((T_SL) reduce 47) ((T_SPACESHIP) reduce 47) ((T_SR) reduce 47) (("[") reduce 47) (("^") reduce 47) (("{") reduce 47) (("|") reduce 47) (("}") reduce 47)) 5008 ((("%") reduce 31) (("(") reduce 31) (("*") reduce 31) (("+") reduce 31) ((",") reduce 31) (("-") reduce 31) ((".") reduce 31) (("/") reduce 31) (("<") reduce 31) ((">") reduce 31) (("?") reduce 31) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_BOOLEAN_AND) reduce 31) ((T_BOOLEAN_OR) reduce 31) ((T_COALESCE) reduce 31) ((T_DOUBLE_ARROW) reduce 31) ((T_INSTANCEOF) reduce 31) ((T_IS_EQUAL) reduce 31) ((T_IS_GREATER_OR_EQUAL) reduce 31) ((T_IS_IDENTICAL) reduce 31) ((T_IS_NOT_EQUAL) reduce 31) ((T_IS_NOT_IDENTICAL) reduce 31) ((T_IS_SMALLER_OR_EQUAL) reduce 31) ((T_LOGICAL_AND) reduce 31) ((T_LOGICAL_OR) reduce 31) ((T_LOGICAL_XOR) reduce 31) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 31) ((T_OBJECT_OPERATOR) reduce 31) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 31) ((T_POW) reduce 31) ((T_SL) reduce 31) ((T_SPACESHIP) reduce 31) ((T_SR) reduce 31) (("[") reduce 31) (("^") reduce 31) (("{") reduce 31) (("|") reduce 31) (("}") reduce 31)) 5009 ((("%") reduce 57) (("(") reduce 57) (("*") reduce 57) (("+") reduce 57) ((",") reduce 57) (("-") reduce 57) ((".") reduce 57) (("/") reduce 57) (("<") reduce 57) ((">") reduce 57) (("?") reduce 57) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_BOOLEAN_AND) reduce 57) ((T_BOOLEAN_OR) reduce 57) ((T_COALESCE) reduce 57) ((T_DOUBLE_ARROW) reduce 57) ((T_INSTANCEOF) reduce 57) ((T_IS_EQUAL) reduce 57) ((T_IS_GREATER_OR_EQUAL) reduce 57) ((T_IS_IDENTICAL) reduce 57) ((T_IS_NOT_EQUAL) reduce 57) ((T_IS_NOT_IDENTICAL) reduce 57) ((T_IS_SMALLER_OR_EQUAL) reduce 57) ((T_LOGICAL_AND) reduce 57) ((T_LOGICAL_OR) reduce 57) ((T_LOGICAL_XOR) reduce 57) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 57) ((T_OBJECT_OPERATOR) reduce 57) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 57) ((T_POW) reduce 57) ((T_SL) reduce 57) ((T_SPACESHIP) reduce 57) ((T_SR) reduce 57) (("[") reduce 57) (("^") reduce 57) (("{") reduce 57) (("|") reduce 57) (("}") reduce 57)) 5010 ((("%") reduce 61) (("(") reduce 61) (("*") reduce 61) (("+") reduce 61) ((",") reduce 61) (("-") reduce 61) ((".") reduce 61) (("/") reduce 61) (("<") reduce 61) ((">") reduce 61) (("?") reduce 61) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_BOOLEAN_AND) reduce 61) ((T_BOOLEAN_OR) reduce 61) ((T_COALESCE) reduce 61) ((T_DOUBLE_ARROW) reduce 61) ((T_INSTANCEOF) reduce 61) ((T_IS_EQUAL) reduce 61) ((T_IS_GREATER_OR_EQUAL) reduce 61) ((T_IS_IDENTICAL) reduce 61) ((T_IS_NOT_EQUAL) reduce 61) ((T_IS_NOT_IDENTICAL) reduce 61) ((T_IS_SMALLER_OR_EQUAL) reduce 61) ((T_LOGICAL_AND) reduce 61) ((T_LOGICAL_OR) reduce 61) ((T_LOGICAL_XOR) reduce 61) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 61) ((T_OBJECT_OPERATOR) reduce 61) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 61) ((T_POW) reduce 61) ((T_SL) reduce 61) ((T_SPACESHIP) reduce 61) ((T_SR) reduce 61) (("[") reduce 61) (("^") reduce 61) (("{") reduce 61) (("|") reduce 61) (("}") reduce 61)) 5011 ((("%") reduce 28) (("(") reduce 28) (("*") reduce 28) (("+") reduce 28) ((",") reduce 28) (("-") reduce 28) ((".") reduce 28) (("/") reduce 28) (("<") reduce 28) ((">") reduce 28) (("?") reduce 28) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_BOOLEAN_AND) reduce 28) ((T_BOOLEAN_OR) reduce 28) ((T_COALESCE) reduce 28) ((T_DOUBLE_ARROW) reduce 28) ((T_INSTANCEOF) reduce 28) ((T_IS_EQUAL) reduce 28) ((T_IS_GREATER_OR_EQUAL) reduce 28) ((T_IS_IDENTICAL) reduce 28) ((T_IS_NOT_EQUAL) reduce 28) ((T_IS_NOT_IDENTICAL) reduce 28) ((T_IS_SMALLER_OR_EQUAL) reduce 28) ((T_LOGICAL_AND) reduce 28) ((T_LOGICAL_OR) reduce 28) ((T_LOGICAL_XOR) reduce 28) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 28) ((T_OBJECT_OPERATOR) reduce 28) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 28) ((T_POW) reduce 28) ((T_SL) reduce 28) ((T_SPACESHIP) reduce 28) ((T_SR) reduce 28) (("[") reduce 28) (("^") reduce 28) (("{") reduce 28) (("|") reduce 28) (("}") reduce 28)) 5012 ((("%") reduce 36) (("(") reduce 36) (("*") reduce 36) (("+") reduce 36) ((",") reduce 36) (("-") reduce 36) ((".") reduce 36) (("/") reduce 36) (("<") reduce 36) ((">") reduce 36) (("?") reduce 36) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_BOOLEAN_AND) reduce 36) ((T_BOOLEAN_OR) reduce 36) ((T_COALESCE) reduce 36) ((T_DOUBLE_ARROW) reduce 36) ((T_INSTANCEOF) reduce 36) ((T_IS_EQUAL) reduce 36) ((T_IS_GREATER_OR_EQUAL) reduce 36) ((T_IS_IDENTICAL) reduce 36) ((T_IS_NOT_EQUAL) reduce 36) ((T_IS_NOT_IDENTICAL) reduce 36) ((T_IS_SMALLER_OR_EQUAL) reduce 36) ((T_LOGICAL_AND) reduce 36) ((T_LOGICAL_OR) reduce 36) ((T_LOGICAL_XOR) reduce 36) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 36) ((T_OBJECT_OPERATOR) reduce 36) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 36) ((T_POW) reduce 36) ((T_SL) reduce 36) ((T_SPACESHIP) reduce 36) ((T_SR) reduce 36) (("[") reduce 36) (("^") reduce 36) (("{") reduce 36) (("|") reduce 36) (("}") reduce 36)) 5013 ((("%") reduce 32) (("(") reduce 32) (("*") reduce 32) (("+") reduce 32) ((",") reduce 32) (("-") reduce 32) ((".") reduce 32) (("/") reduce 32) (("<") reduce 32) ((">") reduce 32) (("?") reduce 32) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_BOOLEAN_AND) reduce 32) ((T_BOOLEAN_OR) reduce 32) ((T_COALESCE) reduce 32) ((T_DOUBLE_ARROW) reduce 32) ((T_INSTANCEOF) reduce 32) ((T_IS_EQUAL) reduce 32) ((T_IS_GREATER_OR_EQUAL) reduce 32) ((T_IS_IDENTICAL) reduce 32) ((T_IS_NOT_EQUAL) reduce 32) ((T_IS_NOT_IDENTICAL) reduce 32) ((T_IS_SMALLER_OR_EQUAL) reduce 32) ((T_LOGICAL_AND) reduce 32) ((T_LOGICAL_OR) reduce 32) ((T_LOGICAL_XOR) reduce 32) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 32) ((T_OBJECT_OPERATOR) reduce 32) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 32) ((T_POW) reduce 32) ((T_SL) reduce 32) ((T_SPACESHIP) reduce 32) ((T_SR) reduce 32) (("[") reduce 32) (("^") reduce 32) (("{") reduce 32) (("|") reduce 32) (("}") reduce 32)) 5014 ((("%") reduce 35) (("(") reduce 35) (("*") reduce 35) (("+") reduce 35) ((",") reduce 35) (("-") reduce 35) ((".") reduce 35) (("/") reduce 35) (("<") reduce 35) ((">") reduce 35) (("?") reduce 35) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_BOOLEAN_AND) reduce 35) ((T_BOOLEAN_OR) reduce 35) ((T_COALESCE) reduce 35) ((T_DOUBLE_ARROW) reduce 35) ((T_INSTANCEOF) reduce 35) ((T_IS_EQUAL) reduce 35) ((T_IS_GREATER_OR_EQUAL) reduce 35) ((T_IS_IDENTICAL) reduce 35) ((T_IS_NOT_EQUAL) reduce 35) ((T_IS_NOT_IDENTICAL) reduce 35) ((T_IS_SMALLER_OR_EQUAL) reduce 35) ((T_LOGICAL_AND) reduce 35) ((T_LOGICAL_OR) reduce 35) ((T_LOGICAL_XOR) reduce 35) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 35) ((T_OBJECT_OPERATOR) reduce 35) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 35) ((T_POW) reduce 35) ((T_SL) reduce 35) ((T_SPACESHIP) reduce 35) ((T_SR) reduce 35) (("[") reduce 35) (("^") reduce 35) (("{") reduce 35) (("|") reduce 35) (("}") reduce 35)) 5015 ((("%") reduce 19) (("(") reduce 19) (("*") reduce 19) (("+") reduce 19) ((",") reduce 19) (("-") reduce 19) ((".") reduce 19) (("/") reduce 19) (("<") reduce 19) ((">") reduce 19) (("?") reduce 19) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_BOOLEAN_AND) reduce 19) ((T_BOOLEAN_OR) reduce 19) ((T_COALESCE) reduce 19) ((T_DOUBLE_ARROW) reduce 19) ((T_INSTANCEOF) reduce 19) ((T_IS_EQUAL) reduce 19) ((T_IS_GREATER_OR_EQUAL) reduce 19) ((T_IS_IDENTICAL) reduce 19) ((T_IS_NOT_EQUAL) reduce 19) ((T_IS_NOT_IDENTICAL) reduce 19) ((T_IS_SMALLER_OR_EQUAL) reduce 19) ((T_LOGICAL_AND) reduce 19) ((T_LOGICAL_OR) reduce 19) ((T_LOGICAL_XOR) reduce 19) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 19) ((T_OBJECT_OPERATOR) reduce 19) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 19) ((T_POW) reduce 19) ((T_SL) reduce 19) ((T_SPACESHIP) reduce 19) ((T_SR) reduce 19) (("[") reduce 19) (("^") reduce 19) (("{") reduce 19) (("|") reduce 19) (("}") reduce 19)) 5016 ((("%") reduce 45) (("(") reduce 45) (("*") reduce 45) (("+") reduce 45) ((",") reduce 45) (("-") reduce 45) ((".") reduce 45) (("/") reduce 45) (("<") reduce 45) ((">") reduce 45) (("?") reduce 45) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_BOOLEAN_AND) reduce 45) ((T_BOOLEAN_OR) reduce 45) ((T_COALESCE) reduce 45) ((T_DOUBLE_ARROW) reduce 45) ((T_INSTANCEOF) reduce 45) ((T_IS_EQUAL) reduce 45) ((T_IS_GREATER_OR_EQUAL) reduce 45) ((T_IS_IDENTICAL) reduce 45) ((T_IS_NOT_EQUAL) reduce 45) ((T_IS_NOT_IDENTICAL) reduce 45) ((T_IS_SMALLER_OR_EQUAL) reduce 45) ((T_LOGICAL_AND) reduce 45) ((T_LOGICAL_OR) reduce 45) ((T_LOGICAL_XOR) reduce 45) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 45) ((T_OBJECT_OPERATOR) reduce 45) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 45) ((T_POW) reduce 45) ((T_SL) reduce 45) ((T_SPACESHIP) reduce 45) ((T_SR) reduce 45) (("[") reduce 45) (("^") reduce 45) (("{") reduce 45) (("|") reduce 45) (("}") reduce 45)) 5017 ((("%") reduce 504) (("(") reduce 541) (("*") reduce 504) (("+") reduce 504) ((",") reduce 504) (("-") reduce 504) ((".") reduce 504) (("/") reduce 504) (("<") reduce 504) ((">") reduce 504) (("?") reduce 504) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_BOOLEAN_AND) reduce 504) ((T_BOOLEAN_OR) reduce 504) ((T_COALESCE) reduce 504) ((T_DOUBLE_ARROW) reduce 504) ((T_INSTANCEOF) reduce 504) ((T_IS_EQUAL) reduce 504) ((T_IS_GREATER_OR_EQUAL) reduce 504) ((T_IS_IDENTICAL) reduce 504) ((T_IS_NOT_EQUAL) reduce 504) ((T_IS_NOT_IDENTICAL) reduce 504) ((T_IS_SMALLER_OR_EQUAL) reduce 504) ((T_LOGICAL_AND) reduce 504) ((T_LOGICAL_OR) reduce 504) ((T_LOGICAL_XOR) reduce 504) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 504) ((T_OBJECT_OPERATOR) reduce 504) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 504) ((T_POW) reduce 504) ((T_SL) reduce 504) ((T_SPACESHIP) reduce 504) ((T_SR) reduce 504) (("[") reduce 504) (("^") reduce 504) (("{") reduce 504) (("|") reduce 504) (("}") reduce 504)) 5019 ((("%") reduce 71) (("(") reduce 71) (("*") reduce 71) (("+") reduce 71) ((",") reduce 71) (("-") reduce 71) ((".") reduce 71) (("/") reduce 71) (("<") reduce 71) ((">") reduce 71) (("?") reduce 71) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_BOOLEAN_AND) reduce 71) ((T_BOOLEAN_OR) reduce 71) ((T_COALESCE) reduce 71) ((T_DOUBLE_ARROW) reduce 71) ((T_INSTANCEOF) reduce 71) ((T_IS_EQUAL) reduce 71) ((T_IS_GREATER_OR_EQUAL) reduce 71) ((T_IS_IDENTICAL) reduce 71) ((T_IS_NOT_EQUAL) reduce 71) ((T_IS_NOT_IDENTICAL) reduce 71) ((T_IS_SMALLER_OR_EQUAL) reduce 71) ((T_LOGICAL_AND) reduce 71) ((T_LOGICAL_OR) reduce 71) ((T_LOGICAL_XOR) reduce 71) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 71) ((T_OBJECT_OPERATOR) reduce 71) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 71) ((T_POW) reduce 71) ((T_SL) reduce 71) ((T_SPACESHIP) reduce 71) ((T_SR) reduce 71) (("[") reduce 71) (("^") reduce 71) (("{") reduce 71) (("|") reduce 71) (("}") reduce 71)) 5020 ((("%") reduce 82) (("(") reduce 82) (("*") reduce 82) (("+") reduce 82) ((",") reduce 82) (("-") reduce 82) ((".") reduce 82) (("/") reduce 82) (("<") reduce 82) ((">") reduce 82) (("?") reduce 82) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_BOOLEAN_AND) reduce 82) ((T_BOOLEAN_OR) reduce 82) ((T_COALESCE) reduce 82) ((T_DOUBLE_ARROW) reduce 82) ((T_INSTANCEOF) reduce 82) ((T_IS_EQUAL) reduce 82) ((T_IS_GREATER_OR_EQUAL) reduce 82) ((T_IS_IDENTICAL) reduce 82) ((T_IS_NOT_EQUAL) reduce 82) ((T_IS_NOT_IDENTICAL) reduce 82) ((T_IS_SMALLER_OR_EQUAL) reduce 82) ((T_LOGICAL_AND) reduce 82) ((T_LOGICAL_OR) reduce 82) ((T_LOGICAL_XOR) reduce 82) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 82) ((T_OBJECT_OPERATOR) reduce 82) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 82) ((T_POW) reduce 82) ((T_SL) reduce 82) ((T_SPACESHIP) reduce 82) ((T_SR) reduce 82) (("[") reduce 82) (("^") reduce 82) (("{") reduce 82) (("|") reduce 82) (("}") reduce 82)) 5021 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) ((",") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) (("<") reduce 533) (("=") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AND_EQUAL) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_COALESCE_EQUAL) reduce 533) ((T_CONCAT_EQUAL) reduce 533) ((T_DEC) reduce 533) ((T_DIV_EQUAL) reduce 533) ((T_DOUBLE_ARROW) reduce 533) ((T_INC) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_MINUS_EQUAL) reduce 533) ((T_MOD_EQUAL) reduce 533) ((T_MUL_EQUAL) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_OR_EQUAL) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_PLUS_EQUAL) reduce 533) ((T_POW) reduce 533) ((T_POW_EQUAL) reduce 533) ((T_SL) reduce 533) ((T_SL_EQUAL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) ((T_SR_EQUAL) reduce 533) ((T_XOR_EQUAL) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533) (("}") reduce 533)) 5024 ((("%") reduce 506) (("(") reduce 542) (("*") reduce 506) (("+") reduce 506) ((",") reduce 506) (("-") reduce 506) ((".") reduce 506) (("/") reduce 506) (("<") reduce 506) ((">") reduce 506) (("?") reduce 506) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_BOOLEAN_AND) reduce 506) ((T_BOOLEAN_OR) reduce 506) ((T_COALESCE) reduce 506) ((T_DOUBLE_ARROW) reduce 506) ((T_INSTANCEOF) reduce 506) ((T_IS_EQUAL) reduce 506) ((T_IS_GREATER_OR_EQUAL) reduce 506) ((T_IS_IDENTICAL) reduce 506) ((T_IS_NOT_EQUAL) reduce 506) ((T_IS_NOT_IDENTICAL) reduce 506) ((T_IS_SMALLER_OR_EQUAL) reduce 506) ((T_LOGICAL_AND) reduce 506) ((T_LOGICAL_OR) reduce 506) ((T_LOGICAL_XOR) reduce 506) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 506) ((T_OBJECT_OPERATOR) reduce 506) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 506) ((T_POW) reduce 506) ((T_SL) reduce 506) ((T_SPACESHIP) reduce 506) ((T_SR) reduce 506) (("[") reduce 506) (("^") reduce 506) (("{") reduce 506) (("|") reduce 506) (("}") reduce 506)) 5026 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) ((",") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) (("<") reduce 468) (("=") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AND_EQUAL) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_COALESCE_EQUAL) reduce 468) ((T_CONCAT_EQUAL) reduce 468) ((T_DEC) reduce 468) ((T_DIV_EQUAL) reduce 468) ((T_DOUBLE_ARROW) reduce 468) ((T_INC) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_MINUS_EQUAL) reduce 468) ((T_MOD_EQUAL) reduce 468) ((T_MUL_EQUAL) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_OR_EQUAL) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_PLUS_EQUAL) reduce 468) ((T_POW) reduce 468) ((T_POW_EQUAL) reduce 468) ((T_SL) reduce 468) ((T_SL_EQUAL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) ((T_SR_EQUAL) reduce 468) ((T_XOR_EQUAL) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468) (("}") reduce 468)) 5027 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) ((",") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) (("=") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AND_EQUAL) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_COALESCE_EQUAL) reduce 288) ((T_CONCAT_EQUAL) reduce 288) ((T_DEC) reduce 288) ((T_DIV_EQUAL) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INC) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_MINUS_EQUAL) reduce 288) ((T_MOD_EQUAL) reduce 288) ((T_MUL_EQUAL) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_OR_EQUAL) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_PLUS_EQUAL) reduce 288) ((T_POW) reduce 288) ((T_POW_EQUAL) reduce 288) ((T_SL) reduce 288) ((T_SL_EQUAL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) ((T_SR_EQUAL) reduce 288) ((T_XOR_EQUAL) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288) (("}") reduce 288)) 5031 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) ((",") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) (("=") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AND_EQUAL) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_COALESCE_EQUAL) reduce 289) ((T_CONCAT_EQUAL) reduce 289) ((T_DEC) reduce 289) ((T_DIV_EQUAL) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INC) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_MINUS_EQUAL) reduce 289) ((T_MOD_EQUAL) reduce 289) ((T_MUL_EQUAL) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_OR_EQUAL) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_PLUS_EQUAL) reduce 289) ((T_POW) reduce 289) ((T_POW_EQUAL) reduce 289) ((T_SL) reduce 289) ((T_SL_EQUAL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) ((T_SR_EQUAL) reduce 289) ((T_XOR_EQUAL) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289) (("}") reduce 289)) 5032 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) ((",") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) (("=") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AND_EQUAL) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_COALESCE_EQUAL) reduce 290) ((T_CONCAT_EQUAL) reduce 290) ((T_DEC) reduce 290) ((T_DIV_EQUAL) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INC) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_MINUS_EQUAL) reduce 290) ((T_MOD_EQUAL) reduce 290) ((T_MUL_EQUAL) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_OR_EQUAL) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_PLUS_EQUAL) reduce 290) ((T_POW) reduce 290) ((T_POW_EQUAL) reduce 290) ((T_SL) reduce 290) ((T_SL_EQUAL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) ((T_SR_EQUAL) reduce 290) ((T_XOR_EQUAL) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290) (("}") reduce 290)) 5037 ((("%") reduce 388) (("*") reduce 388) (("+") reduce 388) ((",") reduce 388) (("-") reduce 388) ((".") reduce 388) (("/") reduce 388) (("<") reduce 388) ((">") reduce 388) (("?") reduce 388) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_BOOLEAN_AND) reduce 388) ((T_BOOLEAN_OR) reduce 388) ((T_COALESCE) reduce 388) ((T_DOUBLE_ARROW) reduce 388) ((T_INSTANCEOF) reduce 388) ((T_IS_EQUAL) reduce 388) ((T_IS_GREATER_OR_EQUAL) reduce 388) ((T_IS_IDENTICAL) reduce 388) ((T_IS_NOT_EQUAL) reduce 388) ((T_IS_NOT_IDENTICAL) reduce 388) ((T_IS_SMALLER_OR_EQUAL) reduce 388) ((T_LOGICAL_AND) reduce 388) ((T_LOGICAL_OR) reduce 388) ((T_LOGICAL_XOR) reduce 388) ((T_POW) reduce 388) ((T_SL) reduce 388) ((T_SPACESHIP) reduce 388) ((T_SR) reduce 388) (("^") reduce 388) (("|") reduce 388) (("}") reduce 388)) 5039 ((("%") reduce 386) (("*") reduce 386) (("+") reduce 386) ((",") reduce 386) (("-") reduce 386) ((".") reduce 386) (("/") reduce 386) (("<") reduce 386) ((">") reduce 386) (("?") reduce 386) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_BOOLEAN_AND) reduce 386) ((T_BOOLEAN_OR) reduce 386) ((T_COALESCE) reduce 386) ((T_DOUBLE_ARROW) reduce 386) ((T_INSTANCEOF) reduce 386) ((T_IS_EQUAL) reduce 386) ((T_IS_GREATER_OR_EQUAL) reduce 386) ((T_IS_IDENTICAL) reduce 386) ((T_IS_NOT_EQUAL) reduce 386) ((T_IS_NOT_IDENTICAL) reduce 386) ((T_IS_SMALLER_OR_EQUAL) reduce 386) ((T_LOGICAL_AND) reduce 386) ((T_LOGICAL_OR) reduce 386) ((T_LOGICAL_XOR) reduce 386) ((T_POW) reduce 386) ((T_SL) reduce 386) ((T_SPACESHIP) reduce 386) ((T_SR) reduce 386) (("^") reduce 386) (("|") reduce 386) (("}") reduce 386)) 5049 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 382) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 382) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 382) ((T_LOGICAL_OR) reduce 382) ((T_LOGICAL_XOR) reduce 382) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 382)) 5050 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 384) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 384) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 384) ((T_LOGICAL_OR) reduce 384) ((T_LOGICAL_XOR) reduce 384) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 384)) 5051 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 383) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 383) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 383) ((T_LOGICAL_OR) reduce 383) ((T_LOGICAL_XOR) reduce 383) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 383)) 5052 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 376) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 376) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 376) ((T_LOGICAL_OR) reduce 376) ((T_LOGICAL_XOR) reduce 376) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 376)) 5053 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 373) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 373) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 373) ((T_LOGICAL_OR) reduce 373) ((T_LOGICAL_XOR) reduce 373) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 373)) 5054 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 381) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 381) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 381) ((T_LOGICAL_OR) reduce 381) ((T_LOGICAL_XOR) reduce 381) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 381)) 5055 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 375) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 375) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 375) ((T_LOGICAL_OR) reduce 375) ((T_LOGICAL_XOR) reduce 375) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 375)) 5056 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 379) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 379) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 379) ((T_LOGICAL_OR) reduce 379) ((T_LOGICAL_XOR) reduce 379) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 379)) 5057 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 374) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 374) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 374) ((T_LOGICAL_OR) reduce 374) ((T_LOGICAL_XOR) reduce 374) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 374)) 5058 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 377) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 377) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 377) ((T_LOGICAL_OR) reduce 377) ((T_LOGICAL_XOR) reduce 377) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 377)) 5059 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 378) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 378) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 378) ((T_LOGICAL_OR) reduce 378) ((T_LOGICAL_XOR) reduce 378) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 378)) 5060 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 385) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 385) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 385) ((T_LOGICAL_OR) reduce 385) ((T_LOGICAL_XOR) reduce 385) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 385)) 5061 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 380) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 380) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 380) ((T_LOGICAL_OR) reduce 380) ((T_LOGICAL_XOR) reduce 380) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 380)) 5063 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 370) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 370) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 370) ((T_LOGICAL_OR) reduce 370) ((T_LOGICAL_XOR) reduce 370) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 370)) 5066 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) ((",") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529) (("}") reduce 529)) 5069 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) ((",") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) (("<") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_DOUBLE_ARROW) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_POW) reduce 525) ((T_SL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525) (("}") reduce 525)) 5071 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) ((",") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) (("<") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_DOUBLE_ARROW) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_POW) reduce 524) ((T_SL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524) (("}") reduce 524)) 5073 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) ((",") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) (("<") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_DOUBLE_ARROW) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_POW) reduce 519) ((T_SL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519) (("}") reduce 519)) 5074 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) ((",") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) (("<") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_DOUBLE_ARROW) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_POW) reduce 526) ((T_SL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526) (("}") reduce 526)) 5075 ((("%") reduce 371) (("*") reduce 371) (("+") reduce 371) ((",") reduce 371) (("-") reduce 371) ((".") reduce 371) (("/") reduce 371) (("<") reduce 371) ((">") reduce 371) (("?") reduce 371) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_BOOLEAN_AND) reduce 371) ((T_BOOLEAN_OR) reduce 371) ((T_COALESCE) reduce 371) ((T_DOUBLE_ARROW) reduce 371) ((T_INSTANCEOF) reduce 371) ((T_IS_EQUAL) reduce 371) ((T_IS_GREATER_OR_EQUAL) reduce 371) ((T_IS_IDENTICAL) reduce 371) ((T_IS_NOT_EQUAL) reduce 371) ((T_IS_NOT_IDENTICAL) reduce 371) ((T_IS_SMALLER_OR_EQUAL) reduce 371) ((T_LOGICAL_AND) reduce 371) ((T_LOGICAL_OR) reduce 371) ((T_LOGICAL_XOR) reduce 371) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 371) ((T_SL) reduce 371) ((T_SPACESHIP) reduce 371) ((T_SR) reduce 371) (("[") reduce 510) (("^") reduce 371) (("{") reduce 510) (("|") reduce 371) (("}") reduce 371)) 5079 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) ((",") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) (("<") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_DOUBLE_ARROW) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_POW) reduce 533) ((T_SL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533) (("}") reduce 533)) 5081 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) ((",") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) (("<") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_DOUBLE_ARROW) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_POW) reduce 468) ((T_SL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468) (("}") reduce 468)) 5082 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) ((",") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288) (("}") reduce 288)) 5086 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) ((",") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289) (("}") reduce 289)) 5087 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) ((",") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290) (("}") reduce 290)) 5088 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) ((",") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) (("<") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_DOUBLE_ARROW) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_POW) reduce 465) ((T_SL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465) (("}") reduce 465)) 5091 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) ((",") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) (("<") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_DOUBLE_ARROW) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_POW) reduce 532) ((T_SL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532) (("}") reduce 532)) 5092 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) ((",") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) (("<") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_DOUBLE_ARROW) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_POW) reduce 467) ((T_SL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467) (("}") reduce 467)) 5093 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) ((",") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) (("<") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_DOUBLE_ARROW) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_POW) reduce 469) ((T_SL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469) (("}") reduce 469)) 5099 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) ((",") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) (("<") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_DOUBLE_ARROW) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_POW) reduce 521) ((T_SL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521) (("}") reduce 521)) 5101 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) ((",") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) (("<") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_DOUBLE_ARROW) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_POW) reduce 520) ((T_SL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520) (("}") reduce 520)) 5102 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) ((",") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544) (("}") reduce 544)) 5103 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) ((",") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) (("<") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_DOUBLE_ARROW) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_POW) reduce 527) ((T_SL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527) (("}") reduce 527)) 5104 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) ((",") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546) (("}") reduce 546)) 5107 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) ((",") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545) (("}") reduce 545)) 5108 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) ((",") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) (("<") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_DOUBLE_ARROW) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_POW) reduce 522) ((T_SL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522) (("}") reduce 522)) 5109 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) ((",") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) (("<") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_DOUBLE_ARROW) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_POW) reduce 528) ((T_SL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528) (("}") reduce 528)) 5110 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) ((",") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) (("<") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_DOUBLE_ARROW) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_POW) reduce 523) ((T_SL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523) (("}") reduce 523)) 5111 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) ((",") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) (("<") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_DOUBLE_ARROW) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_POW) reduce 466) ((T_SL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466) (("}") reduce 466)) 5112 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) ((",") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531) (("}") reduce 531)) 5115 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) ((",") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530) (("}") reduce 530)) 5116 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) ((",") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) (("<") reduce 465) (("=") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AND_EQUAL) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_COALESCE_EQUAL) reduce 465) ((T_CONCAT_EQUAL) reduce 465) ((T_DEC) reduce 465) ((T_DIV_EQUAL) reduce 465) ((T_DOUBLE_ARROW) reduce 465) ((T_INC) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_MINUS_EQUAL) reduce 465) ((T_MOD_EQUAL) reduce 465) ((T_MUL_EQUAL) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_OR_EQUAL) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_PLUS_EQUAL) reduce 465) ((T_POW) reduce 465) ((T_POW_EQUAL) reduce 465) ((T_SL) reduce 465) ((T_SL_EQUAL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) ((T_SR_EQUAL) reduce 465) ((T_XOR_EQUAL) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465) (("}") reduce 465)) 5127 ((("%") reduce 455) (("*") reduce 455) (("+") reduce 455) ((",") reduce 455) (("-") reduce 455) ((".") reduce 455) (("/") reduce 455) (("<") reduce 455) ((">") reduce 455) (("?") reduce 455) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_BOOLEAN_AND) reduce 455) ((T_BOOLEAN_OR) reduce 455) ((T_COALESCE) reduce 455) ((T_DOUBLE_ARROW) reduce 455) ((T_INSTANCEOF) reduce 455) ((T_IS_EQUAL) reduce 455) ((T_IS_GREATER_OR_EQUAL) reduce 455) ((T_IS_IDENTICAL) reduce 455) ((T_IS_NOT_EQUAL) reduce 455) ((T_IS_NOT_IDENTICAL) reduce 455) ((T_IS_SMALLER_OR_EQUAL) reduce 455) ((T_LOGICAL_AND) reduce 455) ((T_LOGICAL_OR) reduce 455) ((T_LOGICAL_XOR) reduce 455) ((T_POW) reduce 455) ((T_SL) reduce 455) ((T_SPACESHIP) reduce 455) ((T_SR) reduce 455) (("^") reduce 455) (("|") reduce 455) (("}") reduce 455)) 5128 ((("%") reduce 450) (("*") reduce 450) (("+") reduce 450) ((",") reduce 450) (("-") reduce 450) ((".") reduce 450) (("/") reduce 450) (("<") reduce 450) ((">") reduce 450) (("?") reduce 450) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_BOOLEAN_AND) reduce 450) ((T_BOOLEAN_OR) reduce 450) ((T_COALESCE) reduce 450) ((T_DOUBLE_ARROW) reduce 450) ((T_INSTANCEOF) reduce 450) ((T_IS_EQUAL) reduce 450) ((T_IS_GREATER_OR_EQUAL) reduce 450) ((T_IS_IDENTICAL) reduce 450) ((T_IS_NOT_EQUAL) reduce 450) ((T_IS_NOT_IDENTICAL) reduce 450) ((T_IS_SMALLER_OR_EQUAL) reduce 450) ((T_LOGICAL_AND) reduce 450) ((T_LOGICAL_OR) reduce 450) ((T_LOGICAL_XOR) reduce 450) ((T_POW) reduce 450) ((T_SL) reduce 450) ((T_SPACESHIP) reduce 450) ((T_SR) reduce 450) (("^") reduce 450) (("|") reduce 450) (("}") reduce 450)) 5138 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 455) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 455) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 455)) 5139 ((("%") reduce 451) (("*") reduce 451) (("+") reduce 451) ((",") reduce 451) (("-") reduce 451) ((".") reduce 451) (("/") reduce 451) (("<") reduce 451) ((">") reduce 451) (("?") reduce 451) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_BOOLEAN_AND) reduce 451) ((T_BOOLEAN_OR) reduce 451) ((T_COALESCE) reduce 451) ((T_DOUBLE_ARROW) reduce 451) ((T_INSTANCEOF) reduce 451) ((T_IS_EQUAL) reduce 451) ((T_IS_GREATER_OR_EQUAL) reduce 451) ((T_IS_IDENTICAL) reduce 451) ((T_IS_NOT_EQUAL) reduce 451) ((T_IS_NOT_IDENTICAL) reduce 451) ((T_IS_SMALLER_OR_EQUAL) reduce 451) ((T_LOGICAL_AND) reduce 451) ((T_LOGICAL_OR) reduce 451) ((T_LOGICAL_XOR) reduce 451) ((T_POW) reduce 451) ((T_SL) reduce 451) ((T_SPACESHIP) reduce 451) ((T_SR) reduce 451) (("^") reduce 451) (("|") reduce 451) (("}") reduce 451)) 5141 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 442) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 442) ((T_LOGICAL_OR) reduce 442) ((T_LOGICAL_XOR) reduce 442) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 442)) 5143 ((("%") reduce 503) (("(") reduce 541) (("*") reduce 503) (("+") reduce 503) ((",") reduce 503) (("-") reduce 503) ((".") reduce 503) (("/") reduce 503) (("<") reduce 503) ((">") reduce 503) (("?") reduce 503) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_BOOLEAN_AND) reduce 503) ((T_BOOLEAN_OR) reduce 503) ((T_COALESCE) reduce 503) ((T_DOUBLE_ARROW) reduce 503) ((T_INSTANCEOF) reduce 503) ((T_IS_EQUAL) reduce 503) ((T_IS_GREATER_OR_EQUAL) reduce 503) ((T_IS_IDENTICAL) reduce 503) ((T_IS_NOT_EQUAL) reduce 503) ((T_IS_NOT_IDENTICAL) reduce 503) ((T_IS_SMALLER_OR_EQUAL) reduce 503) ((T_LOGICAL_AND) reduce 503) ((T_LOGICAL_OR) reduce 503) ((T_LOGICAL_XOR) reduce 503) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 503) ((T_OBJECT_OPERATOR) reduce 503) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 503) ((T_POW) reduce 503) ((T_SL) reduce 503) ((T_SPACESHIP) reduce 503) ((T_SR) reduce 503) (("[") reduce 503) (("^") reduce 503) (("{") reduce 503) (("|") reduce 503) (("}") reduce 503)) 5145 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) ((",") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) (("<") reduce 532) (("=") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AND_EQUAL) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_COALESCE_EQUAL) reduce 532) ((T_CONCAT_EQUAL) reduce 532) ((T_DEC) reduce 532) ((T_DIV_EQUAL) reduce 532) ((T_DOUBLE_ARROW) reduce 532) ((T_INC) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_MINUS_EQUAL) reduce 532) ((T_MOD_EQUAL) reduce 532) ((T_MUL_EQUAL) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_OR_EQUAL) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_PLUS_EQUAL) reduce 532) ((T_POW) reduce 532) ((T_POW_EQUAL) reduce 532) ((T_SL) reduce 532) ((T_SL_EQUAL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) ((T_SR_EQUAL) reduce 532) ((T_XOR_EQUAL) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532) (("}") reduce 532)) 5148 ((("%") reduce 505) (("(") reduce 542) (("*") reduce 505) (("+") reduce 505) ((",") reduce 505) (("-") reduce 505) ((".") reduce 505) (("/") reduce 505) (("<") reduce 505) ((">") reduce 505) (("?") reduce 505) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_BOOLEAN_AND) reduce 505) ((T_BOOLEAN_OR) reduce 505) ((T_COALESCE) reduce 505) ((T_DOUBLE_ARROW) reduce 505) ((T_INSTANCEOF) reduce 505) ((T_IS_EQUAL) reduce 505) ((T_IS_GREATER_OR_EQUAL) reduce 505) ((T_IS_IDENTICAL) reduce 505) ((T_IS_NOT_EQUAL) reduce 505) ((T_IS_NOT_IDENTICAL) reduce 505) ((T_IS_SMALLER_OR_EQUAL) reduce 505) ((T_LOGICAL_AND) reduce 505) ((T_LOGICAL_OR) reduce 505) ((T_LOGICAL_XOR) reduce 505) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 505) ((T_OBJECT_OPERATOR) reduce 505) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 505) ((T_POW) reduce 505) ((T_SL) reduce 505) ((T_SPACESHIP) reduce 505) ((T_SR) reduce 505) (("[") reduce 505) (("^") reduce 505) (("{") reduce 505) (("|") reduce 505) (("}") reduce 505)) 5149 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) ((",") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) (("<") reduce 467) (("=") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AND_EQUAL) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_COALESCE_EQUAL) reduce 467) ((T_CONCAT_EQUAL) reduce 467) ((T_DEC) reduce 467) ((T_DIV_EQUAL) reduce 467) ((T_DOUBLE_ARROW) reduce 467) ((T_INC) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_MINUS_EQUAL) reduce 467) ((T_MOD_EQUAL) reduce 467) ((T_MUL_EQUAL) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_OR_EQUAL) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_PLUS_EQUAL) reduce 467) ((T_POW) reduce 467) ((T_POW_EQUAL) reduce 467) ((T_SL) reduce 467) ((T_SL_EQUAL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) ((T_SR_EQUAL) reduce 467) ((T_XOR_EQUAL) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467) (("}") reduce 467)) 5150 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) ((",") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) (("<") reduce 469) (("=") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AND_EQUAL) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_COALESCE_EQUAL) reduce 469) ((T_CONCAT_EQUAL) reduce 469) ((T_DEC) reduce 469) ((T_DIV_EQUAL) reduce 469) ((T_DOUBLE_ARROW) reduce 469) ((T_INC) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_MINUS_EQUAL) reduce 469) ((T_MOD_EQUAL) reduce 469) ((T_MUL_EQUAL) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_OR_EQUAL) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_PLUS_EQUAL) reduce 469) ((T_POW) reduce 469) ((T_POW_EQUAL) reduce 469) ((T_SL) reduce 469) ((T_SL_EQUAL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) ((T_SR_EQUAL) reduce 469) ((T_XOR_EQUAL) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469) (("}") reduce 469)) 5152 ((("%") reduce 446) (("*") reduce 446) (("+") reduce 446) ((",") reduce 446) (("-") reduce 446) ((".") reduce 446) (("/") reduce 446) (("<") reduce 446) ((">") reduce 446) (("?") reduce 446) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_BOOLEAN_AND) reduce 446) ((T_BOOLEAN_OR) reduce 446) ((T_COALESCE) reduce 446) ((T_DOUBLE_ARROW) reduce 446) ((T_INSTANCEOF) reduce 446) ((T_IS_EQUAL) reduce 446) ((T_IS_GREATER_OR_EQUAL) reduce 446) ((T_IS_IDENTICAL) reduce 446) ((T_IS_NOT_EQUAL) reduce 446) ((T_IS_NOT_IDENTICAL) reduce 446) ((T_IS_SMALLER_OR_EQUAL) reduce 446) ((T_LOGICAL_AND) reduce 446) ((T_LOGICAL_OR) reduce 446) ((T_LOGICAL_XOR) reduce 446) ((T_POW) reduce 446) ((T_SL) reduce 446) ((T_SPACESHIP) reduce 446) ((T_SR) reduce 446) (("^") reduce 446) (("|") reduce 446) (("}") reduce 446)) 5153 ((("%") reduce 448) (("*") reduce 448) (("+") reduce 448) ((",") reduce 448) (("-") reduce 448) ((".") reduce 448) (("/") reduce 448) (("<") reduce 448) ((">") reduce 448) (("?") reduce 448) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_BOOLEAN_AND) reduce 448) ((T_BOOLEAN_OR) reduce 448) ((T_COALESCE) reduce 448) ((T_DOUBLE_ARROW) reduce 448) ((T_INSTANCEOF) reduce 448) ((T_IS_EQUAL) reduce 448) ((T_IS_GREATER_OR_EQUAL) reduce 448) ((T_IS_IDENTICAL) reduce 448) ((T_IS_NOT_EQUAL) reduce 448) ((T_IS_NOT_IDENTICAL) reduce 448) ((T_IS_SMALLER_OR_EQUAL) reduce 448) ((T_LOGICAL_AND) reduce 448) ((T_LOGICAL_OR) reduce 448) ((T_LOGICAL_XOR) reduce 448) ((T_POW) reduce 448) ((T_SL) reduce 448) ((T_SPACESHIP) reduce 448) ((T_SR) reduce 448) (("^") reduce 448) (("|") reduce 448) (("}") reduce 448)) 5159 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) ((",") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) (("<") reduce 521) (("=") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AND_EQUAL) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_COALESCE_EQUAL) reduce 521) ((T_CONCAT_EQUAL) reduce 521) ((T_DEC) reduce 521) ((T_DIV_EQUAL) reduce 521) ((T_DOUBLE_ARROW) reduce 521) ((T_INC) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_MINUS_EQUAL) reduce 521) ((T_MOD_EQUAL) reduce 521) ((T_MUL_EQUAL) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_OR_EQUAL) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_PLUS_EQUAL) reduce 521) ((T_POW) reduce 521) ((T_POW_EQUAL) reduce 521) ((T_SL) reduce 521) ((T_SL_EQUAL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) ((T_SR_EQUAL) reduce 521) ((T_XOR_EQUAL) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521) (("}") reduce 521)) 5161 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) ((",") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) (("<") reduce 520) (("=") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AND_EQUAL) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_COALESCE_EQUAL) reduce 520) ((T_CONCAT_EQUAL) reduce 520) ((T_DEC) reduce 520) ((T_DIV_EQUAL) reduce 520) ((T_DOUBLE_ARROW) reduce 520) ((T_INC) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_MINUS_EQUAL) reduce 520) ((T_MOD_EQUAL) reduce 520) ((T_MUL_EQUAL) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_OR_EQUAL) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_PLUS_EQUAL) reduce 520) ((T_POW) reduce 520) ((T_POW_EQUAL) reduce 520) ((T_SL) reduce 520) ((T_SL_EQUAL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) ((T_SR_EQUAL) reduce 520) ((T_XOR_EQUAL) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520) (("}") reduce 520)) 5162 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) ((",") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) (("=") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AND_EQUAL) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_COALESCE_EQUAL) reduce 544) ((T_CONCAT_EQUAL) reduce 544) ((T_DEC) reduce 544) ((T_DIV_EQUAL) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INC) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_MINUS_EQUAL) reduce 544) ((T_MOD_EQUAL) reduce 544) ((T_MUL_EQUAL) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_OR_EQUAL) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_PLUS_EQUAL) reduce 544) ((T_POW) reduce 544) ((T_POW_EQUAL) reduce 544) ((T_SL) reduce 544) ((T_SL_EQUAL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) ((T_SR_EQUAL) reduce 544) ((T_XOR_EQUAL) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544) (("}") reduce 544)) 5163 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) ((",") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) (("<") reduce 527) (("=") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AND_EQUAL) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_COALESCE_EQUAL) reduce 527) ((T_CONCAT_EQUAL) reduce 527) ((T_DEC) reduce 527) ((T_DIV_EQUAL) reduce 527) ((T_DOUBLE_ARROW) reduce 527) ((T_INC) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_MINUS_EQUAL) reduce 527) ((T_MOD_EQUAL) reduce 527) ((T_MUL_EQUAL) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_OR_EQUAL) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_PLUS_EQUAL) reduce 527) ((T_POW) reduce 527) ((T_POW_EQUAL) reduce 527) ((T_SL) reduce 527) ((T_SL_EQUAL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) ((T_SR_EQUAL) reduce 527) ((T_XOR_EQUAL) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527) (("}") reduce 527)) 5164 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) ((",") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) (("=") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AND_EQUAL) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_COALESCE_EQUAL) reduce 546) ((T_CONCAT_EQUAL) reduce 546) ((T_DEC) reduce 546) ((T_DIV_EQUAL) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INC) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_MINUS_EQUAL) reduce 546) ((T_MOD_EQUAL) reduce 546) ((T_MUL_EQUAL) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_OR_EQUAL) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_PLUS_EQUAL) reduce 546) ((T_POW) reduce 546) ((T_POW_EQUAL) reduce 546) ((T_SL) reduce 546) ((T_SL_EQUAL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) ((T_SR_EQUAL) reduce 546) ((T_XOR_EQUAL) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546) (("}") reduce 546)) 5167 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) ((",") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) (("=") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AND_EQUAL) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_COALESCE_EQUAL) reduce 545) ((T_CONCAT_EQUAL) reduce 545) ((T_DEC) reduce 545) ((T_DIV_EQUAL) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INC) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_MINUS_EQUAL) reduce 545) ((T_MOD_EQUAL) reduce 545) ((T_MUL_EQUAL) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_OR_EQUAL) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_PLUS_EQUAL) reduce 545) ((T_POW) reduce 545) ((T_POW_EQUAL) reduce 545) ((T_SL) reduce 545) ((T_SL_EQUAL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) ((T_SR_EQUAL) reduce 545) ((T_XOR_EQUAL) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545) (("}") reduce 545)) 5168 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) ((",") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) (("<") reduce 522) (("=") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AND_EQUAL) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_COALESCE_EQUAL) reduce 522) ((T_CONCAT_EQUAL) reduce 522) ((T_DEC) reduce 522) ((T_DIV_EQUAL) reduce 522) ((T_DOUBLE_ARROW) reduce 522) ((T_INC) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_MINUS_EQUAL) reduce 522) ((T_MOD_EQUAL) reduce 522) ((T_MUL_EQUAL) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_OR_EQUAL) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_PLUS_EQUAL) reduce 522) ((T_POW) reduce 522) ((T_POW_EQUAL) reduce 522) ((T_SL) reduce 522) ((T_SL_EQUAL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) ((T_SR_EQUAL) reduce 522) ((T_XOR_EQUAL) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522) (("}") reduce 522)) 5169 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) ((",") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) (("<") reduce 528) (("=") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AND_EQUAL) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_COALESCE_EQUAL) reduce 528) ((T_CONCAT_EQUAL) reduce 528) ((T_DEC) reduce 528) ((T_DIV_EQUAL) reduce 528) ((T_DOUBLE_ARROW) reduce 528) ((T_INC) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_MINUS_EQUAL) reduce 528) ((T_MOD_EQUAL) reduce 528) ((T_MUL_EQUAL) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_OR_EQUAL) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_PLUS_EQUAL) reduce 528) ((T_POW) reduce 528) ((T_POW_EQUAL) reduce 528) ((T_SL) reduce 528) ((T_SL_EQUAL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) ((T_SR_EQUAL) reduce 528) ((T_XOR_EQUAL) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528) (("}") reduce 528)) 5170 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) ((",") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) (("<") reduce 523) (("=") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AND_EQUAL) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_COALESCE_EQUAL) reduce 523) ((T_CONCAT_EQUAL) reduce 523) ((T_DEC) reduce 523) ((T_DIV_EQUAL) reduce 523) ((T_DOUBLE_ARROW) reduce 523) ((T_INC) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_MINUS_EQUAL) reduce 523) ((T_MOD_EQUAL) reduce 523) ((T_MUL_EQUAL) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_OR_EQUAL) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_PLUS_EQUAL) reduce 523) ((T_POW) reduce 523) ((T_POW_EQUAL) reduce 523) ((T_SL) reduce 523) ((T_SL_EQUAL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) ((T_SR_EQUAL) reduce 523) ((T_XOR_EQUAL) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523) (("}") reduce 523)) 5172 ((("%") reduce 438) (("*") reduce 438) (("+") reduce 438) ((",") reduce 438) (("-") reduce 438) ((".") reduce 438) (("/") reduce 438) (("<") reduce 438) ((">") reduce 438) (("?") reduce 438) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_BOOLEAN_AND) reduce 438) ((T_BOOLEAN_OR) reduce 438) ((T_COALESCE) reduce 438) ((T_DOUBLE_ARROW) reduce 438) ((T_INSTANCEOF) reduce 438) ((T_IS_EQUAL) reduce 438) ((T_IS_GREATER_OR_EQUAL) reduce 438) ((T_IS_IDENTICAL) reduce 438) ((T_IS_NOT_EQUAL) reduce 438) ((T_IS_NOT_IDENTICAL) reduce 438) ((T_IS_SMALLER_OR_EQUAL) reduce 438) ((T_LOGICAL_AND) reduce 438) ((T_LOGICAL_OR) reduce 438) ((T_LOGICAL_XOR) reduce 438) ((T_POW) reduce 438) ((T_SL) reduce 438) ((T_SPACESHIP) reduce 438) ((T_SR) reduce 438) (("^") reduce 438) (("|") reduce 438) (("}") reduce 438)) 5174 ((("%") reduce 483) (("(") reduce 483) (("*") reduce 483) (("+") reduce 483) ((",") reduce 483) (("-") reduce 483) ((".") reduce 483) (("/") reduce 483) (("<") reduce 483) (("=") shift) ((">") reduce 483) (("?") reduce 483) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_BOOLEAN_AND) reduce 483) ((T_BOOLEAN_OR) reduce 483) ((T_COALESCE) reduce 483) ((T_DOUBLE_ARROW) reduce 483) ((T_INSTANCEOF) reduce 483) ((T_IS_EQUAL) reduce 483) ((T_IS_GREATER_OR_EQUAL) reduce 483) ((T_IS_IDENTICAL) reduce 483) ((T_IS_NOT_EQUAL) reduce 483) ((T_IS_NOT_IDENTICAL) reduce 483) ((T_IS_SMALLER_OR_EQUAL) reduce 483) ((T_LOGICAL_AND) reduce 483) ((T_LOGICAL_OR) reduce 483) ((T_LOGICAL_XOR) reduce 483) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 483) ((T_OBJECT_OPERATOR) reduce 483) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 483) ((T_POW) reduce 483) ((T_SL) reduce 483) ((T_SPACESHIP) reduce 483) ((T_SR) reduce 483) (("[") reduce 483) (("^") reduce 483) (("{") reduce 483) (("|") reduce 483) (("}") reduce 483)) 5176 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 369) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 369) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 369) ((T_LOGICAL_OR) reduce 369) ((T_LOGICAL_XOR) reduce 369) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 369)) 5177 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 443) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 443) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 443) ((T_LOGICAL_OR) reduce 443) ((T_LOGICAL_XOR) reduce 443) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 443)) 5180 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 442) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 442) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 442) ((T_LOGICAL_OR) reduce 442) ((T_LOGICAL_XOR) reduce 442) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 442)) 5181 ((("%") reduce 434) (("*") reduce 434) (("+") reduce 434) ((",") reduce 434) (("-") reduce 434) ((".") reduce 434) (("/") reduce 434) (("<") reduce 434) ((">") reduce 434) (("?") reduce 434) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_BOOLEAN_AND) reduce 434) ((T_BOOLEAN_OR) reduce 434) ((T_COALESCE) reduce 434) ((T_DOUBLE_ARROW) reduce 434) ((T_INSTANCEOF) reduce 434) ((T_IS_EQUAL) reduce 434) ((T_IS_GREATER_OR_EQUAL) reduce 434) ((T_IS_IDENTICAL) reduce 434) ((T_IS_NOT_EQUAL) reduce 434) ((T_IS_NOT_IDENTICAL) reduce 434) ((T_IS_SMALLER_OR_EQUAL) reduce 434) ((T_LOGICAL_AND) reduce 434) ((T_LOGICAL_OR) reduce 434) ((T_LOGICAL_XOR) reduce 434) ((T_POW) shift) ((T_SL) reduce 434) ((T_SPACESHIP) reduce 434) ((T_SR) reduce 434) (("^") reduce 434) (("|") reduce 434) (("}") reduce 434)) 5182 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 444) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 444) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 444)) 5183 ((("%") reduce 430) (("*") reduce 430) (("+") reduce 430) ((",") reduce 430) (("-") reduce 430) ((".") reduce 430) (("/") reduce 430) (("<") reduce 430) ((">") reduce 430) (("?") reduce 430) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_BOOLEAN_AND) reduce 430) ((T_BOOLEAN_OR) reduce 430) ((T_COALESCE) reduce 430) ((T_DOUBLE_ARROW) reduce 430) ((T_INSTANCEOF) reduce 430) ((T_IS_EQUAL) reduce 430) ((T_IS_GREATER_OR_EQUAL) reduce 430) ((T_IS_IDENTICAL) reduce 430) ((T_IS_NOT_EQUAL) reduce 430) ((T_IS_NOT_IDENTICAL) reduce 430) ((T_IS_SMALLER_OR_EQUAL) reduce 430) ((T_LOGICAL_AND) reduce 430) ((T_LOGICAL_OR) reduce 430) ((T_LOGICAL_XOR) reduce 430) ((T_POW) shift) ((T_SL) reduce 430) ((T_SPACESHIP) reduce 430) ((T_SR) reduce 430) (("^") reduce 430) (("|") reduce 430) (("}") reduce 430)) 5184 ((("%") reduce 447) (("*") reduce 447) (("+") reduce 447) ((",") reduce 447) (("-") reduce 447) ((".") reduce 447) (("/") reduce 447) (("<") reduce 447) ((">") reduce 447) (("?") reduce 447) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_BOOLEAN_AND) reduce 447) ((T_BOOLEAN_OR) reduce 447) ((T_COALESCE) reduce 447) ((T_DOUBLE_ARROW) reduce 447) ((T_INSTANCEOF) reduce 447) ((T_IS_EQUAL) reduce 447) ((T_IS_GREATER_OR_EQUAL) reduce 447) ((T_IS_IDENTICAL) reduce 447) ((T_IS_NOT_EQUAL) reduce 447) ((T_IS_NOT_IDENTICAL) reduce 447) ((T_IS_SMALLER_OR_EQUAL) reduce 447) ((T_LOGICAL_AND) reduce 447) ((T_LOGICAL_OR) reduce 447) ((T_LOGICAL_XOR) reduce 447) ((T_POW) reduce 447) ((T_SL) reduce 447) ((T_SPACESHIP) reduce 447) ((T_SR) reduce 447) (("^") reduce 447) (("|") reduce 447) (("}") reduce 447)) 5186 ((("%") reduce 489) (("*") reduce 489) (("+") reduce 489) ((",") reduce 489) (("-") reduce 489) ((".") reduce 489) (("/") reduce 489) (("<") reduce 489) ((">") reduce 489) (("?") reduce 489) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_BOOLEAN_AND) reduce 489) ((T_BOOLEAN_OR) reduce 489) ((T_COALESCE) reduce 489) ((T_DOUBLE_ARROW) reduce 489) ((T_INSTANCEOF) reduce 489) ((T_IS_EQUAL) reduce 489) ((T_IS_GREATER_OR_EQUAL) reduce 489) ((T_IS_IDENTICAL) reduce 489) ((T_IS_NOT_EQUAL) reduce 489) ((T_IS_NOT_IDENTICAL) reduce 489) ((T_IS_SMALLER_OR_EQUAL) reduce 489) ((T_LOGICAL_AND) reduce 489) ((T_LOGICAL_OR) reduce 489) ((T_LOGICAL_XOR) reduce 489) ((T_POW) reduce 489) ((T_SL) reduce 489) ((T_SPACESHIP) reduce 489) ((T_SR) reduce 489) (("^") reduce 489) (("|") reduce 489) (("}") reduce 489)) 5188 ((("%") reduce 490) (("*") reduce 490) (("+") reduce 490) ((",") reduce 490) (("-") reduce 490) ((".") reduce 490) (("/") reduce 490) (("<") reduce 490) ((">") reduce 490) (("?") reduce 490) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_BOOLEAN_AND) reduce 490) ((T_BOOLEAN_OR) reduce 490) ((T_COALESCE) reduce 490) ((T_DOUBLE_ARROW) reduce 490) ((T_INSTANCEOF) reduce 490) ((T_IS_EQUAL) reduce 490) ((T_IS_GREATER_OR_EQUAL) reduce 490) ((T_IS_IDENTICAL) reduce 490) ((T_IS_NOT_EQUAL) reduce 490) ((T_IS_NOT_IDENTICAL) reduce 490) ((T_IS_SMALLER_OR_EQUAL) reduce 490) ((T_LOGICAL_AND) reduce 490) ((T_LOGICAL_OR) reduce 490) ((T_LOGICAL_XOR) reduce 490) ((T_POW) reduce 490) ((T_SL) reduce 490) ((T_SPACESHIP) reduce 490) ((T_SR) reduce 490) (("^") reduce 490) (("|") reduce 490) (("}") reduce 490)) 5189 ((("%") reduce 488) (("*") reduce 488) (("+") reduce 488) ((",") reduce 488) (("-") reduce 488) ((".") reduce 488) (("/") reduce 488) (("<") reduce 488) ((">") reduce 488) (("?") reduce 488) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_BOOLEAN_AND) reduce 488) ((T_BOOLEAN_OR) reduce 488) ((T_COALESCE) reduce 488) ((T_DOUBLE_ARROW) reduce 488) ((T_INSTANCEOF) reduce 488) ((T_IS_EQUAL) reduce 488) ((T_IS_GREATER_OR_EQUAL) reduce 488) ((T_IS_IDENTICAL) reduce 488) ((T_IS_NOT_EQUAL) reduce 488) ((T_IS_NOT_IDENTICAL) reduce 488) ((T_IS_SMALLER_OR_EQUAL) reduce 488) ((T_LOGICAL_AND) reduce 488) ((T_LOGICAL_OR) reduce 488) ((T_LOGICAL_XOR) reduce 488) ((T_POW) reduce 488) ((T_SL) reduce 488) ((T_SPACESHIP) reduce 488) ((T_SR) reduce 488) (("^") reduce 488) (("|") reduce 488) (("}") reduce 488)) 5190 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 581) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 581) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 581)) 5191 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 580) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 580) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 580)) 5192 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) ((",") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) (("<") reduce 466) (("=") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AND_EQUAL) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_COALESCE_EQUAL) reduce 466) ((T_CONCAT_EQUAL) reduce 466) ((T_DEC) reduce 466) ((T_DIV_EQUAL) reduce 466) ((T_DOUBLE_ARROW) reduce 466) ((T_INC) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_MINUS_EQUAL) reduce 466) ((T_MOD_EQUAL) reduce 466) ((T_MUL_EQUAL) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_OR_EQUAL) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_PLUS_EQUAL) reduce 466) ((T_POW) reduce 466) ((T_POW_EQUAL) reduce 466) ((T_SL) reduce 466) ((T_SL_EQUAL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) ((T_SR_EQUAL) reduce 466) ((T_XOR_EQUAL) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466) (("}") reduce 466)) 5193 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 439) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 439) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 439) ((T_LOGICAL_OR) reduce 439) ((T_LOGICAL_XOR) reduce 439) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 439)) 5194 ((("%") reduce 432) (("*") reduce 432) (("+") reduce 432) ((",") reduce 432) (("-") reduce 432) ((".") reduce 432) (("/") reduce 432) (("<") reduce 432) ((">") reduce 432) (("?") reduce 432) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_BOOLEAN_AND) reduce 432) ((T_BOOLEAN_OR) reduce 432) ((T_COALESCE) reduce 432) ((T_DOUBLE_ARROW) reduce 432) ((T_INSTANCEOF) reduce 432) ((T_IS_EQUAL) reduce 432) ((T_IS_GREATER_OR_EQUAL) reduce 432) ((T_IS_IDENTICAL) reduce 432) ((T_IS_NOT_EQUAL) reduce 432) ((T_IS_NOT_IDENTICAL) reduce 432) ((T_IS_SMALLER_OR_EQUAL) reduce 432) ((T_LOGICAL_AND) reduce 432) ((T_LOGICAL_OR) reduce 432) ((T_LOGICAL_XOR) reduce 432) ((T_POW) shift) ((T_SL) reduce 432) ((T_SPACESHIP) reduce 432) ((T_SR) reduce 432) (("^") reduce 432) (("|") reduce 432) (("}") reduce 432)) 5196 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) ((",") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93) (("}") reduce 93)) 5197 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) ((",") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92) (("}") reduce 92)) 5198 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) ((",") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94) (("}") reduce 94)) 5199 ((("%") reduce 470) (("(") reduce 470) (("*") reduce 470) (("+") reduce 470) ((",") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_DOUBLE_ARROW) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470) (("}") reduce 470)) 5200 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) ((",") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91) (("}") reduce 91)) 5201 ((("%") reduce 365) (("*") reduce 365) (("+") reduce 365) ((",") reduce 365) (("-") reduce 365) ((".") reduce 365) (("/") reduce 365) (("<") reduce 365) ((">") reduce 365) (("?") reduce 365) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_BOOLEAN_AND) reduce 365) ((T_BOOLEAN_OR) reduce 365) ((T_COALESCE) reduce 365) ((T_DOUBLE_ARROW) reduce 365) ((T_INSTANCEOF) reduce 365) ((T_IS_EQUAL) reduce 365) ((T_IS_GREATER_OR_EQUAL) reduce 365) ((T_IS_IDENTICAL) reduce 365) ((T_IS_NOT_EQUAL) reduce 365) ((T_IS_NOT_IDENTICAL) reduce 365) ((T_IS_SMALLER_OR_EQUAL) reduce 365) ((T_LOGICAL_AND) reduce 365) ((T_LOGICAL_OR) reduce 365) ((T_LOGICAL_XOR) reduce 365) ((T_POW) reduce 365) ((T_SL) reduce 365) ((T_SPACESHIP) reduce 365) ((T_SR) reduce 365) (("^") reduce 365) (("|") reduce 365) (("}") reduce 365)) 5204 ((("%") reduce 472) (("(") reduce 472) (("*") reduce 472) (("+") reduce 472) ((",") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_DOUBLE_ARROW) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472) (("}") reduce 472)) 5205 ((("%") reduce 480) (("(") shift) (("*") reduce 480) (("+") reduce 480) ((",") reduce 480) (("-") reduce 480) ((".") reduce 480) (("/") reduce 480) (("<") reduce 480) ((">") reduce 480) (("?") reduce 480) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_BOOLEAN_AND) reduce 480) ((T_BOOLEAN_OR) reduce 480) ((T_COALESCE) reduce 480) ((T_DOUBLE_ARROW) reduce 480) ((T_INSTANCEOF) reduce 480) ((T_IS_EQUAL) reduce 480) ((T_IS_GREATER_OR_EQUAL) reduce 480) ((T_IS_IDENTICAL) reduce 480) ((T_IS_NOT_EQUAL) reduce 480) ((T_IS_NOT_IDENTICAL) reduce 480) ((T_IS_SMALLER_OR_EQUAL) reduce 480) ((T_LOGICAL_AND) reduce 480) ((T_LOGICAL_OR) reduce 480) ((T_LOGICAL_XOR) reduce 480) ((T_POW) reduce 480) ((T_SL) reduce 480) ((T_SPACESHIP) reduce 480) ((T_SR) reduce 480) (("^") reduce 480) (("|") reduce 480) (("}") reduce 480)) 5206 ((("%") reduce 471) (("(") reduce 471) (("*") reduce 471) (("+") reduce 471) ((",") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_DOUBLE_ARROW) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471) (("}") reduce 471)) 5207 ((("%") reduce 473) (("(") reduce 473) (("*") reduce 473) (("+") reduce 473) ((",") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_DOUBLE_ARROW) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473) (("}") reduce 473)) 5208 ((("%") reduce 534) (("(") reduce 534) (("*") reduce 534) (("+") reduce 534) ((",") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_DOUBLE_ARROW) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534) (("}") reduce 534)) 5215 ((("%") reduce 536) (("(") reduce 536) (("*") reduce 536) (("+") reduce 536) ((",") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_DOUBLE_ARROW) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536) (("}") reduce 536)) 5217 ((("%") reduce 535) (("(") reduce 535) (("*") reduce 535) (("+") reduce 535) ((",") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_DOUBLE_ARROW) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535) (("}") reduce 535)) 5218 ((("%") reduce 540) (("(") reduce 540) (("*") reduce 540) (("+") reduce 540) ((",") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_DOUBLE_ARROW) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540) (("}") reduce 540)) 5219 ((("%") reduce 537) (("(") reduce 537) (("*") reduce 537) (("+") reduce 537) ((",") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_DOUBLE_ARROW) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537) (("}") reduce 537)) 5220 ((("%") reduce 538) (("(") reduce 538) (("*") reduce 538) (("+") reduce 538) ((",") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_DOUBLE_ARROW) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538) (("}") reduce 538)) 5222 ((("%") reduce 481) (("*") reduce 481) (("+") reduce 481) ((",") reduce 481) (("-") reduce 481) ((".") reduce 481) (("/") reduce 481) (("<") reduce 481) ((">") reduce 481) (("?") reduce 481) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_BOOLEAN_AND) reduce 481) ((T_BOOLEAN_OR) reduce 481) ((T_COALESCE) reduce 481) ((T_DOUBLE_ARROW) reduce 481) ((T_INSTANCEOF) reduce 481) ((T_IS_EQUAL) reduce 481) ((T_IS_GREATER_OR_EQUAL) reduce 481) ((T_IS_IDENTICAL) reduce 481) ((T_IS_NOT_EQUAL) reduce 481) ((T_IS_NOT_IDENTICAL) reduce 481) ((T_IS_SMALLER_OR_EQUAL) reduce 481) ((T_LOGICAL_AND) reduce 481) ((T_LOGICAL_OR) reduce 481) ((T_LOGICAL_XOR) reduce 481) ((T_POW) reduce 481) ((T_SL) reduce 481) ((T_SPACESHIP) reduce 481) ((T_SR) reduce 481) (("^") reduce 481) (("|") reduce 481) (("}") reduce 481)) 5223 ((("%") reduce 364) (("*") reduce 364) (("+") reduce 364) ((",") reduce 364) (("-") reduce 364) ((".") reduce 364) (("/") reduce 364) (("<") reduce 364) ((">") reduce 364) (("?") reduce 364) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_BOOLEAN_AND) reduce 364) ((T_BOOLEAN_OR) reduce 364) ((T_COALESCE) reduce 364) ((T_DOUBLE_ARROW) reduce 364) ((T_INSTANCEOF) reduce 364) ((T_IS_EQUAL) reduce 364) ((T_IS_GREATER_OR_EQUAL) reduce 364) ((T_IS_IDENTICAL) reduce 364) ((T_IS_NOT_EQUAL) reduce 364) ((T_IS_NOT_IDENTICAL) reduce 364) ((T_IS_SMALLER_OR_EQUAL) reduce 364) ((T_LOGICAL_AND) reduce 364) ((T_LOGICAL_OR) reduce 364) ((T_LOGICAL_XOR) reduce 364) ((T_POW) reduce 364) ((T_SL) reduce 364) ((T_SPACESHIP) reduce 364) ((T_SR) reduce 364) (("^") reduce 364) (("|") reduce 364) (("}") reduce 364)) 5224 ((("%") reduce 288) (("*") reduce 288) (("+") reduce 288) ((",") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("^") reduce 288) (("|") reduce 288) (("}") reduce 288)) 5228 ((("%") reduce 289) (("*") reduce 289) (("+") reduce 289) ((",") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("^") reduce 289) (("|") reduce 289) (("}") reduce 289)) 5229 ((("%") reduce 290) (("*") reduce 290) (("+") reduce 290) ((",") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("^") reduce 290) (("|") reduce 290) (("}") reduce 290)) 5231 ((("%") reduce 539) (("(") reduce 539) (("*") reduce 539) (("+") reduce 539) ((",") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_DOUBLE_ARROW) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539) (("}") reduce 539)) 5232 ((("%") reduce 366) (("*") reduce 366) (("+") reduce 366) ((",") reduce 366) (("-") reduce 366) ((".") reduce 366) (("/") reduce 366) (("<") reduce 366) ((">") reduce 366) (("?") reduce 366) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_BOOLEAN_AND) reduce 366) ((T_BOOLEAN_OR) reduce 366) ((T_COALESCE) reduce 366) ((T_DOUBLE_ARROW) reduce 366) ((T_INSTANCEOF) reduce 366) ((T_IS_EQUAL) reduce 366) ((T_IS_GREATER_OR_EQUAL) reduce 366) ((T_IS_IDENTICAL) reduce 366) ((T_IS_NOT_EQUAL) reduce 366) ((T_IS_NOT_IDENTICAL) reduce 366) ((T_IS_SMALLER_OR_EQUAL) reduce 366) ((T_LOGICAL_AND) reduce 366) ((T_LOGICAL_OR) reduce 366) ((T_LOGICAL_XOR) reduce 366) ((T_POW) reduce 366) ((T_SL) reduce 366) ((T_SPACESHIP) reduce 366) ((T_SR) reduce 366) (("^") reduce 366) (("|") reduce 366) (("}") reduce 366)) 5240 ((("%") reduce 363) (("*") reduce 363) (("+") reduce 363) ((",") reduce 363) (("-") reduce 363) ((".") reduce 363) (("/") reduce 363) (("<") reduce 363) ((">") reduce 363) (("?") reduce 363) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_BOOLEAN_AND) reduce 363) ((T_BOOLEAN_OR) reduce 363) ((T_COALESCE) reduce 363) ((T_DOUBLE_ARROW) reduce 363) ((T_INSTANCEOF) reduce 363) ((T_IS_EQUAL) reduce 363) ((T_IS_GREATER_OR_EQUAL) reduce 363) ((T_IS_IDENTICAL) reduce 363) ((T_IS_NOT_EQUAL) reduce 363) ((T_IS_NOT_IDENTICAL) reduce 363) ((T_IS_SMALLER_OR_EQUAL) reduce 363) ((T_LOGICAL_AND) reduce 363) ((T_LOGICAL_OR) reduce 363) ((T_LOGICAL_XOR) reduce 363) ((T_POW) reduce 363) ((T_SL) reduce 363) ((T_SPACESHIP) reduce 363) ((T_SR) reduce 363) (("^") reduce 363) (("|") reduce 363) (("}") reduce 363)) 5242 ((("%") reduce 474) (("(") reduce 474) (("*") reduce 474) (("+") reduce 474) ((",") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_DOUBLE_ARROW) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474) (("}") reduce 474)) 5248 ((("%") reduce 230) (("*") reduce 230) (("+") reduce 230) ((",") reduce 230) (("-") reduce 230) ((".") reduce 230) (("/") reduce 230) (("<") reduce 230) ((">") reduce 230) (("?") reduce 230) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_BOOLEAN_AND) reduce 230) ((T_BOOLEAN_OR) reduce 230) ((T_COALESCE) reduce 230) ((T_DOUBLE_ARROW) reduce 230) ((T_INSTANCEOF) reduce 230) ((T_IS_EQUAL) reduce 230) ((T_IS_GREATER_OR_EQUAL) reduce 230) ((T_IS_IDENTICAL) reduce 230) ((T_IS_NOT_EQUAL) reduce 230) ((T_IS_NOT_IDENTICAL) reduce 230) ((T_IS_SMALLER_OR_EQUAL) reduce 230) ((T_LOGICAL_AND) reduce 230) ((T_LOGICAL_OR) reduce 230) ((T_LOGICAL_XOR) reduce 230) ((T_POW) reduce 230) ((T_SL) reduce 230) ((T_SPACESHIP) reduce 230) ((T_SR) reduce 230) (("^") reduce 230) (("|") reduce 230) (("}") reduce 230)) 5253 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 368) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 368) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 368) ((T_LOGICAL_OR) reduce 368) ((T_LOGICAL_XOR) reduce 368) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 368)) 5255 ((("%") shift) ((")") reduce 584) (("*") shift) (("+") shift) ((",") reduce 584) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 5256 (((")") reduce 582) ((",") reduce 582)) 5258 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) ((")") reduce 124) (("+") shift) (("-") shift) (("@") shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("~") shift)) 5260 ((("%") reduce 575) (("*") reduce 575) (("+") reduce 575) ((",") reduce 575) (("-") reduce 575) ((".") reduce 575) (("/") reduce 575) (("<") reduce 575) ((">") reduce 575) (("?") reduce 575) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_BOOLEAN_AND) reduce 575) ((T_BOOLEAN_OR) reduce 575) ((T_COALESCE) reduce 575) ((T_DOUBLE_ARROW) reduce 575) ((T_INSTANCEOF) reduce 575) ((T_IS_EQUAL) reduce 575) ((T_IS_GREATER_OR_EQUAL) reduce 575) ((T_IS_IDENTICAL) reduce 575) ((T_IS_NOT_EQUAL) reduce 575) ((T_IS_NOT_IDENTICAL) reduce 575) ((T_IS_SMALLER_OR_EQUAL) reduce 575) ((T_LOGICAL_AND) reduce 575) ((T_LOGICAL_OR) reduce 575) ((T_LOGICAL_XOR) reduce 575) ((T_POW) reduce 575) ((T_SL) reduce 575) ((T_SPACESHIP) reduce 575) ((T_SR) reduce 575) (("^") reduce 575) (("|") reduce 575) (("}") reduce 575)) 5261 (((")") reduce 583) ((",") reduce 583)) 5262 ((("%") reduce 428) (("*") reduce 428) (("+") reduce 428) ((",") reduce 428) (("-") reduce 428) ((".") reduce 428) (("/") reduce 428) (("<") reduce 428) ((">") reduce 428) (("?") reduce 428) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_BOOLEAN_AND) reduce 428) ((T_BOOLEAN_OR) reduce 428) ((T_COALESCE) reduce 428) ((T_DOUBLE_ARROW) reduce 428) ((T_INSTANCEOF) reduce 428) ((T_IS_EQUAL) reduce 428) ((T_IS_GREATER_OR_EQUAL) reduce 428) ((T_IS_IDENTICAL) reduce 428) ((T_IS_NOT_EQUAL) reduce 428) ((T_IS_NOT_IDENTICAL) reduce 428) ((T_IS_SMALLER_OR_EQUAL) reduce 428) ((T_LOGICAL_AND) reduce 428) ((T_LOGICAL_OR) reduce 428) ((T_LOGICAL_XOR) reduce 428) ((T_POW) shift) ((T_SL) reduce 428) ((T_SPACESHIP) reduce 428) ((T_SR) reduce 428) (("^") reduce 428) (("|") reduce 428) (("}") reduce 428)) 5263 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 578) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 578) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 578)) 5264 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 577) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 577) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 577)) 5265 ((("%") reduce 387) (("*") reduce 387) (("+") reduce 387) ((",") reduce 387) (("-") reduce 387) ((".") reduce 387) (("/") reduce 387) (("<") reduce 387) ((">") reduce 387) (("?") reduce 387) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_BOOLEAN_AND) reduce 387) ((T_BOOLEAN_OR) reduce 387) ((T_COALESCE) reduce 387) ((T_DOUBLE_ARROW) reduce 387) ((T_INSTANCEOF) reduce 387) ((T_IS_EQUAL) reduce 387) ((T_IS_GREATER_OR_EQUAL) reduce 387) ((T_IS_IDENTICAL) reduce 387) ((T_IS_NOT_EQUAL) reduce 387) ((T_IS_NOT_IDENTICAL) reduce 387) ((T_IS_SMALLER_OR_EQUAL) reduce 387) ((T_LOGICAL_AND) reduce 387) ((T_LOGICAL_OR) reduce 387) ((T_LOGICAL_XOR) reduce 387) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 387) ((T_SL) reduce 387) ((T_SPACESHIP) reduce 387) ((T_SR) reduce 387) (("[") reduce 510) (("^") reduce 387) (("{") reduce 510) (("|") reduce 387) (("}") reduce 387)) 5266 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) ((")") reduce 507) (("+") shift) (("-") shift) (("@") shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("~") shift)) 5267 ((("%") reduce 435) (("*") reduce 435) (("+") reduce 435) ((",") reduce 435) (("-") reduce 435) ((".") reduce 435) (("/") reduce 435) (("<") reduce 435) ((">") reduce 435) (("?") reduce 435) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_BOOLEAN_AND) reduce 435) ((T_BOOLEAN_OR) reduce 435) ((T_COALESCE) reduce 435) ((T_DOUBLE_ARROW) reduce 435) ((T_INSTANCEOF) reduce 435) ((T_IS_EQUAL) reduce 435) ((T_IS_GREATER_OR_EQUAL) reduce 435) ((T_IS_IDENTICAL) reduce 435) ((T_IS_NOT_EQUAL) reduce 435) ((T_IS_NOT_IDENTICAL) reduce 435) ((T_IS_SMALLER_OR_EQUAL) reduce 435) ((T_LOGICAL_AND) reduce 435) ((T_LOGICAL_OR) reduce 435) ((T_LOGICAL_XOR) reduce 435) ((T_POW) reduce 435) ((T_SL) reduce 435) ((T_SPACESHIP) reduce 435) ((T_SR) reduce 435) (("^") reduce 435) (("|") reduce 435) (("}") reduce 435)) 5268 ((("%") shift) ((")") reduce 508) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 5270 ((("%") reduce 476) (("*") reduce 476) (("+") reduce 476) ((",") reduce 476) (("-") reduce 476) ((".") reduce 476) (("/") reduce 476) (("<") reduce 476) ((">") reduce 476) (("?") reduce 476) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_BOOLEAN_AND) reduce 476) ((T_BOOLEAN_OR) reduce 476) ((T_COALESCE) reduce 476) ((T_DOUBLE_ARROW) reduce 476) ((T_INSTANCEOF) reduce 476) ((T_IS_EQUAL) reduce 476) ((T_IS_GREATER_OR_EQUAL) reduce 476) ((T_IS_IDENTICAL) reduce 476) ((T_IS_NOT_EQUAL) reduce 476) ((T_IS_NOT_IDENTICAL) reduce 476) ((T_IS_SMALLER_OR_EQUAL) reduce 476) ((T_LOGICAL_AND) reduce 476) ((T_LOGICAL_OR) reduce 476) ((T_LOGICAL_XOR) reduce 476) ((T_POW) reduce 476) ((T_SL) reduce 476) ((T_SPACESHIP) reduce 476) ((T_SR) reduce 476) (("^") reduce 476) (("|") reduce 476) (("}") reduce 476)) 5273 ((("%") reduce 579) (("*") reduce 579) (("+") reduce 579) ((",") reduce 579) (("-") reduce 579) ((".") reduce 579) (("/") reduce 579) (("<") reduce 579) ((">") reduce 579) (("?") reduce 579) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_BOOLEAN_AND) reduce 579) ((T_BOOLEAN_OR) reduce 579) ((T_COALESCE) reduce 579) ((T_DOUBLE_ARROW) reduce 579) ((T_INSTANCEOF) reduce 579) ((T_IS_EQUAL) reduce 579) ((T_IS_GREATER_OR_EQUAL) reduce 579) ((T_IS_IDENTICAL) reduce 579) ((T_IS_NOT_EQUAL) reduce 579) ((T_IS_NOT_IDENTICAL) reduce 579) ((T_IS_SMALLER_OR_EQUAL) reduce 579) ((T_LOGICAL_AND) reduce 579) ((T_LOGICAL_OR) reduce 579) ((T_LOGICAL_XOR) reduce 579) ((T_POW) reduce 579) ((T_SL) reduce 579) ((T_SPACESHIP) reduce 579) ((T_SR) reduce 579) (("^") reduce 579) (("|") reduce 579) (("}") reduce 579)) 5276 ((("%") reduce 576) (("*") reduce 576) (("+") reduce 576) ((",") reduce 576) (("-") reduce 576) ((".") reduce 576) (("/") reduce 576) (("<") reduce 576) ((">") reduce 576) (("?") reduce 576) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_BOOLEAN_AND) reduce 576) ((T_BOOLEAN_OR) reduce 576) ((T_COALESCE) reduce 576) ((T_DOUBLE_ARROW) reduce 576) ((T_INSTANCEOF) reduce 576) ((T_IS_EQUAL) reduce 576) ((T_IS_GREATER_OR_EQUAL) reduce 576) ((T_IS_IDENTICAL) reduce 576) ((T_IS_NOT_EQUAL) reduce 576) ((T_IS_NOT_IDENTICAL) reduce 576) ((T_IS_SMALLER_OR_EQUAL) reduce 576) ((T_LOGICAL_AND) reduce 576) ((T_LOGICAL_OR) reduce 576) ((T_LOGICAL_XOR) reduce 576) ((T_POW) reduce 576) ((T_SL) reduce 576) ((T_SPACESHIP) reduce 576) ((T_SR) reduce 576) (("^") reduce 576) (("|") reduce 576) (("}") reduce 576)) 5277 ((("%") reduce 429) (("*") reduce 429) (("+") reduce 429) ((",") reduce 429) (("-") reduce 429) ((".") reduce 429) (("/") reduce 429) (("<") reduce 429) ((">") reduce 429) (("?") reduce 429) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_BOOLEAN_AND) reduce 429) ((T_BOOLEAN_OR) reduce 429) ((T_COALESCE) reduce 429) ((T_DOUBLE_ARROW) reduce 429) ((T_INSTANCEOF) reduce 429) ((T_IS_EQUAL) reduce 429) ((T_IS_GREATER_OR_EQUAL) reduce 429) ((T_IS_IDENTICAL) reduce 429) ((T_IS_NOT_EQUAL) reduce 429) ((T_IS_NOT_IDENTICAL) reduce 429) ((T_IS_SMALLER_OR_EQUAL) reduce 429) ((T_LOGICAL_AND) reduce 429) ((T_LOGICAL_OR) reduce 429) ((T_LOGICAL_XOR) reduce 429) ((T_POW) shift) ((T_SL) reduce 429) ((T_SPACESHIP) reduce 429) ((T_SR) reduce 429) (("^") reduce 429) (("|") reduce 429) (("}") reduce 429)) 5278 ((("%") reduce 389) (("*") reduce 389) (("+") reduce 389) ((",") reduce 389) (("-") reduce 389) ((".") reduce 389) (("/") reduce 389) (("<") reduce 389) ((">") reduce 389) (("?") reduce 389) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_BOOLEAN_AND) reduce 389) ((T_BOOLEAN_OR) reduce 389) ((T_COALESCE) reduce 389) ((T_DOUBLE_ARROW) reduce 389) ((T_INSTANCEOF) reduce 389) ((T_IS_EQUAL) reduce 389) ((T_IS_GREATER_OR_EQUAL) reduce 389) ((T_IS_IDENTICAL) reduce 389) ((T_IS_NOT_EQUAL) reduce 389) ((T_IS_NOT_IDENTICAL) reduce 389) ((T_IS_SMALLER_OR_EQUAL) reduce 389) ((T_LOGICAL_AND) reduce 389) ((T_LOGICAL_OR) reduce 389) ((T_LOGICAL_XOR) reduce 389) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 389) ((T_SL) reduce 389) ((T_SPACESHIP) reduce 389) ((T_SR) reduce 389) (("[") reduce 510) (("^") reduce 389) (("{") reduce 510) (("|") reduce 389) (("}") reduce 389)) 5279 ((("%") reduce 372) (("*") reduce 372) (("+") reduce 372) ((",") reduce 372) (("-") reduce 372) ((".") reduce 372) (("/") reduce 372) (("<") reduce 372) ((">") reduce 372) (("?") reduce 372) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_BOOLEAN_AND) reduce 372) ((T_BOOLEAN_OR) reduce 372) ((T_COALESCE) reduce 372) ((T_DOUBLE_ARROW) reduce 372) ((T_INSTANCEOF) reduce 372) ((T_IS_EQUAL) reduce 372) ((T_IS_GREATER_OR_EQUAL) reduce 372) ((T_IS_IDENTICAL) reduce 372) ((T_IS_NOT_EQUAL) reduce 372) ((T_IS_NOT_IDENTICAL) reduce 372) ((T_IS_SMALLER_OR_EQUAL) reduce 372) ((T_LOGICAL_AND) reduce 372) ((T_LOGICAL_OR) reduce 372) ((T_LOGICAL_XOR) reduce 372) ((T_POW) reduce 372) ((T_SL) reduce 372) ((T_SPACESHIP) reduce 372) ((T_SR) reduce 372) (("^") reduce 372) (("|") reduce 372) (("}") reduce 372)) 5280 ((("%") reduce 433) (("*") reduce 433) (("+") reduce 433) ((",") reduce 433) (("-") reduce 433) ((".") reduce 433) (("/") reduce 433) (("<") reduce 433) ((">") reduce 433) (("?") reduce 433) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_BOOLEAN_AND) reduce 433) ((T_BOOLEAN_OR) reduce 433) ((T_COALESCE) reduce 433) ((T_DOUBLE_ARROW) reduce 433) ((T_INSTANCEOF) reduce 433) ((T_IS_EQUAL) reduce 433) ((T_IS_GREATER_OR_EQUAL) reduce 433) ((T_IS_IDENTICAL) reduce 433) ((T_IS_NOT_EQUAL) reduce 433) ((T_IS_NOT_IDENTICAL) reduce 433) ((T_IS_SMALLER_OR_EQUAL) reduce 433) ((T_LOGICAL_AND) reduce 433) ((T_LOGICAL_OR) reduce 433) ((T_LOGICAL_XOR) reduce 433) ((T_POW) shift) ((T_SL) reduce 433) ((T_SPACESHIP) reduce 433) ((T_SR) reduce 433) (("^") reduce 433) (("|") reduce 433) (("}") reduce 433)) 5281 ((("%") reduce 431) (("*") reduce 431) (("+") reduce 431) ((",") reduce 431) (("-") reduce 431) ((".") reduce 431) (("/") reduce 431) (("<") reduce 431) ((">") reduce 431) (("?") reduce 431) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_BOOLEAN_AND) reduce 431) ((T_BOOLEAN_OR) reduce 431) ((T_COALESCE) reduce 431) ((T_DOUBLE_ARROW) reduce 431) ((T_INSTANCEOF) reduce 431) ((T_IS_EQUAL) reduce 431) ((T_IS_GREATER_OR_EQUAL) reduce 431) ((T_IS_IDENTICAL) reduce 431) ((T_IS_NOT_EQUAL) reduce 431) ((T_IS_NOT_IDENTICAL) reduce 431) ((T_IS_SMALLER_OR_EQUAL) reduce 431) ((T_LOGICAL_AND) reduce 431) ((T_LOGICAL_OR) reduce 431) ((T_LOGICAL_XOR) reduce 431) ((T_POW) shift) ((T_SL) reduce 431) ((T_SPACESHIP) reduce 431) ((T_SR) reduce 431) (("^") reduce 431) (("|") reduce 431) (("}") reduce 431)) 5284 ((("%") reduce 482) (("(") reduce 482) (("*") reduce 482) (("+") reduce 482) ((",") reduce 482) (("-") reduce 482) ((".") reduce 482) (("/") reduce 482) (("<") reduce 482) ((">") reduce 482) (("?") reduce 482) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_BOOLEAN_AND) reduce 482) ((T_BOOLEAN_OR) reduce 482) ((T_COALESCE) reduce 482) ((T_DOUBLE_ARROW) reduce 482) ((T_INSTANCEOF) reduce 482) ((T_IS_EQUAL) reduce 482) ((T_IS_GREATER_OR_EQUAL) reduce 482) ((T_IS_IDENTICAL) reduce 482) ((T_IS_NOT_EQUAL) reduce 482) ((T_IS_NOT_IDENTICAL) reduce 482) ((T_IS_SMALLER_OR_EQUAL) reduce 482) ((T_LOGICAL_AND) reduce 482) ((T_LOGICAL_OR) reduce 482) ((T_LOGICAL_XOR) reduce 482) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 482) ((T_OBJECT_OPERATOR) reduce 482) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 482) ((T_POW) reduce 482) ((T_SL) reduce 482) ((T_SPACESHIP) reduce 482) ((T_SR) reduce 482) (("[") reduce 482) (("^") reduce 482) (("{") reduce 482) (("|") reduce 482) (("}") reduce 482)) 5285 ((("%") reduce 436) (("*") reduce 436) (("+") reduce 436) ((",") reduce 436) (("-") reduce 436) ((".") reduce 436) (("/") reduce 436) (("<") reduce 436) ((">") reduce 436) (("?") reduce 436) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_BOOLEAN_AND) reduce 436) ((T_BOOLEAN_OR) reduce 436) ((T_COALESCE) reduce 436) ((T_DOUBLE_ARROW) reduce 436) ((T_INSTANCEOF) reduce 436) ((T_IS_EQUAL) reduce 436) ((T_IS_GREATER_OR_EQUAL) reduce 436) ((T_IS_IDENTICAL) reduce 436) ((T_IS_NOT_EQUAL) reduce 436) ((T_IS_NOT_IDENTICAL) reduce 436) ((T_IS_SMALLER_OR_EQUAL) reduce 436) ((T_LOGICAL_AND) reduce 436) ((T_LOGICAL_OR) reduce 436) ((T_LOGICAL_XOR) reduce 436) ((T_POW) shift) ((T_SL) reduce 436) ((T_SPACESHIP) reduce 436) ((T_SR) reduce 436) (("^") reduce 436) (("|") reduce 436) (("}") reduce 436)) 5286 ((("%") reduce 409) (("*") reduce 409) (("+") reduce 409) ((",") reduce 409) (("-") reduce 409) ((".") reduce 409) (("/") reduce 409) (("<") reduce 409) ((">") reduce 409) (("?") reduce 409) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_BOOLEAN_AND) reduce 409) ((T_BOOLEAN_OR) reduce 409) ((T_COALESCE) reduce 409) ((T_DOUBLE_ARROW) reduce 409) ((T_INSTANCEOF) reduce 409) ((T_IS_EQUAL) reduce 409) ((T_IS_GREATER_OR_EQUAL) reduce 409) ((T_IS_IDENTICAL) reduce 409) ((T_IS_NOT_EQUAL) reduce 409) ((T_IS_NOT_IDENTICAL) reduce 409) ((T_IS_SMALLER_OR_EQUAL) reduce 409) ((T_LOGICAL_AND) reduce 409) ((T_LOGICAL_OR) reduce 409) ((T_LOGICAL_XOR) reduce 409) ((T_POW) shift) ((T_SL) reduce 409) ((T_SPACESHIP) reduce 409) ((T_SR) reduce 409) (("^") reduce 409) (("|") reduce 409) (("}") reduce 409)) 5287 ((("%") reduce 408) (("*") reduce 408) (("+") reduce 408) ((",") reduce 408) (("-") reduce 408) ((".") reduce 408) (("/") reduce 408) (("<") reduce 408) ((">") reduce 408) (("?") reduce 408) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_BOOLEAN_AND) reduce 408) ((T_BOOLEAN_OR) reduce 408) ((T_COALESCE) reduce 408) ((T_DOUBLE_ARROW) reduce 408) ((T_INSTANCEOF) reduce 408) ((T_IS_EQUAL) reduce 408) ((T_IS_GREATER_OR_EQUAL) reduce 408) ((T_IS_IDENTICAL) reduce 408) ((T_IS_NOT_EQUAL) reduce 408) ((T_IS_NOT_IDENTICAL) reduce 408) ((T_IS_SMALLER_OR_EQUAL) reduce 408) ((T_LOGICAL_AND) reduce 408) ((T_LOGICAL_OR) reduce 408) ((T_LOGICAL_XOR) reduce 408) ((T_POW) shift) ((T_SL) reduce 408) ((T_SPACESHIP) reduce 408) ((T_SR) reduce 408) (("^") reduce 408) (("|") reduce 408) (("}") reduce 408)) 5289 ((("%") reduce 422) (("(") reduce 517) (("*") reduce 422) (("+") reduce 422) ((",") reduce 422) (("-") reduce 422) ((".") reduce 422) (("/") reduce 422) (("<") reduce 422) ((">") reduce 422) (("?") reduce 422) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_BOOLEAN_AND) reduce 422) ((T_BOOLEAN_OR) reduce 422) ((T_COALESCE) reduce 422) ((T_DOUBLE_ARROW) reduce 422) ((T_INSTANCEOF) reduce 422) ((T_IS_EQUAL) reduce 422) ((T_IS_GREATER_OR_EQUAL) reduce 422) ((T_IS_IDENTICAL) reduce 422) ((T_IS_NOT_EQUAL) reduce 422) ((T_IS_NOT_IDENTICAL) reduce 422) ((T_IS_SMALLER_OR_EQUAL) reduce 422) ((T_LOGICAL_AND) reduce 422) ((T_LOGICAL_OR) reduce 422) ((T_LOGICAL_XOR) reduce 422) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 511) ((T_OBJECT_OPERATOR) reduce 511) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 511) ((T_POW) reduce 422) ((T_SL) reduce 422) ((T_SPACESHIP) reduce 422) ((T_SR) reduce 422) (("[") reduce 511) (("^") reduce 422) (("{") reduce 511) (("|") reduce 422) (("}") reduce 422)) 5290 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) ((",") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) (("=") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AND_EQUAL) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_COALESCE_EQUAL) reduce 531) ((T_CONCAT_EQUAL) reduce 531) ((T_DEC) reduce 531) ((T_DIV_EQUAL) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INC) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_MINUS_EQUAL) reduce 531) ((T_MOD_EQUAL) reduce 531) ((T_MUL_EQUAL) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_OR_EQUAL) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_PLUS_EQUAL) reduce 531) ((T_POW) reduce 531) ((T_POW_EQUAL) reduce 531) ((T_SL) reduce 531) ((T_SL_EQUAL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) ((T_SR_EQUAL) reduce 531) ((T_XOR_EQUAL) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531) (("}") reduce 531)) 5293 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) ((",") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) (("=") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AND_EQUAL) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_COALESCE_EQUAL) reduce 530) ((T_CONCAT_EQUAL) reduce 530) ((T_DEC) reduce 530) ((T_DIV_EQUAL) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INC) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_MINUS_EQUAL) reduce 530) ((T_MOD_EQUAL) reduce 530) ((T_MUL_EQUAL) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_OR_EQUAL) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_PLUS_EQUAL) reduce 530) ((T_POW) reduce 530) ((T_POW_EQUAL) reduce 530) ((T_SL) reduce 530) ((T_SL_EQUAL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) ((T_SR_EQUAL) reduce 530) ((T_XOR_EQUAL) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530) (("}") reduce 530)) 5296 (((T_CURLY_OPEN) shift) ((T_DOLLAR_OPEN_CURLY_BRACES) shift) ((T_VARIABLE) shift)) 5297 ((("\"") reduce 563) ((T_CURLY_OPEN) reduce 563) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 563) ((T_ENCAPSED_AND_WHITESPACE) reduce 563) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_VARIABLE) reduce 563) (("[") shift)) 5298 ((("\"") shift) ((T_CURLY_OPEN) shift) ((T_DOLLAR_OPEN_CURLY_BRACES) shift) ((T_ENCAPSED_AND_WHITESPACE) shift) ((T_VARIABLE) shift)) 5299 ((("\"") reduce 561) ((T_CURLY_OPEN) reduce 561) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 561) ((T_ENCAPSED_AND_WHITESPACE) reduce 561) ((T_VARIABLE) reduce 561)) 5300 ((("%") reduce 485) (("(") reduce 485) (("*") reduce 485) (("+") reduce 485) ((",") reduce 485) (("-") reduce 485) ((".") reduce 485) (("/") reduce 485) (("<") reduce 485) ((">") reduce 485) (("?") reduce 485) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_BOOLEAN_AND) reduce 485) ((T_BOOLEAN_OR) reduce 485) ((T_COALESCE) reduce 485) ((T_DOUBLE_ARROW) reduce 485) ((T_INSTANCEOF) reduce 485) ((T_IS_EQUAL) reduce 485) ((T_IS_GREATER_OR_EQUAL) reduce 485) ((T_IS_IDENTICAL) reduce 485) ((T_IS_NOT_EQUAL) reduce 485) ((T_IS_NOT_IDENTICAL) reduce 485) ((T_IS_SMALLER_OR_EQUAL) reduce 485) ((T_LOGICAL_AND) reduce 485) ((T_LOGICAL_OR) reduce 485) ((T_LOGICAL_XOR) reduce 485) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 485) ((T_OBJECT_OPERATOR) reduce 485) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 485) ((T_POW) reduce 485) ((T_SL) reduce 485) ((T_SPACESHIP) reduce 485) ((T_SR) reduce 485) (("[") reduce 485) (("^") reduce 485) (("{") reduce 485) (("|") reduce 485) (("}") reduce 485)) 5301 ((("\"") reduce 560) ((T_CURLY_OPEN) reduce 560) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 560) ((T_ENCAPSED_AND_WHITESPACE) reduce 560) ((T_VARIABLE) reduce 560)) 5302 ((("\"") reduce 559) ((T_CURLY_OPEN) reduce 559) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 559) ((T_ENCAPSED_AND_WHITESPACE) reduce 559) ((T_VARIABLE) reduce 559)) 5307 ((("\"") reduce 564) ((T_CURLY_OPEN) reduce 564) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 564) ((T_ENCAPSED_AND_WHITESPACE) reduce 564) ((T_VARIABLE) reduce 564)) 5308 ((("\"") reduce 565) ((T_CURLY_OPEN) reduce 565) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 565) ((T_ENCAPSED_AND_WHITESPACE) reduce 565) ((T_VARIABLE) reduce 565)) 5309 ((("\"") reduce 566) ((T_CURLY_OPEN) reduce 566) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 566) ((T_ENCAPSED_AND_WHITESPACE) reduce 566) ((T_VARIABLE) reduce 566)) 5310 ((("\"") reduce 562) ((T_CURLY_OPEN) reduce 562) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 562) ((T_ENCAPSED_AND_WHITESPACE) reduce 562) ((T_VARIABLE) reduce 562)) 5313 ((("\"") reduce 567) ((T_CURLY_OPEN) reduce 567) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 567) ((T_ENCAPSED_AND_WHITESPACE) reduce 567) ((T_VARIABLE) reduce 567)) 5315 ((("\"") reduce 568) ((T_CURLY_OPEN) reduce 568) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 568) ((T_ENCAPSED_AND_WHITESPACE) reduce 568) ((T_VARIABLE) reduce 568)) 5318 ((("\"") reduce 569) ((T_CURLY_OPEN) reduce 569) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 569) ((T_ENCAPSED_AND_WHITESPACE) reduce 569) ((T_VARIABLE) reduce 569)) 5320 ((("\"") reduce 570) ((T_CURLY_OPEN) reduce 570) ((T_DOLLAR_OPEN_CURLY_BRACES) reduce 570) ((T_ENCAPSED_AND_WHITESPACE) reduce 570) ((T_VARIABLE) reduce 570)) 5321 ((("%") reduce 410) (("*") reduce 410) (("+") reduce 410) ((",") reduce 410) (("-") reduce 410) ((".") reduce 410) (("/") reduce 410) (("<") reduce 410) ((">") reduce 410) (("?") reduce 410) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_BOOLEAN_AND) reduce 410) ((T_BOOLEAN_OR) reduce 410) ((T_COALESCE) reduce 410) ((T_DOUBLE_ARROW) reduce 410) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 410) ((T_IS_GREATER_OR_EQUAL) reduce 410) ((T_IS_IDENTICAL) reduce 410) ((T_IS_NOT_EQUAL) reduce 410) ((T_IS_NOT_IDENTICAL) reduce 410) ((T_IS_SMALLER_OR_EQUAL) reduce 410) ((T_LOGICAL_AND) reduce 410) ((T_LOGICAL_OR) reduce 410) ((T_LOGICAL_XOR) reduce 410) ((T_POW) shift) ((T_SL) reduce 410) ((T_SPACESHIP) reduce 410) ((T_SR) reduce 410) (("^") reduce 410) (("|") reduce 410) (("}") reduce 410)) 5322 ((("%") reduce 434) (("*") reduce 434) (("+") reduce 434) ((",") reduce 434) (("-") reduce 434) ((".") reduce 434) (("/") reduce 434) (("<") reduce 434) ((">") reduce 434) (("?") reduce 434) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_BOOLEAN_AND) reduce 434) ((T_BOOLEAN_OR) reduce 434) ((T_COALESCE) reduce 434) ((T_INSTANCEOF) reduce 434) ((T_IS_EQUAL) reduce 434) ((T_IS_GREATER_OR_EQUAL) reduce 434) ((T_IS_IDENTICAL) reduce 434) ((T_IS_NOT_EQUAL) reduce 434) ((T_IS_NOT_IDENTICAL) reduce 434) ((T_IS_SMALLER_OR_EQUAL) reduce 434) ((T_LOGICAL_AND) reduce 434) ((T_LOGICAL_OR) reduce 434) ((T_LOGICAL_XOR) reduce 434) ((T_POW) shift) ((T_SL) reduce 434) ((T_SPACESHIP) reduce 434) ((T_SR) reduce 434) (("^") reduce 434) (("|") reduce 434) (("}") reduce 434)) 5323 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 444) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 444)) 5324 ((("%") reduce 430) (("*") reduce 430) (("+") reduce 430) ((",") reduce 430) (("-") reduce 430) ((".") reduce 430) (("/") reduce 430) (("<") reduce 430) ((">") reduce 430) (("?") reduce 430) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_BOOLEAN_AND) reduce 430) ((T_BOOLEAN_OR) reduce 430) ((T_COALESCE) reduce 430) ((T_INSTANCEOF) reduce 430) ((T_IS_EQUAL) reduce 430) ((T_IS_GREATER_OR_EQUAL) reduce 430) ((T_IS_IDENTICAL) reduce 430) ((T_IS_NOT_EQUAL) reduce 430) ((T_IS_NOT_IDENTICAL) reduce 430) ((T_IS_SMALLER_OR_EQUAL) reduce 430) ((T_LOGICAL_AND) reduce 430) ((T_LOGICAL_OR) reduce 430) ((T_LOGICAL_XOR) reduce 430) ((T_POW) shift) ((T_SL) reduce 430) ((T_SPACESHIP) reduce 430) ((T_SR) reduce 430) (("^") reduce 430) (("|") reduce 430) (("}") reduce 430)) 5325 ((("%") reduce 447) (("*") reduce 447) (("+") reduce 447) ((",") reduce 447) (("-") reduce 447) ((".") reduce 447) (("/") reduce 447) (("<") reduce 447) ((">") reduce 447) (("?") reduce 447) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_BOOLEAN_AND) reduce 447) ((T_BOOLEAN_OR) reduce 447) ((T_COALESCE) reduce 447) ((T_INSTANCEOF) reduce 447) ((T_IS_EQUAL) reduce 447) ((T_IS_GREATER_OR_EQUAL) reduce 447) ((T_IS_IDENTICAL) reduce 447) ((T_IS_NOT_EQUAL) reduce 447) ((T_IS_NOT_IDENTICAL) reduce 447) ((T_IS_SMALLER_OR_EQUAL) reduce 447) ((T_LOGICAL_AND) reduce 447) ((T_LOGICAL_OR) reduce 447) ((T_LOGICAL_XOR) reduce 447) ((T_POW) reduce 447) ((T_SL) reduce 447) ((T_SPACESHIP) reduce 447) ((T_SR) reduce 447) (("^") reduce 447) (("|") reduce 447) (("}") reduce 447)) 5327 ((("%") reduce 489) (("*") reduce 489) (("+") reduce 489) ((",") reduce 489) (("-") reduce 489) ((".") reduce 489) (("/") reduce 489) (("<") reduce 489) ((">") reduce 489) (("?") reduce 489) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_BOOLEAN_AND) reduce 489) ((T_BOOLEAN_OR) reduce 489) ((T_COALESCE) reduce 489) ((T_INSTANCEOF) reduce 489) ((T_IS_EQUAL) reduce 489) ((T_IS_GREATER_OR_EQUAL) reduce 489) ((T_IS_IDENTICAL) reduce 489) ((T_IS_NOT_EQUAL) reduce 489) ((T_IS_NOT_IDENTICAL) reduce 489) ((T_IS_SMALLER_OR_EQUAL) reduce 489) ((T_LOGICAL_AND) reduce 489) ((T_LOGICAL_OR) reduce 489) ((T_LOGICAL_XOR) reduce 489) ((T_POW) reduce 489) ((T_SL) reduce 489) ((T_SPACESHIP) reduce 489) ((T_SR) reduce 489) (("^") reduce 489) (("|") reduce 489) (("}") reduce 489)) 5329 ((("%") reduce 490) (("*") reduce 490) (("+") reduce 490) ((",") reduce 490) (("-") reduce 490) ((".") reduce 490) (("/") reduce 490) (("<") reduce 490) ((">") reduce 490) (("?") reduce 490) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_BOOLEAN_AND) reduce 490) ((T_BOOLEAN_OR) reduce 490) ((T_COALESCE) reduce 490) ((T_INSTANCEOF) reduce 490) ((T_IS_EQUAL) reduce 490) ((T_IS_GREATER_OR_EQUAL) reduce 490) ((T_IS_IDENTICAL) reduce 490) ((T_IS_NOT_EQUAL) reduce 490) ((T_IS_NOT_IDENTICAL) reduce 490) ((T_IS_SMALLER_OR_EQUAL) reduce 490) ((T_LOGICAL_AND) reduce 490) ((T_LOGICAL_OR) reduce 490) ((T_LOGICAL_XOR) reduce 490) ((T_POW) reduce 490) ((T_SL) reduce 490) ((T_SPACESHIP) reduce 490) ((T_SR) reduce 490) (("^") reduce 490) (("|") reduce 490) (("}") reduce 490)) 5330 ((("%") reduce 488) (("*") reduce 488) (("+") reduce 488) ((",") reduce 488) (("-") reduce 488) ((".") reduce 488) (("/") reduce 488) (("<") reduce 488) ((">") reduce 488) (("?") reduce 488) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_BOOLEAN_AND) reduce 488) ((T_BOOLEAN_OR) reduce 488) ((T_COALESCE) reduce 488) ((T_INSTANCEOF) reduce 488) ((T_IS_EQUAL) reduce 488) ((T_IS_GREATER_OR_EQUAL) reduce 488) ((T_IS_IDENTICAL) reduce 488) ((T_IS_NOT_EQUAL) reduce 488) ((T_IS_NOT_IDENTICAL) reduce 488) ((T_IS_SMALLER_OR_EQUAL) reduce 488) ((T_LOGICAL_AND) reduce 488) ((T_LOGICAL_OR) reduce 488) ((T_LOGICAL_XOR) reduce 488) ((T_POW) reduce 488) ((T_SL) reduce 488) ((T_SPACESHIP) reduce 488) ((T_SR) reduce 488) (("^") reduce 488) (("|") reduce 488) (("}") reduce 488)) 5331 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 581) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 581)) 5332 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 580) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 580)) 5333 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) ((",") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) (("<") reduce 466) (("=") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AND_EQUAL) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_COALESCE_EQUAL) reduce 466) ((T_CONCAT_EQUAL) reduce 466) ((T_DEC) reduce 466) ((T_DIV_EQUAL) reduce 466) ((T_INC) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_MINUS_EQUAL) reduce 466) ((T_MOD_EQUAL) reduce 466) ((T_MUL_EQUAL) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_OR_EQUAL) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_PLUS_EQUAL) reduce 466) ((T_POW) reduce 466) ((T_POW_EQUAL) reduce 466) ((T_SL) reduce 466) ((T_SL_EQUAL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) ((T_SR_EQUAL) reduce 466) ((T_XOR_EQUAL) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466) (("}") reduce 466)) 5334 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 439) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 439) ((T_LOGICAL_OR) reduce 439) ((T_LOGICAL_XOR) reduce 439) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 439)) 5335 ((("%") reduce 432) (("*") reduce 432) (("+") reduce 432) ((",") reduce 432) (("-") reduce 432) ((".") reduce 432) (("/") reduce 432) (("<") reduce 432) ((">") reduce 432) (("?") reduce 432) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_BOOLEAN_AND) reduce 432) ((T_BOOLEAN_OR) reduce 432) ((T_COALESCE) reduce 432) ((T_INSTANCEOF) reduce 432) ((T_IS_EQUAL) reduce 432) ((T_IS_GREATER_OR_EQUAL) reduce 432) ((T_IS_IDENTICAL) reduce 432) ((T_IS_NOT_EQUAL) reduce 432) ((T_IS_NOT_IDENTICAL) reduce 432) ((T_IS_SMALLER_OR_EQUAL) reduce 432) ((T_LOGICAL_AND) reduce 432) ((T_LOGICAL_OR) reduce 432) ((T_LOGICAL_XOR) reduce 432) ((T_POW) shift) ((T_SL) reduce 432) ((T_SPACESHIP) reduce 432) ((T_SR) reduce 432) (("^") reduce 432) (("|") reduce 432) (("}") reduce 432)) 5337 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) ((",") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93) (("}") reduce 93)) 5338 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) ((",") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92) (("}") reduce 92)) 5339 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) ((",") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94) (("}") reduce 94)) 5340 ((("%") reduce 470) (("(") reduce 470) (("*") reduce 470) (("+") reduce 470) ((",") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470) (("}") reduce 470)) 5341 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) ((",") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91) (("}") reduce 91)) 5342 ((("%") reduce 365) (("*") reduce 365) (("+") reduce 365) ((",") reduce 365) (("-") reduce 365) ((".") reduce 365) (("/") reduce 365) (("<") reduce 365) ((">") reduce 365) (("?") reduce 365) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_BOOLEAN_AND) reduce 365) ((T_BOOLEAN_OR) reduce 365) ((T_COALESCE) reduce 365) ((T_INSTANCEOF) reduce 365) ((T_IS_EQUAL) reduce 365) ((T_IS_GREATER_OR_EQUAL) reduce 365) ((T_IS_IDENTICAL) reduce 365) ((T_IS_NOT_EQUAL) reduce 365) ((T_IS_NOT_IDENTICAL) reduce 365) ((T_IS_SMALLER_OR_EQUAL) reduce 365) ((T_LOGICAL_AND) reduce 365) ((T_LOGICAL_OR) reduce 365) ((T_LOGICAL_XOR) reduce 365) ((T_POW) reduce 365) ((T_SL) reduce 365) ((T_SPACESHIP) reduce 365) ((T_SR) reduce 365) (("^") reduce 365) (("|") reduce 365) (("}") reduce 365)) 5345 ((("%") reduce 472) (("(") reduce 472) (("*") reduce 472) (("+") reduce 472) ((",") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472) (("}") reduce 472)) 5346 ((("%") reduce 480) (("(") shift) (("*") reduce 480) (("+") reduce 480) ((",") reduce 480) (("-") reduce 480) ((".") reduce 480) (("/") reduce 480) (("<") reduce 480) ((">") reduce 480) (("?") reduce 480) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_BOOLEAN_AND) reduce 480) ((T_BOOLEAN_OR) reduce 480) ((T_COALESCE) reduce 480) ((T_INSTANCEOF) reduce 480) ((T_IS_EQUAL) reduce 480) ((T_IS_GREATER_OR_EQUAL) reduce 480) ((T_IS_IDENTICAL) reduce 480) ((T_IS_NOT_EQUAL) reduce 480) ((T_IS_NOT_IDENTICAL) reduce 480) ((T_IS_SMALLER_OR_EQUAL) reduce 480) ((T_LOGICAL_AND) reduce 480) ((T_LOGICAL_OR) reduce 480) ((T_LOGICAL_XOR) reduce 480) ((T_POW) reduce 480) ((T_SL) reduce 480) ((T_SPACESHIP) reduce 480) ((T_SR) reduce 480) (("^") reduce 480) (("|") reduce 480) (("}") reduce 480)) 5347 ((("%") reduce 471) (("(") reduce 471) (("*") reduce 471) (("+") reduce 471) ((",") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471) (("}") reduce 471)) 5348 ((("%") reduce 473) (("(") reduce 473) (("*") reduce 473) (("+") reduce 473) ((",") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473) (("}") reduce 473)) 5349 ((("%") reduce 534) (("(") reduce 534) (("*") reduce 534) (("+") reduce 534) ((",") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534) (("}") reduce 534)) 5356 ((("%") reduce 536) (("(") reduce 536) (("*") reduce 536) (("+") reduce 536) ((",") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536) (("}") reduce 536)) 5358 ((("%") reduce 535) (("(") reduce 535) (("*") reduce 535) (("+") reduce 535) ((",") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535) (("}") reduce 535)) 5359 ((("%") reduce 540) (("(") reduce 540) (("*") reduce 540) (("+") reduce 540) ((",") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540) (("}") reduce 540)) 5360 ((("%") reduce 537) (("(") reduce 537) (("*") reduce 537) (("+") reduce 537) ((",") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537) (("}") reduce 537)) 5361 ((("%") reduce 538) (("(") reduce 538) (("*") reduce 538) (("+") reduce 538) ((",") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538) (("}") reduce 538)) 5363 ((("%") reduce 481) (("*") reduce 481) (("+") reduce 481) ((",") reduce 481) (("-") reduce 481) ((".") reduce 481) (("/") reduce 481) (("<") reduce 481) ((">") reduce 481) (("?") reduce 481) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_BOOLEAN_AND) reduce 481) ((T_BOOLEAN_OR) reduce 481) ((T_COALESCE) reduce 481) ((T_INSTANCEOF) reduce 481) ((T_IS_EQUAL) reduce 481) ((T_IS_GREATER_OR_EQUAL) reduce 481) ((T_IS_IDENTICAL) reduce 481) ((T_IS_NOT_EQUAL) reduce 481) ((T_IS_NOT_IDENTICAL) reduce 481) ((T_IS_SMALLER_OR_EQUAL) reduce 481) ((T_LOGICAL_AND) reduce 481) ((T_LOGICAL_OR) reduce 481) ((T_LOGICAL_XOR) reduce 481) ((T_POW) reduce 481) ((T_SL) reduce 481) ((T_SPACESHIP) reduce 481) ((T_SR) reduce 481) (("^") reduce 481) (("|") reduce 481) (("}") reduce 481)) 5364 ((("%") reduce 364) (("*") reduce 364) (("+") reduce 364) ((",") reduce 364) (("-") reduce 364) ((".") reduce 364) (("/") reduce 364) (("<") reduce 364) ((">") reduce 364) (("?") reduce 364) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_BOOLEAN_AND) reduce 364) ((T_BOOLEAN_OR) reduce 364) ((T_COALESCE) reduce 364) ((T_INSTANCEOF) reduce 364) ((T_IS_EQUAL) reduce 364) ((T_IS_GREATER_OR_EQUAL) reduce 364) ((T_IS_IDENTICAL) reduce 364) ((T_IS_NOT_EQUAL) reduce 364) ((T_IS_NOT_IDENTICAL) reduce 364) ((T_IS_SMALLER_OR_EQUAL) reduce 364) ((T_LOGICAL_AND) reduce 364) ((T_LOGICAL_OR) reduce 364) ((T_LOGICAL_XOR) reduce 364) ((T_POW) reduce 364) ((T_SL) reduce 364) ((T_SPACESHIP) reduce 364) ((T_SR) reduce 364) (("^") reduce 364) (("|") reduce 364) (("}") reduce 364)) 5365 ((("%") reduce 288) (("*") reduce 288) (("+") reduce 288) ((",") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("^") reduce 288) (("|") reduce 288) (("}") reduce 288)) 5369 ((("%") reduce 289) (("*") reduce 289) (("+") reduce 289) ((",") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("^") reduce 289) (("|") reduce 289) (("}") reduce 289)) 5370 ((("%") reduce 290) (("*") reduce 290) (("+") reduce 290) ((",") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("^") reduce 290) (("|") reduce 290) (("}") reduce 290)) 5372 ((("%") reduce 539) (("(") reduce 539) (("*") reduce 539) (("+") reduce 539) ((",") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539) (("}") reduce 539)) 5373 ((("%") reduce 366) (("*") reduce 366) (("+") reduce 366) ((",") reduce 366) (("-") reduce 366) ((".") reduce 366) (("/") reduce 366) (("<") reduce 366) ((">") reduce 366) (("?") reduce 366) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_BOOLEAN_AND) reduce 366) ((T_BOOLEAN_OR) reduce 366) ((T_COALESCE) reduce 366) ((T_INSTANCEOF) reduce 366) ((T_IS_EQUAL) reduce 366) ((T_IS_GREATER_OR_EQUAL) reduce 366) ((T_IS_IDENTICAL) reduce 366) ((T_IS_NOT_EQUAL) reduce 366) ((T_IS_NOT_IDENTICAL) reduce 366) ((T_IS_SMALLER_OR_EQUAL) reduce 366) ((T_LOGICAL_AND) reduce 366) ((T_LOGICAL_OR) reduce 366) ((T_LOGICAL_XOR) reduce 366) ((T_POW) reduce 366) ((T_SL) reduce 366) ((T_SPACESHIP) reduce 366) ((T_SR) reduce 366) (("^") reduce 366) (("|") reduce 366) (("}") reduce 366)) 5381 ((("%") reduce 363) (("*") reduce 363) (("+") reduce 363) ((",") reduce 363) (("-") reduce 363) ((".") reduce 363) (("/") reduce 363) (("<") reduce 363) ((">") reduce 363) (("?") reduce 363) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_BOOLEAN_AND) reduce 363) ((T_BOOLEAN_OR) reduce 363) ((T_COALESCE) reduce 363) ((T_INSTANCEOF) reduce 363) ((T_IS_EQUAL) reduce 363) ((T_IS_GREATER_OR_EQUAL) reduce 363) ((T_IS_IDENTICAL) reduce 363) ((T_IS_NOT_EQUAL) reduce 363) ((T_IS_NOT_IDENTICAL) reduce 363) ((T_IS_SMALLER_OR_EQUAL) reduce 363) ((T_LOGICAL_AND) reduce 363) ((T_LOGICAL_OR) reduce 363) ((T_LOGICAL_XOR) reduce 363) ((T_POW) reduce 363) ((T_SL) reduce 363) ((T_SPACESHIP) reduce 363) ((T_SR) reduce 363) (("^") reduce 363) (("|") reduce 363) (("}") reduce 363)) 5383 ((("%") reduce 474) (("(") reduce 474) (("*") reduce 474) (("+") reduce 474) ((",") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474) (("}") reduce 474)) 5389 ((("%") reduce 230) (("*") reduce 230) (("+") reduce 230) ((",") reduce 230) (("-") reduce 230) ((".") reduce 230) (("/") reduce 230) (("<") reduce 230) ((">") reduce 230) (("?") reduce 230) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_BOOLEAN_AND) reduce 230) ((T_BOOLEAN_OR) reduce 230) ((T_COALESCE) reduce 230) ((T_INSTANCEOF) reduce 230) ((T_IS_EQUAL) reduce 230) ((T_IS_GREATER_OR_EQUAL) reduce 230) ((T_IS_IDENTICAL) reduce 230) ((T_IS_NOT_EQUAL) reduce 230) ((T_IS_NOT_IDENTICAL) reduce 230) ((T_IS_SMALLER_OR_EQUAL) reduce 230) ((T_LOGICAL_AND) reduce 230) ((T_LOGICAL_OR) reduce 230) ((T_LOGICAL_XOR) reduce 230) ((T_POW) reduce 230) ((T_SL) reduce 230) ((T_SPACESHIP) reduce 230) ((T_SR) reduce 230) (("^") reduce 230) (("|") reduce 230) (("}") reduce 230)) 5394 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 368) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 368) ((T_LOGICAL_OR) reduce 368) ((T_LOGICAL_XOR) reduce 368) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 368)) 5398 ((("%") reduce 575) (("*") reduce 575) (("+") reduce 575) ((",") reduce 575) (("-") reduce 575) ((".") reduce 575) (("/") reduce 575) (("<") reduce 575) ((">") reduce 575) (("?") reduce 575) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_BOOLEAN_AND) reduce 575) ((T_BOOLEAN_OR) reduce 575) ((T_COALESCE) reduce 575) ((T_INSTANCEOF) reduce 575) ((T_IS_EQUAL) reduce 575) ((T_IS_GREATER_OR_EQUAL) reduce 575) ((T_IS_IDENTICAL) reduce 575) ((T_IS_NOT_EQUAL) reduce 575) ((T_IS_NOT_IDENTICAL) reduce 575) ((T_IS_SMALLER_OR_EQUAL) reduce 575) ((T_LOGICAL_AND) reduce 575) ((T_LOGICAL_OR) reduce 575) ((T_LOGICAL_XOR) reduce 575) ((T_POW) reduce 575) ((T_SL) reduce 575) ((T_SPACESHIP) reduce 575) ((T_SR) reduce 575) (("^") reduce 575) (("|") reduce 575) (("}") reduce 575)) 5399 ((("%") reduce 428) (("*") reduce 428) (("+") reduce 428) ((",") reduce 428) (("-") reduce 428) ((".") reduce 428) (("/") reduce 428) (("<") reduce 428) ((">") reduce 428) (("?") reduce 428) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_BOOLEAN_AND) reduce 428) ((T_BOOLEAN_OR) reduce 428) ((T_COALESCE) reduce 428) ((T_INSTANCEOF) reduce 428) ((T_IS_EQUAL) reduce 428) ((T_IS_GREATER_OR_EQUAL) reduce 428) ((T_IS_IDENTICAL) reduce 428) ((T_IS_NOT_EQUAL) reduce 428) ((T_IS_NOT_IDENTICAL) reduce 428) ((T_IS_SMALLER_OR_EQUAL) reduce 428) ((T_LOGICAL_AND) reduce 428) ((T_LOGICAL_OR) reduce 428) ((T_LOGICAL_XOR) reduce 428) ((T_POW) shift) ((T_SL) reduce 428) ((T_SPACESHIP) reduce 428) ((T_SR) reduce 428) (("^") reduce 428) (("|") reduce 428) (("}") reduce 428)) 5400 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 578) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 578)) 5401 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 577) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 577)) 5402 ((("%") reduce 387) (("*") reduce 387) (("+") reduce 387) ((",") reduce 387) (("-") reduce 387) ((".") reduce 387) (("/") reduce 387) (("<") reduce 387) ((">") reduce 387) (("?") reduce 387) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_BOOLEAN_AND) reduce 387) ((T_BOOLEAN_OR) reduce 387) ((T_COALESCE) reduce 387) ((T_INSTANCEOF) reduce 387) ((T_IS_EQUAL) reduce 387) ((T_IS_GREATER_OR_EQUAL) reduce 387) ((T_IS_IDENTICAL) reduce 387) ((T_IS_NOT_EQUAL) reduce 387) ((T_IS_NOT_IDENTICAL) reduce 387) ((T_IS_SMALLER_OR_EQUAL) reduce 387) ((T_LOGICAL_AND) reduce 387) ((T_LOGICAL_OR) reduce 387) ((T_LOGICAL_XOR) reduce 387) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 387) ((T_SL) reduce 387) ((T_SPACESHIP) reduce 387) ((T_SR) reduce 387) (("[") reduce 510) (("^") reduce 387) (("{") reduce 510) (("|") reduce 387) (("}") reduce 387)) 5404 ((("%") reduce 435) (("*") reduce 435) (("+") reduce 435) ((",") reduce 435) (("-") reduce 435) ((".") reduce 435) (("/") reduce 435) (("<") reduce 435) ((">") reduce 435) (("?") reduce 435) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_BOOLEAN_AND) reduce 435) ((T_BOOLEAN_OR) reduce 435) ((T_COALESCE) reduce 435) ((T_INSTANCEOF) reduce 435) ((T_IS_EQUAL) reduce 435) ((T_IS_GREATER_OR_EQUAL) reduce 435) ((T_IS_IDENTICAL) reduce 435) ((T_IS_NOT_EQUAL) reduce 435) ((T_IS_NOT_IDENTICAL) reduce 435) ((T_IS_SMALLER_OR_EQUAL) reduce 435) ((T_LOGICAL_AND) reduce 435) ((T_LOGICAL_OR) reduce 435) ((T_LOGICAL_XOR) reduce 435) ((T_POW) reduce 435) ((T_SL) reduce 435) ((T_SPACESHIP) reduce 435) ((T_SR) reduce 435) (("^") reduce 435) (("|") reduce 435) (("}") reduce 435)) 5406 ((("%") reduce 476) (("*") reduce 476) (("+") reduce 476) ((",") reduce 476) (("-") reduce 476) ((".") reduce 476) (("/") reduce 476) (("<") reduce 476) ((">") reduce 476) (("?") reduce 476) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_BOOLEAN_AND) reduce 476) ((T_BOOLEAN_OR) reduce 476) ((T_COALESCE) reduce 476) ((T_INSTANCEOF) reduce 476) ((T_IS_EQUAL) reduce 476) ((T_IS_GREATER_OR_EQUAL) reduce 476) ((T_IS_IDENTICAL) reduce 476) ((T_IS_NOT_EQUAL) reduce 476) ((T_IS_NOT_IDENTICAL) reduce 476) ((T_IS_SMALLER_OR_EQUAL) reduce 476) ((T_LOGICAL_AND) reduce 476) ((T_LOGICAL_OR) reduce 476) ((T_LOGICAL_XOR) reduce 476) ((T_POW) reduce 476) ((T_SL) reduce 476) ((T_SPACESHIP) reduce 476) ((T_SR) reduce 476) (("^") reduce 476) (("|") reduce 476) (("}") reduce 476)) 5409 ((("%") reduce 579) (("*") reduce 579) (("+") reduce 579) ((",") reduce 579) (("-") reduce 579) ((".") reduce 579) (("/") reduce 579) (("<") reduce 579) ((">") reduce 579) (("?") reduce 579) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_BOOLEAN_AND) reduce 579) ((T_BOOLEAN_OR) reduce 579) ((T_COALESCE) reduce 579) ((T_INSTANCEOF) reduce 579) ((T_IS_EQUAL) reduce 579) ((T_IS_GREATER_OR_EQUAL) reduce 579) ((T_IS_IDENTICAL) reduce 579) ((T_IS_NOT_EQUAL) reduce 579) ((T_IS_NOT_IDENTICAL) reduce 579) ((T_IS_SMALLER_OR_EQUAL) reduce 579) ((T_LOGICAL_AND) reduce 579) ((T_LOGICAL_OR) reduce 579) ((T_LOGICAL_XOR) reduce 579) ((T_POW) reduce 579) ((T_SL) reduce 579) ((T_SPACESHIP) reduce 579) ((T_SR) reduce 579) (("^") reduce 579) (("|") reduce 579) (("}") reduce 579)) 5412 ((("%") reduce 576) (("*") reduce 576) (("+") reduce 576) ((",") reduce 576) (("-") reduce 576) ((".") reduce 576) (("/") reduce 576) (("<") reduce 576) ((">") reduce 576) (("?") reduce 576) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_BOOLEAN_AND) reduce 576) ((T_BOOLEAN_OR) reduce 576) ((T_COALESCE) reduce 576) ((T_INSTANCEOF) reduce 576) ((T_IS_EQUAL) reduce 576) ((T_IS_GREATER_OR_EQUAL) reduce 576) ((T_IS_IDENTICAL) reduce 576) ((T_IS_NOT_EQUAL) reduce 576) ((T_IS_NOT_IDENTICAL) reduce 576) ((T_IS_SMALLER_OR_EQUAL) reduce 576) ((T_LOGICAL_AND) reduce 576) ((T_LOGICAL_OR) reduce 576) ((T_LOGICAL_XOR) reduce 576) ((T_POW) reduce 576) ((T_SL) reduce 576) ((T_SPACESHIP) reduce 576) ((T_SR) reduce 576) (("^") reduce 576) (("|") reduce 576) (("}") reduce 576)) 5413 ((("%") reduce 429) (("*") reduce 429) (("+") reduce 429) ((",") reduce 429) (("-") reduce 429) ((".") reduce 429) (("/") reduce 429) (("<") reduce 429) ((">") reduce 429) (("?") reduce 429) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_BOOLEAN_AND) reduce 429) ((T_BOOLEAN_OR) reduce 429) ((T_COALESCE) reduce 429) ((T_INSTANCEOF) reduce 429) ((T_IS_EQUAL) reduce 429) ((T_IS_GREATER_OR_EQUAL) reduce 429) ((T_IS_IDENTICAL) reduce 429) ((T_IS_NOT_EQUAL) reduce 429) ((T_IS_NOT_IDENTICAL) reduce 429) ((T_IS_SMALLER_OR_EQUAL) reduce 429) ((T_LOGICAL_AND) reduce 429) ((T_LOGICAL_OR) reduce 429) ((T_LOGICAL_XOR) reduce 429) ((T_POW) shift) ((T_SL) reduce 429) ((T_SPACESHIP) reduce 429) ((T_SR) reduce 429) (("^") reduce 429) (("|") reduce 429) (("}") reduce 429)) 5414 ((("%") reduce 389) (("*") reduce 389) (("+") reduce 389) ((",") reduce 389) (("-") reduce 389) ((".") reduce 389) (("/") reduce 389) (("<") reduce 389) ((">") reduce 389) (("?") reduce 389) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_BOOLEAN_AND) reduce 389) ((T_BOOLEAN_OR) reduce 389) ((T_COALESCE) reduce 389) ((T_INSTANCEOF) reduce 389) ((T_IS_EQUAL) reduce 389) ((T_IS_GREATER_OR_EQUAL) reduce 389) ((T_IS_IDENTICAL) reduce 389) ((T_IS_NOT_EQUAL) reduce 389) ((T_IS_NOT_IDENTICAL) reduce 389) ((T_IS_SMALLER_OR_EQUAL) reduce 389) ((T_LOGICAL_AND) reduce 389) ((T_LOGICAL_OR) reduce 389) ((T_LOGICAL_XOR) reduce 389) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 389) ((T_SL) reduce 389) ((T_SPACESHIP) reduce 389) ((T_SR) reduce 389) (("[") reduce 510) (("^") reduce 389) (("{") reduce 510) (("|") reduce 389) (("}") reduce 389)) 5415 ((("%") reduce 372) (("*") reduce 372) (("+") reduce 372) ((",") reduce 372) (("-") reduce 372) ((".") reduce 372) (("/") reduce 372) (("<") reduce 372) ((">") reduce 372) (("?") reduce 372) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_BOOLEAN_AND) reduce 372) ((T_BOOLEAN_OR) reduce 372) ((T_COALESCE) reduce 372) ((T_INSTANCEOF) reduce 372) ((T_IS_EQUAL) reduce 372) ((T_IS_GREATER_OR_EQUAL) reduce 372) ((T_IS_IDENTICAL) reduce 372) ((T_IS_NOT_EQUAL) reduce 372) ((T_IS_NOT_IDENTICAL) reduce 372) ((T_IS_SMALLER_OR_EQUAL) reduce 372) ((T_LOGICAL_AND) reduce 372) ((T_LOGICAL_OR) reduce 372) ((T_LOGICAL_XOR) reduce 372) ((T_POW) reduce 372) ((T_SL) reduce 372) ((T_SPACESHIP) reduce 372) ((T_SR) reduce 372) (("^") reduce 372) (("|") reduce 372) (("}") reduce 372)) 5416 ((("%") reduce 433) (("*") reduce 433) (("+") reduce 433) ((",") reduce 433) (("-") reduce 433) ((".") reduce 433) (("/") reduce 433) (("<") reduce 433) ((">") reduce 433) (("?") reduce 433) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_BOOLEAN_AND) reduce 433) ((T_BOOLEAN_OR) reduce 433) ((T_COALESCE) reduce 433) ((T_INSTANCEOF) reduce 433) ((T_IS_EQUAL) reduce 433) ((T_IS_GREATER_OR_EQUAL) reduce 433) ((T_IS_IDENTICAL) reduce 433) ((T_IS_NOT_EQUAL) reduce 433) ((T_IS_NOT_IDENTICAL) reduce 433) ((T_IS_SMALLER_OR_EQUAL) reduce 433) ((T_LOGICAL_AND) reduce 433) ((T_LOGICAL_OR) reduce 433) ((T_LOGICAL_XOR) reduce 433) ((T_POW) shift) ((T_SL) reduce 433) ((T_SPACESHIP) reduce 433) ((T_SR) reduce 433) (("^") reduce 433) (("|") reduce 433) (("}") reduce 433)) 5417 ((("%") reduce 431) (("*") reduce 431) (("+") reduce 431) ((",") reduce 431) (("-") reduce 431) ((".") reduce 431) (("/") reduce 431) (("<") reduce 431) ((">") reduce 431) (("?") reduce 431) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_BOOLEAN_AND) reduce 431) ((T_BOOLEAN_OR) reduce 431) ((T_COALESCE) reduce 431) ((T_INSTANCEOF) reduce 431) ((T_IS_EQUAL) reduce 431) ((T_IS_GREATER_OR_EQUAL) reduce 431) ((T_IS_IDENTICAL) reduce 431) ((T_IS_NOT_EQUAL) reduce 431) ((T_IS_NOT_IDENTICAL) reduce 431) ((T_IS_SMALLER_OR_EQUAL) reduce 431) ((T_LOGICAL_AND) reduce 431) ((T_LOGICAL_OR) reduce 431) ((T_LOGICAL_XOR) reduce 431) ((T_POW) shift) ((T_SL) reduce 431) ((T_SPACESHIP) reduce 431) ((T_SR) reduce 431) (("^") reduce 431) (("|") reduce 431) (("}") reduce 431)) 5420 ((("%") reduce 482) (("(") reduce 482) (("*") reduce 482) (("+") reduce 482) ((",") reduce 482) (("-") reduce 482) ((".") reduce 482) (("/") reduce 482) (("<") reduce 482) ((">") reduce 482) (("?") reduce 482) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_BOOLEAN_AND) reduce 482) ((T_BOOLEAN_OR) reduce 482) ((T_COALESCE) reduce 482) ((T_INSTANCEOF) reduce 482) ((T_IS_EQUAL) reduce 482) ((T_IS_GREATER_OR_EQUAL) reduce 482) ((T_IS_IDENTICAL) reduce 482) ((T_IS_NOT_EQUAL) reduce 482) ((T_IS_NOT_IDENTICAL) reduce 482) ((T_IS_SMALLER_OR_EQUAL) reduce 482) ((T_LOGICAL_AND) reduce 482) ((T_LOGICAL_OR) reduce 482) ((T_LOGICAL_XOR) reduce 482) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 482) ((T_OBJECT_OPERATOR) reduce 482) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 482) ((T_POW) reduce 482) ((T_SL) reduce 482) ((T_SPACESHIP) reduce 482) ((T_SR) reduce 482) (("[") reduce 482) (("^") reduce 482) (("{") reduce 482) (("|") reduce 482) (("}") reduce 482)) 5421 ((("%") reduce 436) (("*") reduce 436) (("+") reduce 436) ((",") reduce 436) (("-") reduce 436) ((".") reduce 436) (("/") reduce 436) (("<") reduce 436) ((">") reduce 436) (("?") reduce 436) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_BOOLEAN_AND) reduce 436) ((T_BOOLEAN_OR) reduce 436) ((T_COALESCE) reduce 436) ((T_INSTANCEOF) reduce 436) ((T_IS_EQUAL) reduce 436) ((T_IS_GREATER_OR_EQUAL) reduce 436) ((T_IS_IDENTICAL) reduce 436) ((T_IS_NOT_EQUAL) reduce 436) ((T_IS_NOT_IDENTICAL) reduce 436) ((T_IS_SMALLER_OR_EQUAL) reduce 436) ((T_LOGICAL_AND) reduce 436) ((T_LOGICAL_OR) reduce 436) ((T_LOGICAL_XOR) reduce 436) ((T_POW) shift) ((T_SL) reduce 436) ((T_SPACESHIP) reduce 436) ((T_SR) reduce 436) (("^") reduce 436) (("|") reduce 436) (("}") reduce 436)) 5422 ((("%") reduce 409) (("*") reduce 409) (("+") reduce 409) ((",") reduce 409) (("-") reduce 409) ((".") reduce 409) (("/") reduce 409) (("<") reduce 409) ((">") reduce 409) (("?") reduce 409) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_BOOLEAN_AND) reduce 409) ((T_BOOLEAN_OR) reduce 409) ((T_COALESCE) reduce 409) ((T_INSTANCEOF) reduce 409) ((T_IS_EQUAL) reduce 409) ((T_IS_GREATER_OR_EQUAL) reduce 409) ((T_IS_IDENTICAL) reduce 409) ((T_IS_NOT_EQUAL) reduce 409) ((T_IS_NOT_IDENTICAL) reduce 409) ((T_IS_SMALLER_OR_EQUAL) reduce 409) ((T_LOGICAL_AND) reduce 409) ((T_LOGICAL_OR) reduce 409) ((T_LOGICAL_XOR) reduce 409) ((T_POW) shift) ((T_SL) reduce 409) ((T_SPACESHIP) reduce 409) ((T_SR) reduce 409) (("^") reduce 409) (("|") reduce 409) (("}") reduce 409)) 5423 ((("%") reduce 408) (("*") reduce 408) (("+") reduce 408) ((",") reduce 408) (("-") reduce 408) ((".") reduce 408) (("/") reduce 408) (("<") reduce 408) ((">") reduce 408) (("?") reduce 408) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_BOOLEAN_AND) reduce 408) ((T_BOOLEAN_OR) reduce 408) ((T_COALESCE) reduce 408) ((T_INSTANCEOF) reduce 408) ((T_IS_EQUAL) reduce 408) ((T_IS_GREATER_OR_EQUAL) reduce 408) ((T_IS_IDENTICAL) reduce 408) ((T_IS_NOT_EQUAL) reduce 408) ((T_IS_NOT_IDENTICAL) reduce 408) ((T_IS_SMALLER_OR_EQUAL) reduce 408) ((T_LOGICAL_AND) reduce 408) ((T_LOGICAL_OR) reduce 408) ((T_LOGICAL_XOR) reduce 408) ((T_POW) shift) ((T_SL) reduce 408) ((T_SPACESHIP) reduce 408) ((T_SR) reduce 408) (("^") reduce 408) (("|") reduce 408) (("}") reduce 408)) 5425 ((("%") reduce 422) (("(") reduce 517) (("*") reduce 422) (("+") reduce 422) ((",") reduce 422) (("-") reduce 422) ((".") reduce 422) (("/") reduce 422) (("<") reduce 422) ((">") reduce 422) (("?") reduce 422) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_BOOLEAN_AND) reduce 422) ((T_BOOLEAN_OR) reduce 422) ((T_COALESCE) reduce 422) ((T_INSTANCEOF) reduce 422) ((T_IS_EQUAL) reduce 422) ((T_IS_GREATER_OR_EQUAL) reduce 422) ((T_IS_IDENTICAL) reduce 422) ((T_IS_NOT_EQUAL) reduce 422) ((T_IS_NOT_IDENTICAL) reduce 422) ((T_IS_SMALLER_OR_EQUAL) reduce 422) ((T_LOGICAL_AND) reduce 422) ((T_LOGICAL_OR) reduce 422) ((T_LOGICAL_XOR) reduce 422) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 511) ((T_OBJECT_OPERATOR) reduce 511) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 511) ((T_POW) reduce 422) ((T_SL) reduce 422) ((T_SPACESHIP) reduce 422) ((T_SR) reduce 422) (("[") reduce 511) (("^") reduce 422) (("{") reduce 511) (("|") reduce 422) (("}") reduce 422)) 5426 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) ((",") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) (("=") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AND_EQUAL) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_COALESCE_EQUAL) reduce 531) ((T_CONCAT_EQUAL) reduce 531) ((T_DEC) reduce 531) ((T_DIV_EQUAL) reduce 531) ((T_INC) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_MINUS_EQUAL) reduce 531) ((T_MOD_EQUAL) reduce 531) ((T_MUL_EQUAL) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_OR_EQUAL) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_PLUS_EQUAL) reduce 531) ((T_POW) reduce 531) ((T_POW_EQUAL) reduce 531) ((T_SL) reduce 531) ((T_SL_EQUAL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) ((T_SR_EQUAL) reduce 531) ((T_XOR_EQUAL) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531) (("}") reduce 531)) 5429 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) ((",") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) (("=") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AND_EQUAL) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_COALESCE_EQUAL) reduce 530) ((T_CONCAT_EQUAL) reduce 530) ((T_DEC) reduce 530) ((T_DIV_EQUAL) reduce 530) ((T_INC) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_MINUS_EQUAL) reduce 530) ((T_MOD_EQUAL) reduce 530) ((T_MUL_EQUAL) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_OR_EQUAL) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_PLUS_EQUAL) reduce 530) ((T_POW) reduce 530) ((T_POW_EQUAL) reduce 530) ((T_SL) reduce 530) ((T_SL_EQUAL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) ((T_SR_EQUAL) reduce 530) ((T_XOR_EQUAL) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530) (("}") reduce 530)) 5431 ((("%") reduce 485) (("(") reduce 485) (("*") reduce 485) (("+") reduce 485) ((",") reduce 485) (("-") reduce 485) ((".") reduce 485) (("/") reduce 485) (("<") reduce 485) ((">") reduce 485) (("?") reduce 485) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_BOOLEAN_AND) reduce 485) ((T_BOOLEAN_OR) reduce 485) ((T_COALESCE) reduce 485) ((T_INSTANCEOF) reduce 485) ((T_IS_EQUAL) reduce 485) ((T_IS_GREATER_OR_EQUAL) reduce 485) ((T_IS_IDENTICAL) reduce 485) ((T_IS_NOT_EQUAL) reduce 485) ((T_IS_NOT_IDENTICAL) reduce 485) ((T_IS_SMALLER_OR_EQUAL) reduce 485) ((T_LOGICAL_AND) reduce 485) ((T_LOGICAL_OR) reduce 485) ((T_LOGICAL_XOR) reduce 485) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 485) ((T_OBJECT_OPERATOR) reduce 485) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 485) ((T_POW) reduce 485) ((T_SL) reduce 485) ((T_SPACESHIP) reduce 485) ((T_SR) reduce 485) (("[") reduce 485) (("^") reduce 485) (("{") reduce 485) (("|") reduce 485) (("}") reduce 485)) 5432 ((("%") reduce 410) (("*") reduce 410) (("+") reduce 410) ((",") reduce 410) (("-") reduce 410) ((".") reduce 410) (("/") reduce 410) (("<") reduce 410) ((">") reduce 410) (("?") reduce 410) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_BOOLEAN_AND) reduce 410) ((T_BOOLEAN_OR) reduce 410) ((T_COALESCE) reduce 410) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 410) ((T_IS_GREATER_OR_EQUAL) reduce 410) ((T_IS_IDENTICAL) reduce 410) ((T_IS_NOT_EQUAL) reduce 410) ((T_IS_NOT_IDENTICAL) reduce 410) ((T_IS_SMALLER_OR_EQUAL) reduce 410) ((T_LOGICAL_AND) reduce 410) ((T_LOGICAL_OR) reduce 410) ((T_LOGICAL_XOR) reduce 410) ((T_POW) shift) ((T_SL) reduce 410) ((T_SPACESHIP) reduce 410) ((T_SR) reduce 410) (("^") reduce 410) (("|") reduce 410) (("}") reduce 410)) 5433 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 238) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 238) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 5444 ((("%") reduce 455) (("*") reduce 455) (("+") reduce 455) ((",") reduce 455) (("-") reduce 455) ((".") reduce 455) (("/") reduce 455) (("<") reduce 455) ((">") reduce 455) (("?") reduce 455) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_BOOLEAN_AND) reduce 455) ((T_BOOLEAN_OR) reduce 455) ((T_COALESCE) reduce 455) ((T_DOUBLE_ARROW) reduce 455) ((T_INSTANCEOF) reduce 455) ((T_IS_EQUAL) reduce 455) ((T_IS_GREATER_OR_EQUAL) reduce 455) ((T_IS_IDENTICAL) reduce 455) ((T_IS_NOT_EQUAL) reduce 455) ((T_IS_NOT_IDENTICAL) reduce 455) ((T_IS_SMALLER_OR_EQUAL) reduce 455) ((T_LOGICAL_AND) reduce 455) ((T_LOGICAL_OR) reduce 455) ((T_LOGICAL_XOR) reduce 455) ((T_POW) reduce 455) ((T_SL) reduce 455) ((T_SPACESHIP) reduce 455) ((T_SR) reduce 455) (("^") reduce 455) (("|") reduce 455)) 5445 ((("%") reduce 450) (("*") reduce 450) (("+") reduce 450) ((",") reduce 450) (("-") reduce 450) ((".") reduce 450) (("/") reduce 450) (("<") reduce 450) ((">") reduce 450) (("?") reduce 450) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_BOOLEAN_AND) reduce 450) ((T_BOOLEAN_OR) reduce 450) ((T_COALESCE) reduce 450) ((T_DOUBLE_ARROW) reduce 450) ((T_INSTANCEOF) reduce 450) ((T_IS_EQUAL) reduce 450) ((T_IS_GREATER_OR_EQUAL) reduce 450) ((T_IS_IDENTICAL) reduce 450) ((T_IS_NOT_EQUAL) reduce 450) ((T_IS_NOT_IDENTICAL) reduce 450) ((T_IS_SMALLER_OR_EQUAL) reduce 450) ((T_LOGICAL_AND) reduce 450) ((T_LOGICAL_OR) reduce 450) ((T_LOGICAL_XOR) reduce 450) ((T_POW) reduce 450) ((T_SL) reduce 450) ((T_SPACESHIP) reduce 450) ((T_SR) reduce 450) (("^") reduce 450) (("|") reduce 450)) 5455 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 455) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 455) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 5456 ((("%") reduce 451) (("*") reduce 451) (("+") reduce 451) ((",") reduce 451) (("-") reduce 451) ((".") reduce 451) (("/") reduce 451) (("<") reduce 451) ((">") reduce 451) (("?") reduce 451) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_BOOLEAN_AND) reduce 451) ((T_BOOLEAN_OR) reduce 451) ((T_COALESCE) reduce 451) ((T_DOUBLE_ARROW) reduce 451) ((T_INSTANCEOF) reduce 451) ((T_IS_EQUAL) reduce 451) ((T_IS_GREATER_OR_EQUAL) reduce 451) ((T_IS_IDENTICAL) reduce 451) ((T_IS_NOT_EQUAL) reduce 451) ((T_IS_NOT_IDENTICAL) reduce 451) ((T_IS_SMALLER_OR_EQUAL) reduce 451) ((T_LOGICAL_AND) reduce 451) ((T_LOGICAL_OR) reduce 451) ((T_LOGICAL_XOR) reduce 451) ((T_POW) reduce 451) ((T_SL) reduce 451) ((T_SPACESHIP) reduce 451) ((T_SR) reduce 451) (("^") reduce 451) (("|") reduce 451)) 5458 ((("%") reduce 503) (("(") reduce 541) (("*") reduce 503) (("+") reduce 503) ((",") reduce 503) (("-") reduce 503) ((".") reduce 503) (("/") reduce 503) (("<") reduce 503) ((">") reduce 503) (("?") reduce 503) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_BOOLEAN_AND) reduce 503) ((T_BOOLEAN_OR) reduce 503) ((T_COALESCE) reduce 503) ((T_DOUBLE_ARROW) reduce 503) ((T_INSTANCEOF) reduce 503) ((T_IS_EQUAL) reduce 503) ((T_IS_GREATER_OR_EQUAL) reduce 503) ((T_IS_IDENTICAL) reduce 503) ((T_IS_NOT_EQUAL) reduce 503) ((T_IS_NOT_IDENTICAL) reduce 503) ((T_IS_SMALLER_OR_EQUAL) reduce 503) ((T_LOGICAL_AND) reduce 503) ((T_LOGICAL_OR) reduce 503) ((T_LOGICAL_XOR) reduce 503) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 503) ((T_OBJECT_OPERATOR) reduce 503) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 503) ((T_POW) reduce 503) ((T_SL) reduce 503) ((T_SPACESHIP) reduce 503) ((T_SR) reduce 503) (("[") reduce 503) (("^") reduce 503) (("{") reduce 503) (("|") reduce 503)) 5460 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) ((",") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) (("<") reduce 532) (("=") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AND_EQUAL) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_COALESCE_EQUAL) reduce 532) ((T_CONCAT_EQUAL) reduce 532) ((T_DEC) reduce 532) ((T_DIV_EQUAL) reduce 532) ((T_DOUBLE_ARROW) reduce 532) ((T_INC) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_MINUS_EQUAL) reduce 532) ((T_MOD_EQUAL) reduce 532) ((T_MUL_EQUAL) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_OR_EQUAL) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_PLUS_EQUAL) reduce 532) ((T_POW) reduce 532) ((T_POW_EQUAL) reduce 532) ((T_SL) reduce 532) ((T_SL_EQUAL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) ((T_SR_EQUAL) reduce 532) ((T_XOR_EQUAL) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 5463 ((("%") reduce 505) (("(") reduce 542) (("*") reduce 505) (("+") reduce 505) ((",") reduce 505) (("-") reduce 505) ((".") reduce 505) (("/") reduce 505) (("<") reduce 505) ((">") reduce 505) (("?") reduce 505) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_BOOLEAN_AND) reduce 505) ((T_BOOLEAN_OR) reduce 505) ((T_COALESCE) reduce 505) ((T_DOUBLE_ARROW) reduce 505) ((T_INSTANCEOF) reduce 505) ((T_IS_EQUAL) reduce 505) ((T_IS_GREATER_OR_EQUAL) reduce 505) ((T_IS_IDENTICAL) reduce 505) ((T_IS_NOT_EQUAL) reduce 505) ((T_IS_NOT_IDENTICAL) reduce 505) ((T_IS_SMALLER_OR_EQUAL) reduce 505) ((T_LOGICAL_AND) reduce 505) ((T_LOGICAL_OR) reduce 505) ((T_LOGICAL_XOR) reduce 505) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 505) ((T_OBJECT_OPERATOR) reduce 505) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 505) ((T_POW) reduce 505) ((T_SL) reduce 505) ((T_SPACESHIP) reduce 505) ((T_SR) reduce 505) (("[") reduce 505) (("^") reduce 505) (("{") reduce 505) (("|") reduce 505)) 5464 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) ((",") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) (("<") reduce 467) (("=") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AND_EQUAL) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_COALESCE_EQUAL) reduce 467) ((T_CONCAT_EQUAL) reduce 467) ((T_DEC) reduce 467) ((T_DIV_EQUAL) reduce 467) ((T_DOUBLE_ARROW) reduce 467) ((T_INC) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_MINUS_EQUAL) reduce 467) ((T_MOD_EQUAL) reduce 467) ((T_MUL_EQUAL) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_OR_EQUAL) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_PLUS_EQUAL) reduce 467) ((T_POW) reduce 467) ((T_POW_EQUAL) reduce 467) ((T_SL) reduce 467) ((T_SL_EQUAL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) ((T_SR_EQUAL) reduce 467) ((T_XOR_EQUAL) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 5465 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) ((",") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) (("<") reduce 469) (("=") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AND_EQUAL) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_COALESCE_EQUAL) reduce 469) ((T_CONCAT_EQUAL) reduce 469) ((T_DEC) reduce 469) ((T_DIV_EQUAL) reduce 469) ((T_DOUBLE_ARROW) reduce 469) ((T_INC) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_MINUS_EQUAL) reduce 469) ((T_MOD_EQUAL) reduce 469) ((T_MUL_EQUAL) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_OR_EQUAL) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_PLUS_EQUAL) reduce 469) ((T_POW) reduce 469) ((T_POW_EQUAL) reduce 469) ((T_SL) reduce 469) ((T_SL_EQUAL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) ((T_SR_EQUAL) reduce 469) ((T_XOR_EQUAL) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 5467 ((("%") reduce 446) (("*") reduce 446) (("+") reduce 446) ((",") reduce 446) (("-") reduce 446) ((".") reduce 446) (("/") reduce 446) (("<") reduce 446) ((">") reduce 446) (("?") reduce 446) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_BOOLEAN_AND) reduce 446) ((T_BOOLEAN_OR) reduce 446) ((T_COALESCE) reduce 446) ((T_DOUBLE_ARROW) reduce 446) ((T_INSTANCEOF) reduce 446) ((T_IS_EQUAL) reduce 446) ((T_IS_GREATER_OR_EQUAL) reduce 446) ((T_IS_IDENTICAL) reduce 446) ((T_IS_NOT_EQUAL) reduce 446) ((T_IS_NOT_IDENTICAL) reduce 446) ((T_IS_SMALLER_OR_EQUAL) reduce 446) ((T_LOGICAL_AND) reduce 446) ((T_LOGICAL_OR) reduce 446) ((T_LOGICAL_XOR) reduce 446) ((T_POW) reduce 446) ((T_SL) reduce 446) ((T_SPACESHIP) reduce 446) ((T_SR) reduce 446) (("^") reduce 446) (("|") reduce 446)) 5468 ((("%") reduce 448) (("*") reduce 448) (("+") reduce 448) ((",") reduce 448) (("-") reduce 448) ((".") reduce 448) (("/") reduce 448) (("<") reduce 448) ((">") reduce 448) (("?") reduce 448) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_BOOLEAN_AND) reduce 448) ((T_BOOLEAN_OR) reduce 448) ((T_COALESCE) reduce 448) ((T_DOUBLE_ARROW) reduce 448) ((T_INSTANCEOF) reduce 448) ((T_IS_EQUAL) reduce 448) ((T_IS_GREATER_OR_EQUAL) reduce 448) ((T_IS_IDENTICAL) reduce 448) ((T_IS_NOT_EQUAL) reduce 448) ((T_IS_NOT_IDENTICAL) reduce 448) ((T_IS_SMALLER_OR_EQUAL) reduce 448) ((T_LOGICAL_AND) reduce 448) ((T_LOGICAL_OR) reduce 448) ((T_LOGICAL_XOR) reduce 448) ((T_POW) reduce 448) ((T_SL) reduce 448) ((T_SPACESHIP) reduce 448) ((T_SR) reduce 448) (("^") reduce 448) (("|") reduce 448)) 5474 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) ((",") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) (("<") reduce 521) (("=") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AND_EQUAL) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_COALESCE_EQUAL) reduce 521) ((T_CONCAT_EQUAL) reduce 521) ((T_DEC) reduce 521) ((T_DIV_EQUAL) reduce 521) ((T_DOUBLE_ARROW) reduce 521) ((T_INC) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_MINUS_EQUAL) reduce 521) ((T_MOD_EQUAL) reduce 521) ((T_MUL_EQUAL) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_OR_EQUAL) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_PLUS_EQUAL) reduce 521) ((T_POW) reduce 521) ((T_POW_EQUAL) reduce 521) ((T_SL) reduce 521) ((T_SL_EQUAL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) ((T_SR_EQUAL) reduce 521) ((T_XOR_EQUAL) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 5476 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) ((",") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) (("<") reduce 520) (("=") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AND_EQUAL) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_COALESCE_EQUAL) reduce 520) ((T_CONCAT_EQUAL) reduce 520) ((T_DEC) reduce 520) ((T_DIV_EQUAL) reduce 520) ((T_DOUBLE_ARROW) reduce 520) ((T_INC) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_MINUS_EQUAL) reduce 520) ((T_MOD_EQUAL) reduce 520) ((T_MUL_EQUAL) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_OR_EQUAL) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_PLUS_EQUAL) reduce 520) ((T_POW) reduce 520) ((T_POW_EQUAL) reduce 520) ((T_SL) reduce 520) ((T_SL_EQUAL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) ((T_SR_EQUAL) reduce 520) ((T_XOR_EQUAL) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 5477 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) ((",") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) (("=") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AND_EQUAL) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_COALESCE_EQUAL) reduce 544) ((T_CONCAT_EQUAL) reduce 544) ((T_DEC) reduce 544) ((T_DIV_EQUAL) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INC) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_MINUS_EQUAL) reduce 544) ((T_MOD_EQUAL) reduce 544) ((T_MUL_EQUAL) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_OR_EQUAL) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_PLUS_EQUAL) reduce 544) ((T_POW) reduce 544) ((T_POW_EQUAL) reduce 544) ((T_SL) reduce 544) ((T_SL_EQUAL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) ((T_SR_EQUAL) reduce 544) ((T_XOR_EQUAL) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 5478 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) ((",") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) (("<") reduce 527) (("=") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AND_EQUAL) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_COALESCE_EQUAL) reduce 527) ((T_CONCAT_EQUAL) reduce 527) ((T_DEC) reduce 527) ((T_DIV_EQUAL) reduce 527) ((T_DOUBLE_ARROW) reduce 527) ((T_INC) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_MINUS_EQUAL) reduce 527) ((T_MOD_EQUAL) reduce 527) ((T_MUL_EQUAL) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_OR_EQUAL) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_PLUS_EQUAL) reduce 527) ((T_POW) reduce 527) ((T_POW_EQUAL) reduce 527) ((T_SL) reduce 527) ((T_SL_EQUAL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) ((T_SR_EQUAL) reduce 527) ((T_XOR_EQUAL) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 5479 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) ((",") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) (("=") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AND_EQUAL) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_COALESCE_EQUAL) reduce 546) ((T_CONCAT_EQUAL) reduce 546) ((T_DEC) reduce 546) ((T_DIV_EQUAL) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INC) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_MINUS_EQUAL) reduce 546) ((T_MOD_EQUAL) reduce 546) ((T_MUL_EQUAL) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_OR_EQUAL) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_PLUS_EQUAL) reduce 546) ((T_POW) reduce 546) ((T_POW_EQUAL) reduce 546) ((T_SL) reduce 546) ((T_SL_EQUAL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) ((T_SR_EQUAL) reduce 546) ((T_XOR_EQUAL) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 5482 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) ((",") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) (("=") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AND_EQUAL) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_COALESCE_EQUAL) reduce 545) ((T_CONCAT_EQUAL) reduce 545) ((T_DEC) reduce 545) ((T_DIV_EQUAL) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INC) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_MINUS_EQUAL) reduce 545) ((T_MOD_EQUAL) reduce 545) ((T_MUL_EQUAL) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_OR_EQUAL) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_PLUS_EQUAL) reduce 545) ((T_POW) reduce 545) ((T_POW_EQUAL) reduce 545) ((T_SL) reduce 545) ((T_SL_EQUAL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) ((T_SR_EQUAL) reduce 545) ((T_XOR_EQUAL) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 5483 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) ((",") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) (("<") reduce 522) (("=") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AND_EQUAL) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_COALESCE_EQUAL) reduce 522) ((T_CONCAT_EQUAL) reduce 522) ((T_DEC) reduce 522) ((T_DIV_EQUAL) reduce 522) ((T_DOUBLE_ARROW) reduce 522) ((T_INC) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_MINUS_EQUAL) reduce 522) ((T_MOD_EQUAL) reduce 522) ((T_MUL_EQUAL) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_OR_EQUAL) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_PLUS_EQUAL) reduce 522) ((T_POW) reduce 522) ((T_POW_EQUAL) reduce 522) ((T_SL) reduce 522) ((T_SL_EQUAL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) ((T_SR_EQUAL) reduce 522) ((T_XOR_EQUAL) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 5484 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) ((",") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) (("<") reduce 528) (("=") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AND_EQUAL) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_COALESCE_EQUAL) reduce 528) ((T_CONCAT_EQUAL) reduce 528) ((T_DEC) reduce 528) ((T_DIV_EQUAL) reduce 528) ((T_DOUBLE_ARROW) reduce 528) ((T_INC) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_MINUS_EQUAL) reduce 528) ((T_MOD_EQUAL) reduce 528) ((T_MUL_EQUAL) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_OR_EQUAL) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_PLUS_EQUAL) reduce 528) ((T_POW) reduce 528) ((T_POW_EQUAL) reduce 528) ((T_SL) reduce 528) ((T_SL_EQUAL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) ((T_SR_EQUAL) reduce 528) ((T_XOR_EQUAL) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 5485 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) ((",") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) (("<") reduce 523) (("=") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AND_EQUAL) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_COALESCE_EQUAL) reduce 523) ((T_CONCAT_EQUAL) reduce 523) ((T_DEC) reduce 523) ((T_DIV_EQUAL) reduce 523) ((T_DOUBLE_ARROW) reduce 523) ((T_INC) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_MINUS_EQUAL) reduce 523) ((T_MOD_EQUAL) reduce 523) ((T_MUL_EQUAL) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_OR_EQUAL) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_PLUS_EQUAL) reduce 523) ((T_POW) reduce 523) ((T_POW_EQUAL) reduce 523) ((T_SL) reduce 523) ((T_SL_EQUAL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) ((T_SR_EQUAL) reduce 523) ((T_XOR_EQUAL) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 5487 ((("%") reduce 438) (("*") reduce 438) (("+") reduce 438) ((",") reduce 438) (("-") reduce 438) ((".") reduce 438) (("/") reduce 438) (("<") reduce 438) ((">") reduce 438) (("?") reduce 438) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_BOOLEAN_AND) reduce 438) ((T_BOOLEAN_OR) reduce 438) ((T_COALESCE) reduce 438) ((T_DOUBLE_ARROW) reduce 438) ((T_INSTANCEOF) reduce 438) ((T_IS_EQUAL) reduce 438) ((T_IS_GREATER_OR_EQUAL) reduce 438) ((T_IS_IDENTICAL) reduce 438) ((T_IS_NOT_EQUAL) reduce 438) ((T_IS_NOT_IDENTICAL) reduce 438) ((T_IS_SMALLER_OR_EQUAL) reduce 438) ((T_LOGICAL_AND) reduce 438) ((T_LOGICAL_OR) reduce 438) ((T_LOGICAL_XOR) reduce 438) ((T_POW) reduce 438) ((T_SL) reduce 438) ((T_SPACESHIP) reduce 438) ((T_SR) reduce 438) (("^") reduce 438) (("|") reduce 438)) 5489 ((("%") reduce 483) (("(") reduce 483) (("*") reduce 483) (("+") reduce 483) ((",") reduce 483) (("-") reduce 483) ((".") reduce 483) (("/") reduce 483) (("<") reduce 483) (("=") shift) ((">") reduce 483) (("?") reduce 483) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_BOOLEAN_AND) reduce 483) ((T_BOOLEAN_OR) reduce 483) ((T_COALESCE) reduce 483) ((T_DOUBLE_ARROW) reduce 483) ((T_INSTANCEOF) reduce 483) ((T_IS_EQUAL) reduce 483) ((T_IS_GREATER_OR_EQUAL) reduce 483) ((T_IS_IDENTICAL) reduce 483) ((T_IS_NOT_EQUAL) reduce 483) ((T_IS_NOT_IDENTICAL) reduce 483) ((T_IS_SMALLER_OR_EQUAL) reduce 483) ((T_LOGICAL_AND) reduce 483) ((T_LOGICAL_OR) reduce 483) ((T_LOGICAL_XOR) reduce 483) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 483) ((T_OBJECT_OPERATOR) reduce 483) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 483) ((T_POW) reduce 483) ((T_SL) reduce 483) ((T_SPACESHIP) reduce 483) ((T_SR) reduce 483) (("[") reduce 483) (("^") reduce 483) (("{") reduce 483) (("|") reduce 483)) 5491 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 369) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 369) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 369) ((T_LOGICAL_OR) reduce 369) ((T_LOGICAL_XOR) reduce 369) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 5492 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 443) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 443) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 443) ((T_LOGICAL_OR) reduce 443) ((T_LOGICAL_XOR) reduce 443) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 5493 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 441) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 441) ((T_LOGICAL_OR) reduce 441) ((T_LOGICAL_XOR) reduce 441) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 5495 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 442) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 442) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 442) ((T_LOGICAL_OR) reduce 442) ((T_LOGICAL_XOR) reduce 442) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 5496 ((("%") reduce 434) (("*") reduce 434) (("+") reduce 434) ((",") reduce 434) (("-") reduce 434) ((".") reduce 434) (("/") reduce 434) (("<") reduce 434) ((">") reduce 434) (("?") reduce 434) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_BOOLEAN_AND) reduce 434) ((T_BOOLEAN_OR) reduce 434) ((T_COALESCE) reduce 434) ((T_DOUBLE_ARROW) reduce 434) ((T_INSTANCEOF) reduce 434) ((T_IS_EQUAL) reduce 434) ((T_IS_GREATER_OR_EQUAL) reduce 434) ((T_IS_IDENTICAL) reduce 434) ((T_IS_NOT_EQUAL) reduce 434) ((T_IS_NOT_IDENTICAL) reduce 434) ((T_IS_SMALLER_OR_EQUAL) reduce 434) ((T_LOGICAL_AND) reduce 434) ((T_LOGICAL_OR) reduce 434) ((T_LOGICAL_XOR) reduce 434) ((T_POW) shift) ((T_SL) reduce 434) ((T_SPACESHIP) reduce 434) ((T_SR) reduce 434) (("^") reduce 434) (("|") reduce 434)) 5497 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 444) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 444) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 5498 ((("%") reduce 430) (("*") reduce 430) (("+") reduce 430) ((",") reduce 430) (("-") reduce 430) ((".") reduce 430) (("/") reduce 430) (("<") reduce 430) ((">") reduce 430) (("?") reduce 430) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_BOOLEAN_AND) reduce 430) ((T_BOOLEAN_OR) reduce 430) ((T_COALESCE) reduce 430) ((T_DOUBLE_ARROW) reduce 430) ((T_INSTANCEOF) reduce 430) ((T_IS_EQUAL) reduce 430) ((T_IS_GREATER_OR_EQUAL) reduce 430) ((T_IS_IDENTICAL) reduce 430) ((T_IS_NOT_EQUAL) reduce 430) ((T_IS_NOT_IDENTICAL) reduce 430) ((T_IS_SMALLER_OR_EQUAL) reduce 430) ((T_LOGICAL_AND) reduce 430) ((T_LOGICAL_OR) reduce 430) ((T_LOGICAL_XOR) reduce 430) ((T_POW) shift) ((T_SL) reduce 430) ((T_SPACESHIP) reduce 430) ((T_SR) reduce 430) (("^") reduce 430) (("|") reduce 430)) 5499 ((("%") reduce 447) (("*") reduce 447) (("+") reduce 447) ((",") reduce 447) (("-") reduce 447) ((".") reduce 447) (("/") reduce 447) (("<") reduce 447) ((">") reduce 447) (("?") reduce 447) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_BOOLEAN_AND) reduce 447) ((T_BOOLEAN_OR) reduce 447) ((T_COALESCE) reduce 447) ((T_DOUBLE_ARROW) reduce 447) ((T_INSTANCEOF) reduce 447) ((T_IS_EQUAL) reduce 447) ((T_IS_GREATER_OR_EQUAL) reduce 447) ((T_IS_IDENTICAL) reduce 447) ((T_IS_NOT_EQUAL) reduce 447) ((T_IS_NOT_IDENTICAL) reduce 447) ((T_IS_SMALLER_OR_EQUAL) reduce 447) ((T_LOGICAL_AND) reduce 447) ((T_LOGICAL_OR) reduce 447) ((T_LOGICAL_XOR) reduce 447) ((T_POW) reduce 447) ((T_SL) reduce 447) ((T_SPACESHIP) reduce 447) ((T_SR) reduce 447) (("^") reduce 447) (("|") reduce 447)) 5501 ((("%") reduce 489) (("*") reduce 489) (("+") reduce 489) ((",") reduce 489) (("-") reduce 489) ((".") reduce 489) (("/") reduce 489) (("<") reduce 489) ((">") reduce 489) (("?") reduce 489) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_BOOLEAN_AND) reduce 489) ((T_BOOLEAN_OR) reduce 489) ((T_COALESCE) reduce 489) ((T_DOUBLE_ARROW) reduce 489) ((T_INSTANCEOF) reduce 489) ((T_IS_EQUAL) reduce 489) ((T_IS_GREATER_OR_EQUAL) reduce 489) ((T_IS_IDENTICAL) reduce 489) ((T_IS_NOT_EQUAL) reduce 489) ((T_IS_NOT_IDENTICAL) reduce 489) ((T_IS_SMALLER_OR_EQUAL) reduce 489) ((T_LOGICAL_AND) reduce 489) ((T_LOGICAL_OR) reduce 489) ((T_LOGICAL_XOR) reduce 489) ((T_POW) reduce 489) ((T_SL) reduce 489) ((T_SPACESHIP) reduce 489) ((T_SR) reduce 489) (("^") reduce 489) (("|") reduce 489)) 5503 ((("%") reduce 490) (("*") reduce 490) (("+") reduce 490) ((",") reduce 490) (("-") reduce 490) ((".") reduce 490) (("/") reduce 490) (("<") reduce 490) ((">") reduce 490) (("?") reduce 490) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_BOOLEAN_AND) reduce 490) ((T_BOOLEAN_OR) reduce 490) ((T_COALESCE) reduce 490) ((T_DOUBLE_ARROW) reduce 490) ((T_INSTANCEOF) reduce 490) ((T_IS_EQUAL) reduce 490) ((T_IS_GREATER_OR_EQUAL) reduce 490) ((T_IS_IDENTICAL) reduce 490) ((T_IS_NOT_EQUAL) reduce 490) ((T_IS_NOT_IDENTICAL) reduce 490) ((T_IS_SMALLER_OR_EQUAL) reduce 490) ((T_LOGICAL_AND) reduce 490) ((T_LOGICAL_OR) reduce 490) ((T_LOGICAL_XOR) reduce 490) ((T_POW) reduce 490) ((T_SL) reduce 490) ((T_SPACESHIP) reduce 490) ((T_SR) reduce 490) (("^") reduce 490) (("|") reduce 490)) 5504 ((("%") reduce 488) (("*") reduce 488) (("+") reduce 488) ((",") reduce 488) (("-") reduce 488) ((".") reduce 488) (("/") reduce 488) (("<") reduce 488) ((">") reduce 488) (("?") reduce 488) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_BOOLEAN_AND) reduce 488) ((T_BOOLEAN_OR) reduce 488) ((T_COALESCE) reduce 488) ((T_DOUBLE_ARROW) reduce 488) ((T_INSTANCEOF) reduce 488) ((T_IS_EQUAL) reduce 488) ((T_IS_GREATER_OR_EQUAL) reduce 488) ((T_IS_IDENTICAL) reduce 488) ((T_IS_NOT_EQUAL) reduce 488) ((T_IS_NOT_IDENTICAL) reduce 488) ((T_IS_SMALLER_OR_EQUAL) reduce 488) ((T_LOGICAL_AND) reduce 488) ((T_LOGICAL_OR) reduce 488) ((T_LOGICAL_XOR) reduce 488) ((T_POW) reduce 488) ((T_SL) reduce 488) ((T_SPACESHIP) reduce 488) ((T_SR) reduce 488) (("^") reduce 488) (("|") reduce 488)) 5505 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 581) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 581) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 5506 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 580) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 580) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 5507 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) ((",") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) (("<") reduce 466) (("=") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AND_EQUAL) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_COALESCE_EQUAL) reduce 466) ((T_CONCAT_EQUAL) reduce 466) ((T_DEC) reduce 466) ((T_DIV_EQUAL) reduce 466) ((T_DOUBLE_ARROW) reduce 466) ((T_INC) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_MINUS_EQUAL) reduce 466) ((T_MOD_EQUAL) reduce 466) ((T_MUL_EQUAL) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_OR_EQUAL) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_PLUS_EQUAL) reduce 466) ((T_POW) reduce 466) ((T_POW_EQUAL) reduce 466) ((T_SL) reduce 466) ((T_SL_EQUAL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) ((T_SR_EQUAL) reduce 466) ((T_XOR_EQUAL) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 5508 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 439) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 439) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 439) ((T_LOGICAL_OR) reduce 439) ((T_LOGICAL_XOR) reduce 439) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 5509 ((("%") reduce 432) (("*") reduce 432) (("+") reduce 432) ((",") reduce 432) (("-") reduce 432) ((".") reduce 432) (("/") reduce 432) (("<") reduce 432) ((">") reduce 432) (("?") reduce 432) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_BOOLEAN_AND) reduce 432) ((T_BOOLEAN_OR) reduce 432) ((T_COALESCE) reduce 432) ((T_DOUBLE_ARROW) reduce 432) ((T_INSTANCEOF) reduce 432) ((T_IS_EQUAL) reduce 432) ((T_IS_GREATER_OR_EQUAL) reduce 432) ((T_IS_IDENTICAL) reduce 432) ((T_IS_NOT_EQUAL) reduce 432) ((T_IS_NOT_IDENTICAL) reduce 432) ((T_IS_SMALLER_OR_EQUAL) reduce 432) ((T_LOGICAL_AND) reduce 432) ((T_LOGICAL_OR) reduce 432) ((T_LOGICAL_XOR) reduce 432) ((T_POW) shift) ((T_SL) reduce 432) ((T_SPACESHIP) reduce 432) ((T_SR) reduce 432) (("^") reduce 432) (("|") reduce 432)) 5511 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) ((",") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93)) 5512 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) ((",") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92)) 5513 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) ((",") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94)) 5514 ((("%") reduce 470) (("(") reduce 470) (("*") reduce 470) (("+") reduce 470) ((",") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_DOUBLE_ARROW) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470)) 5515 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) ((",") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91)) 5516 ((("%") reduce 365) (("*") reduce 365) (("+") reduce 365) ((",") reduce 365) (("-") reduce 365) ((".") reduce 365) (("/") reduce 365) (("<") reduce 365) ((">") reduce 365) (("?") reduce 365) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_BOOLEAN_AND) reduce 365) ((T_BOOLEAN_OR) reduce 365) ((T_COALESCE) reduce 365) ((T_DOUBLE_ARROW) reduce 365) ((T_INSTANCEOF) reduce 365) ((T_IS_EQUAL) reduce 365) ((T_IS_GREATER_OR_EQUAL) reduce 365) ((T_IS_IDENTICAL) reduce 365) ((T_IS_NOT_EQUAL) reduce 365) ((T_IS_NOT_IDENTICAL) reduce 365) ((T_IS_SMALLER_OR_EQUAL) reduce 365) ((T_LOGICAL_AND) reduce 365) ((T_LOGICAL_OR) reduce 365) ((T_LOGICAL_XOR) reduce 365) ((T_POW) reduce 365) ((T_SL) reduce 365) ((T_SPACESHIP) reduce 365) ((T_SR) reduce 365) (("^") reduce 365) (("|") reduce 365)) 5519 ((("%") reduce 472) (("(") reduce 472) (("*") reduce 472) (("+") reduce 472) ((",") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_DOUBLE_ARROW) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472)) 5520 ((("%") reduce 480) (("(") shift) (("*") reduce 480) (("+") reduce 480) ((",") reduce 480) (("-") reduce 480) ((".") reduce 480) (("/") reduce 480) (("<") reduce 480) ((">") reduce 480) (("?") reduce 480) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_BOOLEAN_AND) reduce 480) ((T_BOOLEAN_OR) reduce 480) ((T_COALESCE) reduce 480) ((T_DOUBLE_ARROW) reduce 480) ((T_INSTANCEOF) reduce 480) ((T_IS_EQUAL) reduce 480) ((T_IS_GREATER_OR_EQUAL) reduce 480) ((T_IS_IDENTICAL) reduce 480) ((T_IS_NOT_EQUAL) reduce 480) ((T_IS_NOT_IDENTICAL) reduce 480) ((T_IS_SMALLER_OR_EQUAL) reduce 480) ((T_LOGICAL_AND) reduce 480) ((T_LOGICAL_OR) reduce 480) ((T_LOGICAL_XOR) reduce 480) ((T_POW) reduce 480) ((T_SL) reduce 480) ((T_SPACESHIP) reduce 480) ((T_SR) reduce 480) (("^") reduce 480) (("|") reduce 480)) 5521 ((("%") reduce 471) (("(") reduce 471) (("*") reduce 471) (("+") reduce 471) ((",") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_DOUBLE_ARROW) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471)) 5522 ((("%") reduce 473) (("(") reduce 473) (("*") reduce 473) (("+") reduce 473) ((",") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_DOUBLE_ARROW) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 5523 ((("%") reduce 534) (("(") reduce 534) (("*") reduce 534) (("+") reduce 534) ((",") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_DOUBLE_ARROW) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 5530 ((("%") reduce 536) (("(") reduce 536) (("*") reduce 536) (("+") reduce 536) ((",") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_DOUBLE_ARROW) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 5532 ((("%") reduce 535) (("(") reduce 535) (("*") reduce 535) (("+") reduce 535) ((",") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_DOUBLE_ARROW) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 5533 ((("%") reduce 540) (("(") reduce 540) (("*") reduce 540) (("+") reduce 540) ((",") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_DOUBLE_ARROW) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 5534 ((("%") reduce 537) (("(") reduce 537) (("*") reduce 537) (("+") reduce 537) ((",") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_DOUBLE_ARROW) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 5535 ((("%") reduce 538) (("(") reduce 538) (("*") reduce 538) (("+") reduce 538) ((",") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_DOUBLE_ARROW) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 5537 ((("%") reduce 481) (("*") reduce 481) (("+") reduce 481) ((",") reduce 481) (("-") reduce 481) ((".") reduce 481) (("/") reduce 481) (("<") reduce 481) ((">") reduce 481) (("?") reduce 481) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_BOOLEAN_AND) reduce 481) ((T_BOOLEAN_OR) reduce 481) ((T_COALESCE) reduce 481) ((T_DOUBLE_ARROW) reduce 481) ((T_INSTANCEOF) reduce 481) ((T_IS_EQUAL) reduce 481) ((T_IS_GREATER_OR_EQUAL) reduce 481) ((T_IS_IDENTICAL) reduce 481) ((T_IS_NOT_EQUAL) reduce 481) ((T_IS_NOT_IDENTICAL) reduce 481) ((T_IS_SMALLER_OR_EQUAL) reduce 481) ((T_LOGICAL_AND) reduce 481) ((T_LOGICAL_OR) reduce 481) ((T_LOGICAL_XOR) reduce 481) ((T_POW) reduce 481) ((T_SL) reduce 481) ((T_SPACESHIP) reduce 481) ((T_SR) reduce 481) (("^") reduce 481) (("|") reduce 481)) 5538 ((("%") reduce 364) (("*") reduce 364) (("+") reduce 364) ((",") reduce 364) (("-") reduce 364) ((".") reduce 364) (("/") reduce 364) (("<") reduce 364) ((">") reduce 364) (("?") reduce 364) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_BOOLEAN_AND) reduce 364) ((T_BOOLEAN_OR) reduce 364) ((T_COALESCE) reduce 364) ((T_DOUBLE_ARROW) reduce 364) ((T_INSTANCEOF) reduce 364) ((T_IS_EQUAL) reduce 364) ((T_IS_GREATER_OR_EQUAL) reduce 364) ((T_IS_IDENTICAL) reduce 364) ((T_IS_NOT_EQUAL) reduce 364) ((T_IS_NOT_IDENTICAL) reduce 364) ((T_IS_SMALLER_OR_EQUAL) reduce 364) ((T_LOGICAL_AND) reduce 364) ((T_LOGICAL_OR) reduce 364) ((T_LOGICAL_XOR) reduce 364) ((T_POW) reduce 364) ((T_SL) reduce 364) ((T_SPACESHIP) reduce 364) ((T_SR) reduce 364) (("^") reduce 364) (("|") reduce 364)) 5539 ((("%") reduce 288) (("*") reduce 288) (("+") reduce 288) ((",") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("^") reduce 288) (("|") reduce 288)) 5543 ((("%") reduce 289) (("*") reduce 289) (("+") reduce 289) ((",") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("^") reduce 289) (("|") reduce 289)) 5544 ((("%") reduce 290) (("*") reduce 290) (("+") reduce 290) ((",") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("^") reduce 290) (("|") reduce 290)) 5546 ((("%") reduce 539) (("(") reduce 539) (("*") reduce 539) (("+") reduce 539) ((",") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_DOUBLE_ARROW) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 5547 ((("%") reduce 366) (("*") reduce 366) (("+") reduce 366) ((",") reduce 366) (("-") reduce 366) ((".") reduce 366) (("/") reduce 366) (("<") reduce 366) ((">") reduce 366) (("?") reduce 366) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_BOOLEAN_AND) reduce 366) ((T_BOOLEAN_OR) reduce 366) ((T_COALESCE) reduce 366) ((T_DOUBLE_ARROW) reduce 366) ((T_INSTANCEOF) reduce 366) ((T_IS_EQUAL) reduce 366) ((T_IS_GREATER_OR_EQUAL) reduce 366) ((T_IS_IDENTICAL) reduce 366) ((T_IS_NOT_EQUAL) reduce 366) ((T_IS_NOT_IDENTICAL) reduce 366) ((T_IS_SMALLER_OR_EQUAL) reduce 366) ((T_LOGICAL_AND) reduce 366) ((T_LOGICAL_OR) reduce 366) ((T_LOGICAL_XOR) reduce 366) ((T_POW) reduce 366) ((T_SL) reduce 366) ((T_SPACESHIP) reduce 366) ((T_SR) reduce 366) (("^") reduce 366) (("|") reduce 366)) 5555 ((("%") reduce 363) (("*") reduce 363) (("+") reduce 363) ((",") reduce 363) (("-") reduce 363) ((".") reduce 363) (("/") reduce 363) (("<") reduce 363) ((">") reduce 363) (("?") reduce 363) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_BOOLEAN_AND) reduce 363) ((T_BOOLEAN_OR) reduce 363) ((T_COALESCE) reduce 363) ((T_DOUBLE_ARROW) reduce 363) ((T_INSTANCEOF) reduce 363) ((T_IS_EQUAL) reduce 363) ((T_IS_GREATER_OR_EQUAL) reduce 363) ((T_IS_IDENTICAL) reduce 363) ((T_IS_NOT_EQUAL) reduce 363) ((T_IS_NOT_IDENTICAL) reduce 363) ((T_IS_SMALLER_OR_EQUAL) reduce 363) ((T_LOGICAL_AND) reduce 363) ((T_LOGICAL_OR) reduce 363) ((T_LOGICAL_XOR) reduce 363) ((T_POW) reduce 363) ((T_SL) reduce 363) ((T_SPACESHIP) reduce 363) ((T_SR) reduce 363) (("^") reduce 363) (("|") reduce 363)) 5557 ((("%") reduce 474) (("(") reduce 474) (("*") reduce 474) (("+") reduce 474) ((",") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_DOUBLE_ARROW) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474)) 5563 ((("%") reduce 230) (("*") reduce 230) (("+") reduce 230) ((",") reduce 230) (("-") reduce 230) ((".") reduce 230) (("/") reduce 230) (("<") reduce 230) ((">") reduce 230) (("?") reduce 230) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_BOOLEAN_AND) reduce 230) ((T_BOOLEAN_OR) reduce 230) ((T_COALESCE) reduce 230) ((T_DOUBLE_ARROW) reduce 230) ((T_INSTANCEOF) reduce 230) ((T_IS_EQUAL) reduce 230) ((T_IS_GREATER_OR_EQUAL) reduce 230) ((T_IS_IDENTICAL) reduce 230) ((T_IS_NOT_EQUAL) reduce 230) ((T_IS_NOT_IDENTICAL) reduce 230) ((T_IS_SMALLER_OR_EQUAL) reduce 230) ((T_LOGICAL_AND) reduce 230) ((T_LOGICAL_OR) reduce 230) ((T_LOGICAL_XOR) reduce 230) ((T_POW) reduce 230) ((T_SL) reduce 230) ((T_SPACESHIP) reduce 230) ((T_SR) reduce 230) (("^") reduce 230) (("|") reduce 230)) 5568 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 368) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 368) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 368) ((T_LOGICAL_OR) reduce 368) ((T_LOGICAL_XOR) reduce 368) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 5572 ((("%") reduce 575) (("*") reduce 575) (("+") reduce 575) ((",") reduce 575) (("-") reduce 575) ((".") reduce 575) (("/") reduce 575) (("<") reduce 575) ((">") reduce 575) (("?") reduce 575) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_BOOLEAN_AND) reduce 575) ((T_BOOLEAN_OR) reduce 575) ((T_COALESCE) reduce 575) ((T_DOUBLE_ARROW) reduce 575) ((T_INSTANCEOF) reduce 575) ((T_IS_EQUAL) reduce 575) ((T_IS_GREATER_OR_EQUAL) reduce 575) ((T_IS_IDENTICAL) reduce 575) ((T_IS_NOT_EQUAL) reduce 575) ((T_IS_NOT_IDENTICAL) reduce 575) ((T_IS_SMALLER_OR_EQUAL) reduce 575) ((T_LOGICAL_AND) reduce 575) ((T_LOGICAL_OR) reduce 575) ((T_LOGICAL_XOR) reduce 575) ((T_POW) reduce 575) ((T_SL) reduce 575) ((T_SPACESHIP) reduce 575) ((T_SR) reduce 575) (("^") reduce 575) (("|") reduce 575)) 5573 ((("%") reduce 428) (("*") reduce 428) (("+") reduce 428) ((",") reduce 428) (("-") reduce 428) ((".") reduce 428) (("/") reduce 428) (("<") reduce 428) ((">") reduce 428) (("?") reduce 428) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_BOOLEAN_AND) reduce 428) ((T_BOOLEAN_OR) reduce 428) ((T_COALESCE) reduce 428) ((T_DOUBLE_ARROW) reduce 428) ((T_INSTANCEOF) reduce 428) ((T_IS_EQUAL) reduce 428) ((T_IS_GREATER_OR_EQUAL) reduce 428) ((T_IS_IDENTICAL) reduce 428) ((T_IS_NOT_EQUAL) reduce 428) ((T_IS_NOT_IDENTICAL) reduce 428) ((T_IS_SMALLER_OR_EQUAL) reduce 428) ((T_LOGICAL_AND) reduce 428) ((T_LOGICAL_OR) reduce 428) ((T_LOGICAL_XOR) reduce 428) ((T_POW) shift) ((T_SL) reduce 428) ((T_SPACESHIP) reduce 428) ((T_SR) reduce 428) (("^") reduce 428) (("|") reduce 428)) 5574 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 578) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 578) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 5575 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 577) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 577) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 5576 ((("%") reduce 387) (("*") reduce 387) (("+") reduce 387) ((",") reduce 387) (("-") reduce 387) ((".") reduce 387) (("/") reduce 387) (("<") reduce 387) ((">") reduce 387) (("?") reduce 387) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_BOOLEAN_AND) reduce 387) ((T_BOOLEAN_OR) reduce 387) ((T_COALESCE) reduce 387) ((T_DOUBLE_ARROW) reduce 387) ((T_INSTANCEOF) reduce 387) ((T_IS_EQUAL) reduce 387) ((T_IS_GREATER_OR_EQUAL) reduce 387) ((T_IS_IDENTICAL) reduce 387) ((T_IS_NOT_EQUAL) reduce 387) ((T_IS_NOT_IDENTICAL) reduce 387) ((T_IS_SMALLER_OR_EQUAL) reduce 387) ((T_LOGICAL_AND) reduce 387) ((T_LOGICAL_OR) reduce 387) ((T_LOGICAL_XOR) reduce 387) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 387) ((T_SL) reduce 387) ((T_SPACESHIP) reduce 387) ((T_SR) reduce 387) (("[") reduce 510) (("^") reduce 387) (("{") reduce 510) (("|") reduce 387)) 5578 ((("%") reduce 435) (("*") reduce 435) (("+") reduce 435) ((",") reduce 435) (("-") reduce 435) ((".") reduce 435) (("/") reduce 435) (("<") reduce 435) ((">") reduce 435) (("?") reduce 435) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_BOOLEAN_AND) reduce 435) ((T_BOOLEAN_OR) reduce 435) ((T_COALESCE) reduce 435) ((T_DOUBLE_ARROW) reduce 435) ((T_INSTANCEOF) reduce 435) ((T_IS_EQUAL) reduce 435) ((T_IS_GREATER_OR_EQUAL) reduce 435) ((T_IS_IDENTICAL) reduce 435) ((T_IS_NOT_EQUAL) reduce 435) ((T_IS_NOT_IDENTICAL) reduce 435) ((T_IS_SMALLER_OR_EQUAL) reduce 435) ((T_LOGICAL_AND) reduce 435) ((T_LOGICAL_OR) reduce 435) ((T_LOGICAL_XOR) reduce 435) ((T_POW) reduce 435) ((T_SL) reduce 435) ((T_SPACESHIP) reduce 435) ((T_SR) reduce 435) (("^") reduce 435) (("|") reduce 435)) 5580 ((("%") reduce 476) (("*") reduce 476) (("+") reduce 476) ((",") reduce 476) (("-") reduce 476) ((".") reduce 476) (("/") reduce 476) (("<") reduce 476) ((">") reduce 476) (("?") reduce 476) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_BOOLEAN_AND) reduce 476) ((T_BOOLEAN_OR) reduce 476) ((T_COALESCE) reduce 476) ((T_DOUBLE_ARROW) reduce 476) ((T_INSTANCEOF) reduce 476) ((T_IS_EQUAL) reduce 476) ((T_IS_GREATER_OR_EQUAL) reduce 476) ((T_IS_IDENTICAL) reduce 476) ((T_IS_NOT_EQUAL) reduce 476) ((T_IS_NOT_IDENTICAL) reduce 476) ((T_IS_SMALLER_OR_EQUAL) reduce 476) ((T_LOGICAL_AND) reduce 476) ((T_LOGICAL_OR) reduce 476) ((T_LOGICAL_XOR) reduce 476) ((T_POW) reduce 476) ((T_SL) reduce 476) ((T_SPACESHIP) reduce 476) ((T_SR) reduce 476) (("^") reduce 476) (("|") reduce 476)) 5583 ((("%") reduce 579) (("*") reduce 579) (("+") reduce 579) ((",") reduce 579) (("-") reduce 579) ((".") reduce 579) (("/") reduce 579) (("<") reduce 579) ((">") reduce 579) (("?") reduce 579) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_BOOLEAN_AND) reduce 579) ((T_BOOLEAN_OR) reduce 579) ((T_COALESCE) reduce 579) ((T_DOUBLE_ARROW) reduce 579) ((T_INSTANCEOF) reduce 579) ((T_IS_EQUAL) reduce 579) ((T_IS_GREATER_OR_EQUAL) reduce 579) ((T_IS_IDENTICAL) reduce 579) ((T_IS_NOT_EQUAL) reduce 579) ((T_IS_NOT_IDENTICAL) reduce 579) ((T_IS_SMALLER_OR_EQUAL) reduce 579) ((T_LOGICAL_AND) reduce 579) ((T_LOGICAL_OR) reduce 579) ((T_LOGICAL_XOR) reduce 579) ((T_POW) reduce 579) ((T_SL) reduce 579) ((T_SPACESHIP) reduce 579) ((T_SR) reduce 579) (("^") reduce 579) (("|") reduce 579)) 5586 ((("%") reduce 576) (("*") reduce 576) (("+") reduce 576) ((",") reduce 576) (("-") reduce 576) ((".") reduce 576) (("/") reduce 576) (("<") reduce 576) ((">") reduce 576) (("?") reduce 576) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_BOOLEAN_AND) reduce 576) ((T_BOOLEAN_OR) reduce 576) ((T_COALESCE) reduce 576) ((T_DOUBLE_ARROW) reduce 576) ((T_INSTANCEOF) reduce 576) ((T_IS_EQUAL) reduce 576) ((T_IS_GREATER_OR_EQUAL) reduce 576) ((T_IS_IDENTICAL) reduce 576) ((T_IS_NOT_EQUAL) reduce 576) ((T_IS_NOT_IDENTICAL) reduce 576) ((T_IS_SMALLER_OR_EQUAL) reduce 576) ((T_LOGICAL_AND) reduce 576) ((T_LOGICAL_OR) reduce 576) ((T_LOGICAL_XOR) reduce 576) ((T_POW) reduce 576) ((T_SL) reduce 576) ((T_SPACESHIP) reduce 576) ((T_SR) reduce 576) (("^") reduce 576) (("|") reduce 576)) 5587 ((("%") reduce 429) (("*") reduce 429) (("+") reduce 429) ((",") reduce 429) (("-") reduce 429) ((".") reduce 429) (("/") reduce 429) (("<") reduce 429) ((">") reduce 429) (("?") reduce 429) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_BOOLEAN_AND) reduce 429) ((T_BOOLEAN_OR) reduce 429) ((T_COALESCE) reduce 429) ((T_DOUBLE_ARROW) reduce 429) ((T_INSTANCEOF) reduce 429) ((T_IS_EQUAL) reduce 429) ((T_IS_GREATER_OR_EQUAL) reduce 429) ((T_IS_IDENTICAL) reduce 429) ((T_IS_NOT_EQUAL) reduce 429) ((T_IS_NOT_IDENTICAL) reduce 429) ((T_IS_SMALLER_OR_EQUAL) reduce 429) ((T_LOGICAL_AND) reduce 429) ((T_LOGICAL_OR) reduce 429) ((T_LOGICAL_XOR) reduce 429) ((T_POW) shift) ((T_SL) reduce 429) ((T_SPACESHIP) reduce 429) ((T_SR) reduce 429) (("^") reduce 429) (("|") reduce 429)) 5588 (((T_DOUBLE_ARROW) reduce 124)) 5591 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 236) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 236)) 5592 ((("%") reduce 389) (("*") reduce 389) (("+") reduce 389) ((",") reduce 389) (("-") reduce 389) ((".") reduce 389) (("/") reduce 389) (("<") reduce 389) ((">") reduce 389) (("?") reduce 389) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_BOOLEAN_AND) reduce 389) ((T_BOOLEAN_OR) reduce 389) ((T_COALESCE) reduce 389) ((T_DOUBLE_ARROW) reduce 389) ((T_INSTANCEOF) reduce 389) ((T_IS_EQUAL) reduce 389) ((T_IS_GREATER_OR_EQUAL) reduce 389) ((T_IS_IDENTICAL) reduce 389) ((T_IS_NOT_EQUAL) reduce 389) ((T_IS_NOT_IDENTICAL) reduce 389) ((T_IS_SMALLER_OR_EQUAL) reduce 389) ((T_LOGICAL_AND) reduce 389) ((T_LOGICAL_OR) reduce 389) ((T_LOGICAL_XOR) reduce 389) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 389) ((T_SL) reduce 389) ((T_SPACESHIP) reduce 389) ((T_SR) reduce 389) (("[") reduce 510) (("^") reduce 389) (("{") reduce 510) (("|") reduce 389)) 5593 ((("%") reduce 372) (("*") reduce 372) (("+") reduce 372) ((",") reduce 372) (("-") reduce 372) ((".") reduce 372) (("/") reduce 372) (("<") reduce 372) ((">") reduce 372) (("?") reduce 372) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_BOOLEAN_AND) reduce 372) ((T_BOOLEAN_OR) reduce 372) ((T_COALESCE) reduce 372) ((T_DOUBLE_ARROW) reduce 372) ((T_INSTANCEOF) reduce 372) ((T_IS_EQUAL) reduce 372) ((T_IS_GREATER_OR_EQUAL) reduce 372) ((T_IS_IDENTICAL) reduce 372) ((T_IS_NOT_EQUAL) reduce 372) ((T_IS_NOT_IDENTICAL) reduce 372) ((T_IS_SMALLER_OR_EQUAL) reduce 372) ((T_LOGICAL_AND) reduce 372) ((T_LOGICAL_OR) reduce 372) ((T_LOGICAL_XOR) reduce 372) ((T_POW) reduce 372) ((T_SL) reduce 372) ((T_SPACESHIP) reduce 372) ((T_SR) reduce 372) (("^") reduce 372) (("|") reduce 372)) 5594 ((("%") reduce 433) (("*") reduce 433) (("+") reduce 433) ((",") reduce 433) (("-") reduce 433) ((".") reduce 433) (("/") reduce 433) (("<") reduce 433) ((">") reduce 433) (("?") reduce 433) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_BOOLEAN_AND) reduce 433) ((T_BOOLEAN_OR) reduce 433) ((T_COALESCE) reduce 433) ((T_DOUBLE_ARROW) reduce 433) ((T_INSTANCEOF) reduce 433) ((T_IS_EQUAL) reduce 433) ((T_IS_GREATER_OR_EQUAL) reduce 433) ((T_IS_IDENTICAL) reduce 433) ((T_IS_NOT_EQUAL) reduce 433) ((T_IS_NOT_IDENTICAL) reduce 433) ((T_IS_SMALLER_OR_EQUAL) reduce 433) ((T_LOGICAL_AND) reduce 433) ((T_LOGICAL_OR) reduce 433) ((T_LOGICAL_XOR) reduce 433) ((T_POW) shift) ((T_SL) reduce 433) ((T_SPACESHIP) reduce 433) ((T_SR) reduce 433) (("^") reduce 433) (("|") reduce 433)) 5595 ((("%") reduce 431) (("*") reduce 431) (("+") reduce 431) ((",") reduce 431) (("-") reduce 431) ((".") reduce 431) (("/") reduce 431) (("<") reduce 431) ((">") reduce 431) (("?") reduce 431) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_BOOLEAN_AND) reduce 431) ((T_BOOLEAN_OR) reduce 431) ((T_COALESCE) reduce 431) ((T_DOUBLE_ARROW) reduce 431) ((T_INSTANCEOF) reduce 431) ((T_IS_EQUAL) reduce 431) ((T_IS_GREATER_OR_EQUAL) reduce 431) ((T_IS_IDENTICAL) reduce 431) ((T_IS_NOT_EQUAL) reduce 431) ((T_IS_NOT_IDENTICAL) reduce 431) ((T_IS_SMALLER_OR_EQUAL) reduce 431) ((T_LOGICAL_AND) reduce 431) ((T_LOGICAL_OR) reduce 431) ((T_LOGICAL_XOR) reduce 431) ((T_POW) shift) ((T_SL) reduce 431) ((T_SPACESHIP) reduce 431) ((T_SR) reduce 431) (("^") reduce 431) (("|") reduce 431)) 5598 ((("%") reduce 482) (("(") reduce 482) (("*") reduce 482) (("+") reduce 482) ((",") reduce 482) (("-") reduce 482) ((".") reduce 482) (("/") reduce 482) (("<") reduce 482) ((">") reduce 482) (("?") reduce 482) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_BOOLEAN_AND) reduce 482) ((T_BOOLEAN_OR) reduce 482) ((T_COALESCE) reduce 482) ((T_DOUBLE_ARROW) reduce 482) ((T_INSTANCEOF) reduce 482) ((T_IS_EQUAL) reduce 482) ((T_IS_GREATER_OR_EQUAL) reduce 482) ((T_IS_IDENTICAL) reduce 482) ((T_IS_NOT_EQUAL) reduce 482) ((T_IS_NOT_IDENTICAL) reduce 482) ((T_IS_SMALLER_OR_EQUAL) reduce 482) ((T_LOGICAL_AND) reduce 482) ((T_LOGICAL_OR) reduce 482) ((T_LOGICAL_XOR) reduce 482) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 482) ((T_OBJECT_OPERATOR) reduce 482) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 482) ((T_POW) reduce 482) ((T_SL) reduce 482) ((T_SPACESHIP) reduce 482) ((T_SR) reduce 482) (("[") reduce 482) (("^") reduce 482) (("{") reduce 482) (("|") reduce 482)) 5599 ((("%") reduce 436) (("*") reduce 436) (("+") reduce 436) ((",") reduce 436) (("-") reduce 436) ((".") reduce 436) (("/") reduce 436) (("<") reduce 436) ((">") reduce 436) (("?") reduce 436) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_BOOLEAN_AND) reduce 436) ((T_BOOLEAN_OR) reduce 436) ((T_COALESCE) reduce 436) ((T_DOUBLE_ARROW) reduce 436) ((T_INSTANCEOF) reduce 436) ((T_IS_EQUAL) reduce 436) ((T_IS_GREATER_OR_EQUAL) reduce 436) ((T_IS_IDENTICAL) reduce 436) ((T_IS_NOT_EQUAL) reduce 436) ((T_IS_NOT_IDENTICAL) reduce 436) ((T_IS_SMALLER_OR_EQUAL) reduce 436) ((T_LOGICAL_AND) reduce 436) ((T_LOGICAL_OR) reduce 436) ((T_LOGICAL_XOR) reduce 436) ((T_POW) shift) ((T_SL) reduce 436) ((T_SPACESHIP) reduce 436) ((T_SR) reduce 436) (("^") reduce 436) (("|") reduce 436)) 5600 ((("%") reduce 409) (("*") reduce 409) (("+") reduce 409) ((",") reduce 409) (("-") reduce 409) ((".") reduce 409) (("/") reduce 409) (("<") reduce 409) ((">") reduce 409) (("?") reduce 409) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_BOOLEAN_AND) reduce 409) ((T_BOOLEAN_OR) reduce 409) ((T_COALESCE) reduce 409) ((T_DOUBLE_ARROW) reduce 409) ((T_INSTANCEOF) reduce 409) ((T_IS_EQUAL) reduce 409) ((T_IS_GREATER_OR_EQUAL) reduce 409) ((T_IS_IDENTICAL) reduce 409) ((T_IS_NOT_EQUAL) reduce 409) ((T_IS_NOT_IDENTICAL) reduce 409) ((T_IS_SMALLER_OR_EQUAL) reduce 409) ((T_LOGICAL_AND) reduce 409) ((T_LOGICAL_OR) reduce 409) ((T_LOGICAL_XOR) reduce 409) ((T_POW) shift) ((T_SL) reduce 409) ((T_SPACESHIP) reduce 409) ((T_SR) reduce 409) (("^") reduce 409) (("|") reduce 409)) 5601 ((("%") reduce 408) (("*") reduce 408) (("+") reduce 408) ((",") reduce 408) (("-") reduce 408) ((".") reduce 408) (("/") reduce 408) (("<") reduce 408) ((">") reduce 408) (("?") reduce 408) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_BOOLEAN_AND) reduce 408) ((T_BOOLEAN_OR) reduce 408) ((T_COALESCE) reduce 408) ((T_DOUBLE_ARROW) reduce 408) ((T_INSTANCEOF) reduce 408) ((T_IS_EQUAL) reduce 408) ((T_IS_GREATER_OR_EQUAL) reduce 408) ((T_IS_IDENTICAL) reduce 408) ((T_IS_NOT_EQUAL) reduce 408) ((T_IS_NOT_IDENTICAL) reduce 408) ((T_IS_SMALLER_OR_EQUAL) reduce 408) ((T_LOGICAL_AND) reduce 408) ((T_LOGICAL_OR) reduce 408) ((T_LOGICAL_XOR) reduce 408) ((T_POW) shift) ((T_SL) reduce 408) ((T_SPACESHIP) reduce 408) ((T_SR) reduce 408) (("^") reduce 408) (("|") reduce 408)) 5603 ((("%") reduce 422) (("(") reduce 517) (("*") reduce 422) (("+") reduce 422) ((",") reduce 422) (("-") reduce 422) ((".") reduce 422) (("/") reduce 422) (("<") reduce 422) ((">") reduce 422) (("?") reduce 422) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_BOOLEAN_AND) reduce 422) ((T_BOOLEAN_OR) reduce 422) ((T_COALESCE) reduce 422) ((T_DOUBLE_ARROW) reduce 422) ((T_INSTANCEOF) reduce 422) ((T_IS_EQUAL) reduce 422) ((T_IS_GREATER_OR_EQUAL) reduce 422) ((T_IS_IDENTICAL) reduce 422) ((T_IS_NOT_EQUAL) reduce 422) ((T_IS_NOT_IDENTICAL) reduce 422) ((T_IS_SMALLER_OR_EQUAL) reduce 422) ((T_LOGICAL_AND) reduce 422) ((T_LOGICAL_OR) reduce 422) ((T_LOGICAL_XOR) reduce 422) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 511) ((T_OBJECT_OPERATOR) reduce 511) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 511) ((T_POW) reduce 422) ((T_SL) reduce 422) ((T_SPACESHIP) reduce 422) ((T_SR) reduce 422) (("[") reduce 511) (("^") reduce 422) (("{") reduce 511) (("|") reduce 422)) 5604 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) ((",") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) (("=") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AND_EQUAL) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_COALESCE_EQUAL) reduce 531) ((T_CONCAT_EQUAL) reduce 531) ((T_DEC) reduce 531) ((T_DIV_EQUAL) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INC) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_MINUS_EQUAL) reduce 531) ((T_MOD_EQUAL) reduce 531) ((T_MUL_EQUAL) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_OR_EQUAL) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_PLUS_EQUAL) reduce 531) ((T_POW) reduce 531) ((T_POW_EQUAL) reduce 531) ((T_SL) reduce 531) ((T_SL_EQUAL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) ((T_SR_EQUAL) reduce 531) ((T_XOR_EQUAL) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 5607 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) ((",") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) (("=") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AND_EQUAL) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_COALESCE_EQUAL) reduce 530) ((T_CONCAT_EQUAL) reduce 530) ((T_DEC) reduce 530) ((T_DIV_EQUAL) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INC) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_MINUS_EQUAL) reduce 530) ((T_MOD_EQUAL) reduce 530) ((T_MUL_EQUAL) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_OR_EQUAL) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_PLUS_EQUAL) reduce 530) ((T_POW) reduce 530) ((T_POW_EQUAL) reduce 530) ((T_SL) reduce 530) ((T_SL_EQUAL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) ((T_SR_EQUAL) reduce 530) ((T_XOR_EQUAL) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 5609 ((("%") reduce 485) (("(") reduce 485) (("*") reduce 485) (("+") reduce 485) ((",") reduce 485) (("-") reduce 485) ((".") reduce 485) (("/") reduce 485) (("<") reduce 485) ((">") reduce 485) (("?") reduce 485) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_BOOLEAN_AND) reduce 485) ((T_BOOLEAN_OR) reduce 485) ((T_COALESCE) reduce 485) ((T_DOUBLE_ARROW) reduce 485) ((T_INSTANCEOF) reduce 485) ((T_IS_EQUAL) reduce 485) ((T_IS_GREATER_OR_EQUAL) reduce 485) ((T_IS_IDENTICAL) reduce 485) ((T_IS_NOT_EQUAL) reduce 485) ((T_IS_NOT_IDENTICAL) reduce 485) ((T_IS_SMALLER_OR_EQUAL) reduce 485) ((T_LOGICAL_AND) reduce 485) ((T_LOGICAL_OR) reduce 485) ((T_LOGICAL_XOR) reduce 485) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 485) ((T_OBJECT_OPERATOR) reduce 485) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 485) ((T_POW) reduce 485) ((T_SL) reduce 485) ((T_SPACESHIP) reduce 485) ((T_SR) reduce 485) (("[") reduce 485) (("^") reduce 485) (("{") reduce 485) (("|") reduce 485)) 5610 ((("%") reduce 410) (("*") reduce 410) (("+") reduce 410) ((",") reduce 410) (("-") reduce 410) ((".") reduce 410) (("/") reduce 410) (("<") reduce 410) ((">") reduce 410) (("?") reduce 410) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_BOOLEAN_AND) reduce 410) ((T_BOOLEAN_OR) reduce 410) ((T_COALESCE) reduce 410) ((T_DOUBLE_ARROW) reduce 410) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 410) ((T_IS_GREATER_OR_EQUAL) reduce 410) ((T_IS_IDENTICAL) reduce 410) ((T_IS_NOT_EQUAL) reduce 410) ((T_IS_NOT_IDENTICAL) reduce 410) ((T_IS_SMALLER_OR_EQUAL) reduce 410) ((T_LOGICAL_AND) reduce 410) ((T_LOGICAL_OR) reduce 410) ((T_LOGICAL_XOR) reduce 410) ((T_POW) shift) ((T_SL) reduce 410) ((T_SPACESHIP) reduce 410) ((T_SR) reduce 410) (("^") reduce 410) (("|") reduce 410)) 5615 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 368) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 368) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 368) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 368) ((T_LOGICAL_OR) reduce 368) ((T_LOGICAL_XOR) reduce 368) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 5619 ((("%") reduce 575) (("*") reduce 575) (("+") reduce 575) ((",") reduce 575) (("-") reduce 575) ((".") reduce 575) (("/") reduce 575) ((";") reduce 575) (("<") reduce 575) ((">") reduce 575) (("?") reduce 575) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_BOOLEAN_AND) reduce 575) ((T_BOOLEAN_OR) reduce 575) ((T_COALESCE) reduce 575) ((T_DOUBLE_ARROW) reduce 575) ((T_INSTANCEOF) reduce 575) ((T_IS_EQUAL) reduce 575) ((T_IS_GREATER_OR_EQUAL) reduce 575) ((T_IS_IDENTICAL) reduce 575) ((T_IS_NOT_EQUAL) reduce 575) ((T_IS_NOT_IDENTICAL) reduce 575) ((T_IS_SMALLER_OR_EQUAL) reduce 575) ((T_LOGICAL_AND) reduce 575) ((T_LOGICAL_OR) reduce 575) ((T_LOGICAL_XOR) reduce 575) ((T_POW) reduce 575) ((T_SL) reduce 575) ((T_SPACESHIP) reduce 575) ((T_SR) reduce 575) (("^") reduce 575) (("|") reduce 575)) 5620 ((("%") reduce 428) (("*") reduce 428) (("+") reduce 428) ((",") reduce 428) (("-") reduce 428) ((".") reduce 428) (("/") reduce 428) ((";") reduce 428) (("<") reduce 428) ((">") reduce 428) (("?") reduce 428) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_BOOLEAN_AND) reduce 428) ((T_BOOLEAN_OR) reduce 428) ((T_COALESCE) reduce 428) ((T_DOUBLE_ARROW) reduce 428) ((T_INSTANCEOF) reduce 428) ((T_IS_EQUAL) reduce 428) ((T_IS_GREATER_OR_EQUAL) reduce 428) ((T_IS_IDENTICAL) reduce 428) ((T_IS_NOT_EQUAL) reduce 428) ((T_IS_NOT_IDENTICAL) reduce 428) ((T_IS_SMALLER_OR_EQUAL) reduce 428) ((T_LOGICAL_AND) reduce 428) ((T_LOGICAL_OR) reduce 428) ((T_LOGICAL_XOR) reduce 428) ((T_POW) shift) ((T_SL) reduce 428) ((T_SPACESHIP) reduce 428) ((T_SR) reduce 428) (("^") reduce 428) (("|") reduce 428)) 5621 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 578) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 578) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 578) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 5622 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 577) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 577) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 577) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 5623 ((("%") reduce 387) (("*") reduce 387) (("+") reduce 387) ((",") reduce 387) (("-") reduce 387) ((".") reduce 387) (("/") reduce 387) ((";") reduce 387) (("<") reduce 387) ((">") reduce 387) (("?") reduce 387) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_BOOLEAN_AND) reduce 387) ((T_BOOLEAN_OR) reduce 387) ((T_COALESCE) reduce 387) ((T_DOUBLE_ARROW) reduce 387) ((T_INSTANCEOF) reduce 387) ((T_IS_EQUAL) reduce 387) ((T_IS_GREATER_OR_EQUAL) reduce 387) ((T_IS_IDENTICAL) reduce 387) ((T_IS_NOT_EQUAL) reduce 387) ((T_IS_NOT_IDENTICAL) reduce 387) ((T_IS_SMALLER_OR_EQUAL) reduce 387) ((T_LOGICAL_AND) reduce 387) ((T_LOGICAL_OR) reduce 387) ((T_LOGICAL_XOR) reduce 387) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 387) ((T_SL) reduce 387) ((T_SPACESHIP) reduce 387) ((T_SR) reduce 387) (("[") reduce 510) (("^") reduce 387) (("{") reduce 510) (("|") reduce 387)) 5625 ((("%") reduce 435) (("*") reduce 435) (("+") reduce 435) ((",") reduce 435) (("-") reduce 435) ((".") reduce 435) (("/") reduce 435) ((";") reduce 435) (("<") reduce 435) ((">") reduce 435) (("?") reduce 435) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_BOOLEAN_AND) reduce 435) ((T_BOOLEAN_OR) reduce 435) ((T_COALESCE) reduce 435) ((T_DOUBLE_ARROW) reduce 435) ((T_INSTANCEOF) reduce 435) ((T_IS_EQUAL) reduce 435) ((T_IS_GREATER_OR_EQUAL) reduce 435) ((T_IS_IDENTICAL) reduce 435) ((T_IS_NOT_EQUAL) reduce 435) ((T_IS_NOT_IDENTICAL) reduce 435) ((T_IS_SMALLER_OR_EQUAL) reduce 435) ((T_LOGICAL_AND) reduce 435) ((T_LOGICAL_OR) reduce 435) ((T_LOGICAL_XOR) reduce 435) ((T_POW) reduce 435) ((T_SL) reduce 435) ((T_SPACESHIP) reduce 435) ((T_SR) reduce 435) (("^") reduce 435) (("|") reduce 435)) 5627 ((("%") reduce 476) (("*") reduce 476) (("+") reduce 476) ((",") reduce 476) (("-") reduce 476) ((".") reduce 476) (("/") reduce 476) ((";") reduce 476) (("<") reduce 476) ((">") reduce 476) (("?") reduce 476) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_BOOLEAN_AND) reduce 476) ((T_BOOLEAN_OR) reduce 476) ((T_COALESCE) reduce 476) ((T_DOUBLE_ARROW) reduce 476) ((T_INSTANCEOF) reduce 476) ((T_IS_EQUAL) reduce 476) ((T_IS_GREATER_OR_EQUAL) reduce 476) ((T_IS_IDENTICAL) reduce 476) ((T_IS_NOT_EQUAL) reduce 476) ((T_IS_NOT_IDENTICAL) reduce 476) ((T_IS_SMALLER_OR_EQUAL) reduce 476) ((T_LOGICAL_AND) reduce 476) ((T_LOGICAL_OR) reduce 476) ((T_LOGICAL_XOR) reduce 476) ((T_POW) reduce 476) ((T_SL) reduce 476) ((T_SPACESHIP) reduce 476) ((T_SR) reduce 476) (("^") reduce 476) (("|") reduce 476)) 5630 ((("%") reduce 579) (("*") reduce 579) (("+") reduce 579) ((",") reduce 579) (("-") reduce 579) ((".") reduce 579) (("/") reduce 579) ((";") reduce 579) (("<") reduce 579) ((">") reduce 579) (("?") reduce 579) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_BOOLEAN_AND) reduce 579) ((T_BOOLEAN_OR) reduce 579) ((T_COALESCE) reduce 579) ((T_DOUBLE_ARROW) reduce 579) ((T_INSTANCEOF) reduce 579) ((T_IS_EQUAL) reduce 579) ((T_IS_GREATER_OR_EQUAL) reduce 579) ((T_IS_IDENTICAL) reduce 579) ((T_IS_NOT_EQUAL) reduce 579) ((T_IS_NOT_IDENTICAL) reduce 579) ((T_IS_SMALLER_OR_EQUAL) reduce 579) ((T_LOGICAL_AND) reduce 579) ((T_LOGICAL_OR) reduce 579) ((T_LOGICAL_XOR) reduce 579) ((T_POW) reduce 579) ((T_SL) reduce 579) ((T_SPACESHIP) reduce 579) ((T_SR) reduce 579) (("^") reduce 579) (("|") reduce 579)) 5633 ((("%") reduce 576) (("*") reduce 576) (("+") reduce 576) ((",") reduce 576) (("-") reduce 576) ((".") reduce 576) (("/") reduce 576) ((";") reduce 576) (("<") reduce 576) ((">") reduce 576) (("?") reduce 576) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_BOOLEAN_AND) reduce 576) ((T_BOOLEAN_OR) reduce 576) ((T_COALESCE) reduce 576) ((T_DOUBLE_ARROW) reduce 576) ((T_INSTANCEOF) reduce 576) ((T_IS_EQUAL) reduce 576) ((T_IS_GREATER_OR_EQUAL) reduce 576) ((T_IS_IDENTICAL) reduce 576) ((T_IS_NOT_EQUAL) reduce 576) ((T_IS_NOT_IDENTICAL) reduce 576) ((T_IS_SMALLER_OR_EQUAL) reduce 576) ((T_LOGICAL_AND) reduce 576) ((T_LOGICAL_OR) reduce 576) ((T_LOGICAL_XOR) reduce 576) ((T_POW) reduce 576) ((T_SL) reduce 576) ((T_SPACESHIP) reduce 576) ((T_SR) reduce 576) (("^") reduce 576) (("|") reduce 576)) 5634 ((("%") reduce 429) (("*") reduce 429) (("+") reduce 429) ((",") reduce 429) (("-") reduce 429) ((".") reduce 429) (("/") reduce 429) ((";") reduce 429) (("<") reduce 429) ((">") reduce 429) (("?") reduce 429) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_BOOLEAN_AND) reduce 429) ((T_BOOLEAN_OR) reduce 429) ((T_COALESCE) reduce 429) ((T_DOUBLE_ARROW) reduce 429) ((T_INSTANCEOF) reduce 429) ((T_IS_EQUAL) reduce 429) ((T_IS_GREATER_OR_EQUAL) reduce 429) ((T_IS_IDENTICAL) reduce 429) ((T_IS_NOT_EQUAL) reduce 429) ((T_IS_NOT_IDENTICAL) reduce 429) ((T_IS_SMALLER_OR_EQUAL) reduce 429) ((T_LOGICAL_AND) reduce 429) ((T_LOGICAL_OR) reduce 429) ((T_LOGICAL_XOR) reduce 429) ((T_POW) shift) ((T_SL) reduce 429) ((T_SPACESHIP) reduce 429) ((T_SR) reduce 429) (("^") reduce 429) (("|") reduce 429)) 5635 ((("%") reduce 389) (("*") reduce 389) (("+") reduce 389) ((",") reduce 389) (("-") reduce 389) ((".") reduce 389) (("/") reduce 389) ((";") reduce 389) (("<") reduce 389) ((">") reduce 389) (("?") reduce 389) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_BOOLEAN_AND) reduce 389) ((T_BOOLEAN_OR) reduce 389) ((T_COALESCE) reduce 389) ((T_DOUBLE_ARROW) reduce 389) ((T_INSTANCEOF) reduce 389) ((T_IS_EQUAL) reduce 389) ((T_IS_GREATER_OR_EQUAL) reduce 389) ((T_IS_IDENTICAL) reduce 389) ((T_IS_NOT_EQUAL) reduce 389) ((T_IS_NOT_IDENTICAL) reduce 389) ((T_IS_SMALLER_OR_EQUAL) reduce 389) ((T_LOGICAL_AND) reduce 389) ((T_LOGICAL_OR) reduce 389) ((T_LOGICAL_XOR) reduce 389) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 389) ((T_SL) reduce 389) ((T_SPACESHIP) reduce 389) ((T_SR) reduce 389) (("[") reduce 510) (("^") reduce 389) (("{") reduce 510) (("|") reduce 389)) 5636 ((("%") reduce 372) (("*") reduce 372) (("+") reduce 372) ((",") reduce 372) (("-") reduce 372) ((".") reduce 372) (("/") reduce 372) ((";") reduce 372) (("<") reduce 372) ((">") reduce 372) (("?") reduce 372) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_BOOLEAN_AND) reduce 372) ((T_BOOLEAN_OR) reduce 372) ((T_COALESCE) reduce 372) ((T_DOUBLE_ARROW) reduce 372) ((T_INSTANCEOF) reduce 372) ((T_IS_EQUAL) reduce 372) ((T_IS_GREATER_OR_EQUAL) reduce 372) ((T_IS_IDENTICAL) reduce 372) ((T_IS_NOT_EQUAL) reduce 372) ((T_IS_NOT_IDENTICAL) reduce 372) ((T_IS_SMALLER_OR_EQUAL) reduce 372) ((T_LOGICAL_AND) reduce 372) ((T_LOGICAL_OR) reduce 372) ((T_LOGICAL_XOR) reduce 372) ((T_POW) reduce 372) ((T_SL) reduce 372) ((T_SPACESHIP) reduce 372) ((T_SR) reduce 372) (("^") reduce 372) (("|") reduce 372)) 5637 ((("%") reduce 433) (("*") reduce 433) (("+") reduce 433) ((",") reduce 433) (("-") reduce 433) ((".") reduce 433) (("/") reduce 433) ((";") reduce 433) (("<") reduce 433) ((">") reduce 433) (("?") reduce 433) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_BOOLEAN_AND) reduce 433) ((T_BOOLEAN_OR) reduce 433) ((T_COALESCE) reduce 433) ((T_DOUBLE_ARROW) reduce 433) ((T_INSTANCEOF) reduce 433) ((T_IS_EQUAL) reduce 433) ((T_IS_GREATER_OR_EQUAL) reduce 433) ((T_IS_IDENTICAL) reduce 433) ((T_IS_NOT_EQUAL) reduce 433) ((T_IS_NOT_IDENTICAL) reduce 433) ((T_IS_SMALLER_OR_EQUAL) reduce 433) ((T_LOGICAL_AND) reduce 433) ((T_LOGICAL_OR) reduce 433) ((T_LOGICAL_XOR) reduce 433) ((T_POW) shift) ((T_SL) reduce 433) ((T_SPACESHIP) reduce 433) ((T_SR) reduce 433) (("^") reduce 433) (("|") reduce 433)) 5638 ((("%") reduce 431) (("*") reduce 431) (("+") reduce 431) ((",") reduce 431) (("-") reduce 431) ((".") reduce 431) (("/") reduce 431) ((";") reduce 431) (("<") reduce 431) ((">") reduce 431) (("?") reduce 431) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_BOOLEAN_AND) reduce 431) ((T_BOOLEAN_OR) reduce 431) ((T_COALESCE) reduce 431) ((T_DOUBLE_ARROW) reduce 431) ((T_INSTANCEOF) reduce 431) ((T_IS_EQUAL) reduce 431) ((T_IS_GREATER_OR_EQUAL) reduce 431) ((T_IS_IDENTICAL) reduce 431) ((T_IS_NOT_EQUAL) reduce 431) ((T_IS_NOT_IDENTICAL) reduce 431) ((T_IS_SMALLER_OR_EQUAL) reduce 431) ((T_LOGICAL_AND) reduce 431) ((T_LOGICAL_OR) reduce 431) ((T_LOGICAL_XOR) reduce 431) ((T_POW) shift) ((T_SL) reduce 431) ((T_SPACESHIP) reduce 431) ((T_SR) reduce 431) (("^") reduce 431) (("|") reduce 431)) 5641 ((("%") reduce 482) (("(") reduce 482) (("*") reduce 482) (("+") reduce 482) ((",") reduce 482) (("-") reduce 482) ((".") reduce 482) (("/") reduce 482) ((";") reduce 482) (("<") reduce 482) ((">") reduce 482) (("?") reduce 482) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_BOOLEAN_AND) reduce 482) ((T_BOOLEAN_OR) reduce 482) ((T_COALESCE) reduce 482) ((T_DOUBLE_ARROW) reduce 482) ((T_INSTANCEOF) reduce 482) ((T_IS_EQUAL) reduce 482) ((T_IS_GREATER_OR_EQUAL) reduce 482) ((T_IS_IDENTICAL) reduce 482) ((T_IS_NOT_EQUAL) reduce 482) ((T_IS_NOT_IDENTICAL) reduce 482) ((T_IS_SMALLER_OR_EQUAL) reduce 482) ((T_LOGICAL_AND) reduce 482) ((T_LOGICAL_OR) reduce 482) ((T_LOGICAL_XOR) reduce 482) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 482) ((T_OBJECT_OPERATOR) reduce 482) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 482) ((T_POW) reduce 482) ((T_SL) reduce 482) ((T_SPACESHIP) reduce 482) ((T_SR) reduce 482) (("[") reduce 482) (("^") reduce 482) (("{") reduce 482) (("|") reduce 482)) 5642 ((("%") reduce 436) (("*") reduce 436) (("+") reduce 436) ((",") reduce 436) (("-") reduce 436) ((".") reduce 436) (("/") reduce 436) ((";") reduce 436) (("<") reduce 436) ((">") reduce 436) (("?") reduce 436) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_BOOLEAN_AND) reduce 436) ((T_BOOLEAN_OR) reduce 436) ((T_COALESCE) reduce 436) ((T_DOUBLE_ARROW) reduce 436) ((T_INSTANCEOF) reduce 436) ((T_IS_EQUAL) reduce 436) ((T_IS_GREATER_OR_EQUAL) reduce 436) ((T_IS_IDENTICAL) reduce 436) ((T_IS_NOT_EQUAL) reduce 436) ((T_IS_NOT_IDENTICAL) reduce 436) ((T_IS_SMALLER_OR_EQUAL) reduce 436) ((T_LOGICAL_AND) reduce 436) ((T_LOGICAL_OR) reduce 436) ((T_LOGICAL_XOR) reduce 436) ((T_POW) shift) ((T_SL) reduce 436) ((T_SPACESHIP) reduce 436) ((T_SR) reduce 436) (("^") reduce 436) (("|") reduce 436)) 5643 ((("%") reduce 409) (("*") reduce 409) (("+") reduce 409) ((",") reduce 409) (("-") reduce 409) ((".") reduce 409) (("/") reduce 409) ((";") reduce 409) (("<") reduce 409) ((">") reduce 409) (("?") reduce 409) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_BOOLEAN_AND) reduce 409) ((T_BOOLEAN_OR) reduce 409) ((T_COALESCE) reduce 409) ((T_DOUBLE_ARROW) reduce 409) ((T_INSTANCEOF) reduce 409) ((T_IS_EQUAL) reduce 409) ((T_IS_GREATER_OR_EQUAL) reduce 409) ((T_IS_IDENTICAL) reduce 409) ((T_IS_NOT_EQUAL) reduce 409) ((T_IS_NOT_IDENTICAL) reduce 409) ((T_IS_SMALLER_OR_EQUAL) reduce 409) ((T_LOGICAL_AND) reduce 409) ((T_LOGICAL_OR) reduce 409) ((T_LOGICAL_XOR) reduce 409) ((T_POW) shift) ((T_SL) reduce 409) ((T_SPACESHIP) reduce 409) ((T_SR) reduce 409) (("^") reduce 409) (("|") reduce 409)) 5644 ((("%") reduce 408) (("*") reduce 408) (("+") reduce 408) ((",") reduce 408) (("-") reduce 408) ((".") reduce 408) (("/") reduce 408) ((";") reduce 408) (("<") reduce 408) ((">") reduce 408) (("?") reduce 408) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_BOOLEAN_AND) reduce 408) ((T_BOOLEAN_OR) reduce 408) ((T_COALESCE) reduce 408) ((T_DOUBLE_ARROW) reduce 408) ((T_INSTANCEOF) reduce 408) ((T_IS_EQUAL) reduce 408) ((T_IS_GREATER_OR_EQUAL) reduce 408) ((T_IS_IDENTICAL) reduce 408) ((T_IS_NOT_EQUAL) reduce 408) ((T_IS_NOT_IDENTICAL) reduce 408) ((T_IS_SMALLER_OR_EQUAL) reduce 408) ((T_LOGICAL_AND) reduce 408) ((T_LOGICAL_OR) reduce 408) ((T_LOGICAL_XOR) reduce 408) ((T_POW) shift) ((T_SL) reduce 408) ((T_SPACESHIP) reduce 408) ((T_SR) reduce 408) (("^") reduce 408) (("|") reduce 408)) 5646 ((("%") reduce 422) (("(") reduce 517) (("*") reduce 422) (("+") reduce 422) ((",") reduce 422) (("-") reduce 422) ((".") reduce 422) (("/") reduce 422) ((";") reduce 422) (("<") reduce 422) ((">") reduce 422) (("?") reduce 422) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_BOOLEAN_AND) reduce 422) ((T_BOOLEAN_OR) reduce 422) ((T_COALESCE) reduce 422) ((T_DOUBLE_ARROW) reduce 422) ((T_INSTANCEOF) reduce 422) ((T_IS_EQUAL) reduce 422) ((T_IS_GREATER_OR_EQUAL) reduce 422) ((T_IS_IDENTICAL) reduce 422) ((T_IS_NOT_EQUAL) reduce 422) ((T_IS_NOT_IDENTICAL) reduce 422) ((T_IS_SMALLER_OR_EQUAL) reduce 422) ((T_LOGICAL_AND) reduce 422) ((T_LOGICAL_OR) reduce 422) ((T_LOGICAL_XOR) reduce 422) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 511) ((T_OBJECT_OPERATOR) reduce 511) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 511) ((T_POW) reduce 422) ((T_SL) reduce 422) ((T_SPACESHIP) reduce 422) ((T_SR) reduce 422) (("[") reduce 511) (("^") reduce 422) (("{") reduce 511) (("|") reduce 422)) 5647 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) ((",") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) ((";") reduce 531) (("<") reduce 531) (("=") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AND_EQUAL) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_COALESCE_EQUAL) reduce 531) ((T_CONCAT_EQUAL) reduce 531) ((T_DEC) reduce 531) ((T_DIV_EQUAL) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INC) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_MINUS_EQUAL) reduce 531) ((T_MOD_EQUAL) reduce 531) ((T_MUL_EQUAL) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_OR_EQUAL) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_PLUS_EQUAL) reduce 531) ((T_POW) reduce 531) ((T_POW_EQUAL) reduce 531) ((T_SL) reduce 531) ((T_SL_EQUAL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) ((T_SR_EQUAL) reduce 531) ((T_XOR_EQUAL) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 5650 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) ((",") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) ((";") reduce 530) (("<") reduce 530) (("=") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AND_EQUAL) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_COALESCE_EQUAL) reduce 530) ((T_CONCAT_EQUAL) reduce 530) ((T_DEC) reduce 530) ((T_DIV_EQUAL) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INC) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_MINUS_EQUAL) reduce 530) ((T_MOD_EQUAL) reduce 530) ((T_MUL_EQUAL) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_OR_EQUAL) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_PLUS_EQUAL) reduce 530) ((T_POW) reduce 530) ((T_POW_EQUAL) reduce 530) ((T_SL) reduce 530) ((T_SL_EQUAL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) ((T_SR_EQUAL) reduce 530) ((T_XOR_EQUAL) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 5652 ((("%") reduce 485) (("(") reduce 485) (("*") reduce 485) (("+") reduce 485) ((",") reduce 485) (("-") reduce 485) ((".") reduce 485) (("/") reduce 485) ((";") reduce 485) (("<") reduce 485) ((">") reduce 485) (("?") reduce 485) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_BOOLEAN_AND) reduce 485) ((T_BOOLEAN_OR) reduce 485) ((T_COALESCE) reduce 485) ((T_DOUBLE_ARROW) reduce 485) ((T_INSTANCEOF) reduce 485) ((T_IS_EQUAL) reduce 485) ((T_IS_GREATER_OR_EQUAL) reduce 485) ((T_IS_IDENTICAL) reduce 485) ((T_IS_NOT_EQUAL) reduce 485) ((T_IS_NOT_IDENTICAL) reduce 485) ((T_IS_SMALLER_OR_EQUAL) reduce 485) ((T_LOGICAL_AND) reduce 485) ((T_LOGICAL_OR) reduce 485) ((T_LOGICAL_XOR) reduce 485) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 485) ((T_OBJECT_OPERATOR) reduce 485) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 485) ((T_POW) reduce 485) ((T_SL) reduce 485) ((T_SPACESHIP) reduce 485) ((T_SR) reduce 485) (("[") reduce 485) (("^") reduce 485) (("{") reduce 485) (("|") reduce 485)) 5653 ((("%") reduce 410) (("*") reduce 410) (("+") reduce 410) ((",") reduce 410) (("-") reduce 410) ((".") reduce 410) (("/") reduce 410) ((";") reduce 410) (("<") reduce 410) ((">") reduce 410) (("?") reduce 410) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_BOOLEAN_AND) reduce 410) ((T_BOOLEAN_OR) reduce 410) ((T_COALESCE) reduce 410) ((T_DOUBLE_ARROW) reduce 410) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 410) ((T_IS_GREATER_OR_EQUAL) reduce 410) ((T_IS_IDENTICAL) reduce 410) ((T_IS_NOT_EQUAL) reduce 410) ((T_IS_NOT_IDENTICAL) reduce 410) ((T_IS_SMALLER_OR_EQUAL) reduce 410) ((T_LOGICAL_AND) reduce 410) ((T_LOGICAL_OR) reduce 410) ((T_LOGICAL_XOR) reduce 410) ((T_POW) shift) ((T_SL) reduce 410) ((T_SPACESHIP) reduce 410) ((T_SR) reduce 410) (("^") reduce 410) (("|") reduce 410)) 5654 ((("%") reduce 434) (("*") reduce 434) (("+") reduce 434) ((",") reduce 434) (("-") reduce 434) ((".") reduce 434) (("/") reduce 434) ((";") reduce 434) (("<") reduce 434) ((">") reduce 434) (("?") reduce 434) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_BOOLEAN_AND) reduce 434) ((T_BOOLEAN_OR) reduce 434) ((T_COALESCE) reduce 434) ((T_INSTANCEOF) reduce 434) ((T_IS_EQUAL) reduce 434) ((T_IS_GREATER_OR_EQUAL) reduce 434) ((T_IS_IDENTICAL) reduce 434) ((T_IS_NOT_EQUAL) reduce 434) ((T_IS_NOT_IDENTICAL) reduce 434) ((T_IS_SMALLER_OR_EQUAL) reduce 434) ((T_LOGICAL_AND) reduce 434) ((T_LOGICAL_OR) reduce 434) ((T_LOGICAL_XOR) reduce 434) ((T_POW) shift) ((T_SL) reduce 434) ((T_SPACESHIP) reduce 434) ((T_SR) reduce 434) (("^") reduce 434) (("|") reduce 434)) 5655 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 444) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 444) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 5656 ((("%") reduce 430) (("*") reduce 430) (("+") reduce 430) ((",") reduce 430) (("-") reduce 430) ((".") reduce 430) (("/") reduce 430) ((";") reduce 430) (("<") reduce 430) ((">") reduce 430) (("?") reduce 430) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_BOOLEAN_AND) reduce 430) ((T_BOOLEAN_OR) reduce 430) ((T_COALESCE) reduce 430) ((T_INSTANCEOF) reduce 430) ((T_IS_EQUAL) reduce 430) ((T_IS_GREATER_OR_EQUAL) reduce 430) ((T_IS_IDENTICAL) reduce 430) ((T_IS_NOT_EQUAL) reduce 430) ((T_IS_NOT_IDENTICAL) reduce 430) ((T_IS_SMALLER_OR_EQUAL) reduce 430) ((T_LOGICAL_AND) reduce 430) ((T_LOGICAL_OR) reduce 430) ((T_LOGICAL_XOR) reduce 430) ((T_POW) shift) ((T_SL) reduce 430) ((T_SPACESHIP) reduce 430) ((T_SR) reduce 430) (("^") reduce 430) (("|") reduce 430)) 5657 ((("%") reduce 447) (("*") reduce 447) (("+") reduce 447) ((",") reduce 447) (("-") reduce 447) ((".") reduce 447) (("/") reduce 447) ((";") reduce 447) (("<") reduce 447) ((">") reduce 447) (("?") reduce 447) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_BOOLEAN_AND) reduce 447) ((T_BOOLEAN_OR) reduce 447) ((T_COALESCE) reduce 447) ((T_INSTANCEOF) reduce 447) ((T_IS_EQUAL) reduce 447) ((T_IS_GREATER_OR_EQUAL) reduce 447) ((T_IS_IDENTICAL) reduce 447) ((T_IS_NOT_EQUAL) reduce 447) ((T_IS_NOT_IDENTICAL) reduce 447) ((T_IS_SMALLER_OR_EQUAL) reduce 447) ((T_LOGICAL_AND) reduce 447) ((T_LOGICAL_OR) reduce 447) ((T_LOGICAL_XOR) reduce 447) ((T_POW) reduce 447) ((T_SL) reduce 447) ((T_SPACESHIP) reduce 447) ((T_SR) reduce 447) (("^") reduce 447) (("|") reduce 447)) 5659 ((("%") reduce 489) (("*") reduce 489) (("+") reduce 489) ((",") reduce 489) (("-") reduce 489) ((".") reduce 489) (("/") reduce 489) ((";") reduce 489) (("<") reduce 489) ((">") reduce 489) (("?") reduce 489) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_BOOLEAN_AND) reduce 489) ((T_BOOLEAN_OR) reduce 489) ((T_COALESCE) reduce 489) ((T_INSTANCEOF) reduce 489) ((T_IS_EQUAL) reduce 489) ((T_IS_GREATER_OR_EQUAL) reduce 489) ((T_IS_IDENTICAL) reduce 489) ((T_IS_NOT_EQUAL) reduce 489) ((T_IS_NOT_IDENTICAL) reduce 489) ((T_IS_SMALLER_OR_EQUAL) reduce 489) ((T_LOGICAL_AND) reduce 489) ((T_LOGICAL_OR) reduce 489) ((T_LOGICAL_XOR) reduce 489) ((T_POW) reduce 489) ((T_SL) reduce 489) ((T_SPACESHIP) reduce 489) ((T_SR) reduce 489) (("^") reduce 489) (("|") reduce 489)) 5661 ((("%") reduce 490) (("*") reduce 490) (("+") reduce 490) ((",") reduce 490) (("-") reduce 490) ((".") reduce 490) (("/") reduce 490) ((";") reduce 490) (("<") reduce 490) ((">") reduce 490) (("?") reduce 490) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_BOOLEAN_AND) reduce 490) ((T_BOOLEAN_OR) reduce 490) ((T_COALESCE) reduce 490) ((T_INSTANCEOF) reduce 490) ((T_IS_EQUAL) reduce 490) ((T_IS_GREATER_OR_EQUAL) reduce 490) ((T_IS_IDENTICAL) reduce 490) ((T_IS_NOT_EQUAL) reduce 490) ((T_IS_NOT_IDENTICAL) reduce 490) ((T_IS_SMALLER_OR_EQUAL) reduce 490) ((T_LOGICAL_AND) reduce 490) ((T_LOGICAL_OR) reduce 490) ((T_LOGICAL_XOR) reduce 490) ((T_POW) reduce 490) ((T_SL) reduce 490) ((T_SPACESHIP) reduce 490) ((T_SR) reduce 490) (("^") reduce 490) (("|") reduce 490)) 5662 ((("%") reduce 488) (("*") reduce 488) (("+") reduce 488) ((",") reduce 488) (("-") reduce 488) ((".") reduce 488) (("/") reduce 488) ((";") reduce 488) (("<") reduce 488) ((">") reduce 488) (("?") reduce 488) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_BOOLEAN_AND) reduce 488) ((T_BOOLEAN_OR) reduce 488) ((T_COALESCE) reduce 488) ((T_INSTANCEOF) reduce 488) ((T_IS_EQUAL) reduce 488) ((T_IS_GREATER_OR_EQUAL) reduce 488) ((T_IS_IDENTICAL) reduce 488) ((T_IS_NOT_EQUAL) reduce 488) ((T_IS_NOT_IDENTICAL) reduce 488) ((T_IS_SMALLER_OR_EQUAL) reduce 488) ((T_LOGICAL_AND) reduce 488) ((T_LOGICAL_OR) reduce 488) ((T_LOGICAL_XOR) reduce 488) ((T_POW) reduce 488) ((T_SL) reduce 488) ((T_SPACESHIP) reduce 488) ((T_SR) reduce 488) (("^") reduce 488) (("|") reduce 488)) 5663 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 581) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 581) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 5664 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 580) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 580) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 5665 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) ((",") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) ((";") reduce 466) (("<") reduce 466) (("=") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AND_EQUAL) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_COALESCE_EQUAL) reduce 466) ((T_CONCAT_EQUAL) reduce 466) ((T_DEC) reduce 466) ((T_DIV_EQUAL) reduce 466) ((T_INC) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_MINUS_EQUAL) reduce 466) ((T_MOD_EQUAL) reduce 466) ((T_MUL_EQUAL) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_OR_EQUAL) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_PLUS_EQUAL) reduce 466) ((T_POW) reduce 466) ((T_POW_EQUAL) reduce 466) ((T_SL) reduce 466) ((T_SL_EQUAL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) ((T_SR_EQUAL) reduce 466) ((T_XOR_EQUAL) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 5666 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 439) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 439) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 439) ((T_LOGICAL_OR) reduce 439) ((T_LOGICAL_XOR) reduce 439) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 5667 ((("%") reduce 432) (("*") reduce 432) (("+") reduce 432) ((",") reduce 432) (("-") reduce 432) ((".") reduce 432) (("/") reduce 432) ((";") reduce 432) (("<") reduce 432) ((">") reduce 432) (("?") reduce 432) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_BOOLEAN_AND) reduce 432) ((T_BOOLEAN_OR) reduce 432) ((T_COALESCE) reduce 432) ((T_INSTANCEOF) reduce 432) ((T_IS_EQUAL) reduce 432) ((T_IS_GREATER_OR_EQUAL) reduce 432) ((T_IS_IDENTICAL) reduce 432) ((T_IS_NOT_EQUAL) reduce 432) ((T_IS_NOT_IDENTICAL) reduce 432) ((T_IS_SMALLER_OR_EQUAL) reduce 432) ((T_LOGICAL_AND) reduce 432) ((T_LOGICAL_OR) reduce 432) ((T_LOGICAL_XOR) reduce 432) ((T_POW) shift) ((T_SL) reduce 432) ((T_SPACESHIP) reduce 432) ((T_SR) reduce 432) (("^") reduce 432) (("|") reduce 432)) 5669 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) ((",") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) ((";") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93)) 5670 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) ((",") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) ((";") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92)) 5671 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) ((",") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) ((";") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94)) 5672 ((("%") reduce 470) (("(") reduce 470) (("*") reduce 470) (("+") reduce 470) ((",") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) ((";") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470)) 5673 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) ((",") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) ((";") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91)) 5674 ((("%") reduce 365) (("*") reduce 365) (("+") reduce 365) ((",") reduce 365) (("-") reduce 365) ((".") reduce 365) (("/") reduce 365) ((";") reduce 365) (("<") reduce 365) ((">") reduce 365) (("?") reduce 365) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_BOOLEAN_AND) reduce 365) ((T_BOOLEAN_OR) reduce 365) ((T_COALESCE) reduce 365) ((T_INSTANCEOF) reduce 365) ((T_IS_EQUAL) reduce 365) ((T_IS_GREATER_OR_EQUAL) reduce 365) ((T_IS_IDENTICAL) reduce 365) ((T_IS_NOT_EQUAL) reduce 365) ((T_IS_NOT_IDENTICAL) reduce 365) ((T_IS_SMALLER_OR_EQUAL) reduce 365) ((T_LOGICAL_AND) reduce 365) ((T_LOGICAL_OR) reduce 365) ((T_LOGICAL_XOR) reduce 365) ((T_POW) reduce 365) ((T_SL) reduce 365) ((T_SPACESHIP) reduce 365) ((T_SR) reduce 365) (("^") reduce 365) (("|") reduce 365)) 5677 ((("%") reduce 472) (("(") reduce 472) (("*") reduce 472) (("+") reduce 472) ((",") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) ((";") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472)) 5678 ((("%") reduce 480) (("(") shift) (("*") reduce 480) (("+") reduce 480) ((",") reduce 480) (("-") reduce 480) ((".") reduce 480) (("/") reduce 480) ((";") reduce 480) (("<") reduce 480) ((">") reduce 480) (("?") reduce 480) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_BOOLEAN_AND) reduce 480) ((T_BOOLEAN_OR) reduce 480) ((T_COALESCE) reduce 480) ((T_INSTANCEOF) reduce 480) ((T_IS_EQUAL) reduce 480) ((T_IS_GREATER_OR_EQUAL) reduce 480) ((T_IS_IDENTICAL) reduce 480) ((T_IS_NOT_EQUAL) reduce 480) ((T_IS_NOT_IDENTICAL) reduce 480) ((T_IS_SMALLER_OR_EQUAL) reduce 480) ((T_LOGICAL_AND) reduce 480) ((T_LOGICAL_OR) reduce 480) ((T_LOGICAL_XOR) reduce 480) ((T_POW) reduce 480) ((T_SL) reduce 480) ((T_SPACESHIP) reduce 480) ((T_SR) reduce 480) (("^") reduce 480) (("|") reduce 480)) 5679 ((("%") reduce 471) (("(") reduce 471) (("*") reduce 471) (("+") reduce 471) ((",") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) ((";") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471)) 5680 ((("%") reduce 473) (("(") reduce 473) (("*") reduce 473) (("+") reduce 473) ((",") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) ((";") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 5681 ((("%") reduce 534) (("(") reduce 534) (("*") reduce 534) (("+") reduce 534) ((",") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) ((";") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 5688 ((("%") reduce 536) (("(") reduce 536) (("*") reduce 536) (("+") reduce 536) ((",") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) ((";") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 5690 ((("%") reduce 535) (("(") reduce 535) (("*") reduce 535) (("+") reduce 535) ((",") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) ((";") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 5691 ((("%") reduce 540) (("(") reduce 540) (("*") reduce 540) (("+") reduce 540) ((",") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) ((";") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 5692 ((("%") reduce 537) (("(") reduce 537) (("*") reduce 537) (("+") reduce 537) ((",") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) ((";") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 5693 ((("%") reduce 538) (("(") reduce 538) (("*") reduce 538) (("+") reduce 538) ((",") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) ((";") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 5695 ((("%") reduce 481) (("*") reduce 481) (("+") reduce 481) ((",") reduce 481) (("-") reduce 481) ((".") reduce 481) (("/") reduce 481) ((";") reduce 481) (("<") reduce 481) ((">") reduce 481) (("?") reduce 481) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_BOOLEAN_AND) reduce 481) ((T_BOOLEAN_OR) reduce 481) ((T_COALESCE) reduce 481) ((T_INSTANCEOF) reduce 481) ((T_IS_EQUAL) reduce 481) ((T_IS_GREATER_OR_EQUAL) reduce 481) ((T_IS_IDENTICAL) reduce 481) ((T_IS_NOT_EQUAL) reduce 481) ((T_IS_NOT_IDENTICAL) reduce 481) ((T_IS_SMALLER_OR_EQUAL) reduce 481) ((T_LOGICAL_AND) reduce 481) ((T_LOGICAL_OR) reduce 481) ((T_LOGICAL_XOR) reduce 481) ((T_POW) reduce 481) ((T_SL) reduce 481) ((T_SPACESHIP) reduce 481) ((T_SR) reduce 481) (("^") reduce 481) (("|") reduce 481)) 5696 ((("%") reduce 364) (("*") reduce 364) (("+") reduce 364) ((",") reduce 364) (("-") reduce 364) ((".") reduce 364) (("/") reduce 364) ((";") reduce 364) (("<") reduce 364) ((">") reduce 364) (("?") reduce 364) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_BOOLEAN_AND) reduce 364) ((T_BOOLEAN_OR) reduce 364) ((T_COALESCE) reduce 364) ((T_INSTANCEOF) reduce 364) ((T_IS_EQUAL) reduce 364) ((T_IS_GREATER_OR_EQUAL) reduce 364) ((T_IS_IDENTICAL) reduce 364) ((T_IS_NOT_EQUAL) reduce 364) ((T_IS_NOT_IDENTICAL) reduce 364) ((T_IS_SMALLER_OR_EQUAL) reduce 364) ((T_LOGICAL_AND) reduce 364) ((T_LOGICAL_OR) reduce 364) ((T_LOGICAL_XOR) reduce 364) ((T_POW) reduce 364) ((T_SL) reduce 364) ((T_SPACESHIP) reduce 364) ((T_SR) reduce 364) (("^") reduce 364) (("|") reduce 364)) 5697 ((("%") reduce 288) (("*") reduce 288) (("+") reduce 288) ((",") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) ((";") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("^") reduce 288) (("|") reduce 288)) 5701 ((("%") reduce 289) (("*") reduce 289) (("+") reduce 289) ((",") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) ((";") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("^") reduce 289) (("|") reduce 289)) 5702 ((("%") reduce 290) (("*") reduce 290) (("+") reduce 290) ((",") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) ((";") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("^") reduce 290) (("|") reduce 290)) 5704 ((("%") reduce 539) (("(") reduce 539) (("*") reduce 539) (("+") reduce 539) ((",") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) ((";") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 5705 ((("%") reduce 366) (("*") reduce 366) (("+") reduce 366) ((",") reduce 366) (("-") reduce 366) ((".") reduce 366) (("/") reduce 366) ((";") reduce 366) (("<") reduce 366) ((">") reduce 366) (("?") reduce 366) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_BOOLEAN_AND) reduce 366) ((T_BOOLEAN_OR) reduce 366) ((T_COALESCE) reduce 366) ((T_INSTANCEOF) reduce 366) ((T_IS_EQUAL) reduce 366) ((T_IS_GREATER_OR_EQUAL) reduce 366) ((T_IS_IDENTICAL) reduce 366) ((T_IS_NOT_EQUAL) reduce 366) ((T_IS_NOT_IDENTICAL) reduce 366) ((T_IS_SMALLER_OR_EQUAL) reduce 366) ((T_LOGICAL_AND) reduce 366) ((T_LOGICAL_OR) reduce 366) ((T_LOGICAL_XOR) reduce 366) ((T_POW) reduce 366) ((T_SL) reduce 366) ((T_SPACESHIP) reduce 366) ((T_SR) reduce 366) (("^") reduce 366) (("|") reduce 366)) 5713 ((("%") reduce 363) (("*") reduce 363) (("+") reduce 363) ((",") reduce 363) (("-") reduce 363) ((".") reduce 363) (("/") reduce 363) ((";") reduce 363) (("<") reduce 363) ((">") reduce 363) (("?") reduce 363) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_BOOLEAN_AND) reduce 363) ((T_BOOLEAN_OR) reduce 363) ((T_COALESCE) reduce 363) ((T_INSTANCEOF) reduce 363) ((T_IS_EQUAL) reduce 363) ((T_IS_GREATER_OR_EQUAL) reduce 363) ((T_IS_IDENTICAL) reduce 363) ((T_IS_NOT_EQUAL) reduce 363) ((T_IS_NOT_IDENTICAL) reduce 363) ((T_IS_SMALLER_OR_EQUAL) reduce 363) ((T_LOGICAL_AND) reduce 363) ((T_LOGICAL_OR) reduce 363) ((T_LOGICAL_XOR) reduce 363) ((T_POW) reduce 363) ((T_SL) reduce 363) ((T_SPACESHIP) reduce 363) ((T_SR) reduce 363) (("^") reduce 363) (("|") reduce 363)) 5715 ((("%") reduce 474) (("(") reduce 474) (("*") reduce 474) (("+") reduce 474) ((",") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) ((";") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474)) 5721 ((("%") reduce 230) (("*") reduce 230) (("+") reduce 230) ((",") reduce 230) (("-") reduce 230) ((".") reduce 230) (("/") reduce 230) ((";") reduce 230) (("<") reduce 230) ((">") reduce 230) (("?") reduce 230) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_BOOLEAN_AND) reduce 230) ((T_BOOLEAN_OR) reduce 230) ((T_COALESCE) reduce 230) ((T_INSTANCEOF) reduce 230) ((T_IS_EQUAL) reduce 230) ((T_IS_GREATER_OR_EQUAL) reduce 230) ((T_IS_IDENTICAL) reduce 230) ((T_IS_NOT_EQUAL) reduce 230) ((T_IS_NOT_IDENTICAL) reduce 230) ((T_IS_SMALLER_OR_EQUAL) reduce 230) ((T_LOGICAL_AND) reduce 230) ((T_LOGICAL_OR) reduce 230) ((T_LOGICAL_XOR) reduce 230) ((T_POW) reduce 230) ((T_SL) reduce 230) ((T_SPACESHIP) reduce 230) ((T_SR) reduce 230) (("^") reduce 230) (("|") reduce 230)) 5726 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 368) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 368) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 368) ((T_LOGICAL_OR) reduce 368) ((T_LOGICAL_XOR) reduce 368) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 5730 ((("%") reduce 575) (("*") reduce 575) (("+") reduce 575) ((",") reduce 575) (("-") reduce 575) ((".") reduce 575) (("/") reduce 575) ((";") reduce 575) (("<") reduce 575) ((">") reduce 575) (("?") reduce 575) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_BOOLEAN_AND) reduce 575) ((T_BOOLEAN_OR) reduce 575) ((T_COALESCE) reduce 575) ((T_INSTANCEOF) reduce 575) ((T_IS_EQUAL) reduce 575) ((T_IS_GREATER_OR_EQUAL) reduce 575) ((T_IS_IDENTICAL) reduce 575) ((T_IS_NOT_EQUAL) reduce 575) ((T_IS_NOT_IDENTICAL) reduce 575) ((T_IS_SMALLER_OR_EQUAL) reduce 575) ((T_LOGICAL_AND) reduce 575) ((T_LOGICAL_OR) reduce 575) ((T_LOGICAL_XOR) reduce 575) ((T_POW) reduce 575) ((T_SL) reduce 575) ((T_SPACESHIP) reduce 575) ((T_SR) reduce 575) (("^") reduce 575) (("|") reduce 575)) 5731 ((("%") reduce 428) (("*") reduce 428) (("+") reduce 428) ((",") reduce 428) (("-") reduce 428) ((".") reduce 428) (("/") reduce 428) ((";") reduce 428) (("<") reduce 428) ((">") reduce 428) (("?") reduce 428) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_BOOLEAN_AND) reduce 428) ((T_BOOLEAN_OR) reduce 428) ((T_COALESCE) reduce 428) ((T_INSTANCEOF) reduce 428) ((T_IS_EQUAL) reduce 428) ((T_IS_GREATER_OR_EQUAL) reduce 428) ((T_IS_IDENTICAL) reduce 428) ((T_IS_NOT_EQUAL) reduce 428) ((T_IS_NOT_IDENTICAL) reduce 428) ((T_IS_SMALLER_OR_EQUAL) reduce 428) ((T_LOGICAL_AND) reduce 428) ((T_LOGICAL_OR) reduce 428) ((T_LOGICAL_XOR) reduce 428) ((T_POW) shift) ((T_SL) reduce 428) ((T_SPACESHIP) reduce 428) ((T_SR) reduce 428) (("^") reduce 428) (("|") reduce 428)) 5732 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 578) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 578) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 5733 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 577) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 577) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 5734 ((("%") reduce 387) (("*") reduce 387) (("+") reduce 387) ((",") reduce 387) (("-") reduce 387) ((".") reduce 387) (("/") reduce 387) ((";") reduce 387) (("<") reduce 387) ((">") reduce 387) (("?") reduce 387) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_BOOLEAN_AND) reduce 387) ((T_BOOLEAN_OR) reduce 387) ((T_COALESCE) reduce 387) ((T_INSTANCEOF) reduce 387) ((T_IS_EQUAL) reduce 387) ((T_IS_GREATER_OR_EQUAL) reduce 387) ((T_IS_IDENTICAL) reduce 387) ((T_IS_NOT_EQUAL) reduce 387) ((T_IS_NOT_IDENTICAL) reduce 387) ((T_IS_SMALLER_OR_EQUAL) reduce 387) ((T_LOGICAL_AND) reduce 387) ((T_LOGICAL_OR) reduce 387) ((T_LOGICAL_XOR) reduce 387) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 387) ((T_SL) reduce 387) ((T_SPACESHIP) reduce 387) ((T_SR) reduce 387) (("[") reduce 510) (("^") reduce 387) (("{") reduce 510) (("|") reduce 387)) 5736 ((("%") reduce 435) (("*") reduce 435) (("+") reduce 435) ((",") reduce 435) (("-") reduce 435) ((".") reduce 435) (("/") reduce 435) ((";") reduce 435) (("<") reduce 435) ((">") reduce 435) (("?") reduce 435) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_BOOLEAN_AND) reduce 435) ((T_BOOLEAN_OR) reduce 435) ((T_COALESCE) reduce 435) ((T_INSTANCEOF) reduce 435) ((T_IS_EQUAL) reduce 435) ((T_IS_GREATER_OR_EQUAL) reduce 435) ((T_IS_IDENTICAL) reduce 435) ((T_IS_NOT_EQUAL) reduce 435) ((T_IS_NOT_IDENTICAL) reduce 435) ((T_IS_SMALLER_OR_EQUAL) reduce 435) ((T_LOGICAL_AND) reduce 435) ((T_LOGICAL_OR) reduce 435) ((T_LOGICAL_XOR) reduce 435) ((T_POW) reduce 435) ((T_SL) reduce 435) ((T_SPACESHIP) reduce 435) ((T_SR) reduce 435) (("^") reduce 435) (("|") reduce 435)) 5738 ((("%") reduce 476) (("*") reduce 476) (("+") reduce 476) ((",") reduce 476) (("-") reduce 476) ((".") reduce 476) (("/") reduce 476) ((";") reduce 476) (("<") reduce 476) ((">") reduce 476) (("?") reduce 476) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_BOOLEAN_AND) reduce 476) ((T_BOOLEAN_OR) reduce 476) ((T_COALESCE) reduce 476) ((T_INSTANCEOF) reduce 476) ((T_IS_EQUAL) reduce 476) ((T_IS_GREATER_OR_EQUAL) reduce 476) ((T_IS_IDENTICAL) reduce 476) ((T_IS_NOT_EQUAL) reduce 476) ((T_IS_NOT_IDENTICAL) reduce 476) ((T_IS_SMALLER_OR_EQUAL) reduce 476) ((T_LOGICAL_AND) reduce 476) ((T_LOGICAL_OR) reduce 476) ((T_LOGICAL_XOR) reduce 476) ((T_POW) reduce 476) ((T_SL) reduce 476) ((T_SPACESHIP) reduce 476) ((T_SR) reduce 476) (("^") reduce 476) (("|") reduce 476)) 5741 ((("%") reduce 579) (("*") reduce 579) (("+") reduce 579) ((",") reduce 579) (("-") reduce 579) ((".") reduce 579) (("/") reduce 579) ((";") reduce 579) (("<") reduce 579) ((">") reduce 579) (("?") reduce 579) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_BOOLEAN_AND) reduce 579) ((T_BOOLEAN_OR) reduce 579) ((T_COALESCE) reduce 579) ((T_INSTANCEOF) reduce 579) ((T_IS_EQUAL) reduce 579) ((T_IS_GREATER_OR_EQUAL) reduce 579) ((T_IS_IDENTICAL) reduce 579) ((T_IS_NOT_EQUAL) reduce 579) ((T_IS_NOT_IDENTICAL) reduce 579) ((T_IS_SMALLER_OR_EQUAL) reduce 579) ((T_LOGICAL_AND) reduce 579) ((T_LOGICAL_OR) reduce 579) ((T_LOGICAL_XOR) reduce 579) ((T_POW) reduce 579) ((T_SL) reduce 579) ((T_SPACESHIP) reduce 579) ((T_SR) reduce 579) (("^") reduce 579) (("|") reduce 579)) 5744 ((("%") reduce 576) (("*") reduce 576) (("+") reduce 576) ((",") reduce 576) (("-") reduce 576) ((".") reduce 576) (("/") reduce 576) ((";") reduce 576) (("<") reduce 576) ((">") reduce 576) (("?") reduce 576) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_BOOLEAN_AND) reduce 576) ((T_BOOLEAN_OR) reduce 576) ((T_COALESCE) reduce 576) ((T_INSTANCEOF) reduce 576) ((T_IS_EQUAL) reduce 576) ((T_IS_GREATER_OR_EQUAL) reduce 576) ((T_IS_IDENTICAL) reduce 576) ((T_IS_NOT_EQUAL) reduce 576) ((T_IS_NOT_IDENTICAL) reduce 576) ((T_IS_SMALLER_OR_EQUAL) reduce 576) ((T_LOGICAL_AND) reduce 576) ((T_LOGICAL_OR) reduce 576) ((T_LOGICAL_XOR) reduce 576) ((T_POW) reduce 576) ((T_SL) reduce 576) ((T_SPACESHIP) reduce 576) ((T_SR) reduce 576) (("^") reduce 576) (("|") reduce 576)) 5745 ((("%") reduce 429) (("*") reduce 429) (("+") reduce 429) ((",") reduce 429) (("-") reduce 429) ((".") reduce 429) (("/") reduce 429) ((";") reduce 429) (("<") reduce 429) ((">") reduce 429) (("?") reduce 429) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_BOOLEAN_AND) reduce 429) ((T_BOOLEAN_OR) reduce 429) ((T_COALESCE) reduce 429) ((T_INSTANCEOF) reduce 429) ((T_IS_EQUAL) reduce 429) ((T_IS_GREATER_OR_EQUAL) reduce 429) ((T_IS_IDENTICAL) reduce 429) ((T_IS_NOT_EQUAL) reduce 429) ((T_IS_NOT_IDENTICAL) reduce 429) ((T_IS_SMALLER_OR_EQUAL) reduce 429) ((T_LOGICAL_AND) reduce 429) ((T_LOGICAL_OR) reduce 429) ((T_LOGICAL_XOR) reduce 429) ((T_POW) shift) ((T_SL) reduce 429) ((T_SPACESHIP) reduce 429) ((T_SR) reduce 429) (("^") reduce 429) (("|") reduce 429)) 5746 ((("%") reduce 389) (("*") reduce 389) (("+") reduce 389) ((",") reduce 389) (("-") reduce 389) ((".") reduce 389) (("/") reduce 389) ((";") reduce 389) (("<") reduce 389) ((">") reduce 389) (("?") reduce 389) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_BOOLEAN_AND) reduce 389) ((T_BOOLEAN_OR) reduce 389) ((T_COALESCE) reduce 389) ((T_INSTANCEOF) reduce 389) ((T_IS_EQUAL) reduce 389) ((T_IS_GREATER_OR_EQUAL) reduce 389) ((T_IS_IDENTICAL) reduce 389) ((T_IS_NOT_EQUAL) reduce 389) ((T_IS_NOT_IDENTICAL) reduce 389) ((T_IS_SMALLER_OR_EQUAL) reduce 389) ((T_LOGICAL_AND) reduce 389) ((T_LOGICAL_OR) reduce 389) ((T_LOGICAL_XOR) reduce 389) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 389) ((T_SL) reduce 389) ((T_SPACESHIP) reduce 389) ((T_SR) reduce 389) (("[") reduce 510) (("^") reduce 389) (("{") reduce 510) (("|") reduce 389)) 5747 ((("%") reduce 372) (("*") reduce 372) (("+") reduce 372) ((",") reduce 372) (("-") reduce 372) ((".") reduce 372) (("/") reduce 372) ((";") reduce 372) (("<") reduce 372) ((">") reduce 372) (("?") reduce 372) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_BOOLEAN_AND) reduce 372) ((T_BOOLEAN_OR) reduce 372) ((T_COALESCE) reduce 372) ((T_INSTANCEOF) reduce 372) ((T_IS_EQUAL) reduce 372) ((T_IS_GREATER_OR_EQUAL) reduce 372) ((T_IS_IDENTICAL) reduce 372) ((T_IS_NOT_EQUAL) reduce 372) ((T_IS_NOT_IDENTICAL) reduce 372) ((T_IS_SMALLER_OR_EQUAL) reduce 372) ((T_LOGICAL_AND) reduce 372) ((T_LOGICAL_OR) reduce 372) ((T_LOGICAL_XOR) reduce 372) ((T_POW) reduce 372) ((T_SL) reduce 372) ((T_SPACESHIP) reduce 372) ((T_SR) reduce 372) (("^") reduce 372) (("|") reduce 372)) 5748 ((("%") reduce 433) (("*") reduce 433) (("+") reduce 433) ((",") reduce 433) (("-") reduce 433) ((".") reduce 433) (("/") reduce 433) ((";") reduce 433) (("<") reduce 433) ((">") reduce 433) (("?") reduce 433) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_BOOLEAN_AND) reduce 433) ((T_BOOLEAN_OR) reduce 433) ((T_COALESCE) reduce 433) ((T_INSTANCEOF) reduce 433) ((T_IS_EQUAL) reduce 433) ((T_IS_GREATER_OR_EQUAL) reduce 433) ((T_IS_IDENTICAL) reduce 433) ((T_IS_NOT_EQUAL) reduce 433) ((T_IS_NOT_IDENTICAL) reduce 433) ((T_IS_SMALLER_OR_EQUAL) reduce 433) ((T_LOGICAL_AND) reduce 433) ((T_LOGICAL_OR) reduce 433) ((T_LOGICAL_XOR) reduce 433) ((T_POW) shift) ((T_SL) reduce 433) ((T_SPACESHIP) reduce 433) ((T_SR) reduce 433) (("^") reduce 433) (("|") reduce 433)) 5749 ((("%") reduce 431) (("*") reduce 431) (("+") reduce 431) ((",") reduce 431) (("-") reduce 431) ((".") reduce 431) (("/") reduce 431) ((";") reduce 431) (("<") reduce 431) ((">") reduce 431) (("?") reduce 431) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_BOOLEAN_AND) reduce 431) ((T_BOOLEAN_OR) reduce 431) ((T_COALESCE) reduce 431) ((T_INSTANCEOF) reduce 431) ((T_IS_EQUAL) reduce 431) ((T_IS_GREATER_OR_EQUAL) reduce 431) ((T_IS_IDENTICAL) reduce 431) ((T_IS_NOT_EQUAL) reduce 431) ((T_IS_NOT_IDENTICAL) reduce 431) ((T_IS_SMALLER_OR_EQUAL) reduce 431) ((T_LOGICAL_AND) reduce 431) ((T_LOGICAL_OR) reduce 431) ((T_LOGICAL_XOR) reduce 431) ((T_POW) shift) ((T_SL) reduce 431) ((T_SPACESHIP) reduce 431) ((T_SR) reduce 431) (("^") reduce 431) (("|") reduce 431)) 5752 ((("%") reduce 482) (("(") reduce 482) (("*") reduce 482) (("+") reduce 482) ((",") reduce 482) (("-") reduce 482) ((".") reduce 482) (("/") reduce 482) ((";") reduce 482) (("<") reduce 482) ((">") reduce 482) (("?") reduce 482) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_BOOLEAN_AND) reduce 482) ((T_BOOLEAN_OR) reduce 482) ((T_COALESCE) reduce 482) ((T_INSTANCEOF) reduce 482) ((T_IS_EQUAL) reduce 482) ((T_IS_GREATER_OR_EQUAL) reduce 482) ((T_IS_IDENTICAL) reduce 482) ((T_IS_NOT_EQUAL) reduce 482) ((T_IS_NOT_IDENTICAL) reduce 482) ((T_IS_SMALLER_OR_EQUAL) reduce 482) ((T_LOGICAL_AND) reduce 482) ((T_LOGICAL_OR) reduce 482) ((T_LOGICAL_XOR) reduce 482) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 482) ((T_OBJECT_OPERATOR) reduce 482) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 482) ((T_POW) reduce 482) ((T_SL) reduce 482) ((T_SPACESHIP) reduce 482) ((T_SR) reduce 482) (("[") reduce 482) (("^") reduce 482) (("{") reduce 482) (("|") reduce 482)) 5753 ((("%") reduce 436) (("*") reduce 436) (("+") reduce 436) ((",") reduce 436) (("-") reduce 436) ((".") reduce 436) (("/") reduce 436) ((";") reduce 436) (("<") reduce 436) ((">") reduce 436) (("?") reduce 436) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_BOOLEAN_AND) reduce 436) ((T_BOOLEAN_OR) reduce 436) ((T_COALESCE) reduce 436) ((T_INSTANCEOF) reduce 436) ((T_IS_EQUAL) reduce 436) ((T_IS_GREATER_OR_EQUAL) reduce 436) ((T_IS_IDENTICAL) reduce 436) ((T_IS_NOT_EQUAL) reduce 436) ((T_IS_NOT_IDENTICAL) reduce 436) ((T_IS_SMALLER_OR_EQUAL) reduce 436) ((T_LOGICAL_AND) reduce 436) ((T_LOGICAL_OR) reduce 436) ((T_LOGICAL_XOR) reduce 436) ((T_POW) shift) ((T_SL) reduce 436) ((T_SPACESHIP) reduce 436) ((T_SR) reduce 436) (("^") reduce 436) (("|") reduce 436)) 5754 ((("%") reduce 409) (("*") reduce 409) (("+") reduce 409) ((",") reduce 409) (("-") reduce 409) ((".") reduce 409) (("/") reduce 409) ((";") reduce 409) (("<") reduce 409) ((">") reduce 409) (("?") reduce 409) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_BOOLEAN_AND) reduce 409) ((T_BOOLEAN_OR) reduce 409) ((T_COALESCE) reduce 409) ((T_INSTANCEOF) reduce 409) ((T_IS_EQUAL) reduce 409) ((T_IS_GREATER_OR_EQUAL) reduce 409) ((T_IS_IDENTICAL) reduce 409) ((T_IS_NOT_EQUAL) reduce 409) ((T_IS_NOT_IDENTICAL) reduce 409) ((T_IS_SMALLER_OR_EQUAL) reduce 409) ((T_LOGICAL_AND) reduce 409) ((T_LOGICAL_OR) reduce 409) ((T_LOGICAL_XOR) reduce 409) ((T_POW) shift) ((T_SL) reduce 409) ((T_SPACESHIP) reduce 409) ((T_SR) reduce 409) (("^") reduce 409) (("|") reduce 409)) 5755 ((("%") reduce 408) (("*") reduce 408) (("+") reduce 408) ((",") reduce 408) (("-") reduce 408) ((".") reduce 408) (("/") reduce 408) ((";") reduce 408) (("<") reduce 408) ((">") reduce 408) (("?") reduce 408) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_BOOLEAN_AND) reduce 408) ((T_BOOLEAN_OR) reduce 408) ((T_COALESCE) reduce 408) ((T_INSTANCEOF) reduce 408) ((T_IS_EQUAL) reduce 408) ((T_IS_GREATER_OR_EQUAL) reduce 408) ((T_IS_IDENTICAL) reduce 408) ((T_IS_NOT_EQUAL) reduce 408) ((T_IS_NOT_IDENTICAL) reduce 408) ((T_IS_SMALLER_OR_EQUAL) reduce 408) ((T_LOGICAL_AND) reduce 408) ((T_LOGICAL_OR) reduce 408) ((T_LOGICAL_XOR) reduce 408) ((T_POW) shift) ((T_SL) reduce 408) ((T_SPACESHIP) reduce 408) ((T_SR) reduce 408) (("^") reduce 408) (("|") reduce 408)) 5757 ((("%") reduce 422) (("(") reduce 517) (("*") reduce 422) (("+") reduce 422) ((",") reduce 422) (("-") reduce 422) ((".") reduce 422) (("/") reduce 422) ((";") reduce 422) (("<") reduce 422) ((">") reduce 422) (("?") reduce 422) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_BOOLEAN_AND) reduce 422) ((T_BOOLEAN_OR) reduce 422) ((T_COALESCE) reduce 422) ((T_INSTANCEOF) reduce 422) ((T_IS_EQUAL) reduce 422) ((T_IS_GREATER_OR_EQUAL) reduce 422) ((T_IS_IDENTICAL) reduce 422) ((T_IS_NOT_EQUAL) reduce 422) ((T_IS_NOT_IDENTICAL) reduce 422) ((T_IS_SMALLER_OR_EQUAL) reduce 422) ((T_LOGICAL_AND) reduce 422) ((T_LOGICAL_OR) reduce 422) ((T_LOGICAL_XOR) reduce 422) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 511) ((T_OBJECT_OPERATOR) reduce 511) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 511) ((T_POW) reduce 422) ((T_SL) reduce 422) ((T_SPACESHIP) reduce 422) ((T_SR) reduce 422) (("[") reduce 511) (("^") reduce 422) (("{") reduce 511) (("|") reduce 422)) 5758 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) ((",") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) ((";") reduce 531) (("<") reduce 531) (("=") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AND_EQUAL) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_COALESCE_EQUAL) reduce 531) ((T_CONCAT_EQUAL) reduce 531) ((T_DEC) reduce 531) ((T_DIV_EQUAL) reduce 531) ((T_INC) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_MINUS_EQUAL) reduce 531) ((T_MOD_EQUAL) reduce 531) ((T_MUL_EQUAL) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_OR_EQUAL) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_PLUS_EQUAL) reduce 531) ((T_POW) reduce 531) ((T_POW_EQUAL) reduce 531) ((T_SL) reduce 531) ((T_SL_EQUAL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) ((T_SR_EQUAL) reduce 531) ((T_XOR_EQUAL) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 5761 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) ((",") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) ((";") reduce 530) (("<") reduce 530) (("=") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AND_EQUAL) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_COALESCE_EQUAL) reduce 530) ((T_CONCAT_EQUAL) reduce 530) ((T_DEC) reduce 530) ((T_DIV_EQUAL) reduce 530) ((T_INC) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_MINUS_EQUAL) reduce 530) ((T_MOD_EQUAL) reduce 530) ((T_MUL_EQUAL) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_OR_EQUAL) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_PLUS_EQUAL) reduce 530) ((T_POW) reduce 530) ((T_POW_EQUAL) reduce 530) ((T_SL) reduce 530) ((T_SL_EQUAL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) ((T_SR_EQUAL) reduce 530) ((T_XOR_EQUAL) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 5763 ((("%") reduce 485) (("(") reduce 485) (("*") reduce 485) (("+") reduce 485) ((",") reduce 485) (("-") reduce 485) ((".") reduce 485) (("/") reduce 485) ((";") reduce 485) (("<") reduce 485) ((">") reduce 485) (("?") reduce 485) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_BOOLEAN_AND) reduce 485) ((T_BOOLEAN_OR) reduce 485) ((T_COALESCE) reduce 485) ((T_INSTANCEOF) reduce 485) ((T_IS_EQUAL) reduce 485) ((T_IS_GREATER_OR_EQUAL) reduce 485) ((T_IS_IDENTICAL) reduce 485) ((T_IS_NOT_EQUAL) reduce 485) ((T_IS_NOT_IDENTICAL) reduce 485) ((T_IS_SMALLER_OR_EQUAL) reduce 485) ((T_LOGICAL_AND) reduce 485) ((T_LOGICAL_OR) reduce 485) ((T_LOGICAL_XOR) reduce 485) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 485) ((T_OBJECT_OPERATOR) reduce 485) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 485) ((T_POW) reduce 485) ((T_SL) reduce 485) ((T_SPACESHIP) reduce 485) ((T_SR) reduce 485) (("[") reduce 485) (("^") reduce 485) (("{") reduce 485) (("|") reduce 485)) 5764 ((("%") reduce 410) (("*") reduce 410) (("+") reduce 410) ((",") reduce 410) (("-") reduce 410) ((".") reduce 410) (("/") reduce 410) ((";") reduce 410) (("<") reduce 410) ((">") reduce 410) (("?") reduce 410) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_BOOLEAN_AND) reduce 410) ((T_BOOLEAN_OR) reduce 410) ((T_COALESCE) reduce 410) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 410) ((T_IS_GREATER_OR_EQUAL) reduce 410) ((T_IS_IDENTICAL) reduce 410) ((T_IS_NOT_EQUAL) reduce 410) ((T_IS_NOT_IDENTICAL) reduce 410) ((T_IS_SMALLER_OR_EQUAL) reduce 410) ((T_LOGICAL_AND) reduce 410) ((T_LOGICAL_OR) reduce 410) ((T_LOGICAL_XOR) reduce 410) ((T_POW) shift) ((T_SL) reduce 410) ((T_SPACESHIP) reduce 410) ((T_SR) reduce 410) (("^") reduce 410) (("|") reduce 410)) 5766 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 285) ((T_VARIABLE) reduce 285)) 5767 (((T_VARIABLE) reduce 277)) 5768 (((T_VARIABLE) reduce 278)) 5769 (((T_VARIABLE) reduce 93)) 5770 (((T_VARIABLE) reduce 92)) 5771 (((T_VARIABLE) reduce 94)) 5772 (((T_VARIABLE) reduce 91)) 5773 (((T_VARIABLE) reduce 279)) 5774 (((T_VARIABLE) reduce 274)) 5776 ((("|") reduce 281)) 5777 ((("(") reduce 339) (("?") reduce 339) ((T_ABSTRACT) reduce 339) ((T_ARRAY) reduce 339) ((T_CALLABLE) reduce 339) ((T_CONST) reduce 339) ((T_FINAL) reduce 339) ((T_FUNCTION) reduce 339) ((T_NAME_FULLY_QUALIFIED) reduce 339) ((T_NAME_QUALIFIED) reduce 339) ((T_NAME_RELATIVE) reduce 339) ((T_PRIVATE) reduce 339) ((T_PROTECTED) reduce 339) ((T_PUBLIC) reduce 339) ((T_READONLY) reduce 339) ((T_STATIC) reduce 339) ((T_STRING) reduce 339) ((T_VARIABLE) reduce 339)) 5778 (((T_ABSTRACT) reduce 453) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 453) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 453) ((T_ARRAY) reduce 453) ((T_AS) reduce 453) ((T_BREAK) reduce 453) ((T_CALLABLE) reduce 453) ((T_CASE) reduce 453) ((T_CATCH) reduce 453) ((T_CLASS) reduce 453) ((T_CLASS_C) reduce 453) ((T_CLONE) reduce 453) ((T_CONST) reduce 453) ((T_CONTINUE) reduce 453) ((T_DECLARE) reduce 453) ((T_DEFAULT) reduce 453) ((T_DIR) reduce 453) ((T_DO) reduce 453) ((T_ECHO) reduce 453) ((T_ELSE) reduce 453) ((T_ELSEIF) reduce 453) ((T_EMPTY) reduce 453) ((T_ENDDECLARE) reduce 453) ((T_ENDFOR) reduce 453) ((T_ENDFOREACH) reduce 453) ((T_ENDIF) reduce 453) ((T_ENDSWITCH) reduce 453) ((T_ENDWHILE) reduce 453) ((T_ENUM) reduce 453) ((T_EVAL) reduce 453) ((T_EXIT) reduce 453) ((T_EXTENDS) reduce 453) ((T_FILE) reduce 453) ((T_FINAL) reduce 453) ((T_FINALLY) reduce 453) ((T_FN) reduce 453) ((T_FOR) reduce 453) ((T_FOREACH) reduce 453) ((T_FUNCTION) reduce 453) ((T_FUNC_C) reduce 453) ((T_GLOBAL) reduce 453) ((T_GOTO) reduce 453) ((T_IF) reduce 453) ((T_IMPLEMENTS) reduce 453) ((T_INCLUDE) reduce 453) ((T_INCLUDE_ONCE) reduce 453) ((T_INSTANCEOF) reduce 453) ((T_INSTEADOF) reduce 453) ((T_INTERFACE) reduce 453) ((T_ISSET) reduce 453) ((T_LINE) reduce 453) ((T_LIST) reduce 453) ((T_LOGICAL_AND) reduce 453) ((T_LOGICAL_OR) reduce 453) ((T_LOGICAL_XOR) reduce 453) ((T_MATCH) reduce 453) ((T_METHOD_C) reduce 453) ((T_NAMESPACE) reduce 453) ((T_NEW) reduce 453) ((T_NS_C) reduce 453) ((T_PRINT) reduce 453) ((T_PRIVATE) reduce 453) ((T_PROTECTED) reduce 453) ((T_PUBLIC) reduce 453) ((T_READONLY) reduce 453) ((T_REQUIRE) reduce 453) ((T_REQUIRE_ONCE) reduce 453) ((T_RETURN) reduce 453) ((T_STATIC) reduce 453) ((T_STRING) reduce 453) ((T_SWITCH) reduce 453) ((T_THROW) reduce 453) ((T_TRAIT) reduce 453) ((T_TRAIT_C) reduce 453) ((T_TRY) reduce 453) ((T_UNSET) reduce 453) ((T_USE) reduce 453) ((T_VAR) reduce 453) ((T_WHILE) reduce 453) ((T_YIELD) reduce 453)) 5779 (((T_ABSTRACT) reduce 457) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_ARRAY) reduce 457) ((T_AS) reduce 457) ((T_BREAK) reduce 457) ((T_CALLABLE) reduce 457) ((T_CASE) reduce 457) ((T_CATCH) reduce 457) ((T_CLASS) reduce 457) ((T_CLASS_C) reduce 457) ((T_CLONE) reduce 457) ((T_CONST) reduce 457) ((T_CONTINUE) reduce 457) ((T_DECLARE) reduce 457) ((T_DEFAULT) reduce 457) ((T_DIR) reduce 457) ((T_DO) reduce 457) ((T_ECHO) reduce 457) ((T_ELSE) reduce 457) ((T_ELSEIF) reduce 457) ((T_EMPTY) reduce 457) ((T_ENDDECLARE) reduce 457) ((T_ENDFOR) reduce 457) ((T_ENDFOREACH) reduce 457) ((T_ENDIF) reduce 457) ((T_ENDSWITCH) reduce 457) ((T_ENDWHILE) reduce 457) ((T_ENUM) reduce 457) ((T_EVAL) reduce 457) ((T_EXIT) reduce 457) ((T_EXTENDS) reduce 457) ((T_FILE) reduce 457) ((T_FINAL) reduce 457) ((T_FINALLY) reduce 457) ((T_FN) reduce 457) ((T_FOR) reduce 457) ((T_FOREACH) reduce 457) ((T_FUNCTION) reduce 457) ((T_FUNC_C) reduce 457) ((T_GLOBAL) reduce 457) ((T_GOTO) reduce 457) ((T_IF) reduce 457) ((T_IMPLEMENTS) reduce 457) ((T_INCLUDE) reduce 457) ((T_INCLUDE_ONCE) reduce 457) ((T_INSTANCEOF) reduce 457) ((T_INSTEADOF) reduce 457) ((T_INTERFACE) reduce 457) ((T_ISSET) reduce 457) ((T_LINE) reduce 457) ((T_LIST) reduce 457) ((T_LOGICAL_AND) reduce 457) ((T_LOGICAL_OR) reduce 457) ((T_LOGICAL_XOR) reduce 457) ((T_MATCH) reduce 457) ((T_METHOD_C) reduce 457) ((T_NAMESPACE) reduce 457) ((T_NEW) reduce 457) ((T_NS_C) reduce 457) ((T_PRINT) reduce 457) ((T_PRIVATE) reduce 457) ((T_PROTECTED) reduce 457) ((T_PUBLIC) reduce 457) ((T_READONLY) reduce 457) ((T_REQUIRE) reduce 457) ((T_REQUIRE_ONCE) reduce 457) ((T_RETURN) reduce 457) ((T_STATIC) reduce 457) ((T_STRING) reduce 457) ((T_SWITCH) reduce 457) ((T_THROW) reduce 457) ((T_TRAIT) reduce 457) ((T_TRAIT_C) reduce 457) ((T_TRY) reduce 457) ((T_UNSET) reduce 457) ((T_USE) reduce 457) ((T_VAR) reduce 457) ((T_WHILE) reduce 457) ((T_YIELD) reduce 457)) 5780 (((T_ABSTRACT) reduce 79) ((T_ARRAY) reduce 79) ((T_AS) reduce 79) ((T_BREAK) reduce 79) ((T_CALLABLE) reduce 79) ((T_CASE) reduce 79) ((T_CATCH) reduce 79) ((T_CLASS) reduce 79) ((T_CLASS_C) reduce 79) ((T_CLONE) reduce 79) ((T_CONST) reduce 79) ((T_CONTINUE) reduce 79) ((T_DECLARE) reduce 79) ((T_DEFAULT) reduce 79) ((T_DIR) reduce 79) ((T_DO) reduce 79) ((T_ECHO) reduce 79) ((T_ELSE) reduce 79) ((T_ELSEIF) reduce 79) ((T_EMPTY) reduce 79) ((T_ENDDECLARE) reduce 79) ((T_ENDFOR) reduce 79) ((T_ENDFOREACH) reduce 79) ((T_ENDIF) reduce 79) ((T_ENDSWITCH) reduce 79) ((T_ENDWHILE) reduce 79) ((T_ENUM) reduce 79) ((T_EVAL) reduce 79) ((T_EXIT) reduce 79) ((T_EXTENDS) reduce 79) ((T_FILE) reduce 79) ((T_FINAL) reduce 79) ((T_FINALLY) reduce 79) ((T_FN) reduce 79) ((T_FOR) reduce 79) ((T_FOREACH) reduce 79) ((T_FUNCTION) reduce 79) ((T_FUNC_C) reduce 79) ((T_GLOBAL) reduce 79) ((T_GOTO) reduce 79) ((T_IF) reduce 79) ((T_IMPLEMENTS) reduce 79) ((T_INCLUDE) reduce 79) ((T_INCLUDE_ONCE) reduce 79) ((T_INSTANCEOF) reduce 79) ((T_INSTEADOF) reduce 79) ((T_INTERFACE) reduce 79) ((T_ISSET) reduce 79) ((T_LINE) reduce 79) ((T_LIST) reduce 79) ((T_LOGICAL_AND) reduce 79) ((T_LOGICAL_OR) reduce 79) ((T_LOGICAL_XOR) reduce 79) ((T_MATCH) reduce 79) ((T_METHOD_C) reduce 79) ((T_NAMESPACE) reduce 79) ((T_NEW) reduce 79) ((T_NS_C) reduce 79) ((T_PRINT) reduce 79) ((T_PRIVATE) reduce 79) ((T_PROTECTED) reduce 79) ((T_PUBLIC) reduce 79) ((T_READONLY) reduce 79) ((T_REQUIRE) reduce 79) ((T_REQUIRE_ONCE) reduce 79) ((T_RETURN) reduce 79) ((T_STATIC) reduce 79) ((T_STRING) reduce 79) ((T_SWITCH) reduce 79) ((T_THROW) reduce 79) ((T_TRAIT) reduce 79) ((T_TRAIT_C) reduce 79) ((T_TRY) reduce 79) ((T_UNSET) reduce 79) ((T_USE) reduce 79) ((T_VAR) reduce 79) ((T_WHILE) reduce 79) ((T_YIELD) reduce 79)) 5781 (((T_ABSTRACT) reduce 80) ((T_ARRAY) reduce 80) ((T_AS) reduce 80) ((T_BREAK) reduce 80) ((T_CALLABLE) reduce 80) ((T_CASE) reduce 80) ((T_CATCH) reduce 80) ((T_CLASS) reduce 80) ((T_CLASS_C) reduce 80) ((T_CLONE) reduce 80) ((T_CONST) reduce 80) ((T_CONTINUE) reduce 80) ((T_DECLARE) reduce 80) ((T_DEFAULT) reduce 80) ((T_DIR) reduce 80) ((T_DO) reduce 80) ((T_ECHO) reduce 80) ((T_ELSE) reduce 80) ((T_ELSEIF) reduce 80) ((T_EMPTY) reduce 80) ((T_ENDDECLARE) reduce 80) ((T_ENDFOR) reduce 80) ((T_ENDFOREACH) reduce 80) ((T_ENDIF) reduce 80) ((T_ENDSWITCH) reduce 80) ((T_ENDWHILE) reduce 80) ((T_ENUM) reduce 80) ((T_EVAL) reduce 80) ((T_EXIT) reduce 80) ((T_EXTENDS) reduce 80) ((T_FILE) reduce 80) ((T_FINAL) reduce 80) ((T_FINALLY) reduce 80) ((T_FN) reduce 80) ((T_FOR) reduce 80) ((T_FOREACH) reduce 80) ((T_FUNCTION) reduce 80) ((T_FUNC_C) reduce 80) ((T_GLOBAL) reduce 80) ((T_GOTO) reduce 80) ((T_IF) reduce 80) ((T_IMPLEMENTS) reduce 80) ((T_INCLUDE) reduce 80) ((T_INCLUDE_ONCE) reduce 80) ((T_INSTANCEOF) reduce 80) ((T_INSTEADOF) reduce 80) ((T_INTERFACE) reduce 80) ((T_ISSET) reduce 80) ((T_LINE) reduce 80) ((T_LIST) reduce 80) ((T_LOGICAL_AND) reduce 80) ((T_LOGICAL_OR) reduce 80) ((T_LOGICAL_XOR) reduce 80) ((T_MATCH) reduce 80) ((T_METHOD_C) reduce 80) ((T_NAMESPACE) reduce 80) ((T_NEW) reduce 80) ((T_NS_C) reduce 80) ((T_PRINT) reduce 80) ((T_PRIVATE) reduce 80) ((T_PROTECTED) reduce 80) ((T_PUBLIC) reduce 80) ((T_READONLY) reduce 80) ((T_REQUIRE) reduce 80) ((T_REQUIRE_ONCE) reduce 80) ((T_RETURN) reduce 80) ((T_STATIC) reduce 80) ((T_STRING) reduce 80) ((T_SWITCH) reduce 80) ((T_THROW) reduce 80) ((T_TRAIT) reduce 80) ((T_TRAIT_C) reduce 80) ((T_TRY) reduce 80) ((T_UNSET) reduce 80) ((T_USE) reduce 80) ((T_VAR) reduce 80) ((T_WHILE) reduce 80) ((T_YIELD) reduce 80)) 5782 (((T_ABSTRACT) reduce 458) ((T_ARRAY) reduce 458) ((T_AS) reduce 458) ((T_BREAK) reduce 458) ((T_CALLABLE) reduce 458) ((T_CASE) reduce 458) ((T_CATCH) reduce 458) ((T_CLASS) reduce 458) ((T_CLASS_C) reduce 458) ((T_CLONE) reduce 458) ((T_CONST) reduce 458) ((T_CONTINUE) reduce 458) ((T_DECLARE) reduce 458) ((T_DEFAULT) reduce 458) ((T_DIR) reduce 458) ((T_DO) reduce 458) ((T_ECHO) reduce 458) ((T_ELSE) reduce 458) ((T_ELSEIF) reduce 458) ((T_EMPTY) reduce 458) ((T_ENDDECLARE) reduce 458) ((T_ENDFOR) reduce 458) ((T_ENDFOREACH) reduce 458) ((T_ENDIF) reduce 458) ((T_ENDSWITCH) reduce 458) ((T_ENDWHILE) reduce 458) ((T_ENUM) reduce 458) ((T_EVAL) reduce 458) ((T_EXIT) reduce 458) ((T_EXTENDS) reduce 458) ((T_FILE) reduce 458) ((T_FINAL) reduce 458) ((T_FINALLY) reduce 458) ((T_FN) reduce 458) ((T_FOR) reduce 458) ((T_FOREACH) reduce 458) ((T_FUNCTION) reduce 458) ((T_FUNC_C) reduce 458) ((T_GLOBAL) reduce 458) ((T_GOTO) reduce 458) ((T_IF) reduce 458) ((T_IMPLEMENTS) reduce 458) ((T_INCLUDE) reduce 458) ((T_INCLUDE_ONCE) reduce 458) ((T_INSTANCEOF) reduce 458) ((T_INSTEADOF) reduce 458) ((T_INTERFACE) reduce 458) ((T_ISSET) reduce 458) ((T_LINE) reduce 458) ((T_LIST) reduce 458) ((T_LOGICAL_AND) reduce 458) ((T_LOGICAL_OR) reduce 458) ((T_LOGICAL_XOR) reduce 458) ((T_MATCH) reduce 458) ((T_METHOD_C) reduce 458) ((T_NAMESPACE) reduce 458) ((T_NEW) reduce 458) ((T_NS_C) reduce 458) ((T_PRINT) reduce 458) ((T_PRIVATE) reduce 458) ((T_PROTECTED) reduce 458) ((T_PUBLIC) reduce 458) ((T_READONLY) reduce 458) ((T_REQUIRE) reduce 458) ((T_REQUIRE_ONCE) reduce 458) ((T_RETURN) reduce 458) ((T_STATIC) reduce 458) ((T_STRING) reduce 458) ((T_SWITCH) reduce 458) ((T_THROW) reduce 458) ((T_TRAIT) reduce 458) ((T_TRAIT_C) reduce 458) ((T_TRY) reduce 458) ((T_UNSET) reduce 458) ((T_USE) reduce 458) ((T_VAR) reduce 458) ((T_WHILE) reduce 458) ((T_YIELD) reduce 458)) 5783 (((T_ABSTRACT) shift) ((T_ARRAY) shift) ((T_AS) shift) ((T_BREAK) shift) ((T_CALLABLE) shift) ((T_CASE) shift) ((T_CATCH) shift) ((T_CLASS) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONST) shift) ((T_CONTINUE) shift) ((T_DECLARE) shift) ((T_DEFAULT) shift) ((T_DIR) shift) ((T_DO) shift) ((T_ECHO) shift) ((T_ELSE) shift) ((T_ELSEIF) shift) ((T_EMPTY) shift) ((T_ENDDECLARE) shift) ((T_ENDFOR) shift) ((T_ENDFOREACH) shift) ((T_ENDIF) shift) ((T_ENDSWITCH) shift) ((T_ENDWHILE) shift) ((T_ENUM) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_EXTENDS) shift) ((T_FILE) shift) ((T_FINAL) shift) ((T_FINALLY) shift) ((T_FN) shift) ((T_FOR) shift) ((T_FOREACH) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_GLOBAL) shift) ((T_GOTO) shift) ((T_IF) shift) ((T_IMPLEMENTS) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INSTANCEOF) shift) ((T_INSTEADOF) shift) ((T_INTERFACE) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAMESPACE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_PRINT) shift) ((T_PRIVATE) shift) ((T_PROTECTED) shift) ((T_PUBLIC) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_RETURN) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_SWITCH) shift) ((T_THROW) shift) ((T_TRAIT) shift) ((T_TRAIT_C) shift) ((T_TRY) shift) ((T_UNSET) shift) ((T_USE) shift) ((T_VAR) shift) ((T_WHILE) shift) ((T_YIELD) shift)) 5784 ((("(") reduce 73)) 5785 ((("(") reduce 52)) 5786 ((("(") reduce 27)) 5787 ((("(") reduce 51)) 5788 ((("(") reduce 53)) 5789 ((("(") reduce 49)) 5790 ((("(") reduce 29)) 5791 ((("(") reduce 59)) 5792 ((("(") reduce 60)) 5793 ((("(") reduce 11)) 5794 ((("(") reduce 42)) 5795 ((("(") reduce 39)) 5796 ((("(") reduce 25)) 5797 ((("(") reduce 50)) 5798 ((("(") reduce 66)) 5799 ((("(") reduce 18)) 5800 ((("(") reduce 17)) 5801 ((("(") reduce 15)) 5802 ((("(") reduce 14)) 5803 ((("(") reduce 38)) 5804 ((("(") reduce 26)) 5805 ((("(") reduce 22)) 5806 ((("(") reduce 24)) 5807 ((("(") reduce 16)) 5808 ((("(") reduce 48)) 5809 ((("(") reduce 20)) 5810 ((("(") reduce 70)) 5811 ((("(") reduce 3)) 5812 ((("(") reduce 12)) 5813 ((("(") reduce 54)) 5814 ((("(") reduce 65)) 5815 ((("(") reduce 74)) 5816 ((("(") reduce 30)) 5817 ((("(") reduce 68)) 5818 ((("(") reduce 21)) 5819 ((("(") reduce 23)) 5820 ((("(") reduce 41)) 5821 ((("(") reduce 62)) 5822 ((("(") reduce 34)) 5823 ((("(") reduce 40)) 5824 ((("(") reduce 13)) 5825 ((("(") reduce 55)) 5826 ((("(") reduce 1)) 5827 ((("(") reduce 2)) 5828 ((("(") reduce 9)) 5829 ((("(") reduce 33)) 5830 ((("(") reduce 58)) 5831 ((("(") reduce 37)) 5832 ((("(") reduce 64)) 5833 ((("(") reduce 46)) 5834 ((("(") reduce 8)) 5835 ((("(") reduce 6)) 5836 ((("(") reduce 7)) 5837 ((("(") reduce 69)) 5838 ((("(") reduce 63)) 5839 ((("(") reduce 56)) 5840 ((("(") reduce 10)) 5841 ((("(") reduce 67)) 5842 ((("(") reduce 44)) 5843 ((("(") reduce 75)) 5844 ((("(") reduce 76)) 5845 ((("(") reduce 77)) 5846 ((("(") reduce 78)) 5847 ((("(") reduce 4)) 5848 ((("(") reduce 5)) 5849 ((("(") reduce 43)) 5850 ((("(") reduce 72)) 5851 ((("(") reduce 81)) 5852 ((("(") reduce 47)) 5853 ((("(") reduce 31)) 5854 ((("(") reduce 57)) 5855 ((("(") reduce 61)) 5856 ((("(") reduce 28)) 5857 ((("(") reduce 36)) 5858 ((("(") reduce 32)) 5859 ((("(") reduce 35)) 5860 ((("(") reduce 19)) 5861 ((("(") reduce 45)) 5863 ((("(") reduce 71)) 5864 ((("(") reduce 82)) 5868 (((":") shift) ((";") reduce 286) (("{") reduce 286)) 5870 (((";") reduce 455) (("{") reduce 455)) 5871 (((";") shift) (("{") shift)) 5872 (((T_ABSTRACT) reduce 330) ((T_ATTRIBUTE) reduce 330) ((T_CASE) reduce 330) ((T_CONST) reduce 330) ((T_FINAL) reduce 330) ((T_FUNCTION) reduce 330) ((T_PRIVATE) reduce 330) ((T_PROTECTED) reduce 330) ((T_PUBLIC) reduce 330) ((T_READONLY) reduce 330) ((T_STATIC) reduce 330) ((T_USE) reduce 330) ((T_VAR) reduce 330) (("}") reduce 330)) 5873 (((T_ABSTRACT) reduce 455) ((T_ATTRIBUTE) reduce 455) ((T_CASE) reduce 455) ((T_CONST) reduce 455) ((T_FINAL) reduce 455) ((T_FUNCTION) reduce 455) ((T_PRIVATE) reduce 455) ((T_PROTECTED) reduce 455) ((T_PUBLIC) reduce 455) ((T_READONLY) reduce 455) ((T_STATIC) reduce 455) ((T_USE) reduce 455) ((T_VAR) reduce 455) (("}") reduce 455)) 5876 (((T_ABSTRACT) reduce 331) ((T_ATTRIBUTE) reduce 331) ((T_CASE) reduce 331) ((T_CONST) reduce 331) ((T_FINAL) reduce 331) ((T_FUNCTION) reduce 331) ((T_PRIVATE) reduce 331) ((T_PROTECTED) reduce 331) ((T_PUBLIC) reduce 331) ((T_READONLY) reduce 331) ((T_STATIC) reduce 331) ((T_USE) reduce 331) ((T_VAR) reduce 331) (("}") reduce 331)) 5877 (((T_ABSTRACT) reduce 308) ((T_ATTRIBUTE) reduce 308) ((T_CASE) reduce 308) ((T_CONST) reduce 308) ((T_FINAL) reduce 308) ((T_FUNCTION) reduce 308) ((T_PRIVATE) reduce 308) ((T_PROTECTED) reduce 308) ((T_PUBLIC) reduce 308) ((T_READONLY) reduce 308) ((T_STATIC) reduce 308) ((T_USE) reduce 308) ((T_VAR) reduce 308) (("}") reduce 308)) 5879 (((";") reduce 277) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 277) (("{") reduce 277) (("|") reduce 277)) 5880 (((";") reduce 278) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 278) (("{") reduce 278) (("|") reduce 278)) 5881 (((";") reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) (("{") reduce 93) (("|") reduce 93)) 5882 (((";") reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) (("{") reduce 92) (("|") reduce 92)) 5883 (((";") reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) (("{") reduce 94) (("|") reduce 94)) 5884 (((";") reduce 266) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 266) (("{") reduce 266) (("|") reduce 266)) 5885 (((";") reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) (("{") reduce 91) (("|") reduce 91)) 5886 (((";") reduce 264) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) (("{") reduce 264)) 5887 (((";") reduce 279) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 279) (("{") reduce 279) (("|") reduce 279)) 5888 (((";") reduce 261) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) (("{") reduce 261) (("|") reduce 267)) 5889 (((";") reduce 287) (("{") reduce 287)) 5890 (((";") reduce 265) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 265) (("{") reduce 265) (("|") reduce 265)) 5891 (((";") reduce 263) (("{") reduce 263) (("|") shift)) 5895 (((";") reduce 277) (("{") reduce 277) (("|") reduce 277)) 5896 (((";") reduce 278) (("{") reduce 278) (("|") reduce 278)) 5897 (((";") reduce 93) (("{") reduce 93) (("|") reduce 93)) 5898 (((";") reduce 92) (("{") reduce 92) (("|") reduce 92)) 5899 (((";") reduce 94) (("{") reduce 94) (("|") reduce 94)) 5900 (((";") reduce 266) (("{") reduce 266) (("|") reduce 266)) 5901 (((";") reduce 91) (("{") reduce 91) (("|") reduce 91)) 5902 (((";") reduce 279) (("{") reduce 279) (("|") reduce 279)) 5903 (((";") reduce 267) (("{") reduce 267) (("|") reduce 267)) 5904 (((";") reduce 265) (("{") reduce 265) (("|") reduce 265)) 5905 (((";") reduce 269) (("{") reduce 269) (("|") reduce 269)) 5907 (((";") reduce 268) (("{") reduce 268) (("|") reduce 268)) 5909 (((";") reduce 270) (("{") reduce 270) (("|") reduce 270)) 5911 (((";") reduce 277) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 277) (("{") reduce 277)) 5912 (((";") reduce 278) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 278) (("{") reduce 278)) 5913 (((";") reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) (("{") reduce 93)) 5914 (((";") reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) (("{") reduce 92)) 5915 (((";") reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) (("{") reduce 94)) 5916 (((";") reduce 266) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 266) (("{") reduce 266)) 5917 (((";") reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) (("{") reduce 91)) 5918 (((";") reduce 279) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 279) (("{") reduce 279)) 5919 (((";") reduce 271) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 271) (("{") reduce 271)) 5920 (((";") reduce 265) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 265) (("{") reduce 265)) 5922 (((";") reduce 272) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 272) (("{") reduce 272)) 5923 (((";") reduce 277) (("{") reduce 277)) 5924 (((";") reduce 278) (("{") reduce 278)) 5925 (((";") reduce 93) (("{") reduce 93)) 5926 (((";") reduce 92) (("{") reduce 92)) 5927 (((";") reduce 94) (("{") reduce 94)) 5928 (((";") reduce 266) (("{") reduce 266)) 5929 (((";") reduce 91) (("{") reduce 91)) 5930 (((";") reduce 279) (("{") reduce 279)) 5931 (((";") reduce 262) (("{") reduce 262)) 5932 (((";") reduce 265) (("{") reduce 265)) 5933 ((("(") shift) (("?") shift) ((T_ABSTRACT) shift) ((T_ARRAY) shift) ((T_AS) shift) ((T_BREAK) shift) ((T_CALLABLE) shift) ((T_CASE) shift) ((T_CATCH) shift) ((T_CLASS) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONST) shift) ((T_CONTINUE) shift) ((T_DECLARE) shift) ((T_DEFAULT) shift) ((T_DIR) shift) ((T_DO) shift) ((T_ECHO) shift) ((T_ELSE) shift) ((T_ELSEIF) shift) ((T_EMPTY) shift) ((T_ENDDECLARE) shift) ((T_ENDFOR) shift) ((T_ENDFOREACH) shift) ((T_ENDIF) shift) ((T_ENDSWITCH) shift) ((T_ENDWHILE) shift) ((T_ENUM) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_EXTENDS) shift) ((T_FILE) shift) ((T_FINAL) shift) ((T_FINALLY) shift) ((T_FN) shift) ((T_FOR) shift) ((T_FOREACH) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_GLOBAL) shift) ((T_GOTO) shift) ((T_IF) shift) ((T_IMPLEMENTS) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INSTANCEOF) shift) ((T_INSTEADOF) shift) ((T_INTERFACE) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAMESPACE) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_PRINT) shift) ((T_PRIVATE) shift) ((T_PROTECTED) shift) ((T_PUBLIC) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_RETURN) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_SWITCH) shift) ((T_THROW) shift) ((T_TRAIT) shift) ((T_TRAIT_C) shift) ((T_TRY) shift) ((T_UNSET) shift) ((T_USE) shift) ((T_VAR) shift) ((T_WHILE) shift) ((T_YIELD) shift)) 5935 ((("=") reduce 73)) 5936 ((("=") reduce 52) ((T_ABSTRACT) reduce 277) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 277) ((T_ARRAY) reduce 277) ((T_AS) reduce 277) ((T_BREAK) reduce 277) ((T_CALLABLE) reduce 277) ((T_CASE) reduce 277) ((T_CATCH) reduce 277) ((T_CLASS) reduce 277) ((T_CLASS_C) reduce 277) ((T_CLONE) reduce 277) ((T_CONST) reduce 277) ((T_CONTINUE) reduce 277) ((T_DECLARE) reduce 277) ((T_DEFAULT) reduce 277) ((T_DIR) reduce 277) ((T_DO) reduce 277) ((T_ECHO) reduce 277) ((T_ELSE) reduce 277) ((T_ELSEIF) reduce 277) ((T_EMPTY) reduce 277) ((T_ENDDECLARE) reduce 277) ((T_ENDFOR) reduce 277) ((T_ENDFOREACH) reduce 277) ((T_ENDIF) reduce 277) ((T_ENDSWITCH) reduce 277) ((T_ENDWHILE) reduce 277) ((T_ENUM) reduce 277) ((T_EVAL) reduce 277) ((T_EXIT) reduce 277) ((T_EXTENDS) reduce 277) ((T_FILE) reduce 277) ((T_FINAL) reduce 277) ((T_FINALLY) reduce 277) ((T_FN) reduce 277) ((T_FOR) reduce 277) ((T_FOREACH) reduce 277) ((T_FUNCTION) reduce 277) ((T_FUNC_C) reduce 277) ((T_GLOBAL) reduce 277) ((T_GOTO) reduce 277) ((T_IF) reduce 277) ((T_IMPLEMENTS) reduce 277) ((T_INCLUDE) reduce 277) ((T_INCLUDE_ONCE) reduce 277) ((T_INSTANCEOF) reduce 277) ((T_INSTEADOF) reduce 277) ((T_INTERFACE) reduce 277) ((T_ISSET) reduce 277) ((T_LINE) reduce 277) ((T_LIST) reduce 277) ((T_LOGICAL_AND) reduce 277) ((T_LOGICAL_OR) reduce 277) ((T_LOGICAL_XOR) reduce 277) ((T_MATCH) reduce 277) ((T_METHOD_C) reduce 277) ((T_NAMESPACE) reduce 277) ((T_NEW) reduce 277) ((T_NS_C) reduce 277) ((T_PRINT) reduce 277) ((T_PRIVATE) reduce 277) ((T_PROTECTED) reduce 277) ((T_PUBLIC) reduce 277) ((T_READONLY) reduce 277) ((T_REQUIRE) reduce 277) ((T_REQUIRE_ONCE) reduce 277) ((T_RETURN) reduce 277) ((T_STATIC) reduce 277) ((T_STRING) reduce 277) ((T_SWITCH) reduce 277) ((T_THROW) reduce 277) ((T_TRAIT) reduce 277) ((T_TRAIT_C) reduce 277) ((T_TRY) reduce 277) ((T_UNSET) reduce 277) ((T_USE) reduce 277) ((T_VAR) reduce 277) ((T_WHILE) reduce 277) ((T_YIELD) reduce 277) (("|") reduce 277)) 5937 ((("=") reduce 27)) 5938 ((("=") reduce 51)) 5939 ((("=") reduce 53) ((T_ABSTRACT) reduce 278) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 278) ((T_ARRAY) reduce 278) ((T_AS) reduce 278) ((T_BREAK) reduce 278) ((T_CALLABLE) reduce 278) ((T_CASE) reduce 278) ((T_CATCH) reduce 278) ((T_CLASS) reduce 278) ((T_CLASS_C) reduce 278) ((T_CLONE) reduce 278) ((T_CONST) reduce 278) ((T_CONTINUE) reduce 278) ((T_DECLARE) reduce 278) ((T_DEFAULT) reduce 278) ((T_DIR) reduce 278) ((T_DO) reduce 278) ((T_ECHO) reduce 278) ((T_ELSE) reduce 278) ((T_ELSEIF) reduce 278) ((T_EMPTY) reduce 278) ((T_ENDDECLARE) reduce 278) ((T_ENDFOR) reduce 278) ((T_ENDFOREACH) reduce 278) ((T_ENDIF) reduce 278) ((T_ENDSWITCH) reduce 278) ((T_ENDWHILE) reduce 278) ((T_ENUM) reduce 278) ((T_EVAL) reduce 278) ((T_EXIT) reduce 278) ((T_EXTENDS) reduce 278) ((T_FILE) reduce 278) ((T_FINAL) reduce 278) ((T_FINALLY) reduce 278) ((T_FN) reduce 278) ((T_FOR) reduce 278) ((T_FOREACH) reduce 278) ((T_FUNCTION) reduce 278) ((T_FUNC_C) reduce 278) ((T_GLOBAL) reduce 278) ((T_GOTO) reduce 278) ((T_IF) reduce 278) ((T_IMPLEMENTS) reduce 278) ((T_INCLUDE) reduce 278) ((T_INCLUDE_ONCE) reduce 278) ((T_INSTANCEOF) reduce 278) ((T_INSTEADOF) reduce 278) ((T_INTERFACE) reduce 278) ((T_ISSET) reduce 278) ((T_LINE) reduce 278) ((T_LIST) reduce 278) ((T_LOGICAL_AND) reduce 278) ((T_LOGICAL_OR) reduce 278) ((T_LOGICAL_XOR) reduce 278) ((T_MATCH) reduce 278) ((T_METHOD_C) reduce 278) ((T_NAMESPACE) reduce 278) ((T_NEW) reduce 278) ((T_NS_C) reduce 278) ((T_PRINT) reduce 278) ((T_PRIVATE) reduce 278) ((T_PROTECTED) reduce 278) ((T_PUBLIC) reduce 278) ((T_READONLY) reduce 278) ((T_REQUIRE) reduce 278) ((T_REQUIRE_ONCE) reduce 278) ((T_RETURN) reduce 278) ((T_STATIC) reduce 278) ((T_STRING) reduce 278) ((T_SWITCH) reduce 278) ((T_THROW) reduce 278) ((T_TRAIT) reduce 278) ((T_TRAIT_C) reduce 278) ((T_TRY) reduce 278) ((T_UNSET) reduce 278) ((T_USE) reduce 278) ((T_VAR) reduce 278) ((T_WHILE) reduce 278) ((T_YIELD) reduce 278) (("|") reduce 278)) 5940 ((("=") reduce 49)) 5941 ((("=") reduce 29)) 5942 ((("=") reduce 59)) 5943 ((("=") reduce 60)) 5944 ((("=") reduce 11)) 5945 ((("=") reduce 42)) 5946 ((("=") reduce 39)) 5947 ((("=") reduce 25)) 5948 ((("=") reduce 50)) 5949 ((("=") reduce 66)) 5950 ((("=") reduce 18)) 5951 ((("=") reduce 17)) 5952 ((("=") reduce 15)) 5953 ((("=") reduce 14)) 5954 ((("=") reduce 38)) 5955 ((("=") reduce 26)) 5956 ((("=") reduce 22)) 5957 ((("=") reduce 24)) 5958 ((("=") reduce 16)) 5959 ((("=") reduce 48)) 5960 ((("=") reduce 20)) 5961 ((("=") reduce 70)) 5962 ((("=") reduce 3)) 5963 ((("=") reduce 12)) 5964 ((("=") reduce 54)) 5965 ((("=") reduce 65)) 5966 ((("=") reduce 74)) 5967 ((("=") reduce 30)) 5968 ((("=") reduce 68)) 5969 ((("=") reduce 21)) 5970 ((("=") reduce 23)) 5971 ((("=") reduce 41)) 5972 ((("=") reduce 62)) 5973 ((("=") reduce 34)) 5974 ((("=") reduce 40)) 5975 ((("=") reduce 13)) 5976 ((("=") reduce 55)) 5977 ((("=") reduce 1)) 5978 ((("=") reduce 2)) 5979 ((("=") reduce 9)) 5980 ((("=") reduce 33)) 5981 ((("=") reduce 58)) 5982 ((("=") reduce 37)) 5983 ((("=") reduce 64)) 5984 ((("=") reduce 46)) 5985 ((("=") reduce 8)) 5986 ((("=") reduce 6)) 5987 ((("=") reduce 7)) 5988 ((("=") reduce 69)) 5989 ((("=") reduce 63)) 5990 ((("=") reduce 56)) 5991 (((T_ABSTRACT) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_ARRAY) reduce 93) ((T_AS) reduce 93) ((T_BREAK) reduce 93) ((T_CALLABLE) reduce 93) ((T_CASE) reduce 93) ((T_CATCH) reduce 93) ((T_CLASS) reduce 93) ((T_CLASS_C) reduce 93) ((T_CLONE) reduce 93) ((T_CONST) reduce 93) ((T_CONTINUE) reduce 93) ((T_DECLARE) reduce 93) ((T_DEFAULT) reduce 93) ((T_DIR) reduce 93) ((T_DO) reduce 93) ((T_ECHO) reduce 93) ((T_ELSE) reduce 93) ((T_ELSEIF) reduce 93) ((T_EMPTY) reduce 93) ((T_ENDDECLARE) reduce 93) ((T_ENDFOR) reduce 93) ((T_ENDFOREACH) reduce 93) ((T_ENDIF) reduce 93) ((T_ENDSWITCH) reduce 93) ((T_ENDWHILE) reduce 93) ((T_ENUM) reduce 93) ((T_EVAL) reduce 93) ((T_EXIT) reduce 93) ((T_EXTENDS) reduce 93) ((T_FILE) reduce 93) ((T_FINAL) reduce 93) ((T_FINALLY) reduce 93) ((T_FN) reduce 93) ((T_FOR) reduce 93) ((T_FOREACH) reduce 93) ((T_FUNCTION) reduce 93) ((T_FUNC_C) reduce 93) ((T_GLOBAL) reduce 93) ((T_GOTO) reduce 93) ((T_IF) reduce 93) ((T_IMPLEMENTS) reduce 93) ((T_INCLUDE) reduce 93) ((T_INCLUDE_ONCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_INSTEADOF) reduce 93) ((T_INTERFACE) reduce 93) ((T_ISSET) reduce 93) ((T_LINE) reduce 93) ((T_LIST) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_MATCH) reduce 93) ((T_METHOD_C) reduce 93) ((T_NAMESPACE) reduce 93) ((T_NEW) reduce 93) ((T_NS_C) reduce 93) ((T_PRINT) reduce 93) ((T_PRIVATE) reduce 93) ((T_PROTECTED) reduce 93) ((T_PUBLIC) reduce 93) ((T_READONLY) reduce 93) ((T_REQUIRE) reduce 93) ((T_REQUIRE_ONCE) reduce 93) ((T_RETURN) reduce 93) ((T_STATIC) reduce 93) ((T_STRING) reduce 93) ((T_SWITCH) reduce 93) ((T_THROW) reduce 93) ((T_TRAIT) reduce 93) ((T_TRAIT_C) reduce 93) ((T_TRY) reduce 93) ((T_UNSET) reduce 93) ((T_USE) reduce 93) ((T_VAR) reduce 93) ((T_WHILE) reduce 93) ((T_YIELD) reduce 93) (("|") reduce 93)) 5992 (((T_ABSTRACT) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_ARRAY) reduce 92) ((T_AS) reduce 92) ((T_BREAK) reduce 92) ((T_CALLABLE) reduce 92) ((T_CASE) reduce 92) ((T_CATCH) reduce 92) ((T_CLASS) reduce 92) ((T_CLASS_C) reduce 92) ((T_CLONE) reduce 92) ((T_CONST) reduce 92) ((T_CONTINUE) reduce 92) ((T_DECLARE) reduce 92) ((T_DEFAULT) reduce 92) ((T_DIR) reduce 92) ((T_DO) reduce 92) ((T_ECHO) reduce 92) ((T_ELSE) reduce 92) ((T_ELSEIF) reduce 92) ((T_EMPTY) reduce 92) ((T_ENDDECLARE) reduce 92) ((T_ENDFOR) reduce 92) ((T_ENDFOREACH) reduce 92) ((T_ENDIF) reduce 92) ((T_ENDSWITCH) reduce 92) ((T_ENDWHILE) reduce 92) ((T_ENUM) reduce 92) ((T_EVAL) reduce 92) ((T_EXIT) reduce 92) ((T_EXTENDS) reduce 92) ((T_FILE) reduce 92) ((T_FINAL) reduce 92) ((T_FINALLY) reduce 92) ((T_FN) reduce 92) ((T_FOR) reduce 92) ((T_FOREACH) reduce 92) ((T_FUNCTION) reduce 92) ((T_FUNC_C) reduce 92) ((T_GLOBAL) reduce 92) ((T_GOTO) reduce 92) ((T_IF) reduce 92) ((T_IMPLEMENTS) reduce 92) ((T_INCLUDE) reduce 92) ((T_INCLUDE_ONCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_INSTEADOF) reduce 92) ((T_INTERFACE) reduce 92) ((T_ISSET) reduce 92) ((T_LINE) reduce 92) ((T_LIST) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_MATCH) reduce 92) ((T_METHOD_C) reduce 92) ((T_NAMESPACE) reduce 92) ((T_NEW) reduce 92) ((T_NS_C) reduce 92) ((T_PRINT) reduce 92) ((T_PRIVATE) reduce 92) ((T_PROTECTED) reduce 92) ((T_PUBLIC) reduce 92) ((T_READONLY) reduce 92) ((T_REQUIRE) reduce 92) ((T_REQUIRE_ONCE) reduce 92) ((T_RETURN) reduce 92) ((T_STATIC) reduce 92) ((T_STRING) reduce 92) ((T_SWITCH) reduce 92) ((T_THROW) reduce 92) ((T_TRAIT) reduce 92) ((T_TRAIT_C) reduce 92) ((T_TRY) reduce 92) ((T_UNSET) reduce 92) ((T_USE) reduce 92) ((T_VAR) reduce 92) ((T_WHILE) reduce 92) ((T_YIELD) reduce 92) (("|") reduce 92)) 5993 (((T_ABSTRACT) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_ARRAY) reduce 94) ((T_AS) reduce 94) ((T_BREAK) reduce 94) ((T_CALLABLE) reduce 94) ((T_CASE) reduce 94) ((T_CATCH) reduce 94) ((T_CLASS) reduce 94) ((T_CLASS_C) reduce 94) ((T_CLONE) reduce 94) ((T_CONST) reduce 94) ((T_CONTINUE) reduce 94) ((T_DECLARE) reduce 94) ((T_DEFAULT) reduce 94) ((T_DIR) reduce 94) ((T_DO) reduce 94) ((T_ECHO) reduce 94) ((T_ELSE) reduce 94) ((T_ELSEIF) reduce 94) ((T_EMPTY) reduce 94) ((T_ENDDECLARE) reduce 94) ((T_ENDFOR) reduce 94) ((T_ENDFOREACH) reduce 94) ((T_ENDIF) reduce 94) ((T_ENDSWITCH) reduce 94) ((T_ENDWHILE) reduce 94) ((T_ENUM) reduce 94) ((T_EVAL) reduce 94) ((T_EXIT) reduce 94) ((T_EXTENDS) reduce 94) ((T_FILE) reduce 94) ((T_FINAL) reduce 94) ((T_FINALLY) reduce 94) ((T_FN) reduce 94) ((T_FOR) reduce 94) ((T_FOREACH) reduce 94) ((T_FUNCTION) reduce 94) ((T_FUNC_C) reduce 94) ((T_GLOBAL) reduce 94) ((T_GOTO) reduce 94) ((T_IF) reduce 94) ((T_IMPLEMENTS) reduce 94) ((T_INCLUDE) reduce 94) ((T_INCLUDE_ONCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_INSTEADOF) reduce 94) ((T_INTERFACE) reduce 94) ((T_ISSET) reduce 94) ((T_LINE) reduce 94) ((T_LIST) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_MATCH) reduce 94) ((T_METHOD_C) reduce 94) ((T_NAMESPACE) reduce 94) ((T_NEW) reduce 94) ((T_NS_C) reduce 94) ((T_PRINT) reduce 94) ((T_PRIVATE) reduce 94) ((T_PROTECTED) reduce 94) ((T_PUBLIC) reduce 94) ((T_READONLY) reduce 94) ((T_REQUIRE) reduce 94) ((T_REQUIRE_ONCE) reduce 94) ((T_RETURN) reduce 94) ((T_STATIC) reduce 94) ((T_STRING) reduce 94) ((T_SWITCH) reduce 94) ((T_THROW) reduce 94) ((T_TRAIT) reduce 94) ((T_TRAIT_C) reduce 94) ((T_TRY) reduce 94) ((T_UNSET) reduce 94) ((T_USE) reduce 94) ((T_VAR) reduce 94) ((T_WHILE) reduce 94) ((T_YIELD) reduce 94) (("|") reduce 94)) 5994 ((("=") reduce 10)) 5995 ((("=") reduce 67)) 5996 ((("=") reduce 44)) 5997 ((("=") reduce 75)) 5998 ((("=") reduce 76)) 5999 ((("=") reduce 77)) 6000 ((("=") reduce 78)) 6001 ((("=") reduce 4)) 6002 ((("=") reduce 5)) 6003 ((("=") reduce 43)) 6004 ((("=") reduce 72) ((T_ABSTRACT) reduce 266) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 266) ((T_ARRAY) reduce 266) ((T_AS) reduce 266) ((T_BREAK) reduce 266) ((T_CALLABLE) reduce 266) ((T_CASE) reduce 266) ((T_CATCH) reduce 266) ((T_CLASS) reduce 266) ((T_CLASS_C) reduce 266) ((T_CLONE) reduce 266) ((T_CONST) reduce 266) ((T_CONTINUE) reduce 266) ((T_DECLARE) reduce 266) ((T_DEFAULT) reduce 266) ((T_DIR) reduce 266) ((T_DO) reduce 266) ((T_ECHO) reduce 266) ((T_ELSE) reduce 266) ((T_ELSEIF) reduce 266) ((T_EMPTY) reduce 266) ((T_ENDDECLARE) reduce 266) ((T_ENDFOR) reduce 266) ((T_ENDFOREACH) reduce 266) ((T_ENDIF) reduce 266) ((T_ENDSWITCH) reduce 266) ((T_ENDWHILE) reduce 266) ((T_ENUM) reduce 266) ((T_EVAL) reduce 266) ((T_EXIT) reduce 266) ((T_EXTENDS) reduce 266) ((T_FILE) reduce 266) ((T_FINAL) reduce 266) ((T_FINALLY) reduce 266) ((T_FN) reduce 266) ((T_FOR) reduce 266) ((T_FOREACH) reduce 266) ((T_FUNCTION) reduce 266) ((T_FUNC_C) reduce 266) ((T_GLOBAL) reduce 266) ((T_GOTO) reduce 266) ((T_IF) reduce 266) ((T_IMPLEMENTS) reduce 266) ((T_INCLUDE) reduce 266) ((T_INCLUDE_ONCE) reduce 266) ((T_INSTANCEOF) reduce 266) ((T_INSTEADOF) reduce 266) ((T_INTERFACE) reduce 266) ((T_ISSET) reduce 266) ((T_LINE) reduce 266) ((T_LIST) reduce 266) ((T_LOGICAL_AND) reduce 266) ((T_LOGICAL_OR) reduce 266) ((T_LOGICAL_XOR) reduce 266) ((T_MATCH) reduce 266) ((T_METHOD_C) reduce 266) ((T_NAMESPACE) reduce 266) ((T_NEW) reduce 266) ((T_NS_C) reduce 266) ((T_PRINT) reduce 266) ((T_PRIVATE) reduce 266) ((T_PROTECTED) reduce 266) ((T_PUBLIC) reduce 266) ((T_READONLY) reduce 266) ((T_REQUIRE) reduce 266) ((T_REQUIRE_ONCE) reduce 266) ((T_RETURN) reduce 266) ((T_STATIC) reduce 266) ((T_STRING) reduce 266) ((T_SWITCH) reduce 266) ((T_THROW) reduce 266) ((T_TRAIT) reduce 266) ((T_TRAIT_C) reduce 266) ((T_TRY) reduce 266) ((T_UNSET) reduce 266) ((T_USE) reduce 266) ((T_VAR) reduce 266) ((T_WHILE) reduce 266) ((T_YIELD) reduce 266) (("|") reduce 266)) 6005 ((("=") shift) ((T_ABSTRACT) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_ARRAY) reduce 91) ((T_AS) reduce 91) ((T_BREAK) reduce 91) ((T_CALLABLE) reduce 91) ((T_CASE) reduce 91) ((T_CATCH) reduce 91) ((T_CLASS) reduce 91) ((T_CLASS_C) reduce 91) ((T_CLONE) reduce 91) ((T_CONST) reduce 91) ((T_CONTINUE) reduce 91) ((T_DECLARE) reduce 91) ((T_DEFAULT) reduce 91) ((T_DIR) reduce 91) ((T_DO) reduce 91) ((T_ECHO) reduce 91) ((T_ELSE) reduce 91) ((T_ELSEIF) reduce 91) ((T_EMPTY) reduce 91) ((T_ENDDECLARE) reduce 91) ((T_ENDFOR) reduce 91) ((T_ENDFOREACH) reduce 91) ((T_ENDIF) reduce 91) ((T_ENDSWITCH) reduce 91) ((T_ENDWHILE) reduce 91) ((T_ENUM) reduce 91) ((T_EVAL) reduce 91) ((T_EXIT) reduce 91) ((T_EXTENDS) reduce 91) ((T_FILE) reduce 91) ((T_FINAL) reduce 91) ((T_FINALLY) reduce 91) ((T_FN) reduce 91) ((T_FOR) reduce 91) ((T_FOREACH) reduce 91) ((T_FUNCTION) reduce 91) ((T_FUNC_C) reduce 91) ((T_GLOBAL) reduce 91) ((T_GOTO) reduce 91) ((T_IF) reduce 91) ((T_IMPLEMENTS) reduce 91) ((T_INCLUDE) reduce 91) ((T_INCLUDE_ONCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_INSTEADOF) reduce 91) ((T_INTERFACE) reduce 91) ((T_ISSET) reduce 91) ((T_LINE) reduce 91) ((T_LIST) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_MATCH) reduce 91) ((T_METHOD_C) reduce 91) ((T_NAMESPACE) reduce 91) ((T_NEW) reduce 91) ((T_NS_C) reduce 91) ((T_PRINT) reduce 91) ((T_PRIVATE) reduce 91) ((T_PROTECTED) reduce 91) ((T_PUBLIC) reduce 91) ((T_READONLY) reduce 91) ((T_REQUIRE) reduce 91) ((T_REQUIRE_ONCE) reduce 91) ((T_RETURN) reduce 91) ((T_STATIC) reduce 91) ((T_STRING) reduce 91) ((T_SWITCH) reduce 91) ((T_THROW) reduce 91) ((T_TRAIT) reduce 91) ((T_TRAIT_C) reduce 91) ((T_TRY) reduce 91) ((T_UNSET) reduce 91) ((T_USE) reduce 91) ((T_VAR) reduce 91) ((T_WHILE) reduce 91) ((T_YIELD) reduce 91) (("|") reduce 91)) 6006 ((("=") reduce 47)) 6007 ((("=") reduce 31)) 6008 ((("=") reduce 57)) 6009 ((("=") reduce 61)) 6010 ((("=") reduce 28)) 6011 ((("=") reduce 36)) 6012 ((("=") reduce 32)) 6013 ((("=") reduce 35)) 6014 ((("=") reduce 19)) 6015 ((("=") reduce 45)) 6016 (((",") reduce 352) ((";") reduce 352)) 6018 (((T_ABSTRACT) reduce 264) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_ARRAY) reduce 264) ((T_AS) reduce 264) ((T_BREAK) reduce 264) ((T_CALLABLE) reduce 264) ((T_CASE) reduce 264) ((T_CATCH) reduce 264) ((T_CLASS) reduce 264) ((T_CLASS_C) reduce 264) ((T_CLONE) reduce 264) ((T_CONST) reduce 264) ((T_CONTINUE) reduce 264) ((T_DECLARE) reduce 264) ((T_DEFAULT) reduce 264) ((T_DIR) reduce 264) ((T_DO) reduce 264) ((T_ECHO) reduce 264) ((T_ELSE) reduce 264) ((T_ELSEIF) reduce 264) ((T_EMPTY) reduce 264) ((T_ENDDECLARE) reduce 264) ((T_ENDFOR) reduce 264) ((T_ENDFOREACH) reduce 264) ((T_ENDIF) reduce 264) ((T_ENDSWITCH) reduce 264) ((T_ENDWHILE) reduce 264) ((T_ENUM) reduce 264) ((T_EVAL) reduce 264) ((T_EXIT) reduce 264) ((T_EXTENDS) reduce 264) ((T_FILE) reduce 264) ((T_FINAL) reduce 264) ((T_FINALLY) reduce 264) ((T_FN) reduce 264) ((T_FOR) reduce 264) ((T_FOREACH) reduce 264) ((T_FUNCTION) reduce 264) ((T_FUNC_C) reduce 264) ((T_GLOBAL) reduce 264) ((T_GOTO) reduce 264) ((T_IF) reduce 264) ((T_IMPLEMENTS) reduce 264) ((T_INCLUDE) reduce 264) ((T_INCLUDE_ONCE) reduce 264) ((T_INSTANCEOF) reduce 264) ((T_INSTEADOF) reduce 264) ((T_INTERFACE) reduce 264) ((T_ISSET) reduce 264) ((T_LINE) reduce 264) ((T_LIST) reduce 264) ((T_LOGICAL_AND) reduce 264) ((T_LOGICAL_OR) reduce 264) ((T_LOGICAL_XOR) reduce 264) ((T_MATCH) reduce 264) ((T_METHOD_C) reduce 264) ((T_NAMESPACE) reduce 264) ((T_NEW) reduce 264) ((T_NS_C) reduce 264) ((T_PRINT) reduce 264) ((T_PRIVATE) reduce 264) ((T_PROTECTED) reduce 264) ((T_PUBLIC) reduce 264) ((T_READONLY) reduce 264) ((T_REQUIRE) reduce 264) ((T_REQUIRE_ONCE) reduce 264) ((T_RETURN) reduce 264) ((T_STATIC) reduce 264) ((T_STRING) reduce 264) ((T_SWITCH) reduce 264) ((T_THROW) reduce 264) ((T_TRAIT) reduce 264) ((T_TRAIT_C) reduce 264) ((T_TRY) reduce 264) ((T_UNSET) reduce 264) ((T_USE) reduce 264) ((T_VAR) reduce 264) ((T_WHILE) reduce 264) ((T_YIELD) reduce 264)) 6019 (((T_ABSTRACT) reduce 279) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 279) ((T_ARRAY) reduce 279) ((T_AS) reduce 279) ((T_BREAK) reduce 279) ((T_CALLABLE) reduce 279) ((T_CASE) reduce 279) ((T_CATCH) reduce 279) ((T_CLASS) reduce 279) ((T_CLASS_C) reduce 279) ((T_CLONE) reduce 279) ((T_CONST) reduce 279) ((T_CONTINUE) reduce 279) ((T_DECLARE) reduce 279) ((T_DEFAULT) reduce 279) ((T_DIR) reduce 279) ((T_DO) reduce 279) ((T_ECHO) reduce 279) ((T_ELSE) reduce 279) ((T_ELSEIF) reduce 279) ((T_EMPTY) reduce 279) ((T_ENDDECLARE) reduce 279) ((T_ENDFOR) reduce 279) ((T_ENDFOREACH) reduce 279) ((T_ENDIF) reduce 279) ((T_ENDSWITCH) reduce 279) ((T_ENDWHILE) reduce 279) ((T_ENUM) reduce 279) ((T_EVAL) reduce 279) ((T_EXIT) reduce 279) ((T_EXTENDS) reduce 279) ((T_FILE) reduce 279) ((T_FINAL) reduce 279) ((T_FINALLY) reduce 279) ((T_FN) reduce 279) ((T_FOR) reduce 279) ((T_FOREACH) reduce 279) ((T_FUNCTION) reduce 279) ((T_FUNC_C) reduce 279) ((T_GLOBAL) reduce 279) ((T_GOTO) reduce 279) ((T_IF) reduce 279) ((T_IMPLEMENTS) reduce 279) ((T_INCLUDE) reduce 279) ((T_INCLUDE_ONCE) reduce 279) ((T_INSTANCEOF) reduce 279) ((T_INSTEADOF) reduce 279) ((T_INTERFACE) reduce 279) ((T_ISSET) reduce 279) ((T_LINE) reduce 279) ((T_LIST) reduce 279) ((T_LOGICAL_AND) reduce 279) ((T_LOGICAL_OR) reduce 279) ((T_LOGICAL_XOR) reduce 279) ((T_MATCH) reduce 279) ((T_METHOD_C) reduce 279) ((T_NAMESPACE) reduce 279) ((T_NEW) reduce 279) ((T_NS_C) reduce 279) ((T_PRINT) reduce 279) ((T_PRIVATE) reduce 279) ((T_PROTECTED) reduce 279) ((T_PUBLIC) reduce 279) ((T_READONLY) reduce 279) ((T_REQUIRE) reduce 279) ((T_REQUIRE_ONCE) reduce 279) ((T_RETURN) reduce 279) ((T_STATIC) reduce 279) ((T_STRING) reduce 279) ((T_SWITCH) reduce 279) ((T_THROW) reduce 279) ((T_TRAIT) reduce 279) ((T_TRAIT_C) reduce 279) ((T_TRY) reduce 279) ((T_UNSET) reduce 279) ((T_USE) reduce 279) ((T_VAR) reduce 279) ((T_WHILE) reduce 279) ((T_YIELD) reduce 279) (("|") reduce 279)) 6020 ((("=") reduce 71)) 6022 (((T_ABSTRACT) reduce 261) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_ARRAY) reduce 261) ((T_AS) reduce 261) ((T_BREAK) reduce 261) ((T_CALLABLE) reduce 261) ((T_CASE) reduce 261) ((T_CATCH) reduce 261) ((T_CLASS) reduce 261) ((T_CLASS_C) reduce 261) ((T_CLONE) reduce 261) ((T_CONST) reduce 261) ((T_CONTINUE) reduce 261) ((T_DECLARE) reduce 261) ((T_DEFAULT) reduce 261) ((T_DIR) reduce 261) ((T_DO) reduce 261) ((T_ECHO) reduce 261) ((T_ELSE) reduce 261) ((T_ELSEIF) reduce 261) ((T_EMPTY) reduce 261) ((T_ENDDECLARE) reduce 261) ((T_ENDFOR) reduce 261) ((T_ENDFOREACH) reduce 261) ((T_ENDIF) reduce 261) ((T_ENDSWITCH) reduce 261) ((T_ENDWHILE) reduce 261) ((T_ENUM) reduce 261) ((T_EVAL) reduce 261) ((T_EXIT) reduce 261) ((T_EXTENDS) reduce 261) ((T_FILE) reduce 261) ((T_FINAL) reduce 261) ((T_FINALLY) reduce 261) ((T_FN) reduce 261) ((T_FOR) reduce 261) ((T_FOREACH) reduce 261) ((T_FUNCTION) reduce 261) ((T_FUNC_C) reduce 261) ((T_GLOBAL) reduce 261) ((T_GOTO) reduce 261) ((T_IF) reduce 261) ((T_IMPLEMENTS) reduce 261) ((T_INCLUDE) reduce 261) ((T_INCLUDE_ONCE) reduce 261) ((T_INSTANCEOF) reduce 261) ((T_INSTEADOF) reduce 261) ((T_INTERFACE) reduce 261) ((T_ISSET) reduce 261) ((T_LINE) reduce 261) ((T_LIST) reduce 261) ((T_LOGICAL_AND) reduce 261) ((T_LOGICAL_OR) reduce 261) ((T_LOGICAL_XOR) reduce 261) ((T_MATCH) reduce 261) ((T_METHOD_C) reduce 261) ((T_NAMESPACE) reduce 261) ((T_NEW) reduce 261) ((T_NS_C) reduce 261) ((T_PRINT) reduce 261) ((T_PRIVATE) reduce 261) ((T_PROTECTED) reduce 261) ((T_PUBLIC) reduce 261) ((T_READONLY) reduce 261) ((T_REQUIRE) reduce 261) ((T_REQUIRE_ONCE) reduce 261) ((T_RETURN) reduce 261) ((T_STATIC) reduce 261) ((T_STRING) reduce 261) ((T_SWITCH) reduce 261) ((T_THROW) reduce 261) ((T_TRAIT) reduce 261) ((T_TRAIT_C) reduce 261) ((T_TRY) reduce 261) ((T_UNSET) reduce 261) ((T_USE) reduce 261) ((T_VAR) reduce 261) ((T_WHILE) reduce 261) ((T_YIELD) reduce 261) (("|") reduce 267)) 6024 (((T_ABSTRACT) reduce 265) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 265) ((T_ARRAY) reduce 265) ((T_AS) reduce 265) ((T_BREAK) reduce 265) ((T_CALLABLE) reduce 265) ((T_CASE) reduce 265) ((T_CATCH) reduce 265) ((T_CLASS) reduce 265) ((T_CLASS_C) reduce 265) ((T_CLONE) reduce 265) ((T_CONST) reduce 265) ((T_CONTINUE) reduce 265) ((T_DECLARE) reduce 265) ((T_DEFAULT) reduce 265) ((T_DIR) reduce 265) ((T_DO) reduce 265) ((T_ECHO) reduce 265) ((T_ELSE) reduce 265) ((T_ELSEIF) reduce 265) ((T_EMPTY) reduce 265) ((T_ENDDECLARE) reduce 265) ((T_ENDFOR) reduce 265) ((T_ENDFOREACH) reduce 265) ((T_ENDIF) reduce 265) ((T_ENDSWITCH) reduce 265) ((T_ENDWHILE) reduce 265) ((T_ENUM) reduce 265) ((T_EVAL) reduce 265) ((T_EXIT) reduce 265) ((T_EXTENDS) reduce 265) ((T_FILE) reduce 265) ((T_FINAL) reduce 265) ((T_FINALLY) reduce 265) ((T_FN) reduce 265) ((T_FOR) reduce 265) ((T_FOREACH) reduce 265) ((T_FUNCTION) reduce 265) ((T_FUNC_C) reduce 265) ((T_GLOBAL) reduce 265) ((T_GOTO) reduce 265) ((T_IF) reduce 265) ((T_IMPLEMENTS) reduce 265) ((T_INCLUDE) reduce 265) ((T_INCLUDE_ONCE) reduce 265) ((T_INSTANCEOF) reduce 265) ((T_INSTEADOF) reduce 265) ((T_INTERFACE) reduce 265) ((T_ISSET) reduce 265) ((T_LINE) reduce 265) ((T_LIST) reduce 265) ((T_LOGICAL_AND) reduce 265) ((T_LOGICAL_OR) reduce 265) ((T_LOGICAL_XOR) reduce 265) ((T_MATCH) reduce 265) ((T_METHOD_C) reduce 265) ((T_NAMESPACE) reduce 265) ((T_NEW) reduce 265) ((T_NS_C) reduce 265) ((T_PRINT) reduce 265) ((T_PRIVATE) reduce 265) ((T_PROTECTED) reduce 265) ((T_PUBLIC) reduce 265) ((T_READONLY) reduce 265) ((T_REQUIRE) reduce 265) ((T_REQUIRE_ONCE) reduce 265) ((T_RETURN) reduce 265) ((T_STATIC) reduce 265) ((T_STRING) reduce 265) ((T_SWITCH) reduce 265) ((T_THROW) reduce 265) ((T_TRAIT) reduce 265) ((T_TRAIT_C) reduce 265) ((T_TRY) reduce 265) ((T_UNSET) reduce 265) ((T_USE) reduce 265) ((T_VAR) reduce 265) ((T_WHILE) reduce 265) ((T_YIELD) reduce 265) (("|") reduce 265)) 6025 (((T_ABSTRACT) reduce 263) ((T_ARRAY) reduce 263) ((T_AS) reduce 263) ((T_BREAK) reduce 263) ((T_CALLABLE) reduce 263) ((T_CASE) reduce 263) ((T_CATCH) reduce 263) ((T_CLASS) reduce 263) ((T_CLASS_C) reduce 263) ((T_CLONE) reduce 263) ((T_CONST) reduce 263) ((T_CONTINUE) reduce 263) ((T_DECLARE) reduce 263) ((T_DEFAULT) reduce 263) ((T_DIR) reduce 263) ((T_DO) reduce 263) ((T_ECHO) reduce 263) ((T_ELSE) reduce 263) ((T_ELSEIF) reduce 263) ((T_EMPTY) reduce 263) ((T_ENDDECLARE) reduce 263) ((T_ENDFOR) reduce 263) ((T_ENDFOREACH) reduce 263) ((T_ENDIF) reduce 263) ((T_ENDSWITCH) reduce 263) ((T_ENDWHILE) reduce 263) ((T_ENUM) reduce 263) ((T_EVAL) reduce 263) ((T_EXIT) reduce 263) ((T_EXTENDS) reduce 263) ((T_FILE) reduce 263) ((T_FINAL) reduce 263) ((T_FINALLY) reduce 263) ((T_FN) reduce 263) ((T_FOR) reduce 263) ((T_FOREACH) reduce 263) ((T_FUNCTION) reduce 263) ((T_FUNC_C) reduce 263) ((T_GLOBAL) reduce 263) ((T_GOTO) reduce 263) ((T_IF) reduce 263) ((T_IMPLEMENTS) reduce 263) ((T_INCLUDE) reduce 263) ((T_INCLUDE_ONCE) reduce 263) ((T_INSTANCEOF) reduce 263) ((T_INSTEADOF) reduce 263) ((T_INTERFACE) reduce 263) ((T_ISSET) reduce 263) ((T_LINE) reduce 263) ((T_LIST) reduce 263) ((T_LOGICAL_AND) reduce 263) ((T_LOGICAL_OR) reduce 263) ((T_LOGICAL_XOR) reduce 263) ((T_MATCH) reduce 263) ((T_METHOD_C) reduce 263) ((T_NAMESPACE) reduce 263) ((T_NEW) reduce 263) ((T_NS_C) reduce 263) ((T_PRINT) reduce 263) ((T_PRIVATE) reduce 263) ((T_PROTECTED) reduce 263) ((T_PUBLIC) reduce 263) ((T_READONLY) reduce 263) ((T_REQUIRE) reduce 263) ((T_REQUIRE_ONCE) reduce 263) ((T_RETURN) reduce 263) ((T_STATIC) reduce 263) ((T_STRING) reduce 263) ((T_SWITCH) reduce 263) ((T_THROW) reduce 263) ((T_TRAIT) reduce 263) ((T_TRAIT_C) reduce 263) ((T_TRY) reduce 263) ((T_UNSET) reduce 263) ((T_USE) reduce 263) ((T_VAR) reduce 263) ((T_WHILE) reduce 263) ((T_YIELD) reduce 263) (("|") shift)) 6029 (((T_ABSTRACT) reduce 277) ((T_ARRAY) reduce 277) ((T_AS) reduce 277) ((T_BREAK) reduce 277) ((T_CALLABLE) reduce 277) ((T_CASE) reduce 277) ((T_CATCH) reduce 277) ((T_CLASS) reduce 277) ((T_CLASS_C) reduce 277) ((T_CLONE) reduce 277) ((T_CONST) reduce 277) ((T_CONTINUE) reduce 277) ((T_DECLARE) reduce 277) ((T_DEFAULT) reduce 277) ((T_DIR) reduce 277) ((T_DO) reduce 277) ((T_ECHO) reduce 277) ((T_ELSE) reduce 277) ((T_ELSEIF) reduce 277) ((T_EMPTY) reduce 277) ((T_ENDDECLARE) reduce 277) ((T_ENDFOR) reduce 277) ((T_ENDFOREACH) reduce 277) ((T_ENDIF) reduce 277) ((T_ENDSWITCH) reduce 277) ((T_ENDWHILE) reduce 277) ((T_ENUM) reduce 277) ((T_EVAL) reduce 277) ((T_EXIT) reduce 277) ((T_EXTENDS) reduce 277) ((T_FILE) reduce 277) ((T_FINAL) reduce 277) ((T_FINALLY) reduce 277) ((T_FN) reduce 277) ((T_FOR) reduce 277) ((T_FOREACH) reduce 277) ((T_FUNCTION) reduce 277) ((T_FUNC_C) reduce 277) ((T_GLOBAL) reduce 277) ((T_GOTO) reduce 277) ((T_IF) reduce 277) ((T_IMPLEMENTS) reduce 277) ((T_INCLUDE) reduce 277) ((T_INCLUDE_ONCE) reduce 277) ((T_INSTANCEOF) reduce 277) ((T_INSTEADOF) reduce 277) ((T_INTERFACE) reduce 277) ((T_ISSET) reduce 277) ((T_LINE) reduce 277) ((T_LIST) reduce 277) ((T_LOGICAL_AND) reduce 277) ((T_LOGICAL_OR) reduce 277) ((T_LOGICAL_XOR) reduce 277) ((T_MATCH) reduce 277) ((T_METHOD_C) reduce 277) ((T_NAMESPACE) reduce 277) ((T_NEW) reduce 277) ((T_NS_C) reduce 277) ((T_PRINT) reduce 277) ((T_PRIVATE) reduce 277) ((T_PROTECTED) reduce 277) ((T_PUBLIC) reduce 277) ((T_READONLY) reduce 277) ((T_REQUIRE) reduce 277) ((T_REQUIRE_ONCE) reduce 277) ((T_RETURN) reduce 277) ((T_STATIC) reduce 277) ((T_STRING) reduce 277) ((T_SWITCH) reduce 277) ((T_THROW) reduce 277) ((T_TRAIT) reduce 277) ((T_TRAIT_C) reduce 277) ((T_TRY) reduce 277) ((T_UNSET) reduce 277) ((T_USE) reduce 277) ((T_VAR) reduce 277) ((T_WHILE) reduce 277) ((T_YIELD) reduce 277) (("|") reduce 277)) 6030 (((T_ABSTRACT) reduce 278) ((T_ARRAY) reduce 278) ((T_AS) reduce 278) ((T_BREAK) reduce 278) ((T_CALLABLE) reduce 278) ((T_CASE) reduce 278) ((T_CATCH) reduce 278) ((T_CLASS) reduce 278) ((T_CLASS_C) reduce 278) ((T_CLONE) reduce 278) ((T_CONST) reduce 278) ((T_CONTINUE) reduce 278) ((T_DECLARE) reduce 278) ((T_DEFAULT) reduce 278) ((T_DIR) reduce 278) ((T_DO) reduce 278) ((T_ECHO) reduce 278) ((T_ELSE) reduce 278) ((T_ELSEIF) reduce 278) ((T_EMPTY) reduce 278) ((T_ENDDECLARE) reduce 278) ((T_ENDFOR) reduce 278) ((T_ENDFOREACH) reduce 278) ((T_ENDIF) reduce 278) ((T_ENDSWITCH) reduce 278) ((T_ENDWHILE) reduce 278) ((T_ENUM) reduce 278) ((T_EVAL) reduce 278) ((T_EXIT) reduce 278) ((T_EXTENDS) reduce 278) ((T_FILE) reduce 278) ((T_FINAL) reduce 278) ((T_FINALLY) reduce 278) ((T_FN) reduce 278) ((T_FOR) reduce 278) ((T_FOREACH) reduce 278) ((T_FUNCTION) reduce 278) ((T_FUNC_C) reduce 278) ((T_GLOBAL) reduce 278) ((T_GOTO) reduce 278) ((T_IF) reduce 278) ((T_IMPLEMENTS) reduce 278) ((T_INCLUDE) reduce 278) ((T_INCLUDE_ONCE) reduce 278) ((T_INSTANCEOF) reduce 278) ((T_INSTEADOF) reduce 278) ((T_INTERFACE) reduce 278) ((T_ISSET) reduce 278) ((T_LINE) reduce 278) ((T_LIST) reduce 278) ((T_LOGICAL_AND) reduce 278) ((T_LOGICAL_OR) reduce 278) ((T_LOGICAL_XOR) reduce 278) ((T_MATCH) reduce 278) ((T_METHOD_C) reduce 278) ((T_NAMESPACE) reduce 278) ((T_NEW) reduce 278) ((T_NS_C) reduce 278) ((T_PRINT) reduce 278) ((T_PRIVATE) reduce 278) ((T_PROTECTED) reduce 278) ((T_PUBLIC) reduce 278) ((T_READONLY) reduce 278) ((T_REQUIRE) reduce 278) ((T_REQUIRE_ONCE) reduce 278) ((T_RETURN) reduce 278) ((T_STATIC) reduce 278) ((T_STRING) reduce 278) ((T_SWITCH) reduce 278) ((T_THROW) reduce 278) ((T_TRAIT) reduce 278) ((T_TRAIT_C) reduce 278) ((T_TRY) reduce 278) ((T_UNSET) reduce 278) ((T_USE) reduce 278) ((T_VAR) reduce 278) ((T_WHILE) reduce 278) ((T_YIELD) reduce 278) (("|") reduce 278)) 6031 (((T_ABSTRACT) reduce 93) ((T_ARRAY) reduce 93) ((T_AS) reduce 93) ((T_BREAK) reduce 93) ((T_CALLABLE) reduce 93) ((T_CASE) reduce 93) ((T_CATCH) reduce 93) ((T_CLASS) reduce 93) ((T_CLASS_C) reduce 93) ((T_CLONE) reduce 93) ((T_CONST) reduce 93) ((T_CONTINUE) reduce 93) ((T_DECLARE) reduce 93) ((T_DEFAULT) reduce 93) ((T_DIR) reduce 93) ((T_DO) reduce 93) ((T_ECHO) reduce 93) ((T_ELSE) reduce 93) ((T_ELSEIF) reduce 93) ((T_EMPTY) reduce 93) ((T_ENDDECLARE) reduce 93) ((T_ENDFOR) reduce 93) ((T_ENDFOREACH) reduce 93) ((T_ENDIF) reduce 93) ((T_ENDSWITCH) reduce 93) ((T_ENDWHILE) reduce 93) ((T_ENUM) reduce 93) ((T_EVAL) reduce 93) ((T_EXIT) reduce 93) ((T_EXTENDS) reduce 93) ((T_FILE) reduce 93) ((T_FINAL) reduce 93) ((T_FINALLY) reduce 93) ((T_FN) reduce 93) ((T_FOR) reduce 93) ((T_FOREACH) reduce 93) ((T_FUNCTION) reduce 93) ((T_FUNC_C) reduce 93) ((T_GLOBAL) reduce 93) ((T_GOTO) reduce 93) ((T_IF) reduce 93) ((T_IMPLEMENTS) reduce 93) ((T_INCLUDE) reduce 93) ((T_INCLUDE_ONCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_INSTEADOF) reduce 93) ((T_INTERFACE) reduce 93) ((T_ISSET) reduce 93) ((T_LINE) reduce 93) ((T_LIST) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_MATCH) reduce 93) ((T_METHOD_C) reduce 93) ((T_NAMESPACE) reduce 93) ((T_NEW) reduce 93) ((T_NS_C) reduce 93) ((T_PRINT) reduce 93) ((T_PRIVATE) reduce 93) ((T_PROTECTED) reduce 93) ((T_PUBLIC) reduce 93) ((T_READONLY) reduce 93) ((T_REQUIRE) reduce 93) ((T_REQUIRE_ONCE) reduce 93) ((T_RETURN) reduce 93) ((T_STATIC) reduce 93) ((T_STRING) reduce 93) ((T_SWITCH) reduce 93) ((T_THROW) reduce 93) ((T_TRAIT) reduce 93) ((T_TRAIT_C) reduce 93) ((T_TRY) reduce 93) ((T_UNSET) reduce 93) ((T_USE) reduce 93) ((T_VAR) reduce 93) ((T_WHILE) reduce 93) ((T_YIELD) reduce 93) (("|") reduce 93)) 6032 (((T_ABSTRACT) reduce 92) ((T_ARRAY) reduce 92) ((T_AS) reduce 92) ((T_BREAK) reduce 92) ((T_CALLABLE) reduce 92) ((T_CASE) reduce 92) ((T_CATCH) reduce 92) ((T_CLASS) reduce 92) ((T_CLASS_C) reduce 92) ((T_CLONE) reduce 92) ((T_CONST) reduce 92) ((T_CONTINUE) reduce 92) ((T_DECLARE) reduce 92) ((T_DEFAULT) reduce 92) ((T_DIR) reduce 92) ((T_DO) reduce 92) ((T_ECHO) reduce 92) ((T_ELSE) reduce 92) ((T_ELSEIF) reduce 92) ((T_EMPTY) reduce 92) ((T_ENDDECLARE) reduce 92) ((T_ENDFOR) reduce 92) ((T_ENDFOREACH) reduce 92) ((T_ENDIF) reduce 92) ((T_ENDSWITCH) reduce 92) ((T_ENDWHILE) reduce 92) ((T_ENUM) reduce 92) ((T_EVAL) reduce 92) ((T_EXIT) reduce 92) ((T_EXTENDS) reduce 92) ((T_FILE) reduce 92) ((T_FINAL) reduce 92) ((T_FINALLY) reduce 92) ((T_FN) reduce 92) ((T_FOR) reduce 92) ((T_FOREACH) reduce 92) ((T_FUNCTION) reduce 92) ((T_FUNC_C) reduce 92) ((T_GLOBAL) reduce 92) ((T_GOTO) reduce 92) ((T_IF) reduce 92) ((T_IMPLEMENTS) reduce 92) ((T_INCLUDE) reduce 92) ((T_INCLUDE_ONCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_INSTEADOF) reduce 92) ((T_INTERFACE) reduce 92) ((T_ISSET) reduce 92) ((T_LINE) reduce 92) ((T_LIST) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_MATCH) reduce 92) ((T_METHOD_C) reduce 92) ((T_NAMESPACE) reduce 92) ((T_NEW) reduce 92) ((T_NS_C) reduce 92) ((T_PRINT) reduce 92) ((T_PRIVATE) reduce 92) ((T_PROTECTED) reduce 92) ((T_PUBLIC) reduce 92) ((T_READONLY) reduce 92) ((T_REQUIRE) reduce 92) ((T_REQUIRE_ONCE) reduce 92) ((T_RETURN) reduce 92) ((T_STATIC) reduce 92) ((T_STRING) reduce 92) ((T_SWITCH) reduce 92) ((T_THROW) reduce 92) ((T_TRAIT) reduce 92) ((T_TRAIT_C) reduce 92) ((T_TRY) reduce 92) ((T_UNSET) reduce 92) ((T_USE) reduce 92) ((T_VAR) reduce 92) ((T_WHILE) reduce 92) ((T_YIELD) reduce 92) (("|") reduce 92)) 6033 (((T_ABSTRACT) reduce 94) ((T_ARRAY) reduce 94) ((T_AS) reduce 94) ((T_BREAK) reduce 94) ((T_CALLABLE) reduce 94) ((T_CASE) reduce 94) ((T_CATCH) reduce 94) ((T_CLASS) reduce 94) ((T_CLASS_C) reduce 94) ((T_CLONE) reduce 94) ((T_CONST) reduce 94) ((T_CONTINUE) reduce 94) ((T_DECLARE) reduce 94) ((T_DEFAULT) reduce 94) ((T_DIR) reduce 94) ((T_DO) reduce 94) ((T_ECHO) reduce 94) ((T_ELSE) reduce 94) ((T_ELSEIF) reduce 94) ((T_EMPTY) reduce 94) ((T_ENDDECLARE) reduce 94) ((T_ENDFOR) reduce 94) ((T_ENDFOREACH) reduce 94) ((T_ENDIF) reduce 94) ((T_ENDSWITCH) reduce 94) ((T_ENDWHILE) reduce 94) ((T_ENUM) reduce 94) ((T_EVAL) reduce 94) ((T_EXIT) reduce 94) ((T_EXTENDS) reduce 94) ((T_FILE) reduce 94) ((T_FINAL) reduce 94) ((T_FINALLY) reduce 94) ((T_FN) reduce 94) ((T_FOR) reduce 94) ((T_FOREACH) reduce 94) ((T_FUNCTION) reduce 94) ((T_FUNC_C) reduce 94) ((T_GLOBAL) reduce 94) ((T_GOTO) reduce 94) ((T_IF) reduce 94) ((T_IMPLEMENTS) reduce 94) ((T_INCLUDE) reduce 94) ((T_INCLUDE_ONCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_INSTEADOF) reduce 94) ((T_INTERFACE) reduce 94) ((T_ISSET) reduce 94) ((T_LINE) reduce 94) ((T_LIST) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_MATCH) reduce 94) ((T_METHOD_C) reduce 94) ((T_NAMESPACE) reduce 94) ((T_NEW) reduce 94) ((T_NS_C) reduce 94) ((T_PRINT) reduce 94) ((T_PRIVATE) reduce 94) ((T_PROTECTED) reduce 94) ((T_PUBLIC) reduce 94) ((T_READONLY) reduce 94) ((T_REQUIRE) reduce 94) ((T_REQUIRE_ONCE) reduce 94) ((T_RETURN) reduce 94) ((T_STATIC) reduce 94) ((T_STRING) reduce 94) ((T_SWITCH) reduce 94) ((T_THROW) reduce 94) ((T_TRAIT) reduce 94) ((T_TRAIT_C) reduce 94) ((T_TRY) reduce 94) ((T_UNSET) reduce 94) ((T_USE) reduce 94) ((T_VAR) reduce 94) ((T_WHILE) reduce 94) ((T_YIELD) reduce 94) (("|") reduce 94)) 6034 (((T_ABSTRACT) reduce 266) ((T_ARRAY) reduce 266) ((T_AS) reduce 266) ((T_BREAK) reduce 266) ((T_CALLABLE) reduce 266) ((T_CASE) reduce 266) ((T_CATCH) reduce 266) ((T_CLASS) reduce 266) ((T_CLASS_C) reduce 266) ((T_CLONE) reduce 266) ((T_CONST) reduce 266) ((T_CONTINUE) reduce 266) ((T_DECLARE) reduce 266) ((T_DEFAULT) reduce 266) ((T_DIR) reduce 266) ((T_DO) reduce 266) ((T_ECHO) reduce 266) ((T_ELSE) reduce 266) ((T_ELSEIF) reduce 266) ((T_EMPTY) reduce 266) ((T_ENDDECLARE) reduce 266) ((T_ENDFOR) reduce 266) ((T_ENDFOREACH) reduce 266) ((T_ENDIF) reduce 266) ((T_ENDSWITCH) reduce 266) ((T_ENDWHILE) reduce 266) ((T_ENUM) reduce 266) ((T_EVAL) reduce 266) ((T_EXIT) reduce 266) ((T_EXTENDS) reduce 266) ((T_FILE) reduce 266) ((T_FINAL) reduce 266) ((T_FINALLY) reduce 266) ((T_FN) reduce 266) ((T_FOR) reduce 266) ((T_FOREACH) reduce 266) ((T_FUNCTION) reduce 266) ((T_FUNC_C) reduce 266) ((T_GLOBAL) reduce 266) ((T_GOTO) reduce 266) ((T_IF) reduce 266) ((T_IMPLEMENTS) reduce 266) ((T_INCLUDE) reduce 266) ((T_INCLUDE_ONCE) reduce 266) ((T_INSTANCEOF) reduce 266) ((T_INSTEADOF) reduce 266) ((T_INTERFACE) reduce 266) ((T_ISSET) reduce 266) ((T_LINE) reduce 266) ((T_LIST) reduce 266) ((T_LOGICAL_AND) reduce 266) ((T_LOGICAL_OR) reduce 266) ((T_LOGICAL_XOR) reduce 266) ((T_MATCH) reduce 266) ((T_METHOD_C) reduce 266) ((T_NAMESPACE) reduce 266) ((T_NEW) reduce 266) ((T_NS_C) reduce 266) ((T_PRINT) reduce 266) ((T_PRIVATE) reduce 266) ((T_PROTECTED) reduce 266) ((T_PUBLIC) reduce 266) ((T_READONLY) reduce 266) ((T_REQUIRE) reduce 266) ((T_REQUIRE_ONCE) reduce 266) ((T_RETURN) reduce 266) ((T_STATIC) reduce 266) ((T_STRING) reduce 266) ((T_SWITCH) reduce 266) ((T_THROW) reduce 266) ((T_TRAIT) reduce 266) ((T_TRAIT_C) reduce 266) ((T_TRY) reduce 266) ((T_UNSET) reduce 266) ((T_USE) reduce 266) ((T_VAR) reduce 266) ((T_WHILE) reduce 266) ((T_YIELD) reduce 266) (("|") reduce 266)) 6035 (((T_ABSTRACT) reduce 91) ((T_ARRAY) reduce 91) ((T_AS) reduce 91) ((T_BREAK) reduce 91) ((T_CALLABLE) reduce 91) ((T_CASE) reduce 91) ((T_CATCH) reduce 91) ((T_CLASS) reduce 91) ((T_CLASS_C) reduce 91) ((T_CLONE) reduce 91) ((T_CONST) reduce 91) ((T_CONTINUE) reduce 91) ((T_DECLARE) reduce 91) ((T_DEFAULT) reduce 91) ((T_DIR) reduce 91) ((T_DO) reduce 91) ((T_ECHO) reduce 91) ((T_ELSE) reduce 91) ((T_ELSEIF) reduce 91) ((T_EMPTY) reduce 91) ((T_ENDDECLARE) reduce 91) ((T_ENDFOR) reduce 91) ((T_ENDFOREACH) reduce 91) ((T_ENDIF) reduce 91) ((T_ENDSWITCH) reduce 91) ((T_ENDWHILE) reduce 91) ((T_ENUM) reduce 91) ((T_EVAL) reduce 91) ((T_EXIT) reduce 91) ((T_EXTENDS) reduce 91) ((T_FILE) reduce 91) ((T_FINAL) reduce 91) ((T_FINALLY) reduce 91) ((T_FN) reduce 91) ((T_FOR) reduce 91) ((T_FOREACH) reduce 91) ((T_FUNCTION) reduce 91) ((T_FUNC_C) reduce 91) ((T_GLOBAL) reduce 91) ((T_GOTO) reduce 91) ((T_IF) reduce 91) ((T_IMPLEMENTS) reduce 91) ((T_INCLUDE) reduce 91) ((T_INCLUDE_ONCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_INSTEADOF) reduce 91) ((T_INTERFACE) reduce 91) ((T_ISSET) reduce 91) ((T_LINE) reduce 91) ((T_LIST) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_MATCH) reduce 91) ((T_METHOD_C) reduce 91) ((T_NAMESPACE) reduce 91) ((T_NEW) reduce 91) ((T_NS_C) reduce 91) ((T_PRINT) reduce 91) ((T_PRIVATE) reduce 91) ((T_PROTECTED) reduce 91) ((T_PUBLIC) reduce 91) ((T_READONLY) reduce 91) ((T_REQUIRE) reduce 91) ((T_REQUIRE_ONCE) reduce 91) ((T_RETURN) reduce 91) ((T_STATIC) reduce 91) ((T_STRING) reduce 91) ((T_SWITCH) reduce 91) ((T_THROW) reduce 91) ((T_TRAIT) reduce 91) ((T_TRAIT_C) reduce 91) ((T_TRY) reduce 91) ((T_UNSET) reduce 91) ((T_USE) reduce 91) ((T_VAR) reduce 91) ((T_WHILE) reduce 91) ((T_YIELD) reduce 91) (("|") reduce 91)) 6036 (((T_ABSTRACT) reduce 279) ((T_ARRAY) reduce 279) ((T_AS) reduce 279) ((T_BREAK) reduce 279) ((T_CALLABLE) reduce 279) ((T_CASE) reduce 279) ((T_CATCH) reduce 279) ((T_CLASS) reduce 279) ((T_CLASS_C) reduce 279) ((T_CLONE) reduce 279) ((T_CONST) reduce 279) ((T_CONTINUE) reduce 279) ((T_DECLARE) reduce 279) ((T_DEFAULT) reduce 279) ((T_DIR) reduce 279) ((T_DO) reduce 279) ((T_ECHO) reduce 279) ((T_ELSE) reduce 279) ((T_ELSEIF) reduce 279) ((T_EMPTY) reduce 279) ((T_ENDDECLARE) reduce 279) ((T_ENDFOR) reduce 279) ((T_ENDFOREACH) reduce 279) ((T_ENDIF) reduce 279) ((T_ENDSWITCH) reduce 279) ((T_ENDWHILE) reduce 279) ((T_ENUM) reduce 279) ((T_EVAL) reduce 279) ((T_EXIT) reduce 279) ((T_EXTENDS) reduce 279) ((T_FILE) reduce 279) ((T_FINAL) reduce 279) ((T_FINALLY) reduce 279) ((T_FN) reduce 279) ((T_FOR) reduce 279) ((T_FOREACH) reduce 279) ((T_FUNCTION) reduce 279) ((T_FUNC_C) reduce 279) ((T_GLOBAL) reduce 279) ((T_GOTO) reduce 279) ((T_IF) reduce 279) ((T_IMPLEMENTS) reduce 279) ((T_INCLUDE) reduce 279) ((T_INCLUDE_ONCE) reduce 279) ((T_INSTANCEOF) reduce 279) ((T_INSTEADOF) reduce 279) ((T_INTERFACE) reduce 279) ((T_ISSET) reduce 279) ((T_LINE) reduce 279) ((T_LIST) reduce 279) ((T_LOGICAL_AND) reduce 279) ((T_LOGICAL_OR) reduce 279) ((T_LOGICAL_XOR) reduce 279) ((T_MATCH) reduce 279) ((T_METHOD_C) reduce 279) ((T_NAMESPACE) reduce 279) ((T_NEW) reduce 279) ((T_NS_C) reduce 279) ((T_PRINT) reduce 279) ((T_PRIVATE) reduce 279) ((T_PROTECTED) reduce 279) ((T_PUBLIC) reduce 279) ((T_READONLY) reduce 279) ((T_REQUIRE) reduce 279) ((T_REQUIRE_ONCE) reduce 279) ((T_RETURN) reduce 279) ((T_STATIC) reduce 279) ((T_STRING) reduce 279) ((T_SWITCH) reduce 279) ((T_THROW) reduce 279) ((T_TRAIT) reduce 279) ((T_TRAIT_C) reduce 279) ((T_TRY) reduce 279) ((T_UNSET) reduce 279) ((T_USE) reduce 279) ((T_VAR) reduce 279) ((T_WHILE) reduce 279) ((T_YIELD) reduce 279) (("|") reduce 279)) 6037 (((T_ABSTRACT) reduce 267) ((T_ARRAY) reduce 267) ((T_AS) reduce 267) ((T_BREAK) reduce 267) ((T_CALLABLE) reduce 267) ((T_CASE) reduce 267) ((T_CATCH) reduce 267) ((T_CLASS) reduce 267) ((T_CLASS_C) reduce 267) ((T_CLONE) reduce 267) ((T_CONST) reduce 267) ((T_CONTINUE) reduce 267) ((T_DECLARE) reduce 267) ((T_DEFAULT) reduce 267) ((T_DIR) reduce 267) ((T_DO) reduce 267) ((T_ECHO) reduce 267) ((T_ELSE) reduce 267) ((T_ELSEIF) reduce 267) ((T_EMPTY) reduce 267) ((T_ENDDECLARE) reduce 267) ((T_ENDFOR) reduce 267) ((T_ENDFOREACH) reduce 267) ((T_ENDIF) reduce 267) ((T_ENDSWITCH) reduce 267) ((T_ENDWHILE) reduce 267) ((T_ENUM) reduce 267) ((T_EVAL) reduce 267) ((T_EXIT) reduce 267) ((T_EXTENDS) reduce 267) ((T_FILE) reduce 267) ((T_FINAL) reduce 267) ((T_FINALLY) reduce 267) ((T_FN) reduce 267) ((T_FOR) reduce 267) ((T_FOREACH) reduce 267) ((T_FUNCTION) reduce 267) ((T_FUNC_C) reduce 267) ((T_GLOBAL) reduce 267) ((T_GOTO) reduce 267) ((T_IF) reduce 267) ((T_IMPLEMENTS) reduce 267) ((T_INCLUDE) reduce 267) ((T_INCLUDE_ONCE) reduce 267) ((T_INSTANCEOF) reduce 267) ((T_INSTEADOF) reduce 267) ((T_INTERFACE) reduce 267) ((T_ISSET) reduce 267) ((T_LINE) reduce 267) ((T_LIST) reduce 267) ((T_LOGICAL_AND) reduce 267) ((T_LOGICAL_OR) reduce 267) ((T_LOGICAL_XOR) reduce 267) ((T_MATCH) reduce 267) ((T_METHOD_C) reduce 267) ((T_NAMESPACE) reduce 267) ((T_NEW) reduce 267) ((T_NS_C) reduce 267) ((T_PRINT) reduce 267) ((T_PRIVATE) reduce 267) ((T_PROTECTED) reduce 267) ((T_PUBLIC) reduce 267) ((T_READONLY) reduce 267) ((T_REQUIRE) reduce 267) ((T_REQUIRE_ONCE) reduce 267) ((T_RETURN) reduce 267) ((T_STATIC) reduce 267) ((T_STRING) reduce 267) ((T_SWITCH) reduce 267) ((T_THROW) reduce 267) ((T_TRAIT) reduce 267) ((T_TRAIT_C) reduce 267) ((T_TRY) reduce 267) ((T_UNSET) reduce 267) ((T_USE) reduce 267) ((T_VAR) reduce 267) ((T_WHILE) reduce 267) ((T_YIELD) reduce 267) (("|") reduce 267)) 6038 (((T_ABSTRACT) reduce 265) ((T_ARRAY) reduce 265) ((T_AS) reduce 265) ((T_BREAK) reduce 265) ((T_CALLABLE) reduce 265) ((T_CASE) reduce 265) ((T_CATCH) reduce 265) ((T_CLASS) reduce 265) ((T_CLASS_C) reduce 265) ((T_CLONE) reduce 265) ((T_CONST) reduce 265) ((T_CONTINUE) reduce 265) ((T_DECLARE) reduce 265) ((T_DEFAULT) reduce 265) ((T_DIR) reduce 265) ((T_DO) reduce 265) ((T_ECHO) reduce 265) ((T_ELSE) reduce 265) ((T_ELSEIF) reduce 265) ((T_EMPTY) reduce 265) ((T_ENDDECLARE) reduce 265) ((T_ENDFOR) reduce 265) ((T_ENDFOREACH) reduce 265) ((T_ENDIF) reduce 265) ((T_ENDSWITCH) reduce 265) ((T_ENDWHILE) reduce 265) ((T_ENUM) reduce 265) ((T_EVAL) reduce 265) ((T_EXIT) reduce 265) ((T_EXTENDS) reduce 265) ((T_FILE) reduce 265) ((T_FINAL) reduce 265) ((T_FINALLY) reduce 265) ((T_FN) reduce 265) ((T_FOR) reduce 265) ((T_FOREACH) reduce 265) ((T_FUNCTION) reduce 265) ((T_FUNC_C) reduce 265) ((T_GLOBAL) reduce 265) ((T_GOTO) reduce 265) ((T_IF) reduce 265) ((T_IMPLEMENTS) reduce 265) ((T_INCLUDE) reduce 265) ((T_INCLUDE_ONCE) reduce 265) ((T_INSTANCEOF) reduce 265) ((T_INSTEADOF) reduce 265) ((T_INTERFACE) reduce 265) ((T_ISSET) reduce 265) ((T_LINE) reduce 265) ((T_LIST) reduce 265) ((T_LOGICAL_AND) reduce 265) ((T_LOGICAL_OR) reduce 265) ((T_LOGICAL_XOR) reduce 265) ((T_MATCH) reduce 265) ((T_METHOD_C) reduce 265) ((T_NAMESPACE) reduce 265) ((T_NEW) reduce 265) ((T_NS_C) reduce 265) ((T_PRINT) reduce 265) ((T_PRIVATE) reduce 265) ((T_PROTECTED) reduce 265) ((T_PUBLIC) reduce 265) ((T_READONLY) reduce 265) ((T_REQUIRE) reduce 265) ((T_REQUIRE_ONCE) reduce 265) ((T_RETURN) reduce 265) ((T_STATIC) reduce 265) ((T_STRING) reduce 265) ((T_SWITCH) reduce 265) ((T_THROW) reduce 265) ((T_TRAIT) reduce 265) ((T_TRAIT_C) reduce 265) ((T_TRY) reduce 265) ((T_UNSET) reduce 265) ((T_USE) reduce 265) ((T_VAR) reduce 265) ((T_WHILE) reduce 265) ((T_YIELD) reduce 265) (("|") reduce 265)) 6039 (((T_ABSTRACT) reduce 269) ((T_ARRAY) reduce 269) ((T_AS) reduce 269) ((T_BREAK) reduce 269) ((T_CALLABLE) reduce 269) ((T_CASE) reduce 269) ((T_CATCH) reduce 269) ((T_CLASS) reduce 269) ((T_CLASS_C) reduce 269) ((T_CLONE) reduce 269) ((T_CONST) reduce 269) ((T_CONTINUE) reduce 269) ((T_DECLARE) reduce 269) ((T_DEFAULT) reduce 269) ((T_DIR) reduce 269) ((T_DO) reduce 269) ((T_ECHO) reduce 269) ((T_ELSE) reduce 269) ((T_ELSEIF) reduce 269) ((T_EMPTY) reduce 269) ((T_ENDDECLARE) reduce 269) ((T_ENDFOR) reduce 269) ((T_ENDFOREACH) reduce 269) ((T_ENDIF) reduce 269) ((T_ENDSWITCH) reduce 269) ((T_ENDWHILE) reduce 269) ((T_ENUM) reduce 269) ((T_EVAL) reduce 269) ((T_EXIT) reduce 269) ((T_EXTENDS) reduce 269) ((T_FILE) reduce 269) ((T_FINAL) reduce 269) ((T_FINALLY) reduce 269) ((T_FN) reduce 269) ((T_FOR) reduce 269) ((T_FOREACH) reduce 269) ((T_FUNCTION) reduce 269) ((T_FUNC_C) reduce 269) ((T_GLOBAL) reduce 269) ((T_GOTO) reduce 269) ((T_IF) reduce 269) ((T_IMPLEMENTS) reduce 269) ((T_INCLUDE) reduce 269) ((T_INCLUDE_ONCE) reduce 269) ((T_INSTANCEOF) reduce 269) ((T_INSTEADOF) reduce 269) ((T_INTERFACE) reduce 269) ((T_ISSET) reduce 269) ((T_LINE) reduce 269) ((T_LIST) reduce 269) ((T_LOGICAL_AND) reduce 269) ((T_LOGICAL_OR) reduce 269) ((T_LOGICAL_XOR) reduce 269) ((T_MATCH) reduce 269) ((T_METHOD_C) reduce 269) ((T_NAMESPACE) reduce 269) ((T_NEW) reduce 269) ((T_NS_C) reduce 269) ((T_PRINT) reduce 269) ((T_PRIVATE) reduce 269) ((T_PROTECTED) reduce 269) ((T_PUBLIC) reduce 269) ((T_READONLY) reduce 269) ((T_REQUIRE) reduce 269) ((T_REQUIRE_ONCE) reduce 269) ((T_RETURN) reduce 269) ((T_STATIC) reduce 269) ((T_STRING) reduce 269) ((T_SWITCH) reduce 269) ((T_THROW) reduce 269) ((T_TRAIT) reduce 269) ((T_TRAIT_C) reduce 269) ((T_TRY) reduce 269) ((T_UNSET) reduce 269) ((T_USE) reduce 269) ((T_VAR) reduce 269) ((T_WHILE) reduce 269) ((T_YIELD) reduce 269) (("|") reduce 269)) 6041 (((T_ABSTRACT) reduce 268) ((T_ARRAY) reduce 268) ((T_AS) reduce 268) ((T_BREAK) reduce 268) ((T_CALLABLE) reduce 268) ((T_CASE) reduce 268) ((T_CATCH) reduce 268) ((T_CLASS) reduce 268) ((T_CLASS_C) reduce 268) ((T_CLONE) reduce 268) ((T_CONST) reduce 268) ((T_CONTINUE) reduce 268) ((T_DECLARE) reduce 268) ((T_DEFAULT) reduce 268) ((T_DIR) reduce 268) ((T_DO) reduce 268) ((T_ECHO) reduce 268) ((T_ELSE) reduce 268) ((T_ELSEIF) reduce 268) ((T_EMPTY) reduce 268) ((T_ENDDECLARE) reduce 268) ((T_ENDFOR) reduce 268) ((T_ENDFOREACH) reduce 268) ((T_ENDIF) reduce 268) ((T_ENDSWITCH) reduce 268) ((T_ENDWHILE) reduce 268) ((T_ENUM) reduce 268) ((T_EVAL) reduce 268) ((T_EXIT) reduce 268) ((T_EXTENDS) reduce 268) ((T_FILE) reduce 268) ((T_FINAL) reduce 268) ((T_FINALLY) reduce 268) ((T_FN) reduce 268) ((T_FOR) reduce 268) ((T_FOREACH) reduce 268) ((T_FUNCTION) reduce 268) ((T_FUNC_C) reduce 268) ((T_GLOBAL) reduce 268) ((T_GOTO) reduce 268) ((T_IF) reduce 268) ((T_IMPLEMENTS) reduce 268) ((T_INCLUDE) reduce 268) ((T_INCLUDE_ONCE) reduce 268) ((T_INSTANCEOF) reduce 268) ((T_INSTEADOF) reduce 268) ((T_INTERFACE) reduce 268) ((T_ISSET) reduce 268) ((T_LINE) reduce 268) ((T_LIST) reduce 268) ((T_LOGICAL_AND) reduce 268) ((T_LOGICAL_OR) reduce 268) ((T_LOGICAL_XOR) reduce 268) ((T_MATCH) reduce 268) ((T_METHOD_C) reduce 268) ((T_NAMESPACE) reduce 268) ((T_NEW) reduce 268) ((T_NS_C) reduce 268) ((T_PRINT) reduce 268) ((T_PRIVATE) reduce 268) ((T_PROTECTED) reduce 268) ((T_PUBLIC) reduce 268) ((T_READONLY) reduce 268) ((T_REQUIRE) reduce 268) ((T_REQUIRE_ONCE) reduce 268) ((T_RETURN) reduce 268) ((T_STATIC) reduce 268) ((T_STRING) reduce 268) ((T_SWITCH) reduce 268) ((T_THROW) reduce 268) ((T_TRAIT) reduce 268) ((T_TRAIT_C) reduce 268) ((T_TRY) reduce 268) ((T_UNSET) reduce 268) ((T_USE) reduce 268) ((T_VAR) reduce 268) ((T_WHILE) reduce 268) ((T_YIELD) reduce 268) (("|") reduce 268)) 6043 (((T_ABSTRACT) reduce 270) ((T_ARRAY) reduce 270) ((T_AS) reduce 270) ((T_BREAK) reduce 270) ((T_CALLABLE) reduce 270) ((T_CASE) reduce 270) ((T_CATCH) reduce 270) ((T_CLASS) reduce 270) ((T_CLASS_C) reduce 270) ((T_CLONE) reduce 270) ((T_CONST) reduce 270) ((T_CONTINUE) reduce 270) ((T_DECLARE) reduce 270) ((T_DEFAULT) reduce 270) ((T_DIR) reduce 270) ((T_DO) reduce 270) ((T_ECHO) reduce 270) ((T_ELSE) reduce 270) ((T_ELSEIF) reduce 270) ((T_EMPTY) reduce 270) ((T_ENDDECLARE) reduce 270) ((T_ENDFOR) reduce 270) ((T_ENDFOREACH) reduce 270) ((T_ENDIF) reduce 270) ((T_ENDSWITCH) reduce 270) ((T_ENDWHILE) reduce 270) ((T_ENUM) reduce 270) ((T_EVAL) reduce 270) ((T_EXIT) reduce 270) ((T_EXTENDS) reduce 270) ((T_FILE) reduce 270) ((T_FINAL) reduce 270) ((T_FINALLY) reduce 270) ((T_FN) reduce 270) ((T_FOR) reduce 270) ((T_FOREACH) reduce 270) ((T_FUNCTION) reduce 270) ((T_FUNC_C) reduce 270) ((T_GLOBAL) reduce 270) ((T_GOTO) reduce 270) ((T_IF) reduce 270) ((T_IMPLEMENTS) reduce 270) ((T_INCLUDE) reduce 270) ((T_INCLUDE_ONCE) reduce 270) ((T_INSTANCEOF) reduce 270) ((T_INSTEADOF) reduce 270) ((T_INTERFACE) reduce 270) ((T_ISSET) reduce 270) ((T_LINE) reduce 270) ((T_LIST) reduce 270) ((T_LOGICAL_AND) reduce 270) ((T_LOGICAL_OR) reduce 270) ((T_LOGICAL_XOR) reduce 270) ((T_MATCH) reduce 270) ((T_METHOD_C) reduce 270) ((T_NAMESPACE) reduce 270) ((T_NEW) reduce 270) ((T_NS_C) reduce 270) ((T_PRINT) reduce 270) ((T_PRIVATE) reduce 270) ((T_PROTECTED) reduce 270) ((T_PUBLIC) reduce 270) ((T_READONLY) reduce 270) ((T_REQUIRE) reduce 270) ((T_REQUIRE_ONCE) reduce 270) ((T_RETURN) reduce 270) ((T_STATIC) reduce 270) ((T_STRING) reduce 270) ((T_SWITCH) reduce 270) ((T_THROW) reduce 270) ((T_TRAIT) reduce 270) ((T_TRAIT_C) reduce 270) ((T_TRY) reduce 270) ((T_UNSET) reduce 270) ((T_USE) reduce 270) ((T_VAR) reduce 270) ((T_WHILE) reduce 270) ((T_YIELD) reduce 270) (("|") reduce 270)) 6044 ((("=") reduce 52)) 6045 ((("=") reduce 53)) 6046 ((("=") reduce 72)) 6050 (((T_ABSTRACT) reduce 307) ((T_ATTRIBUTE) reduce 307) ((T_CASE) reduce 307) ((T_CONST) reduce 307) ((T_FINAL) reduce 307) ((T_FUNCTION) reduce 307) ((T_PRIVATE) reduce 307) ((T_PROTECTED) reduce 307) ((T_PUBLIC) reduce 307) ((T_READONLY) reduce 307) ((T_STATIC) reduce 307) ((T_USE) reduce 307) ((T_VAR) reduce 307) (("}") reduce 307)) 6051 (((",") reduce 351) ((";") reduce 351)) 6054 (((",") reduce 353) ((";") reduce 353)) 6056 (((T_ABSTRACT) reduce 277) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 277) ((T_ARRAY) reduce 277) ((T_AS) reduce 277) ((T_BREAK) reduce 277) ((T_CALLABLE) reduce 277) ((T_CASE) reduce 277) ((T_CATCH) reduce 277) ((T_CLASS) reduce 277) ((T_CLASS_C) reduce 277) ((T_CLONE) reduce 277) ((T_CONST) reduce 277) ((T_CONTINUE) reduce 277) ((T_DECLARE) reduce 277) ((T_DEFAULT) reduce 277) ((T_DIR) reduce 277) ((T_DO) reduce 277) ((T_ECHO) reduce 277) ((T_ELSE) reduce 277) ((T_ELSEIF) reduce 277) ((T_EMPTY) reduce 277) ((T_ENDDECLARE) reduce 277) ((T_ENDFOR) reduce 277) ((T_ENDFOREACH) reduce 277) ((T_ENDIF) reduce 277) ((T_ENDSWITCH) reduce 277) ((T_ENDWHILE) reduce 277) ((T_ENUM) reduce 277) ((T_EVAL) reduce 277) ((T_EXIT) reduce 277) ((T_EXTENDS) reduce 277) ((T_FILE) reduce 277) ((T_FINAL) reduce 277) ((T_FINALLY) reduce 277) ((T_FN) reduce 277) ((T_FOR) reduce 277) ((T_FOREACH) reduce 277) ((T_FUNCTION) reduce 277) ((T_FUNC_C) reduce 277) ((T_GLOBAL) reduce 277) ((T_GOTO) reduce 277) ((T_IF) reduce 277) ((T_IMPLEMENTS) reduce 277) ((T_INCLUDE) reduce 277) ((T_INCLUDE_ONCE) reduce 277) ((T_INSTANCEOF) reduce 277) ((T_INSTEADOF) reduce 277) ((T_INTERFACE) reduce 277) ((T_ISSET) reduce 277) ((T_LINE) reduce 277) ((T_LIST) reduce 277) ((T_LOGICAL_AND) reduce 277) ((T_LOGICAL_OR) reduce 277) ((T_LOGICAL_XOR) reduce 277) ((T_MATCH) reduce 277) ((T_METHOD_C) reduce 277) ((T_NAMESPACE) reduce 277) ((T_NEW) reduce 277) ((T_NS_C) reduce 277) ((T_PRINT) reduce 277) ((T_PRIVATE) reduce 277) ((T_PROTECTED) reduce 277) ((T_PUBLIC) reduce 277) ((T_READONLY) reduce 277) ((T_REQUIRE) reduce 277) ((T_REQUIRE_ONCE) reduce 277) ((T_RETURN) reduce 277) ((T_STATIC) reduce 277) ((T_STRING) reduce 277) ((T_SWITCH) reduce 277) ((T_THROW) reduce 277) ((T_TRAIT) reduce 277) ((T_TRAIT_C) reduce 277) ((T_TRY) reduce 277) ((T_UNSET) reduce 277) ((T_USE) reduce 277) ((T_VAR) reduce 277) ((T_WHILE) reduce 277) ((T_YIELD) reduce 277)) 6057 (((T_ABSTRACT) reduce 278) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 278) ((T_ARRAY) reduce 278) ((T_AS) reduce 278) ((T_BREAK) reduce 278) ((T_CALLABLE) reduce 278) ((T_CASE) reduce 278) ((T_CATCH) reduce 278) ((T_CLASS) reduce 278) ((T_CLASS_C) reduce 278) ((T_CLONE) reduce 278) ((T_CONST) reduce 278) ((T_CONTINUE) reduce 278) ((T_DECLARE) reduce 278) ((T_DEFAULT) reduce 278) ((T_DIR) reduce 278) ((T_DO) reduce 278) ((T_ECHO) reduce 278) ((T_ELSE) reduce 278) ((T_ELSEIF) reduce 278) ((T_EMPTY) reduce 278) ((T_ENDDECLARE) reduce 278) ((T_ENDFOR) reduce 278) ((T_ENDFOREACH) reduce 278) ((T_ENDIF) reduce 278) ((T_ENDSWITCH) reduce 278) ((T_ENDWHILE) reduce 278) ((T_ENUM) reduce 278) ((T_EVAL) reduce 278) ((T_EXIT) reduce 278) ((T_EXTENDS) reduce 278) ((T_FILE) reduce 278) ((T_FINAL) reduce 278) ((T_FINALLY) reduce 278) ((T_FN) reduce 278) ((T_FOR) reduce 278) ((T_FOREACH) reduce 278) ((T_FUNCTION) reduce 278) ((T_FUNC_C) reduce 278) ((T_GLOBAL) reduce 278) ((T_GOTO) reduce 278) ((T_IF) reduce 278) ((T_IMPLEMENTS) reduce 278) ((T_INCLUDE) reduce 278) ((T_INCLUDE_ONCE) reduce 278) ((T_INSTANCEOF) reduce 278) ((T_INSTEADOF) reduce 278) ((T_INTERFACE) reduce 278) ((T_ISSET) reduce 278) ((T_LINE) reduce 278) ((T_LIST) reduce 278) ((T_LOGICAL_AND) reduce 278) ((T_LOGICAL_OR) reduce 278) ((T_LOGICAL_XOR) reduce 278) ((T_MATCH) reduce 278) ((T_METHOD_C) reduce 278) ((T_NAMESPACE) reduce 278) ((T_NEW) reduce 278) ((T_NS_C) reduce 278) ((T_PRINT) reduce 278) ((T_PRIVATE) reduce 278) ((T_PROTECTED) reduce 278) ((T_PUBLIC) reduce 278) ((T_READONLY) reduce 278) ((T_REQUIRE) reduce 278) ((T_REQUIRE_ONCE) reduce 278) ((T_RETURN) reduce 278) ((T_STATIC) reduce 278) ((T_STRING) reduce 278) ((T_SWITCH) reduce 278) ((T_THROW) reduce 278) ((T_TRAIT) reduce 278) ((T_TRAIT_C) reduce 278) ((T_TRY) reduce 278) ((T_UNSET) reduce 278) ((T_USE) reduce 278) ((T_VAR) reduce 278) ((T_WHILE) reduce 278) ((T_YIELD) reduce 278)) 6058 (((T_ABSTRACT) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_ARRAY) reduce 93) ((T_AS) reduce 93) ((T_BREAK) reduce 93) ((T_CALLABLE) reduce 93) ((T_CASE) reduce 93) ((T_CATCH) reduce 93) ((T_CLASS) reduce 93) ((T_CLASS_C) reduce 93) ((T_CLONE) reduce 93) ((T_CONST) reduce 93) ((T_CONTINUE) reduce 93) ((T_DECLARE) reduce 93) ((T_DEFAULT) reduce 93) ((T_DIR) reduce 93) ((T_DO) reduce 93) ((T_ECHO) reduce 93) ((T_ELSE) reduce 93) ((T_ELSEIF) reduce 93) ((T_EMPTY) reduce 93) ((T_ENDDECLARE) reduce 93) ((T_ENDFOR) reduce 93) ((T_ENDFOREACH) reduce 93) ((T_ENDIF) reduce 93) ((T_ENDSWITCH) reduce 93) ((T_ENDWHILE) reduce 93) ((T_ENUM) reduce 93) ((T_EVAL) reduce 93) ((T_EXIT) reduce 93) ((T_EXTENDS) reduce 93) ((T_FILE) reduce 93) ((T_FINAL) reduce 93) ((T_FINALLY) reduce 93) ((T_FN) reduce 93) ((T_FOR) reduce 93) ((T_FOREACH) reduce 93) ((T_FUNCTION) reduce 93) ((T_FUNC_C) reduce 93) ((T_GLOBAL) reduce 93) ((T_GOTO) reduce 93) ((T_IF) reduce 93) ((T_IMPLEMENTS) reduce 93) ((T_INCLUDE) reduce 93) ((T_INCLUDE_ONCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_INSTEADOF) reduce 93) ((T_INTERFACE) reduce 93) ((T_ISSET) reduce 93) ((T_LINE) reduce 93) ((T_LIST) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_MATCH) reduce 93) ((T_METHOD_C) reduce 93) ((T_NAMESPACE) reduce 93) ((T_NEW) reduce 93) ((T_NS_C) reduce 93) ((T_PRINT) reduce 93) ((T_PRIVATE) reduce 93) ((T_PROTECTED) reduce 93) ((T_PUBLIC) reduce 93) ((T_READONLY) reduce 93) ((T_REQUIRE) reduce 93) ((T_REQUIRE_ONCE) reduce 93) ((T_RETURN) reduce 93) ((T_STATIC) reduce 93) ((T_STRING) reduce 93) ((T_SWITCH) reduce 93) ((T_THROW) reduce 93) ((T_TRAIT) reduce 93) ((T_TRAIT_C) reduce 93) ((T_TRY) reduce 93) ((T_UNSET) reduce 93) ((T_USE) reduce 93) ((T_VAR) reduce 93) ((T_WHILE) reduce 93) ((T_YIELD) reduce 93)) 6059 (((T_ABSTRACT) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_ARRAY) reduce 92) ((T_AS) reduce 92) ((T_BREAK) reduce 92) ((T_CALLABLE) reduce 92) ((T_CASE) reduce 92) ((T_CATCH) reduce 92) ((T_CLASS) reduce 92) ((T_CLASS_C) reduce 92) ((T_CLONE) reduce 92) ((T_CONST) reduce 92) ((T_CONTINUE) reduce 92) ((T_DECLARE) reduce 92) ((T_DEFAULT) reduce 92) ((T_DIR) reduce 92) ((T_DO) reduce 92) ((T_ECHO) reduce 92) ((T_ELSE) reduce 92) ((T_ELSEIF) reduce 92) ((T_EMPTY) reduce 92) ((T_ENDDECLARE) reduce 92) ((T_ENDFOR) reduce 92) ((T_ENDFOREACH) reduce 92) ((T_ENDIF) reduce 92) ((T_ENDSWITCH) reduce 92) ((T_ENDWHILE) reduce 92) ((T_ENUM) reduce 92) ((T_EVAL) reduce 92) ((T_EXIT) reduce 92) ((T_EXTENDS) reduce 92) ((T_FILE) reduce 92) ((T_FINAL) reduce 92) ((T_FINALLY) reduce 92) ((T_FN) reduce 92) ((T_FOR) reduce 92) ((T_FOREACH) reduce 92) ((T_FUNCTION) reduce 92) ((T_FUNC_C) reduce 92) ((T_GLOBAL) reduce 92) ((T_GOTO) reduce 92) ((T_IF) reduce 92) ((T_IMPLEMENTS) reduce 92) ((T_INCLUDE) reduce 92) ((T_INCLUDE_ONCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_INSTEADOF) reduce 92) ((T_INTERFACE) reduce 92) ((T_ISSET) reduce 92) ((T_LINE) reduce 92) ((T_LIST) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_MATCH) reduce 92) ((T_METHOD_C) reduce 92) ((T_NAMESPACE) reduce 92) ((T_NEW) reduce 92) ((T_NS_C) reduce 92) ((T_PRINT) reduce 92) ((T_PRIVATE) reduce 92) ((T_PROTECTED) reduce 92) ((T_PUBLIC) reduce 92) ((T_READONLY) reduce 92) ((T_REQUIRE) reduce 92) ((T_REQUIRE_ONCE) reduce 92) ((T_RETURN) reduce 92) ((T_STATIC) reduce 92) ((T_STRING) reduce 92) ((T_SWITCH) reduce 92) ((T_THROW) reduce 92) ((T_TRAIT) reduce 92) ((T_TRAIT_C) reduce 92) ((T_TRY) reduce 92) ((T_UNSET) reduce 92) ((T_USE) reduce 92) ((T_VAR) reduce 92) ((T_WHILE) reduce 92) ((T_YIELD) reduce 92)) 6060 (((T_ABSTRACT) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_ARRAY) reduce 94) ((T_AS) reduce 94) ((T_BREAK) reduce 94) ((T_CALLABLE) reduce 94) ((T_CASE) reduce 94) ((T_CATCH) reduce 94) ((T_CLASS) reduce 94) ((T_CLASS_C) reduce 94) ((T_CLONE) reduce 94) ((T_CONST) reduce 94) ((T_CONTINUE) reduce 94) ((T_DECLARE) reduce 94) ((T_DEFAULT) reduce 94) ((T_DIR) reduce 94) ((T_DO) reduce 94) ((T_ECHO) reduce 94) ((T_ELSE) reduce 94) ((T_ELSEIF) reduce 94) ((T_EMPTY) reduce 94) ((T_ENDDECLARE) reduce 94) ((T_ENDFOR) reduce 94) ((T_ENDFOREACH) reduce 94) ((T_ENDIF) reduce 94) ((T_ENDSWITCH) reduce 94) ((T_ENDWHILE) reduce 94) ((T_ENUM) reduce 94) ((T_EVAL) reduce 94) ((T_EXIT) reduce 94) ((T_EXTENDS) reduce 94) ((T_FILE) reduce 94) ((T_FINAL) reduce 94) ((T_FINALLY) reduce 94) ((T_FN) reduce 94) ((T_FOR) reduce 94) ((T_FOREACH) reduce 94) ((T_FUNCTION) reduce 94) ((T_FUNC_C) reduce 94) ((T_GLOBAL) reduce 94) ((T_GOTO) reduce 94) ((T_IF) reduce 94) ((T_IMPLEMENTS) reduce 94) ((T_INCLUDE) reduce 94) ((T_INCLUDE_ONCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_INSTEADOF) reduce 94) ((T_INTERFACE) reduce 94) ((T_ISSET) reduce 94) ((T_LINE) reduce 94) ((T_LIST) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_MATCH) reduce 94) ((T_METHOD_C) reduce 94) ((T_NAMESPACE) reduce 94) ((T_NEW) reduce 94) ((T_NS_C) reduce 94) ((T_PRINT) reduce 94) ((T_PRIVATE) reduce 94) ((T_PROTECTED) reduce 94) ((T_PUBLIC) reduce 94) ((T_READONLY) reduce 94) ((T_REQUIRE) reduce 94) ((T_REQUIRE_ONCE) reduce 94) ((T_RETURN) reduce 94) ((T_STATIC) reduce 94) ((T_STRING) reduce 94) ((T_SWITCH) reduce 94) ((T_THROW) reduce 94) ((T_TRAIT) reduce 94) ((T_TRAIT_C) reduce 94) ((T_TRY) reduce 94) ((T_UNSET) reduce 94) ((T_USE) reduce 94) ((T_VAR) reduce 94) ((T_WHILE) reduce 94) ((T_YIELD) reduce 94)) 6061 (((T_ABSTRACT) reduce 266) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 266) ((T_ARRAY) reduce 266) ((T_AS) reduce 266) ((T_BREAK) reduce 266) ((T_CALLABLE) reduce 266) ((T_CASE) reduce 266) ((T_CATCH) reduce 266) ((T_CLASS) reduce 266) ((T_CLASS_C) reduce 266) ((T_CLONE) reduce 266) ((T_CONST) reduce 266) ((T_CONTINUE) reduce 266) ((T_DECLARE) reduce 266) ((T_DEFAULT) reduce 266) ((T_DIR) reduce 266) ((T_DO) reduce 266) ((T_ECHO) reduce 266) ((T_ELSE) reduce 266) ((T_ELSEIF) reduce 266) ((T_EMPTY) reduce 266) ((T_ENDDECLARE) reduce 266) ((T_ENDFOR) reduce 266) ((T_ENDFOREACH) reduce 266) ((T_ENDIF) reduce 266) ((T_ENDSWITCH) reduce 266) ((T_ENDWHILE) reduce 266) ((T_ENUM) reduce 266) ((T_EVAL) reduce 266) ((T_EXIT) reduce 266) ((T_EXTENDS) reduce 266) ((T_FILE) reduce 266) ((T_FINAL) reduce 266) ((T_FINALLY) reduce 266) ((T_FN) reduce 266) ((T_FOR) reduce 266) ((T_FOREACH) reduce 266) ((T_FUNCTION) reduce 266) ((T_FUNC_C) reduce 266) ((T_GLOBAL) reduce 266) ((T_GOTO) reduce 266) ((T_IF) reduce 266) ((T_IMPLEMENTS) reduce 266) ((T_INCLUDE) reduce 266) ((T_INCLUDE_ONCE) reduce 266) ((T_INSTANCEOF) reduce 266) ((T_INSTEADOF) reduce 266) ((T_INTERFACE) reduce 266) ((T_ISSET) reduce 266) ((T_LINE) reduce 266) ((T_LIST) reduce 266) ((T_LOGICAL_AND) reduce 266) ((T_LOGICAL_OR) reduce 266) ((T_LOGICAL_XOR) reduce 266) ((T_MATCH) reduce 266) ((T_METHOD_C) reduce 266) ((T_NAMESPACE) reduce 266) ((T_NEW) reduce 266) ((T_NS_C) reduce 266) ((T_PRINT) reduce 266) ((T_PRIVATE) reduce 266) ((T_PROTECTED) reduce 266) ((T_PUBLIC) reduce 266) ((T_READONLY) reduce 266) ((T_REQUIRE) reduce 266) ((T_REQUIRE_ONCE) reduce 266) ((T_RETURN) reduce 266) ((T_STATIC) reduce 266) ((T_STRING) reduce 266) ((T_SWITCH) reduce 266) ((T_THROW) reduce 266) ((T_TRAIT) reduce 266) ((T_TRAIT_C) reduce 266) ((T_TRY) reduce 266) ((T_UNSET) reduce 266) ((T_USE) reduce 266) ((T_VAR) reduce 266) ((T_WHILE) reduce 266) ((T_YIELD) reduce 266)) 6062 (((T_ABSTRACT) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_ARRAY) reduce 91) ((T_AS) reduce 91) ((T_BREAK) reduce 91) ((T_CALLABLE) reduce 91) ((T_CASE) reduce 91) ((T_CATCH) reduce 91) ((T_CLASS) reduce 91) ((T_CLASS_C) reduce 91) ((T_CLONE) reduce 91) ((T_CONST) reduce 91) ((T_CONTINUE) reduce 91) ((T_DECLARE) reduce 91) ((T_DEFAULT) reduce 91) ((T_DIR) reduce 91) ((T_DO) reduce 91) ((T_ECHO) reduce 91) ((T_ELSE) reduce 91) ((T_ELSEIF) reduce 91) ((T_EMPTY) reduce 91) ((T_ENDDECLARE) reduce 91) ((T_ENDFOR) reduce 91) ((T_ENDFOREACH) reduce 91) ((T_ENDIF) reduce 91) ((T_ENDSWITCH) reduce 91) ((T_ENDWHILE) reduce 91) ((T_ENUM) reduce 91) ((T_EVAL) reduce 91) ((T_EXIT) reduce 91) ((T_EXTENDS) reduce 91) ((T_FILE) reduce 91) ((T_FINAL) reduce 91) ((T_FINALLY) reduce 91) ((T_FN) reduce 91) ((T_FOR) reduce 91) ((T_FOREACH) reduce 91) ((T_FUNCTION) reduce 91) ((T_FUNC_C) reduce 91) ((T_GLOBAL) reduce 91) ((T_GOTO) reduce 91) ((T_IF) reduce 91) ((T_IMPLEMENTS) reduce 91) ((T_INCLUDE) reduce 91) ((T_INCLUDE_ONCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_INSTEADOF) reduce 91) ((T_INTERFACE) reduce 91) ((T_ISSET) reduce 91) ((T_LINE) reduce 91) ((T_LIST) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_MATCH) reduce 91) ((T_METHOD_C) reduce 91) ((T_NAMESPACE) reduce 91) ((T_NEW) reduce 91) ((T_NS_C) reduce 91) ((T_PRINT) reduce 91) ((T_PRIVATE) reduce 91) ((T_PROTECTED) reduce 91) ((T_PUBLIC) reduce 91) ((T_READONLY) reduce 91) ((T_REQUIRE) reduce 91) ((T_REQUIRE_ONCE) reduce 91) ((T_RETURN) reduce 91) ((T_STATIC) reduce 91) ((T_STRING) reduce 91) ((T_SWITCH) reduce 91) ((T_THROW) reduce 91) ((T_TRAIT) reduce 91) ((T_TRAIT_C) reduce 91) ((T_TRY) reduce 91) ((T_UNSET) reduce 91) ((T_USE) reduce 91) ((T_VAR) reduce 91) ((T_WHILE) reduce 91) ((T_YIELD) reduce 91)) 6063 (((T_ABSTRACT) reduce 279) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 279) ((T_ARRAY) reduce 279) ((T_AS) reduce 279) ((T_BREAK) reduce 279) ((T_CALLABLE) reduce 279) ((T_CASE) reduce 279) ((T_CATCH) reduce 279) ((T_CLASS) reduce 279) ((T_CLASS_C) reduce 279) ((T_CLONE) reduce 279) ((T_CONST) reduce 279) ((T_CONTINUE) reduce 279) ((T_DECLARE) reduce 279) ((T_DEFAULT) reduce 279) ((T_DIR) reduce 279) ((T_DO) reduce 279) ((T_ECHO) reduce 279) ((T_ELSE) reduce 279) ((T_ELSEIF) reduce 279) ((T_EMPTY) reduce 279) ((T_ENDDECLARE) reduce 279) ((T_ENDFOR) reduce 279) ((T_ENDFOREACH) reduce 279) ((T_ENDIF) reduce 279) ((T_ENDSWITCH) reduce 279) ((T_ENDWHILE) reduce 279) ((T_ENUM) reduce 279) ((T_EVAL) reduce 279) ((T_EXIT) reduce 279) ((T_EXTENDS) reduce 279) ((T_FILE) reduce 279) ((T_FINAL) reduce 279) ((T_FINALLY) reduce 279) ((T_FN) reduce 279) ((T_FOR) reduce 279) ((T_FOREACH) reduce 279) ((T_FUNCTION) reduce 279) ((T_FUNC_C) reduce 279) ((T_GLOBAL) reduce 279) ((T_GOTO) reduce 279) ((T_IF) reduce 279) ((T_IMPLEMENTS) reduce 279) ((T_INCLUDE) reduce 279) ((T_INCLUDE_ONCE) reduce 279) ((T_INSTANCEOF) reduce 279) ((T_INSTEADOF) reduce 279) ((T_INTERFACE) reduce 279) ((T_ISSET) reduce 279) ((T_LINE) reduce 279) ((T_LIST) reduce 279) ((T_LOGICAL_AND) reduce 279) ((T_LOGICAL_OR) reduce 279) ((T_LOGICAL_XOR) reduce 279) ((T_MATCH) reduce 279) ((T_METHOD_C) reduce 279) ((T_NAMESPACE) reduce 279) ((T_NEW) reduce 279) ((T_NS_C) reduce 279) ((T_PRINT) reduce 279) ((T_PRIVATE) reduce 279) ((T_PROTECTED) reduce 279) ((T_PUBLIC) reduce 279) ((T_READONLY) reduce 279) ((T_REQUIRE) reduce 279) ((T_REQUIRE_ONCE) reduce 279) ((T_RETURN) reduce 279) ((T_STATIC) reduce 279) ((T_STRING) reduce 279) ((T_SWITCH) reduce 279) ((T_THROW) reduce 279) ((T_TRAIT) reduce 279) ((T_TRAIT_C) reduce 279) ((T_TRY) reduce 279) ((T_UNSET) reduce 279) ((T_USE) reduce 279) ((T_VAR) reduce 279) ((T_WHILE) reduce 279) ((T_YIELD) reduce 279)) 6064 (((T_ABSTRACT) reduce 271) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 271) ((T_ARRAY) reduce 271) ((T_AS) reduce 271) ((T_BREAK) reduce 271) ((T_CALLABLE) reduce 271) ((T_CASE) reduce 271) ((T_CATCH) reduce 271) ((T_CLASS) reduce 271) ((T_CLASS_C) reduce 271) ((T_CLONE) reduce 271) ((T_CONST) reduce 271) ((T_CONTINUE) reduce 271) ((T_DECLARE) reduce 271) ((T_DEFAULT) reduce 271) ((T_DIR) reduce 271) ((T_DO) reduce 271) ((T_ECHO) reduce 271) ((T_ELSE) reduce 271) ((T_ELSEIF) reduce 271) ((T_EMPTY) reduce 271) ((T_ENDDECLARE) reduce 271) ((T_ENDFOR) reduce 271) ((T_ENDFOREACH) reduce 271) ((T_ENDIF) reduce 271) ((T_ENDSWITCH) reduce 271) ((T_ENDWHILE) reduce 271) ((T_ENUM) reduce 271) ((T_EVAL) reduce 271) ((T_EXIT) reduce 271) ((T_EXTENDS) reduce 271) ((T_FILE) reduce 271) ((T_FINAL) reduce 271) ((T_FINALLY) reduce 271) ((T_FN) reduce 271) ((T_FOR) reduce 271) ((T_FOREACH) reduce 271) ((T_FUNCTION) reduce 271) ((T_FUNC_C) reduce 271) ((T_GLOBAL) reduce 271) ((T_GOTO) reduce 271) ((T_IF) reduce 271) ((T_IMPLEMENTS) reduce 271) ((T_INCLUDE) reduce 271) ((T_INCLUDE_ONCE) reduce 271) ((T_INSTANCEOF) reduce 271) ((T_INSTEADOF) reduce 271) ((T_INTERFACE) reduce 271) ((T_ISSET) reduce 271) ((T_LINE) reduce 271) ((T_LIST) reduce 271) ((T_LOGICAL_AND) reduce 271) ((T_LOGICAL_OR) reduce 271) ((T_LOGICAL_XOR) reduce 271) ((T_MATCH) reduce 271) ((T_METHOD_C) reduce 271) ((T_NAMESPACE) reduce 271) ((T_NEW) reduce 271) ((T_NS_C) reduce 271) ((T_PRINT) reduce 271) ((T_PRIVATE) reduce 271) ((T_PROTECTED) reduce 271) ((T_PUBLIC) reduce 271) ((T_READONLY) reduce 271) ((T_REQUIRE) reduce 271) ((T_REQUIRE_ONCE) reduce 271) ((T_RETURN) reduce 271) ((T_STATIC) reduce 271) ((T_STRING) reduce 271) ((T_SWITCH) reduce 271) ((T_THROW) reduce 271) ((T_TRAIT) reduce 271) ((T_TRAIT_C) reduce 271) ((T_TRY) reduce 271) ((T_UNSET) reduce 271) ((T_USE) reduce 271) ((T_VAR) reduce 271) ((T_WHILE) reduce 271) ((T_YIELD) reduce 271)) 6065 (((T_ABSTRACT) reduce 265) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 265) ((T_ARRAY) reduce 265) ((T_AS) reduce 265) ((T_BREAK) reduce 265) ((T_CALLABLE) reduce 265) ((T_CASE) reduce 265) ((T_CATCH) reduce 265) ((T_CLASS) reduce 265) ((T_CLASS_C) reduce 265) ((T_CLONE) reduce 265) ((T_CONST) reduce 265) ((T_CONTINUE) reduce 265) ((T_DECLARE) reduce 265) ((T_DEFAULT) reduce 265) ((T_DIR) reduce 265) ((T_DO) reduce 265) ((T_ECHO) reduce 265) ((T_ELSE) reduce 265) ((T_ELSEIF) reduce 265) ((T_EMPTY) reduce 265) ((T_ENDDECLARE) reduce 265) ((T_ENDFOR) reduce 265) ((T_ENDFOREACH) reduce 265) ((T_ENDIF) reduce 265) ((T_ENDSWITCH) reduce 265) ((T_ENDWHILE) reduce 265) ((T_ENUM) reduce 265) ((T_EVAL) reduce 265) ((T_EXIT) reduce 265) ((T_EXTENDS) reduce 265) ((T_FILE) reduce 265) ((T_FINAL) reduce 265) ((T_FINALLY) reduce 265) ((T_FN) reduce 265) ((T_FOR) reduce 265) ((T_FOREACH) reduce 265) ((T_FUNCTION) reduce 265) ((T_FUNC_C) reduce 265) ((T_GLOBAL) reduce 265) ((T_GOTO) reduce 265) ((T_IF) reduce 265) ((T_IMPLEMENTS) reduce 265) ((T_INCLUDE) reduce 265) ((T_INCLUDE_ONCE) reduce 265) ((T_INSTANCEOF) reduce 265) ((T_INSTEADOF) reduce 265) ((T_INTERFACE) reduce 265) ((T_ISSET) reduce 265) ((T_LINE) reduce 265) ((T_LIST) reduce 265) ((T_LOGICAL_AND) reduce 265) ((T_LOGICAL_OR) reduce 265) ((T_LOGICAL_XOR) reduce 265) ((T_MATCH) reduce 265) ((T_METHOD_C) reduce 265) ((T_NAMESPACE) reduce 265) ((T_NEW) reduce 265) ((T_NS_C) reduce 265) ((T_PRINT) reduce 265) ((T_PRIVATE) reduce 265) ((T_PROTECTED) reduce 265) ((T_PUBLIC) reduce 265) ((T_READONLY) reduce 265) ((T_REQUIRE) reduce 265) ((T_REQUIRE_ONCE) reduce 265) ((T_RETURN) reduce 265) ((T_STATIC) reduce 265) ((T_STRING) reduce 265) ((T_SWITCH) reduce 265) ((T_THROW) reduce 265) ((T_TRAIT) reduce 265) ((T_TRAIT_C) reduce 265) ((T_TRY) reduce 265) ((T_UNSET) reduce 265) ((T_USE) reduce 265) ((T_VAR) reduce 265) ((T_WHILE) reduce 265) ((T_YIELD) reduce 265)) 6068 (((",") reduce 354) ((";") reduce 354)) 6070 (((T_ABSTRACT) reduce 272) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 272) ((T_ARRAY) reduce 272) ((T_AS) reduce 272) ((T_BREAK) reduce 272) ((T_CALLABLE) reduce 272) ((T_CASE) reduce 272) ((T_CATCH) reduce 272) ((T_CLASS) reduce 272) ((T_CLASS_C) reduce 272) ((T_CLONE) reduce 272) ((T_CONST) reduce 272) ((T_CONTINUE) reduce 272) ((T_DECLARE) reduce 272) ((T_DEFAULT) reduce 272) ((T_DIR) reduce 272) ((T_DO) reduce 272) ((T_ECHO) reduce 272) ((T_ELSE) reduce 272) ((T_ELSEIF) reduce 272) ((T_EMPTY) reduce 272) ((T_ENDDECLARE) reduce 272) ((T_ENDFOR) reduce 272) ((T_ENDFOREACH) reduce 272) ((T_ENDIF) reduce 272) ((T_ENDSWITCH) reduce 272) ((T_ENDWHILE) reduce 272) ((T_ENUM) reduce 272) ((T_EVAL) reduce 272) ((T_EXIT) reduce 272) ((T_EXTENDS) reduce 272) ((T_FILE) reduce 272) ((T_FINAL) reduce 272) ((T_FINALLY) reduce 272) ((T_FN) reduce 272) ((T_FOR) reduce 272) ((T_FOREACH) reduce 272) ((T_FUNCTION) reduce 272) ((T_FUNC_C) reduce 272) ((T_GLOBAL) reduce 272) ((T_GOTO) reduce 272) ((T_IF) reduce 272) ((T_IMPLEMENTS) reduce 272) ((T_INCLUDE) reduce 272) ((T_INCLUDE_ONCE) reduce 272) ((T_INSTANCEOF) reduce 272) ((T_INSTEADOF) reduce 272) ((T_INTERFACE) reduce 272) ((T_ISSET) reduce 272) ((T_LINE) reduce 272) ((T_LIST) reduce 272) ((T_LOGICAL_AND) reduce 272) ((T_LOGICAL_OR) reduce 272) ((T_LOGICAL_XOR) reduce 272) ((T_MATCH) reduce 272) ((T_METHOD_C) reduce 272) ((T_NAMESPACE) reduce 272) ((T_NEW) reduce 272) ((T_NS_C) reduce 272) ((T_PRINT) reduce 272) ((T_PRIVATE) reduce 272) ((T_PROTECTED) reduce 272) ((T_PUBLIC) reduce 272) ((T_READONLY) reduce 272) ((T_REQUIRE) reduce 272) ((T_REQUIRE_ONCE) reduce 272) ((T_RETURN) reduce 272) ((T_STATIC) reduce 272) ((T_STRING) reduce 272) ((T_SWITCH) reduce 272) ((T_THROW) reduce 272) ((T_TRAIT) reduce 272) ((T_TRAIT_C) reduce 272) ((T_TRY) reduce 272) ((T_UNSET) reduce 272) ((T_USE) reduce 272) ((T_VAR) reduce 272) ((T_WHILE) reduce 272) ((T_YIELD) reduce 272)) 6071 (((T_ABSTRACT) reduce 306) ((T_ATTRIBUTE) reduce 306) ((T_CASE) reduce 306) ((T_CONST) reduce 306) ((T_FINAL) reduce 306) ((T_FUNCTION) reduce 306) ((T_PRIVATE) reduce 306) ((T_PROTECTED) reduce 306) ((T_PUBLIC) reduce 306) ((T_READONLY) reduce 306) ((T_STATIC) reduce 306) ((T_USE) reduce 306) ((T_VAR) reduce 306) (("}") reduce 306)) 6072 (((T_ABSTRACT) reduce 277) ((T_ARRAY) reduce 277) ((T_AS) reduce 277) ((T_BREAK) reduce 277) ((T_CALLABLE) reduce 277) ((T_CASE) reduce 277) ((T_CATCH) reduce 277) ((T_CLASS) reduce 277) ((T_CLASS_C) reduce 277) ((T_CLONE) reduce 277) ((T_CONST) reduce 277) ((T_CONTINUE) reduce 277) ((T_DECLARE) reduce 277) ((T_DEFAULT) reduce 277) ((T_DIR) reduce 277) ((T_DO) reduce 277) ((T_ECHO) reduce 277) ((T_ELSE) reduce 277) ((T_ELSEIF) reduce 277) ((T_EMPTY) reduce 277) ((T_ENDDECLARE) reduce 277) ((T_ENDFOR) reduce 277) ((T_ENDFOREACH) reduce 277) ((T_ENDIF) reduce 277) ((T_ENDSWITCH) reduce 277) ((T_ENDWHILE) reduce 277) ((T_ENUM) reduce 277) ((T_EVAL) reduce 277) ((T_EXIT) reduce 277) ((T_EXTENDS) reduce 277) ((T_FILE) reduce 277) ((T_FINAL) reduce 277) ((T_FINALLY) reduce 277) ((T_FN) reduce 277) ((T_FOR) reduce 277) ((T_FOREACH) reduce 277) ((T_FUNCTION) reduce 277) ((T_FUNC_C) reduce 277) ((T_GLOBAL) reduce 277) ((T_GOTO) reduce 277) ((T_IF) reduce 277) ((T_IMPLEMENTS) reduce 277) ((T_INCLUDE) reduce 277) ((T_INCLUDE_ONCE) reduce 277) ((T_INSTANCEOF) reduce 277) ((T_INSTEADOF) reduce 277) ((T_INTERFACE) reduce 277) ((T_ISSET) reduce 277) ((T_LINE) reduce 277) ((T_LIST) reduce 277) ((T_LOGICAL_AND) reduce 277) ((T_LOGICAL_OR) reduce 277) ((T_LOGICAL_XOR) reduce 277) ((T_MATCH) reduce 277) ((T_METHOD_C) reduce 277) ((T_NAMESPACE) reduce 277) ((T_NEW) reduce 277) ((T_NS_C) reduce 277) ((T_PRINT) reduce 277) ((T_PRIVATE) reduce 277) ((T_PROTECTED) reduce 277) ((T_PUBLIC) reduce 277) ((T_READONLY) reduce 277) ((T_REQUIRE) reduce 277) ((T_REQUIRE_ONCE) reduce 277) ((T_RETURN) reduce 277) ((T_STATIC) reduce 277) ((T_STRING) reduce 277) ((T_SWITCH) reduce 277) ((T_THROW) reduce 277) ((T_TRAIT) reduce 277) ((T_TRAIT_C) reduce 277) ((T_TRY) reduce 277) ((T_UNSET) reduce 277) ((T_USE) reduce 277) ((T_VAR) reduce 277) ((T_WHILE) reduce 277) ((T_YIELD) reduce 277)) 6073 (((T_ABSTRACT) reduce 278) ((T_ARRAY) reduce 278) ((T_AS) reduce 278) ((T_BREAK) reduce 278) ((T_CALLABLE) reduce 278) ((T_CASE) reduce 278) ((T_CATCH) reduce 278) ((T_CLASS) reduce 278) ((T_CLASS_C) reduce 278) ((T_CLONE) reduce 278) ((T_CONST) reduce 278) ((T_CONTINUE) reduce 278) ((T_DECLARE) reduce 278) ((T_DEFAULT) reduce 278) ((T_DIR) reduce 278) ((T_DO) reduce 278) ((T_ECHO) reduce 278) ((T_ELSE) reduce 278) ((T_ELSEIF) reduce 278) ((T_EMPTY) reduce 278) ((T_ENDDECLARE) reduce 278) ((T_ENDFOR) reduce 278) ((T_ENDFOREACH) reduce 278) ((T_ENDIF) reduce 278) ((T_ENDSWITCH) reduce 278) ((T_ENDWHILE) reduce 278) ((T_ENUM) reduce 278) ((T_EVAL) reduce 278) ((T_EXIT) reduce 278) ((T_EXTENDS) reduce 278) ((T_FILE) reduce 278) ((T_FINAL) reduce 278) ((T_FINALLY) reduce 278) ((T_FN) reduce 278) ((T_FOR) reduce 278) ((T_FOREACH) reduce 278) ((T_FUNCTION) reduce 278) ((T_FUNC_C) reduce 278) ((T_GLOBAL) reduce 278) ((T_GOTO) reduce 278) ((T_IF) reduce 278) ((T_IMPLEMENTS) reduce 278) ((T_INCLUDE) reduce 278) ((T_INCLUDE_ONCE) reduce 278) ((T_INSTANCEOF) reduce 278) ((T_INSTEADOF) reduce 278) ((T_INTERFACE) reduce 278) ((T_ISSET) reduce 278) ((T_LINE) reduce 278) ((T_LIST) reduce 278) ((T_LOGICAL_AND) reduce 278) ((T_LOGICAL_OR) reduce 278) ((T_LOGICAL_XOR) reduce 278) ((T_MATCH) reduce 278) ((T_METHOD_C) reduce 278) ((T_NAMESPACE) reduce 278) ((T_NEW) reduce 278) ((T_NS_C) reduce 278) ((T_PRINT) reduce 278) ((T_PRIVATE) reduce 278) ((T_PROTECTED) reduce 278) ((T_PUBLIC) reduce 278) ((T_READONLY) reduce 278) ((T_REQUIRE) reduce 278) ((T_REQUIRE_ONCE) reduce 278) ((T_RETURN) reduce 278) ((T_STATIC) reduce 278) ((T_STRING) reduce 278) ((T_SWITCH) reduce 278) ((T_THROW) reduce 278) ((T_TRAIT) reduce 278) ((T_TRAIT_C) reduce 278) ((T_TRY) reduce 278) ((T_UNSET) reduce 278) ((T_USE) reduce 278) ((T_VAR) reduce 278) ((T_WHILE) reduce 278) ((T_YIELD) reduce 278)) 6074 (((T_ABSTRACT) reduce 93) ((T_ARRAY) reduce 93) ((T_AS) reduce 93) ((T_BREAK) reduce 93) ((T_CALLABLE) reduce 93) ((T_CASE) reduce 93) ((T_CATCH) reduce 93) ((T_CLASS) reduce 93) ((T_CLASS_C) reduce 93) ((T_CLONE) reduce 93) ((T_CONST) reduce 93) ((T_CONTINUE) reduce 93) ((T_DECLARE) reduce 93) ((T_DEFAULT) reduce 93) ((T_DIR) reduce 93) ((T_DO) reduce 93) ((T_ECHO) reduce 93) ((T_ELSE) reduce 93) ((T_ELSEIF) reduce 93) ((T_EMPTY) reduce 93) ((T_ENDDECLARE) reduce 93) ((T_ENDFOR) reduce 93) ((T_ENDFOREACH) reduce 93) ((T_ENDIF) reduce 93) ((T_ENDSWITCH) reduce 93) ((T_ENDWHILE) reduce 93) ((T_ENUM) reduce 93) ((T_EVAL) reduce 93) ((T_EXIT) reduce 93) ((T_EXTENDS) reduce 93) ((T_FILE) reduce 93) ((T_FINAL) reduce 93) ((T_FINALLY) reduce 93) ((T_FN) reduce 93) ((T_FOR) reduce 93) ((T_FOREACH) reduce 93) ((T_FUNCTION) reduce 93) ((T_FUNC_C) reduce 93) ((T_GLOBAL) reduce 93) ((T_GOTO) reduce 93) ((T_IF) reduce 93) ((T_IMPLEMENTS) reduce 93) ((T_INCLUDE) reduce 93) ((T_INCLUDE_ONCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_INSTEADOF) reduce 93) ((T_INTERFACE) reduce 93) ((T_ISSET) reduce 93) ((T_LINE) reduce 93) ((T_LIST) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_MATCH) reduce 93) ((T_METHOD_C) reduce 93) ((T_NAMESPACE) reduce 93) ((T_NEW) reduce 93) ((T_NS_C) reduce 93) ((T_PRINT) reduce 93) ((T_PRIVATE) reduce 93) ((T_PROTECTED) reduce 93) ((T_PUBLIC) reduce 93) ((T_READONLY) reduce 93) ((T_REQUIRE) reduce 93) ((T_REQUIRE_ONCE) reduce 93) ((T_RETURN) reduce 93) ((T_STATIC) reduce 93) ((T_STRING) reduce 93) ((T_SWITCH) reduce 93) ((T_THROW) reduce 93) ((T_TRAIT) reduce 93) ((T_TRAIT_C) reduce 93) ((T_TRY) reduce 93) ((T_UNSET) reduce 93) ((T_USE) reduce 93) ((T_VAR) reduce 93) ((T_WHILE) reduce 93) ((T_YIELD) reduce 93)) 6075 (((T_ABSTRACT) reduce 92) ((T_ARRAY) reduce 92) ((T_AS) reduce 92) ((T_BREAK) reduce 92) ((T_CALLABLE) reduce 92) ((T_CASE) reduce 92) ((T_CATCH) reduce 92) ((T_CLASS) reduce 92) ((T_CLASS_C) reduce 92) ((T_CLONE) reduce 92) ((T_CONST) reduce 92) ((T_CONTINUE) reduce 92) ((T_DECLARE) reduce 92) ((T_DEFAULT) reduce 92) ((T_DIR) reduce 92) ((T_DO) reduce 92) ((T_ECHO) reduce 92) ((T_ELSE) reduce 92) ((T_ELSEIF) reduce 92) ((T_EMPTY) reduce 92) ((T_ENDDECLARE) reduce 92) ((T_ENDFOR) reduce 92) ((T_ENDFOREACH) reduce 92) ((T_ENDIF) reduce 92) ((T_ENDSWITCH) reduce 92) ((T_ENDWHILE) reduce 92) ((T_ENUM) reduce 92) ((T_EVAL) reduce 92) ((T_EXIT) reduce 92) ((T_EXTENDS) reduce 92) ((T_FILE) reduce 92) ((T_FINAL) reduce 92) ((T_FINALLY) reduce 92) ((T_FN) reduce 92) ((T_FOR) reduce 92) ((T_FOREACH) reduce 92) ((T_FUNCTION) reduce 92) ((T_FUNC_C) reduce 92) ((T_GLOBAL) reduce 92) ((T_GOTO) reduce 92) ((T_IF) reduce 92) ((T_IMPLEMENTS) reduce 92) ((T_INCLUDE) reduce 92) ((T_INCLUDE_ONCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_INSTEADOF) reduce 92) ((T_INTERFACE) reduce 92) ((T_ISSET) reduce 92) ((T_LINE) reduce 92) ((T_LIST) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_MATCH) reduce 92) ((T_METHOD_C) reduce 92) ((T_NAMESPACE) reduce 92) ((T_NEW) reduce 92) ((T_NS_C) reduce 92) ((T_PRINT) reduce 92) ((T_PRIVATE) reduce 92) ((T_PROTECTED) reduce 92) ((T_PUBLIC) reduce 92) ((T_READONLY) reduce 92) ((T_REQUIRE) reduce 92) ((T_REQUIRE_ONCE) reduce 92) ((T_RETURN) reduce 92) ((T_STATIC) reduce 92) ((T_STRING) reduce 92) ((T_SWITCH) reduce 92) ((T_THROW) reduce 92) ((T_TRAIT) reduce 92) ((T_TRAIT_C) reduce 92) ((T_TRY) reduce 92) ((T_UNSET) reduce 92) ((T_USE) reduce 92) ((T_VAR) reduce 92) ((T_WHILE) reduce 92) ((T_YIELD) reduce 92)) 6076 (((T_ABSTRACT) reduce 94) ((T_ARRAY) reduce 94) ((T_AS) reduce 94) ((T_BREAK) reduce 94) ((T_CALLABLE) reduce 94) ((T_CASE) reduce 94) ((T_CATCH) reduce 94) ((T_CLASS) reduce 94) ((T_CLASS_C) reduce 94) ((T_CLONE) reduce 94) ((T_CONST) reduce 94) ((T_CONTINUE) reduce 94) ((T_DECLARE) reduce 94) ((T_DEFAULT) reduce 94) ((T_DIR) reduce 94) ((T_DO) reduce 94) ((T_ECHO) reduce 94) ((T_ELSE) reduce 94) ((T_ELSEIF) reduce 94) ((T_EMPTY) reduce 94) ((T_ENDDECLARE) reduce 94) ((T_ENDFOR) reduce 94) ((T_ENDFOREACH) reduce 94) ((T_ENDIF) reduce 94) ((T_ENDSWITCH) reduce 94) ((T_ENDWHILE) reduce 94) ((T_ENUM) reduce 94) ((T_EVAL) reduce 94) ((T_EXIT) reduce 94) ((T_EXTENDS) reduce 94) ((T_FILE) reduce 94) ((T_FINAL) reduce 94) ((T_FINALLY) reduce 94) ((T_FN) reduce 94) ((T_FOR) reduce 94) ((T_FOREACH) reduce 94) ((T_FUNCTION) reduce 94) ((T_FUNC_C) reduce 94) ((T_GLOBAL) reduce 94) ((T_GOTO) reduce 94) ((T_IF) reduce 94) ((T_IMPLEMENTS) reduce 94) ((T_INCLUDE) reduce 94) ((T_INCLUDE_ONCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_INSTEADOF) reduce 94) ((T_INTERFACE) reduce 94) ((T_ISSET) reduce 94) ((T_LINE) reduce 94) ((T_LIST) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_MATCH) reduce 94) ((T_METHOD_C) reduce 94) ((T_NAMESPACE) reduce 94) ((T_NEW) reduce 94) ((T_NS_C) reduce 94) ((T_PRINT) reduce 94) ((T_PRIVATE) reduce 94) ((T_PROTECTED) reduce 94) ((T_PUBLIC) reduce 94) ((T_READONLY) reduce 94) ((T_REQUIRE) reduce 94) ((T_REQUIRE_ONCE) reduce 94) ((T_RETURN) reduce 94) ((T_STATIC) reduce 94) ((T_STRING) reduce 94) ((T_SWITCH) reduce 94) ((T_THROW) reduce 94) ((T_TRAIT) reduce 94) ((T_TRAIT_C) reduce 94) ((T_TRY) reduce 94) ((T_UNSET) reduce 94) ((T_USE) reduce 94) ((T_VAR) reduce 94) ((T_WHILE) reduce 94) ((T_YIELD) reduce 94)) 6077 (((T_ABSTRACT) reduce 266) ((T_ARRAY) reduce 266) ((T_AS) reduce 266) ((T_BREAK) reduce 266) ((T_CALLABLE) reduce 266) ((T_CASE) reduce 266) ((T_CATCH) reduce 266) ((T_CLASS) reduce 266) ((T_CLASS_C) reduce 266) ((T_CLONE) reduce 266) ((T_CONST) reduce 266) ((T_CONTINUE) reduce 266) ((T_DECLARE) reduce 266) ((T_DEFAULT) reduce 266) ((T_DIR) reduce 266) ((T_DO) reduce 266) ((T_ECHO) reduce 266) ((T_ELSE) reduce 266) ((T_ELSEIF) reduce 266) ((T_EMPTY) reduce 266) ((T_ENDDECLARE) reduce 266) ((T_ENDFOR) reduce 266) ((T_ENDFOREACH) reduce 266) ((T_ENDIF) reduce 266) ((T_ENDSWITCH) reduce 266) ((T_ENDWHILE) reduce 266) ((T_ENUM) reduce 266) ((T_EVAL) reduce 266) ((T_EXIT) reduce 266) ((T_EXTENDS) reduce 266) ((T_FILE) reduce 266) ((T_FINAL) reduce 266) ((T_FINALLY) reduce 266) ((T_FN) reduce 266) ((T_FOR) reduce 266) ((T_FOREACH) reduce 266) ((T_FUNCTION) reduce 266) ((T_FUNC_C) reduce 266) ((T_GLOBAL) reduce 266) ((T_GOTO) reduce 266) ((T_IF) reduce 266) ((T_IMPLEMENTS) reduce 266) ((T_INCLUDE) reduce 266) ((T_INCLUDE_ONCE) reduce 266) ((T_INSTANCEOF) reduce 266) ((T_INSTEADOF) reduce 266) ((T_INTERFACE) reduce 266) ((T_ISSET) reduce 266) ((T_LINE) reduce 266) ((T_LIST) reduce 266) ((T_LOGICAL_AND) reduce 266) ((T_LOGICAL_OR) reduce 266) ((T_LOGICAL_XOR) reduce 266) ((T_MATCH) reduce 266) ((T_METHOD_C) reduce 266) ((T_NAMESPACE) reduce 266) ((T_NEW) reduce 266) ((T_NS_C) reduce 266) ((T_PRINT) reduce 266) ((T_PRIVATE) reduce 266) ((T_PROTECTED) reduce 266) ((T_PUBLIC) reduce 266) ((T_READONLY) reduce 266) ((T_REQUIRE) reduce 266) ((T_REQUIRE_ONCE) reduce 266) ((T_RETURN) reduce 266) ((T_STATIC) reduce 266) ((T_STRING) reduce 266) ((T_SWITCH) reduce 266) ((T_THROW) reduce 266) ((T_TRAIT) reduce 266) ((T_TRAIT_C) reduce 266) ((T_TRY) reduce 266) ((T_UNSET) reduce 266) ((T_USE) reduce 266) ((T_VAR) reduce 266) ((T_WHILE) reduce 266) ((T_YIELD) reduce 266)) 6078 (((T_ABSTRACT) reduce 91) ((T_ARRAY) reduce 91) ((T_AS) reduce 91) ((T_BREAK) reduce 91) ((T_CALLABLE) reduce 91) ((T_CASE) reduce 91) ((T_CATCH) reduce 91) ((T_CLASS) reduce 91) ((T_CLASS_C) reduce 91) ((T_CLONE) reduce 91) ((T_CONST) reduce 91) ((T_CONTINUE) reduce 91) ((T_DECLARE) reduce 91) ((T_DEFAULT) reduce 91) ((T_DIR) reduce 91) ((T_DO) reduce 91) ((T_ECHO) reduce 91) ((T_ELSE) reduce 91) ((T_ELSEIF) reduce 91) ((T_EMPTY) reduce 91) ((T_ENDDECLARE) reduce 91) ((T_ENDFOR) reduce 91) ((T_ENDFOREACH) reduce 91) ((T_ENDIF) reduce 91) ((T_ENDSWITCH) reduce 91) ((T_ENDWHILE) reduce 91) ((T_ENUM) reduce 91) ((T_EVAL) reduce 91) ((T_EXIT) reduce 91) ((T_EXTENDS) reduce 91) ((T_FILE) reduce 91) ((T_FINAL) reduce 91) ((T_FINALLY) reduce 91) ((T_FN) reduce 91) ((T_FOR) reduce 91) ((T_FOREACH) reduce 91) ((T_FUNCTION) reduce 91) ((T_FUNC_C) reduce 91) ((T_GLOBAL) reduce 91) ((T_GOTO) reduce 91) ((T_IF) reduce 91) ((T_IMPLEMENTS) reduce 91) ((T_INCLUDE) reduce 91) ((T_INCLUDE_ONCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_INSTEADOF) reduce 91) ((T_INTERFACE) reduce 91) ((T_ISSET) reduce 91) ((T_LINE) reduce 91) ((T_LIST) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_MATCH) reduce 91) ((T_METHOD_C) reduce 91) ((T_NAMESPACE) reduce 91) ((T_NEW) reduce 91) ((T_NS_C) reduce 91) ((T_PRINT) reduce 91) ((T_PRIVATE) reduce 91) ((T_PROTECTED) reduce 91) ((T_PUBLIC) reduce 91) ((T_READONLY) reduce 91) ((T_REQUIRE) reduce 91) ((T_REQUIRE_ONCE) reduce 91) ((T_RETURN) reduce 91) ((T_STATIC) reduce 91) ((T_STRING) reduce 91) ((T_SWITCH) reduce 91) ((T_THROW) reduce 91) ((T_TRAIT) reduce 91) ((T_TRAIT_C) reduce 91) ((T_TRY) reduce 91) ((T_UNSET) reduce 91) ((T_USE) reduce 91) ((T_VAR) reduce 91) ((T_WHILE) reduce 91) ((T_YIELD) reduce 91)) 6079 (((T_ABSTRACT) reduce 279) ((T_ARRAY) reduce 279) ((T_AS) reduce 279) ((T_BREAK) reduce 279) ((T_CALLABLE) reduce 279) ((T_CASE) reduce 279) ((T_CATCH) reduce 279) ((T_CLASS) reduce 279) ((T_CLASS_C) reduce 279) ((T_CLONE) reduce 279) ((T_CONST) reduce 279) ((T_CONTINUE) reduce 279) ((T_DECLARE) reduce 279) ((T_DEFAULT) reduce 279) ((T_DIR) reduce 279) ((T_DO) reduce 279) ((T_ECHO) reduce 279) ((T_ELSE) reduce 279) ((T_ELSEIF) reduce 279) ((T_EMPTY) reduce 279) ((T_ENDDECLARE) reduce 279) ((T_ENDFOR) reduce 279) ((T_ENDFOREACH) reduce 279) ((T_ENDIF) reduce 279) ((T_ENDSWITCH) reduce 279) ((T_ENDWHILE) reduce 279) ((T_ENUM) reduce 279) ((T_EVAL) reduce 279) ((T_EXIT) reduce 279) ((T_EXTENDS) reduce 279) ((T_FILE) reduce 279) ((T_FINAL) reduce 279) ((T_FINALLY) reduce 279) ((T_FN) reduce 279) ((T_FOR) reduce 279) ((T_FOREACH) reduce 279) ((T_FUNCTION) reduce 279) ((T_FUNC_C) reduce 279) ((T_GLOBAL) reduce 279) ((T_GOTO) reduce 279) ((T_IF) reduce 279) ((T_IMPLEMENTS) reduce 279) ((T_INCLUDE) reduce 279) ((T_INCLUDE_ONCE) reduce 279) ((T_INSTANCEOF) reduce 279) ((T_INSTEADOF) reduce 279) ((T_INTERFACE) reduce 279) ((T_ISSET) reduce 279) ((T_LINE) reduce 279) ((T_LIST) reduce 279) ((T_LOGICAL_AND) reduce 279) ((T_LOGICAL_OR) reduce 279) ((T_LOGICAL_XOR) reduce 279) ((T_MATCH) reduce 279) ((T_METHOD_C) reduce 279) ((T_NAMESPACE) reduce 279) ((T_NEW) reduce 279) ((T_NS_C) reduce 279) ((T_PRINT) reduce 279) ((T_PRIVATE) reduce 279) ((T_PROTECTED) reduce 279) ((T_PUBLIC) reduce 279) ((T_READONLY) reduce 279) ((T_REQUIRE) reduce 279) ((T_REQUIRE_ONCE) reduce 279) ((T_RETURN) reduce 279) ((T_STATIC) reduce 279) ((T_STRING) reduce 279) ((T_SWITCH) reduce 279) ((T_THROW) reduce 279) ((T_TRAIT) reduce 279) ((T_TRAIT_C) reduce 279) ((T_TRY) reduce 279) ((T_UNSET) reduce 279) ((T_USE) reduce 279) ((T_VAR) reduce 279) ((T_WHILE) reduce 279) ((T_YIELD) reduce 279)) 6080 (((T_ABSTRACT) reduce 262) ((T_ARRAY) reduce 262) ((T_AS) reduce 262) ((T_BREAK) reduce 262) ((T_CALLABLE) reduce 262) ((T_CASE) reduce 262) ((T_CATCH) reduce 262) ((T_CLASS) reduce 262) ((T_CLASS_C) reduce 262) ((T_CLONE) reduce 262) ((T_CONST) reduce 262) ((T_CONTINUE) reduce 262) ((T_DECLARE) reduce 262) ((T_DEFAULT) reduce 262) ((T_DIR) reduce 262) ((T_DO) reduce 262) ((T_ECHO) reduce 262) ((T_ELSE) reduce 262) ((T_ELSEIF) reduce 262) ((T_EMPTY) reduce 262) ((T_ENDDECLARE) reduce 262) ((T_ENDFOR) reduce 262) ((T_ENDFOREACH) reduce 262) ((T_ENDIF) reduce 262) ((T_ENDSWITCH) reduce 262) ((T_ENDWHILE) reduce 262) ((T_ENUM) reduce 262) ((T_EVAL) reduce 262) ((T_EXIT) reduce 262) ((T_EXTENDS) reduce 262) ((T_FILE) reduce 262) ((T_FINAL) reduce 262) ((T_FINALLY) reduce 262) ((T_FN) reduce 262) ((T_FOR) reduce 262) ((T_FOREACH) reduce 262) ((T_FUNCTION) reduce 262) ((T_FUNC_C) reduce 262) ((T_GLOBAL) reduce 262) ((T_GOTO) reduce 262) ((T_IF) reduce 262) ((T_IMPLEMENTS) reduce 262) ((T_INCLUDE) reduce 262) ((T_INCLUDE_ONCE) reduce 262) ((T_INSTANCEOF) reduce 262) ((T_INSTEADOF) reduce 262) ((T_INTERFACE) reduce 262) ((T_ISSET) reduce 262) ((T_LINE) reduce 262) ((T_LIST) reduce 262) ((T_LOGICAL_AND) reduce 262) ((T_LOGICAL_OR) reduce 262) ((T_LOGICAL_XOR) reduce 262) ((T_MATCH) reduce 262) ((T_METHOD_C) reduce 262) ((T_NAMESPACE) reduce 262) ((T_NEW) reduce 262) ((T_NS_C) reduce 262) ((T_PRINT) reduce 262) ((T_PRIVATE) reduce 262) ((T_PROTECTED) reduce 262) ((T_PUBLIC) reduce 262) ((T_READONLY) reduce 262) ((T_REQUIRE) reduce 262) ((T_REQUIRE_ONCE) reduce 262) ((T_RETURN) reduce 262) ((T_STATIC) reduce 262) ((T_STRING) reduce 262) ((T_SWITCH) reduce 262) ((T_THROW) reduce 262) ((T_TRAIT) reduce 262) ((T_TRAIT_C) reduce 262) ((T_TRY) reduce 262) ((T_UNSET) reduce 262) ((T_USE) reduce 262) ((T_VAR) reduce 262) ((T_WHILE) reduce 262) ((T_YIELD) reduce 262)) 6081 (((T_ABSTRACT) reduce 265) ((T_ARRAY) reduce 265) ((T_AS) reduce 265) ((T_BREAK) reduce 265) ((T_CALLABLE) reduce 265) ((T_CASE) reduce 265) ((T_CATCH) reduce 265) ((T_CLASS) reduce 265) ((T_CLASS_C) reduce 265) ((T_CLONE) reduce 265) ((T_CONST) reduce 265) ((T_CONTINUE) reduce 265) ((T_DECLARE) reduce 265) ((T_DEFAULT) reduce 265) ((T_DIR) reduce 265) ((T_DO) reduce 265) ((T_ECHO) reduce 265) ((T_ELSE) reduce 265) ((T_ELSEIF) reduce 265) ((T_EMPTY) reduce 265) ((T_ENDDECLARE) reduce 265) ((T_ENDFOR) reduce 265) ((T_ENDFOREACH) reduce 265) ((T_ENDIF) reduce 265) ((T_ENDSWITCH) reduce 265) ((T_ENDWHILE) reduce 265) ((T_ENUM) reduce 265) ((T_EVAL) reduce 265) ((T_EXIT) reduce 265) ((T_EXTENDS) reduce 265) ((T_FILE) reduce 265) ((T_FINAL) reduce 265) ((T_FINALLY) reduce 265) ((T_FN) reduce 265) ((T_FOR) reduce 265) ((T_FOREACH) reduce 265) ((T_FUNCTION) reduce 265) ((T_FUNC_C) reduce 265) ((T_GLOBAL) reduce 265) ((T_GOTO) reduce 265) ((T_IF) reduce 265) ((T_IMPLEMENTS) reduce 265) ((T_INCLUDE) reduce 265) ((T_INCLUDE_ONCE) reduce 265) ((T_INSTANCEOF) reduce 265) ((T_INSTEADOF) reduce 265) ((T_INTERFACE) reduce 265) ((T_ISSET) reduce 265) ((T_LINE) reduce 265) ((T_LIST) reduce 265) ((T_LOGICAL_AND) reduce 265) ((T_LOGICAL_OR) reduce 265) ((T_LOGICAL_XOR) reduce 265) ((T_MATCH) reduce 265) ((T_METHOD_C) reduce 265) ((T_NAMESPACE) reduce 265) ((T_NEW) reduce 265) ((T_NS_C) reduce 265) ((T_PRINT) reduce 265) ((T_PRIVATE) reduce 265) ((T_PROTECTED) reduce 265) ((T_PUBLIC) reduce 265) ((T_READONLY) reduce 265) ((T_REQUIRE) reduce 265) ((T_REQUIRE_ONCE) reduce 265) ((T_RETURN) reduce 265) ((T_STATIC) reduce 265) ((T_STRING) reduce 265) ((T_SWITCH) reduce 265) ((T_THROW) reduce 265) ((T_TRAIT) reduce 265) ((T_TRAIT_C) reduce 265) ((T_TRY) reduce 265) ((T_UNSET) reduce 265) ((T_USE) reduce 265) ((T_VAR) reduce 265) ((T_WHILE) reduce 265) ((T_YIELD) reduce 265)) 6082 (((T_ABSTRACT) reduce 101) ((T_ATTRIBUTE) reduce 101) ((T_CASE) reduce 101) ((T_CONST) reduce 101) ((T_FINAL) reduce 101) ((T_FUNCTION) reduce 101) ((T_PRIVATE) reduce 101) ((T_PROTECTED) reduce 101) ((T_PUBLIC) reduce 101) ((T_READONLY) reduce 101) ((T_STATIC) reduce 101) ((T_VAR) reduce 101)) 6083 (((T_ABSTRACT) reduce 311) ((T_ATTRIBUTE) reduce 311) ((T_CASE) reduce 311) ((T_CONST) reduce 311) ((T_FINAL) reduce 311) ((T_FUNCTION) reduce 311) ((T_PRIVATE) reduce 311) ((T_PROTECTED) reduce 311) ((T_PUBLIC) reduce 311) ((T_READONLY) reduce 311) ((T_STATIC) reduce 311) ((T_USE) reduce 311) ((T_VAR) reduce 311) (("}") reduce 311)) 6084 (((",") reduce 93) ((";") reduce 93) (("{") reduce 93)) 6085 (((",") reduce 92) ((";") reduce 92) (("{") reduce 92)) 6086 (((",") reduce 94) ((";") reduce 94) (("{") reduce 94)) 6087 (((",") reduce 470) ((";") reduce 470) (("{") reduce 470)) 6088 (((",") reduce 91) ((";") reduce 91) (("{") reduce 91)) 6089 (((",") reduce 313) ((";") reduce 313) (("{") reduce 313)) 6090 (((",") shift) ((";") shift) (("{") shift)) 6091 (((",") reduce 471) ((";") reduce 471) (("{") reduce 471)) 6093 (((T_ABSTRACT) reduce 315) ((T_ATTRIBUTE) reduce 315) ((T_CASE) reduce 315) ((T_CONST) reduce 315) ((T_FINAL) reduce 315) ((T_FUNCTION) reduce 315) ((T_PRIVATE) reduce 315) ((T_PROTECTED) reduce 315) ((T_PUBLIC) reduce 315) ((T_READONLY) reduce 315) ((T_STATIC) reduce 315) ((T_USE) reduce 315) ((T_VAR) reduce 315) (("}") reduce 315)) 6094 (((T_ABSTRACT) reduce 312) ((T_ATTRIBUTE) reduce 312) ((T_CASE) reduce 312) ((T_CONST) reduce 312) ((T_FINAL) reduce 312) ((T_FUNCTION) reduce 312) ((T_PRIVATE) reduce 312) ((T_PROTECTED) reduce 312) ((T_PUBLIC) reduce 312) ((T_READONLY) reduce 312) ((T_STATIC) reduce 312) ((T_USE) reduce 312) ((T_VAR) reduce 312) (("}") reduce 312)) 6095 (((T_ABSTRACT) shift) ((T_ARRAY) shift) ((T_AS) shift) ((T_BREAK) shift) ((T_CALLABLE) shift) ((T_CASE) shift) ((T_CATCH) shift) ((T_CLASS) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONST) shift) ((T_CONTINUE) shift) ((T_DECLARE) shift) ((T_DEFAULT) shift) ((T_DIR) shift) ((T_DO) shift) ((T_ECHO) shift) ((T_ELSE) shift) ((T_ELSEIF) shift) ((T_EMPTY) shift) ((T_ENDDECLARE) shift) ((T_ENDFOR) shift) ((T_ENDFOREACH) shift) ((T_ENDIF) shift) ((T_ENDSWITCH) shift) ((T_ENDWHILE) shift) ((T_ENUM) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_EXTENDS) shift) ((T_FILE) shift) ((T_FINAL) shift) ((T_FINALLY) shift) ((T_FN) shift) ((T_FOR) shift) ((T_FOREACH) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_GLOBAL) shift) ((T_GOTO) shift) ((T_IF) shift) ((T_IMPLEMENTS) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INSTANCEOF) shift) ((T_INSTEADOF) shift) ((T_INTERFACE) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAMESPACE) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_PRINT) shift) ((T_PRIVATE) shift) ((T_PROTECTED) shift) ((T_PUBLIC) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_RETURN) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_SWITCH) shift) ((T_THROW) shift) ((T_TRAIT) shift) ((T_TRAIT_C) shift) ((T_TRY) shift) ((T_UNSET) shift) ((T_USE) shift) ((T_VAR) shift) ((T_WHILE) shift) ((T_YIELD) shift) (("}") shift)) 6096 (((T_AS) reduce 73)) 6097 (((T_AS) reduce 52)) 6098 (((T_AS) reduce 27)) 6099 (((T_AS) reduce 51)) 6100 (((T_AS) reduce 53)) 6101 (((T_AS) reduce 49)) 6102 (((T_AS) reduce 29)) 6103 (((T_AS) reduce 59)) 6104 (((T_AS) reduce 60)) 6105 (((T_AS) reduce 11)) 6106 (((T_AS) reduce 42)) 6107 (((T_AS) reduce 39)) 6108 (((T_AS) reduce 25)) 6109 (((T_AS) reduce 50)) 6110 (((T_AS) reduce 66)) 6111 (((T_AS) reduce 18)) 6112 (((T_AS) reduce 17)) 6113 (((T_AS) reduce 15)) 6114 (((T_AS) reduce 14)) 6115 (((T_AS) reduce 38)) 6116 (((T_AS) reduce 26)) 6117 (((T_AS) reduce 22)) 6118 (((T_AS) reduce 24)) 6119 (((T_AS) reduce 16)) 6120 (((T_AS) reduce 48)) 6121 (((T_AS) reduce 20)) 6122 (((T_AS) reduce 70)) 6123 (((T_AS) reduce 3)) 6124 (((T_AS) reduce 12)) 6125 (((T_AS) reduce 54)) 6126 (((T_AS) reduce 65)) 6127 (((T_AS) reduce 74)) 6128 (((T_AS) reduce 30)) 6129 (((T_AS) reduce 68)) 6130 (((T_AS) reduce 21)) 6131 (((T_AS) reduce 23)) 6132 (((T_AS) reduce 41)) 6133 (((T_AS) reduce 62)) 6134 (((T_AS) reduce 34)) 6135 (((T_AS) reduce 40)) 6136 (((T_AS) reduce 13)) 6137 (((T_AS) reduce 55)) 6138 (((T_AS) reduce 1)) 6139 (((T_AS) reduce 2)) 6140 (((T_AS) reduce 9)) 6141 (((T_AS) reduce 33)) 6142 (((T_AS) reduce 58)) 6143 (((T_AS) reduce 37)) 6144 (((T_AS) reduce 64)) 6145 (((T_AS) reduce 46)) 6146 (((T_AS) reduce 8)) 6147 (((T_AS) reduce 6)) 6148 (((T_AS) reduce 7)) 6149 (((T_AS) reduce 69)) 6150 (((T_AS) reduce 63)) 6151 (((T_AS) reduce 56)) 6152 (((T_PAAMAYIM_NEKUDOTAYIM) reduce 93)) 6153 (((T_PAAMAYIM_NEKUDOTAYIM) reduce 92)) 6154 (((T_PAAMAYIM_NEKUDOTAYIM) reduce 94)) 6155 (((T_AS) reduce 10)) 6156 (((T_AS) reduce 67)) 6157 (((T_AS) reduce 44)) 6158 (((T_AS) reduce 75)) 6159 (((T_AS) reduce 76)) 6160 (((T_AS) reduce 77)) 6161 (((T_AS) reduce 78)) 6162 (((T_AS) reduce 4)) 6163 (((T_AS) reduce 5)) 6164 (((T_AS) reduce 43)) 6165 (((T_AS) reduce 72) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470)) 6166 (((T_AS) reduce 81) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91)) 6167 (((T_AS) reduce 47)) 6168 (((T_AS) reduce 31)) 6169 (((T_AS) reduce 57)) 6170 (((T_AS) reduce 61)) 6171 (((T_AS) reduce 28)) 6172 (((T_AS) reduce 36)) 6173 (((T_AS) reduce 32)) 6174 (((T_AS) reduce 35)) 6175 (((T_AS) reduce 19)) 6176 (((T_AS) reduce 45)) 6177 (((T_AS) reduce 328) ((T_INSTEADOF) shift)) 6179 (((T_AS) reduce 327)) 6180 (((T_PAAMAYIM_NEKUDOTAYIM) reduce 471)) 6181 (((T_AS) reduce 71)) 6182 (((T_AS) reduce 82)) 6183 (((T_ABSTRACT) reduce 318) ((T_ARRAY) reduce 318) ((T_AS) reduce 318) ((T_BREAK) reduce 318) ((T_CALLABLE) reduce 318) ((T_CASE) reduce 318) ((T_CATCH) reduce 318) ((T_CLASS) reduce 318) ((T_CLASS_C) reduce 318) ((T_CLONE) reduce 318) ((T_CONST) reduce 318) ((T_CONTINUE) reduce 318) ((T_DECLARE) reduce 318) ((T_DEFAULT) reduce 318) ((T_DIR) reduce 318) ((T_DO) reduce 318) ((T_ECHO) reduce 318) ((T_ELSE) reduce 318) ((T_ELSEIF) reduce 318) ((T_EMPTY) reduce 318) ((T_ENDDECLARE) reduce 318) ((T_ENDFOR) reduce 318) ((T_ENDFOREACH) reduce 318) ((T_ENDIF) reduce 318) ((T_ENDSWITCH) reduce 318) ((T_ENDWHILE) reduce 318) ((T_ENUM) reduce 318) ((T_EVAL) reduce 318) ((T_EXIT) reduce 318) ((T_EXTENDS) reduce 318) ((T_FILE) reduce 318) ((T_FINAL) reduce 318) ((T_FINALLY) reduce 318) ((T_FN) reduce 318) ((T_FOR) reduce 318) ((T_FOREACH) reduce 318) ((T_FUNCTION) reduce 318) ((T_FUNC_C) reduce 318) ((T_GLOBAL) reduce 318) ((T_GOTO) reduce 318) ((T_IF) reduce 318) ((T_IMPLEMENTS) reduce 318) ((T_INCLUDE) reduce 318) ((T_INCLUDE_ONCE) reduce 318) ((T_INSTANCEOF) reduce 318) ((T_INSTEADOF) reduce 318) ((T_INTERFACE) reduce 318) ((T_ISSET) reduce 318) ((T_LINE) reduce 318) ((T_LIST) reduce 318) ((T_LOGICAL_AND) reduce 318) ((T_LOGICAL_OR) reduce 318) ((T_LOGICAL_XOR) reduce 318) ((T_MATCH) reduce 318) ((T_METHOD_C) reduce 318) ((T_NAMESPACE) reduce 318) ((T_NAME_FULLY_QUALIFIED) reduce 318) ((T_NAME_QUALIFIED) reduce 318) ((T_NAME_RELATIVE) reduce 318) ((T_NEW) reduce 318) ((T_NS_C) reduce 318) ((T_PRINT) reduce 318) ((T_PRIVATE) reduce 318) ((T_PROTECTED) reduce 318) ((T_PUBLIC) reduce 318) ((T_READONLY) reduce 318) ((T_REQUIRE) reduce 318) ((T_REQUIRE_ONCE) reduce 318) ((T_RETURN) reduce 318) ((T_STATIC) reduce 318) ((T_STRING) reduce 318) ((T_SWITCH) reduce 318) ((T_THROW) reduce 318) ((T_TRAIT) reduce 318) ((T_TRAIT_C) reduce 318) ((T_TRY) reduce 318) ((T_UNSET) reduce 318) ((T_USE) reduce 318) ((T_VAR) reduce 318) ((T_WHILE) reduce 318) ((T_YIELD) reduce 318) (("}") reduce 318)) 6185 (((";") shift)) 6186 (((T_AS) shift)) 6188 (((T_ABSTRACT) reduce 316) ((T_ATTRIBUTE) reduce 316) ((T_CASE) reduce 316) ((T_CONST) reduce 316) ((T_FINAL) reduce 316) ((T_FUNCTION) reduce 316) ((T_PRIVATE) reduce 316) ((T_PROTECTED) reduce 316) ((T_PUBLIC) reduce 316) ((T_READONLY) reduce 316) ((T_STATIC) reduce 316) ((T_USE) reduce 316) ((T_VAR) reduce 316) (("}") reduce 316)) 6189 (((T_ABSTRACT) reduce 320) ((T_ARRAY) reduce 320) ((T_AS) reduce 320) ((T_BREAK) reduce 320) ((T_CALLABLE) reduce 320) ((T_CASE) reduce 320) ((T_CATCH) reduce 320) ((T_CLASS) reduce 320) ((T_CLASS_C) reduce 320) ((T_CLONE) reduce 320) ((T_CONST) reduce 320) ((T_CONTINUE) reduce 320) ((T_DECLARE) reduce 320) ((T_DEFAULT) reduce 320) ((T_DIR) reduce 320) ((T_DO) reduce 320) ((T_ECHO) reduce 320) ((T_ELSE) reduce 320) ((T_ELSEIF) reduce 320) ((T_EMPTY) reduce 320) ((T_ENDDECLARE) reduce 320) ((T_ENDFOR) reduce 320) ((T_ENDFOREACH) reduce 320) ((T_ENDIF) reduce 320) ((T_ENDSWITCH) reduce 320) ((T_ENDWHILE) reduce 320) ((T_ENUM) reduce 320) ((T_EVAL) reduce 320) ((T_EXIT) reduce 320) ((T_EXTENDS) reduce 320) ((T_FILE) reduce 320) ((T_FINAL) reduce 320) ((T_FINALLY) reduce 320) ((T_FN) reduce 320) ((T_FOR) reduce 320) ((T_FOREACH) reduce 320) ((T_FUNCTION) reduce 320) ((T_FUNC_C) reduce 320) ((T_GLOBAL) reduce 320) ((T_GOTO) reduce 320) ((T_IF) reduce 320) ((T_IMPLEMENTS) reduce 320) ((T_INCLUDE) reduce 320) ((T_INCLUDE_ONCE) reduce 320) ((T_INSTANCEOF) reduce 320) ((T_INSTEADOF) reduce 320) ((T_INTERFACE) reduce 320) ((T_ISSET) reduce 320) ((T_LINE) reduce 320) ((T_LIST) reduce 320) ((T_LOGICAL_AND) reduce 320) ((T_LOGICAL_OR) reduce 320) ((T_LOGICAL_XOR) reduce 320) ((T_MATCH) reduce 320) ((T_METHOD_C) reduce 320) ((T_NAMESPACE) reduce 320) ((T_NAME_FULLY_QUALIFIED) reduce 320) ((T_NAME_QUALIFIED) reduce 320) ((T_NAME_RELATIVE) reduce 320) ((T_NEW) reduce 320) ((T_NS_C) reduce 320) ((T_PRINT) reduce 320) ((T_PRIVATE) reduce 320) ((T_PROTECTED) reduce 320) ((T_PUBLIC) reduce 320) ((T_READONLY) reduce 320) ((T_REQUIRE) reduce 320) ((T_REQUIRE_ONCE) reduce 320) ((T_RETURN) reduce 320) ((T_STATIC) reduce 320) ((T_STRING) reduce 320) ((T_SWITCH) reduce 320) ((T_THROW) reduce 320) ((T_TRAIT) reduce 320) ((T_TRAIT_C) reduce 320) ((T_TRY) reduce 320) ((T_UNSET) reduce 320) ((T_USE) reduce 320) ((T_VAR) reduce 320) ((T_WHILE) reduce 320) ((T_YIELD) reduce 320) (("}") reduce 320)) 6191 (((";") reduce 344) ((T_ABSTRACT) reduce 344) ((T_ARRAY) reduce 344) ((T_AS) reduce 344) ((T_BREAK) reduce 344) ((T_CALLABLE) reduce 344) ((T_CASE) reduce 344) ((T_CATCH) reduce 344) ((T_CLASS) reduce 344) ((T_CLASS_C) reduce 344) ((T_CLONE) reduce 344) ((T_CONST) reduce 344) ((T_CONTINUE) reduce 344) ((T_DECLARE) reduce 344) ((T_DEFAULT) reduce 344) ((T_DIR) reduce 344) ((T_DO) reduce 344) ((T_ECHO) reduce 344) ((T_ELSE) reduce 344) ((T_ELSEIF) reduce 344) ((T_EMPTY) reduce 344) ((T_ENDDECLARE) reduce 344) ((T_ENDFOR) reduce 344) ((T_ENDFOREACH) reduce 344) ((T_ENDIF) reduce 344) ((T_ENDSWITCH) reduce 344) ((T_ENDWHILE) reduce 344) ((T_ENUM) reduce 344) ((T_EVAL) reduce 344) ((T_EXIT) reduce 344) ((T_EXTENDS) reduce 344) ((T_FILE) reduce 344) ((T_FINAL) reduce 344) ((T_FINALLY) reduce 344) ((T_FN) reduce 344) ((T_FOR) reduce 344) ((T_FOREACH) reduce 344) ((T_FUNCTION) reduce 344) ((T_FUNC_C) reduce 344) ((T_GLOBAL) reduce 344) ((T_GOTO) reduce 344) ((T_IF) reduce 344) ((T_IMPLEMENTS) reduce 344) ((T_INCLUDE) reduce 344) ((T_INCLUDE_ONCE) reduce 344) ((T_INSTANCEOF) reduce 344) ((T_INSTEADOF) reduce 344) ((T_INTERFACE) reduce 344) ((T_ISSET) reduce 344) ((T_LINE) reduce 344) ((T_LIST) reduce 344) ((T_LOGICAL_AND) reduce 344) ((T_LOGICAL_OR) reduce 344) ((T_LOGICAL_XOR) reduce 344) ((T_MATCH) reduce 344) ((T_METHOD_C) reduce 344) ((T_NAMESPACE) reduce 344) ((T_NEW) reduce 344) ((T_NS_C) reduce 344) ((T_PRINT) reduce 344) ((T_PRIVATE) reduce 344) ((T_PROTECTED) reduce 344) ((T_PUBLIC) reduce 344) ((T_READONLY) reduce 344) ((T_REQUIRE) reduce 344) ((T_REQUIRE_ONCE) reduce 344) ((T_RETURN) reduce 344) ((T_STATIC) reduce 344) ((T_STRING) reduce 344) ((T_SWITCH) reduce 344) ((T_THROW) reduce 344) ((T_TRAIT) reduce 344) ((T_TRAIT_C) reduce 344) ((T_TRY) reduce 344) ((T_UNSET) reduce 344) ((T_USE) reduce 344) ((T_VAR) reduce 344) ((T_WHILE) reduce 344) ((T_YIELD) reduce 344)) 6192 (((";") reduce 52)) 6193 (((";") reduce 27)) 6194 (((";") reduce 51)) 6195 (((";") reduce 53)) 6196 (((";") reduce 49)) 6197 (((";") reduce 29)) 6198 (((";") reduce 59)) 6199 (((";") reduce 60)) 6200 (((";") reduce 11)) 6201 (((";") reduce 42)) 6202 (((";") reduce 39)) 6203 (((";") reduce 25)) 6204 (((";") reduce 50)) 6205 (((";") reduce 66)) 6206 (((";") reduce 18)) 6207 (((";") reduce 17)) 6208 (((";") reduce 15)) 6209 (((";") reduce 14)) 6210 (((";") reduce 38)) 6211 (((";") reduce 26)) 6212 (((";") reduce 22)) 6213 (((";") reduce 24)) 6214 (((";") reduce 16)) 6215 (((";") reduce 48)) 6216 (((";") reduce 20)) 6217 (((";") reduce 70)) 6218 (((";") reduce 3)) 6219 (((";") reduce 12)) 6220 (((";") reduce 54)) 6221 (((";") reduce 65)) 6222 (((";") reduce 345) ((T_ABSTRACT) reduce 345) ((T_ARRAY) reduce 345) ((T_AS) reduce 345) ((T_BREAK) reduce 345) ((T_CALLABLE) reduce 345) ((T_CASE) reduce 345) ((T_CATCH) reduce 345) ((T_CLASS) reduce 345) ((T_CLASS_C) reduce 345) ((T_CLONE) reduce 345) ((T_CONST) reduce 345) ((T_CONTINUE) reduce 345) ((T_DECLARE) reduce 345) ((T_DEFAULT) reduce 345) ((T_DIR) reduce 345) ((T_DO) reduce 345) ((T_ECHO) reduce 345) ((T_ELSE) reduce 345) ((T_ELSEIF) reduce 345) ((T_EMPTY) reduce 345) ((T_ENDDECLARE) reduce 345) ((T_ENDFOR) reduce 345) ((T_ENDFOREACH) reduce 345) ((T_ENDIF) reduce 345) ((T_ENDSWITCH) reduce 345) ((T_ENDWHILE) reduce 345) ((T_ENUM) reduce 345) ((T_EVAL) reduce 345) ((T_EXIT) reduce 345) ((T_EXTENDS) reduce 345) ((T_FILE) reduce 345) ((T_FINAL) reduce 345) ((T_FINALLY) reduce 345) ((T_FN) reduce 345) ((T_FOR) reduce 345) ((T_FOREACH) reduce 345) ((T_FUNCTION) reduce 345) ((T_FUNC_C) reduce 345) ((T_GLOBAL) reduce 345) ((T_GOTO) reduce 345) ((T_IF) reduce 345) ((T_IMPLEMENTS) reduce 345) ((T_INCLUDE) reduce 345) ((T_INCLUDE_ONCE) reduce 345) ((T_INSTANCEOF) reduce 345) ((T_INSTEADOF) reduce 345) ((T_INTERFACE) reduce 345) ((T_ISSET) reduce 345) ((T_LINE) reduce 345) ((T_LIST) reduce 345) ((T_LOGICAL_AND) reduce 345) ((T_LOGICAL_OR) reduce 345) ((T_LOGICAL_XOR) reduce 345) ((T_MATCH) reduce 345) ((T_METHOD_C) reduce 345) ((T_NAMESPACE) reduce 345) ((T_NEW) reduce 345) ((T_NS_C) reduce 345) ((T_PRINT) reduce 345) ((T_PRIVATE) reduce 345) ((T_PROTECTED) reduce 345) ((T_PUBLIC) reduce 345) ((T_READONLY) reduce 345) ((T_REQUIRE) reduce 345) ((T_REQUIRE_ONCE) reduce 345) ((T_RETURN) reduce 345) ((T_STATIC) reduce 345) ((T_STRING) reduce 345) ((T_SWITCH) reduce 345) ((T_THROW) reduce 345) ((T_TRAIT) reduce 345) ((T_TRAIT_C) reduce 345) ((T_TRY) reduce 345) ((T_UNSET) reduce 345) ((T_USE) reduce 345) ((T_VAR) reduce 345) ((T_WHILE) reduce 345) ((T_YIELD) reduce 345)) 6223 (((";") reduce 30)) 6224 (((";") reduce 68)) 6225 (((";") reduce 21)) 6226 (((";") reduce 23)) 6227 (((";") reduce 41)) 6228 (((";") reduce 62)) 6229 (((";") reduce 34)) 6230 (((";") reduce 40)) 6231 (((";") reduce 13)) 6232 (((";") reduce 55)) 6233 (((";") reduce 1)) 6234 (((";") reduce 2)) 6235 (((";") reduce 9)) 6236 (((";") reduce 33)) 6237 (((";") reduce 58)) 6238 (((";") reduce 37)) 6239 (((";") reduce 64)) 6240 (((";") reduce 46)) 6241 (((";") reduce 8)) 6242 (((";") reduce 6)) 6243 (((";") reduce 7)) 6244 (((";") reduce 69)) 6245 (((";") reduce 63)) 6246 (((";") reduce 56)) 6247 (((";") reduce 10)) 6248 (((";") reduce 67)) 6249 (((";") reduce 44)) 6250 (((";") reduce 342) ((T_ABSTRACT) reduce 342) ((T_ARRAY) reduce 342) ((T_AS) reduce 342) ((T_BREAK) reduce 342) ((T_CALLABLE) reduce 342) ((T_CASE) reduce 342) ((T_CATCH) reduce 342) ((T_CLASS) reduce 342) ((T_CLASS_C) reduce 342) ((T_CLONE) reduce 342) ((T_CONST) reduce 342) ((T_CONTINUE) reduce 342) ((T_DECLARE) reduce 342) ((T_DEFAULT) reduce 342) ((T_DIR) reduce 342) ((T_DO) reduce 342) ((T_ECHO) reduce 342) ((T_ELSE) reduce 342) ((T_ELSEIF) reduce 342) ((T_EMPTY) reduce 342) ((T_ENDDECLARE) reduce 342) ((T_ENDFOR) reduce 342) ((T_ENDFOREACH) reduce 342) ((T_ENDIF) reduce 342) ((T_ENDSWITCH) reduce 342) ((T_ENDWHILE) reduce 342) ((T_ENUM) reduce 342) ((T_EVAL) reduce 342) ((T_EXIT) reduce 342) ((T_EXTENDS) reduce 342) ((T_FILE) reduce 342) ((T_FINAL) reduce 342) ((T_FINALLY) reduce 342) ((T_FN) reduce 342) ((T_FOR) reduce 342) ((T_FOREACH) reduce 342) ((T_FUNCTION) reduce 342) ((T_FUNC_C) reduce 342) ((T_GLOBAL) reduce 342) ((T_GOTO) reduce 342) ((T_IF) reduce 342) ((T_IMPLEMENTS) reduce 342) ((T_INCLUDE) reduce 342) ((T_INCLUDE_ONCE) reduce 342) ((T_INSTANCEOF) reduce 342) ((T_INSTEADOF) reduce 342) ((T_INTERFACE) reduce 342) ((T_ISSET) reduce 342) ((T_LINE) reduce 342) ((T_LIST) reduce 342) ((T_LOGICAL_AND) reduce 342) ((T_LOGICAL_OR) reduce 342) ((T_LOGICAL_XOR) reduce 342) ((T_MATCH) reduce 342) ((T_METHOD_C) reduce 342) ((T_NAMESPACE) reduce 342) ((T_NEW) reduce 342) ((T_NS_C) reduce 342) ((T_PRINT) reduce 342) ((T_PRIVATE) reduce 342) ((T_PROTECTED) reduce 342) ((T_PUBLIC) reduce 342) ((T_READONLY) reduce 342) ((T_REQUIRE) reduce 342) ((T_REQUIRE_ONCE) reduce 342) ((T_RETURN) reduce 342) ((T_STATIC) reduce 342) ((T_STRING) reduce 342) ((T_SWITCH) reduce 342) ((T_THROW) reduce 342) ((T_TRAIT) reduce 342) ((T_TRAIT_C) reduce 342) ((T_TRY) reduce 342) ((T_UNSET) reduce 342) ((T_USE) reduce 342) ((T_VAR) reduce 342) ((T_WHILE) reduce 342) ((T_YIELD) reduce 342)) 6251 (((";") reduce 341) ((T_ABSTRACT) reduce 341) ((T_ARRAY) reduce 341) ((T_AS) reduce 341) ((T_BREAK) reduce 341) ((T_CALLABLE) reduce 341) ((T_CASE) reduce 341) ((T_CATCH) reduce 341) ((T_CLASS) reduce 341) ((T_CLASS_C) reduce 341) ((T_CLONE) reduce 341) ((T_CONST) reduce 341) ((T_CONTINUE) reduce 341) ((T_DECLARE) reduce 341) ((T_DEFAULT) reduce 341) ((T_DIR) reduce 341) ((T_DO) reduce 341) ((T_ECHO) reduce 341) ((T_ELSE) reduce 341) ((T_ELSEIF) reduce 341) ((T_EMPTY) reduce 341) ((T_ENDDECLARE) reduce 341) ((T_ENDFOR) reduce 341) ((T_ENDFOREACH) reduce 341) ((T_ENDIF) reduce 341) ((T_ENDSWITCH) reduce 341) ((T_ENDWHILE) reduce 341) ((T_ENUM) reduce 341) ((T_EVAL) reduce 341) ((T_EXIT) reduce 341) ((T_EXTENDS) reduce 341) ((T_FILE) reduce 341) ((T_FINAL) reduce 341) ((T_FINALLY) reduce 341) ((T_FN) reduce 341) ((T_FOR) reduce 341) ((T_FOREACH) reduce 341) ((T_FUNCTION) reduce 341) ((T_FUNC_C) reduce 341) ((T_GLOBAL) reduce 341) ((T_GOTO) reduce 341) ((T_IF) reduce 341) ((T_IMPLEMENTS) reduce 341) ((T_INCLUDE) reduce 341) ((T_INCLUDE_ONCE) reduce 341) ((T_INSTANCEOF) reduce 341) ((T_INSTEADOF) reduce 341) ((T_INTERFACE) reduce 341) ((T_ISSET) reduce 341) ((T_LINE) reduce 341) ((T_LIST) reduce 341) ((T_LOGICAL_AND) reduce 341) ((T_LOGICAL_OR) reduce 341) ((T_LOGICAL_XOR) reduce 341) ((T_MATCH) reduce 341) ((T_METHOD_C) reduce 341) ((T_NAMESPACE) reduce 341) ((T_NEW) reduce 341) ((T_NS_C) reduce 341) ((T_PRINT) reduce 341) ((T_PRIVATE) reduce 341) ((T_PROTECTED) reduce 341) ((T_PUBLIC) reduce 341) ((T_READONLY) reduce 341) ((T_REQUIRE) reduce 341) ((T_REQUIRE_ONCE) reduce 341) ((T_RETURN) reduce 341) ((T_STATIC) reduce 341) ((T_STRING) reduce 341) ((T_SWITCH) reduce 341) ((T_THROW) reduce 341) ((T_TRAIT) reduce 341) ((T_TRAIT_C) reduce 341) ((T_TRY) reduce 341) ((T_UNSET) reduce 341) ((T_USE) reduce 341) ((T_VAR) reduce 341) ((T_WHILE) reduce 341) ((T_YIELD) reduce 341)) 6252 (((";") reduce 340) ((T_ABSTRACT) reduce 340) ((T_ARRAY) reduce 340) ((T_AS) reduce 340) ((T_BREAK) reduce 340) ((T_CALLABLE) reduce 340) ((T_CASE) reduce 340) ((T_CATCH) reduce 340) ((T_CLASS) reduce 340) ((T_CLASS_C) reduce 340) ((T_CLONE) reduce 340) ((T_CONST) reduce 340) ((T_CONTINUE) reduce 340) ((T_DECLARE) reduce 340) ((T_DEFAULT) reduce 340) ((T_DIR) reduce 340) ((T_DO) reduce 340) ((T_ECHO) reduce 340) ((T_ELSE) reduce 340) ((T_ELSEIF) reduce 340) ((T_EMPTY) reduce 340) ((T_ENDDECLARE) reduce 340) ((T_ENDFOR) reduce 340) ((T_ENDFOREACH) reduce 340) ((T_ENDIF) reduce 340) ((T_ENDSWITCH) reduce 340) ((T_ENDWHILE) reduce 340) ((T_ENUM) reduce 340) ((T_EVAL) reduce 340) ((T_EXIT) reduce 340) ((T_EXTENDS) reduce 340) ((T_FILE) reduce 340) ((T_FINAL) reduce 340) ((T_FINALLY) reduce 340) ((T_FN) reduce 340) ((T_FOR) reduce 340) ((T_FOREACH) reduce 340) ((T_FUNCTION) reduce 340) ((T_FUNC_C) reduce 340) ((T_GLOBAL) reduce 340) ((T_GOTO) reduce 340) ((T_IF) reduce 340) ((T_IMPLEMENTS) reduce 340) ((T_INCLUDE) reduce 340) ((T_INCLUDE_ONCE) reduce 340) ((T_INSTANCEOF) reduce 340) ((T_INSTEADOF) reduce 340) ((T_INTERFACE) reduce 340) ((T_ISSET) reduce 340) ((T_LINE) reduce 340) ((T_LIST) reduce 340) ((T_LOGICAL_AND) reduce 340) ((T_LOGICAL_OR) reduce 340) ((T_LOGICAL_XOR) reduce 340) ((T_MATCH) reduce 340) ((T_METHOD_C) reduce 340) ((T_NAMESPACE) reduce 340) ((T_NEW) reduce 340) ((T_NS_C) reduce 340) ((T_PRINT) reduce 340) ((T_PRIVATE) reduce 340) ((T_PROTECTED) reduce 340) ((T_PUBLIC) reduce 340) ((T_READONLY) reduce 340) ((T_REQUIRE) reduce 340) ((T_REQUIRE_ONCE) reduce 340) ((T_RETURN) reduce 340) ((T_STATIC) reduce 340) ((T_STRING) reduce 340) ((T_SWITCH) reduce 340) ((T_THROW) reduce 340) ((T_TRAIT) reduce 340) ((T_TRAIT_C) reduce 340) ((T_TRY) reduce 340) ((T_UNSET) reduce 340) ((T_USE) reduce 340) ((T_VAR) reduce 340) ((T_WHILE) reduce 340) ((T_YIELD) reduce 340)) 6253 (((";") reduce 346) ((T_ABSTRACT) reduce 346) ((T_ARRAY) reduce 346) ((T_AS) reduce 346) ((T_BREAK) reduce 346) ((T_CALLABLE) reduce 346) ((T_CASE) reduce 346) ((T_CATCH) reduce 346) ((T_CLASS) reduce 346) ((T_CLASS_C) reduce 346) ((T_CLONE) reduce 346) ((T_CONST) reduce 346) ((T_CONTINUE) reduce 346) ((T_DECLARE) reduce 346) ((T_DEFAULT) reduce 346) ((T_DIR) reduce 346) ((T_DO) reduce 346) ((T_ECHO) reduce 346) ((T_ELSE) reduce 346) ((T_ELSEIF) reduce 346) ((T_EMPTY) reduce 346) ((T_ENDDECLARE) reduce 346) ((T_ENDFOR) reduce 346) ((T_ENDFOREACH) reduce 346) ((T_ENDIF) reduce 346) ((T_ENDSWITCH) reduce 346) ((T_ENDWHILE) reduce 346) ((T_ENUM) reduce 346) ((T_EVAL) reduce 346) ((T_EXIT) reduce 346) ((T_EXTENDS) reduce 346) ((T_FILE) reduce 346) ((T_FINAL) reduce 346) ((T_FINALLY) reduce 346) ((T_FN) reduce 346) ((T_FOR) reduce 346) ((T_FOREACH) reduce 346) ((T_FUNCTION) reduce 346) ((T_FUNC_C) reduce 346) ((T_GLOBAL) reduce 346) ((T_GOTO) reduce 346) ((T_IF) reduce 346) ((T_IMPLEMENTS) reduce 346) ((T_INCLUDE) reduce 346) ((T_INCLUDE_ONCE) reduce 346) ((T_INSTANCEOF) reduce 346) ((T_INSTEADOF) reduce 346) ((T_INTERFACE) reduce 346) ((T_ISSET) reduce 346) ((T_LINE) reduce 346) ((T_LIST) reduce 346) ((T_LOGICAL_AND) reduce 346) ((T_LOGICAL_OR) reduce 346) ((T_LOGICAL_XOR) reduce 346) ((T_MATCH) reduce 346) ((T_METHOD_C) reduce 346) ((T_NAMESPACE) reduce 346) ((T_NEW) reduce 346) ((T_NS_C) reduce 346) ((T_PRINT) reduce 346) ((T_PRIVATE) reduce 346) ((T_PROTECTED) reduce 346) ((T_PUBLIC) reduce 346) ((T_READONLY) reduce 346) ((T_REQUIRE) reduce 346) ((T_REQUIRE_ONCE) reduce 346) ((T_RETURN) reduce 346) ((T_STATIC) reduce 346) ((T_STRING) reduce 346) ((T_SWITCH) reduce 346) ((T_THROW) reduce 346) ((T_TRAIT) reduce 346) ((T_TRAIT_C) reduce 346) ((T_TRY) reduce 346) ((T_UNSET) reduce 346) ((T_USE) reduce 346) ((T_VAR) reduce 346) ((T_WHILE) reduce 346) ((T_YIELD) reduce 346)) 6254 (((";") reduce 4)) 6255 (((";") reduce 5)) 6256 (((";") reduce 43)) 6257 (((";") reduce 343) ((T_ABSTRACT) reduce 343) ((T_ARRAY) reduce 343) ((T_AS) reduce 343) ((T_BREAK) reduce 343) ((T_CALLABLE) reduce 343) ((T_CASE) reduce 343) ((T_CATCH) reduce 343) ((T_CLASS) reduce 343) ((T_CLASS_C) reduce 343) ((T_CLONE) reduce 343) ((T_CONST) reduce 343) ((T_CONTINUE) reduce 343) ((T_DECLARE) reduce 343) ((T_DEFAULT) reduce 343) ((T_DIR) reduce 343) ((T_DO) reduce 343) ((T_ECHO) reduce 343) ((T_ELSE) reduce 343) ((T_ELSEIF) reduce 343) ((T_EMPTY) reduce 343) ((T_ENDDECLARE) reduce 343) ((T_ENDFOR) reduce 343) ((T_ENDFOREACH) reduce 343) ((T_ENDIF) reduce 343) ((T_ENDSWITCH) reduce 343) ((T_ENDWHILE) reduce 343) ((T_ENUM) reduce 343) ((T_EVAL) reduce 343) ((T_EXIT) reduce 343) ((T_EXTENDS) reduce 343) ((T_FILE) reduce 343) ((T_FINAL) reduce 343) ((T_FINALLY) reduce 343) ((T_FN) reduce 343) ((T_FOR) reduce 343) ((T_FOREACH) reduce 343) ((T_FUNCTION) reduce 343) ((T_FUNC_C) reduce 343) ((T_GLOBAL) reduce 343) ((T_GOTO) reduce 343) ((T_IF) reduce 343) ((T_IMPLEMENTS) reduce 343) ((T_INCLUDE) reduce 343) ((T_INCLUDE_ONCE) reduce 343) ((T_INSTANCEOF) reduce 343) ((T_INSTEADOF) reduce 343) ((T_INTERFACE) reduce 343) ((T_ISSET) reduce 343) ((T_LINE) reduce 343) ((T_LIST) reduce 343) ((T_LOGICAL_AND) reduce 343) ((T_LOGICAL_OR) reduce 343) ((T_LOGICAL_XOR) reduce 343) ((T_MATCH) reduce 343) ((T_METHOD_C) reduce 343) ((T_NAMESPACE) reduce 343) ((T_NEW) reduce 343) ((T_NS_C) reduce 343) ((T_PRINT) reduce 343) ((T_PRIVATE) reduce 343) ((T_PROTECTED) reduce 343) ((T_PUBLIC) reduce 343) ((T_READONLY) reduce 343) ((T_REQUIRE) reduce 343) ((T_REQUIRE_ONCE) reduce 343) ((T_RETURN) reduce 343) ((T_STATIC) reduce 343) ((T_STRING) reduce 343) ((T_SWITCH) reduce 343) ((T_THROW) reduce 343) ((T_TRAIT) reduce 343) ((T_TRAIT_C) reduce 343) ((T_TRY) reduce 343) ((T_UNSET) reduce 343) ((T_USE) reduce 343) ((T_VAR) reduce 343) ((T_WHILE) reduce 343) ((T_YIELD) reduce 343)) 6258 (((";") reduce 323)) 6259 (((";") reduce 47)) 6260 (((";") reduce 31)) 6261 (((";") reduce 57)) 6262 (((";") reduce 61)) 6263 (((";") reduce 28)) 6264 (((";") reduce 36)) 6265 (((";") reduce 32)) 6266 (((";") reduce 35)) 6267 (((";") reduce 19)) 6268 (((";") reduce 45)) 6269 (((";") reduce 326) ((T_ABSTRACT) shift) ((T_ARRAY) shift) ((T_AS) shift) ((T_BREAK) shift) ((T_CALLABLE) shift) ((T_CASE) shift) ((T_CATCH) shift) ((T_CLASS) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONST) shift) ((T_CONTINUE) shift) ((T_DECLARE) shift) ((T_DEFAULT) shift) ((T_DIR) shift) ((T_DO) shift) ((T_ECHO) shift) ((T_ELSE) shift) ((T_ELSEIF) shift) ((T_EMPTY) shift) ((T_ENDDECLARE) shift) ((T_ENDFOR) shift) ((T_ENDFOREACH) shift) ((T_ENDIF) shift) ((T_ENDSWITCH) shift) ((T_ENDWHILE) shift) ((T_ENUM) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_EXTENDS) shift) ((T_FILE) shift) ((T_FINAL) shift) ((T_FINALLY) shift) ((T_FN) shift) ((T_FOR) shift) ((T_FOREACH) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_GLOBAL) shift) ((T_GOTO) shift) ((T_IF) shift) ((T_IMPLEMENTS) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INSTANCEOF) shift) ((T_INSTEADOF) shift) ((T_INTERFACE) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAMESPACE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_PRINT) shift) ((T_PRIVATE) shift) ((T_PROTECTED) shift) ((T_PUBLIC) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_RETURN) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_SWITCH) shift) ((T_THROW) shift) ((T_TRAIT) shift) ((T_TRAIT_C) shift) ((T_TRY) shift) ((T_UNSET) shift) ((T_USE) shift) ((T_VAR) shift) ((T_WHILE) shift) ((T_YIELD) shift)) 6270 (((";") reduce 324)) 6271 (((";") reduce 73)) 6272 (((";") reduce 74)) 6273 (((";") reduce 75)) 6274 (((";") reduce 76)) 6275 (((";") reduce 77)) 6276 (((";") reduce 78)) 6277 (((";") reduce 72)) 6278 (((";") reduce 81)) 6279 (((";") reduce 325)) 6280 (((";") reduce 71)) 6281 (((";") reduce 82)) 6282 (((T_ABSTRACT) reduce 321) ((T_ARRAY) reduce 321) ((T_AS) reduce 321) ((T_BREAK) reduce 321) ((T_CALLABLE) reduce 321) ((T_CASE) reduce 321) ((T_CATCH) reduce 321) ((T_CLASS) reduce 321) ((T_CLASS_C) reduce 321) ((T_CLONE) reduce 321) ((T_CONST) reduce 321) ((T_CONTINUE) reduce 321) ((T_DECLARE) reduce 321) ((T_DEFAULT) reduce 321) ((T_DIR) reduce 321) ((T_DO) reduce 321) ((T_ECHO) reduce 321) ((T_ELSE) reduce 321) ((T_ELSEIF) reduce 321) ((T_EMPTY) reduce 321) ((T_ENDDECLARE) reduce 321) ((T_ENDFOR) reduce 321) ((T_ENDFOREACH) reduce 321) ((T_ENDIF) reduce 321) ((T_ENDSWITCH) reduce 321) ((T_ENDWHILE) reduce 321) ((T_ENUM) reduce 321) ((T_EVAL) reduce 321) ((T_EXIT) reduce 321) ((T_EXTENDS) reduce 321) ((T_FILE) reduce 321) ((T_FINAL) reduce 321) ((T_FINALLY) reduce 321) ((T_FN) reduce 321) ((T_FOR) reduce 321) ((T_FOREACH) reduce 321) ((T_FUNCTION) reduce 321) ((T_FUNC_C) reduce 321) ((T_GLOBAL) reduce 321) ((T_GOTO) reduce 321) ((T_IF) reduce 321) ((T_IMPLEMENTS) reduce 321) ((T_INCLUDE) reduce 321) ((T_INCLUDE_ONCE) reduce 321) ((T_INSTANCEOF) reduce 321) ((T_INSTEADOF) reduce 321) ((T_INTERFACE) reduce 321) ((T_ISSET) reduce 321) ((T_LINE) reduce 321) ((T_LIST) reduce 321) ((T_LOGICAL_AND) reduce 321) ((T_LOGICAL_OR) reduce 321) ((T_LOGICAL_XOR) reduce 321) ((T_MATCH) reduce 321) ((T_METHOD_C) reduce 321) ((T_NAMESPACE) reduce 321) ((T_NAME_FULLY_QUALIFIED) reduce 321) ((T_NAME_QUALIFIED) reduce 321) ((T_NAME_RELATIVE) reduce 321) ((T_NEW) reduce 321) ((T_NS_C) reduce 321) ((T_PRINT) reduce 321) ((T_PRIVATE) reduce 321) ((T_PROTECTED) reduce 321) ((T_PUBLIC) reduce 321) ((T_READONLY) reduce 321) ((T_REQUIRE) reduce 321) ((T_REQUIRE_ONCE) reduce 321) ((T_RETURN) reduce 321) ((T_STATIC) reduce 321) ((T_STRING) reduce 321) ((T_SWITCH) reduce 321) ((T_THROW) reduce 321) ((T_TRAIT) reduce 321) ((T_TRAIT_C) reduce 321) ((T_TRY) reduce 321) ((T_UNSET) reduce 321) ((T_USE) reduce 321) ((T_VAR) reduce 321) ((T_WHILE) reduce 321) ((T_YIELD) reduce 321) (("}") reduce 321)) 6283 (((T_ABSTRACT) reduce 319) ((T_ARRAY) reduce 319) ((T_AS) reduce 319) ((T_BREAK) reduce 319) ((T_CALLABLE) reduce 319) ((T_CASE) reduce 319) ((T_CATCH) reduce 319) ((T_CLASS) reduce 319) ((T_CLASS_C) reduce 319) ((T_CLONE) reduce 319) ((T_CONST) reduce 319) ((T_CONTINUE) reduce 319) ((T_DECLARE) reduce 319) ((T_DEFAULT) reduce 319) ((T_DIR) reduce 319) ((T_DO) reduce 319) ((T_ECHO) reduce 319) ((T_ELSE) reduce 319) ((T_ELSEIF) reduce 319) ((T_EMPTY) reduce 319) ((T_ENDDECLARE) reduce 319) ((T_ENDFOR) reduce 319) ((T_ENDFOREACH) reduce 319) ((T_ENDIF) reduce 319) ((T_ENDSWITCH) reduce 319) ((T_ENDWHILE) reduce 319) ((T_ENUM) reduce 319) ((T_EVAL) reduce 319) ((T_EXIT) reduce 319) ((T_EXTENDS) reduce 319) ((T_FILE) reduce 319) ((T_FINAL) reduce 319) ((T_FINALLY) reduce 319) ((T_FN) reduce 319) ((T_FOR) reduce 319) ((T_FOREACH) reduce 319) ((T_FUNCTION) reduce 319) ((T_FUNC_C) reduce 319) ((T_GLOBAL) reduce 319) ((T_GOTO) reduce 319) ((T_IF) reduce 319) ((T_IMPLEMENTS) reduce 319) ((T_INCLUDE) reduce 319) ((T_INCLUDE_ONCE) reduce 319) ((T_INSTANCEOF) reduce 319) ((T_INSTEADOF) reduce 319) ((T_INTERFACE) reduce 319) ((T_ISSET) reduce 319) ((T_LINE) reduce 319) ((T_LIST) reduce 319) ((T_LOGICAL_AND) reduce 319) ((T_LOGICAL_OR) reduce 319) ((T_LOGICAL_XOR) reduce 319) ((T_MATCH) reduce 319) ((T_METHOD_C) reduce 319) ((T_NAMESPACE) reduce 319) ((T_NAME_FULLY_QUALIFIED) reduce 319) ((T_NAME_QUALIFIED) reduce 319) ((T_NAME_RELATIVE) reduce 319) ((T_NEW) reduce 319) ((T_NS_C) reduce 319) ((T_PRINT) reduce 319) ((T_PRIVATE) reduce 319) ((T_PROTECTED) reduce 319) ((T_PUBLIC) reduce 319) ((T_READONLY) reduce 319) ((T_REQUIRE) reduce 319) ((T_REQUIRE_ONCE) reduce 319) ((T_RETURN) reduce 319) ((T_STATIC) reduce 319) ((T_STRING) reduce 319) ((T_SWITCH) reduce 319) ((T_THROW) reduce 319) ((T_TRAIT) reduce 319) ((T_TRAIT_C) reduce 319) ((T_TRY) reduce 319) ((T_UNSET) reduce 319) ((T_USE) reduce 319) ((T_VAR) reduce 319) ((T_WHILE) reduce 319) ((T_YIELD) reduce 319) (("}") reduce 319)) 6284 (((T_ABSTRACT) reduce 317) ((T_ATTRIBUTE) reduce 317) ((T_CASE) reduce 317) ((T_CONST) reduce 317) ((T_FINAL) reduce 317) ((T_FUNCTION) reduce 317) ((T_PRIVATE) reduce 317) ((T_PROTECTED) reduce 317) ((T_PUBLIC) reduce 317) ((T_READONLY) reduce 317) ((T_STATIC) reduce 317) ((T_USE) reduce 317) ((T_VAR) reduce 317) (("}") reduce 317)) 6286 (((T_AS) reduce 73) ((T_INSTEADOF) reduce 73)) 6287 (((T_AS) reduce 52) ((T_INSTEADOF) reduce 52)) 6288 (((T_AS) reduce 27) ((T_INSTEADOF) reduce 27)) 6289 (((T_AS) reduce 51) ((T_INSTEADOF) reduce 51)) 6290 (((T_AS) reduce 53) ((T_INSTEADOF) reduce 53)) 6291 (((T_AS) reduce 49) ((T_INSTEADOF) reduce 49)) 6292 (((T_AS) reduce 29) ((T_INSTEADOF) reduce 29)) 6293 (((T_AS) reduce 59) ((T_INSTEADOF) reduce 59)) 6294 (((T_AS) reduce 60) ((T_INSTEADOF) reduce 60)) 6295 (((T_AS) reduce 11) ((T_INSTEADOF) reduce 11)) 6296 (((T_AS) reduce 42) ((T_INSTEADOF) reduce 42)) 6297 (((T_AS) reduce 39) ((T_INSTEADOF) reduce 39)) 6298 (((T_AS) reduce 25) ((T_INSTEADOF) reduce 25)) 6299 (((T_AS) reduce 50) ((T_INSTEADOF) reduce 50)) 6300 (((T_AS) reduce 66) ((T_INSTEADOF) reduce 66)) 6301 (((T_AS) reduce 18) ((T_INSTEADOF) reduce 18)) 6302 (((T_AS) reduce 17) ((T_INSTEADOF) reduce 17)) 6303 (((T_AS) reduce 15) ((T_INSTEADOF) reduce 15)) 6304 (((T_AS) reduce 14) ((T_INSTEADOF) reduce 14)) 6305 (((T_AS) reduce 38) ((T_INSTEADOF) reduce 38)) 6306 (((T_AS) reduce 26) ((T_INSTEADOF) reduce 26)) 6307 (((T_AS) reduce 22) ((T_INSTEADOF) reduce 22)) 6308 (((T_AS) reduce 24) ((T_INSTEADOF) reduce 24)) 6309 (((T_AS) reduce 16) ((T_INSTEADOF) reduce 16)) 6310 (((T_AS) reduce 48) ((T_INSTEADOF) reduce 48)) 6311 (((T_AS) reduce 20) ((T_INSTEADOF) reduce 20)) 6312 (((T_AS) reduce 70) ((T_INSTEADOF) reduce 70)) 6313 (((T_AS) reduce 3) ((T_INSTEADOF) reduce 3)) 6314 (((T_AS) reduce 12) ((T_INSTEADOF) reduce 12)) 6315 (((T_AS) reduce 54) ((T_INSTEADOF) reduce 54)) 6316 (((T_AS) reduce 65) ((T_INSTEADOF) reduce 65)) 6317 (((T_AS) reduce 74) ((T_INSTEADOF) reduce 74)) 6318 (((T_AS) reduce 30) ((T_INSTEADOF) reduce 30)) 6319 (((T_AS) reduce 68) ((T_INSTEADOF) reduce 68)) 6320 (((T_AS) reduce 21) ((T_INSTEADOF) reduce 21)) 6321 (((T_AS) reduce 23) ((T_INSTEADOF) reduce 23)) 6322 (((T_AS) reduce 41) ((T_INSTEADOF) reduce 41)) 6323 (((T_AS) reduce 62) ((T_INSTEADOF) reduce 62)) 6324 (((T_AS) reduce 34) ((T_INSTEADOF) reduce 34)) 6325 (((T_AS) reduce 40) ((T_INSTEADOF) reduce 40)) 6326 (((T_AS) reduce 13) ((T_INSTEADOF) reduce 13)) 6327 (((T_AS) reduce 55) ((T_INSTEADOF) reduce 55)) 6328 (((T_AS) reduce 1) ((T_INSTEADOF) reduce 1)) 6329 (((T_AS) reduce 2) ((T_INSTEADOF) reduce 2)) 6330 (((T_AS) reduce 9) ((T_INSTEADOF) reduce 9)) 6331 (((T_AS) reduce 33) ((T_INSTEADOF) reduce 33)) 6332 (((T_AS) reduce 58) ((T_INSTEADOF) reduce 58)) 6333 (((T_AS) reduce 37) ((T_INSTEADOF) reduce 37)) 6334 (((T_AS) reduce 64) ((T_INSTEADOF) reduce 64)) 6335 (((T_AS) reduce 46) ((T_INSTEADOF) reduce 46)) 6336 (((T_AS) reduce 8) ((T_INSTEADOF) reduce 8)) 6337 (((T_AS) reduce 6) ((T_INSTEADOF) reduce 6)) 6338 (((T_AS) reduce 7) ((T_INSTEADOF) reduce 7)) 6339 (((T_AS) reduce 69) ((T_INSTEADOF) reduce 69)) 6340 (((T_AS) reduce 63) ((T_INSTEADOF) reduce 63)) 6341 (((T_AS) reduce 56) ((T_INSTEADOF) reduce 56)) 6342 (((T_AS) reduce 10) ((T_INSTEADOF) reduce 10)) 6343 (((T_AS) reduce 67) ((T_INSTEADOF) reduce 67)) 6344 (((T_AS) reduce 44) ((T_INSTEADOF) reduce 44)) 6345 (((T_AS) reduce 75) ((T_INSTEADOF) reduce 75)) 6346 (((T_AS) reduce 76) ((T_INSTEADOF) reduce 76)) 6347 (((T_AS) reduce 77) ((T_INSTEADOF) reduce 77)) 6348 (((T_AS) reduce 78) ((T_INSTEADOF) reduce 78)) 6349 (((T_AS) reduce 4) ((T_INSTEADOF) reduce 4)) 6350 (((T_AS) reduce 5) ((T_INSTEADOF) reduce 5)) 6351 (((T_AS) reduce 43) ((T_INSTEADOF) reduce 43)) 6352 (((T_AS) reduce 72) ((T_INSTEADOF) reduce 72)) 6353 (((T_AS) reduce 81) ((T_INSTEADOF) reduce 81)) 6354 (((T_AS) reduce 47) ((T_INSTEADOF) reduce 47)) 6355 (((T_AS) reduce 31) ((T_INSTEADOF) reduce 31)) 6356 (((T_AS) reduce 57) ((T_INSTEADOF) reduce 57)) 6357 (((T_AS) reduce 61) ((T_INSTEADOF) reduce 61)) 6358 (((T_AS) reduce 28) ((T_INSTEADOF) reduce 28)) 6359 (((T_AS) reduce 36) ((T_INSTEADOF) reduce 36)) 6360 (((T_AS) reduce 32) ((T_INSTEADOF) reduce 32)) 6361 (((T_AS) reduce 35) ((T_INSTEADOF) reduce 35)) 6362 (((T_AS) reduce 19) ((T_INSTEADOF) reduce 19)) 6363 (((T_AS) reduce 45) ((T_INSTEADOF) reduce 45)) 6364 (((T_AS) reduce 329) ((T_INSTEADOF) reduce 329)) 6365 (((T_AS) reduce 71) ((T_INSTEADOF) reduce 71)) 6366 (((T_AS) reduce 82) ((T_INSTEADOF) reduce 82)) 6368 (((",") reduce 93) ((";") reduce 93)) 6369 (((",") reduce 92) ((";") reduce 92)) 6370 (((",") reduce 94) ((";") reduce 94)) 6371 (((",") reduce 470) ((";") reduce 470)) 6372 (((",") reduce 91) ((";") reduce 91)) 6373 (((",") reduce 313) ((";") reduce 313)) 6374 (((",") shift) ((";") reduce 322)) 6375 (((",") reduce 471) ((";") reduce 471)) 6377 (((",") reduce 314) ((";") reduce 314)) 6378 (((",") reduce 314) ((";") reduce 314) (("{") reduce 314)) 6380 (((";") reduce 73) (("=") reduce 73)) 6381 (((";") reduce 52) (("=") reduce 52)) 6382 (((";") reduce 27) (("=") reduce 27)) 6383 (((";") reduce 51) (("=") reduce 51)) 6384 (((";") reduce 53) (("=") reduce 53)) 6385 (((";") reduce 49) (("=") reduce 49)) 6386 (((";") reduce 29) (("=") reduce 29)) 6387 (((";") reduce 59) (("=") reduce 59)) 6388 (((";") reduce 60) (("=") reduce 60)) 6389 (((";") reduce 11) (("=") reduce 11)) 6390 (((";") reduce 42) (("=") reduce 42)) 6391 (((";") reduce 39) (("=") reduce 39)) 6392 (((";") reduce 25) (("=") reduce 25)) 6393 (((";") reduce 50) (("=") reduce 50)) 6394 (((";") reduce 66) (("=") reduce 66)) 6395 (((";") reduce 18) (("=") reduce 18)) 6396 (((";") reduce 17) (("=") reduce 17)) 6397 (((";") reduce 15) (("=") reduce 15)) 6398 (((";") reduce 14) (("=") reduce 14)) 6399 (((";") reduce 38) (("=") reduce 38)) 6400 (((";") reduce 26) (("=") reduce 26)) 6401 (((";") reduce 22) (("=") reduce 22)) 6402 (((";") reduce 24) (("=") reduce 24)) 6403 (((";") reduce 16) (("=") reduce 16)) 6404 (((";") reduce 48) (("=") reduce 48)) 6405 (((";") reduce 20) (("=") reduce 20)) 6406 (((";") reduce 70) (("=") reduce 70)) 6407 (((";") reduce 3) (("=") reduce 3)) 6408 (((";") reduce 12) (("=") reduce 12)) 6409 (((";") reduce 54) (("=") reduce 54)) 6410 (((";") reduce 65) (("=") reduce 65)) 6411 (((";") reduce 74) (("=") reduce 74)) 6412 (((";") reduce 30) (("=") reduce 30)) 6413 (((";") reduce 68) (("=") reduce 68)) 6414 (((";") reduce 21) (("=") reduce 21)) 6415 (((";") reduce 23) (("=") reduce 23)) 6416 (((";") reduce 41) (("=") reduce 41)) 6417 (((";") reduce 62) (("=") reduce 62)) 6418 (((";") reduce 34) (("=") reduce 34)) 6419 (((";") reduce 40) (("=") reduce 40)) 6420 (((";") reduce 13) (("=") reduce 13)) 6421 (((";") reduce 55) (("=") reduce 55)) 6422 (((";") reduce 1) (("=") reduce 1)) 6423 (((";") reduce 2) (("=") reduce 2)) 6424 (((";") reduce 9) (("=") reduce 9)) 6425 (((";") reduce 33) (("=") reduce 33)) 6426 (((";") reduce 58) (("=") reduce 58)) 6427 (((";") reduce 37) (("=") reduce 37)) 6428 (((";") reduce 64) (("=") reduce 64)) 6429 (((";") reduce 46) (("=") reduce 46)) 6430 (((";") reduce 8) (("=") reduce 8)) 6431 (((";") reduce 6) (("=") reduce 6)) 6432 (((";") reduce 7) (("=") reduce 7)) 6433 (((";") reduce 69) (("=") reduce 69)) 6434 (((";") reduce 63) (("=") reduce 63)) 6435 (((";") reduce 56) (("=") reduce 56)) 6436 (((";") reduce 10) (("=") reduce 10)) 6437 (((";") reduce 67) (("=") reduce 67)) 6438 (((";") reduce 44) (("=") reduce 44)) 6439 (((";") reduce 75) (("=") reduce 75)) 6440 (((";") reduce 76) (("=") reduce 76)) 6441 (((";") reduce 77) (("=") reduce 77)) 6442 (((";") reduce 78) (("=") reduce 78)) 6443 (((";") reduce 4) (("=") reduce 4)) 6444 (((";") reduce 5) (("=") reduce 5)) 6445 (((";") reduce 43) (("=") reduce 43)) 6446 (((";") reduce 72) (("=") reduce 72)) 6447 (((";") reduce 81) (("=") reduce 81)) 6448 (((";") reduce 47) (("=") reduce 47)) 6449 (((";") reduce 31) (("=") reduce 31)) 6450 (((";") reduce 57) (("=") reduce 57)) 6451 (((";") reduce 61) (("=") reduce 61)) 6452 (((";") reduce 28) (("=") reduce 28)) 6453 (((";") reduce 36) (("=") reduce 36)) 6454 (((";") reduce 32) (("=") reduce 32)) 6455 (((";") reduce 35) (("=") reduce 35)) 6456 (((";") reduce 19) (("=") reduce 19)) 6457 (((";") reduce 45) (("=") reduce 45)) 6458 (((";") reduce 203) (("=") shift)) 6459 (((";") reduce 71) (("=") reduce 71)) 6460 (((";") reduce 82) (("=") reduce 82)) 6463 (((T_ABSTRACT) reduce 202) ((T_ATTRIBUTE) reduce 202) ((T_CASE) reduce 202) ((T_CONST) reduce 202) ((T_FINAL) reduce 202) ((T_FUNCTION) reduce 202) ((T_PRIVATE) reduce 202) ((T_PROTECTED) reduce 202) ((T_PUBLIC) reduce 202) ((T_READONLY) reduce 202) ((T_STATIC) reduce 202) ((T_USE) reduce 202) ((T_VAR) reduce 202) (("}") reduce 202)) 6464 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 204) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 6495 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 395) (("<") shift) ((">") shift) (("?") reduce 395) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 395) ((T_BOOLEAN_OR) reduce 395) ((T_COALESCE) reduce 395) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 395) ((T_LOGICAL_OR) reduce 395) ((T_LOGICAL_XOR) reduce 395) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") reduce 395)) 6496 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 398) (("<") shift) ((">") shift) (("?") reduce 398) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 398) ((T_BOOLEAN_OR) reduce 398) ((T_COALESCE) reduce 398) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 398) ((T_LOGICAL_OR) reduce 398) ((T_LOGICAL_XOR) reduce 398) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 398) (("|") reduce 398)) 6497 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 407) (("/") shift) ((";") reduce 407) (("<") reduce 407) ((">") reduce 407) (("?") reduce 407) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_BOOLEAN_AND) reduce 407) ((T_BOOLEAN_OR) reduce 407) ((T_COALESCE) reduce 407) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 407) ((T_IS_GREATER_OR_EQUAL) reduce 407) ((T_IS_IDENTICAL) reduce 407) ((T_IS_NOT_EQUAL) reduce 407) ((T_IS_NOT_IDENTICAL) reduce 407) ((T_IS_SMALLER_OR_EQUAL) reduce 407) ((T_LOGICAL_AND) reduce 407) ((T_LOGICAL_OR) reduce 407) ((T_LOGICAL_XOR) reduce 407) ((T_POW) shift) ((T_SL) reduce 407) ((T_SPACESHIP) reduce 407) ((T_SR) reduce 407) (("^") reduce 407) (("|") reduce 407)) 6498 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 420) (("<") shift) ((">") shift) (("?") reduce 420) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_BOOLEAN_AND) reduce 420) ((T_BOOLEAN_OR) reduce 420) ((T_COALESCE) reduce 420) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 420) ((T_LOGICAL_OR) reduce 420) ((T_LOGICAL_XOR) reduce 420) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 420) (("|") reduce 420)) 6499 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 406) (("/") shift) ((";") reduce 406) (("<") reduce 406) ((">") reduce 406) (("?") reduce 406) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_BOOLEAN_AND) reduce 406) ((T_BOOLEAN_OR) reduce 406) ((T_COALESCE) reduce 406) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 406) ((T_IS_GREATER_OR_EQUAL) reduce 406) ((T_IS_IDENTICAL) reduce 406) ((T_IS_NOT_EQUAL) reduce 406) ((T_IS_NOT_IDENTICAL) reduce 406) ((T_IS_SMALLER_OR_EQUAL) reduce 406) ((T_LOGICAL_AND) reduce 406) ((T_LOGICAL_OR) reduce 406) ((T_LOGICAL_XOR) reduce 406) ((T_POW) shift) ((T_SL) reduce 406) ((T_SPACESHIP) reduce 406) ((T_SR) reduce 406) (("^") reduce 406) (("|") reduce 406)) 6500 ((("%") reduce 403) (("*") reduce 403) (("+") reduce 403) (("-") reduce 403) ((".") reduce 403) (("/") reduce 403) ((";") reduce 403) (("<") reduce 403) ((">") reduce 403) (("?") reduce 403) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_BOOLEAN_AND) reduce 403) ((T_BOOLEAN_OR) reduce 403) ((T_COALESCE) reduce 403) ((T_INSTANCEOF) reduce 403) ((T_IS_EQUAL) reduce 403) ((T_IS_GREATER_OR_EQUAL) reduce 403) ((T_IS_IDENTICAL) reduce 403) ((T_IS_NOT_EQUAL) reduce 403) ((T_IS_NOT_IDENTICAL) reduce 403) ((T_IS_SMALLER_OR_EQUAL) reduce 403) ((T_LOGICAL_AND) reduce 403) ((T_LOGICAL_OR) reduce 403) ((T_LOGICAL_XOR) reduce 403) ((T_POW) shift) ((T_SL) reduce 403) ((T_SPACESHIP) reduce 403) ((T_SR) reduce 403) (("^") reduce 403) (("|") reduce 403)) 6501 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 394) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 394) ((T_LOGICAL_XOR) reduce 394) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 6502 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 392) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 392) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 6503 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 393) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 393) ((T_LOGICAL_OR) reduce 393) ((T_LOGICAL_XOR) reduce 393) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 6504 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 417) (("<") shift) ((">") shift) (("?") reduce 417) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_BOOLEAN_AND) reduce 417) ((T_BOOLEAN_OR) reduce 417) ((T_COALESCE) reduce 417) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 417) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 417) ((T_IS_NOT_EQUAL) reduce 417) ((T_IS_NOT_IDENTICAL) reduce 417) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 417) ((T_LOGICAL_OR) reduce 417) ((T_LOGICAL_XOR) reduce 417) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 417) ((T_SR) shift) (("^") reduce 417) (("|") reduce 417)) 6505 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 413) (("<") shift) ((">") shift) (("?") reduce 413) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_BOOLEAN_AND) reduce 413) ((T_BOOLEAN_OR) reduce 413) ((T_COALESCE) reduce 413) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 413) ((T_LOGICAL_OR) reduce 413) ((T_LOGICAL_XOR) reduce 413) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 413) (("|") reduce 413)) 6506 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 415) (("<") shift) ((">") shift) (("?") reduce 415) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_BOOLEAN_AND) reduce 415) ((T_BOOLEAN_OR) reduce 415) ((T_COALESCE) reduce 415) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 415) ((T_LOGICAL_OR) reduce 415) ((T_LOGICAL_XOR) reduce 415) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 415) (("|") reduce 415)) 6507 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 412) (("<") shift) ((">") shift) (("?") reduce 412) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_BOOLEAN_AND) reduce 412) ((T_BOOLEAN_OR) reduce 412) ((T_COALESCE) reduce 412) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 412) ((T_LOGICAL_OR) reduce 412) ((T_LOGICAL_XOR) reduce 412) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 412) (("|") reduce 412)) 6508 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 419) (("<") shift) ((">") shift) (("?") reduce 419) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_BOOLEAN_AND) reduce 419) ((T_BOOLEAN_OR) reduce 419) ((T_COALESCE) reduce 419) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 419) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 419) ((T_IS_NOT_EQUAL) reduce 419) ((T_IS_NOT_IDENTICAL) reduce 419) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 419) ((T_LOGICAL_OR) reduce 419) ((T_LOGICAL_XOR) reduce 419) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 419) ((T_SR) shift) (("^") reduce 419) (("|") reduce 419)) 6509 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 414) (("<") shift) ((">") shift) (("?") reduce 414) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_BOOLEAN_AND) reduce 414) ((T_BOOLEAN_OR) reduce 414) ((T_COALESCE) reduce 414) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 414) ((T_LOGICAL_OR) reduce 414) ((T_LOGICAL_XOR) reduce 414) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 414) (("|") reduce 414)) 6512 ((("%") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) ((";") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93)) 6513 ((("%") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) ((";") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92)) 6514 ((("%") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) ((";") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94)) 6515 ((("%") reduce 470) (("*") reduce 470) (("+") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) ((";") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470)) 6516 ((("%") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) ((";") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91)) 6517 ((("%") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) ((";") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 6518 ((("%") reduce 472) (("*") reduce 472) (("+") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) ((";") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472)) 6519 ((("%") reduce 421) (("*") reduce 421) (("+") reduce 421) (("-") reduce 421) ((".") reduce 421) (("/") reduce 421) ((";") reduce 421) (("<") reduce 421) ((">") reduce 421) (("?") reduce 421) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_BOOLEAN_AND) reduce 421) ((T_BOOLEAN_OR) reduce 421) ((T_COALESCE) reduce 421) ((T_INSTANCEOF) reduce 421) ((T_IS_EQUAL) reduce 421) ((T_IS_GREATER_OR_EQUAL) reduce 421) ((T_IS_IDENTICAL) reduce 421) ((T_IS_NOT_EQUAL) reduce 421) ((T_IS_NOT_IDENTICAL) reduce 421) ((T_IS_SMALLER_OR_EQUAL) reduce 421) ((T_LOGICAL_AND) reduce 421) ((T_LOGICAL_OR) reduce 421) ((T_LOGICAL_XOR) reduce 421) ((T_POW) reduce 421) ((T_SL) reduce 421) ((T_SPACESHIP) reduce 421) ((T_SR) reduce 421) (("^") reduce 421) (("|") reduce 421)) 6520 ((("%") reduce 471) (("*") reduce 471) (("+") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) ((";") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471)) 6521 ((("%") reduce 473) (("*") reduce 473) (("+") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) ((";") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 6522 ((("%") reduce 534) (("*") reduce 534) (("+") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) ((";") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 6529 ((("%") reduce 536) (("*") reduce 536) (("+") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) ((";") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 6531 ((("%") reduce 535) (("*") reduce 535) (("+") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) ((";") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 6532 ((("%") reduce 540) (("*") reduce 540) (("+") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) ((";") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 6533 ((("%") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) ((";") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 6534 ((("%") reduce 537) (("*") reduce 537) (("+") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) ((";") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 6535 ((("%") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) ((";") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 6538 ((("%") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) ((";") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 6539 ((("%") reduce 538) (("*") reduce 538) (("+") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) ((";") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 6541 ((("%") reduce 539) (("*") reduce 539) (("+") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) ((";") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 6543 ((("%") reduce 474) (("*") reduce 474) (("+") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) ((";") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474)) 6544 ((("%") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) ((";") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 6547 ((("%") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) ((";") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 6548 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 426) (("<") shift) ((">") shift) (("?") reduce 426) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 426) ((T_LOGICAL_OR) reduce 426) ((T_LOGICAL_XOR) reduce 426) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 6549 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 390) (("<") shift) ((">") shift) (("?") reduce 390) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) reduce 390) ((T_COALESCE) reduce 390) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 390) ((T_LOGICAL_OR) reduce 390) ((T_LOGICAL_XOR) reduce 390) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 6550 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 391) (("<") shift) ((">") shift) (("?") reduce 391) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 391) ((T_BOOLEAN_OR) reduce 391) ((T_COALESCE) reduce 391) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 391) ((T_LOGICAL_OR) reduce 391) ((T_LOGICAL_XOR) reduce 391) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 6551 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 396) (("<") shift) ((">") shift) (("?") reduce 396) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_BOOLEAN_AND) reduce 396) ((T_BOOLEAN_OR) reduce 396) ((T_COALESCE) reduce 396) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 396) ((T_LOGICAL_OR) reduce 396) ((T_LOGICAL_XOR) reduce 396) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 396) (("|") reduce 396)) 6552 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 397) (("<") shift) ((">") shift) (("?") reduce 397) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_BOOLEAN_AND) reduce 397) ((T_BOOLEAN_OR) reduce 397) ((T_COALESCE) reduce 397) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 397) ((T_LOGICAL_OR) reduce 397) ((T_LOGICAL_XOR) reduce 397) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 397) (("|") reduce 397)) 6556 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 424) (("<") shift) ((">") shift) (("?") reduce 424) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 424) ((T_LOGICAL_OR) reduce 424) ((T_LOGICAL_XOR) reduce 424) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 6557 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 425) (("<") shift) ((">") shift) (("?") reduce 425) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 425) ((T_LOGICAL_OR) reduce 425) ((T_LOGICAL_XOR) reduce 425) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 6558 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 418) (("<") shift) ((">") shift) (("?") reduce 418) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_BOOLEAN_AND) reduce 418) ((T_BOOLEAN_OR) reduce 418) ((T_COALESCE) reduce 418) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 418) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 418) ((T_IS_NOT_EQUAL) reduce 418) ((T_IS_NOT_IDENTICAL) reduce 418) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 418) ((T_LOGICAL_OR) reduce 418) ((T_LOGICAL_XOR) reduce 418) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 418) ((T_SR) shift) (("^") reduce 418) (("|") reduce 418)) 6559 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 416) (("<") shift) ((">") shift) (("?") reduce 416) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_BOOLEAN_AND) reduce 416) ((T_BOOLEAN_OR) reduce 416) ((T_COALESCE) reduce 416) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 416) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 416) ((T_IS_NOT_EQUAL) reduce 416) ((T_IS_NOT_IDENTICAL) reduce 416) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 416) ((T_LOGICAL_OR) reduce 416) ((T_LOGICAL_XOR) reduce 416) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 416) ((T_SR) shift) (("^") reduce 416) (("|") reduce 416)) 6560 ((("%") reduce 404) (("*") reduce 404) (("+") reduce 404) (("-") reduce 404) ((".") reduce 404) (("/") reduce 404) ((";") reduce 404) (("<") reduce 404) ((">") reduce 404) (("?") reduce 404) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_BOOLEAN_AND) reduce 404) ((T_BOOLEAN_OR) reduce 404) ((T_COALESCE) reduce 404) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 404) ((T_IS_GREATER_OR_EQUAL) reduce 404) ((T_IS_IDENTICAL) reduce 404) ((T_IS_NOT_EQUAL) reduce 404) ((T_IS_NOT_IDENTICAL) reduce 404) ((T_IS_SMALLER_OR_EQUAL) reduce 404) ((T_LOGICAL_AND) reduce 404) ((T_LOGICAL_OR) reduce 404) ((T_LOGICAL_XOR) reduce 404) ((T_POW) shift) ((T_SL) reduce 404) ((T_SPACESHIP) reduce 404) ((T_SR) reduce 404) (("^") reduce 404) (("|") reduce 404)) 6561 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 399) (("/") shift) ((";") reduce 399) (("<") reduce 399) ((">") reduce 399) (("?") reduce 399) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_BOOLEAN_AND) reduce 399) ((T_BOOLEAN_OR) reduce 399) ((T_COALESCE) reduce 399) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 399) ((T_IS_GREATER_OR_EQUAL) reduce 399) ((T_IS_IDENTICAL) reduce 399) ((T_IS_NOT_EQUAL) reduce 399) ((T_IS_NOT_IDENTICAL) reduce 399) ((T_IS_SMALLER_OR_EQUAL) reduce 399) ((T_LOGICAL_AND) reduce 399) ((T_LOGICAL_OR) reduce 399) ((T_LOGICAL_XOR) reduce 399) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 399) ((T_SR) shift) (("^") reduce 399) (("|") reduce 399)) 6562 ((("%") shift) (("*") shift) (("+") reduce 401) (("-") reduce 401) ((".") reduce 401) (("/") shift) ((";") reduce 401) (("<") reduce 401) ((">") reduce 401) (("?") reduce 401) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_BOOLEAN_AND) reduce 401) ((T_BOOLEAN_OR) reduce 401) ((T_COALESCE) reduce 401) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 401) ((T_IS_GREATER_OR_EQUAL) reduce 401) ((T_IS_IDENTICAL) reduce 401) ((T_IS_NOT_EQUAL) reduce 401) ((T_IS_NOT_IDENTICAL) reduce 401) ((T_IS_SMALLER_OR_EQUAL) reduce 401) ((T_LOGICAL_AND) reduce 401) ((T_LOGICAL_OR) reduce 401) ((T_LOGICAL_XOR) reduce 401) ((T_POW) shift) ((T_SL) reduce 401) ((T_SPACESHIP) reduce 401) ((T_SR) reduce 401) (("^") reduce 401) (("|") reduce 401)) 6563 ((("%") shift) (("*") shift) (("+") reduce 400) (("-") reduce 400) ((".") reduce 400) (("/") shift) ((";") reduce 400) (("<") reduce 400) ((">") reduce 400) (("?") reduce 400) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_BOOLEAN_AND) reduce 400) ((T_BOOLEAN_OR) reduce 400) ((T_COALESCE) reduce 400) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 400) ((T_IS_GREATER_OR_EQUAL) reduce 400) ((T_IS_IDENTICAL) reduce 400) ((T_IS_NOT_EQUAL) reduce 400) ((T_IS_NOT_IDENTICAL) reduce 400) ((T_IS_SMALLER_OR_EQUAL) reduce 400) ((T_LOGICAL_AND) reduce 400) ((T_LOGICAL_OR) reduce 400) ((T_LOGICAL_XOR) reduce 400) ((T_POW) shift) ((T_SL) reduce 400) ((T_SPACESHIP) reduce 400) ((T_SR) reduce 400) (("^") reduce 400) (("|") reduce 400)) 6564 ((("%") reduce 402) (("*") reduce 402) (("+") reduce 402) (("-") reduce 402) ((".") reduce 402) (("/") reduce 402) ((";") reduce 402) (("<") reduce 402) ((">") reduce 402) (("?") reduce 402) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_BOOLEAN_AND) reduce 402) ((T_BOOLEAN_OR) reduce 402) ((T_COALESCE) reduce 402) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 402) ((T_IS_GREATER_OR_EQUAL) reduce 402) ((T_IS_IDENTICAL) reduce 402) ((T_IS_NOT_EQUAL) reduce 402) ((T_IS_NOT_IDENTICAL) reduce 402) ((T_IS_SMALLER_OR_EQUAL) reduce 402) ((T_LOGICAL_AND) reduce 402) ((T_LOGICAL_OR) reduce 402) ((T_LOGICAL_XOR) reduce 402) ((T_POW) shift) ((T_SL) reduce 402) ((T_SPACESHIP) reduce 402) ((T_SR) reduce 402) (("^") reduce 402) (("|") reduce 402)) 6565 ((("%") reduce 405) (("*") reduce 405) (("+") reduce 405) (("-") reduce 405) ((".") reduce 405) (("/") reduce 405) ((";") reduce 405) (("<") reduce 405) ((">") reduce 405) (("?") reduce 405) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_BOOLEAN_AND) reduce 405) ((T_BOOLEAN_OR) reduce 405) ((T_COALESCE) reduce 405) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 405) ((T_IS_GREATER_OR_EQUAL) reduce 405) ((T_IS_IDENTICAL) reduce 405) ((T_IS_NOT_EQUAL) reduce 405) ((T_IS_NOT_IDENTICAL) reduce 405) ((T_IS_SMALLER_OR_EQUAL) reduce 405) ((T_LOGICAL_AND) reduce 405) ((T_LOGICAL_OR) reduce 405) ((T_LOGICAL_XOR) reduce 405) ((T_POW) shift) ((T_SL) reduce 405) ((T_SPACESHIP) reduce 405) ((T_SR) reduce 405) (("^") reduce 405) (("|") reduce 405)) 6566 ((("(") reduce 93) ((",") reduce 93) (("]") reduce 93)) 6567 ((("(") reduce 92) ((",") reduce 92) (("]") reduce 92)) 6568 ((("(") reduce 94) ((",") reduce 94) (("]") reduce 94)) 6569 ((("(") reduce 470) ((",") reduce 470) (("]") reduce 470)) 6570 ((("(") reduce 91) ((",") reduce 91) (("]") reduce 91)) 6571 (((",") reduce 97) (("]") reduce 97)) 6572 (((",") shift) (("]") reduce 123)) 6573 ((("(") shift) ((",") reduce 95) (("]") reduce 95)) 6574 ((("(") reduce 471) ((",") reduce 471) (("]") reduce 471)) 6576 (((",") reduce 96) (("]") reduce 96)) 6577 (((",") reduce 288) (("]") reduce 288)) 6581 (((",") reduce 289) (("]") reduce 289)) 6582 (((",") reduce 290) (("]") reduce 290)) 6583 (((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_STATIC) shift) ((T_STRING) shift) (("]") reduce 124)) 6585 (((T_ABSTRACT) reduce 99) ((T_ATTRIBUTE) reduce 99) ((T_CASE) reduce 99) ((T_CONST) reduce 99) ((T_FINAL) reduce 99) ((T_FUNCTION) reduce 99) ((T_PRIVATE) reduce 99) ((T_PROTECTED) reduce 99) ((T_PUBLIC) reduce 99) ((T_READONLY) reduce 99) ((T_STATIC) reduce 99) ((T_VAR) reduce 99)) 6586 (((",") reduce 98) (("]") reduce 98)) 6587 (((",") reduce 93) (("{") reduce 93)) 6588 (((",") reduce 92) (("{") reduce 92)) 6589 (((",") reduce 94) (("{") reduce 94)) 6590 (((",") reduce 470) (("{") reduce 470)) 6591 (((",") reduce 91) (("{") reduce 91)) 6592 (((",") reduce 313) (("{") reduce 313)) 6593 (((",") shift) (("{") reduce 210)) 6594 (((",") reduce 471) (("{") reduce 471)) 6596 (((",") reduce 314) (("{") reduce 314)) 6597 (((T_IMPLEMENTS) reduce 93) (("{") reduce 93)) 6598 (((T_IMPLEMENTS) reduce 92) (("{") reduce 92)) 6599 (((T_IMPLEMENTS) reduce 94) (("{") reduce 94)) 6600 (((T_IMPLEMENTS) reduce 470) (("{") reduce 470)) 6601 (((T_IMPLEMENTS) reduce 91) (("{") reduce 91)) 6602 (((T_IMPLEMENTS) reduce 206) (("{") reduce 206)) 6603 (((T_IMPLEMENTS) reduce 471) (("{") reduce 471)) 6604 (((T_EXTENDS) reduce 288) ((T_IMPLEMENTS) reduce 288) (("{") reduce 288)) 6608 (((T_EXTENDS) reduce 289) ((T_IMPLEMENTS) reduce 289) (("{") reduce 289)) 6609 (((T_EXTENDS) reduce 290) ((T_IMPLEMENTS) reduce 290) (("{") reduce 290)) 6610 (((T_ABSTRACT) reduce 191) ((T_CLASS) reduce 191) ((T_FINAL) reduce 191) ((T_READONLY) reduce 191)) 6613 (((T_ABSTRACT) reduce 99) ((T_ATTRIBUTE) reduce 99) ((T_CLASS) reduce 99) ((T_FINAL) reduce 99) ((T_READONLY) reduce 99)) 6615 ((("%") reduce 474) (("(") reduce 474) ((")") reduce 474) (("*") reduce 474) (("+") reduce 474) ((",") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474)) 6625 ((("%") reduce 230) ((")") reduce 230) (("*") reduce 230) (("+") reduce 230) ((",") reduce 230) (("-") reduce 230) ((".") reduce 230) (("/") reduce 230) (("<") reduce 230) ((">") reduce 230) (("?") reduce 230) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_BOOLEAN_AND) reduce 230) ((T_BOOLEAN_OR) reduce 230) ((T_COALESCE) reduce 230) ((T_INSTANCEOF) reduce 230) ((T_IS_EQUAL) reduce 230) ((T_IS_GREATER_OR_EQUAL) reduce 230) ((T_IS_IDENTICAL) reduce 230) ((T_IS_NOT_EQUAL) reduce 230) ((T_IS_NOT_IDENTICAL) reduce 230) ((T_IS_SMALLER_OR_EQUAL) reduce 230) ((T_LOGICAL_AND) reduce 230) ((T_LOGICAL_OR) reduce 230) ((T_LOGICAL_XOR) reduce 230) ((T_POW) reduce 230) ((T_SL) reduce 230) ((T_SPACESHIP) reduce 230) ((T_SR) reduce 230) (("^") reduce 230) (("|") reduce 230)) 6628 (((")") reduce 557) ((",") reduce 557) (("=") shift)) 6632 ((("%") reduce 575) ((")") reduce 575) (("*") reduce 575) (("+") reduce 575) ((",") reduce 575) (("-") reduce 575) ((".") reduce 575) (("/") reduce 575) (("<") reduce 575) ((">") reduce 575) (("?") reduce 575) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_BOOLEAN_AND) reduce 575) ((T_BOOLEAN_OR) reduce 575) ((T_COALESCE) reduce 575) ((T_INSTANCEOF) reduce 575) ((T_IS_EQUAL) reduce 575) ((T_IS_GREATER_OR_EQUAL) reduce 575) ((T_IS_IDENTICAL) reduce 575) ((T_IS_NOT_EQUAL) reduce 575) ((T_IS_NOT_IDENTICAL) reduce 575) ((T_IS_SMALLER_OR_EQUAL) reduce 575) ((T_LOGICAL_AND) reduce 575) ((T_LOGICAL_OR) reduce 575) ((T_LOGICAL_XOR) reduce 575) ((T_POW) reduce 575) ((T_SL) reduce 575) ((T_SPACESHIP) reduce 575) ((T_SR) reduce 575) (("^") reduce 575) (("|") reduce 575)) 6633 ((("%") reduce 428) ((")") reduce 428) (("*") reduce 428) (("+") reduce 428) ((",") reduce 428) (("-") reduce 428) ((".") reduce 428) (("/") reduce 428) (("<") reduce 428) ((">") reduce 428) (("?") reduce 428) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_BOOLEAN_AND) reduce 428) ((T_BOOLEAN_OR) reduce 428) ((T_COALESCE) reduce 428) ((T_INSTANCEOF) reduce 428) ((T_IS_EQUAL) reduce 428) ((T_IS_GREATER_OR_EQUAL) reduce 428) ((T_IS_IDENTICAL) reduce 428) ((T_IS_NOT_EQUAL) reduce 428) ((T_IS_NOT_IDENTICAL) reduce 428) ((T_IS_SMALLER_OR_EQUAL) reduce 428) ((T_LOGICAL_AND) reduce 428) ((T_LOGICAL_OR) reduce 428) ((T_LOGICAL_XOR) reduce 428) ((T_POW) shift) ((T_SL) reduce 428) ((T_SPACESHIP) reduce 428) ((T_SR) reduce 428) (("^") reduce 428) (("|") reduce 428)) 6634 ((("%") shift) ((")") reduce 578) (("*") shift) (("+") shift) ((",") reduce 578) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 6635 ((("%") shift) ((")") reduce 577) (("*") shift) (("+") shift) ((",") reduce 577) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 6636 ((("%") reduce 387) ((")") reduce 387) (("*") reduce 387) (("+") reduce 387) ((",") reduce 387) (("-") reduce 387) ((".") reduce 387) (("/") reduce 387) (("<") reduce 387) ((">") reduce 387) (("?") reduce 387) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_BOOLEAN_AND) reduce 387) ((T_BOOLEAN_OR) reduce 387) ((T_COALESCE) reduce 387) ((T_INSTANCEOF) reduce 387) ((T_IS_EQUAL) reduce 387) ((T_IS_GREATER_OR_EQUAL) reduce 387) ((T_IS_IDENTICAL) reduce 387) ((T_IS_NOT_EQUAL) reduce 387) ((T_IS_NOT_IDENTICAL) reduce 387) ((T_IS_SMALLER_OR_EQUAL) reduce 387) ((T_LOGICAL_AND) reduce 387) ((T_LOGICAL_OR) reduce 387) ((T_LOGICAL_XOR) reduce 387) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 387) ((T_SL) reduce 387) ((T_SPACESHIP) reduce 387) ((T_SR) reduce 387) (("[") reduce 510) (("^") reduce 387) (("{") reduce 510) (("|") reduce 387)) 6638 ((("%") reduce 435) ((")") reduce 435) (("*") reduce 435) (("+") reduce 435) ((",") reduce 435) (("-") reduce 435) ((".") reduce 435) (("/") reduce 435) (("<") reduce 435) ((">") reduce 435) (("?") reduce 435) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_BOOLEAN_AND) reduce 435) ((T_BOOLEAN_OR) reduce 435) ((T_COALESCE) reduce 435) ((T_INSTANCEOF) reduce 435) ((T_IS_EQUAL) reduce 435) ((T_IS_GREATER_OR_EQUAL) reduce 435) ((T_IS_IDENTICAL) reduce 435) ((T_IS_NOT_EQUAL) reduce 435) ((T_IS_NOT_IDENTICAL) reduce 435) ((T_IS_SMALLER_OR_EQUAL) reduce 435) ((T_LOGICAL_AND) reduce 435) ((T_LOGICAL_OR) reduce 435) ((T_LOGICAL_XOR) reduce 435) ((T_POW) reduce 435) ((T_SL) reduce 435) ((T_SPACESHIP) reduce 435) ((T_SR) reduce 435) (("^") reduce 435) (("|") reduce 435)) 6640 ((("%") reduce 476) ((")") reduce 476) (("*") reduce 476) (("+") reduce 476) ((",") reduce 476) (("-") reduce 476) ((".") reduce 476) (("/") reduce 476) (("<") reduce 476) ((">") reduce 476) (("?") reduce 476) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_BOOLEAN_AND) reduce 476) ((T_BOOLEAN_OR) reduce 476) ((T_COALESCE) reduce 476) ((T_INSTANCEOF) reduce 476) ((T_IS_EQUAL) reduce 476) ((T_IS_GREATER_OR_EQUAL) reduce 476) ((T_IS_IDENTICAL) reduce 476) ((T_IS_NOT_EQUAL) reduce 476) ((T_IS_NOT_IDENTICAL) reduce 476) ((T_IS_SMALLER_OR_EQUAL) reduce 476) ((T_LOGICAL_AND) reduce 476) ((T_LOGICAL_OR) reduce 476) ((T_LOGICAL_XOR) reduce 476) ((T_POW) reduce 476) ((T_SL) reduce 476) ((T_SPACESHIP) reduce 476) ((T_SR) reduce 476) (("^") reduce 476) (("|") reduce 476)) 6643 ((("%") reduce 579) ((")") reduce 579) (("*") reduce 579) (("+") reduce 579) ((",") reduce 579) (("-") reduce 579) ((".") reduce 579) (("/") reduce 579) (("<") reduce 579) ((">") reduce 579) (("?") reduce 579) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_BOOLEAN_AND) reduce 579) ((T_BOOLEAN_OR) reduce 579) ((T_COALESCE) reduce 579) ((T_INSTANCEOF) reduce 579) ((T_IS_EQUAL) reduce 579) ((T_IS_GREATER_OR_EQUAL) reduce 579) ((T_IS_IDENTICAL) reduce 579) ((T_IS_NOT_EQUAL) reduce 579) ((T_IS_NOT_IDENTICAL) reduce 579) ((T_IS_SMALLER_OR_EQUAL) reduce 579) ((T_LOGICAL_AND) reduce 579) ((T_LOGICAL_OR) reduce 579) ((T_LOGICAL_XOR) reduce 579) ((T_POW) reduce 579) ((T_SL) reduce 579) ((T_SPACESHIP) reduce 579) ((T_SR) reduce 579) (("^") reduce 579) (("|") reduce 579)) 6646 ((("%") reduce 576) ((")") reduce 576) (("*") reduce 576) (("+") reduce 576) ((",") reduce 576) (("-") reduce 576) ((".") reduce 576) (("/") reduce 576) (("<") reduce 576) ((">") reduce 576) (("?") reduce 576) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_BOOLEAN_AND) reduce 576) ((T_BOOLEAN_OR) reduce 576) ((T_COALESCE) reduce 576) ((T_INSTANCEOF) reduce 576) ((T_IS_EQUAL) reduce 576) ((T_IS_GREATER_OR_EQUAL) reduce 576) ((T_IS_IDENTICAL) reduce 576) ((T_IS_NOT_EQUAL) reduce 576) ((T_IS_NOT_IDENTICAL) reduce 576) ((T_IS_SMALLER_OR_EQUAL) reduce 576) ((T_LOGICAL_AND) reduce 576) ((T_LOGICAL_OR) reduce 576) ((T_LOGICAL_XOR) reduce 576) ((T_POW) reduce 576) ((T_SL) reduce 576) ((T_SPACESHIP) reduce 576) ((T_SR) reduce 576) (("^") reduce 576) (("|") reduce 576)) 6647 ((("%") reduce 429) ((")") reduce 429) (("*") reduce 429) (("+") reduce 429) ((",") reduce 429) (("-") reduce 429) ((".") reduce 429) (("/") reduce 429) (("<") reduce 429) ((">") reduce 429) (("?") reduce 429) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_BOOLEAN_AND) reduce 429) ((T_BOOLEAN_OR) reduce 429) ((T_COALESCE) reduce 429) ((T_INSTANCEOF) reduce 429) ((T_IS_EQUAL) reduce 429) ((T_IS_GREATER_OR_EQUAL) reduce 429) ((T_IS_IDENTICAL) reduce 429) ((T_IS_NOT_EQUAL) reduce 429) ((T_IS_NOT_IDENTICAL) reduce 429) ((T_IS_SMALLER_OR_EQUAL) reduce 429) ((T_LOGICAL_AND) reduce 429) ((T_LOGICAL_OR) reduce 429) ((T_LOGICAL_XOR) reduce 429) ((T_POW) shift) ((T_SL) reduce 429) ((T_SPACESHIP) reduce 429) ((T_SR) reduce 429) (("^") reduce 429) (("|") reduce 429)) 6648 ((("%") reduce 389) ((")") reduce 389) (("*") reduce 389) (("+") reduce 389) ((",") reduce 389) (("-") reduce 389) ((".") reduce 389) (("/") reduce 389) (("<") reduce 389) ((">") reduce 389) (("?") reduce 389) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_BOOLEAN_AND) reduce 389) ((T_BOOLEAN_OR) reduce 389) ((T_COALESCE) reduce 389) ((T_INSTANCEOF) reduce 389) ((T_IS_EQUAL) reduce 389) ((T_IS_GREATER_OR_EQUAL) reduce 389) ((T_IS_IDENTICAL) reduce 389) ((T_IS_NOT_EQUAL) reduce 389) ((T_IS_NOT_IDENTICAL) reduce 389) ((T_IS_SMALLER_OR_EQUAL) reduce 389) ((T_LOGICAL_AND) reduce 389) ((T_LOGICAL_OR) reduce 389) ((T_LOGICAL_XOR) reduce 389) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 389) ((T_SL) reduce 389) ((T_SPACESHIP) reduce 389) ((T_SR) reduce 389) (("[") reduce 510) (("^") reduce 389) (("{") reduce 510) (("|") reduce 389)) 6649 ((("%") reduce 372) ((")") reduce 372) (("*") reduce 372) (("+") reduce 372) ((",") reduce 372) (("-") reduce 372) ((".") reduce 372) (("/") reduce 372) (("<") reduce 372) ((">") reduce 372) (("?") reduce 372) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_BOOLEAN_AND) reduce 372) ((T_BOOLEAN_OR) reduce 372) ((T_COALESCE) reduce 372) ((T_INSTANCEOF) reduce 372) ((T_IS_EQUAL) reduce 372) ((T_IS_GREATER_OR_EQUAL) reduce 372) ((T_IS_IDENTICAL) reduce 372) ((T_IS_NOT_EQUAL) reduce 372) ((T_IS_NOT_IDENTICAL) reduce 372) ((T_IS_SMALLER_OR_EQUAL) reduce 372) ((T_LOGICAL_AND) reduce 372) ((T_LOGICAL_OR) reduce 372) ((T_LOGICAL_XOR) reduce 372) ((T_POW) reduce 372) ((T_SL) reduce 372) ((T_SPACESHIP) reduce 372) ((T_SR) reduce 372) (("^") reduce 372) (("|") reduce 372)) 6650 ((("%") reduce 433) ((")") reduce 433) (("*") reduce 433) (("+") reduce 433) ((",") reduce 433) (("-") reduce 433) ((".") reduce 433) (("/") reduce 433) (("<") reduce 433) ((">") reduce 433) (("?") reduce 433) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_BOOLEAN_AND) reduce 433) ((T_BOOLEAN_OR) reduce 433) ((T_COALESCE) reduce 433) ((T_INSTANCEOF) reduce 433) ((T_IS_EQUAL) reduce 433) ((T_IS_GREATER_OR_EQUAL) reduce 433) ((T_IS_IDENTICAL) reduce 433) ((T_IS_NOT_EQUAL) reduce 433) ((T_IS_NOT_IDENTICAL) reduce 433) ((T_IS_SMALLER_OR_EQUAL) reduce 433) ((T_LOGICAL_AND) reduce 433) ((T_LOGICAL_OR) reduce 433) ((T_LOGICAL_XOR) reduce 433) ((T_POW) shift) ((T_SL) reduce 433) ((T_SPACESHIP) reduce 433) ((T_SR) reduce 433) (("^") reduce 433) (("|") reduce 433)) 6651 ((("%") reduce 431) ((")") reduce 431) (("*") reduce 431) (("+") reduce 431) ((",") reduce 431) (("-") reduce 431) ((".") reduce 431) (("/") reduce 431) (("<") reduce 431) ((">") reduce 431) (("?") reduce 431) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_BOOLEAN_AND) reduce 431) ((T_BOOLEAN_OR) reduce 431) ((T_COALESCE) reduce 431) ((T_INSTANCEOF) reduce 431) ((T_IS_EQUAL) reduce 431) ((T_IS_GREATER_OR_EQUAL) reduce 431) ((T_IS_IDENTICAL) reduce 431) ((T_IS_NOT_EQUAL) reduce 431) ((T_IS_NOT_IDENTICAL) reduce 431) ((T_IS_SMALLER_OR_EQUAL) reduce 431) ((T_LOGICAL_AND) reduce 431) ((T_LOGICAL_OR) reduce 431) ((T_LOGICAL_XOR) reduce 431) ((T_POW) shift) ((T_SL) reduce 431) ((T_SPACESHIP) reduce 431) ((T_SR) reduce 431) (("^") reduce 431) (("|") reduce 431)) 6654 ((("%") reduce 482) (("(") reduce 482) ((")") reduce 482) (("*") reduce 482) (("+") reduce 482) ((",") reduce 482) (("-") reduce 482) ((".") reduce 482) (("/") reduce 482) (("<") reduce 482) ((">") reduce 482) (("?") reduce 482) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_BOOLEAN_AND) reduce 482) ((T_BOOLEAN_OR) reduce 482) ((T_COALESCE) reduce 482) ((T_INSTANCEOF) reduce 482) ((T_IS_EQUAL) reduce 482) ((T_IS_GREATER_OR_EQUAL) reduce 482) ((T_IS_IDENTICAL) reduce 482) ((T_IS_NOT_EQUAL) reduce 482) ((T_IS_NOT_IDENTICAL) reduce 482) ((T_IS_SMALLER_OR_EQUAL) reduce 482) ((T_LOGICAL_AND) reduce 482) ((T_LOGICAL_OR) reduce 482) ((T_LOGICAL_XOR) reduce 482) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 482) ((T_OBJECT_OPERATOR) reduce 482) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 482) ((T_POW) reduce 482) ((T_SL) reduce 482) ((T_SPACESHIP) reduce 482) ((T_SR) reduce 482) (("[") reduce 482) (("^") reduce 482) (("{") reduce 482) (("|") reduce 482)) 6655 ((("%") reduce 436) ((")") reduce 436) (("*") reduce 436) (("+") reduce 436) ((",") reduce 436) (("-") reduce 436) ((".") reduce 436) (("/") reduce 436) (("<") reduce 436) ((">") reduce 436) (("?") reduce 436) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_BOOLEAN_AND) reduce 436) ((T_BOOLEAN_OR) reduce 436) ((T_COALESCE) reduce 436) ((T_INSTANCEOF) reduce 436) ((T_IS_EQUAL) reduce 436) ((T_IS_GREATER_OR_EQUAL) reduce 436) ((T_IS_IDENTICAL) reduce 436) ((T_IS_NOT_EQUAL) reduce 436) ((T_IS_NOT_IDENTICAL) reduce 436) ((T_IS_SMALLER_OR_EQUAL) reduce 436) ((T_LOGICAL_AND) reduce 436) ((T_LOGICAL_OR) reduce 436) ((T_LOGICAL_XOR) reduce 436) ((T_POW) shift) ((T_SL) reduce 436) ((T_SPACESHIP) reduce 436) ((T_SR) reduce 436) (("^") reduce 436) (("|") reduce 436)) 6656 ((("%") reduce 409) ((")") reduce 409) (("*") reduce 409) (("+") reduce 409) ((",") reduce 409) (("-") reduce 409) ((".") reduce 409) (("/") reduce 409) (("<") reduce 409) ((">") reduce 409) (("?") reduce 409) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_BOOLEAN_AND) reduce 409) ((T_BOOLEAN_OR) reduce 409) ((T_COALESCE) reduce 409) ((T_INSTANCEOF) reduce 409) ((T_IS_EQUAL) reduce 409) ((T_IS_GREATER_OR_EQUAL) reduce 409) ((T_IS_IDENTICAL) reduce 409) ((T_IS_NOT_EQUAL) reduce 409) ((T_IS_NOT_IDENTICAL) reduce 409) ((T_IS_SMALLER_OR_EQUAL) reduce 409) ((T_LOGICAL_AND) reduce 409) ((T_LOGICAL_OR) reduce 409) ((T_LOGICAL_XOR) reduce 409) ((T_POW) shift) ((T_SL) reduce 409) ((T_SPACESHIP) reduce 409) ((T_SR) reduce 409) (("^") reduce 409) (("|") reduce 409)) 6657 ((("%") reduce 408) ((")") reduce 408) (("*") reduce 408) (("+") reduce 408) ((",") reduce 408) (("-") reduce 408) ((".") reduce 408) (("/") reduce 408) (("<") reduce 408) ((">") reduce 408) (("?") reduce 408) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_BOOLEAN_AND) reduce 408) ((T_BOOLEAN_OR) reduce 408) ((T_COALESCE) reduce 408) ((T_INSTANCEOF) reduce 408) ((T_IS_EQUAL) reduce 408) ((T_IS_GREATER_OR_EQUAL) reduce 408) ((T_IS_IDENTICAL) reduce 408) ((T_IS_NOT_EQUAL) reduce 408) ((T_IS_NOT_IDENTICAL) reduce 408) ((T_IS_SMALLER_OR_EQUAL) reduce 408) ((T_LOGICAL_AND) reduce 408) ((T_LOGICAL_OR) reduce 408) ((T_LOGICAL_XOR) reduce 408) ((T_POW) shift) ((T_SL) reduce 408) ((T_SPACESHIP) reduce 408) ((T_SR) reduce 408) (("^") reduce 408) (("|") reduce 408)) 6659 ((("%") reduce 422) (("(") reduce 517) ((")") reduce 422) (("*") reduce 422) (("+") reduce 422) ((",") reduce 422) (("-") reduce 422) ((".") reduce 422) (("/") reduce 422) (("<") reduce 422) ((">") reduce 422) (("?") reduce 422) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_BOOLEAN_AND) reduce 422) ((T_BOOLEAN_OR) reduce 422) ((T_COALESCE) reduce 422) ((T_INSTANCEOF) reduce 422) ((T_IS_EQUAL) reduce 422) ((T_IS_GREATER_OR_EQUAL) reduce 422) ((T_IS_IDENTICAL) reduce 422) ((T_IS_NOT_EQUAL) reduce 422) ((T_IS_NOT_IDENTICAL) reduce 422) ((T_IS_SMALLER_OR_EQUAL) reduce 422) ((T_LOGICAL_AND) reduce 422) ((T_LOGICAL_OR) reduce 422) ((T_LOGICAL_XOR) reduce 422) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 511) ((T_OBJECT_OPERATOR) reduce 511) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 511) ((T_POW) reduce 422) ((T_SL) reduce 422) ((T_SPACESHIP) reduce 422) ((T_SR) reduce 422) (("[") reduce 511) (("^") reduce 422) (("{") reduce 511) (("|") reduce 422)) 6660 ((("%") reduce 531) (("(") reduce 531) ((")") reduce 531) (("*") reduce 531) (("+") reduce 531) ((",") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) (("=") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AND_EQUAL) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_COALESCE_EQUAL) reduce 531) ((T_CONCAT_EQUAL) reduce 531) ((T_DEC) reduce 531) ((T_DIV_EQUAL) reduce 531) ((T_INC) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_MINUS_EQUAL) reduce 531) ((T_MOD_EQUAL) reduce 531) ((T_MUL_EQUAL) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_OR_EQUAL) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_PLUS_EQUAL) reduce 531) ((T_POW) reduce 531) ((T_POW_EQUAL) reduce 531) ((T_SL) reduce 531) ((T_SL_EQUAL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) ((T_SR_EQUAL) reduce 531) ((T_XOR_EQUAL) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 6663 ((("%") reduce 530) (("(") reduce 530) ((")") reduce 530) (("*") reduce 530) (("+") reduce 530) ((",") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) (("=") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AND_EQUAL) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_COALESCE_EQUAL) reduce 530) ((T_CONCAT_EQUAL) reduce 530) ((T_DEC) reduce 530) ((T_DIV_EQUAL) reduce 530) ((T_INC) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_MINUS_EQUAL) reduce 530) ((T_MOD_EQUAL) reduce 530) ((T_MUL_EQUAL) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_OR_EQUAL) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_PLUS_EQUAL) reduce 530) ((T_POW) reduce 530) ((T_POW_EQUAL) reduce 530) ((T_SL) reduce 530) ((T_SL_EQUAL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) ((T_SR_EQUAL) reduce 530) ((T_XOR_EQUAL) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 6665 ((("%") reduce 485) (("(") reduce 485) ((")") reduce 485) (("*") reduce 485) (("+") reduce 485) ((",") reduce 485) (("-") reduce 485) ((".") reduce 485) (("/") reduce 485) (("<") reduce 485) ((">") reduce 485) (("?") reduce 485) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_BOOLEAN_AND) reduce 485) ((T_BOOLEAN_OR) reduce 485) ((T_COALESCE) reduce 485) ((T_INSTANCEOF) reduce 485) ((T_IS_EQUAL) reduce 485) ((T_IS_GREATER_OR_EQUAL) reduce 485) ((T_IS_IDENTICAL) reduce 485) ((T_IS_NOT_EQUAL) reduce 485) ((T_IS_NOT_IDENTICAL) reduce 485) ((T_IS_SMALLER_OR_EQUAL) reduce 485) ((T_LOGICAL_AND) reduce 485) ((T_LOGICAL_OR) reduce 485) ((T_LOGICAL_XOR) reduce 485) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 485) ((T_OBJECT_OPERATOR) reduce 485) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 485) ((T_POW) reduce 485) ((T_SL) reduce 485) ((T_SPACESHIP) reduce 485) ((T_SR) reduce 485) (("[") reduce 485) (("^") reduce 485) (("{") reduce 485) (("|") reduce 485)) 6666 ((("%") reduce 410) ((")") reduce 410) (("*") reduce 410) (("+") reduce 410) ((",") reduce 410) (("-") reduce 410) ((".") reduce 410) (("/") reduce 410) (("<") reduce 410) ((">") reduce 410) (("?") reduce 410) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_BOOLEAN_AND) reduce 410) ((T_BOOLEAN_OR) reduce 410) ((T_COALESCE) reduce 410) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 410) ((T_IS_GREATER_OR_EQUAL) reduce 410) ((T_IS_IDENTICAL) reduce 410) ((T_IS_NOT_EQUAL) reduce 410) ((T_IS_NOT_IDENTICAL) reduce 410) ((T_IS_SMALLER_OR_EQUAL) reduce 410) ((T_LOGICAL_AND) reduce 410) ((T_LOGICAL_OR) reduce 410) ((T_LOGICAL_XOR) reduce 410) ((T_POW) shift) ((T_SL) reduce 410) ((T_SPACESHIP) reduce 410) ((T_SR) reduce 410) (("^") reduce 410) (("|") reduce 410)) 6668 ((("%") reduce 503) (("(") reduce 541) ((")") reduce 503) (("*") reduce 503) (("+") reduce 503) ((",") reduce 503) (("-") reduce 503) ((".") reduce 503) (("/") reduce 503) (("<") reduce 503) ((">") reduce 503) (("?") reduce 503) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_BOOLEAN_AND) reduce 503) ((T_BOOLEAN_OR) reduce 503) ((T_COALESCE) reduce 503) ((T_DOUBLE_ARROW) reduce 503) ((T_INSTANCEOF) reduce 503) ((T_IS_EQUAL) reduce 503) ((T_IS_GREATER_OR_EQUAL) reduce 503) ((T_IS_IDENTICAL) reduce 503) ((T_IS_NOT_EQUAL) reduce 503) ((T_IS_NOT_IDENTICAL) reduce 503) ((T_IS_SMALLER_OR_EQUAL) reduce 503) ((T_LOGICAL_AND) reduce 503) ((T_LOGICAL_OR) reduce 503) ((T_LOGICAL_XOR) reduce 503) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 503) ((T_OBJECT_OPERATOR) reduce 503) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 503) ((T_POW) reduce 503) ((T_SL) reduce 503) ((T_SPACESHIP) reduce 503) ((T_SR) reduce 503) (("[") reduce 503) (("^") reduce 503) (("{") reduce 503) (("|") reduce 503)) 6670 ((("%") reduce 532) (("(") reduce 543) ((")") reduce 532) (("*") reduce 532) (("+") reduce 532) ((",") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) (("<") reduce 532) (("=") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AND_EQUAL) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_COALESCE_EQUAL) reduce 532) ((T_CONCAT_EQUAL) reduce 532) ((T_DEC) reduce 532) ((T_DIV_EQUAL) reduce 532) ((T_DOUBLE_ARROW) reduce 532) ((T_INC) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_MINUS_EQUAL) reduce 532) ((T_MOD_EQUAL) reduce 532) ((T_MUL_EQUAL) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_OR_EQUAL) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_PLUS_EQUAL) reduce 532) ((T_POW) reduce 532) ((T_POW_EQUAL) reduce 532) ((T_SL) reduce 532) ((T_SL_EQUAL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) ((T_SR_EQUAL) reduce 532) ((T_XOR_EQUAL) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 6673 ((("%") reduce 505) (("(") reduce 542) ((")") reduce 505) (("*") reduce 505) (("+") reduce 505) ((",") reduce 505) (("-") reduce 505) ((".") reduce 505) (("/") reduce 505) (("<") reduce 505) ((">") reduce 505) (("?") reduce 505) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_BOOLEAN_AND) reduce 505) ((T_BOOLEAN_OR) reduce 505) ((T_COALESCE) reduce 505) ((T_DOUBLE_ARROW) reduce 505) ((T_INSTANCEOF) reduce 505) ((T_IS_EQUAL) reduce 505) ((T_IS_GREATER_OR_EQUAL) reduce 505) ((T_IS_IDENTICAL) reduce 505) ((T_IS_NOT_EQUAL) reduce 505) ((T_IS_NOT_IDENTICAL) reduce 505) ((T_IS_SMALLER_OR_EQUAL) reduce 505) ((T_LOGICAL_AND) reduce 505) ((T_LOGICAL_OR) reduce 505) ((T_LOGICAL_XOR) reduce 505) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 505) ((T_OBJECT_OPERATOR) reduce 505) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 505) ((T_POW) reduce 505) ((T_SL) reduce 505) ((T_SPACESHIP) reduce 505) ((T_SR) reduce 505) (("[") reduce 505) (("^") reduce 505) (("{") reduce 505) (("|") reduce 505)) 6674 ((("%") reduce 467) (("(") reduce 467) ((")") reduce 467) (("*") reduce 467) (("+") reduce 467) ((",") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) (("<") reduce 467) (("=") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AND_EQUAL) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_COALESCE_EQUAL) reduce 467) ((T_CONCAT_EQUAL) reduce 467) ((T_DEC) reduce 467) ((T_DIV_EQUAL) reduce 467) ((T_DOUBLE_ARROW) reduce 467) ((T_INC) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_MINUS_EQUAL) reduce 467) ((T_MOD_EQUAL) reduce 467) ((T_MUL_EQUAL) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_OR_EQUAL) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_PLUS_EQUAL) reduce 467) ((T_POW) reduce 467) ((T_POW_EQUAL) reduce 467) ((T_SL) reduce 467) ((T_SL_EQUAL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) ((T_SR_EQUAL) reduce 467) ((T_XOR_EQUAL) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 6675 ((("%") reduce 469) (("(") reduce 469) ((")") reduce 469) (("*") reduce 469) (("+") reduce 469) ((",") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) (("<") reduce 469) (("=") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AND_EQUAL) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_COALESCE_EQUAL) reduce 469) ((T_CONCAT_EQUAL) reduce 469) ((T_DEC) reduce 469) ((T_DIV_EQUAL) reduce 469) ((T_DOUBLE_ARROW) reduce 469) ((T_INC) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_MINUS_EQUAL) reduce 469) ((T_MOD_EQUAL) reduce 469) ((T_MUL_EQUAL) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_OR_EQUAL) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_PLUS_EQUAL) reduce 469) ((T_POW) reduce 469) ((T_POW_EQUAL) reduce 469) ((T_SL) reduce 469) ((T_SL_EQUAL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) ((T_SR_EQUAL) reduce 469) ((T_XOR_EQUAL) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 6677 ((("%") reduce 446) ((")") reduce 446) (("*") reduce 446) (("+") reduce 446) ((",") reduce 446) (("-") reduce 446) ((".") reduce 446) (("/") reduce 446) (("<") reduce 446) ((">") reduce 446) (("?") reduce 446) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_BOOLEAN_AND) reduce 446) ((T_BOOLEAN_OR) reduce 446) ((T_COALESCE) reduce 446) ((T_DOUBLE_ARROW) reduce 446) ((T_INSTANCEOF) reduce 446) ((T_IS_EQUAL) reduce 446) ((T_IS_GREATER_OR_EQUAL) reduce 446) ((T_IS_IDENTICAL) reduce 446) ((T_IS_NOT_EQUAL) reduce 446) ((T_IS_NOT_IDENTICAL) reduce 446) ((T_IS_SMALLER_OR_EQUAL) reduce 446) ((T_LOGICAL_AND) reduce 446) ((T_LOGICAL_OR) reduce 446) ((T_LOGICAL_XOR) reduce 446) ((T_POW) reduce 446) ((T_SL) reduce 446) ((T_SPACESHIP) reduce 446) ((T_SR) reduce 446) (("^") reduce 446) (("|") reduce 446)) 6678 ((("%") reduce 448) ((")") reduce 448) (("*") reduce 448) (("+") reduce 448) ((",") reduce 448) (("-") reduce 448) ((".") reduce 448) (("/") reduce 448) (("<") reduce 448) ((">") reduce 448) (("?") reduce 448) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_BOOLEAN_AND) reduce 448) ((T_BOOLEAN_OR) reduce 448) ((T_COALESCE) reduce 448) ((T_DOUBLE_ARROW) reduce 448) ((T_INSTANCEOF) reduce 448) ((T_IS_EQUAL) reduce 448) ((T_IS_GREATER_OR_EQUAL) reduce 448) ((T_IS_IDENTICAL) reduce 448) ((T_IS_NOT_EQUAL) reduce 448) ((T_IS_NOT_IDENTICAL) reduce 448) ((T_IS_SMALLER_OR_EQUAL) reduce 448) ((T_LOGICAL_AND) reduce 448) ((T_LOGICAL_OR) reduce 448) ((T_LOGICAL_XOR) reduce 448) ((T_POW) reduce 448) ((T_SL) reduce 448) ((T_SPACESHIP) reduce 448) ((T_SR) reduce 448) (("^") reduce 448) (("|") reduce 448)) 6681 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 368) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 368) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 368) ((T_LOGICAL_OR) reduce 368) ((T_LOGICAL_XOR) reduce 368) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 368) (("^") shift) (("|") shift)) 6687 ((("%") reduce 521) (("(") reduce 521) ((")") reduce 521) (("*") reduce 521) (("+") reduce 521) ((",") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) (("<") reduce 521) (("=") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AND_EQUAL) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_COALESCE_EQUAL) reduce 521) ((T_CONCAT_EQUAL) reduce 521) ((T_DEC) reduce 521) ((T_DIV_EQUAL) reduce 521) ((T_DOUBLE_ARROW) reduce 521) ((T_INC) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_MINUS_EQUAL) reduce 521) ((T_MOD_EQUAL) reduce 521) ((T_MUL_EQUAL) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_OR_EQUAL) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_PLUS_EQUAL) reduce 521) ((T_POW) reduce 521) ((T_POW_EQUAL) reduce 521) ((T_SL) reduce 521) ((T_SL_EQUAL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) ((T_SR_EQUAL) reduce 521) ((T_XOR_EQUAL) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 6689 ((("%") reduce 520) (("(") reduce 520) ((")") reduce 520) (("*") reduce 520) (("+") reduce 520) ((",") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) (("<") reduce 520) (("=") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AND_EQUAL) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_COALESCE_EQUAL) reduce 520) ((T_CONCAT_EQUAL) reduce 520) ((T_DEC) reduce 520) ((T_DIV_EQUAL) reduce 520) ((T_DOUBLE_ARROW) reduce 520) ((T_INC) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_MINUS_EQUAL) reduce 520) ((T_MOD_EQUAL) reduce 520) ((T_MUL_EQUAL) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_OR_EQUAL) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_PLUS_EQUAL) reduce 520) ((T_POW) reduce 520) ((T_POW_EQUAL) reduce 520) ((T_SL) reduce 520) ((T_SL_EQUAL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) ((T_SR_EQUAL) reduce 520) ((T_XOR_EQUAL) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 6690 ((("%") reduce 544) (("(") reduce 544) ((")") reduce 544) (("*") reduce 544) (("+") reduce 544) ((",") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) (("=") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AND_EQUAL) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_COALESCE_EQUAL) reduce 544) ((T_CONCAT_EQUAL) reduce 544) ((T_DEC) reduce 544) ((T_DIV_EQUAL) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INC) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_MINUS_EQUAL) reduce 544) ((T_MOD_EQUAL) reduce 544) ((T_MUL_EQUAL) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_OR_EQUAL) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_PLUS_EQUAL) reduce 544) ((T_POW) reduce 544) ((T_POW_EQUAL) reduce 544) ((T_SL) reduce 544) ((T_SL_EQUAL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) ((T_SR_EQUAL) reduce 544) ((T_XOR_EQUAL) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 6691 ((("%") reduce 527) (("(") shift) ((")") reduce 527) (("*") reduce 527) (("+") reduce 527) ((",") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) (("<") reduce 527) (("=") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AND_EQUAL) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_COALESCE_EQUAL) reduce 527) ((T_CONCAT_EQUAL) reduce 527) ((T_DEC) reduce 527) ((T_DIV_EQUAL) reduce 527) ((T_DOUBLE_ARROW) reduce 527) ((T_INC) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_MINUS_EQUAL) reduce 527) ((T_MOD_EQUAL) reduce 527) ((T_MUL_EQUAL) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_OR_EQUAL) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_PLUS_EQUAL) reduce 527) ((T_POW) reduce 527) ((T_POW_EQUAL) reduce 527) ((T_SL) reduce 527) ((T_SL_EQUAL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) ((T_SR_EQUAL) reduce 527) ((T_XOR_EQUAL) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 6692 ((("%") reduce 546) (("(") reduce 546) ((")") reduce 546) (("*") reduce 546) (("+") reduce 546) ((",") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) (("=") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AND_EQUAL) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_COALESCE_EQUAL) reduce 546) ((T_CONCAT_EQUAL) reduce 546) ((T_DEC) reduce 546) ((T_DIV_EQUAL) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INC) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_MINUS_EQUAL) reduce 546) ((T_MOD_EQUAL) reduce 546) ((T_MUL_EQUAL) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_OR_EQUAL) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_PLUS_EQUAL) reduce 546) ((T_POW) reduce 546) ((T_POW_EQUAL) reduce 546) ((T_SL) reduce 546) ((T_SL_EQUAL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) ((T_SR_EQUAL) reduce 546) ((T_XOR_EQUAL) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 6695 ((("%") reduce 545) (("(") reduce 545) ((")") reduce 545) (("*") reduce 545) (("+") reduce 545) ((",") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) (("=") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AND_EQUAL) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_COALESCE_EQUAL) reduce 545) ((T_CONCAT_EQUAL) reduce 545) ((T_DEC) reduce 545) ((T_DIV_EQUAL) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INC) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_MINUS_EQUAL) reduce 545) ((T_MOD_EQUAL) reduce 545) ((T_MUL_EQUAL) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_OR_EQUAL) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_PLUS_EQUAL) reduce 545) ((T_POW) reduce 545) ((T_POW_EQUAL) reduce 545) ((T_SL) reduce 545) ((T_SL_EQUAL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) ((T_SR_EQUAL) reduce 545) ((T_XOR_EQUAL) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 6696 ((("%") reduce 522) (("(") reduce 522) ((")") reduce 522) (("*") reduce 522) (("+") reduce 522) ((",") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) (("<") reduce 522) (("=") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AND_EQUAL) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_COALESCE_EQUAL) reduce 522) ((T_CONCAT_EQUAL) reduce 522) ((T_DEC) reduce 522) ((T_DIV_EQUAL) reduce 522) ((T_DOUBLE_ARROW) reduce 522) ((T_INC) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_MINUS_EQUAL) reduce 522) ((T_MOD_EQUAL) reduce 522) ((T_MUL_EQUAL) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_OR_EQUAL) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_PLUS_EQUAL) reduce 522) ((T_POW) reduce 522) ((T_POW_EQUAL) reduce 522) ((T_SL) reduce 522) ((T_SL_EQUAL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) ((T_SR_EQUAL) reduce 522) ((T_XOR_EQUAL) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 6697 ((("%") reduce 528) (("(") shift) ((")") reduce 528) (("*") reduce 528) (("+") reduce 528) ((",") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) (("<") reduce 528) (("=") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AND_EQUAL) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_COALESCE_EQUAL) reduce 528) ((T_CONCAT_EQUAL) reduce 528) ((T_DEC) reduce 528) ((T_DIV_EQUAL) reduce 528) ((T_DOUBLE_ARROW) reduce 528) ((T_INC) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_MINUS_EQUAL) reduce 528) ((T_MOD_EQUAL) reduce 528) ((T_MUL_EQUAL) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_OR_EQUAL) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_PLUS_EQUAL) reduce 528) ((T_POW) reduce 528) ((T_POW_EQUAL) reduce 528) ((T_SL) reduce 528) ((T_SL_EQUAL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) ((T_SR_EQUAL) reduce 528) ((T_XOR_EQUAL) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 6698 ((("%") reduce 523) (("(") reduce 523) ((")") reduce 523) (("*") reduce 523) (("+") reduce 523) ((",") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) (("<") reduce 523) (("=") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AND_EQUAL) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_COALESCE_EQUAL) reduce 523) ((T_CONCAT_EQUAL) reduce 523) ((T_DEC) reduce 523) ((T_DIV_EQUAL) reduce 523) ((T_DOUBLE_ARROW) reduce 523) ((T_INC) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_MINUS_EQUAL) reduce 523) ((T_MOD_EQUAL) reduce 523) ((T_MUL_EQUAL) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_OR_EQUAL) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_PLUS_EQUAL) reduce 523) ((T_POW) reduce 523) ((T_POW_EQUAL) reduce 523) ((T_SL) reduce 523) ((T_SL_EQUAL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) ((T_SR_EQUAL) reduce 523) ((T_XOR_EQUAL) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 6699 (((")") reduce 555) ((",") reduce 555) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) (("[") reduce 510) (("{") reduce 510)) 6701 ((("%") reduce 438) ((")") reduce 438) (("*") reduce 438) (("+") reduce 438) ((",") reduce 438) (("-") reduce 438) ((".") reduce 438) (("/") reduce 438) (("<") reduce 438) ((">") reduce 438) (("?") reduce 438) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_BOOLEAN_AND) reduce 438) ((T_BOOLEAN_OR) reduce 438) ((T_COALESCE) reduce 438) ((T_DOUBLE_ARROW) reduce 438) ((T_INSTANCEOF) reduce 438) ((T_IS_EQUAL) reduce 438) ((T_IS_GREATER_OR_EQUAL) reduce 438) ((T_IS_IDENTICAL) reduce 438) ((T_IS_NOT_EQUAL) reduce 438) ((T_IS_NOT_IDENTICAL) reduce 438) ((T_IS_SMALLER_OR_EQUAL) reduce 438) ((T_LOGICAL_AND) reduce 438) ((T_LOGICAL_OR) reduce 438) ((T_LOGICAL_XOR) reduce 438) ((T_POW) reduce 438) ((T_SL) reduce 438) ((T_SPACESHIP) reduce 438) ((T_SR) reduce 438) (("^") reduce 438) (("|") reduce 438)) 6703 ((("%") reduce 483) (("(") reduce 483) ((")") reduce 483) (("*") reduce 483) (("+") reduce 483) ((",") reduce 483) (("-") reduce 483) ((".") reduce 483) (("/") reduce 483) (("<") reduce 483) (("=") shift) ((">") reduce 483) (("?") reduce 483) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_BOOLEAN_AND) reduce 483) ((T_BOOLEAN_OR) reduce 483) ((T_COALESCE) reduce 483) ((T_DOUBLE_ARROW) reduce 483) ((T_INSTANCEOF) reduce 483) ((T_IS_EQUAL) reduce 483) ((T_IS_GREATER_OR_EQUAL) reduce 483) ((T_IS_IDENTICAL) reduce 483) ((T_IS_NOT_EQUAL) reduce 483) ((T_IS_NOT_IDENTICAL) reduce 483) ((T_IS_SMALLER_OR_EQUAL) reduce 483) ((T_LOGICAL_AND) reduce 483) ((T_LOGICAL_OR) reduce 483) ((T_LOGICAL_XOR) reduce 483) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 483) ((T_OBJECT_OPERATOR) reduce 483) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 483) ((T_POW) reduce 483) ((T_SL) reduce 483) ((T_SPACESHIP) reduce 483) ((T_SR) reduce 483) (("[") reduce 483) (("^") reduce 483) (("{") reduce 483) (("|") reduce 483)) 6705 ((("%") shift) ((")") reduce 369) (("*") shift) (("+") shift) ((",") reduce 369) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 369) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 369) ((T_LOGICAL_OR) reduce 369) ((T_LOGICAL_XOR) reduce 369) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 6706 ((("%") shift) ((")") reduce 443) (("*") shift) (("+") shift) ((",") reduce 443) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 443) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 443) ((T_LOGICAL_OR) reduce 443) ((T_LOGICAL_XOR) reduce 443) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 6709 ((("%") shift) ((")") reduce 442) (("*") shift) (("+") shift) ((",") reduce 442) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 442) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 442) ((T_LOGICAL_OR) reduce 442) ((T_LOGICAL_XOR) reduce 442) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 6710 ((("%") reduce 434) ((")") reduce 434) (("*") reduce 434) (("+") reduce 434) ((",") reduce 434) (("-") reduce 434) ((".") reduce 434) (("/") reduce 434) (("<") reduce 434) ((">") reduce 434) (("?") reduce 434) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_BOOLEAN_AND) reduce 434) ((T_BOOLEAN_OR) reduce 434) ((T_COALESCE) reduce 434) ((T_DOUBLE_ARROW) reduce 434) ((T_INSTANCEOF) reduce 434) ((T_IS_EQUAL) reduce 434) ((T_IS_GREATER_OR_EQUAL) reduce 434) ((T_IS_IDENTICAL) reduce 434) ((T_IS_NOT_EQUAL) reduce 434) ((T_IS_NOT_IDENTICAL) reduce 434) ((T_IS_SMALLER_OR_EQUAL) reduce 434) ((T_LOGICAL_AND) reduce 434) ((T_LOGICAL_OR) reduce 434) ((T_LOGICAL_XOR) reduce 434) ((T_POW) shift) ((T_SL) reduce 434) ((T_SPACESHIP) reduce 434) ((T_SR) reduce 434) (("^") reduce 434) (("|") reduce 434)) 6711 ((("%") shift) ((")") reduce 444) (("*") shift) (("+") shift) ((",") reduce 444) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 444) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 6712 ((("%") reduce 430) ((")") reduce 430) (("*") reduce 430) (("+") reduce 430) ((",") reduce 430) (("-") reduce 430) ((".") reduce 430) (("/") reduce 430) (("<") reduce 430) ((">") reduce 430) (("?") reduce 430) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_BOOLEAN_AND) reduce 430) ((T_BOOLEAN_OR) reduce 430) ((T_COALESCE) reduce 430) ((T_DOUBLE_ARROW) reduce 430) ((T_INSTANCEOF) reduce 430) ((T_IS_EQUAL) reduce 430) ((T_IS_GREATER_OR_EQUAL) reduce 430) ((T_IS_IDENTICAL) reduce 430) ((T_IS_NOT_EQUAL) reduce 430) ((T_IS_NOT_IDENTICAL) reduce 430) ((T_IS_SMALLER_OR_EQUAL) reduce 430) ((T_LOGICAL_AND) reduce 430) ((T_LOGICAL_OR) reduce 430) ((T_LOGICAL_XOR) reduce 430) ((T_POW) shift) ((T_SL) reduce 430) ((T_SPACESHIP) reduce 430) ((T_SR) reduce 430) (("^") reduce 430) (("|") reduce 430)) 6713 ((("%") reduce 447) ((")") reduce 447) (("*") reduce 447) (("+") reduce 447) ((",") reduce 447) (("-") reduce 447) ((".") reduce 447) (("/") reduce 447) (("<") reduce 447) ((">") reduce 447) (("?") reduce 447) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_BOOLEAN_AND) reduce 447) ((T_BOOLEAN_OR) reduce 447) ((T_COALESCE) reduce 447) ((T_DOUBLE_ARROW) reduce 447) ((T_INSTANCEOF) reduce 447) ((T_IS_EQUAL) reduce 447) ((T_IS_GREATER_OR_EQUAL) reduce 447) ((T_IS_IDENTICAL) reduce 447) ((T_IS_NOT_EQUAL) reduce 447) ((T_IS_NOT_IDENTICAL) reduce 447) ((T_IS_SMALLER_OR_EQUAL) reduce 447) ((T_LOGICAL_AND) reduce 447) ((T_LOGICAL_OR) reduce 447) ((T_LOGICAL_XOR) reduce 447) ((T_POW) reduce 447) ((T_SL) reduce 447) ((T_SPACESHIP) reduce 447) ((T_SR) reduce 447) (("^") reduce 447) (("|") reduce 447)) 6715 ((("%") reduce 489) ((")") reduce 489) (("*") reduce 489) (("+") reduce 489) ((",") reduce 489) (("-") reduce 489) ((".") reduce 489) (("/") reduce 489) (("<") reduce 489) ((">") reduce 489) (("?") reduce 489) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_BOOLEAN_AND) reduce 489) ((T_BOOLEAN_OR) reduce 489) ((T_COALESCE) reduce 489) ((T_DOUBLE_ARROW) reduce 489) ((T_INSTANCEOF) reduce 489) ((T_IS_EQUAL) reduce 489) ((T_IS_GREATER_OR_EQUAL) reduce 489) ((T_IS_IDENTICAL) reduce 489) ((T_IS_NOT_EQUAL) reduce 489) ((T_IS_NOT_IDENTICAL) reduce 489) ((T_IS_SMALLER_OR_EQUAL) reduce 489) ((T_LOGICAL_AND) reduce 489) ((T_LOGICAL_OR) reduce 489) ((T_LOGICAL_XOR) reduce 489) ((T_POW) reduce 489) ((T_SL) reduce 489) ((T_SPACESHIP) reduce 489) ((T_SR) reduce 489) (("^") reduce 489) (("|") reduce 489)) 6717 ((("%") reduce 490) ((")") reduce 490) (("*") reduce 490) (("+") reduce 490) ((",") reduce 490) (("-") reduce 490) ((".") reduce 490) (("/") reduce 490) (("<") reduce 490) ((">") reduce 490) (("?") reduce 490) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_BOOLEAN_AND) reduce 490) ((T_BOOLEAN_OR) reduce 490) ((T_COALESCE) reduce 490) ((T_DOUBLE_ARROW) reduce 490) ((T_INSTANCEOF) reduce 490) ((T_IS_EQUAL) reduce 490) ((T_IS_GREATER_OR_EQUAL) reduce 490) ((T_IS_IDENTICAL) reduce 490) ((T_IS_NOT_EQUAL) reduce 490) ((T_IS_NOT_IDENTICAL) reduce 490) ((T_IS_SMALLER_OR_EQUAL) reduce 490) ((T_LOGICAL_AND) reduce 490) ((T_LOGICAL_OR) reduce 490) ((T_LOGICAL_XOR) reduce 490) ((T_POW) reduce 490) ((T_SL) reduce 490) ((T_SPACESHIP) reduce 490) ((T_SR) reduce 490) (("^") reduce 490) (("|") reduce 490)) 6718 ((("%") reduce 488) ((")") reduce 488) (("*") reduce 488) (("+") reduce 488) ((",") reduce 488) (("-") reduce 488) ((".") reduce 488) (("/") reduce 488) (("<") reduce 488) ((">") reduce 488) (("?") reduce 488) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_BOOLEAN_AND) reduce 488) ((T_BOOLEAN_OR) reduce 488) ((T_COALESCE) reduce 488) ((T_DOUBLE_ARROW) reduce 488) ((T_INSTANCEOF) reduce 488) ((T_IS_EQUAL) reduce 488) ((T_IS_GREATER_OR_EQUAL) reduce 488) ((T_IS_IDENTICAL) reduce 488) ((T_IS_NOT_EQUAL) reduce 488) ((T_IS_NOT_IDENTICAL) reduce 488) ((T_IS_SMALLER_OR_EQUAL) reduce 488) ((T_LOGICAL_AND) reduce 488) ((T_LOGICAL_OR) reduce 488) ((T_LOGICAL_XOR) reduce 488) ((T_POW) reduce 488) ((T_SL) reduce 488) ((T_SPACESHIP) reduce 488) ((T_SR) reduce 488) (("^") reduce 488) (("|") reduce 488)) 6719 ((("%") shift) ((")") reduce 581) (("*") shift) (("+") shift) ((",") reduce 581) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 581) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 6720 ((("%") shift) ((")") reduce 580) (("*") shift) (("+") shift) ((",") reduce 580) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 580) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 6721 ((("%") reduce 466) (("(") reduce 466) ((")") reduce 466) (("*") reduce 466) (("+") reduce 466) ((",") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) (("<") reduce 466) (("=") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AND_EQUAL) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_COALESCE_EQUAL) reduce 466) ((T_CONCAT_EQUAL) reduce 466) ((T_DEC) reduce 466) ((T_DIV_EQUAL) reduce 466) ((T_DOUBLE_ARROW) reduce 466) ((T_INC) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_MINUS_EQUAL) reduce 466) ((T_MOD_EQUAL) reduce 466) ((T_MUL_EQUAL) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_OR_EQUAL) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_PLUS_EQUAL) reduce 466) ((T_POW) reduce 466) ((T_POW_EQUAL) reduce 466) ((T_SL) reduce 466) ((T_SL_EQUAL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) ((T_SR_EQUAL) reduce 466) ((T_XOR_EQUAL) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 6722 ((("%") shift) ((")") reduce 439) (("*") shift) (("+") shift) ((",") reduce 439) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 439) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 439) ((T_LOGICAL_OR) reduce 439) ((T_LOGICAL_XOR) reduce 439) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 6723 ((("%") reduce 432) ((")") reduce 432) (("*") reduce 432) (("+") reduce 432) ((",") reduce 432) (("-") reduce 432) ((".") reduce 432) (("/") reduce 432) (("<") reduce 432) ((">") reduce 432) (("?") reduce 432) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_BOOLEAN_AND) reduce 432) ((T_BOOLEAN_OR) reduce 432) ((T_COALESCE) reduce 432) ((T_DOUBLE_ARROW) reduce 432) ((T_INSTANCEOF) reduce 432) ((T_IS_EQUAL) reduce 432) ((T_IS_GREATER_OR_EQUAL) reduce 432) ((T_IS_IDENTICAL) reduce 432) ((T_IS_NOT_EQUAL) reduce 432) ((T_IS_NOT_IDENTICAL) reduce 432) ((T_IS_SMALLER_OR_EQUAL) reduce 432) ((T_LOGICAL_AND) reduce 432) ((T_LOGICAL_OR) reduce 432) ((T_LOGICAL_XOR) reduce 432) ((T_POW) shift) ((T_SL) reduce 432) ((T_SPACESHIP) reduce 432) ((T_SR) reduce 432) (("^") reduce 432) (("|") reduce 432)) 6725 ((("%") reduce 93) (("(") reduce 93) ((")") reduce 93) (("*") reduce 93) (("+") reduce 93) ((",") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93)) 6726 ((("%") reduce 92) (("(") reduce 92) ((")") reduce 92) (("*") reduce 92) (("+") reduce 92) ((",") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92)) 6727 ((("%") reduce 94) (("(") reduce 94) ((")") reduce 94) (("*") reduce 94) (("+") reduce 94) ((",") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94)) 6728 ((("%") reduce 470) (("(") reduce 470) ((")") reduce 470) (("*") reduce 470) (("+") reduce 470) ((",") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_DOUBLE_ARROW) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470)) 6729 ((("%") reduce 91) (("(") reduce 91) ((")") reduce 91) (("*") reduce 91) (("+") reduce 91) ((",") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91)) 6730 ((("%") reduce 365) ((")") reduce 365) (("*") reduce 365) (("+") reduce 365) ((",") reduce 365) (("-") reduce 365) ((".") reduce 365) (("/") reduce 365) (("<") reduce 365) ((">") reduce 365) (("?") reduce 365) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_BOOLEAN_AND) reduce 365) ((T_BOOLEAN_OR) reduce 365) ((T_COALESCE) reduce 365) ((T_DOUBLE_ARROW) reduce 365) ((T_INSTANCEOF) reduce 365) ((T_IS_EQUAL) reduce 365) ((T_IS_GREATER_OR_EQUAL) reduce 365) ((T_IS_IDENTICAL) reduce 365) ((T_IS_NOT_EQUAL) reduce 365) ((T_IS_NOT_IDENTICAL) reduce 365) ((T_IS_SMALLER_OR_EQUAL) reduce 365) ((T_LOGICAL_AND) reduce 365) ((T_LOGICAL_OR) reduce 365) ((T_LOGICAL_XOR) reduce 365) ((T_POW) reduce 365) ((T_SL) reduce 365) ((T_SPACESHIP) reduce 365) ((T_SR) reduce 365) (("^") reduce 365) (("|") reduce 365)) 6733 ((("%") reduce 472) (("(") reduce 472) ((")") reduce 472) (("*") reduce 472) (("+") reduce 472) ((",") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_DOUBLE_ARROW) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472)) 6734 ((("%") reduce 480) (("(") shift) ((")") reduce 480) (("*") reduce 480) (("+") reduce 480) ((",") reduce 480) (("-") reduce 480) ((".") reduce 480) (("/") reduce 480) (("<") reduce 480) ((">") reduce 480) (("?") reduce 480) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_BOOLEAN_AND) reduce 480) ((T_BOOLEAN_OR) reduce 480) ((T_COALESCE) reduce 480) ((T_DOUBLE_ARROW) reduce 480) ((T_INSTANCEOF) reduce 480) ((T_IS_EQUAL) reduce 480) ((T_IS_GREATER_OR_EQUAL) reduce 480) ((T_IS_IDENTICAL) reduce 480) ((T_IS_NOT_EQUAL) reduce 480) ((T_IS_NOT_IDENTICAL) reduce 480) ((T_IS_SMALLER_OR_EQUAL) reduce 480) ((T_LOGICAL_AND) reduce 480) ((T_LOGICAL_OR) reduce 480) ((T_LOGICAL_XOR) reduce 480) ((T_POW) reduce 480) ((T_SL) reduce 480) ((T_SPACESHIP) reduce 480) ((T_SR) reduce 480) (("^") reduce 480) (("|") reduce 480)) 6735 ((("%") reduce 471) (("(") reduce 471) ((")") reduce 471) (("*") reduce 471) (("+") reduce 471) ((",") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_DOUBLE_ARROW) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471)) 6736 ((("%") reduce 473) (("(") reduce 473) ((")") reduce 473) (("*") reduce 473) (("+") reduce 473) ((",") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_DOUBLE_ARROW) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 6737 ((("%") reduce 534) (("(") reduce 534) ((")") reduce 534) (("*") reduce 534) (("+") reduce 534) ((",") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_DOUBLE_ARROW) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 6744 ((("%") reduce 536) (("(") reduce 536) ((")") reduce 536) (("*") reduce 536) (("+") reduce 536) ((",") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_DOUBLE_ARROW) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 6746 ((("%") reduce 535) (("(") reduce 535) ((")") reduce 535) (("*") reduce 535) (("+") reduce 535) ((",") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_DOUBLE_ARROW) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 6747 ((("%") reduce 540) (("(") reduce 540) ((")") reduce 540) (("*") reduce 540) (("+") reduce 540) ((",") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_DOUBLE_ARROW) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 6748 ((("%") reduce 537) (("(") reduce 537) ((")") reduce 537) (("*") reduce 537) (("+") reduce 537) ((",") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_DOUBLE_ARROW) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 6749 ((("%") reduce 538) (("(") reduce 538) ((")") reduce 538) (("*") reduce 538) (("+") reduce 538) ((",") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_DOUBLE_ARROW) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 6751 ((("%") reduce 481) ((")") reduce 481) (("*") reduce 481) (("+") reduce 481) ((",") reduce 481) (("-") reduce 481) ((".") reduce 481) (("/") reduce 481) (("<") reduce 481) ((">") reduce 481) (("?") reduce 481) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_BOOLEAN_AND) reduce 481) ((T_BOOLEAN_OR) reduce 481) ((T_COALESCE) reduce 481) ((T_DOUBLE_ARROW) reduce 481) ((T_INSTANCEOF) reduce 481) ((T_IS_EQUAL) reduce 481) ((T_IS_GREATER_OR_EQUAL) reduce 481) ((T_IS_IDENTICAL) reduce 481) ((T_IS_NOT_EQUAL) reduce 481) ((T_IS_NOT_IDENTICAL) reduce 481) ((T_IS_SMALLER_OR_EQUAL) reduce 481) ((T_LOGICAL_AND) reduce 481) ((T_LOGICAL_OR) reduce 481) ((T_LOGICAL_XOR) reduce 481) ((T_POW) reduce 481) ((T_SL) reduce 481) ((T_SPACESHIP) reduce 481) ((T_SR) reduce 481) (("^") reduce 481) (("|") reduce 481)) 6752 ((("%") reduce 364) ((")") reduce 364) (("*") reduce 364) (("+") reduce 364) ((",") reduce 364) (("-") reduce 364) ((".") reduce 364) (("/") reduce 364) (("<") reduce 364) ((">") reduce 364) (("?") reduce 364) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_BOOLEAN_AND) reduce 364) ((T_BOOLEAN_OR) reduce 364) ((T_COALESCE) reduce 364) ((T_DOUBLE_ARROW) reduce 364) ((T_INSTANCEOF) reduce 364) ((T_IS_EQUAL) reduce 364) ((T_IS_GREATER_OR_EQUAL) reduce 364) ((T_IS_IDENTICAL) reduce 364) ((T_IS_NOT_EQUAL) reduce 364) ((T_IS_NOT_IDENTICAL) reduce 364) ((T_IS_SMALLER_OR_EQUAL) reduce 364) ((T_LOGICAL_AND) reduce 364) ((T_LOGICAL_OR) reduce 364) ((T_LOGICAL_XOR) reduce 364) ((T_POW) reduce 364) ((T_SL) reduce 364) ((T_SPACESHIP) reduce 364) ((T_SR) reduce 364) (("^") reduce 364) (("|") reduce 364)) 6753 ((("%") reduce 288) ((")") reduce 288) (("*") reduce 288) (("+") reduce 288) ((",") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("^") reduce 288) (("|") reduce 288)) 6757 ((("%") reduce 289) ((")") reduce 289) (("*") reduce 289) (("+") reduce 289) ((",") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("^") reduce 289) (("|") reduce 289)) 6758 ((("%") reduce 290) ((")") reduce 290) (("*") reduce 290) (("+") reduce 290) ((",") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("^") reduce 290) (("|") reduce 290)) 6760 ((("%") reduce 539) (("(") reduce 539) ((")") reduce 539) (("*") reduce 539) (("+") reduce 539) ((",") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_DOUBLE_ARROW) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 6761 ((("%") reduce 366) ((")") reduce 366) (("*") reduce 366) (("+") reduce 366) ((",") reduce 366) (("-") reduce 366) ((".") reduce 366) (("/") reduce 366) (("<") reduce 366) ((">") reduce 366) (("?") reduce 366) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_BOOLEAN_AND) reduce 366) ((T_BOOLEAN_OR) reduce 366) ((T_COALESCE) reduce 366) ((T_DOUBLE_ARROW) reduce 366) ((T_INSTANCEOF) reduce 366) ((T_IS_EQUAL) reduce 366) ((T_IS_GREATER_OR_EQUAL) reduce 366) ((T_IS_IDENTICAL) reduce 366) ((T_IS_NOT_EQUAL) reduce 366) ((T_IS_NOT_IDENTICAL) reduce 366) ((T_IS_SMALLER_OR_EQUAL) reduce 366) ((T_LOGICAL_AND) reduce 366) ((T_LOGICAL_OR) reduce 366) ((T_LOGICAL_XOR) reduce 366) ((T_POW) reduce 366) ((T_SL) reduce 366) ((T_SPACESHIP) reduce 366) ((T_SR) reduce 366) (("^") reduce 366) (("|") reduce 366)) 6769 ((("%") reduce 363) ((")") reduce 363) (("*") reduce 363) (("+") reduce 363) ((",") reduce 363) (("-") reduce 363) ((".") reduce 363) (("/") reduce 363) (("<") reduce 363) ((">") reduce 363) (("?") reduce 363) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_BOOLEAN_AND) reduce 363) ((T_BOOLEAN_OR) reduce 363) ((T_COALESCE) reduce 363) ((T_DOUBLE_ARROW) reduce 363) ((T_INSTANCEOF) reduce 363) ((T_IS_EQUAL) reduce 363) ((T_IS_GREATER_OR_EQUAL) reduce 363) ((T_IS_IDENTICAL) reduce 363) ((T_IS_NOT_EQUAL) reduce 363) ((T_IS_NOT_IDENTICAL) reduce 363) ((T_IS_SMALLER_OR_EQUAL) reduce 363) ((T_LOGICAL_AND) reduce 363) ((T_LOGICAL_OR) reduce 363) ((T_LOGICAL_XOR) reduce 363) ((T_POW) reduce 363) ((T_SL) reduce 363) ((T_SPACESHIP) reduce 363) ((T_SR) reduce 363) (("^") reduce 363) (("|") reduce 363)) 6771 ((("%") reduce 474) (("(") reduce 474) ((")") reduce 474) (("*") reduce 474) (("+") reduce 474) ((",") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_DOUBLE_ARROW) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474)) 6777 ((("%") reduce 230) ((")") reduce 230) (("*") reduce 230) (("+") reduce 230) ((",") reduce 230) (("-") reduce 230) ((".") reduce 230) (("/") reduce 230) (("<") reduce 230) ((">") reduce 230) (("?") reduce 230) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_BOOLEAN_AND) reduce 230) ((T_BOOLEAN_OR) reduce 230) ((T_COALESCE) reduce 230) ((T_DOUBLE_ARROW) reduce 230) ((T_INSTANCEOF) reduce 230) ((T_IS_EQUAL) reduce 230) ((T_IS_GREATER_OR_EQUAL) reduce 230) ((T_IS_IDENTICAL) reduce 230) ((T_IS_NOT_EQUAL) reduce 230) ((T_IS_NOT_IDENTICAL) reduce 230) ((T_IS_SMALLER_OR_EQUAL) reduce 230) ((T_LOGICAL_AND) reduce 230) ((T_LOGICAL_OR) reduce 230) ((T_LOGICAL_XOR) reduce 230) ((T_POW) reduce 230) ((T_SL) reduce 230) ((T_SPACESHIP) reduce 230) ((T_SR) reduce 230) (("^") reduce 230) (("|") reduce 230)) 6780 (((")") reduce 558) ((",") reduce 558) (("=") shift)) 6784 ((("%") reduce 575) ((")") reduce 575) (("*") reduce 575) (("+") reduce 575) ((",") reduce 575) (("-") reduce 575) ((".") reduce 575) (("/") reduce 575) (("<") reduce 575) ((">") reduce 575) (("?") reduce 575) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_BOOLEAN_AND) reduce 575) ((T_BOOLEAN_OR) reduce 575) ((T_COALESCE) reduce 575) ((T_DOUBLE_ARROW) reduce 575) ((T_INSTANCEOF) reduce 575) ((T_IS_EQUAL) reduce 575) ((T_IS_GREATER_OR_EQUAL) reduce 575) ((T_IS_IDENTICAL) reduce 575) ((T_IS_NOT_EQUAL) reduce 575) ((T_IS_NOT_IDENTICAL) reduce 575) ((T_IS_SMALLER_OR_EQUAL) reduce 575) ((T_LOGICAL_AND) reduce 575) ((T_LOGICAL_OR) reduce 575) ((T_LOGICAL_XOR) reduce 575) ((T_POW) reduce 575) ((T_SL) reduce 575) ((T_SPACESHIP) reduce 575) ((T_SR) reduce 575) (("^") reduce 575) (("|") reduce 575)) 6785 ((("%") reduce 428) ((")") reduce 428) (("*") reduce 428) (("+") reduce 428) ((",") reduce 428) (("-") reduce 428) ((".") reduce 428) (("/") reduce 428) (("<") reduce 428) ((">") reduce 428) (("?") reduce 428) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_BOOLEAN_AND) reduce 428) ((T_BOOLEAN_OR) reduce 428) ((T_COALESCE) reduce 428) ((T_DOUBLE_ARROW) reduce 428) ((T_INSTANCEOF) reduce 428) ((T_IS_EQUAL) reduce 428) ((T_IS_GREATER_OR_EQUAL) reduce 428) ((T_IS_IDENTICAL) reduce 428) ((T_IS_NOT_EQUAL) reduce 428) ((T_IS_NOT_IDENTICAL) reduce 428) ((T_IS_SMALLER_OR_EQUAL) reduce 428) ((T_LOGICAL_AND) reduce 428) ((T_LOGICAL_OR) reduce 428) ((T_LOGICAL_XOR) reduce 428) ((T_POW) shift) ((T_SL) reduce 428) ((T_SPACESHIP) reduce 428) ((T_SR) reduce 428) (("^") reduce 428) (("|") reduce 428)) 6786 ((("%") shift) ((")") reduce 578) (("*") shift) (("+") shift) ((",") reduce 578) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 578) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 6787 ((("%") shift) ((")") reduce 577) (("*") shift) (("+") shift) ((",") reduce 577) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 577) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 6788 ((("%") reduce 387) ((")") reduce 387) (("*") reduce 387) (("+") reduce 387) ((",") reduce 387) (("-") reduce 387) ((".") reduce 387) (("/") reduce 387) (("<") reduce 387) ((">") reduce 387) (("?") reduce 387) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_BOOLEAN_AND) reduce 387) ((T_BOOLEAN_OR) reduce 387) ((T_COALESCE) reduce 387) ((T_DOUBLE_ARROW) reduce 387) ((T_INSTANCEOF) reduce 387) ((T_IS_EQUAL) reduce 387) ((T_IS_GREATER_OR_EQUAL) reduce 387) ((T_IS_IDENTICAL) reduce 387) ((T_IS_NOT_EQUAL) reduce 387) ((T_IS_NOT_IDENTICAL) reduce 387) ((T_IS_SMALLER_OR_EQUAL) reduce 387) ((T_LOGICAL_AND) reduce 387) ((T_LOGICAL_OR) reduce 387) ((T_LOGICAL_XOR) reduce 387) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 387) ((T_SL) reduce 387) ((T_SPACESHIP) reduce 387) ((T_SR) reduce 387) (("[") reduce 510) (("^") reduce 387) (("{") reduce 510) (("|") reduce 387)) 6790 ((("%") reduce 435) ((")") reduce 435) (("*") reduce 435) (("+") reduce 435) ((",") reduce 435) (("-") reduce 435) ((".") reduce 435) (("/") reduce 435) (("<") reduce 435) ((">") reduce 435) (("?") reduce 435) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_BOOLEAN_AND) reduce 435) ((T_BOOLEAN_OR) reduce 435) ((T_COALESCE) reduce 435) ((T_DOUBLE_ARROW) reduce 435) ((T_INSTANCEOF) reduce 435) ((T_IS_EQUAL) reduce 435) ((T_IS_GREATER_OR_EQUAL) reduce 435) ((T_IS_IDENTICAL) reduce 435) ((T_IS_NOT_EQUAL) reduce 435) ((T_IS_NOT_IDENTICAL) reduce 435) ((T_IS_SMALLER_OR_EQUAL) reduce 435) ((T_LOGICAL_AND) reduce 435) ((T_LOGICAL_OR) reduce 435) ((T_LOGICAL_XOR) reduce 435) ((T_POW) reduce 435) ((T_SL) reduce 435) ((T_SPACESHIP) reduce 435) ((T_SR) reduce 435) (("^") reduce 435) (("|") reduce 435)) 6792 ((("%") reduce 476) ((")") reduce 476) (("*") reduce 476) (("+") reduce 476) ((",") reduce 476) (("-") reduce 476) ((".") reduce 476) (("/") reduce 476) (("<") reduce 476) ((">") reduce 476) (("?") reduce 476) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_BOOLEAN_AND) reduce 476) ((T_BOOLEAN_OR) reduce 476) ((T_COALESCE) reduce 476) ((T_DOUBLE_ARROW) reduce 476) ((T_INSTANCEOF) reduce 476) ((T_IS_EQUAL) reduce 476) ((T_IS_GREATER_OR_EQUAL) reduce 476) ((T_IS_IDENTICAL) reduce 476) ((T_IS_NOT_EQUAL) reduce 476) ((T_IS_NOT_IDENTICAL) reduce 476) ((T_IS_SMALLER_OR_EQUAL) reduce 476) ((T_LOGICAL_AND) reduce 476) ((T_LOGICAL_OR) reduce 476) ((T_LOGICAL_XOR) reduce 476) ((T_POW) reduce 476) ((T_SL) reduce 476) ((T_SPACESHIP) reduce 476) ((T_SR) reduce 476) (("^") reduce 476) (("|") reduce 476)) 6795 ((("%") reduce 579) ((")") reduce 579) (("*") reduce 579) (("+") reduce 579) ((",") reduce 579) (("-") reduce 579) ((".") reduce 579) (("/") reduce 579) (("<") reduce 579) ((">") reduce 579) (("?") reduce 579) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_BOOLEAN_AND) reduce 579) ((T_BOOLEAN_OR) reduce 579) ((T_COALESCE) reduce 579) ((T_DOUBLE_ARROW) reduce 579) ((T_INSTANCEOF) reduce 579) ((T_IS_EQUAL) reduce 579) ((T_IS_GREATER_OR_EQUAL) reduce 579) ((T_IS_IDENTICAL) reduce 579) ((T_IS_NOT_EQUAL) reduce 579) ((T_IS_NOT_IDENTICAL) reduce 579) ((T_IS_SMALLER_OR_EQUAL) reduce 579) ((T_LOGICAL_AND) reduce 579) ((T_LOGICAL_OR) reduce 579) ((T_LOGICAL_XOR) reduce 579) ((T_POW) reduce 579) ((T_SL) reduce 579) ((T_SPACESHIP) reduce 579) ((T_SR) reduce 579) (("^") reduce 579) (("|") reduce 579)) 6798 ((("%") reduce 576) ((")") reduce 576) (("*") reduce 576) (("+") reduce 576) ((",") reduce 576) (("-") reduce 576) ((".") reduce 576) (("/") reduce 576) (("<") reduce 576) ((">") reduce 576) (("?") reduce 576) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_BOOLEAN_AND) reduce 576) ((T_BOOLEAN_OR) reduce 576) ((T_COALESCE) reduce 576) ((T_DOUBLE_ARROW) reduce 576) ((T_INSTANCEOF) reduce 576) ((T_IS_EQUAL) reduce 576) ((T_IS_GREATER_OR_EQUAL) reduce 576) ((T_IS_IDENTICAL) reduce 576) ((T_IS_NOT_EQUAL) reduce 576) ((T_IS_NOT_IDENTICAL) reduce 576) ((T_IS_SMALLER_OR_EQUAL) reduce 576) ((T_LOGICAL_AND) reduce 576) ((T_LOGICAL_OR) reduce 576) ((T_LOGICAL_XOR) reduce 576) ((T_POW) reduce 576) ((T_SL) reduce 576) ((T_SPACESHIP) reduce 576) ((T_SR) reduce 576) (("^") reduce 576) (("|") reduce 576)) 6799 ((("%") shift) ((")") reduce 556) (("*") shift) (("+") shift) ((",") reduce 556) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 6800 ((("%") reduce 429) ((")") reduce 429) (("*") reduce 429) (("+") reduce 429) ((",") reduce 429) (("-") reduce 429) ((".") reduce 429) (("/") reduce 429) (("<") reduce 429) ((">") reduce 429) (("?") reduce 429) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_BOOLEAN_AND) reduce 429) ((T_BOOLEAN_OR) reduce 429) ((T_COALESCE) reduce 429) ((T_DOUBLE_ARROW) reduce 429) ((T_INSTANCEOF) reduce 429) ((T_IS_EQUAL) reduce 429) ((T_IS_GREATER_OR_EQUAL) reduce 429) ((T_IS_IDENTICAL) reduce 429) ((T_IS_NOT_EQUAL) reduce 429) ((T_IS_NOT_IDENTICAL) reduce 429) ((T_IS_SMALLER_OR_EQUAL) reduce 429) ((T_LOGICAL_AND) reduce 429) ((T_LOGICAL_OR) reduce 429) ((T_LOGICAL_XOR) reduce 429) ((T_POW) shift) ((T_SL) reduce 429) ((T_SPACESHIP) reduce 429) ((T_SR) reduce 429) (("^") reduce 429) (("|") reduce 429)) 6801 ((("%") reduce 389) ((")") reduce 389) (("*") reduce 389) (("+") reduce 389) ((",") reduce 389) (("-") reduce 389) ((".") reduce 389) (("/") reduce 389) (("<") reduce 389) ((">") reduce 389) (("?") reduce 389) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_BOOLEAN_AND) reduce 389) ((T_BOOLEAN_OR) reduce 389) ((T_COALESCE) reduce 389) ((T_DOUBLE_ARROW) reduce 389) ((T_INSTANCEOF) reduce 389) ((T_IS_EQUAL) reduce 389) ((T_IS_GREATER_OR_EQUAL) reduce 389) ((T_IS_IDENTICAL) reduce 389) ((T_IS_NOT_EQUAL) reduce 389) ((T_IS_NOT_IDENTICAL) reduce 389) ((T_IS_SMALLER_OR_EQUAL) reduce 389) ((T_LOGICAL_AND) reduce 389) ((T_LOGICAL_OR) reduce 389) ((T_LOGICAL_XOR) reduce 389) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 389) ((T_SL) reduce 389) ((T_SPACESHIP) reduce 389) ((T_SR) reduce 389) (("[") reduce 510) (("^") reduce 389) (("{") reduce 510) (("|") reduce 389)) 6802 ((("%") reduce 372) ((")") reduce 372) (("*") reduce 372) (("+") reduce 372) ((",") reduce 372) (("-") reduce 372) ((".") reduce 372) (("/") reduce 372) (("<") reduce 372) ((">") reduce 372) (("?") reduce 372) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_BOOLEAN_AND) reduce 372) ((T_BOOLEAN_OR) reduce 372) ((T_COALESCE) reduce 372) ((T_DOUBLE_ARROW) reduce 372) ((T_INSTANCEOF) reduce 372) ((T_IS_EQUAL) reduce 372) ((T_IS_GREATER_OR_EQUAL) reduce 372) ((T_IS_IDENTICAL) reduce 372) ((T_IS_NOT_EQUAL) reduce 372) ((T_IS_NOT_IDENTICAL) reduce 372) ((T_IS_SMALLER_OR_EQUAL) reduce 372) ((T_LOGICAL_AND) reduce 372) ((T_LOGICAL_OR) reduce 372) ((T_LOGICAL_XOR) reduce 372) ((T_POW) reduce 372) ((T_SL) reduce 372) ((T_SPACESHIP) reduce 372) ((T_SR) reduce 372) (("^") reduce 372) (("|") reduce 372)) 6803 ((("%") reduce 433) ((")") reduce 433) (("*") reduce 433) (("+") reduce 433) ((",") reduce 433) (("-") reduce 433) ((".") reduce 433) (("/") reduce 433) (("<") reduce 433) ((">") reduce 433) (("?") reduce 433) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_BOOLEAN_AND) reduce 433) ((T_BOOLEAN_OR) reduce 433) ((T_COALESCE) reduce 433) ((T_DOUBLE_ARROW) reduce 433) ((T_INSTANCEOF) reduce 433) ((T_IS_EQUAL) reduce 433) ((T_IS_GREATER_OR_EQUAL) reduce 433) ((T_IS_IDENTICAL) reduce 433) ((T_IS_NOT_EQUAL) reduce 433) ((T_IS_NOT_IDENTICAL) reduce 433) ((T_IS_SMALLER_OR_EQUAL) reduce 433) ((T_LOGICAL_AND) reduce 433) ((T_LOGICAL_OR) reduce 433) ((T_LOGICAL_XOR) reduce 433) ((T_POW) shift) ((T_SL) reduce 433) ((T_SPACESHIP) reduce 433) ((T_SR) reduce 433) (("^") reduce 433) (("|") reduce 433)) 6804 ((("%") reduce 431) ((")") reduce 431) (("*") reduce 431) (("+") reduce 431) ((",") reduce 431) (("-") reduce 431) ((".") reduce 431) (("/") reduce 431) (("<") reduce 431) ((">") reduce 431) (("?") reduce 431) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_BOOLEAN_AND) reduce 431) ((T_BOOLEAN_OR) reduce 431) ((T_COALESCE) reduce 431) ((T_DOUBLE_ARROW) reduce 431) ((T_INSTANCEOF) reduce 431) ((T_IS_EQUAL) reduce 431) ((T_IS_GREATER_OR_EQUAL) reduce 431) ((T_IS_IDENTICAL) reduce 431) ((T_IS_NOT_EQUAL) reduce 431) ((T_IS_NOT_IDENTICAL) reduce 431) ((T_IS_SMALLER_OR_EQUAL) reduce 431) ((T_LOGICAL_AND) reduce 431) ((T_LOGICAL_OR) reduce 431) ((T_LOGICAL_XOR) reduce 431) ((T_POW) shift) ((T_SL) reduce 431) ((T_SPACESHIP) reduce 431) ((T_SR) reduce 431) (("^") reduce 431) (("|") reduce 431)) 6807 ((("%") reduce 482) (("(") reduce 482) ((")") reduce 482) (("*") reduce 482) (("+") reduce 482) ((",") reduce 482) (("-") reduce 482) ((".") reduce 482) (("/") reduce 482) (("<") reduce 482) ((">") reduce 482) (("?") reduce 482) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_BOOLEAN_AND) reduce 482) ((T_BOOLEAN_OR) reduce 482) ((T_COALESCE) reduce 482) ((T_DOUBLE_ARROW) reduce 482) ((T_INSTANCEOF) reduce 482) ((T_IS_EQUAL) reduce 482) ((T_IS_GREATER_OR_EQUAL) reduce 482) ((T_IS_IDENTICAL) reduce 482) ((T_IS_NOT_EQUAL) reduce 482) ((T_IS_NOT_IDENTICAL) reduce 482) ((T_IS_SMALLER_OR_EQUAL) reduce 482) ((T_LOGICAL_AND) reduce 482) ((T_LOGICAL_OR) reduce 482) ((T_LOGICAL_XOR) reduce 482) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 482) ((T_OBJECT_OPERATOR) reduce 482) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 482) ((T_POW) reduce 482) ((T_SL) reduce 482) ((T_SPACESHIP) reduce 482) ((T_SR) reduce 482) (("[") reduce 482) (("^") reduce 482) (("{") reduce 482) (("|") reduce 482)) 6808 ((("%") reduce 436) ((")") reduce 436) (("*") reduce 436) (("+") reduce 436) ((",") reduce 436) (("-") reduce 436) ((".") reduce 436) (("/") reduce 436) (("<") reduce 436) ((">") reduce 436) (("?") reduce 436) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_BOOLEAN_AND) reduce 436) ((T_BOOLEAN_OR) reduce 436) ((T_COALESCE) reduce 436) ((T_DOUBLE_ARROW) reduce 436) ((T_INSTANCEOF) reduce 436) ((T_IS_EQUAL) reduce 436) ((T_IS_GREATER_OR_EQUAL) reduce 436) ((T_IS_IDENTICAL) reduce 436) ((T_IS_NOT_EQUAL) reduce 436) ((T_IS_NOT_IDENTICAL) reduce 436) ((T_IS_SMALLER_OR_EQUAL) reduce 436) ((T_LOGICAL_AND) reduce 436) ((T_LOGICAL_OR) reduce 436) ((T_LOGICAL_XOR) reduce 436) ((T_POW) shift) ((T_SL) reduce 436) ((T_SPACESHIP) reduce 436) ((T_SR) reduce 436) (("^") reduce 436) (("|") reduce 436)) 6809 ((("%") reduce 409) ((")") reduce 409) (("*") reduce 409) (("+") reduce 409) ((",") reduce 409) (("-") reduce 409) ((".") reduce 409) (("/") reduce 409) (("<") reduce 409) ((">") reduce 409) (("?") reduce 409) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_BOOLEAN_AND) reduce 409) ((T_BOOLEAN_OR) reduce 409) ((T_COALESCE) reduce 409) ((T_DOUBLE_ARROW) reduce 409) ((T_INSTANCEOF) reduce 409) ((T_IS_EQUAL) reduce 409) ((T_IS_GREATER_OR_EQUAL) reduce 409) ((T_IS_IDENTICAL) reduce 409) ((T_IS_NOT_EQUAL) reduce 409) ((T_IS_NOT_IDENTICAL) reduce 409) ((T_IS_SMALLER_OR_EQUAL) reduce 409) ((T_LOGICAL_AND) reduce 409) ((T_LOGICAL_OR) reduce 409) ((T_LOGICAL_XOR) reduce 409) ((T_POW) shift) ((T_SL) reduce 409) ((T_SPACESHIP) reduce 409) ((T_SR) reduce 409) (("^") reduce 409) (("|") reduce 409)) 6810 ((("%") reduce 408) ((")") reduce 408) (("*") reduce 408) (("+") reduce 408) ((",") reduce 408) (("-") reduce 408) ((".") reduce 408) (("/") reduce 408) (("<") reduce 408) ((">") reduce 408) (("?") reduce 408) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_BOOLEAN_AND) reduce 408) ((T_BOOLEAN_OR) reduce 408) ((T_COALESCE) reduce 408) ((T_DOUBLE_ARROW) reduce 408) ((T_INSTANCEOF) reduce 408) ((T_IS_EQUAL) reduce 408) ((T_IS_GREATER_OR_EQUAL) reduce 408) ((T_IS_IDENTICAL) reduce 408) ((T_IS_NOT_EQUAL) reduce 408) ((T_IS_NOT_IDENTICAL) reduce 408) ((T_IS_SMALLER_OR_EQUAL) reduce 408) ((T_LOGICAL_AND) reduce 408) ((T_LOGICAL_OR) reduce 408) ((T_LOGICAL_XOR) reduce 408) ((T_POW) shift) ((T_SL) reduce 408) ((T_SPACESHIP) reduce 408) ((T_SR) reduce 408) (("^") reduce 408) (("|") reduce 408)) 6812 ((("%") reduce 422) (("(") reduce 517) ((")") reduce 422) (("*") reduce 422) (("+") reduce 422) ((",") reduce 422) (("-") reduce 422) ((".") reduce 422) (("/") reduce 422) (("<") reduce 422) ((">") reduce 422) (("?") reduce 422) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_BOOLEAN_AND) reduce 422) ((T_BOOLEAN_OR) reduce 422) ((T_COALESCE) reduce 422) ((T_DOUBLE_ARROW) reduce 422) ((T_INSTANCEOF) reduce 422) ((T_IS_EQUAL) reduce 422) ((T_IS_GREATER_OR_EQUAL) reduce 422) ((T_IS_IDENTICAL) reduce 422) ((T_IS_NOT_EQUAL) reduce 422) ((T_IS_NOT_IDENTICAL) reduce 422) ((T_IS_SMALLER_OR_EQUAL) reduce 422) ((T_LOGICAL_AND) reduce 422) ((T_LOGICAL_OR) reduce 422) ((T_LOGICAL_XOR) reduce 422) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 511) ((T_OBJECT_OPERATOR) reduce 511) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 511) ((T_POW) reduce 422) ((T_SL) reduce 422) ((T_SPACESHIP) reduce 422) ((T_SR) reduce 422) (("[") reduce 511) (("^") reduce 422) (("{") reduce 511) (("|") reduce 422)) 6813 ((("%") reduce 531) (("(") reduce 531) ((")") reduce 531) (("*") reduce 531) (("+") reduce 531) ((",") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) (("=") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AND_EQUAL) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_COALESCE_EQUAL) reduce 531) ((T_CONCAT_EQUAL) reduce 531) ((T_DEC) reduce 531) ((T_DIV_EQUAL) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INC) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_MINUS_EQUAL) reduce 531) ((T_MOD_EQUAL) reduce 531) ((T_MUL_EQUAL) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_OR_EQUAL) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_PLUS_EQUAL) reduce 531) ((T_POW) reduce 531) ((T_POW_EQUAL) reduce 531) ((T_SL) reduce 531) ((T_SL_EQUAL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) ((T_SR_EQUAL) reduce 531) ((T_XOR_EQUAL) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 6816 ((("%") reduce 530) (("(") reduce 530) ((")") reduce 530) (("*") reduce 530) (("+") reduce 530) ((",") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) (("=") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AND_EQUAL) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_COALESCE_EQUAL) reduce 530) ((T_CONCAT_EQUAL) reduce 530) ((T_DEC) reduce 530) ((T_DIV_EQUAL) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INC) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_MINUS_EQUAL) reduce 530) ((T_MOD_EQUAL) reduce 530) ((T_MUL_EQUAL) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_OR_EQUAL) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_PLUS_EQUAL) reduce 530) ((T_POW) reduce 530) ((T_POW_EQUAL) reduce 530) ((T_SL) reduce 530) ((T_SL_EQUAL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) ((T_SR_EQUAL) reduce 530) ((T_XOR_EQUAL) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 6818 ((("%") reduce 485) (("(") reduce 485) ((")") reduce 485) (("*") reduce 485) (("+") reduce 485) ((",") reduce 485) (("-") reduce 485) ((".") reduce 485) (("/") reduce 485) (("<") reduce 485) ((">") reduce 485) (("?") reduce 485) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_BOOLEAN_AND) reduce 485) ((T_BOOLEAN_OR) reduce 485) ((T_COALESCE) reduce 485) ((T_DOUBLE_ARROW) reduce 485) ((T_INSTANCEOF) reduce 485) ((T_IS_EQUAL) reduce 485) ((T_IS_GREATER_OR_EQUAL) reduce 485) ((T_IS_IDENTICAL) reduce 485) ((T_IS_NOT_EQUAL) reduce 485) ((T_IS_NOT_IDENTICAL) reduce 485) ((T_IS_SMALLER_OR_EQUAL) reduce 485) ((T_LOGICAL_AND) reduce 485) ((T_LOGICAL_OR) reduce 485) ((T_LOGICAL_XOR) reduce 485) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 485) ((T_OBJECT_OPERATOR) reduce 485) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 485) ((T_POW) reduce 485) ((T_SL) reduce 485) ((T_SPACESHIP) reduce 485) ((T_SR) reduce 485) (("[") reduce 485) (("^") reduce 485) (("{") reduce 485) (("|") reduce 485)) 6819 ((("%") reduce 410) ((")") reduce 410) (("*") reduce 410) (("+") reduce 410) ((",") reduce 410) (("-") reduce 410) ((".") reduce 410) (("/") reduce 410) (("<") reduce 410) ((">") reduce 410) (("?") reduce 410) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_BOOLEAN_AND) reduce 410) ((T_BOOLEAN_OR) reduce 410) ((T_COALESCE) reduce 410) ((T_DOUBLE_ARROW) reduce 410) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 410) ((T_IS_GREATER_OR_EQUAL) reduce 410) ((T_IS_IDENTICAL) reduce 410) ((T_IS_NOT_EQUAL) reduce 410) ((T_IS_NOT_IDENTICAL) reduce 410) ((T_IS_SMALLER_OR_EQUAL) reduce 410) ((T_LOGICAL_AND) reduce 410) ((T_LOGICAL_OR) reduce 410) ((T_LOGICAL_XOR) reduce 410) ((T_POW) shift) ((T_SL) reduce 410) ((T_SPACESHIP) reduce 410) ((T_SR) reduce 410) (("^") reduce 410) (("|") reduce 410)) 6821 ((("%") reduce 73) (("(") reduce 73) (("*") reduce 73) (("+") reduce 73) ((",") reduce 73) (("-") reduce 73) ((".") reduce 73) (("/") reduce 73) (("<") reduce 73) ((">") reduce 73) (("?") reduce 73) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_BOOLEAN_AND) reduce 73) ((T_BOOLEAN_OR) reduce 73) ((T_COALESCE) reduce 73) ((T_DOUBLE_ARROW) reduce 73) ((T_INSTANCEOF) reduce 73) ((T_IS_EQUAL) reduce 73) ((T_IS_GREATER_OR_EQUAL) reduce 73) ((T_IS_IDENTICAL) reduce 73) ((T_IS_NOT_EQUAL) reduce 73) ((T_IS_NOT_IDENTICAL) reduce 73) ((T_IS_SMALLER_OR_EQUAL) reduce 73) ((T_LOGICAL_AND) reduce 73) ((T_LOGICAL_OR) reduce 73) ((T_LOGICAL_XOR) reduce 73) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 73) ((T_OBJECT_OPERATOR) reduce 73) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 73) ((T_POW) reduce 73) ((T_SL) reduce 73) ((T_SPACESHIP) reduce 73) ((T_SR) reduce 73) (("[") reduce 73) (("]") reduce 73) (("^") reduce 73) (("{") reduce 73) (("|") reduce 73)) 6822 ((("%") reduce 52) (("(") reduce 52) (("*") reduce 52) (("+") reduce 52) ((",") reduce 52) (("-") reduce 52) ((".") reduce 52) (("/") reduce 52) (("<") reduce 52) ((">") reduce 52) (("?") reduce 52) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_BOOLEAN_AND) reduce 52) ((T_BOOLEAN_OR) reduce 52) ((T_COALESCE) reduce 52) ((T_DOUBLE_ARROW) reduce 52) ((T_INSTANCEOF) reduce 52) ((T_IS_EQUAL) reduce 52) ((T_IS_GREATER_OR_EQUAL) reduce 52) ((T_IS_IDENTICAL) reduce 52) ((T_IS_NOT_EQUAL) reduce 52) ((T_IS_NOT_IDENTICAL) reduce 52) ((T_IS_SMALLER_OR_EQUAL) reduce 52) ((T_LOGICAL_AND) reduce 52) ((T_LOGICAL_OR) reduce 52) ((T_LOGICAL_XOR) reduce 52) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 52) ((T_OBJECT_OPERATOR) reduce 52) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 52) ((T_POW) reduce 52) ((T_SL) reduce 52) ((T_SPACESHIP) reduce 52) ((T_SR) reduce 52) (("[") reduce 52) (("]") reduce 52) (("^") reduce 52) (("{") reduce 52) (("|") reduce 52)) 6823 ((("%") reduce 27) (("(") reduce 27) (("*") reduce 27) (("+") reduce 27) ((",") reduce 27) (("-") reduce 27) ((".") reduce 27) (("/") reduce 27) (("<") reduce 27) ((">") reduce 27) (("?") reduce 27) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_BOOLEAN_AND) reduce 27) ((T_BOOLEAN_OR) reduce 27) ((T_COALESCE) reduce 27) ((T_DOUBLE_ARROW) reduce 27) ((T_INSTANCEOF) reduce 27) ((T_IS_EQUAL) reduce 27) ((T_IS_GREATER_OR_EQUAL) reduce 27) ((T_IS_IDENTICAL) reduce 27) ((T_IS_NOT_EQUAL) reduce 27) ((T_IS_NOT_IDENTICAL) reduce 27) ((T_IS_SMALLER_OR_EQUAL) reduce 27) ((T_LOGICAL_AND) reduce 27) ((T_LOGICAL_OR) reduce 27) ((T_LOGICAL_XOR) reduce 27) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 27) ((T_OBJECT_OPERATOR) reduce 27) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 27) ((T_POW) reduce 27) ((T_SL) reduce 27) ((T_SPACESHIP) reduce 27) ((T_SR) reduce 27) (("[") reduce 27) (("]") reduce 27) (("^") reduce 27) (("{") reduce 27) (("|") reduce 27)) 6824 ((("%") reduce 51) (("(") reduce 51) (("*") reduce 51) (("+") reduce 51) ((",") reduce 51) (("-") reduce 51) ((".") reduce 51) (("/") reduce 51) (("<") reduce 51) ((">") reduce 51) (("?") reduce 51) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_BOOLEAN_AND) reduce 51) ((T_BOOLEAN_OR) reduce 51) ((T_COALESCE) reduce 51) ((T_DOUBLE_ARROW) reduce 51) ((T_INSTANCEOF) reduce 51) ((T_IS_EQUAL) reduce 51) ((T_IS_GREATER_OR_EQUAL) reduce 51) ((T_IS_IDENTICAL) reduce 51) ((T_IS_NOT_EQUAL) reduce 51) ((T_IS_NOT_IDENTICAL) reduce 51) ((T_IS_SMALLER_OR_EQUAL) reduce 51) ((T_LOGICAL_AND) reduce 51) ((T_LOGICAL_OR) reduce 51) ((T_LOGICAL_XOR) reduce 51) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 51) ((T_OBJECT_OPERATOR) reduce 51) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 51) ((T_POW) reduce 51) ((T_SL) reduce 51) ((T_SPACESHIP) reduce 51) ((T_SR) reduce 51) (("[") reduce 51) (("]") reduce 51) (("^") reduce 51) (("{") reduce 51) (("|") reduce 51)) 6825 ((("%") reduce 53) (("(") reduce 53) (("*") reduce 53) (("+") reduce 53) ((",") reduce 53) (("-") reduce 53) ((".") reduce 53) (("/") reduce 53) (("<") reduce 53) ((">") reduce 53) (("?") reduce 53) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_BOOLEAN_AND) reduce 53) ((T_BOOLEAN_OR) reduce 53) ((T_COALESCE) reduce 53) ((T_DOUBLE_ARROW) reduce 53) ((T_INSTANCEOF) reduce 53) ((T_IS_EQUAL) reduce 53) ((T_IS_GREATER_OR_EQUAL) reduce 53) ((T_IS_IDENTICAL) reduce 53) ((T_IS_NOT_EQUAL) reduce 53) ((T_IS_NOT_IDENTICAL) reduce 53) ((T_IS_SMALLER_OR_EQUAL) reduce 53) ((T_LOGICAL_AND) reduce 53) ((T_LOGICAL_OR) reduce 53) ((T_LOGICAL_XOR) reduce 53) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 53) ((T_OBJECT_OPERATOR) reduce 53) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 53) ((T_POW) reduce 53) ((T_SL) reduce 53) ((T_SPACESHIP) reduce 53) ((T_SR) reduce 53) (("[") reduce 53) (("]") reduce 53) (("^") reduce 53) (("{") reduce 53) (("|") reduce 53)) 6826 ((("%") reduce 49) (("(") reduce 49) (("*") reduce 49) (("+") reduce 49) ((",") reduce 49) (("-") reduce 49) ((".") reduce 49) (("/") reduce 49) (("<") reduce 49) ((">") reduce 49) (("?") reduce 49) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_BOOLEAN_AND) reduce 49) ((T_BOOLEAN_OR) reduce 49) ((T_COALESCE) reduce 49) ((T_DOUBLE_ARROW) reduce 49) ((T_INSTANCEOF) reduce 49) ((T_IS_EQUAL) reduce 49) ((T_IS_GREATER_OR_EQUAL) reduce 49) ((T_IS_IDENTICAL) reduce 49) ((T_IS_NOT_EQUAL) reduce 49) ((T_IS_NOT_IDENTICAL) reduce 49) ((T_IS_SMALLER_OR_EQUAL) reduce 49) ((T_LOGICAL_AND) reduce 49) ((T_LOGICAL_OR) reduce 49) ((T_LOGICAL_XOR) reduce 49) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 49) ((T_OBJECT_OPERATOR) reduce 49) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 49) ((T_POW) reduce 49) ((T_SL) reduce 49) ((T_SPACESHIP) reduce 49) ((T_SR) reduce 49) (("[") reduce 49) (("]") reduce 49) (("^") reduce 49) (("{") reduce 49) (("|") reduce 49)) 6827 ((("%") reduce 29) (("(") reduce 29) (("*") reduce 29) (("+") reduce 29) ((",") reduce 29) (("-") reduce 29) ((".") reduce 29) (("/") reduce 29) (("<") reduce 29) ((">") reduce 29) (("?") reduce 29) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_BOOLEAN_AND) reduce 29) ((T_BOOLEAN_OR) reduce 29) ((T_COALESCE) reduce 29) ((T_DOUBLE_ARROW) reduce 29) ((T_INSTANCEOF) reduce 29) ((T_IS_EQUAL) reduce 29) ((T_IS_GREATER_OR_EQUAL) reduce 29) ((T_IS_IDENTICAL) reduce 29) ((T_IS_NOT_EQUAL) reduce 29) ((T_IS_NOT_IDENTICAL) reduce 29) ((T_IS_SMALLER_OR_EQUAL) reduce 29) ((T_LOGICAL_AND) reduce 29) ((T_LOGICAL_OR) reduce 29) ((T_LOGICAL_XOR) reduce 29) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 29) ((T_OBJECT_OPERATOR) reduce 29) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 29) ((T_POW) reduce 29) ((T_SL) reduce 29) ((T_SPACESHIP) reduce 29) ((T_SR) reduce 29) (("[") reduce 29) (("]") reduce 29) (("^") reduce 29) (("{") reduce 29) (("|") reduce 29)) 6828 ((("%") reduce 59) (("(") reduce 59) (("*") reduce 59) (("+") reduce 59) ((",") reduce 59) (("-") reduce 59) ((".") reduce 59) (("/") reduce 59) (("<") reduce 59) ((">") reduce 59) (("?") reduce 59) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_BOOLEAN_AND) reduce 59) ((T_BOOLEAN_OR) reduce 59) ((T_COALESCE) reduce 59) ((T_DOUBLE_ARROW) reduce 59) ((T_INSTANCEOF) reduce 59) ((T_IS_EQUAL) reduce 59) ((T_IS_GREATER_OR_EQUAL) reduce 59) ((T_IS_IDENTICAL) reduce 59) ((T_IS_NOT_EQUAL) reduce 59) ((T_IS_NOT_IDENTICAL) reduce 59) ((T_IS_SMALLER_OR_EQUAL) reduce 59) ((T_LOGICAL_AND) reduce 59) ((T_LOGICAL_OR) reduce 59) ((T_LOGICAL_XOR) reduce 59) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 59) ((T_OBJECT_OPERATOR) reduce 59) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 59) ((T_POW) reduce 59) ((T_SL) reduce 59) ((T_SPACESHIP) reduce 59) ((T_SR) reduce 59) (("[") reduce 59) (("]") reduce 59) (("^") reduce 59) (("{") reduce 59) (("|") reduce 59)) 6829 ((("%") reduce 60) (("(") reduce 60) (("*") reduce 60) (("+") reduce 60) ((",") reduce 60) (("-") reduce 60) ((".") reduce 60) (("/") reduce 60) (("<") reduce 60) ((">") reduce 60) (("?") reduce 60) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_BOOLEAN_AND) reduce 60) ((T_BOOLEAN_OR) reduce 60) ((T_COALESCE) reduce 60) ((T_DOUBLE_ARROW) reduce 60) ((T_INSTANCEOF) reduce 60) ((T_IS_EQUAL) reduce 60) ((T_IS_GREATER_OR_EQUAL) reduce 60) ((T_IS_IDENTICAL) reduce 60) ((T_IS_NOT_EQUAL) reduce 60) ((T_IS_NOT_IDENTICAL) reduce 60) ((T_IS_SMALLER_OR_EQUAL) reduce 60) ((T_LOGICAL_AND) reduce 60) ((T_LOGICAL_OR) reduce 60) ((T_LOGICAL_XOR) reduce 60) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 60) ((T_OBJECT_OPERATOR) reduce 60) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 60) ((T_POW) reduce 60) ((T_SL) reduce 60) ((T_SPACESHIP) reduce 60) ((T_SR) reduce 60) (("[") reduce 60) (("]") reduce 60) (("^") reduce 60) (("{") reduce 60) (("|") reduce 60)) 6830 ((("%") reduce 11) (("(") reduce 11) (("*") reduce 11) (("+") reduce 11) ((",") reduce 11) (("-") reduce 11) ((".") reduce 11) (("/") reduce 11) (("<") reduce 11) ((">") reduce 11) (("?") reduce 11) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_BOOLEAN_AND) reduce 11) ((T_BOOLEAN_OR) reduce 11) ((T_COALESCE) reduce 11) ((T_DOUBLE_ARROW) reduce 11) ((T_INSTANCEOF) reduce 11) ((T_IS_EQUAL) reduce 11) ((T_IS_GREATER_OR_EQUAL) reduce 11) ((T_IS_IDENTICAL) reduce 11) ((T_IS_NOT_EQUAL) reduce 11) ((T_IS_NOT_IDENTICAL) reduce 11) ((T_IS_SMALLER_OR_EQUAL) reduce 11) ((T_LOGICAL_AND) reduce 11) ((T_LOGICAL_OR) reduce 11) ((T_LOGICAL_XOR) reduce 11) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 11) ((T_OBJECT_OPERATOR) reduce 11) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 11) ((T_POW) reduce 11) ((T_SL) reduce 11) ((T_SPACESHIP) reduce 11) ((T_SR) reduce 11) (("[") reduce 11) (("]") reduce 11) (("^") reduce 11) (("{") reduce 11) (("|") reduce 11)) 6831 ((("%") reduce 42) (("(") reduce 42) (("*") reduce 42) (("+") reduce 42) ((",") reduce 42) (("-") reduce 42) ((".") reduce 42) (("/") reduce 42) (("<") reduce 42) ((">") reduce 42) (("?") reduce 42) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_BOOLEAN_AND) reduce 42) ((T_BOOLEAN_OR) reduce 42) ((T_COALESCE) reduce 42) ((T_DOUBLE_ARROW) reduce 42) ((T_INSTANCEOF) reduce 42) ((T_IS_EQUAL) reduce 42) ((T_IS_GREATER_OR_EQUAL) reduce 42) ((T_IS_IDENTICAL) reduce 42) ((T_IS_NOT_EQUAL) reduce 42) ((T_IS_NOT_IDENTICAL) reduce 42) ((T_IS_SMALLER_OR_EQUAL) reduce 42) ((T_LOGICAL_AND) reduce 42) ((T_LOGICAL_OR) reduce 42) ((T_LOGICAL_XOR) reduce 42) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 42) ((T_OBJECT_OPERATOR) reduce 42) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 42) ((T_POW) reduce 42) ((T_SL) reduce 42) ((T_SPACESHIP) reduce 42) ((T_SR) reduce 42) (("[") reduce 42) (("]") reduce 42) (("^") reduce 42) (("{") reduce 42) (("|") reduce 42)) 6832 ((("%") reduce 39) (("(") reduce 39) (("*") reduce 39) (("+") reduce 39) ((",") reduce 39) (("-") reduce 39) ((".") reduce 39) (("/") reduce 39) (("<") reduce 39) ((">") reduce 39) (("?") reduce 39) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_BOOLEAN_AND) reduce 39) ((T_BOOLEAN_OR) reduce 39) ((T_COALESCE) reduce 39) ((T_DOUBLE_ARROW) reduce 39) ((T_INSTANCEOF) reduce 39) ((T_IS_EQUAL) reduce 39) ((T_IS_GREATER_OR_EQUAL) reduce 39) ((T_IS_IDENTICAL) reduce 39) ((T_IS_NOT_EQUAL) reduce 39) ((T_IS_NOT_IDENTICAL) reduce 39) ((T_IS_SMALLER_OR_EQUAL) reduce 39) ((T_LOGICAL_AND) reduce 39) ((T_LOGICAL_OR) reduce 39) ((T_LOGICAL_XOR) reduce 39) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 39) ((T_OBJECT_OPERATOR) reduce 39) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 39) ((T_POW) reduce 39) ((T_SL) reduce 39) ((T_SPACESHIP) reduce 39) ((T_SR) reduce 39) (("[") reduce 39) (("]") reduce 39) (("^") reduce 39) (("{") reduce 39) (("|") reduce 39)) 6833 ((("%") reduce 25) (("(") reduce 25) (("*") reduce 25) (("+") reduce 25) ((",") reduce 25) (("-") reduce 25) ((".") reduce 25) (("/") reduce 25) (("<") reduce 25) ((">") reduce 25) (("?") reduce 25) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_BOOLEAN_AND) reduce 25) ((T_BOOLEAN_OR) reduce 25) ((T_COALESCE) reduce 25) ((T_DOUBLE_ARROW) reduce 25) ((T_INSTANCEOF) reduce 25) ((T_IS_EQUAL) reduce 25) ((T_IS_GREATER_OR_EQUAL) reduce 25) ((T_IS_IDENTICAL) reduce 25) ((T_IS_NOT_EQUAL) reduce 25) ((T_IS_NOT_IDENTICAL) reduce 25) ((T_IS_SMALLER_OR_EQUAL) reduce 25) ((T_LOGICAL_AND) reduce 25) ((T_LOGICAL_OR) reduce 25) ((T_LOGICAL_XOR) reduce 25) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 25) ((T_OBJECT_OPERATOR) reduce 25) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 25) ((T_POW) reduce 25) ((T_SL) reduce 25) ((T_SPACESHIP) reduce 25) ((T_SR) reduce 25) (("[") reduce 25) (("]") reduce 25) (("^") reduce 25) (("{") reduce 25) (("|") reduce 25)) 6834 ((("%") reduce 50) (("(") reduce 50) (("*") reduce 50) (("+") reduce 50) ((",") reduce 50) (("-") reduce 50) ((".") reduce 50) (("/") reduce 50) (("<") reduce 50) ((">") reduce 50) (("?") reduce 50) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_BOOLEAN_AND) reduce 50) ((T_BOOLEAN_OR) reduce 50) ((T_COALESCE) reduce 50) ((T_DOUBLE_ARROW) reduce 50) ((T_INSTANCEOF) reduce 50) ((T_IS_EQUAL) reduce 50) ((T_IS_GREATER_OR_EQUAL) reduce 50) ((T_IS_IDENTICAL) reduce 50) ((T_IS_NOT_EQUAL) reduce 50) ((T_IS_NOT_IDENTICAL) reduce 50) ((T_IS_SMALLER_OR_EQUAL) reduce 50) ((T_LOGICAL_AND) reduce 50) ((T_LOGICAL_OR) reduce 50) ((T_LOGICAL_XOR) reduce 50) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 50) ((T_OBJECT_OPERATOR) reduce 50) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 50) ((T_POW) reduce 50) ((T_SL) reduce 50) ((T_SPACESHIP) reduce 50) ((T_SR) reduce 50) (("[") reduce 50) (("]") reduce 50) (("^") reduce 50) (("{") reduce 50) (("|") reduce 50)) 6835 ((("%") reduce 66) (("(") reduce 66) (("*") reduce 66) (("+") reduce 66) ((",") reduce 66) (("-") reduce 66) ((".") reduce 66) (("/") reduce 66) (("<") reduce 66) ((">") reduce 66) (("?") reduce 66) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_BOOLEAN_AND) reduce 66) ((T_BOOLEAN_OR) reduce 66) ((T_COALESCE) reduce 66) ((T_DOUBLE_ARROW) reduce 66) ((T_INSTANCEOF) reduce 66) ((T_IS_EQUAL) reduce 66) ((T_IS_GREATER_OR_EQUAL) reduce 66) ((T_IS_IDENTICAL) reduce 66) ((T_IS_NOT_EQUAL) reduce 66) ((T_IS_NOT_IDENTICAL) reduce 66) ((T_IS_SMALLER_OR_EQUAL) reduce 66) ((T_LOGICAL_AND) reduce 66) ((T_LOGICAL_OR) reduce 66) ((T_LOGICAL_XOR) reduce 66) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 66) ((T_OBJECT_OPERATOR) reduce 66) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 66) ((T_POW) reduce 66) ((T_SL) reduce 66) ((T_SPACESHIP) reduce 66) ((T_SR) reduce 66) (("[") reduce 66) (("]") reduce 66) (("^") reduce 66) (("{") reduce 66) (("|") reduce 66)) 6836 ((("%") reduce 18) (("(") reduce 18) (("*") reduce 18) (("+") reduce 18) ((",") reduce 18) (("-") reduce 18) ((".") reduce 18) (("/") reduce 18) (("<") reduce 18) ((">") reduce 18) (("?") reduce 18) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_BOOLEAN_AND) reduce 18) ((T_BOOLEAN_OR) reduce 18) ((T_COALESCE) reduce 18) ((T_DOUBLE_ARROW) reduce 18) ((T_INSTANCEOF) reduce 18) ((T_IS_EQUAL) reduce 18) ((T_IS_GREATER_OR_EQUAL) reduce 18) ((T_IS_IDENTICAL) reduce 18) ((T_IS_NOT_EQUAL) reduce 18) ((T_IS_NOT_IDENTICAL) reduce 18) ((T_IS_SMALLER_OR_EQUAL) reduce 18) ((T_LOGICAL_AND) reduce 18) ((T_LOGICAL_OR) reduce 18) ((T_LOGICAL_XOR) reduce 18) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 18) ((T_OBJECT_OPERATOR) reduce 18) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 18) ((T_POW) reduce 18) ((T_SL) reduce 18) ((T_SPACESHIP) reduce 18) ((T_SR) reduce 18) (("[") reduce 18) (("]") reduce 18) (("^") reduce 18) (("{") reduce 18) (("|") reduce 18)) 6837 ((("%") reduce 17) (("(") reduce 17) (("*") reduce 17) (("+") reduce 17) ((",") reduce 17) (("-") reduce 17) ((".") reduce 17) (("/") reduce 17) (("<") reduce 17) ((">") reduce 17) (("?") reduce 17) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_BOOLEAN_AND) reduce 17) ((T_BOOLEAN_OR) reduce 17) ((T_COALESCE) reduce 17) ((T_DOUBLE_ARROW) reduce 17) ((T_INSTANCEOF) reduce 17) ((T_IS_EQUAL) reduce 17) ((T_IS_GREATER_OR_EQUAL) reduce 17) ((T_IS_IDENTICAL) reduce 17) ((T_IS_NOT_EQUAL) reduce 17) ((T_IS_NOT_IDENTICAL) reduce 17) ((T_IS_SMALLER_OR_EQUAL) reduce 17) ((T_LOGICAL_AND) reduce 17) ((T_LOGICAL_OR) reduce 17) ((T_LOGICAL_XOR) reduce 17) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 17) ((T_OBJECT_OPERATOR) reduce 17) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 17) ((T_POW) reduce 17) ((T_SL) reduce 17) ((T_SPACESHIP) reduce 17) ((T_SR) reduce 17) (("[") reduce 17) (("]") reduce 17) (("^") reduce 17) (("{") reduce 17) (("|") reduce 17)) 6838 ((("%") reduce 15) (("(") reduce 15) (("*") reduce 15) (("+") reduce 15) ((",") reduce 15) (("-") reduce 15) ((".") reduce 15) (("/") reduce 15) (("<") reduce 15) ((">") reduce 15) (("?") reduce 15) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_BOOLEAN_AND) reduce 15) ((T_BOOLEAN_OR) reduce 15) ((T_COALESCE) reduce 15) ((T_DOUBLE_ARROW) reduce 15) ((T_INSTANCEOF) reduce 15) ((T_IS_EQUAL) reduce 15) ((T_IS_GREATER_OR_EQUAL) reduce 15) ((T_IS_IDENTICAL) reduce 15) ((T_IS_NOT_EQUAL) reduce 15) ((T_IS_NOT_IDENTICAL) reduce 15) ((T_IS_SMALLER_OR_EQUAL) reduce 15) ((T_LOGICAL_AND) reduce 15) ((T_LOGICAL_OR) reduce 15) ((T_LOGICAL_XOR) reduce 15) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 15) ((T_OBJECT_OPERATOR) reduce 15) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 15) ((T_POW) reduce 15) ((T_SL) reduce 15) ((T_SPACESHIP) reduce 15) ((T_SR) reduce 15) (("[") reduce 15) (("]") reduce 15) (("^") reduce 15) (("{") reduce 15) (("|") reduce 15)) 6839 ((("%") reduce 14) (("(") reduce 14) (("*") reduce 14) (("+") reduce 14) ((",") reduce 14) (("-") reduce 14) ((".") reduce 14) (("/") reduce 14) (("<") reduce 14) ((">") reduce 14) (("?") reduce 14) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_BOOLEAN_AND) reduce 14) ((T_BOOLEAN_OR) reduce 14) ((T_COALESCE) reduce 14) ((T_DOUBLE_ARROW) reduce 14) ((T_INSTANCEOF) reduce 14) ((T_IS_EQUAL) reduce 14) ((T_IS_GREATER_OR_EQUAL) reduce 14) ((T_IS_IDENTICAL) reduce 14) ((T_IS_NOT_EQUAL) reduce 14) ((T_IS_NOT_IDENTICAL) reduce 14) ((T_IS_SMALLER_OR_EQUAL) reduce 14) ((T_LOGICAL_AND) reduce 14) ((T_LOGICAL_OR) reduce 14) ((T_LOGICAL_XOR) reduce 14) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 14) ((T_OBJECT_OPERATOR) reduce 14) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 14) ((T_POW) reduce 14) ((T_SL) reduce 14) ((T_SPACESHIP) reduce 14) ((T_SR) reduce 14) (("[") reduce 14) (("]") reduce 14) (("^") reduce 14) (("{") reduce 14) (("|") reduce 14)) 6840 ((("%") reduce 38) (("(") reduce 38) (("*") reduce 38) (("+") reduce 38) ((",") reduce 38) (("-") reduce 38) ((".") reduce 38) (("/") reduce 38) (("<") reduce 38) ((">") reduce 38) (("?") reduce 38) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_BOOLEAN_AND) reduce 38) ((T_BOOLEAN_OR) reduce 38) ((T_COALESCE) reduce 38) ((T_DOUBLE_ARROW) reduce 38) ((T_INSTANCEOF) reduce 38) ((T_IS_EQUAL) reduce 38) ((T_IS_GREATER_OR_EQUAL) reduce 38) ((T_IS_IDENTICAL) reduce 38) ((T_IS_NOT_EQUAL) reduce 38) ((T_IS_NOT_IDENTICAL) reduce 38) ((T_IS_SMALLER_OR_EQUAL) reduce 38) ((T_LOGICAL_AND) reduce 38) ((T_LOGICAL_OR) reduce 38) ((T_LOGICAL_XOR) reduce 38) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 38) ((T_OBJECT_OPERATOR) reduce 38) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 38) ((T_POW) reduce 38) ((T_SL) reduce 38) ((T_SPACESHIP) reduce 38) ((T_SR) reduce 38) (("[") reduce 38) (("]") reduce 38) (("^") reduce 38) (("{") reduce 38) (("|") reduce 38)) 6841 ((("%") reduce 26) (("(") reduce 26) (("*") reduce 26) (("+") reduce 26) ((",") reduce 26) (("-") reduce 26) ((".") reduce 26) (("/") reduce 26) (("<") reduce 26) ((">") reduce 26) (("?") reduce 26) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_BOOLEAN_AND) reduce 26) ((T_BOOLEAN_OR) reduce 26) ((T_COALESCE) reduce 26) ((T_DOUBLE_ARROW) reduce 26) ((T_INSTANCEOF) reduce 26) ((T_IS_EQUAL) reduce 26) ((T_IS_GREATER_OR_EQUAL) reduce 26) ((T_IS_IDENTICAL) reduce 26) ((T_IS_NOT_EQUAL) reduce 26) ((T_IS_NOT_IDENTICAL) reduce 26) ((T_IS_SMALLER_OR_EQUAL) reduce 26) ((T_LOGICAL_AND) reduce 26) ((T_LOGICAL_OR) reduce 26) ((T_LOGICAL_XOR) reduce 26) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 26) ((T_OBJECT_OPERATOR) reduce 26) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 26) ((T_POW) reduce 26) ((T_SL) reduce 26) ((T_SPACESHIP) reduce 26) ((T_SR) reduce 26) (("[") reduce 26) (("]") reduce 26) (("^") reduce 26) (("{") reduce 26) (("|") reduce 26)) 6842 ((("%") reduce 22) (("(") reduce 22) (("*") reduce 22) (("+") reduce 22) ((",") reduce 22) (("-") reduce 22) ((".") reduce 22) (("/") reduce 22) (("<") reduce 22) ((">") reduce 22) (("?") reduce 22) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_BOOLEAN_AND) reduce 22) ((T_BOOLEAN_OR) reduce 22) ((T_COALESCE) reduce 22) ((T_DOUBLE_ARROW) reduce 22) ((T_INSTANCEOF) reduce 22) ((T_IS_EQUAL) reduce 22) ((T_IS_GREATER_OR_EQUAL) reduce 22) ((T_IS_IDENTICAL) reduce 22) ((T_IS_NOT_EQUAL) reduce 22) ((T_IS_NOT_IDENTICAL) reduce 22) ((T_IS_SMALLER_OR_EQUAL) reduce 22) ((T_LOGICAL_AND) reduce 22) ((T_LOGICAL_OR) reduce 22) ((T_LOGICAL_XOR) reduce 22) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 22) ((T_OBJECT_OPERATOR) reduce 22) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 22) ((T_POW) reduce 22) ((T_SL) reduce 22) ((T_SPACESHIP) reduce 22) ((T_SR) reduce 22) (("[") reduce 22) (("]") reduce 22) (("^") reduce 22) (("{") reduce 22) (("|") reduce 22)) 6843 ((("%") reduce 24) (("(") reduce 24) (("*") reduce 24) (("+") reduce 24) ((",") reduce 24) (("-") reduce 24) ((".") reduce 24) (("/") reduce 24) (("<") reduce 24) ((">") reduce 24) (("?") reduce 24) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_BOOLEAN_AND) reduce 24) ((T_BOOLEAN_OR) reduce 24) ((T_COALESCE) reduce 24) ((T_DOUBLE_ARROW) reduce 24) ((T_INSTANCEOF) reduce 24) ((T_IS_EQUAL) reduce 24) ((T_IS_GREATER_OR_EQUAL) reduce 24) ((T_IS_IDENTICAL) reduce 24) ((T_IS_NOT_EQUAL) reduce 24) ((T_IS_NOT_IDENTICAL) reduce 24) ((T_IS_SMALLER_OR_EQUAL) reduce 24) ((T_LOGICAL_AND) reduce 24) ((T_LOGICAL_OR) reduce 24) ((T_LOGICAL_XOR) reduce 24) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 24) ((T_OBJECT_OPERATOR) reduce 24) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 24) ((T_POW) reduce 24) ((T_SL) reduce 24) ((T_SPACESHIP) reduce 24) ((T_SR) reduce 24) (("[") reduce 24) (("]") reduce 24) (("^") reduce 24) (("{") reduce 24) (("|") reduce 24)) 6844 ((("%") reduce 16) (("(") reduce 16) (("*") reduce 16) (("+") reduce 16) ((",") reduce 16) (("-") reduce 16) ((".") reduce 16) (("/") reduce 16) (("<") reduce 16) ((">") reduce 16) (("?") reduce 16) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_BOOLEAN_AND) reduce 16) ((T_BOOLEAN_OR) reduce 16) ((T_COALESCE) reduce 16) ((T_DOUBLE_ARROW) reduce 16) ((T_INSTANCEOF) reduce 16) ((T_IS_EQUAL) reduce 16) ((T_IS_GREATER_OR_EQUAL) reduce 16) ((T_IS_IDENTICAL) reduce 16) ((T_IS_NOT_EQUAL) reduce 16) ((T_IS_NOT_IDENTICAL) reduce 16) ((T_IS_SMALLER_OR_EQUAL) reduce 16) ((T_LOGICAL_AND) reduce 16) ((T_LOGICAL_OR) reduce 16) ((T_LOGICAL_XOR) reduce 16) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 16) ((T_OBJECT_OPERATOR) reduce 16) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 16) ((T_POW) reduce 16) ((T_SL) reduce 16) ((T_SPACESHIP) reduce 16) ((T_SR) reduce 16) (("[") reduce 16) (("]") reduce 16) (("^") reduce 16) (("{") reduce 16) (("|") reduce 16)) 6845 ((("%") reduce 48) (("(") reduce 48) (("*") reduce 48) (("+") reduce 48) ((",") reduce 48) (("-") reduce 48) ((".") reduce 48) (("/") reduce 48) (("<") reduce 48) ((">") reduce 48) (("?") reduce 48) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_BOOLEAN_AND) reduce 48) ((T_BOOLEAN_OR) reduce 48) ((T_COALESCE) reduce 48) ((T_DOUBLE_ARROW) reduce 48) ((T_INSTANCEOF) reduce 48) ((T_IS_EQUAL) reduce 48) ((T_IS_GREATER_OR_EQUAL) reduce 48) ((T_IS_IDENTICAL) reduce 48) ((T_IS_NOT_EQUAL) reduce 48) ((T_IS_NOT_IDENTICAL) reduce 48) ((T_IS_SMALLER_OR_EQUAL) reduce 48) ((T_LOGICAL_AND) reduce 48) ((T_LOGICAL_OR) reduce 48) ((T_LOGICAL_XOR) reduce 48) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 48) ((T_OBJECT_OPERATOR) reduce 48) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 48) ((T_POW) reduce 48) ((T_SL) reduce 48) ((T_SPACESHIP) reduce 48) ((T_SR) reduce 48) (("[") reduce 48) (("]") reduce 48) (("^") reduce 48) (("{") reduce 48) (("|") reduce 48)) 6846 ((("%") reduce 20) (("(") reduce 20) (("*") reduce 20) (("+") reduce 20) ((",") reduce 20) (("-") reduce 20) ((".") reduce 20) (("/") reduce 20) (("<") reduce 20) ((">") reduce 20) (("?") reduce 20) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_BOOLEAN_AND) reduce 20) ((T_BOOLEAN_OR) reduce 20) ((T_COALESCE) reduce 20) ((T_DOUBLE_ARROW) reduce 20) ((T_INSTANCEOF) reduce 20) ((T_IS_EQUAL) reduce 20) ((T_IS_GREATER_OR_EQUAL) reduce 20) ((T_IS_IDENTICAL) reduce 20) ((T_IS_NOT_EQUAL) reduce 20) ((T_IS_NOT_IDENTICAL) reduce 20) ((T_IS_SMALLER_OR_EQUAL) reduce 20) ((T_LOGICAL_AND) reduce 20) ((T_LOGICAL_OR) reduce 20) ((T_LOGICAL_XOR) reduce 20) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 20) ((T_OBJECT_OPERATOR) reduce 20) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 20) ((T_POW) reduce 20) ((T_SL) reduce 20) ((T_SPACESHIP) reduce 20) ((T_SR) reduce 20) (("[") reduce 20) (("]") reduce 20) (("^") reduce 20) (("{") reduce 20) (("|") reduce 20)) 6847 ((("%") reduce 70) (("(") reduce 70) (("*") reduce 70) (("+") reduce 70) ((",") reduce 70) (("-") reduce 70) ((".") reduce 70) (("/") reduce 70) (("<") reduce 70) ((">") reduce 70) (("?") reduce 70) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_BOOLEAN_AND) reduce 70) ((T_BOOLEAN_OR) reduce 70) ((T_COALESCE) reduce 70) ((T_DOUBLE_ARROW) reduce 70) ((T_INSTANCEOF) reduce 70) ((T_IS_EQUAL) reduce 70) ((T_IS_GREATER_OR_EQUAL) reduce 70) ((T_IS_IDENTICAL) reduce 70) ((T_IS_NOT_EQUAL) reduce 70) ((T_IS_NOT_IDENTICAL) reduce 70) ((T_IS_SMALLER_OR_EQUAL) reduce 70) ((T_LOGICAL_AND) reduce 70) ((T_LOGICAL_OR) reduce 70) ((T_LOGICAL_XOR) reduce 70) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 70) ((T_OBJECT_OPERATOR) reduce 70) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 70) ((T_POW) reduce 70) ((T_SL) reduce 70) ((T_SPACESHIP) reduce 70) ((T_SR) reduce 70) (("[") reduce 70) (("]") reduce 70) (("^") reduce 70) (("{") reduce 70) (("|") reduce 70)) 6848 ((("%") reduce 3) (("(") reduce 3) (("*") reduce 3) (("+") reduce 3) ((",") reduce 3) (("-") reduce 3) ((".") reduce 3) (("/") reduce 3) (("<") reduce 3) ((">") reduce 3) (("?") reduce 3) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_BOOLEAN_AND) reduce 3) ((T_BOOLEAN_OR) reduce 3) ((T_COALESCE) reduce 3) ((T_DOUBLE_ARROW) reduce 3) ((T_INSTANCEOF) reduce 3) ((T_IS_EQUAL) reduce 3) ((T_IS_GREATER_OR_EQUAL) reduce 3) ((T_IS_IDENTICAL) reduce 3) ((T_IS_NOT_EQUAL) reduce 3) ((T_IS_NOT_IDENTICAL) reduce 3) ((T_IS_SMALLER_OR_EQUAL) reduce 3) ((T_LOGICAL_AND) reduce 3) ((T_LOGICAL_OR) reduce 3) ((T_LOGICAL_XOR) reduce 3) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 3) ((T_OBJECT_OPERATOR) reduce 3) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 3) ((T_POW) reduce 3) ((T_SL) reduce 3) ((T_SPACESHIP) reduce 3) ((T_SR) reduce 3) (("[") reduce 3) (("]") reduce 3) (("^") reduce 3) (("{") reduce 3) (("|") reduce 3)) 6849 ((("%") reduce 12) (("(") reduce 12) (("*") reduce 12) (("+") reduce 12) ((",") reduce 12) (("-") reduce 12) ((".") reduce 12) (("/") reduce 12) (("<") reduce 12) ((">") reduce 12) (("?") reduce 12) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_BOOLEAN_AND) reduce 12) ((T_BOOLEAN_OR) reduce 12) ((T_COALESCE) reduce 12) ((T_DOUBLE_ARROW) reduce 12) ((T_INSTANCEOF) reduce 12) ((T_IS_EQUAL) reduce 12) ((T_IS_GREATER_OR_EQUAL) reduce 12) ((T_IS_IDENTICAL) reduce 12) ((T_IS_NOT_EQUAL) reduce 12) ((T_IS_NOT_IDENTICAL) reduce 12) ((T_IS_SMALLER_OR_EQUAL) reduce 12) ((T_LOGICAL_AND) reduce 12) ((T_LOGICAL_OR) reduce 12) ((T_LOGICAL_XOR) reduce 12) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 12) ((T_OBJECT_OPERATOR) reduce 12) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 12) ((T_POW) reduce 12) ((T_SL) reduce 12) ((T_SPACESHIP) reduce 12) ((T_SR) reduce 12) (("[") reduce 12) (("]") reduce 12) (("^") reduce 12) (("{") reduce 12) (("|") reduce 12)) 6850 ((("%") reduce 54) (("(") reduce 54) (("*") reduce 54) (("+") reduce 54) ((",") reduce 54) (("-") reduce 54) ((".") reduce 54) (("/") reduce 54) (("<") reduce 54) ((">") reduce 54) (("?") reduce 54) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_BOOLEAN_AND) reduce 54) ((T_BOOLEAN_OR) reduce 54) ((T_COALESCE) reduce 54) ((T_DOUBLE_ARROW) reduce 54) ((T_INSTANCEOF) reduce 54) ((T_IS_EQUAL) reduce 54) ((T_IS_GREATER_OR_EQUAL) reduce 54) ((T_IS_IDENTICAL) reduce 54) ((T_IS_NOT_EQUAL) reduce 54) ((T_IS_NOT_IDENTICAL) reduce 54) ((T_IS_SMALLER_OR_EQUAL) reduce 54) ((T_LOGICAL_AND) reduce 54) ((T_LOGICAL_OR) reduce 54) ((T_LOGICAL_XOR) reduce 54) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 54) ((T_OBJECT_OPERATOR) reduce 54) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 54) ((T_POW) reduce 54) ((T_SL) reduce 54) ((T_SPACESHIP) reduce 54) ((T_SR) reduce 54) (("[") reduce 54) (("]") reduce 54) (("^") reduce 54) (("{") reduce 54) (("|") reduce 54)) 6851 ((("%") reduce 65) (("(") reduce 65) (("*") reduce 65) (("+") reduce 65) ((",") reduce 65) (("-") reduce 65) ((".") reduce 65) (("/") reduce 65) (("<") reduce 65) ((">") reduce 65) (("?") reduce 65) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_BOOLEAN_AND) reduce 65) ((T_BOOLEAN_OR) reduce 65) ((T_COALESCE) reduce 65) ((T_DOUBLE_ARROW) reduce 65) ((T_INSTANCEOF) reduce 65) ((T_IS_EQUAL) reduce 65) ((T_IS_GREATER_OR_EQUAL) reduce 65) ((T_IS_IDENTICAL) reduce 65) ((T_IS_NOT_EQUAL) reduce 65) ((T_IS_NOT_IDENTICAL) reduce 65) ((T_IS_SMALLER_OR_EQUAL) reduce 65) ((T_LOGICAL_AND) reduce 65) ((T_LOGICAL_OR) reduce 65) ((T_LOGICAL_XOR) reduce 65) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 65) ((T_OBJECT_OPERATOR) reduce 65) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 65) ((T_POW) reduce 65) ((T_SL) reduce 65) ((T_SPACESHIP) reduce 65) ((T_SR) reduce 65) (("[") reduce 65) (("]") reduce 65) (("^") reduce 65) (("{") reduce 65) (("|") reduce 65)) 6852 ((("%") reduce 74) (("(") reduce 74) (("*") reduce 74) (("+") reduce 74) ((",") reduce 74) (("-") reduce 74) ((".") reduce 74) (("/") reduce 74) (("<") reduce 74) ((">") reduce 74) (("?") reduce 74) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_BOOLEAN_AND) reduce 74) ((T_BOOLEAN_OR) reduce 74) ((T_COALESCE) reduce 74) ((T_DOUBLE_ARROW) reduce 74) ((T_INSTANCEOF) reduce 74) ((T_IS_EQUAL) reduce 74) ((T_IS_GREATER_OR_EQUAL) reduce 74) ((T_IS_IDENTICAL) reduce 74) ((T_IS_NOT_EQUAL) reduce 74) ((T_IS_NOT_IDENTICAL) reduce 74) ((T_IS_SMALLER_OR_EQUAL) reduce 74) ((T_LOGICAL_AND) reduce 74) ((T_LOGICAL_OR) reduce 74) ((T_LOGICAL_XOR) reduce 74) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 74) ((T_OBJECT_OPERATOR) reduce 74) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 74) ((T_POW) reduce 74) ((T_SL) reduce 74) ((T_SPACESHIP) reduce 74) ((T_SR) reduce 74) (("[") reduce 74) (("]") reduce 74) (("^") reduce 74) (("{") reduce 74) (("|") reduce 74)) 6853 ((("%") reduce 30) (("(") reduce 30) (("*") reduce 30) (("+") reduce 30) ((",") reduce 30) (("-") reduce 30) ((".") reduce 30) (("/") reduce 30) (("<") reduce 30) ((">") reduce 30) (("?") reduce 30) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_BOOLEAN_AND) reduce 30) ((T_BOOLEAN_OR) reduce 30) ((T_COALESCE) reduce 30) ((T_DOUBLE_ARROW) reduce 30) ((T_INSTANCEOF) reduce 30) ((T_IS_EQUAL) reduce 30) ((T_IS_GREATER_OR_EQUAL) reduce 30) ((T_IS_IDENTICAL) reduce 30) ((T_IS_NOT_EQUAL) reduce 30) ((T_IS_NOT_IDENTICAL) reduce 30) ((T_IS_SMALLER_OR_EQUAL) reduce 30) ((T_LOGICAL_AND) reduce 30) ((T_LOGICAL_OR) reduce 30) ((T_LOGICAL_XOR) reduce 30) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 30) ((T_OBJECT_OPERATOR) reduce 30) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 30) ((T_POW) reduce 30) ((T_SL) reduce 30) ((T_SPACESHIP) reduce 30) ((T_SR) reduce 30) (("[") reduce 30) (("]") reduce 30) (("^") reduce 30) (("{") reduce 30) (("|") reduce 30)) 6854 ((("%") reduce 68) (("(") reduce 68) (("*") reduce 68) (("+") reduce 68) ((",") reduce 68) (("-") reduce 68) ((".") reduce 68) (("/") reduce 68) (("<") reduce 68) ((">") reduce 68) (("?") reduce 68) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_BOOLEAN_AND) reduce 68) ((T_BOOLEAN_OR) reduce 68) ((T_COALESCE) reduce 68) ((T_DOUBLE_ARROW) reduce 68) ((T_INSTANCEOF) reduce 68) ((T_IS_EQUAL) reduce 68) ((T_IS_GREATER_OR_EQUAL) reduce 68) ((T_IS_IDENTICAL) reduce 68) ((T_IS_NOT_EQUAL) reduce 68) ((T_IS_NOT_IDENTICAL) reduce 68) ((T_IS_SMALLER_OR_EQUAL) reduce 68) ((T_LOGICAL_AND) reduce 68) ((T_LOGICAL_OR) reduce 68) ((T_LOGICAL_XOR) reduce 68) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 68) ((T_OBJECT_OPERATOR) reduce 68) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 68) ((T_POW) reduce 68) ((T_SL) reduce 68) ((T_SPACESHIP) reduce 68) ((T_SR) reduce 68) (("[") reduce 68) (("]") reduce 68) (("^") reduce 68) (("{") reduce 68) (("|") reduce 68)) 6855 ((("%") reduce 21) (("(") reduce 21) (("*") reduce 21) (("+") reduce 21) ((",") reduce 21) (("-") reduce 21) ((".") reduce 21) (("/") reduce 21) (("<") reduce 21) ((">") reduce 21) (("?") reduce 21) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_BOOLEAN_AND) reduce 21) ((T_BOOLEAN_OR) reduce 21) ((T_COALESCE) reduce 21) ((T_DOUBLE_ARROW) reduce 21) ((T_INSTANCEOF) reduce 21) ((T_IS_EQUAL) reduce 21) ((T_IS_GREATER_OR_EQUAL) reduce 21) ((T_IS_IDENTICAL) reduce 21) ((T_IS_NOT_EQUAL) reduce 21) ((T_IS_NOT_IDENTICAL) reduce 21) ((T_IS_SMALLER_OR_EQUAL) reduce 21) ((T_LOGICAL_AND) reduce 21) ((T_LOGICAL_OR) reduce 21) ((T_LOGICAL_XOR) reduce 21) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 21) ((T_OBJECT_OPERATOR) reduce 21) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 21) ((T_POW) reduce 21) ((T_SL) reduce 21) ((T_SPACESHIP) reduce 21) ((T_SR) reduce 21) (("[") reduce 21) (("]") reduce 21) (("^") reduce 21) (("{") reduce 21) (("|") reduce 21)) 6856 ((("%") reduce 23) (("(") reduce 23) (("*") reduce 23) (("+") reduce 23) ((",") reduce 23) (("-") reduce 23) ((".") reduce 23) (("/") reduce 23) (("<") reduce 23) ((">") reduce 23) (("?") reduce 23) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_BOOLEAN_AND) reduce 23) ((T_BOOLEAN_OR) reduce 23) ((T_COALESCE) reduce 23) ((T_DOUBLE_ARROW) reduce 23) ((T_INSTANCEOF) reduce 23) ((T_IS_EQUAL) reduce 23) ((T_IS_GREATER_OR_EQUAL) reduce 23) ((T_IS_IDENTICAL) reduce 23) ((T_IS_NOT_EQUAL) reduce 23) ((T_IS_NOT_IDENTICAL) reduce 23) ((T_IS_SMALLER_OR_EQUAL) reduce 23) ((T_LOGICAL_AND) reduce 23) ((T_LOGICAL_OR) reduce 23) ((T_LOGICAL_XOR) reduce 23) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 23) ((T_OBJECT_OPERATOR) reduce 23) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 23) ((T_POW) reduce 23) ((T_SL) reduce 23) ((T_SPACESHIP) reduce 23) ((T_SR) reduce 23) (("[") reduce 23) (("]") reduce 23) (("^") reduce 23) (("{") reduce 23) (("|") reduce 23)) 6857 ((("%") reduce 41) (("(") reduce 41) (("*") reduce 41) (("+") reduce 41) ((",") reduce 41) (("-") reduce 41) ((".") reduce 41) (("/") reduce 41) (("<") reduce 41) ((">") reduce 41) (("?") reduce 41) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_BOOLEAN_AND) reduce 41) ((T_BOOLEAN_OR) reduce 41) ((T_COALESCE) reduce 41) ((T_DOUBLE_ARROW) reduce 41) ((T_INSTANCEOF) reduce 41) ((T_IS_EQUAL) reduce 41) ((T_IS_GREATER_OR_EQUAL) reduce 41) ((T_IS_IDENTICAL) reduce 41) ((T_IS_NOT_EQUAL) reduce 41) ((T_IS_NOT_IDENTICAL) reduce 41) ((T_IS_SMALLER_OR_EQUAL) reduce 41) ((T_LOGICAL_AND) reduce 41) ((T_LOGICAL_OR) reduce 41) ((T_LOGICAL_XOR) reduce 41) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 41) ((T_OBJECT_OPERATOR) reduce 41) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 41) ((T_POW) reduce 41) ((T_SL) reduce 41) ((T_SPACESHIP) reduce 41) ((T_SR) reduce 41) (("[") reduce 41) (("]") reduce 41) (("^") reduce 41) (("{") reduce 41) (("|") reduce 41)) 6858 ((("%") reduce 62) (("(") reduce 62) (("*") reduce 62) (("+") reduce 62) ((",") reduce 62) (("-") reduce 62) ((".") reduce 62) (("/") reduce 62) (("<") reduce 62) ((">") reduce 62) (("?") reduce 62) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_BOOLEAN_AND) reduce 62) ((T_BOOLEAN_OR) reduce 62) ((T_COALESCE) reduce 62) ((T_DOUBLE_ARROW) reduce 62) ((T_INSTANCEOF) reduce 62) ((T_IS_EQUAL) reduce 62) ((T_IS_GREATER_OR_EQUAL) reduce 62) ((T_IS_IDENTICAL) reduce 62) ((T_IS_NOT_EQUAL) reduce 62) ((T_IS_NOT_IDENTICAL) reduce 62) ((T_IS_SMALLER_OR_EQUAL) reduce 62) ((T_LOGICAL_AND) reduce 62) ((T_LOGICAL_OR) reduce 62) ((T_LOGICAL_XOR) reduce 62) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 62) ((T_OBJECT_OPERATOR) reduce 62) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 62) ((T_POW) reduce 62) ((T_SL) reduce 62) ((T_SPACESHIP) reduce 62) ((T_SR) reduce 62) (("[") reduce 62) (("]") reduce 62) (("^") reduce 62) (("{") reduce 62) (("|") reduce 62)) 6859 ((("%") reduce 34) (("(") reduce 34) (("*") reduce 34) (("+") reduce 34) ((",") reduce 34) (("-") reduce 34) ((".") reduce 34) (("/") reduce 34) (("<") reduce 34) ((">") reduce 34) (("?") reduce 34) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_BOOLEAN_AND) reduce 34) ((T_BOOLEAN_OR) reduce 34) ((T_COALESCE) reduce 34) ((T_DOUBLE_ARROW) reduce 34) ((T_INSTANCEOF) reduce 34) ((T_IS_EQUAL) reduce 34) ((T_IS_GREATER_OR_EQUAL) reduce 34) ((T_IS_IDENTICAL) reduce 34) ((T_IS_NOT_EQUAL) reduce 34) ((T_IS_NOT_IDENTICAL) reduce 34) ((T_IS_SMALLER_OR_EQUAL) reduce 34) ((T_LOGICAL_AND) reduce 34) ((T_LOGICAL_OR) reduce 34) ((T_LOGICAL_XOR) reduce 34) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 34) ((T_OBJECT_OPERATOR) reduce 34) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 34) ((T_POW) reduce 34) ((T_SL) reduce 34) ((T_SPACESHIP) reduce 34) ((T_SR) reduce 34) (("[") reduce 34) (("]") reduce 34) (("^") reduce 34) (("{") reduce 34) (("|") reduce 34)) 6860 ((("%") reduce 40) (("(") reduce 40) (("*") reduce 40) (("+") reduce 40) ((",") reduce 40) (("-") reduce 40) ((".") reduce 40) (("/") reduce 40) (("<") reduce 40) ((">") reduce 40) (("?") reduce 40) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_BOOLEAN_AND) reduce 40) ((T_BOOLEAN_OR) reduce 40) ((T_COALESCE) reduce 40) ((T_DOUBLE_ARROW) reduce 40) ((T_INSTANCEOF) reduce 40) ((T_IS_EQUAL) reduce 40) ((T_IS_GREATER_OR_EQUAL) reduce 40) ((T_IS_IDENTICAL) reduce 40) ((T_IS_NOT_EQUAL) reduce 40) ((T_IS_NOT_IDENTICAL) reduce 40) ((T_IS_SMALLER_OR_EQUAL) reduce 40) ((T_LOGICAL_AND) reduce 40) ((T_LOGICAL_OR) reduce 40) ((T_LOGICAL_XOR) reduce 40) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 40) ((T_OBJECT_OPERATOR) reduce 40) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 40) ((T_POW) reduce 40) ((T_SL) reduce 40) ((T_SPACESHIP) reduce 40) ((T_SR) reduce 40) (("[") reduce 40) (("]") reduce 40) (("^") reduce 40) (("{") reduce 40) (("|") reduce 40)) 6861 ((("%") reduce 13) (("(") reduce 13) (("*") reduce 13) (("+") reduce 13) ((",") reduce 13) (("-") reduce 13) ((".") reduce 13) (("/") reduce 13) (("<") reduce 13) ((">") reduce 13) (("?") reduce 13) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_BOOLEAN_AND) reduce 13) ((T_BOOLEAN_OR) reduce 13) ((T_COALESCE) reduce 13) ((T_DOUBLE_ARROW) reduce 13) ((T_INSTANCEOF) reduce 13) ((T_IS_EQUAL) reduce 13) ((T_IS_GREATER_OR_EQUAL) reduce 13) ((T_IS_IDENTICAL) reduce 13) ((T_IS_NOT_EQUAL) reduce 13) ((T_IS_NOT_IDENTICAL) reduce 13) ((T_IS_SMALLER_OR_EQUAL) reduce 13) ((T_LOGICAL_AND) reduce 13) ((T_LOGICAL_OR) reduce 13) ((T_LOGICAL_XOR) reduce 13) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 13) ((T_OBJECT_OPERATOR) reduce 13) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 13) ((T_POW) reduce 13) ((T_SL) reduce 13) ((T_SPACESHIP) reduce 13) ((T_SR) reduce 13) (("[") reduce 13) (("]") reduce 13) (("^") reduce 13) (("{") reduce 13) (("|") reduce 13)) 6862 ((("%") reduce 55) (("(") reduce 55) (("*") reduce 55) (("+") reduce 55) ((",") reduce 55) (("-") reduce 55) ((".") reduce 55) (("/") reduce 55) (("<") reduce 55) ((">") reduce 55) (("?") reduce 55) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_BOOLEAN_AND) reduce 55) ((T_BOOLEAN_OR) reduce 55) ((T_COALESCE) reduce 55) ((T_DOUBLE_ARROW) reduce 55) ((T_INSTANCEOF) reduce 55) ((T_IS_EQUAL) reduce 55) ((T_IS_GREATER_OR_EQUAL) reduce 55) ((T_IS_IDENTICAL) reduce 55) ((T_IS_NOT_EQUAL) reduce 55) ((T_IS_NOT_IDENTICAL) reduce 55) ((T_IS_SMALLER_OR_EQUAL) reduce 55) ((T_LOGICAL_AND) reduce 55) ((T_LOGICAL_OR) reduce 55) ((T_LOGICAL_XOR) reduce 55) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 55) ((T_OBJECT_OPERATOR) reduce 55) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 55) ((T_POW) reduce 55) ((T_SL) reduce 55) ((T_SPACESHIP) reduce 55) ((T_SR) reduce 55) (("[") reduce 55) (("]") reduce 55) (("^") reduce 55) (("{") reduce 55) (("|") reduce 55)) 6863 ((("%") reduce 1) (("(") reduce 1) (("*") reduce 1) (("+") reduce 1) ((",") reduce 1) (("-") reduce 1) ((".") reduce 1) (("/") reduce 1) (("<") reduce 1) ((">") reduce 1) (("?") reduce 1) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_BOOLEAN_AND) reduce 1) ((T_BOOLEAN_OR) reduce 1) ((T_COALESCE) reduce 1) ((T_DOUBLE_ARROW) reduce 1) ((T_INSTANCEOF) reduce 1) ((T_IS_EQUAL) reduce 1) ((T_IS_GREATER_OR_EQUAL) reduce 1) ((T_IS_IDENTICAL) reduce 1) ((T_IS_NOT_EQUAL) reduce 1) ((T_IS_NOT_IDENTICAL) reduce 1) ((T_IS_SMALLER_OR_EQUAL) reduce 1) ((T_LOGICAL_AND) reduce 1) ((T_LOGICAL_OR) reduce 1) ((T_LOGICAL_XOR) reduce 1) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 1) ((T_OBJECT_OPERATOR) reduce 1) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 1) ((T_POW) reduce 1) ((T_SL) reduce 1) ((T_SPACESHIP) reduce 1) ((T_SR) reduce 1) (("[") reduce 1) (("]") reduce 1) (("^") reduce 1) (("{") reduce 1) (("|") reduce 1)) 6864 ((("%") reduce 2) (("(") reduce 2) (("*") reduce 2) (("+") reduce 2) ((",") reduce 2) (("-") reduce 2) ((".") reduce 2) (("/") reduce 2) (("<") reduce 2) ((">") reduce 2) (("?") reduce 2) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_BOOLEAN_AND) reduce 2) ((T_BOOLEAN_OR) reduce 2) ((T_COALESCE) reduce 2) ((T_DOUBLE_ARROW) reduce 2) ((T_INSTANCEOF) reduce 2) ((T_IS_EQUAL) reduce 2) ((T_IS_GREATER_OR_EQUAL) reduce 2) ((T_IS_IDENTICAL) reduce 2) ((T_IS_NOT_EQUAL) reduce 2) ((T_IS_NOT_IDENTICAL) reduce 2) ((T_IS_SMALLER_OR_EQUAL) reduce 2) ((T_LOGICAL_AND) reduce 2) ((T_LOGICAL_OR) reduce 2) ((T_LOGICAL_XOR) reduce 2) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 2) ((T_OBJECT_OPERATOR) reduce 2) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 2) ((T_POW) reduce 2) ((T_SL) reduce 2) ((T_SPACESHIP) reduce 2) ((T_SR) reduce 2) (("[") reduce 2) (("]") reduce 2) (("^") reduce 2) (("{") reduce 2) (("|") reduce 2)) 6865 ((("%") reduce 9) (("(") reduce 9) (("*") reduce 9) (("+") reduce 9) ((",") reduce 9) (("-") reduce 9) ((".") reduce 9) (("/") reduce 9) (("<") reduce 9) ((">") reduce 9) (("?") reduce 9) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_BOOLEAN_AND) reduce 9) ((T_BOOLEAN_OR) reduce 9) ((T_COALESCE) reduce 9) ((T_DOUBLE_ARROW) reduce 9) ((T_INSTANCEOF) reduce 9) ((T_IS_EQUAL) reduce 9) ((T_IS_GREATER_OR_EQUAL) reduce 9) ((T_IS_IDENTICAL) reduce 9) ((T_IS_NOT_EQUAL) reduce 9) ((T_IS_NOT_IDENTICAL) reduce 9) ((T_IS_SMALLER_OR_EQUAL) reduce 9) ((T_LOGICAL_AND) reduce 9) ((T_LOGICAL_OR) reduce 9) ((T_LOGICAL_XOR) reduce 9) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 9) ((T_OBJECT_OPERATOR) reduce 9) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 9) ((T_POW) reduce 9) ((T_SL) reduce 9) ((T_SPACESHIP) reduce 9) ((T_SR) reduce 9) (("[") reduce 9) (("]") reduce 9) (("^") reduce 9) (("{") reduce 9) (("|") reduce 9)) 6866 ((("%") reduce 33) (("(") reduce 33) (("*") reduce 33) (("+") reduce 33) ((",") reduce 33) (("-") reduce 33) ((".") reduce 33) (("/") reduce 33) (("<") reduce 33) ((">") reduce 33) (("?") reduce 33) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_BOOLEAN_AND) reduce 33) ((T_BOOLEAN_OR) reduce 33) ((T_COALESCE) reduce 33) ((T_DOUBLE_ARROW) reduce 33) ((T_INSTANCEOF) reduce 33) ((T_IS_EQUAL) reduce 33) ((T_IS_GREATER_OR_EQUAL) reduce 33) ((T_IS_IDENTICAL) reduce 33) ((T_IS_NOT_EQUAL) reduce 33) ((T_IS_NOT_IDENTICAL) reduce 33) ((T_IS_SMALLER_OR_EQUAL) reduce 33) ((T_LOGICAL_AND) reduce 33) ((T_LOGICAL_OR) reduce 33) ((T_LOGICAL_XOR) reduce 33) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 33) ((T_OBJECT_OPERATOR) reduce 33) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 33) ((T_POW) reduce 33) ((T_SL) reduce 33) ((T_SPACESHIP) reduce 33) ((T_SR) reduce 33) (("[") reduce 33) (("]") reduce 33) (("^") reduce 33) (("{") reduce 33) (("|") reduce 33)) 6867 ((("%") reduce 58) (("(") reduce 58) (("*") reduce 58) (("+") reduce 58) ((",") reduce 58) (("-") reduce 58) ((".") reduce 58) (("/") reduce 58) (("<") reduce 58) ((">") reduce 58) (("?") reduce 58) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_BOOLEAN_AND) reduce 58) ((T_BOOLEAN_OR) reduce 58) ((T_COALESCE) reduce 58) ((T_DOUBLE_ARROW) reduce 58) ((T_INSTANCEOF) reduce 58) ((T_IS_EQUAL) reduce 58) ((T_IS_GREATER_OR_EQUAL) reduce 58) ((T_IS_IDENTICAL) reduce 58) ((T_IS_NOT_EQUAL) reduce 58) ((T_IS_NOT_IDENTICAL) reduce 58) ((T_IS_SMALLER_OR_EQUAL) reduce 58) ((T_LOGICAL_AND) reduce 58) ((T_LOGICAL_OR) reduce 58) ((T_LOGICAL_XOR) reduce 58) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 58) ((T_OBJECT_OPERATOR) reduce 58) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 58) ((T_POW) reduce 58) ((T_SL) reduce 58) ((T_SPACESHIP) reduce 58) ((T_SR) reduce 58) (("[") reduce 58) (("]") reduce 58) (("^") reduce 58) (("{") reduce 58) (("|") reduce 58)) 6868 ((("%") reduce 37) (("(") reduce 37) (("*") reduce 37) (("+") reduce 37) ((",") reduce 37) (("-") reduce 37) ((".") reduce 37) (("/") reduce 37) (("<") reduce 37) ((">") reduce 37) (("?") reduce 37) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_BOOLEAN_AND) reduce 37) ((T_BOOLEAN_OR) reduce 37) ((T_COALESCE) reduce 37) ((T_DOUBLE_ARROW) reduce 37) ((T_INSTANCEOF) reduce 37) ((T_IS_EQUAL) reduce 37) ((T_IS_GREATER_OR_EQUAL) reduce 37) ((T_IS_IDENTICAL) reduce 37) ((T_IS_NOT_EQUAL) reduce 37) ((T_IS_NOT_IDENTICAL) reduce 37) ((T_IS_SMALLER_OR_EQUAL) reduce 37) ((T_LOGICAL_AND) reduce 37) ((T_LOGICAL_OR) reduce 37) ((T_LOGICAL_XOR) reduce 37) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 37) ((T_OBJECT_OPERATOR) reduce 37) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 37) ((T_POW) reduce 37) ((T_SL) reduce 37) ((T_SPACESHIP) reduce 37) ((T_SR) reduce 37) (("[") reduce 37) (("]") reduce 37) (("^") reduce 37) (("{") reduce 37) (("|") reduce 37)) 6869 ((("%") reduce 64) (("(") reduce 64) (("*") reduce 64) (("+") reduce 64) ((",") reduce 64) (("-") reduce 64) ((".") reduce 64) (("/") reduce 64) (("<") reduce 64) ((">") reduce 64) (("?") reduce 64) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_BOOLEAN_AND) reduce 64) ((T_BOOLEAN_OR) reduce 64) ((T_COALESCE) reduce 64) ((T_DOUBLE_ARROW) reduce 64) ((T_INSTANCEOF) reduce 64) ((T_IS_EQUAL) reduce 64) ((T_IS_GREATER_OR_EQUAL) reduce 64) ((T_IS_IDENTICAL) reduce 64) ((T_IS_NOT_EQUAL) reduce 64) ((T_IS_NOT_IDENTICAL) reduce 64) ((T_IS_SMALLER_OR_EQUAL) reduce 64) ((T_LOGICAL_AND) reduce 64) ((T_LOGICAL_OR) reduce 64) ((T_LOGICAL_XOR) reduce 64) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 64) ((T_OBJECT_OPERATOR) reduce 64) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 64) ((T_POW) reduce 64) ((T_SL) reduce 64) ((T_SPACESHIP) reduce 64) ((T_SR) reduce 64) (("[") reduce 64) (("]") reduce 64) (("^") reduce 64) (("{") reduce 64) (("|") reduce 64)) 6870 ((("%") reduce 46) (("(") reduce 46) (("*") reduce 46) (("+") reduce 46) ((",") reduce 46) (("-") reduce 46) ((".") reduce 46) (("/") reduce 46) (("<") reduce 46) ((">") reduce 46) (("?") reduce 46) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_BOOLEAN_AND) reduce 46) ((T_BOOLEAN_OR) reduce 46) ((T_COALESCE) reduce 46) ((T_DOUBLE_ARROW) reduce 46) ((T_INSTANCEOF) reduce 46) ((T_IS_EQUAL) reduce 46) ((T_IS_GREATER_OR_EQUAL) reduce 46) ((T_IS_IDENTICAL) reduce 46) ((T_IS_NOT_EQUAL) reduce 46) ((T_IS_NOT_IDENTICAL) reduce 46) ((T_IS_SMALLER_OR_EQUAL) reduce 46) ((T_LOGICAL_AND) reduce 46) ((T_LOGICAL_OR) reduce 46) ((T_LOGICAL_XOR) reduce 46) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 46) ((T_OBJECT_OPERATOR) reduce 46) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 46) ((T_POW) reduce 46) ((T_SL) reduce 46) ((T_SPACESHIP) reduce 46) ((T_SR) reduce 46) (("[") reduce 46) (("]") reduce 46) (("^") reduce 46) (("{") reduce 46) (("|") reduce 46)) 6871 ((("%") reduce 8) (("(") reduce 8) (("*") reduce 8) (("+") reduce 8) ((",") reduce 8) (("-") reduce 8) ((".") reduce 8) (("/") reduce 8) (("<") reduce 8) ((">") reduce 8) (("?") reduce 8) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_BOOLEAN_AND) reduce 8) ((T_BOOLEAN_OR) reduce 8) ((T_COALESCE) reduce 8) ((T_DOUBLE_ARROW) reduce 8) ((T_INSTANCEOF) reduce 8) ((T_IS_EQUAL) reduce 8) ((T_IS_GREATER_OR_EQUAL) reduce 8) ((T_IS_IDENTICAL) reduce 8) ((T_IS_NOT_EQUAL) reduce 8) ((T_IS_NOT_IDENTICAL) reduce 8) ((T_IS_SMALLER_OR_EQUAL) reduce 8) ((T_LOGICAL_AND) reduce 8) ((T_LOGICAL_OR) reduce 8) ((T_LOGICAL_XOR) reduce 8) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 8) ((T_OBJECT_OPERATOR) reduce 8) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 8) ((T_POW) reduce 8) ((T_SL) reduce 8) ((T_SPACESHIP) reduce 8) ((T_SR) reduce 8) (("[") reduce 8) (("]") reduce 8) (("^") reduce 8) (("{") reduce 8) (("|") reduce 8)) 6872 ((("%") reduce 6) (("(") reduce 6) (("*") reduce 6) (("+") reduce 6) ((",") reduce 6) (("-") reduce 6) ((".") reduce 6) (("/") reduce 6) (("<") reduce 6) ((">") reduce 6) (("?") reduce 6) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_BOOLEAN_AND) reduce 6) ((T_BOOLEAN_OR) reduce 6) ((T_COALESCE) reduce 6) ((T_DOUBLE_ARROW) reduce 6) ((T_INSTANCEOF) reduce 6) ((T_IS_EQUAL) reduce 6) ((T_IS_GREATER_OR_EQUAL) reduce 6) ((T_IS_IDENTICAL) reduce 6) ((T_IS_NOT_EQUAL) reduce 6) ((T_IS_NOT_IDENTICAL) reduce 6) ((T_IS_SMALLER_OR_EQUAL) reduce 6) ((T_LOGICAL_AND) reduce 6) ((T_LOGICAL_OR) reduce 6) ((T_LOGICAL_XOR) reduce 6) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 6) ((T_OBJECT_OPERATOR) reduce 6) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 6) ((T_POW) reduce 6) ((T_SL) reduce 6) ((T_SPACESHIP) reduce 6) ((T_SR) reduce 6) (("[") reduce 6) (("]") reduce 6) (("^") reduce 6) (("{") reduce 6) (("|") reduce 6)) 6873 ((("%") reduce 7) (("(") reduce 7) (("*") reduce 7) (("+") reduce 7) ((",") reduce 7) (("-") reduce 7) ((".") reduce 7) (("/") reduce 7) (("<") reduce 7) ((">") reduce 7) (("?") reduce 7) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_BOOLEAN_AND) reduce 7) ((T_BOOLEAN_OR) reduce 7) ((T_COALESCE) reduce 7) ((T_DOUBLE_ARROW) reduce 7) ((T_INSTANCEOF) reduce 7) ((T_IS_EQUAL) reduce 7) ((T_IS_GREATER_OR_EQUAL) reduce 7) ((T_IS_IDENTICAL) reduce 7) ((T_IS_NOT_EQUAL) reduce 7) ((T_IS_NOT_IDENTICAL) reduce 7) ((T_IS_SMALLER_OR_EQUAL) reduce 7) ((T_LOGICAL_AND) reduce 7) ((T_LOGICAL_OR) reduce 7) ((T_LOGICAL_XOR) reduce 7) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 7) ((T_OBJECT_OPERATOR) reduce 7) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 7) ((T_POW) reduce 7) ((T_SL) reduce 7) ((T_SPACESHIP) reduce 7) ((T_SR) reduce 7) (("[") reduce 7) (("]") reduce 7) (("^") reduce 7) (("{") reduce 7) (("|") reduce 7)) 6874 ((("%") reduce 69) (("(") reduce 69) (("*") reduce 69) (("+") reduce 69) ((",") reduce 69) (("-") reduce 69) ((".") reduce 69) (("/") reduce 69) (("<") reduce 69) ((">") reduce 69) (("?") reduce 69) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_BOOLEAN_AND) reduce 69) ((T_BOOLEAN_OR) reduce 69) ((T_COALESCE) reduce 69) ((T_DOUBLE_ARROW) reduce 69) ((T_INSTANCEOF) reduce 69) ((T_IS_EQUAL) reduce 69) ((T_IS_GREATER_OR_EQUAL) reduce 69) ((T_IS_IDENTICAL) reduce 69) ((T_IS_NOT_EQUAL) reduce 69) ((T_IS_NOT_IDENTICAL) reduce 69) ((T_IS_SMALLER_OR_EQUAL) reduce 69) ((T_LOGICAL_AND) reduce 69) ((T_LOGICAL_OR) reduce 69) ((T_LOGICAL_XOR) reduce 69) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 69) ((T_OBJECT_OPERATOR) reduce 69) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 69) ((T_POW) reduce 69) ((T_SL) reduce 69) ((T_SPACESHIP) reduce 69) ((T_SR) reduce 69) (("[") reduce 69) (("]") reduce 69) (("^") reduce 69) (("{") reduce 69) (("|") reduce 69)) 6875 ((("%") reduce 63) (("(") reduce 63) (("*") reduce 63) (("+") reduce 63) ((",") reduce 63) (("-") reduce 63) ((".") reduce 63) (("/") reduce 63) (("<") reduce 63) ((">") reduce 63) (("?") reduce 63) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_BOOLEAN_AND) reduce 63) ((T_BOOLEAN_OR) reduce 63) ((T_COALESCE) reduce 63) ((T_DOUBLE_ARROW) reduce 63) ((T_INSTANCEOF) reduce 63) ((T_IS_EQUAL) reduce 63) ((T_IS_GREATER_OR_EQUAL) reduce 63) ((T_IS_IDENTICAL) reduce 63) ((T_IS_NOT_EQUAL) reduce 63) ((T_IS_NOT_IDENTICAL) reduce 63) ((T_IS_SMALLER_OR_EQUAL) reduce 63) ((T_LOGICAL_AND) reduce 63) ((T_LOGICAL_OR) reduce 63) ((T_LOGICAL_XOR) reduce 63) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 63) ((T_OBJECT_OPERATOR) reduce 63) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 63) ((T_POW) reduce 63) ((T_SL) reduce 63) ((T_SPACESHIP) reduce 63) ((T_SR) reduce 63) (("[") reduce 63) (("]") reduce 63) (("^") reduce 63) (("{") reduce 63) (("|") reduce 63)) 6876 ((("%") reduce 56) (("(") reduce 56) (("*") reduce 56) (("+") reduce 56) ((",") reduce 56) (("-") reduce 56) ((".") reduce 56) (("/") reduce 56) (("<") reduce 56) ((">") reduce 56) (("?") reduce 56) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_BOOLEAN_AND) reduce 56) ((T_BOOLEAN_OR) reduce 56) ((T_COALESCE) reduce 56) ((T_DOUBLE_ARROW) reduce 56) ((T_INSTANCEOF) reduce 56) ((T_IS_EQUAL) reduce 56) ((T_IS_GREATER_OR_EQUAL) reduce 56) ((T_IS_IDENTICAL) reduce 56) ((T_IS_NOT_EQUAL) reduce 56) ((T_IS_NOT_IDENTICAL) reduce 56) ((T_IS_SMALLER_OR_EQUAL) reduce 56) ((T_LOGICAL_AND) reduce 56) ((T_LOGICAL_OR) reduce 56) ((T_LOGICAL_XOR) reduce 56) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 56) ((T_OBJECT_OPERATOR) reduce 56) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 56) ((T_POW) reduce 56) ((T_SL) reduce 56) ((T_SPACESHIP) reduce 56) ((T_SR) reduce 56) (("[") reduce 56) (("]") reduce 56) (("^") reduce 56) (("{") reduce 56) (("|") reduce 56)) 6877 ((("%") reduce 10) (("(") reduce 10) (("*") reduce 10) (("+") reduce 10) ((",") reduce 10) (("-") reduce 10) ((".") reduce 10) (("/") reduce 10) (("<") reduce 10) ((">") reduce 10) (("?") reduce 10) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_BOOLEAN_AND) reduce 10) ((T_BOOLEAN_OR) reduce 10) ((T_COALESCE) reduce 10) ((T_DOUBLE_ARROW) reduce 10) ((T_INSTANCEOF) reduce 10) ((T_IS_EQUAL) reduce 10) ((T_IS_GREATER_OR_EQUAL) reduce 10) ((T_IS_IDENTICAL) reduce 10) ((T_IS_NOT_EQUAL) reduce 10) ((T_IS_NOT_IDENTICAL) reduce 10) ((T_IS_SMALLER_OR_EQUAL) reduce 10) ((T_LOGICAL_AND) reduce 10) ((T_LOGICAL_OR) reduce 10) ((T_LOGICAL_XOR) reduce 10) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 10) ((T_OBJECT_OPERATOR) reduce 10) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 10) ((T_POW) reduce 10) ((T_SL) reduce 10) ((T_SPACESHIP) reduce 10) ((T_SR) reduce 10) (("[") reduce 10) (("]") reduce 10) (("^") reduce 10) (("{") reduce 10) (("|") reduce 10)) 6878 ((("%") reduce 67) (("(") reduce 67) (("*") reduce 67) (("+") reduce 67) ((",") reduce 67) (("-") reduce 67) ((".") reduce 67) (("/") reduce 67) (("<") reduce 67) ((">") reduce 67) (("?") reduce 67) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_BOOLEAN_AND) reduce 67) ((T_BOOLEAN_OR) reduce 67) ((T_COALESCE) reduce 67) ((T_DOUBLE_ARROW) reduce 67) ((T_INSTANCEOF) reduce 67) ((T_IS_EQUAL) reduce 67) ((T_IS_GREATER_OR_EQUAL) reduce 67) ((T_IS_IDENTICAL) reduce 67) ((T_IS_NOT_EQUAL) reduce 67) ((T_IS_NOT_IDENTICAL) reduce 67) ((T_IS_SMALLER_OR_EQUAL) reduce 67) ((T_LOGICAL_AND) reduce 67) ((T_LOGICAL_OR) reduce 67) ((T_LOGICAL_XOR) reduce 67) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 67) ((T_OBJECT_OPERATOR) reduce 67) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 67) ((T_POW) reduce 67) ((T_SL) reduce 67) ((T_SPACESHIP) reduce 67) ((T_SR) reduce 67) (("[") reduce 67) (("]") reduce 67) (("^") reduce 67) (("{") reduce 67) (("|") reduce 67)) 6879 ((("%") reduce 44) (("(") reduce 44) (("*") reduce 44) (("+") reduce 44) ((",") reduce 44) (("-") reduce 44) ((".") reduce 44) (("/") reduce 44) (("<") reduce 44) ((">") reduce 44) (("?") reduce 44) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_BOOLEAN_AND) reduce 44) ((T_BOOLEAN_OR) reduce 44) ((T_COALESCE) reduce 44) ((T_DOUBLE_ARROW) reduce 44) ((T_INSTANCEOF) reduce 44) ((T_IS_EQUAL) reduce 44) ((T_IS_GREATER_OR_EQUAL) reduce 44) ((T_IS_IDENTICAL) reduce 44) ((T_IS_NOT_EQUAL) reduce 44) ((T_IS_NOT_IDENTICAL) reduce 44) ((T_IS_SMALLER_OR_EQUAL) reduce 44) ((T_LOGICAL_AND) reduce 44) ((T_LOGICAL_OR) reduce 44) ((T_LOGICAL_XOR) reduce 44) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 44) ((T_OBJECT_OPERATOR) reduce 44) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 44) ((T_POW) reduce 44) ((T_SL) reduce 44) ((T_SPACESHIP) reduce 44) ((T_SR) reduce 44) (("[") reduce 44) (("]") reduce 44) (("^") reduce 44) (("{") reduce 44) (("|") reduce 44)) 6880 ((("%") reduce 75) (("(") reduce 75) (("*") reduce 75) (("+") reduce 75) ((",") reduce 75) (("-") reduce 75) ((".") reduce 75) (("/") reduce 75) (("<") reduce 75) ((">") reduce 75) (("?") reduce 75) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_BOOLEAN_AND) reduce 75) ((T_BOOLEAN_OR) reduce 75) ((T_COALESCE) reduce 75) ((T_DOUBLE_ARROW) reduce 75) ((T_INSTANCEOF) reduce 75) ((T_IS_EQUAL) reduce 75) ((T_IS_GREATER_OR_EQUAL) reduce 75) ((T_IS_IDENTICAL) reduce 75) ((T_IS_NOT_EQUAL) reduce 75) ((T_IS_NOT_IDENTICAL) reduce 75) ((T_IS_SMALLER_OR_EQUAL) reduce 75) ((T_LOGICAL_AND) reduce 75) ((T_LOGICAL_OR) reduce 75) ((T_LOGICAL_XOR) reduce 75) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 75) ((T_OBJECT_OPERATOR) reduce 75) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 75) ((T_POW) reduce 75) ((T_SL) reduce 75) ((T_SPACESHIP) reduce 75) ((T_SR) reduce 75) (("[") reduce 75) (("]") reduce 75) (("^") reduce 75) (("{") reduce 75) (("|") reduce 75)) 6881 ((("%") reduce 76) (("(") reduce 76) (("*") reduce 76) (("+") reduce 76) ((",") reduce 76) (("-") reduce 76) ((".") reduce 76) (("/") reduce 76) (("<") reduce 76) ((">") reduce 76) (("?") reduce 76) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_BOOLEAN_AND) reduce 76) ((T_BOOLEAN_OR) reduce 76) ((T_COALESCE) reduce 76) ((T_DOUBLE_ARROW) reduce 76) ((T_INSTANCEOF) reduce 76) ((T_IS_EQUAL) reduce 76) ((T_IS_GREATER_OR_EQUAL) reduce 76) ((T_IS_IDENTICAL) reduce 76) ((T_IS_NOT_EQUAL) reduce 76) ((T_IS_NOT_IDENTICAL) reduce 76) ((T_IS_SMALLER_OR_EQUAL) reduce 76) ((T_LOGICAL_AND) reduce 76) ((T_LOGICAL_OR) reduce 76) ((T_LOGICAL_XOR) reduce 76) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 76) ((T_OBJECT_OPERATOR) reduce 76) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 76) ((T_POW) reduce 76) ((T_SL) reduce 76) ((T_SPACESHIP) reduce 76) ((T_SR) reduce 76) (("[") reduce 76) (("]") reduce 76) (("^") reduce 76) (("{") reduce 76) (("|") reduce 76)) 6882 ((("%") reduce 77) (("(") reduce 77) (("*") reduce 77) (("+") reduce 77) ((",") reduce 77) (("-") reduce 77) ((".") reduce 77) (("/") reduce 77) (("<") reduce 77) ((">") reduce 77) (("?") reduce 77) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_BOOLEAN_AND) reduce 77) ((T_BOOLEAN_OR) reduce 77) ((T_COALESCE) reduce 77) ((T_DOUBLE_ARROW) reduce 77) ((T_INSTANCEOF) reduce 77) ((T_IS_EQUAL) reduce 77) ((T_IS_GREATER_OR_EQUAL) reduce 77) ((T_IS_IDENTICAL) reduce 77) ((T_IS_NOT_EQUAL) reduce 77) ((T_IS_NOT_IDENTICAL) reduce 77) ((T_IS_SMALLER_OR_EQUAL) reduce 77) ((T_LOGICAL_AND) reduce 77) ((T_LOGICAL_OR) reduce 77) ((T_LOGICAL_XOR) reduce 77) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 77) ((T_OBJECT_OPERATOR) reduce 77) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 77) ((T_POW) reduce 77) ((T_SL) reduce 77) ((T_SPACESHIP) reduce 77) ((T_SR) reduce 77) (("[") reduce 77) (("]") reduce 77) (("^") reduce 77) (("{") reduce 77) (("|") reduce 77)) 6883 ((("%") reduce 78) (("(") reduce 78) (("*") reduce 78) (("+") reduce 78) ((",") reduce 78) (("-") reduce 78) ((".") reduce 78) (("/") reduce 78) (("<") reduce 78) ((">") reduce 78) (("?") reduce 78) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_BOOLEAN_AND) reduce 78) ((T_BOOLEAN_OR) reduce 78) ((T_COALESCE) reduce 78) ((T_DOUBLE_ARROW) reduce 78) ((T_INSTANCEOF) reduce 78) ((T_IS_EQUAL) reduce 78) ((T_IS_GREATER_OR_EQUAL) reduce 78) ((T_IS_IDENTICAL) reduce 78) ((T_IS_NOT_EQUAL) reduce 78) ((T_IS_NOT_IDENTICAL) reduce 78) ((T_IS_SMALLER_OR_EQUAL) reduce 78) ((T_LOGICAL_AND) reduce 78) ((T_LOGICAL_OR) reduce 78) ((T_LOGICAL_XOR) reduce 78) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 78) ((T_OBJECT_OPERATOR) reduce 78) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 78) ((T_POW) reduce 78) ((T_SL) reduce 78) ((T_SPACESHIP) reduce 78) ((T_SR) reduce 78) (("[") reduce 78) (("]") reduce 78) (("^") reduce 78) (("{") reduce 78) (("|") reduce 78)) 6884 ((("%") reduce 4) (("(") reduce 4) (("*") reduce 4) (("+") reduce 4) ((",") reduce 4) (("-") reduce 4) ((".") reduce 4) (("/") reduce 4) (("<") reduce 4) ((">") reduce 4) (("?") reduce 4) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_BOOLEAN_AND) reduce 4) ((T_BOOLEAN_OR) reduce 4) ((T_COALESCE) reduce 4) ((T_DOUBLE_ARROW) reduce 4) ((T_INSTANCEOF) reduce 4) ((T_IS_EQUAL) reduce 4) ((T_IS_GREATER_OR_EQUAL) reduce 4) ((T_IS_IDENTICAL) reduce 4) ((T_IS_NOT_EQUAL) reduce 4) ((T_IS_NOT_IDENTICAL) reduce 4) ((T_IS_SMALLER_OR_EQUAL) reduce 4) ((T_LOGICAL_AND) reduce 4) ((T_LOGICAL_OR) reduce 4) ((T_LOGICAL_XOR) reduce 4) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 4) ((T_OBJECT_OPERATOR) reduce 4) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 4) ((T_POW) reduce 4) ((T_SL) reduce 4) ((T_SPACESHIP) reduce 4) ((T_SR) reduce 4) (("[") reduce 4) (("]") reduce 4) (("^") reduce 4) (("{") reduce 4) (("|") reduce 4)) 6885 ((("%") reduce 5) (("(") reduce 5) (("*") reduce 5) (("+") reduce 5) ((",") reduce 5) (("-") reduce 5) ((".") reduce 5) (("/") reduce 5) (("<") reduce 5) ((">") reduce 5) (("?") reduce 5) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_BOOLEAN_AND) reduce 5) ((T_BOOLEAN_OR) reduce 5) ((T_COALESCE) reduce 5) ((T_DOUBLE_ARROW) reduce 5) ((T_INSTANCEOF) reduce 5) ((T_IS_EQUAL) reduce 5) ((T_IS_GREATER_OR_EQUAL) reduce 5) ((T_IS_IDENTICAL) reduce 5) ((T_IS_NOT_EQUAL) reduce 5) ((T_IS_NOT_IDENTICAL) reduce 5) ((T_IS_SMALLER_OR_EQUAL) reduce 5) ((T_LOGICAL_AND) reduce 5) ((T_LOGICAL_OR) reduce 5) ((T_LOGICAL_XOR) reduce 5) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 5) ((T_OBJECT_OPERATOR) reduce 5) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 5) ((T_POW) reduce 5) ((T_SL) reduce 5) ((T_SPACESHIP) reduce 5) ((T_SR) reduce 5) (("[") reduce 5) (("]") reduce 5) (("^") reduce 5) (("{") reduce 5) (("|") reduce 5)) 6886 ((("%") reduce 43) (("(") reduce 43) (("*") reduce 43) (("+") reduce 43) ((",") reduce 43) (("-") reduce 43) ((".") reduce 43) (("/") reduce 43) (("<") reduce 43) ((">") reduce 43) (("?") reduce 43) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_BOOLEAN_AND) reduce 43) ((T_BOOLEAN_OR) reduce 43) ((T_COALESCE) reduce 43) ((T_DOUBLE_ARROW) reduce 43) ((T_INSTANCEOF) reduce 43) ((T_IS_EQUAL) reduce 43) ((T_IS_GREATER_OR_EQUAL) reduce 43) ((T_IS_IDENTICAL) reduce 43) ((T_IS_NOT_EQUAL) reduce 43) ((T_IS_NOT_IDENTICAL) reduce 43) ((T_IS_SMALLER_OR_EQUAL) reduce 43) ((T_LOGICAL_AND) reduce 43) ((T_LOGICAL_OR) reduce 43) ((T_LOGICAL_XOR) reduce 43) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 43) ((T_OBJECT_OPERATOR) reduce 43) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 43) ((T_POW) reduce 43) ((T_SL) reduce 43) ((T_SPACESHIP) reduce 43) ((T_SR) reduce 43) (("[") reduce 43) (("]") reduce 43) (("^") reduce 43) (("{") reduce 43) (("|") reduce 43)) 6887 ((("%") reduce 72) (("(") reduce 72) (("*") reduce 72) (("+") reduce 72) ((",") reduce 72) (("-") reduce 72) ((".") reduce 72) (("/") reduce 72) (("<") reduce 72) ((">") reduce 72) (("?") reduce 72) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_BOOLEAN_AND) reduce 72) ((T_BOOLEAN_OR) reduce 72) ((T_COALESCE) reduce 72) ((T_DOUBLE_ARROW) reduce 72) ((T_INSTANCEOF) reduce 72) ((T_IS_EQUAL) reduce 72) ((T_IS_GREATER_OR_EQUAL) reduce 72) ((T_IS_IDENTICAL) reduce 72) ((T_IS_NOT_EQUAL) reduce 72) ((T_IS_NOT_IDENTICAL) reduce 72) ((T_IS_SMALLER_OR_EQUAL) reduce 72) ((T_LOGICAL_AND) reduce 72) ((T_LOGICAL_OR) reduce 72) ((T_LOGICAL_XOR) reduce 72) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 72) ((T_OBJECT_OPERATOR) reduce 72) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 72) ((T_POW) reduce 72) ((T_SL) reduce 72) ((T_SPACESHIP) reduce 72) ((T_SR) reduce 72) (("[") reduce 72) (("]") reduce 72) (("^") reduce 72) (("{") reduce 72) (("|") reduce 72)) 6888 ((("%") reduce 81) (("(") reduce 81) (("*") reduce 81) (("+") reduce 81) ((",") reduce 81) (("-") reduce 81) ((".") reduce 81) (("/") reduce 81) (("<") reduce 81) ((">") reduce 81) (("?") reduce 81) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_BOOLEAN_AND) reduce 81) ((T_BOOLEAN_OR) reduce 81) ((T_COALESCE) reduce 81) ((T_DOUBLE_ARROW) reduce 81) ((T_INSTANCEOF) reduce 81) ((T_IS_EQUAL) reduce 81) ((T_IS_GREATER_OR_EQUAL) reduce 81) ((T_IS_IDENTICAL) reduce 81) ((T_IS_NOT_EQUAL) reduce 81) ((T_IS_NOT_IDENTICAL) reduce 81) ((T_IS_SMALLER_OR_EQUAL) reduce 81) ((T_LOGICAL_AND) reduce 81) ((T_LOGICAL_OR) reduce 81) ((T_LOGICAL_XOR) reduce 81) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 81) ((T_OBJECT_OPERATOR) reduce 81) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 81) ((T_POW) reduce 81) ((T_SL) reduce 81) ((T_SPACESHIP) reduce 81) ((T_SR) reduce 81) (("[") reduce 81) (("]") reduce 81) (("^") reduce 81) (("{") reduce 81) (("|") reduce 81)) 6889 ((("%") reduce 47) (("(") reduce 47) (("*") reduce 47) (("+") reduce 47) ((",") reduce 47) (("-") reduce 47) ((".") reduce 47) (("/") reduce 47) (("<") reduce 47) ((">") reduce 47) (("?") reduce 47) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_BOOLEAN_AND) reduce 47) ((T_BOOLEAN_OR) reduce 47) ((T_COALESCE) reduce 47) ((T_DOUBLE_ARROW) reduce 47) ((T_INSTANCEOF) reduce 47) ((T_IS_EQUAL) reduce 47) ((T_IS_GREATER_OR_EQUAL) reduce 47) ((T_IS_IDENTICAL) reduce 47) ((T_IS_NOT_EQUAL) reduce 47) ((T_IS_NOT_IDENTICAL) reduce 47) ((T_IS_SMALLER_OR_EQUAL) reduce 47) ((T_LOGICAL_AND) reduce 47) ((T_LOGICAL_OR) reduce 47) ((T_LOGICAL_XOR) reduce 47) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 47) ((T_OBJECT_OPERATOR) reduce 47) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 47) ((T_POW) reduce 47) ((T_SL) reduce 47) ((T_SPACESHIP) reduce 47) ((T_SR) reduce 47) (("[") reduce 47) (("]") reduce 47) (("^") reduce 47) (("{") reduce 47) (("|") reduce 47)) 6890 ((("%") reduce 31) (("(") reduce 31) (("*") reduce 31) (("+") reduce 31) ((",") reduce 31) (("-") reduce 31) ((".") reduce 31) (("/") reduce 31) (("<") reduce 31) ((">") reduce 31) (("?") reduce 31) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_BOOLEAN_AND) reduce 31) ((T_BOOLEAN_OR) reduce 31) ((T_COALESCE) reduce 31) ((T_DOUBLE_ARROW) reduce 31) ((T_INSTANCEOF) reduce 31) ((T_IS_EQUAL) reduce 31) ((T_IS_GREATER_OR_EQUAL) reduce 31) ((T_IS_IDENTICAL) reduce 31) ((T_IS_NOT_EQUAL) reduce 31) ((T_IS_NOT_IDENTICAL) reduce 31) ((T_IS_SMALLER_OR_EQUAL) reduce 31) ((T_LOGICAL_AND) reduce 31) ((T_LOGICAL_OR) reduce 31) ((T_LOGICAL_XOR) reduce 31) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 31) ((T_OBJECT_OPERATOR) reduce 31) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 31) ((T_POW) reduce 31) ((T_SL) reduce 31) ((T_SPACESHIP) reduce 31) ((T_SR) reduce 31) (("[") reduce 31) (("]") reduce 31) (("^") reduce 31) (("{") reduce 31) (("|") reduce 31)) 6891 ((("%") reduce 57) (("(") reduce 57) (("*") reduce 57) (("+") reduce 57) ((",") reduce 57) (("-") reduce 57) ((".") reduce 57) (("/") reduce 57) (("<") reduce 57) ((">") reduce 57) (("?") reduce 57) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_BOOLEAN_AND) reduce 57) ((T_BOOLEAN_OR) reduce 57) ((T_COALESCE) reduce 57) ((T_DOUBLE_ARROW) reduce 57) ((T_INSTANCEOF) reduce 57) ((T_IS_EQUAL) reduce 57) ((T_IS_GREATER_OR_EQUAL) reduce 57) ((T_IS_IDENTICAL) reduce 57) ((T_IS_NOT_EQUAL) reduce 57) ((T_IS_NOT_IDENTICAL) reduce 57) ((T_IS_SMALLER_OR_EQUAL) reduce 57) ((T_LOGICAL_AND) reduce 57) ((T_LOGICAL_OR) reduce 57) ((T_LOGICAL_XOR) reduce 57) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 57) ((T_OBJECT_OPERATOR) reduce 57) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 57) ((T_POW) reduce 57) ((T_SL) reduce 57) ((T_SPACESHIP) reduce 57) ((T_SR) reduce 57) (("[") reduce 57) (("]") reduce 57) (("^") reduce 57) (("{") reduce 57) (("|") reduce 57)) 6892 ((("%") reduce 61) (("(") reduce 61) (("*") reduce 61) (("+") reduce 61) ((",") reduce 61) (("-") reduce 61) ((".") reduce 61) (("/") reduce 61) (("<") reduce 61) ((">") reduce 61) (("?") reduce 61) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_BOOLEAN_AND) reduce 61) ((T_BOOLEAN_OR) reduce 61) ((T_COALESCE) reduce 61) ((T_DOUBLE_ARROW) reduce 61) ((T_INSTANCEOF) reduce 61) ((T_IS_EQUAL) reduce 61) ((T_IS_GREATER_OR_EQUAL) reduce 61) ((T_IS_IDENTICAL) reduce 61) ((T_IS_NOT_EQUAL) reduce 61) ((T_IS_NOT_IDENTICAL) reduce 61) ((T_IS_SMALLER_OR_EQUAL) reduce 61) ((T_LOGICAL_AND) reduce 61) ((T_LOGICAL_OR) reduce 61) ((T_LOGICAL_XOR) reduce 61) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 61) ((T_OBJECT_OPERATOR) reduce 61) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 61) ((T_POW) reduce 61) ((T_SL) reduce 61) ((T_SPACESHIP) reduce 61) ((T_SR) reduce 61) (("[") reduce 61) (("]") reduce 61) (("^") reduce 61) (("{") reduce 61) (("|") reduce 61)) 6893 ((("%") reduce 28) (("(") reduce 28) (("*") reduce 28) (("+") reduce 28) ((",") reduce 28) (("-") reduce 28) ((".") reduce 28) (("/") reduce 28) (("<") reduce 28) ((">") reduce 28) (("?") reduce 28) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_BOOLEAN_AND) reduce 28) ((T_BOOLEAN_OR) reduce 28) ((T_COALESCE) reduce 28) ((T_DOUBLE_ARROW) reduce 28) ((T_INSTANCEOF) reduce 28) ((T_IS_EQUAL) reduce 28) ((T_IS_GREATER_OR_EQUAL) reduce 28) ((T_IS_IDENTICAL) reduce 28) ((T_IS_NOT_EQUAL) reduce 28) ((T_IS_NOT_IDENTICAL) reduce 28) ((T_IS_SMALLER_OR_EQUAL) reduce 28) ((T_LOGICAL_AND) reduce 28) ((T_LOGICAL_OR) reduce 28) ((T_LOGICAL_XOR) reduce 28) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 28) ((T_OBJECT_OPERATOR) reduce 28) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 28) ((T_POW) reduce 28) ((T_SL) reduce 28) ((T_SPACESHIP) reduce 28) ((T_SR) reduce 28) (("[") reduce 28) (("]") reduce 28) (("^") reduce 28) (("{") reduce 28) (("|") reduce 28)) 6894 ((("%") reduce 36) (("(") reduce 36) (("*") reduce 36) (("+") reduce 36) ((",") reduce 36) (("-") reduce 36) ((".") reduce 36) (("/") reduce 36) (("<") reduce 36) ((">") reduce 36) (("?") reduce 36) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_BOOLEAN_AND) reduce 36) ((T_BOOLEAN_OR) reduce 36) ((T_COALESCE) reduce 36) ((T_DOUBLE_ARROW) reduce 36) ((T_INSTANCEOF) reduce 36) ((T_IS_EQUAL) reduce 36) ((T_IS_GREATER_OR_EQUAL) reduce 36) ((T_IS_IDENTICAL) reduce 36) ((T_IS_NOT_EQUAL) reduce 36) ((T_IS_NOT_IDENTICAL) reduce 36) ((T_IS_SMALLER_OR_EQUAL) reduce 36) ((T_LOGICAL_AND) reduce 36) ((T_LOGICAL_OR) reduce 36) ((T_LOGICAL_XOR) reduce 36) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 36) ((T_OBJECT_OPERATOR) reduce 36) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 36) ((T_POW) reduce 36) ((T_SL) reduce 36) ((T_SPACESHIP) reduce 36) ((T_SR) reduce 36) (("[") reduce 36) (("]") reduce 36) (("^") reduce 36) (("{") reduce 36) (("|") reduce 36)) 6895 ((("%") reduce 32) (("(") reduce 32) (("*") reduce 32) (("+") reduce 32) ((",") reduce 32) (("-") reduce 32) ((".") reduce 32) (("/") reduce 32) (("<") reduce 32) ((">") reduce 32) (("?") reduce 32) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_BOOLEAN_AND) reduce 32) ((T_BOOLEAN_OR) reduce 32) ((T_COALESCE) reduce 32) ((T_DOUBLE_ARROW) reduce 32) ((T_INSTANCEOF) reduce 32) ((T_IS_EQUAL) reduce 32) ((T_IS_GREATER_OR_EQUAL) reduce 32) ((T_IS_IDENTICAL) reduce 32) ((T_IS_NOT_EQUAL) reduce 32) ((T_IS_NOT_IDENTICAL) reduce 32) ((T_IS_SMALLER_OR_EQUAL) reduce 32) ((T_LOGICAL_AND) reduce 32) ((T_LOGICAL_OR) reduce 32) ((T_LOGICAL_XOR) reduce 32) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 32) ((T_OBJECT_OPERATOR) reduce 32) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 32) ((T_POW) reduce 32) ((T_SL) reduce 32) ((T_SPACESHIP) reduce 32) ((T_SR) reduce 32) (("[") reduce 32) (("]") reduce 32) (("^") reduce 32) (("{") reduce 32) (("|") reduce 32)) 6896 ((("%") reduce 35) (("(") reduce 35) (("*") reduce 35) (("+") reduce 35) ((",") reduce 35) (("-") reduce 35) ((".") reduce 35) (("/") reduce 35) (("<") reduce 35) ((">") reduce 35) (("?") reduce 35) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_BOOLEAN_AND) reduce 35) ((T_BOOLEAN_OR) reduce 35) ((T_COALESCE) reduce 35) ((T_DOUBLE_ARROW) reduce 35) ((T_INSTANCEOF) reduce 35) ((T_IS_EQUAL) reduce 35) ((T_IS_GREATER_OR_EQUAL) reduce 35) ((T_IS_IDENTICAL) reduce 35) ((T_IS_NOT_EQUAL) reduce 35) ((T_IS_NOT_IDENTICAL) reduce 35) ((T_IS_SMALLER_OR_EQUAL) reduce 35) ((T_LOGICAL_AND) reduce 35) ((T_LOGICAL_OR) reduce 35) ((T_LOGICAL_XOR) reduce 35) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 35) ((T_OBJECT_OPERATOR) reduce 35) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 35) ((T_POW) reduce 35) ((T_SL) reduce 35) ((T_SPACESHIP) reduce 35) ((T_SR) reduce 35) (("[") reduce 35) (("]") reduce 35) (("^") reduce 35) (("{") reduce 35) (("|") reduce 35)) 6897 ((("%") reduce 19) (("(") reduce 19) (("*") reduce 19) (("+") reduce 19) ((",") reduce 19) (("-") reduce 19) ((".") reduce 19) (("/") reduce 19) (("<") reduce 19) ((">") reduce 19) (("?") reduce 19) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_BOOLEAN_AND) reduce 19) ((T_BOOLEAN_OR) reduce 19) ((T_COALESCE) reduce 19) ((T_DOUBLE_ARROW) reduce 19) ((T_INSTANCEOF) reduce 19) ((T_IS_EQUAL) reduce 19) ((T_IS_GREATER_OR_EQUAL) reduce 19) ((T_IS_IDENTICAL) reduce 19) ((T_IS_NOT_EQUAL) reduce 19) ((T_IS_NOT_IDENTICAL) reduce 19) ((T_IS_SMALLER_OR_EQUAL) reduce 19) ((T_LOGICAL_AND) reduce 19) ((T_LOGICAL_OR) reduce 19) ((T_LOGICAL_XOR) reduce 19) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 19) ((T_OBJECT_OPERATOR) reduce 19) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 19) ((T_POW) reduce 19) ((T_SL) reduce 19) ((T_SPACESHIP) reduce 19) ((T_SR) reduce 19) (("[") reduce 19) (("]") reduce 19) (("^") reduce 19) (("{") reduce 19) (("|") reduce 19)) 6898 ((("%") reduce 45) (("(") reduce 45) (("*") reduce 45) (("+") reduce 45) ((",") reduce 45) (("-") reduce 45) ((".") reduce 45) (("/") reduce 45) (("<") reduce 45) ((">") reduce 45) (("?") reduce 45) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_BOOLEAN_AND) reduce 45) ((T_BOOLEAN_OR) reduce 45) ((T_COALESCE) reduce 45) ((T_DOUBLE_ARROW) reduce 45) ((T_INSTANCEOF) reduce 45) ((T_IS_EQUAL) reduce 45) ((T_IS_GREATER_OR_EQUAL) reduce 45) ((T_IS_IDENTICAL) reduce 45) ((T_IS_NOT_EQUAL) reduce 45) ((T_IS_NOT_IDENTICAL) reduce 45) ((T_IS_SMALLER_OR_EQUAL) reduce 45) ((T_LOGICAL_AND) reduce 45) ((T_LOGICAL_OR) reduce 45) ((T_LOGICAL_XOR) reduce 45) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 45) ((T_OBJECT_OPERATOR) reduce 45) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 45) ((T_POW) reduce 45) ((T_SL) reduce 45) ((T_SPACESHIP) reduce 45) ((T_SR) reduce 45) (("[") reduce 45) (("]") reduce 45) (("^") reduce 45) (("{") reduce 45) (("|") reduce 45)) 6899 ((("%") reduce 504) (("(") reduce 541) (("*") reduce 504) (("+") reduce 504) ((",") reduce 504) (("-") reduce 504) ((".") reduce 504) (("/") reduce 504) (("<") reduce 504) ((">") reduce 504) (("?") reduce 504) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_BOOLEAN_AND) reduce 504) ((T_BOOLEAN_OR) reduce 504) ((T_COALESCE) reduce 504) ((T_DOUBLE_ARROW) reduce 504) ((T_INSTANCEOF) reduce 504) ((T_IS_EQUAL) reduce 504) ((T_IS_GREATER_OR_EQUAL) reduce 504) ((T_IS_IDENTICAL) reduce 504) ((T_IS_NOT_EQUAL) reduce 504) ((T_IS_NOT_IDENTICAL) reduce 504) ((T_IS_SMALLER_OR_EQUAL) reduce 504) ((T_LOGICAL_AND) reduce 504) ((T_LOGICAL_OR) reduce 504) ((T_LOGICAL_XOR) reduce 504) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 504) ((T_OBJECT_OPERATOR) reduce 504) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 504) ((T_POW) reduce 504) ((T_SL) reduce 504) ((T_SPACESHIP) reduce 504) ((T_SR) reduce 504) (("[") reduce 504) (("]") reduce 504) (("^") reduce 504) (("{") reduce 504) (("|") reduce 504)) 6901 ((("%") reduce 71) (("(") reduce 71) (("*") reduce 71) (("+") reduce 71) ((",") reduce 71) (("-") reduce 71) ((".") reduce 71) (("/") reduce 71) (("<") reduce 71) ((">") reduce 71) (("?") reduce 71) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_BOOLEAN_AND) reduce 71) ((T_BOOLEAN_OR) reduce 71) ((T_COALESCE) reduce 71) ((T_DOUBLE_ARROW) reduce 71) ((T_INSTANCEOF) reduce 71) ((T_IS_EQUAL) reduce 71) ((T_IS_GREATER_OR_EQUAL) reduce 71) ((T_IS_IDENTICAL) reduce 71) ((T_IS_NOT_EQUAL) reduce 71) ((T_IS_NOT_IDENTICAL) reduce 71) ((T_IS_SMALLER_OR_EQUAL) reduce 71) ((T_LOGICAL_AND) reduce 71) ((T_LOGICAL_OR) reduce 71) ((T_LOGICAL_XOR) reduce 71) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 71) ((T_OBJECT_OPERATOR) reduce 71) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 71) ((T_POW) reduce 71) ((T_SL) reduce 71) ((T_SPACESHIP) reduce 71) ((T_SR) reduce 71) (("[") reduce 71) (("]") reduce 71) (("^") reduce 71) (("{") reduce 71) (("|") reduce 71)) 6902 ((("%") reduce 82) (("(") reduce 82) (("*") reduce 82) (("+") reduce 82) ((",") reduce 82) (("-") reduce 82) ((".") reduce 82) (("/") reduce 82) (("<") reduce 82) ((">") reduce 82) (("?") reduce 82) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_BOOLEAN_AND) reduce 82) ((T_BOOLEAN_OR) reduce 82) ((T_COALESCE) reduce 82) ((T_DOUBLE_ARROW) reduce 82) ((T_INSTANCEOF) reduce 82) ((T_IS_EQUAL) reduce 82) ((T_IS_GREATER_OR_EQUAL) reduce 82) ((T_IS_IDENTICAL) reduce 82) ((T_IS_NOT_EQUAL) reduce 82) ((T_IS_NOT_IDENTICAL) reduce 82) ((T_IS_SMALLER_OR_EQUAL) reduce 82) ((T_LOGICAL_AND) reduce 82) ((T_LOGICAL_OR) reduce 82) ((T_LOGICAL_XOR) reduce 82) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 82) ((T_OBJECT_OPERATOR) reduce 82) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 82) ((T_POW) reduce 82) ((T_SL) reduce 82) ((T_SPACESHIP) reduce 82) ((T_SR) reduce 82) (("[") reduce 82) (("]") reduce 82) (("^") reduce 82) (("{") reduce 82) (("|") reduce 82)) 6903 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) ((",") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) (("<") reduce 533) (("=") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AND_EQUAL) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_COALESCE_EQUAL) reduce 533) ((T_CONCAT_EQUAL) reduce 533) ((T_DEC) reduce 533) ((T_DIV_EQUAL) reduce 533) ((T_DOUBLE_ARROW) reduce 533) ((T_INC) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_MINUS_EQUAL) reduce 533) ((T_MOD_EQUAL) reduce 533) ((T_MUL_EQUAL) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_OR_EQUAL) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_PLUS_EQUAL) reduce 533) ((T_POW) reduce 533) ((T_POW_EQUAL) reduce 533) ((T_SL) reduce 533) ((T_SL_EQUAL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) ((T_SR_EQUAL) reduce 533) ((T_XOR_EQUAL) reduce 533) (("[") reduce 533) (("]") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 6906 ((("%") reduce 506) (("(") reduce 542) (("*") reduce 506) (("+") reduce 506) ((",") reduce 506) (("-") reduce 506) ((".") reduce 506) (("/") reduce 506) (("<") reduce 506) ((">") reduce 506) (("?") reduce 506) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_BOOLEAN_AND) reduce 506) ((T_BOOLEAN_OR) reduce 506) ((T_COALESCE) reduce 506) ((T_DOUBLE_ARROW) reduce 506) ((T_INSTANCEOF) reduce 506) ((T_IS_EQUAL) reduce 506) ((T_IS_GREATER_OR_EQUAL) reduce 506) ((T_IS_IDENTICAL) reduce 506) ((T_IS_NOT_EQUAL) reduce 506) ((T_IS_NOT_IDENTICAL) reduce 506) ((T_IS_SMALLER_OR_EQUAL) reduce 506) ((T_LOGICAL_AND) reduce 506) ((T_LOGICAL_OR) reduce 506) ((T_LOGICAL_XOR) reduce 506) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 506) ((T_OBJECT_OPERATOR) reduce 506) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 506) ((T_POW) reduce 506) ((T_SL) reduce 506) ((T_SPACESHIP) reduce 506) ((T_SR) reduce 506) (("[") reduce 506) (("]") reduce 506) (("^") reduce 506) (("{") reduce 506) (("|") reduce 506)) 6908 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) ((",") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) (("<") reduce 468) (("=") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AND_EQUAL) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_COALESCE_EQUAL) reduce 468) ((T_CONCAT_EQUAL) reduce 468) ((T_DEC) reduce 468) ((T_DIV_EQUAL) reduce 468) ((T_DOUBLE_ARROW) reduce 468) ((T_INC) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_MINUS_EQUAL) reduce 468) ((T_MOD_EQUAL) reduce 468) ((T_MUL_EQUAL) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_OR_EQUAL) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_PLUS_EQUAL) reduce 468) ((T_POW) reduce 468) ((T_POW_EQUAL) reduce 468) ((T_SL) reduce 468) ((T_SL_EQUAL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) ((T_SR_EQUAL) reduce 468) ((T_XOR_EQUAL) reduce 468) (("[") reduce 468) (("]") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 6909 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) ((",") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) (("=") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AND_EQUAL) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_COALESCE_EQUAL) reduce 288) ((T_CONCAT_EQUAL) reduce 288) ((T_DEC) reduce 288) ((T_DIV_EQUAL) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INC) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_MINUS_EQUAL) reduce 288) ((T_MOD_EQUAL) reduce 288) ((T_MUL_EQUAL) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_OR_EQUAL) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_PLUS_EQUAL) reduce 288) ((T_POW) reduce 288) ((T_POW_EQUAL) reduce 288) ((T_SL) reduce 288) ((T_SL_EQUAL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) ((T_SR_EQUAL) reduce 288) ((T_XOR_EQUAL) reduce 288) (("[") reduce 288) (("]") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 6913 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) ((",") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) (("=") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AND_EQUAL) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_COALESCE_EQUAL) reduce 289) ((T_CONCAT_EQUAL) reduce 289) ((T_DEC) reduce 289) ((T_DIV_EQUAL) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INC) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_MINUS_EQUAL) reduce 289) ((T_MOD_EQUAL) reduce 289) ((T_MUL_EQUAL) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_OR_EQUAL) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_PLUS_EQUAL) reduce 289) ((T_POW) reduce 289) ((T_POW_EQUAL) reduce 289) ((T_SL) reduce 289) ((T_SL_EQUAL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) ((T_SR_EQUAL) reduce 289) ((T_XOR_EQUAL) reduce 289) (("[") reduce 289) (("]") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 6914 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) ((",") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) (("=") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AND_EQUAL) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_COALESCE_EQUAL) reduce 290) ((T_CONCAT_EQUAL) reduce 290) ((T_DEC) reduce 290) ((T_DIV_EQUAL) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INC) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_MINUS_EQUAL) reduce 290) ((T_MOD_EQUAL) reduce 290) ((T_MUL_EQUAL) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_OR_EQUAL) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_PLUS_EQUAL) reduce 290) ((T_POW) reduce 290) ((T_POW_EQUAL) reduce 290) ((T_SL) reduce 290) ((T_SL_EQUAL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) ((T_SR_EQUAL) reduce 290) ((T_XOR_EQUAL) reduce 290) (("[") reduce 290) (("]") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 6919 ((("%") reduce 388) (("*") reduce 388) (("+") reduce 388) ((",") reduce 388) (("-") reduce 388) ((".") reduce 388) (("/") reduce 388) (("<") reduce 388) ((">") reduce 388) (("?") reduce 388) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_BOOLEAN_AND) reduce 388) ((T_BOOLEAN_OR) reduce 388) ((T_COALESCE) reduce 388) ((T_DOUBLE_ARROW) reduce 388) ((T_INSTANCEOF) reduce 388) ((T_IS_EQUAL) reduce 388) ((T_IS_GREATER_OR_EQUAL) reduce 388) ((T_IS_IDENTICAL) reduce 388) ((T_IS_NOT_EQUAL) reduce 388) ((T_IS_NOT_IDENTICAL) reduce 388) ((T_IS_SMALLER_OR_EQUAL) reduce 388) ((T_LOGICAL_AND) reduce 388) ((T_LOGICAL_OR) reduce 388) ((T_LOGICAL_XOR) reduce 388) ((T_POW) reduce 388) ((T_SL) reduce 388) ((T_SPACESHIP) reduce 388) ((T_SR) reduce 388) (("]") reduce 388) (("^") reduce 388) (("|") reduce 388)) 6921 ((("%") reduce 386) (("*") reduce 386) (("+") reduce 386) ((",") reduce 386) (("-") reduce 386) ((".") reduce 386) (("/") reduce 386) (("<") reduce 386) ((">") reduce 386) (("?") reduce 386) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_BOOLEAN_AND) reduce 386) ((T_BOOLEAN_OR) reduce 386) ((T_COALESCE) reduce 386) ((T_DOUBLE_ARROW) reduce 386) ((T_INSTANCEOF) reduce 386) ((T_IS_EQUAL) reduce 386) ((T_IS_GREATER_OR_EQUAL) reduce 386) ((T_IS_IDENTICAL) reduce 386) ((T_IS_NOT_EQUAL) reduce 386) ((T_IS_NOT_IDENTICAL) reduce 386) ((T_IS_SMALLER_OR_EQUAL) reduce 386) ((T_LOGICAL_AND) reduce 386) ((T_LOGICAL_OR) reduce 386) ((T_LOGICAL_XOR) reduce 386) ((T_POW) reduce 386) ((T_SL) reduce 386) ((T_SPACESHIP) reduce 386) ((T_SR) reduce 386) (("]") reduce 386) (("^") reduce 386) (("|") reduce 386)) 6931 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 382) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 382) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 382) ((T_LOGICAL_OR) reduce 382) ((T_LOGICAL_XOR) reduce 382) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 382) (("^") shift) (("|") shift)) 6932 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 384) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 384) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 384) ((T_LOGICAL_OR) reduce 384) ((T_LOGICAL_XOR) reduce 384) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 384) (("^") shift) (("|") shift)) 6933 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 383) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 383) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 383) ((T_LOGICAL_OR) reduce 383) ((T_LOGICAL_XOR) reduce 383) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 383) (("^") shift) (("|") shift)) 6934 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 376) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 376) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 376) ((T_LOGICAL_OR) reduce 376) ((T_LOGICAL_XOR) reduce 376) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 376) (("^") shift) (("|") shift)) 6935 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 373) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 373) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 373) ((T_LOGICAL_OR) reduce 373) ((T_LOGICAL_XOR) reduce 373) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 373) (("^") shift) (("|") shift)) 6936 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 381) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 381) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 381) ((T_LOGICAL_OR) reduce 381) ((T_LOGICAL_XOR) reduce 381) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 381) (("^") shift) (("|") shift)) 6937 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 375) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 375) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 375) ((T_LOGICAL_OR) reduce 375) ((T_LOGICAL_XOR) reduce 375) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 375) (("^") shift) (("|") shift)) 6938 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 379) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 379) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 379) ((T_LOGICAL_OR) reduce 379) ((T_LOGICAL_XOR) reduce 379) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 379) (("^") shift) (("|") shift)) 6939 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 374) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 374) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 374) ((T_LOGICAL_OR) reduce 374) ((T_LOGICAL_XOR) reduce 374) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 374) (("^") shift) (("|") shift)) 6940 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 377) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 377) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 377) ((T_LOGICAL_OR) reduce 377) ((T_LOGICAL_XOR) reduce 377) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 377) (("^") shift) (("|") shift)) 6941 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 378) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 378) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 378) ((T_LOGICAL_OR) reduce 378) ((T_LOGICAL_XOR) reduce 378) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 378) (("^") shift) (("|") shift)) 6942 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 385) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 385) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 385) ((T_LOGICAL_OR) reduce 385) ((T_LOGICAL_XOR) reduce 385) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 385) (("^") shift) (("|") shift)) 6943 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 380) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 380) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 380) ((T_LOGICAL_OR) reduce 380) ((T_LOGICAL_XOR) reduce 380) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 380) (("^") shift) (("|") shift)) 6945 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 370) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 370) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 370) ((T_LOGICAL_OR) reduce 370) ((T_LOGICAL_XOR) reduce 370) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 370) (("^") shift) (("|") shift)) 6948 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) ((",") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("]") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 6951 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) ((",") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) (("<") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_DOUBLE_ARROW) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_POW) reduce 525) ((T_SL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) (("[") reduce 525) (("]") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 6953 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) ((",") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) (("<") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_DOUBLE_ARROW) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_POW) reduce 524) ((T_SL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) (("[") reduce 524) (("]") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 6955 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) ((",") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) (("<") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_DOUBLE_ARROW) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_POW) reduce 519) ((T_SL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) (("[") reduce 519) (("]") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 6956 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) ((",") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) (("<") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_DOUBLE_ARROW) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_POW) reduce 526) ((T_SL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) (("[") reduce 526) (("]") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 6957 ((("%") reduce 371) (("*") reduce 371) (("+") reduce 371) ((",") reduce 371) (("-") reduce 371) ((".") reduce 371) (("/") reduce 371) (("<") reduce 371) ((">") reduce 371) (("?") reduce 371) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_BOOLEAN_AND) reduce 371) ((T_BOOLEAN_OR) reduce 371) ((T_COALESCE) reduce 371) ((T_DOUBLE_ARROW) reduce 371) ((T_INSTANCEOF) reduce 371) ((T_IS_EQUAL) reduce 371) ((T_IS_GREATER_OR_EQUAL) reduce 371) ((T_IS_IDENTICAL) reduce 371) ((T_IS_NOT_EQUAL) reduce 371) ((T_IS_NOT_IDENTICAL) reduce 371) ((T_IS_SMALLER_OR_EQUAL) reduce 371) ((T_LOGICAL_AND) reduce 371) ((T_LOGICAL_OR) reduce 371) ((T_LOGICAL_XOR) reduce 371) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 371) ((T_SL) reduce 371) ((T_SPACESHIP) reduce 371) ((T_SR) reduce 371) (("[") reduce 510) (("]") reduce 371) (("^") reduce 371) (("{") reduce 510) (("|") reduce 371)) 6961 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) ((",") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) (("<") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_DOUBLE_ARROW) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_POW) reduce 533) ((T_SL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) (("[") reduce 533) (("]") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 6963 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) ((",") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) (("<") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_DOUBLE_ARROW) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_POW) reduce 468) ((T_SL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) (("[") reduce 468) (("]") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 6964 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) ((",") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("[") reduce 288) (("]") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 6968 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) ((",") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("[") reduce 289) (("]") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 6969 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) ((",") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("[") reduce 290) (("]") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 6970 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) ((",") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) (("<") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_DOUBLE_ARROW) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_POW) reduce 465) ((T_SL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) (("[") reduce 465) (("]") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 6973 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) ((",") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) (("<") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_DOUBLE_ARROW) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_POW) reduce 532) ((T_SL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) (("[") reduce 532) (("]") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 6974 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) ((",") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) (("<") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_DOUBLE_ARROW) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_POW) reduce 467) ((T_SL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) (("[") reduce 467) (("]") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 6975 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) ((",") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) (("<") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_DOUBLE_ARROW) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_POW) reduce 469) ((T_SL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) (("[") reduce 469) (("]") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 6981 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) ((",") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) (("<") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_DOUBLE_ARROW) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_POW) reduce 521) ((T_SL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) (("[") reduce 521) (("]") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 6983 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) ((",") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) (("<") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_DOUBLE_ARROW) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_POW) reduce 520) ((T_SL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) (("[") reduce 520) (("]") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 6984 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) ((",") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("]") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 6985 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) ((",") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) (("<") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_DOUBLE_ARROW) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_POW) reduce 527) ((T_SL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) (("[") reduce 527) (("]") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 6986 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) ((",") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("]") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 6989 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) ((",") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("]") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 6990 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) ((",") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) (("<") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_DOUBLE_ARROW) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_POW) reduce 522) ((T_SL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) (("[") reduce 522) (("]") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 6991 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) ((",") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) (("<") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_DOUBLE_ARROW) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_POW) reduce 528) ((T_SL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) (("[") reduce 528) (("]") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 6992 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) ((",") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) (("<") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_DOUBLE_ARROW) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_POW) reduce 523) ((T_SL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) (("[") reduce 523) (("]") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 6993 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) ((",") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) (("<") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_DOUBLE_ARROW) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_POW) reduce 466) ((T_SL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) (("[") reduce 466) (("]") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 6994 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) ((",") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("]") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 6997 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) ((",") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("]") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 6999 (((",") reduce 550) (("]") reduce 550)) 7000 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) ((",") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) (("<") reduce 465) (("=") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AND_EQUAL) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_COALESCE_EQUAL) reduce 465) ((T_CONCAT_EQUAL) reduce 465) ((T_DEC) reduce 465) ((T_DIV_EQUAL) reduce 465) ((T_DOUBLE_ARROW) reduce 465) ((T_INC) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_MINUS_EQUAL) reduce 465) ((T_MOD_EQUAL) reduce 465) ((T_MUL_EQUAL) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_OR_EQUAL) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_PLUS_EQUAL) reduce 465) ((T_POW) reduce 465) ((T_POW_EQUAL) reduce 465) ((T_SL) reduce 465) ((T_SL_EQUAL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) ((T_SR_EQUAL) reduce 465) ((T_XOR_EQUAL) reduce 465) (("[") reduce 465) (("]") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 7011 ((("%") reduce 455) (("*") reduce 455) (("+") reduce 455) ((",") reduce 455) (("-") reduce 455) ((".") reduce 455) (("/") reduce 455) (("<") reduce 455) ((">") reduce 455) (("?") reduce 455) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_BOOLEAN_AND) reduce 455) ((T_BOOLEAN_OR) reduce 455) ((T_COALESCE) reduce 455) ((T_DOUBLE_ARROW) reduce 455) ((T_INSTANCEOF) reduce 455) ((T_IS_EQUAL) reduce 455) ((T_IS_GREATER_OR_EQUAL) reduce 455) ((T_IS_IDENTICAL) reduce 455) ((T_IS_NOT_EQUAL) reduce 455) ((T_IS_NOT_IDENTICAL) reduce 455) ((T_IS_SMALLER_OR_EQUAL) reduce 455) ((T_LOGICAL_AND) reduce 455) ((T_LOGICAL_OR) reduce 455) ((T_LOGICAL_XOR) reduce 455) ((T_POW) reduce 455) ((T_SL) reduce 455) ((T_SPACESHIP) reduce 455) ((T_SR) reduce 455) (("]") reduce 455) (("^") reduce 455) (("|") reduce 455)) 7012 ((("%") reduce 450) (("*") reduce 450) (("+") reduce 450) ((",") reduce 450) (("-") reduce 450) ((".") reduce 450) (("/") reduce 450) (("<") reduce 450) ((">") reduce 450) (("?") reduce 450) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_BOOLEAN_AND) reduce 450) ((T_BOOLEAN_OR) reduce 450) ((T_COALESCE) reduce 450) ((T_DOUBLE_ARROW) reduce 450) ((T_INSTANCEOF) reduce 450) ((T_IS_EQUAL) reduce 450) ((T_IS_GREATER_OR_EQUAL) reduce 450) ((T_IS_IDENTICAL) reduce 450) ((T_IS_NOT_EQUAL) reduce 450) ((T_IS_NOT_IDENTICAL) reduce 450) ((T_IS_SMALLER_OR_EQUAL) reduce 450) ((T_LOGICAL_AND) reduce 450) ((T_LOGICAL_OR) reduce 450) ((T_LOGICAL_XOR) reduce 450) ((T_POW) reduce 450) ((T_SL) reduce 450) ((T_SPACESHIP) reduce 450) ((T_SR) reduce 450) (("]") reduce 450) (("^") reduce 450) (("|") reduce 450)) 7084 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 455) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 455) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 455) (("^") shift) (("|") shift)) 7402 ((("%") reduce 451) (("*") reduce 451) (("+") reduce 451) ((",") reduce 451) (("-") reduce 451) ((".") reduce 451) (("/") reduce 451) (("<") reduce 451) ((">") reduce 451) (("?") reduce 451) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_BOOLEAN_AND) reduce 451) ((T_BOOLEAN_OR) reduce 451) ((T_COALESCE) reduce 451) ((T_DOUBLE_ARROW) reduce 451) ((T_INSTANCEOF) reduce 451) ((T_IS_EQUAL) reduce 451) ((T_IS_GREATER_OR_EQUAL) reduce 451) ((T_IS_IDENTICAL) reduce 451) ((T_IS_NOT_EQUAL) reduce 451) ((T_IS_NOT_IDENTICAL) reduce 451) ((T_IS_SMALLER_OR_EQUAL) reduce 451) ((T_LOGICAL_AND) reduce 451) ((T_LOGICAL_OR) reduce 451) ((T_LOGICAL_XOR) reduce 451) ((T_POW) reduce 451) ((T_SL) reduce 451) ((T_SPACESHIP) reduce 451) ((T_SR) reduce 451) (("]") reduce 451) (("^") reduce 451) (("|") reduce 451)) 7405 ((("%") reduce 503) (("(") reduce 541) (("*") reduce 503) (("+") reduce 503) ((",") reduce 503) (("-") reduce 503) ((".") reduce 503) (("/") reduce 503) (("<") reduce 503) ((">") reduce 503) (("?") reduce 503) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_BOOLEAN_AND) reduce 503) ((T_BOOLEAN_OR) reduce 503) ((T_COALESCE) reduce 503) ((T_DOUBLE_ARROW) reduce 503) ((T_INSTANCEOF) reduce 503) ((T_IS_EQUAL) reduce 503) ((T_IS_GREATER_OR_EQUAL) reduce 503) ((T_IS_IDENTICAL) reduce 503) ((T_IS_NOT_EQUAL) reduce 503) ((T_IS_NOT_IDENTICAL) reduce 503) ((T_IS_SMALLER_OR_EQUAL) reduce 503) ((T_LOGICAL_AND) reduce 503) ((T_LOGICAL_OR) reduce 503) ((T_LOGICAL_XOR) reduce 503) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 503) ((T_OBJECT_OPERATOR) reduce 503) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 503) ((T_POW) reduce 503) ((T_SL) reduce 503) ((T_SPACESHIP) reduce 503) ((T_SR) reduce 503) (("[") reduce 503) (("]") reduce 503) (("^") reduce 503) (("{") reduce 503) (("|") reduce 503)) 7407 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) ((",") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) (("<") reduce 532) (("=") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AND_EQUAL) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_COALESCE_EQUAL) reduce 532) ((T_CONCAT_EQUAL) reduce 532) ((T_DEC) reduce 532) ((T_DIV_EQUAL) reduce 532) ((T_DOUBLE_ARROW) reduce 532) ((T_INC) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_MINUS_EQUAL) reduce 532) ((T_MOD_EQUAL) reduce 532) ((T_MUL_EQUAL) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_OR_EQUAL) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_PLUS_EQUAL) reduce 532) ((T_POW) reduce 532) ((T_POW_EQUAL) reduce 532) ((T_SL) reduce 532) ((T_SL_EQUAL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) ((T_SR_EQUAL) reduce 532) ((T_XOR_EQUAL) reduce 532) (("[") reduce 532) (("]") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 7410 ((("%") reduce 505) (("(") reduce 542) (("*") reduce 505) (("+") reduce 505) ((",") reduce 505) (("-") reduce 505) ((".") reduce 505) (("/") reduce 505) (("<") reduce 505) ((">") reduce 505) (("?") reduce 505) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_BOOLEAN_AND) reduce 505) ((T_BOOLEAN_OR) reduce 505) ((T_COALESCE) reduce 505) ((T_DOUBLE_ARROW) reduce 505) ((T_INSTANCEOF) reduce 505) ((T_IS_EQUAL) reduce 505) ((T_IS_GREATER_OR_EQUAL) reduce 505) ((T_IS_IDENTICAL) reduce 505) ((T_IS_NOT_EQUAL) reduce 505) ((T_IS_NOT_IDENTICAL) reduce 505) ((T_IS_SMALLER_OR_EQUAL) reduce 505) ((T_LOGICAL_AND) reduce 505) ((T_LOGICAL_OR) reduce 505) ((T_LOGICAL_XOR) reduce 505) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 505) ((T_OBJECT_OPERATOR) reduce 505) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 505) ((T_POW) reduce 505) ((T_SL) reduce 505) ((T_SPACESHIP) reduce 505) ((T_SR) reduce 505) (("[") reduce 505) (("]") reduce 505) (("^") reduce 505) (("{") reduce 505) (("|") reduce 505)) 7411 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) ((",") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) (("<") reduce 467) (("=") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AND_EQUAL) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_COALESCE_EQUAL) reduce 467) ((T_CONCAT_EQUAL) reduce 467) ((T_DEC) reduce 467) ((T_DIV_EQUAL) reduce 467) ((T_DOUBLE_ARROW) reduce 467) ((T_INC) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_MINUS_EQUAL) reduce 467) ((T_MOD_EQUAL) reduce 467) ((T_MUL_EQUAL) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_OR_EQUAL) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_PLUS_EQUAL) reduce 467) ((T_POW) reduce 467) ((T_POW_EQUAL) reduce 467) ((T_SL) reduce 467) ((T_SL_EQUAL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) ((T_SR_EQUAL) reduce 467) ((T_XOR_EQUAL) reduce 467) (("[") reduce 467) (("]") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 7412 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) ((",") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) (("<") reduce 469) (("=") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AND_EQUAL) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_COALESCE_EQUAL) reduce 469) ((T_CONCAT_EQUAL) reduce 469) ((T_DEC) reduce 469) ((T_DIV_EQUAL) reduce 469) ((T_DOUBLE_ARROW) reduce 469) ((T_INC) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_MINUS_EQUAL) reduce 469) ((T_MOD_EQUAL) reduce 469) ((T_MUL_EQUAL) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_OR_EQUAL) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_PLUS_EQUAL) reduce 469) ((T_POW) reduce 469) ((T_POW_EQUAL) reduce 469) ((T_SL) reduce 469) ((T_SL_EQUAL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) ((T_SR_EQUAL) reduce 469) ((T_XOR_EQUAL) reduce 469) (("[") reduce 469) (("]") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 7414 ((("%") reduce 446) (("*") reduce 446) (("+") reduce 446) ((",") reduce 446) (("-") reduce 446) ((".") reduce 446) (("/") reduce 446) (("<") reduce 446) ((">") reduce 446) (("?") reduce 446) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_BOOLEAN_AND) reduce 446) ((T_BOOLEAN_OR) reduce 446) ((T_COALESCE) reduce 446) ((T_DOUBLE_ARROW) reduce 446) ((T_INSTANCEOF) reduce 446) ((T_IS_EQUAL) reduce 446) ((T_IS_GREATER_OR_EQUAL) reduce 446) ((T_IS_IDENTICAL) reduce 446) ((T_IS_NOT_EQUAL) reduce 446) ((T_IS_NOT_IDENTICAL) reduce 446) ((T_IS_SMALLER_OR_EQUAL) reduce 446) ((T_LOGICAL_AND) reduce 446) ((T_LOGICAL_OR) reduce 446) ((T_LOGICAL_XOR) reduce 446) ((T_POW) reduce 446) ((T_SL) reduce 446) ((T_SPACESHIP) reduce 446) ((T_SR) reduce 446) (("]") reduce 446) (("^") reduce 446) (("|") reduce 446)) 7415 ((("%") reduce 448) (("*") reduce 448) (("+") reduce 448) ((",") reduce 448) (("-") reduce 448) ((".") reduce 448) (("/") reduce 448) (("<") reduce 448) ((">") reduce 448) (("?") reduce 448) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_BOOLEAN_AND) reduce 448) ((T_BOOLEAN_OR) reduce 448) ((T_COALESCE) reduce 448) ((T_DOUBLE_ARROW) reduce 448) ((T_INSTANCEOF) reduce 448) ((T_IS_EQUAL) reduce 448) ((T_IS_GREATER_OR_EQUAL) reduce 448) ((T_IS_IDENTICAL) reduce 448) ((T_IS_NOT_EQUAL) reduce 448) ((T_IS_NOT_IDENTICAL) reduce 448) ((T_IS_SMALLER_OR_EQUAL) reduce 448) ((T_LOGICAL_AND) reduce 448) ((T_LOGICAL_OR) reduce 448) ((T_LOGICAL_XOR) reduce 448) ((T_POW) reduce 448) ((T_SL) reduce 448) ((T_SPACESHIP) reduce 448) ((T_SR) reduce 448) (("]") reduce 448) (("^") reduce 448) (("|") reduce 448)) 7421 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) ((",") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) (("<") reduce 521) (("=") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AND_EQUAL) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_COALESCE_EQUAL) reduce 521) ((T_CONCAT_EQUAL) reduce 521) ((T_DEC) reduce 521) ((T_DIV_EQUAL) reduce 521) ((T_DOUBLE_ARROW) reduce 521) ((T_INC) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_MINUS_EQUAL) reduce 521) ((T_MOD_EQUAL) reduce 521) ((T_MUL_EQUAL) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_OR_EQUAL) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_PLUS_EQUAL) reduce 521) ((T_POW) reduce 521) ((T_POW_EQUAL) reduce 521) ((T_SL) reduce 521) ((T_SL_EQUAL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) ((T_SR_EQUAL) reduce 521) ((T_XOR_EQUAL) reduce 521) (("[") reduce 521) (("]") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 7423 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) ((",") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) (("<") reduce 520) (("=") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AND_EQUAL) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_COALESCE_EQUAL) reduce 520) ((T_CONCAT_EQUAL) reduce 520) ((T_DEC) reduce 520) ((T_DIV_EQUAL) reduce 520) ((T_DOUBLE_ARROW) reduce 520) ((T_INC) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_MINUS_EQUAL) reduce 520) ((T_MOD_EQUAL) reduce 520) ((T_MUL_EQUAL) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_OR_EQUAL) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_PLUS_EQUAL) reduce 520) ((T_POW) reduce 520) ((T_POW_EQUAL) reduce 520) ((T_SL) reduce 520) ((T_SL_EQUAL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) ((T_SR_EQUAL) reduce 520) ((T_XOR_EQUAL) reduce 520) (("[") reduce 520) (("]") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 7424 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) ((",") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) (("=") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AND_EQUAL) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_COALESCE_EQUAL) reduce 544) ((T_CONCAT_EQUAL) reduce 544) ((T_DEC) reduce 544) ((T_DIV_EQUAL) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INC) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_MINUS_EQUAL) reduce 544) ((T_MOD_EQUAL) reduce 544) ((T_MUL_EQUAL) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_OR_EQUAL) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_PLUS_EQUAL) reduce 544) ((T_POW) reduce 544) ((T_POW_EQUAL) reduce 544) ((T_SL) reduce 544) ((T_SL_EQUAL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) ((T_SR_EQUAL) reduce 544) ((T_XOR_EQUAL) reduce 544) (("[") reduce 544) (("]") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 7425 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) ((",") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) (("<") reduce 527) (("=") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AND_EQUAL) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_COALESCE_EQUAL) reduce 527) ((T_CONCAT_EQUAL) reduce 527) ((T_DEC) reduce 527) ((T_DIV_EQUAL) reduce 527) ((T_DOUBLE_ARROW) reduce 527) ((T_INC) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_MINUS_EQUAL) reduce 527) ((T_MOD_EQUAL) reduce 527) ((T_MUL_EQUAL) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_OR_EQUAL) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_PLUS_EQUAL) reduce 527) ((T_POW) reduce 527) ((T_POW_EQUAL) reduce 527) ((T_SL) reduce 527) ((T_SL_EQUAL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) ((T_SR_EQUAL) reduce 527) ((T_XOR_EQUAL) reduce 527) (("[") reduce 527) (("]") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 7426 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) ((",") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) (("=") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AND_EQUAL) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_COALESCE_EQUAL) reduce 546) ((T_CONCAT_EQUAL) reduce 546) ((T_DEC) reduce 546) ((T_DIV_EQUAL) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INC) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_MINUS_EQUAL) reduce 546) ((T_MOD_EQUAL) reduce 546) ((T_MUL_EQUAL) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_OR_EQUAL) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_PLUS_EQUAL) reduce 546) ((T_POW) reduce 546) ((T_POW_EQUAL) reduce 546) ((T_SL) reduce 546) ((T_SL_EQUAL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) ((T_SR_EQUAL) reduce 546) ((T_XOR_EQUAL) reduce 546) (("[") reduce 546) (("]") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 7429 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) ((",") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) (("=") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AND_EQUAL) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_COALESCE_EQUAL) reduce 545) ((T_CONCAT_EQUAL) reduce 545) ((T_DEC) reduce 545) ((T_DIV_EQUAL) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INC) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_MINUS_EQUAL) reduce 545) ((T_MOD_EQUAL) reduce 545) ((T_MUL_EQUAL) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_OR_EQUAL) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_PLUS_EQUAL) reduce 545) ((T_POW) reduce 545) ((T_POW_EQUAL) reduce 545) ((T_SL) reduce 545) ((T_SL_EQUAL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) ((T_SR_EQUAL) reduce 545) ((T_XOR_EQUAL) reduce 545) (("[") reduce 545) (("]") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 7430 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) ((",") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) (("<") reduce 522) (("=") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AND_EQUAL) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_COALESCE_EQUAL) reduce 522) ((T_CONCAT_EQUAL) reduce 522) ((T_DEC) reduce 522) ((T_DIV_EQUAL) reduce 522) ((T_DOUBLE_ARROW) reduce 522) ((T_INC) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_MINUS_EQUAL) reduce 522) ((T_MOD_EQUAL) reduce 522) ((T_MUL_EQUAL) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_OR_EQUAL) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_PLUS_EQUAL) reduce 522) ((T_POW) reduce 522) ((T_POW_EQUAL) reduce 522) ((T_SL) reduce 522) ((T_SL_EQUAL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) ((T_SR_EQUAL) reduce 522) ((T_XOR_EQUAL) reduce 522) (("[") reduce 522) (("]") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 7431 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) ((",") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) (("<") reduce 528) (("=") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AND_EQUAL) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_COALESCE_EQUAL) reduce 528) ((T_CONCAT_EQUAL) reduce 528) ((T_DEC) reduce 528) ((T_DIV_EQUAL) reduce 528) ((T_DOUBLE_ARROW) reduce 528) ((T_INC) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_MINUS_EQUAL) reduce 528) ((T_MOD_EQUAL) reduce 528) ((T_MUL_EQUAL) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_OR_EQUAL) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_PLUS_EQUAL) reduce 528) ((T_POW) reduce 528) ((T_POW_EQUAL) reduce 528) ((T_SL) reduce 528) ((T_SL_EQUAL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) ((T_SR_EQUAL) reduce 528) ((T_XOR_EQUAL) reduce 528) (("[") reduce 528) (("]") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 7432 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) ((",") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) (("<") reduce 523) (("=") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AND_EQUAL) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_COALESCE_EQUAL) reduce 523) ((T_CONCAT_EQUAL) reduce 523) ((T_DEC) reduce 523) ((T_DIV_EQUAL) reduce 523) ((T_DOUBLE_ARROW) reduce 523) ((T_INC) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_MINUS_EQUAL) reduce 523) ((T_MOD_EQUAL) reduce 523) ((T_MUL_EQUAL) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_OR_EQUAL) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_PLUS_EQUAL) reduce 523) ((T_POW) reduce 523) ((T_POW_EQUAL) reduce 523) ((T_SL) reduce 523) ((T_SL_EQUAL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) ((T_SR_EQUAL) reduce 523) ((T_XOR_EQUAL) reduce 523) (("[") reduce 523) (("]") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 7434 ((("%") reduce 438) (("*") reduce 438) (("+") reduce 438) ((",") reduce 438) (("-") reduce 438) ((".") reduce 438) (("/") reduce 438) (("<") reduce 438) ((">") reduce 438) (("?") reduce 438) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_BOOLEAN_AND) reduce 438) ((T_BOOLEAN_OR) reduce 438) ((T_COALESCE) reduce 438) ((T_DOUBLE_ARROW) reduce 438) ((T_INSTANCEOF) reduce 438) ((T_IS_EQUAL) reduce 438) ((T_IS_GREATER_OR_EQUAL) reduce 438) ((T_IS_IDENTICAL) reduce 438) ((T_IS_NOT_EQUAL) reduce 438) ((T_IS_NOT_IDENTICAL) reduce 438) ((T_IS_SMALLER_OR_EQUAL) reduce 438) ((T_LOGICAL_AND) reduce 438) ((T_LOGICAL_OR) reduce 438) ((T_LOGICAL_XOR) reduce 438) ((T_POW) reduce 438) ((T_SL) reduce 438) ((T_SPACESHIP) reduce 438) ((T_SR) reduce 438) (("]") reduce 438) (("^") reduce 438) (("|") reduce 438)) 7436 ((("%") reduce 483) (("(") reduce 483) (("*") reduce 483) (("+") reduce 483) ((",") reduce 483) (("-") reduce 483) ((".") reduce 483) (("/") reduce 483) (("<") reduce 483) (("=") shift) ((">") reduce 483) (("?") reduce 483) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_BOOLEAN_AND) reduce 483) ((T_BOOLEAN_OR) reduce 483) ((T_COALESCE) reduce 483) ((T_DOUBLE_ARROW) reduce 483) ((T_INSTANCEOF) reduce 483) ((T_IS_EQUAL) reduce 483) ((T_IS_GREATER_OR_EQUAL) reduce 483) ((T_IS_IDENTICAL) reduce 483) ((T_IS_NOT_EQUAL) reduce 483) ((T_IS_NOT_IDENTICAL) reduce 483) ((T_IS_SMALLER_OR_EQUAL) reduce 483) ((T_LOGICAL_AND) reduce 483) ((T_LOGICAL_OR) reduce 483) ((T_LOGICAL_XOR) reduce 483) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 483) ((T_OBJECT_OPERATOR) reduce 483) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 483) ((T_POW) reduce 483) ((T_SL) reduce 483) ((T_SPACESHIP) reduce 483) ((T_SR) reduce 483) (("[") reduce 483) (("]") reduce 483) (("^") reduce 483) (("{") reduce 483) (("|") reduce 483)) 7438 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 369) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 369) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 369) ((T_LOGICAL_OR) reduce 369) ((T_LOGICAL_XOR) reduce 369) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 369) (("^") shift) (("|") shift)) 7439 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 443) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 443) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 443) ((T_LOGICAL_OR) reduce 443) ((T_LOGICAL_XOR) reduce 443) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 443) (("^") shift) (("|") shift)) 7440 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 441) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 441) ((T_LOGICAL_OR) reduce 441) ((T_LOGICAL_XOR) reduce 441) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 441) (("^") shift) (("|") shift)) 7442 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 442) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 442) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 442) ((T_LOGICAL_OR) reduce 442) ((T_LOGICAL_XOR) reduce 442) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 442) (("^") shift) (("|") shift)) 7443 ((("%") reduce 434) (("*") reduce 434) (("+") reduce 434) ((",") reduce 434) (("-") reduce 434) ((".") reduce 434) (("/") reduce 434) (("<") reduce 434) ((">") reduce 434) (("?") reduce 434) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_BOOLEAN_AND) reduce 434) ((T_BOOLEAN_OR) reduce 434) ((T_COALESCE) reduce 434) ((T_DOUBLE_ARROW) reduce 434) ((T_INSTANCEOF) reduce 434) ((T_IS_EQUAL) reduce 434) ((T_IS_GREATER_OR_EQUAL) reduce 434) ((T_IS_IDENTICAL) reduce 434) ((T_IS_NOT_EQUAL) reduce 434) ((T_IS_NOT_IDENTICAL) reduce 434) ((T_IS_SMALLER_OR_EQUAL) reduce 434) ((T_LOGICAL_AND) reduce 434) ((T_LOGICAL_OR) reduce 434) ((T_LOGICAL_XOR) reduce 434) ((T_POW) shift) ((T_SL) reduce 434) ((T_SPACESHIP) reduce 434) ((T_SR) reduce 434) (("]") reduce 434) (("^") reduce 434) (("|") reduce 434)) 7444 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 444) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 444) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 444) (("^") shift) (("|") shift)) 7445 ((("%") reduce 430) (("*") reduce 430) (("+") reduce 430) ((",") reduce 430) (("-") reduce 430) ((".") reduce 430) (("/") reduce 430) (("<") reduce 430) ((">") reduce 430) (("?") reduce 430) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_BOOLEAN_AND) reduce 430) ((T_BOOLEAN_OR) reduce 430) ((T_COALESCE) reduce 430) ((T_DOUBLE_ARROW) reduce 430) ((T_INSTANCEOF) reduce 430) ((T_IS_EQUAL) reduce 430) ((T_IS_GREATER_OR_EQUAL) reduce 430) ((T_IS_IDENTICAL) reduce 430) ((T_IS_NOT_EQUAL) reduce 430) ((T_IS_NOT_IDENTICAL) reduce 430) ((T_IS_SMALLER_OR_EQUAL) reduce 430) ((T_LOGICAL_AND) reduce 430) ((T_LOGICAL_OR) reduce 430) ((T_LOGICAL_XOR) reduce 430) ((T_POW) shift) ((T_SL) reduce 430) ((T_SPACESHIP) reduce 430) ((T_SR) reduce 430) (("]") reduce 430) (("^") reduce 430) (("|") reduce 430)) 7446 ((("%") reduce 447) (("*") reduce 447) (("+") reduce 447) ((",") reduce 447) (("-") reduce 447) ((".") reduce 447) (("/") reduce 447) (("<") reduce 447) ((">") reduce 447) (("?") reduce 447) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_BOOLEAN_AND) reduce 447) ((T_BOOLEAN_OR) reduce 447) ((T_COALESCE) reduce 447) ((T_DOUBLE_ARROW) reduce 447) ((T_INSTANCEOF) reduce 447) ((T_IS_EQUAL) reduce 447) ((T_IS_GREATER_OR_EQUAL) reduce 447) ((T_IS_IDENTICAL) reduce 447) ((T_IS_NOT_EQUAL) reduce 447) ((T_IS_NOT_IDENTICAL) reduce 447) ((T_IS_SMALLER_OR_EQUAL) reduce 447) ((T_LOGICAL_AND) reduce 447) ((T_LOGICAL_OR) reduce 447) ((T_LOGICAL_XOR) reduce 447) ((T_POW) reduce 447) ((T_SL) reduce 447) ((T_SPACESHIP) reduce 447) ((T_SR) reduce 447) (("]") reduce 447) (("^") reduce 447) (("|") reduce 447)) 7448 ((("%") reduce 489) (("*") reduce 489) (("+") reduce 489) ((",") reduce 489) (("-") reduce 489) ((".") reduce 489) (("/") reduce 489) (("<") reduce 489) ((">") reduce 489) (("?") reduce 489) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_BOOLEAN_AND) reduce 489) ((T_BOOLEAN_OR) reduce 489) ((T_COALESCE) reduce 489) ((T_DOUBLE_ARROW) reduce 489) ((T_INSTANCEOF) reduce 489) ((T_IS_EQUAL) reduce 489) ((T_IS_GREATER_OR_EQUAL) reduce 489) ((T_IS_IDENTICAL) reduce 489) ((T_IS_NOT_EQUAL) reduce 489) ((T_IS_NOT_IDENTICAL) reduce 489) ((T_IS_SMALLER_OR_EQUAL) reduce 489) ((T_LOGICAL_AND) reduce 489) ((T_LOGICAL_OR) reduce 489) ((T_LOGICAL_XOR) reduce 489) ((T_POW) reduce 489) ((T_SL) reduce 489) ((T_SPACESHIP) reduce 489) ((T_SR) reduce 489) (("]") reduce 489) (("^") reduce 489) (("|") reduce 489)) 7450 ((("%") reduce 490) (("*") reduce 490) (("+") reduce 490) ((",") reduce 490) (("-") reduce 490) ((".") reduce 490) (("/") reduce 490) (("<") reduce 490) ((">") reduce 490) (("?") reduce 490) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_BOOLEAN_AND) reduce 490) ((T_BOOLEAN_OR) reduce 490) ((T_COALESCE) reduce 490) ((T_DOUBLE_ARROW) reduce 490) ((T_INSTANCEOF) reduce 490) ((T_IS_EQUAL) reduce 490) ((T_IS_GREATER_OR_EQUAL) reduce 490) ((T_IS_IDENTICAL) reduce 490) ((T_IS_NOT_EQUAL) reduce 490) ((T_IS_NOT_IDENTICAL) reduce 490) ((T_IS_SMALLER_OR_EQUAL) reduce 490) ((T_LOGICAL_AND) reduce 490) ((T_LOGICAL_OR) reduce 490) ((T_LOGICAL_XOR) reduce 490) ((T_POW) reduce 490) ((T_SL) reduce 490) ((T_SPACESHIP) reduce 490) ((T_SR) reduce 490) (("]") reduce 490) (("^") reduce 490) (("|") reduce 490)) 7451 ((("%") reduce 488) (("*") reduce 488) (("+") reduce 488) ((",") reduce 488) (("-") reduce 488) ((".") reduce 488) (("/") reduce 488) (("<") reduce 488) ((">") reduce 488) (("?") reduce 488) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_BOOLEAN_AND) reduce 488) ((T_BOOLEAN_OR) reduce 488) ((T_COALESCE) reduce 488) ((T_DOUBLE_ARROW) reduce 488) ((T_INSTANCEOF) reduce 488) ((T_IS_EQUAL) reduce 488) ((T_IS_GREATER_OR_EQUAL) reduce 488) ((T_IS_IDENTICAL) reduce 488) ((T_IS_NOT_EQUAL) reduce 488) ((T_IS_NOT_IDENTICAL) reduce 488) ((T_IS_SMALLER_OR_EQUAL) reduce 488) ((T_LOGICAL_AND) reduce 488) ((T_LOGICAL_OR) reduce 488) ((T_LOGICAL_XOR) reduce 488) ((T_POW) reduce 488) ((T_SL) reduce 488) ((T_SPACESHIP) reduce 488) ((T_SR) reduce 488) (("]") reduce 488) (("^") reduce 488) (("|") reduce 488)) 7452 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 581) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 581) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 581) (("^") shift) (("|") shift)) 7453 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 580) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 580) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 580) (("^") shift) (("|") shift)) 7454 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) ((",") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) (("<") reduce 466) (("=") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AND_EQUAL) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_COALESCE_EQUAL) reduce 466) ((T_CONCAT_EQUAL) reduce 466) ((T_DEC) reduce 466) ((T_DIV_EQUAL) reduce 466) ((T_DOUBLE_ARROW) reduce 466) ((T_INC) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_MINUS_EQUAL) reduce 466) ((T_MOD_EQUAL) reduce 466) ((T_MUL_EQUAL) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_OR_EQUAL) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_PLUS_EQUAL) reduce 466) ((T_POW) reduce 466) ((T_POW_EQUAL) reduce 466) ((T_SL) reduce 466) ((T_SL_EQUAL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) ((T_SR_EQUAL) reduce 466) ((T_XOR_EQUAL) reduce 466) (("[") reduce 466) (("]") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 7455 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 439) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 439) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 439) ((T_LOGICAL_OR) reduce 439) ((T_LOGICAL_XOR) reduce 439) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 439) (("^") shift) (("|") shift)) 7456 ((("%") reduce 432) (("*") reduce 432) (("+") reduce 432) ((",") reduce 432) (("-") reduce 432) ((".") reduce 432) (("/") reduce 432) (("<") reduce 432) ((">") reduce 432) (("?") reduce 432) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_BOOLEAN_AND) reduce 432) ((T_BOOLEAN_OR) reduce 432) ((T_COALESCE) reduce 432) ((T_DOUBLE_ARROW) reduce 432) ((T_INSTANCEOF) reduce 432) ((T_IS_EQUAL) reduce 432) ((T_IS_GREATER_OR_EQUAL) reduce 432) ((T_IS_IDENTICAL) reduce 432) ((T_IS_NOT_EQUAL) reduce 432) ((T_IS_NOT_IDENTICAL) reduce 432) ((T_IS_SMALLER_OR_EQUAL) reduce 432) ((T_LOGICAL_AND) reduce 432) ((T_LOGICAL_OR) reduce 432) ((T_LOGICAL_XOR) reduce 432) ((T_POW) shift) ((T_SL) reduce 432) ((T_SPACESHIP) reduce 432) ((T_SR) reduce 432) (("]") reduce 432) (("^") reduce 432) (("|") reduce 432)) 7458 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) ((",") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("]") reduce 93) (("^") reduce 93) (("|") reduce 93)) 7459 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) ((",") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("]") reduce 92) (("^") reduce 92) (("|") reduce 92)) 7460 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) ((",") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("]") reduce 94) (("^") reduce 94) (("|") reduce 94)) 7461 ((("%") reduce 470) (("(") reduce 470) (("*") reduce 470) (("+") reduce 470) ((",") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_DOUBLE_ARROW) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("]") reduce 470) (("^") reduce 470) (("|") reduce 470)) 7462 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) ((",") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("]") reduce 91) (("^") reduce 91) (("|") reduce 91)) 7463 ((("%") reduce 365) (("*") reduce 365) (("+") reduce 365) ((",") reduce 365) (("-") reduce 365) ((".") reduce 365) (("/") reduce 365) (("<") reduce 365) ((">") reduce 365) (("?") reduce 365) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_BOOLEAN_AND) reduce 365) ((T_BOOLEAN_OR) reduce 365) ((T_COALESCE) reduce 365) ((T_DOUBLE_ARROW) reduce 365) ((T_INSTANCEOF) reduce 365) ((T_IS_EQUAL) reduce 365) ((T_IS_GREATER_OR_EQUAL) reduce 365) ((T_IS_IDENTICAL) reduce 365) ((T_IS_NOT_EQUAL) reduce 365) ((T_IS_NOT_IDENTICAL) reduce 365) ((T_IS_SMALLER_OR_EQUAL) reduce 365) ((T_LOGICAL_AND) reduce 365) ((T_LOGICAL_OR) reduce 365) ((T_LOGICAL_XOR) reduce 365) ((T_POW) reduce 365) ((T_SL) reduce 365) ((T_SPACESHIP) reduce 365) ((T_SR) reduce 365) (("]") reduce 365) (("^") reduce 365) (("|") reduce 365)) 7466 ((("%") reduce 472) (("(") reduce 472) (("*") reduce 472) (("+") reduce 472) ((",") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_DOUBLE_ARROW) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("]") reduce 472) (("^") reduce 472) (("|") reduce 472)) 7467 ((("%") reduce 480) (("(") shift) (("*") reduce 480) (("+") reduce 480) ((",") reduce 480) (("-") reduce 480) ((".") reduce 480) (("/") reduce 480) (("<") reduce 480) ((">") reduce 480) (("?") reduce 480) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_BOOLEAN_AND) reduce 480) ((T_BOOLEAN_OR) reduce 480) ((T_COALESCE) reduce 480) ((T_DOUBLE_ARROW) reduce 480) ((T_INSTANCEOF) reduce 480) ((T_IS_EQUAL) reduce 480) ((T_IS_GREATER_OR_EQUAL) reduce 480) ((T_IS_IDENTICAL) reduce 480) ((T_IS_NOT_EQUAL) reduce 480) ((T_IS_NOT_IDENTICAL) reduce 480) ((T_IS_SMALLER_OR_EQUAL) reduce 480) ((T_LOGICAL_AND) reduce 480) ((T_LOGICAL_OR) reduce 480) ((T_LOGICAL_XOR) reduce 480) ((T_POW) reduce 480) ((T_SL) reduce 480) ((T_SPACESHIP) reduce 480) ((T_SR) reduce 480) (("]") reduce 480) (("^") reduce 480) (("|") reduce 480)) 7468 ((("%") reduce 471) (("(") reduce 471) (("*") reduce 471) (("+") reduce 471) ((",") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_DOUBLE_ARROW) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("]") reduce 471) (("^") reduce 471) (("|") reduce 471)) 7469 ((("%") reduce 473) (("(") reduce 473) (("*") reduce 473) (("+") reduce 473) ((",") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_DOUBLE_ARROW) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("]") reduce 473) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 7470 ((("%") reduce 534) (("(") reduce 534) (("*") reduce 534) (("+") reduce 534) ((",") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_DOUBLE_ARROW) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("]") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 7477 ((("%") reduce 536) (("(") reduce 536) (("*") reduce 536) (("+") reduce 536) ((",") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_DOUBLE_ARROW) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("]") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 7479 ((("%") reduce 535) (("(") reduce 535) (("*") reduce 535) (("+") reduce 535) ((",") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_DOUBLE_ARROW) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("]") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 7480 ((("%") reduce 540) (("(") reduce 540) (("*") reduce 540) (("+") reduce 540) ((",") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_DOUBLE_ARROW) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("]") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 7481 ((("%") reduce 537) (("(") reduce 537) (("*") reduce 537) (("+") reduce 537) ((",") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_DOUBLE_ARROW) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("]") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 7482 ((("%") reduce 538) (("(") reduce 538) (("*") reduce 538) (("+") reduce 538) ((",") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_DOUBLE_ARROW) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("]") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 7484 ((("%") reduce 481) (("*") reduce 481) (("+") reduce 481) ((",") reduce 481) (("-") reduce 481) ((".") reduce 481) (("/") reduce 481) (("<") reduce 481) ((">") reduce 481) (("?") reduce 481) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_BOOLEAN_AND) reduce 481) ((T_BOOLEAN_OR) reduce 481) ((T_COALESCE) reduce 481) ((T_DOUBLE_ARROW) reduce 481) ((T_INSTANCEOF) reduce 481) ((T_IS_EQUAL) reduce 481) ((T_IS_GREATER_OR_EQUAL) reduce 481) ((T_IS_IDENTICAL) reduce 481) ((T_IS_NOT_EQUAL) reduce 481) ((T_IS_NOT_IDENTICAL) reduce 481) ((T_IS_SMALLER_OR_EQUAL) reduce 481) ((T_LOGICAL_AND) reduce 481) ((T_LOGICAL_OR) reduce 481) ((T_LOGICAL_XOR) reduce 481) ((T_POW) reduce 481) ((T_SL) reduce 481) ((T_SPACESHIP) reduce 481) ((T_SR) reduce 481) (("]") reduce 481) (("^") reduce 481) (("|") reduce 481)) 7485 ((("%") reduce 364) (("*") reduce 364) (("+") reduce 364) ((",") reduce 364) (("-") reduce 364) ((".") reduce 364) (("/") reduce 364) (("<") reduce 364) ((">") reduce 364) (("?") reduce 364) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_BOOLEAN_AND) reduce 364) ((T_BOOLEAN_OR) reduce 364) ((T_COALESCE) reduce 364) ((T_DOUBLE_ARROW) reduce 364) ((T_INSTANCEOF) reduce 364) ((T_IS_EQUAL) reduce 364) ((T_IS_GREATER_OR_EQUAL) reduce 364) ((T_IS_IDENTICAL) reduce 364) ((T_IS_NOT_EQUAL) reduce 364) ((T_IS_NOT_IDENTICAL) reduce 364) ((T_IS_SMALLER_OR_EQUAL) reduce 364) ((T_LOGICAL_AND) reduce 364) ((T_LOGICAL_OR) reduce 364) ((T_LOGICAL_XOR) reduce 364) ((T_POW) reduce 364) ((T_SL) reduce 364) ((T_SPACESHIP) reduce 364) ((T_SR) reduce 364) (("]") reduce 364) (("^") reduce 364) (("|") reduce 364)) 7486 ((("%") reduce 288) (("*") reduce 288) (("+") reduce 288) ((",") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("]") reduce 288) (("^") reduce 288) (("|") reduce 288)) 7490 ((("%") reduce 289) (("*") reduce 289) (("+") reduce 289) ((",") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("]") reduce 289) (("^") reduce 289) (("|") reduce 289)) 7491 ((("%") reduce 290) (("*") reduce 290) (("+") reduce 290) ((",") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("]") reduce 290) (("^") reduce 290) (("|") reduce 290)) 7493 ((("%") reduce 539) (("(") reduce 539) (("*") reduce 539) (("+") reduce 539) ((",") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_DOUBLE_ARROW) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("]") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 7494 ((("%") reduce 366) (("*") reduce 366) (("+") reduce 366) ((",") reduce 366) (("-") reduce 366) ((".") reduce 366) (("/") reduce 366) (("<") reduce 366) ((">") reduce 366) (("?") reduce 366) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_BOOLEAN_AND) reduce 366) ((T_BOOLEAN_OR) reduce 366) ((T_COALESCE) reduce 366) ((T_DOUBLE_ARROW) reduce 366) ((T_INSTANCEOF) reduce 366) ((T_IS_EQUAL) reduce 366) ((T_IS_GREATER_OR_EQUAL) reduce 366) ((T_IS_IDENTICAL) reduce 366) ((T_IS_NOT_EQUAL) reduce 366) ((T_IS_NOT_IDENTICAL) reduce 366) ((T_IS_SMALLER_OR_EQUAL) reduce 366) ((T_LOGICAL_AND) reduce 366) ((T_LOGICAL_OR) reduce 366) ((T_LOGICAL_XOR) reduce 366) ((T_POW) reduce 366) ((T_SL) reduce 366) ((T_SPACESHIP) reduce 366) ((T_SR) reduce 366) (("]") reduce 366) (("^") reduce 366) (("|") reduce 366)) 7502 ((("%") reduce 363) (("*") reduce 363) (("+") reduce 363) ((",") reduce 363) (("-") reduce 363) ((".") reduce 363) (("/") reduce 363) (("<") reduce 363) ((">") reduce 363) (("?") reduce 363) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_BOOLEAN_AND) reduce 363) ((T_BOOLEAN_OR) reduce 363) ((T_COALESCE) reduce 363) ((T_DOUBLE_ARROW) reduce 363) ((T_INSTANCEOF) reduce 363) ((T_IS_EQUAL) reduce 363) ((T_IS_GREATER_OR_EQUAL) reduce 363) ((T_IS_IDENTICAL) reduce 363) ((T_IS_NOT_EQUAL) reduce 363) ((T_IS_NOT_IDENTICAL) reduce 363) ((T_IS_SMALLER_OR_EQUAL) reduce 363) ((T_LOGICAL_AND) reduce 363) ((T_LOGICAL_OR) reduce 363) ((T_LOGICAL_XOR) reduce 363) ((T_POW) reduce 363) ((T_SL) reduce 363) ((T_SPACESHIP) reduce 363) ((T_SR) reduce 363) (("]") reduce 363) (("^") reduce 363) (("|") reduce 363)) 7504 ((("%") reduce 474) (("(") reduce 474) (("*") reduce 474) (("+") reduce 474) ((",") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_DOUBLE_ARROW) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("]") reduce 474) (("^") reduce 474) (("|") reduce 474)) 7510 ((("%") reduce 230) (("*") reduce 230) (("+") reduce 230) ((",") reduce 230) (("-") reduce 230) ((".") reduce 230) (("/") reduce 230) (("<") reduce 230) ((">") reduce 230) (("?") reduce 230) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_BOOLEAN_AND) reduce 230) ((T_BOOLEAN_OR) reduce 230) ((T_COALESCE) reduce 230) ((T_DOUBLE_ARROW) reduce 230) ((T_INSTANCEOF) reduce 230) ((T_IS_EQUAL) reduce 230) ((T_IS_GREATER_OR_EQUAL) reduce 230) ((T_IS_IDENTICAL) reduce 230) ((T_IS_NOT_EQUAL) reduce 230) ((T_IS_NOT_IDENTICAL) reduce 230) ((T_IS_SMALLER_OR_EQUAL) reduce 230) ((T_LOGICAL_AND) reduce 230) ((T_LOGICAL_OR) reduce 230) ((T_LOGICAL_XOR) reduce 230) ((T_POW) reduce 230) ((T_SL) reduce 230) ((T_SPACESHIP) reduce 230) ((T_SR) reduce 230) (("]") reduce 230) (("^") reduce 230) (("|") reduce 230)) 7519 ((("%") reduce 575) (("*") reduce 575) (("+") reduce 575) ((",") reduce 575) (("-") reduce 575) ((".") reduce 575) (("/") reduce 575) (("<") reduce 575) ((">") reduce 575) (("?") reduce 575) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_BOOLEAN_AND) reduce 575) ((T_BOOLEAN_OR) reduce 575) ((T_COALESCE) reduce 575) ((T_DOUBLE_ARROW) reduce 575) ((T_INSTANCEOF) reduce 575) ((T_IS_EQUAL) reduce 575) ((T_IS_GREATER_OR_EQUAL) reduce 575) ((T_IS_IDENTICAL) reduce 575) ((T_IS_NOT_EQUAL) reduce 575) ((T_IS_NOT_IDENTICAL) reduce 575) ((T_IS_SMALLER_OR_EQUAL) reduce 575) ((T_LOGICAL_AND) reduce 575) ((T_LOGICAL_OR) reduce 575) ((T_LOGICAL_XOR) reduce 575) ((T_POW) reduce 575) ((T_SL) reduce 575) ((T_SPACESHIP) reduce 575) ((T_SR) reduce 575) (("]") reduce 575) (("^") reduce 575) (("|") reduce 575)) 7520 ((("%") reduce 428) (("*") reduce 428) (("+") reduce 428) ((",") reduce 428) (("-") reduce 428) ((".") reduce 428) (("/") reduce 428) (("<") reduce 428) ((">") reduce 428) (("?") reduce 428) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_BOOLEAN_AND) reduce 428) ((T_BOOLEAN_OR) reduce 428) ((T_COALESCE) reduce 428) ((T_DOUBLE_ARROW) reduce 428) ((T_INSTANCEOF) reduce 428) ((T_IS_EQUAL) reduce 428) ((T_IS_GREATER_OR_EQUAL) reduce 428) ((T_IS_IDENTICAL) reduce 428) ((T_IS_NOT_EQUAL) reduce 428) ((T_IS_NOT_IDENTICAL) reduce 428) ((T_IS_SMALLER_OR_EQUAL) reduce 428) ((T_LOGICAL_AND) reduce 428) ((T_LOGICAL_OR) reduce 428) ((T_LOGICAL_XOR) reduce 428) ((T_POW) shift) ((T_SL) reduce 428) ((T_SPACESHIP) reduce 428) ((T_SR) reduce 428) (("]") reduce 428) (("^") reduce 428) (("|") reduce 428)) 7521 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 578) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 578) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 578) (("^") shift) (("|") shift)) 7522 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 577) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 577) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 577) (("^") shift) (("|") shift)) 7523 ((("%") reduce 387) (("*") reduce 387) (("+") reduce 387) ((",") reduce 387) (("-") reduce 387) ((".") reduce 387) (("/") reduce 387) (("<") reduce 387) ((">") reduce 387) (("?") reduce 387) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_BOOLEAN_AND) reduce 387) ((T_BOOLEAN_OR) reduce 387) ((T_COALESCE) reduce 387) ((T_DOUBLE_ARROW) reduce 387) ((T_INSTANCEOF) reduce 387) ((T_IS_EQUAL) reduce 387) ((T_IS_GREATER_OR_EQUAL) reduce 387) ((T_IS_IDENTICAL) reduce 387) ((T_IS_NOT_EQUAL) reduce 387) ((T_IS_NOT_IDENTICAL) reduce 387) ((T_IS_SMALLER_OR_EQUAL) reduce 387) ((T_LOGICAL_AND) reduce 387) ((T_LOGICAL_OR) reduce 387) ((T_LOGICAL_XOR) reduce 387) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 387) ((T_SL) reduce 387) ((T_SPACESHIP) reduce 387) ((T_SR) reduce 387) (("[") reduce 510) (("]") reduce 387) (("^") reduce 387) (("{") reduce 510) (("|") reduce 387)) 7525 ((("%") reduce 435) (("*") reduce 435) (("+") reduce 435) ((",") reduce 435) (("-") reduce 435) ((".") reduce 435) (("/") reduce 435) (("<") reduce 435) ((">") reduce 435) (("?") reduce 435) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_BOOLEAN_AND) reduce 435) ((T_BOOLEAN_OR) reduce 435) ((T_COALESCE) reduce 435) ((T_DOUBLE_ARROW) reduce 435) ((T_INSTANCEOF) reduce 435) ((T_IS_EQUAL) reduce 435) ((T_IS_GREATER_OR_EQUAL) reduce 435) ((T_IS_IDENTICAL) reduce 435) ((T_IS_NOT_EQUAL) reduce 435) ((T_IS_NOT_IDENTICAL) reduce 435) ((T_IS_SMALLER_OR_EQUAL) reduce 435) ((T_LOGICAL_AND) reduce 435) ((T_LOGICAL_OR) reduce 435) ((T_LOGICAL_XOR) reduce 435) ((T_POW) reduce 435) ((T_SL) reduce 435) ((T_SPACESHIP) reduce 435) ((T_SR) reduce 435) (("]") reduce 435) (("^") reduce 435) (("|") reduce 435)) 7527 ((("%") reduce 476) (("*") reduce 476) (("+") reduce 476) ((",") reduce 476) (("-") reduce 476) ((".") reduce 476) (("/") reduce 476) (("<") reduce 476) ((">") reduce 476) (("?") reduce 476) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_BOOLEAN_AND) reduce 476) ((T_BOOLEAN_OR) reduce 476) ((T_COALESCE) reduce 476) ((T_DOUBLE_ARROW) reduce 476) ((T_INSTANCEOF) reduce 476) ((T_IS_EQUAL) reduce 476) ((T_IS_GREATER_OR_EQUAL) reduce 476) ((T_IS_IDENTICAL) reduce 476) ((T_IS_NOT_EQUAL) reduce 476) ((T_IS_NOT_IDENTICAL) reduce 476) ((T_IS_SMALLER_OR_EQUAL) reduce 476) ((T_LOGICAL_AND) reduce 476) ((T_LOGICAL_OR) reduce 476) ((T_LOGICAL_XOR) reduce 476) ((T_POW) reduce 476) ((T_SL) reduce 476) ((T_SPACESHIP) reduce 476) ((T_SR) reduce 476) (("]") reduce 476) (("^") reduce 476) (("|") reduce 476)) 7530 ((("%") reduce 579) (("*") reduce 579) (("+") reduce 579) ((",") reduce 579) (("-") reduce 579) ((".") reduce 579) (("/") reduce 579) (("<") reduce 579) ((">") reduce 579) (("?") reduce 579) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_BOOLEAN_AND) reduce 579) ((T_BOOLEAN_OR) reduce 579) ((T_COALESCE) reduce 579) ((T_DOUBLE_ARROW) reduce 579) ((T_INSTANCEOF) reduce 579) ((T_IS_EQUAL) reduce 579) ((T_IS_GREATER_OR_EQUAL) reduce 579) ((T_IS_IDENTICAL) reduce 579) ((T_IS_NOT_EQUAL) reduce 579) ((T_IS_NOT_IDENTICAL) reduce 579) ((T_IS_SMALLER_OR_EQUAL) reduce 579) ((T_LOGICAL_AND) reduce 579) ((T_LOGICAL_OR) reduce 579) ((T_LOGICAL_XOR) reduce 579) ((T_POW) reduce 579) ((T_SL) reduce 579) ((T_SPACESHIP) reduce 579) ((T_SR) reduce 579) (("]") reduce 579) (("^") reduce 579) (("|") reduce 579)) 7533 ((("%") reduce 576) (("*") reduce 576) (("+") reduce 576) ((",") reduce 576) (("-") reduce 576) ((".") reduce 576) (("/") reduce 576) (("<") reduce 576) ((">") reduce 576) (("?") reduce 576) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_BOOLEAN_AND) reduce 576) ((T_BOOLEAN_OR) reduce 576) ((T_COALESCE) reduce 576) ((T_DOUBLE_ARROW) reduce 576) ((T_INSTANCEOF) reduce 576) ((T_IS_EQUAL) reduce 576) ((T_IS_GREATER_OR_EQUAL) reduce 576) ((T_IS_IDENTICAL) reduce 576) ((T_IS_NOT_EQUAL) reduce 576) ((T_IS_NOT_IDENTICAL) reduce 576) ((T_IS_SMALLER_OR_EQUAL) reduce 576) ((T_LOGICAL_AND) reduce 576) ((T_LOGICAL_OR) reduce 576) ((T_LOGICAL_XOR) reduce 576) ((T_POW) reduce 576) ((T_SL) reduce 576) ((T_SPACESHIP) reduce 576) ((T_SR) reduce 576) (("]") reduce 576) (("^") reduce 576) (("|") reduce 576)) 7534 ((("%") reduce 429) (("*") reduce 429) (("+") reduce 429) ((",") reduce 429) (("-") reduce 429) ((".") reduce 429) (("/") reduce 429) (("<") reduce 429) ((">") reduce 429) (("?") reduce 429) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_BOOLEAN_AND) reduce 429) ((T_BOOLEAN_OR) reduce 429) ((T_COALESCE) reduce 429) ((T_DOUBLE_ARROW) reduce 429) ((T_INSTANCEOF) reduce 429) ((T_IS_EQUAL) reduce 429) ((T_IS_GREATER_OR_EQUAL) reduce 429) ((T_IS_IDENTICAL) reduce 429) ((T_IS_NOT_EQUAL) reduce 429) ((T_IS_NOT_IDENTICAL) reduce 429) ((T_IS_SMALLER_OR_EQUAL) reduce 429) ((T_LOGICAL_AND) reduce 429) ((T_LOGICAL_OR) reduce 429) ((T_LOGICAL_XOR) reduce 429) ((T_POW) shift) ((T_SL) reduce 429) ((T_SPACESHIP) reduce 429) ((T_SR) reduce 429) (("]") reduce 429) (("^") reduce 429) (("|") reduce 429)) 7535 ((("%") reduce 389) (("*") reduce 389) (("+") reduce 389) ((",") reduce 389) (("-") reduce 389) ((".") reduce 389) (("/") reduce 389) (("<") reduce 389) ((">") reduce 389) (("?") reduce 389) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_BOOLEAN_AND) reduce 389) ((T_BOOLEAN_OR) reduce 389) ((T_COALESCE) reduce 389) ((T_DOUBLE_ARROW) reduce 389) ((T_INSTANCEOF) reduce 389) ((T_IS_EQUAL) reduce 389) ((T_IS_GREATER_OR_EQUAL) reduce 389) ((T_IS_IDENTICAL) reduce 389) ((T_IS_NOT_EQUAL) reduce 389) ((T_IS_NOT_IDENTICAL) reduce 389) ((T_IS_SMALLER_OR_EQUAL) reduce 389) ((T_LOGICAL_AND) reduce 389) ((T_LOGICAL_OR) reduce 389) ((T_LOGICAL_XOR) reduce 389) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 389) ((T_SL) reduce 389) ((T_SPACESHIP) reduce 389) ((T_SR) reduce 389) (("[") reduce 510) (("]") reduce 389) (("^") reduce 389) (("{") reduce 510) (("|") reduce 389)) 7536 ((("%") reduce 372) (("*") reduce 372) (("+") reduce 372) ((",") reduce 372) (("-") reduce 372) ((".") reduce 372) (("/") reduce 372) (("<") reduce 372) ((">") reduce 372) (("?") reduce 372) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_BOOLEAN_AND) reduce 372) ((T_BOOLEAN_OR) reduce 372) ((T_COALESCE) reduce 372) ((T_DOUBLE_ARROW) reduce 372) ((T_INSTANCEOF) reduce 372) ((T_IS_EQUAL) reduce 372) ((T_IS_GREATER_OR_EQUAL) reduce 372) ((T_IS_IDENTICAL) reduce 372) ((T_IS_NOT_EQUAL) reduce 372) ((T_IS_NOT_IDENTICAL) reduce 372) ((T_IS_SMALLER_OR_EQUAL) reduce 372) ((T_LOGICAL_AND) reduce 372) ((T_LOGICAL_OR) reduce 372) ((T_LOGICAL_XOR) reduce 372) ((T_POW) reduce 372) ((T_SL) reduce 372) ((T_SPACESHIP) reduce 372) ((T_SR) reduce 372) (("]") reduce 372) (("^") reduce 372) (("|") reduce 372)) 7537 ((("%") reduce 433) (("*") reduce 433) (("+") reduce 433) ((",") reduce 433) (("-") reduce 433) ((".") reduce 433) (("/") reduce 433) (("<") reduce 433) ((">") reduce 433) (("?") reduce 433) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_BOOLEAN_AND) reduce 433) ((T_BOOLEAN_OR) reduce 433) ((T_COALESCE) reduce 433) ((T_DOUBLE_ARROW) reduce 433) ((T_INSTANCEOF) reduce 433) ((T_IS_EQUAL) reduce 433) ((T_IS_GREATER_OR_EQUAL) reduce 433) ((T_IS_IDENTICAL) reduce 433) ((T_IS_NOT_EQUAL) reduce 433) ((T_IS_NOT_IDENTICAL) reduce 433) ((T_IS_SMALLER_OR_EQUAL) reduce 433) ((T_LOGICAL_AND) reduce 433) ((T_LOGICAL_OR) reduce 433) ((T_LOGICAL_XOR) reduce 433) ((T_POW) shift) ((T_SL) reduce 433) ((T_SPACESHIP) reduce 433) ((T_SR) reduce 433) (("]") reduce 433) (("^") reduce 433) (("|") reduce 433)) 7538 ((("%") reduce 431) (("*") reduce 431) (("+") reduce 431) ((",") reduce 431) (("-") reduce 431) ((".") reduce 431) (("/") reduce 431) (("<") reduce 431) ((">") reduce 431) (("?") reduce 431) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_BOOLEAN_AND) reduce 431) ((T_BOOLEAN_OR) reduce 431) ((T_COALESCE) reduce 431) ((T_DOUBLE_ARROW) reduce 431) ((T_INSTANCEOF) reduce 431) ((T_IS_EQUAL) reduce 431) ((T_IS_GREATER_OR_EQUAL) reduce 431) ((T_IS_IDENTICAL) reduce 431) ((T_IS_NOT_EQUAL) reduce 431) ((T_IS_NOT_IDENTICAL) reduce 431) ((T_IS_SMALLER_OR_EQUAL) reduce 431) ((T_LOGICAL_AND) reduce 431) ((T_LOGICAL_OR) reduce 431) ((T_LOGICAL_XOR) reduce 431) ((T_POW) shift) ((T_SL) reduce 431) ((T_SPACESHIP) reduce 431) ((T_SR) reduce 431) (("]") reduce 431) (("^") reduce 431) (("|") reduce 431)) 7541 ((("%") reduce 482) (("(") reduce 482) (("*") reduce 482) (("+") reduce 482) ((",") reduce 482) (("-") reduce 482) ((".") reduce 482) (("/") reduce 482) (("<") reduce 482) ((">") reduce 482) (("?") reduce 482) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_BOOLEAN_AND) reduce 482) ((T_BOOLEAN_OR) reduce 482) ((T_COALESCE) reduce 482) ((T_DOUBLE_ARROW) reduce 482) ((T_INSTANCEOF) reduce 482) ((T_IS_EQUAL) reduce 482) ((T_IS_GREATER_OR_EQUAL) reduce 482) ((T_IS_IDENTICAL) reduce 482) ((T_IS_NOT_EQUAL) reduce 482) ((T_IS_NOT_IDENTICAL) reduce 482) ((T_IS_SMALLER_OR_EQUAL) reduce 482) ((T_LOGICAL_AND) reduce 482) ((T_LOGICAL_OR) reduce 482) ((T_LOGICAL_XOR) reduce 482) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 482) ((T_OBJECT_OPERATOR) reduce 482) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 482) ((T_POW) reduce 482) ((T_SL) reduce 482) ((T_SPACESHIP) reduce 482) ((T_SR) reduce 482) (("[") reduce 482) (("]") reduce 482) (("^") reduce 482) (("{") reduce 482) (("|") reduce 482)) 7542 ((("%") reduce 436) (("*") reduce 436) (("+") reduce 436) ((",") reduce 436) (("-") reduce 436) ((".") reduce 436) (("/") reduce 436) (("<") reduce 436) ((">") reduce 436) (("?") reduce 436) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_BOOLEAN_AND) reduce 436) ((T_BOOLEAN_OR) reduce 436) ((T_COALESCE) reduce 436) ((T_DOUBLE_ARROW) reduce 436) ((T_INSTANCEOF) reduce 436) ((T_IS_EQUAL) reduce 436) ((T_IS_GREATER_OR_EQUAL) reduce 436) ((T_IS_IDENTICAL) reduce 436) ((T_IS_NOT_EQUAL) reduce 436) ((T_IS_NOT_IDENTICAL) reduce 436) ((T_IS_SMALLER_OR_EQUAL) reduce 436) ((T_LOGICAL_AND) reduce 436) ((T_LOGICAL_OR) reduce 436) ((T_LOGICAL_XOR) reduce 436) ((T_POW) shift) ((T_SL) reduce 436) ((T_SPACESHIP) reduce 436) ((T_SR) reduce 436) (("]") reduce 436) (("^") reduce 436) (("|") reduce 436)) 7543 ((("%") reduce 409) (("*") reduce 409) (("+") reduce 409) ((",") reduce 409) (("-") reduce 409) ((".") reduce 409) (("/") reduce 409) (("<") reduce 409) ((">") reduce 409) (("?") reduce 409) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_BOOLEAN_AND) reduce 409) ((T_BOOLEAN_OR) reduce 409) ((T_COALESCE) reduce 409) ((T_DOUBLE_ARROW) reduce 409) ((T_INSTANCEOF) reduce 409) ((T_IS_EQUAL) reduce 409) ((T_IS_GREATER_OR_EQUAL) reduce 409) ((T_IS_IDENTICAL) reduce 409) ((T_IS_NOT_EQUAL) reduce 409) ((T_IS_NOT_IDENTICAL) reduce 409) ((T_IS_SMALLER_OR_EQUAL) reduce 409) ((T_LOGICAL_AND) reduce 409) ((T_LOGICAL_OR) reduce 409) ((T_LOGICAL_XOR) reduce 409) ((T_POW) shift) ((T_SL) reduce 409) ((T_SPACESHIP) reduce 409) ((T_SR) reduce 409) (("]") reduce 409) (("^") reduce 409) (("|") reduce 409)) 7544 ((("%") reduce 408) (("*") reduce 408) (("+") reduce 408) ((",") reduce 408) (("-") reduce 408) ((".") reduce 408) (("/") reduce 408) (("<") reduce 408) ((">") reduce 408) (("?") reduce 408) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_BOOLEAN_AND) reduce 408) ((T_BOOLEAN_OR) reduce 408) ((T_COALESCE) reduce 408) ((T_DOUBLE_ARROW) reduce 408) ((T_INSTANCEOF) reduce 408) ((T_IS_EQUAL) reduce 408) ((T_IS_GREATER_OR_EQUAL) reduce 408) ((T_IS_IDENTICAL) reduce 408) ((T_IS_NOT_EQUAL) reduce 408) ((T_IS_NOT_IDENTICAL) reduce 408) ((T_IS_SMALLER_OR_EQUAL) reduce 408) ((T_LOGICAL_AND) reduce 408) ((T_LOGICAL_OR) reduce 408) ((T_LOGICAL_XOR) reduce 408) ((T_POW) shift) ((T_SL) reduce 408) ((T_SPACESHIP) reduce 408) ((T_SR) reduce 408) (("]") reduce 408) (("^") reduce 408) (("|") reduce 408)) 7546 ((("%") reduce 422) (("(") reduce 517) (("*") reduce 422) (("+") reduce 422) ((",") reduce 422) (("-") reduce 422) ((".") reduce 422) (("/") reduce 422) (("<") reduce 422) ((">") reduce 422) (("?") reduce 422) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_BOOLEAN_AND) reduce 422) ((T_BOOLEAN_OR) reduce 422) ((T_COALESCE) reduce 422) ((T_DOUBLE_ARROW) reduce 422) ((T_INSTANCEOF) reduce 422) ((T_IS_EQUAL) reduce 422) ((T_IS_GREATER_OR_EQUAL) reduce 422) ((T_IS_IDENTICAL) reduce 422) ((T_IS_NOT_EQUAL) reduce 422) ((T_IS_NOT_IDENTICAL) reduce 422) ((T_IS_SMALLER_OR_EQUAL) reduce 422) ((T_LOGICAL_AND) reduce 422) ((T_LOGICAL_OR) reduce 422) ((T_LOGICAL_XOR) reduce 422) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 511) ((T_OBJECT_OPERATOR) reduce 511) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 511) ((T_POW) reduce 422) ((T_SL) reduce 422) ((T_SPACESHIP) reduce 422) ((T_SR) reduce 422) (("[") reduce 511) (("]") reduce 422) (("^") reduce 422) (("{") reduce 511) (("|") reduce 422)) 7547 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) ((",") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) (("=") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AND_EQUAL) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_COALESCE_EQUAL) reduce 531) ((T_CONCAT_EQUAL) reduce 531) ((T_DEC) reduce 531) ((T_DIV_EQUAL) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INC) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_MINUS_EQUAL) reduce 531) ((T_MOD_EQUAL) reduce 531) ((T_MUL_EQUAL) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_OR_EQUAL) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_PLUS_EQUAL) reduce 531) ((T_POW) reduce 531) ((T_POW_EQUAL) reduce 531) ((T_SL) reduce 531) ((T_SL_EQUAL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) ((T_SR_EQUAL) reduce 531) ((T_XOR_EQUAL) reduce 531) (("[") reduce 531) (("]") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 7550 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) ((",") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) (("=") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AND_EQUAL) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_COALESCE_EQUAL) reduce 530) ((T_CONCAT_EQUAL) reduce 530) ((T_DEC) reduce 530) ((T_DIV_EQUAL) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INC) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_MINUS_EQUAL) reduce 530) ((T_MOD_EQUAL) reduce 530) ((T_MUL_EQUAL) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_OR_EQUAL) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_PLUS_EQUAL) reduce 530) ((T_POW) reduce 530) ((T_POW_EQUAL) reduce 530) ((T_SL) reduce 530) ((T_SL_EQUAL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) ((T_SR_EQUAL) reduce 530) ((T_XOR_EQUAL) reduce 530) (("[") reduce 530) (("]") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 7552 ((("%") reduce 485) (("(") reduce 485) (("*") reduce 485) (("+") reduce 485) ((",") reduce 485) (("-") reduce 485) ((".") reduce 485) (("/") reduce 485) (("<") reduce 485) ((">") reduce 485) (("?") reduce 485) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_BOOLEAN_AND) reduce 485) ((T_BOOLEAN_OR) reduce 485) ((T_COALESCE) reduce 485) ((T_DOUBLE_ARROW) reduce 485) ((T_INSTANCEOF) reduce 485) ((T_IS_EQUAL) reduce 485) ((T_IS_GREATER_OR_EQUAL) reduce 485) ((T_IS_IDENTICAL) reduce 485) ((T_IS_NOT_EQUAL) reduce 485) ((T_IS_NOT_IDENTICAL) reduce 485) ((T_IS_SMALLER_OR_EQUAL) reduce 485) ((T_LOGICAL_AND) reduce 485) ((T_LOGICAL_OR) reduce 485) ((T_LOGICAL_XOR) reduce 485) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 485) ((T_OBJECT_OPERATOR) reduce 485) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 485) ((T_POW) reduce 485) ((T_SL) reduce 485) ((T_SPACESHIP) reduce 485) ((T_SR) reduce 485) (("[") reduce 485) (("]") reduce 485) (("^") reduce 485) (("{") reduce 485) (("|") reduce 485)) 7553 ((("%") reduce 410) (("*") reduce 410) (("+") reduce 410) ((",") reduce 410) (("-") reduce 410) ((".") reduce 410) (("/") reduce 410) (("<") reduce 410) ((">") reduce 410) (("?") reduce 410) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_BOOLEAN_AND) reduce 410) ((T_BOOLEAN_OR) reduce 410) ((T_COALESCE) reduce 410) ((T_DOUBLE_ARROW) reduce 410) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 410) ((T_IS_GREATER_OR_EQUAL) reduce 410) ((T_IS_IDENTICAL) reduce 410) ((T_IS_NOT_EQUAL) reduce 410) ((T_IS_NOT_IDENTICAL) reduce 410) ((T_IS_SMALLER_OR_EQUAL) reduce 410) ((T_LOGICAL_AND) reduce 410) ((T_LOGICAL_OR) reduce 410) ((T_LOGICAL_XOR) reduce 410) ((T_POW) shift) ((T_SL) reduce 410) ((T_SPACESHIP) reduce 410) ((T_SR) reduce 410) (("]") reduce 410) (("^") reduce 410) (("|") reduce 410)) 7565 ((("%") reduce 502) (("*") reduce 502) (("+") reduce 502) ((",") reduce 502) (("-") reduce 502) ((".") reduce 502) (("/") reduce 502) (("<") reduce 502) ((">") reduce 502) (("?") reduce 502) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_BOOLEAN_AND) reduce 502) ((T_BOOLEAN_OR) reduce 502) ((T_COALESCE) reduce 502) ((T_INSTANCEOF) reduce 502) ((T_IS_EQUAL) reduce 502) ((T_IS_GREATER_OR_EQUAL) reduce 502) ((T_IS_IDENTICAL) reduce 502) ((T_IS_NOT_EQUAL) reduce 502) ((T_IS_NOT_IDENTICAL) reduce 502) ((T_IS_SMALLER_OR_EQUAL) reduce 502) ((T_LOGICAL_AND) reduce 502) ((T_LOGICAL_OR) reduce 502) ((T_LOGICAL_XOR) reduce 502) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 502) ((T_OBJECT_OPERATOR) reduce 502) ((T_POW) reduce 502) ((T_SL) reduce 502) ((T_SPACESHIP) reduce 502) ((T_SR) reduce 502) (("[") reduce 502) (("]") reduce 502) (("^") reduce 502) (("{") reduce 502) (("|") reduce 502)) 7567 ((("%") reduce 484) (("(") reduce 484) (("*") reduce 484) (("+") reduce 484) ((",") reduce 484) (("-") reduce 484) ((".") reduce 484) (("/") reduce 484) (("<") reduce 484) ((">") reduce 484) (("?") reduce 484) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_BOOLEAN_AND) reduce 484) ((T_BOOLEAN_OR) reduce 484) ((T_COALESCE) reduce 484) ((T_INSTANCEOF) reduce 484) ((T_IS_EQUAL) reduce 484) ((T_IS_GREATER_OR_EQUAL) reduce 484) ((T_IS_IDENTICAL) reduce 484) ((T_IS_NOT_EQUAL) reduce 484) ((T_IS_NOT_IDENTICAL) reduce 484) ((T_IS_SMALLER_OR_EQUAL) reduce 484) ((T_LOGICAL_AND) reduce 484) ((T_LOGICAL_OR) reduce 484) ((T_LOGICAL_XOR) reduce 484) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 484) ((T_OBJECT_OPERATOR) reduce 484) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 484) ((T_POW) reduce 484) ((T_SL) reduce 484) ((T_SPACESHIP) reduce 484) ((T_SR) reduce 484) (("[") reduce 484) (("]") reduce 484) (("^") reduce 484) (("{") reduce 484) (("|") reduce 484)) 7569 ((("%") reduce 497) (("*") reduce 497) (("+") reduce 497) ((",") reduce 497) (("-") reduce 497) ((".") reduce 497) (("/") reduce 497) (("<") reduce 497) ((">") reduce 497) (("?") reduce 497) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_BOOLEAN_AND) reduce 497) ((T_BOOLEAN_OR) reduce 497) ((T_COALESCE) reduce 497) ((T_INSTANCEOF) reduce 497) ((T_IS_EQUAL) reduce 497) ((T_IS_GREATER_OR_EQUAL) reduce 497) ((T_IS_IDENTICAL) reduce 497) ((T_IS_NOT_EQUAL) reduce 497) ((T_IS_NOT_IDENTICAL) reduce 497) ((T_IS_SMALLER_OR_EQUAL) reduce 497) ((T_LOGICAL_AND) reduce 497) ((T_LOGICAL_OR) reduce 497) ((T_LOGICAL_XOR) reduce 497) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 497) ((T_OBJECT_OPERATOR) reduce 497) ((T_POW) reduce 497) ((T_SL) reduce 497) ((T_SPACESHIP) reduce 497) ((T_SR) reduce 497) (("[") reduce 497) (("]") reduce 497) (("^") reduce 497) (("{") reduce 497) (("|") reduce 497)) 7570 ((("%") reduce 487) (("*") reduce 487) (("+") reduce 487) ((",") reduce 487) (("-") reduce 487) ((".") reduce 487) (("/") reduce 487) (("<") reduce 487) ((">") reduce 487) (("?") reduce 487) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_BOOLEAN_AND) reduce 487) ((T_BOOLEAN_OR) reduce 487) ((T_COALESCE) reduce 487) ((T_INSTANCEOF) reduce 487) ((T_IS_EQUAL) reduce 487) ((T_IS_GREATER_OR_EQUAL) reduce 487) ((T_IS_IDENTICAL) reduce 487) ((T_IS_NOT_EQUAL) reduce 487) ((T_IS_NOT_IDENTICAL) reduce 487) ((T_IS_SMALLER_OR_EQUAL) reduce 487) ((T_LOGICAL_AND) reduce 487) ((T_LOGICAL_OR) reduce 487) ((T_LOGICAL_XOR) reduce 487) ((T_POW) reduce 487) ((T_SL) reduce 487) ((T_SPACESHIP) reduce 487) ((T_SR) reduce 487) (("]") reduce 487) (("^") reduce 487) (("|") reduce 487)) 7574 ((("%") reduce 475) (("(") shift) (("*") reduce 475) (("+") reduce 475) ((",") reduce 475) (("-") reduce 475) ((".") reduce 475) (("/") reduce 475) (("<") reduce 475) ((">") reduce 475) (("?") reduce 475) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_BOOLEAN_AND) reduce 475) ((T_BOOLEAN_OR) reduce 475) ((T_COALESCE) reduce 475) ((T_INSTANCEOF) reduce 475) ((T_IS_EQUAL) reduce 475) ((T_IS_GREATER_OR_EQUAL) reduce 475) ((T_IS_IDENTICAL) reduce 475) ((T_IS_NOT_EQUAL) reduce 475) ((T_IS_NOT_IDENTICAL) reduce 475) ((T_IS_SMALLER_OR_EQUAL) reduce 475) ((T_LOGICAL_AND) reduce 475) ((T_LOGICAL_OR) reduce 475) ((T_LOGICAL_XOR) reduce 475) ((T_POW) reduce 475) ((T_SL) reduce 475) ((T_SPACESHIP) reduce 475) ((T_SR) reduce 475) (("]") reduce 475) (("^") reduce 475) (("|") reduce 475)) 7575 ((("%") reduce 496) (("*") reduce 496) (("+") reduce 496) ((",") reduce 496) (("-") reduce 496) ((".") reduce 496) (("/") reduce 496) (("<") reduce 496) ((">") reduce 496) (("?") reduce 496) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_BOOLEAN_AND) reduce 496) ((T_BOOLEAN_OR) reduce 496) ((T_COALESCE) reduce 496) ((T_INSTANCEOF) reduce 496) ((T_IS_EQUAL) reduce 496) ((T_IS_GREATER_OR_EQUAL) reduce 496) ((T_IS_IDENTICAL) reduce 496) ((T_IS_NOT_EQUAL) reduce 496) ((T_IS_NOT_IDENTICAL) reduce 496) ((T_IS_SMALLER_OR_EQUAL) reduce 496) ((T_LOGICAL_AND) reduce 496) ((T_LOGICAL_OR) reduce 496) ((T_LOGICAL_XOR) reduce 496) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 496) ((T_OBJECT_OPERATOR) reduce 496) ((T_POW) reduce 496) ((T_SL) reduce 496) ((T_SPACESHIP) reduce 496) ((T_SR) reduce 496) (("[") reduce 496) (("]") reduce 496) (("^") reduce 496) (("{") reduce 496) (("|") reduce 496)) 7576 ((("%") reduce 500) (("*") reduce 500) (("+") reduce 500) ((",") reduce 500) (("-") reduce 500) ((".") reduce 500) (("/") reduce 500) (("<") reduce 500) ((">") reduce 500) (("?") reduce 500) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_BOOLEAN_AND) reduce 500) ((T_BOOLEAN_OR) reduce 500) ((T_COALESCE) reduce 500) ((T_INSTANCEOF) reduce 500) ((T_IS_EQUAL) reduce 500) ((T_IS_GREATER_OR_EQUAL) reduce 500) ((T_IS_IDENTICAL) reduce 500) ((T_IS_NOT_EQUAL) reduce 500) ((T_IS_NOT_IDENTICAL) reduce 500) ((T_IS_SMALLER_OR_EQUAL) reduce 500) ((T_LOGICAL_AND) reduce 500) ((T_LOGICAL_OR) reduce 500) ((T_LOGICAL_XOR) reduce 500) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 500) ((T_OBJECT_OPERATOR) reduce 500) ((T_POW) reduce 500) ((T_SL) reduce 500) ((T_SPACESHIP) reduce 500) ((T_SR) reduce 500) (("[") reduce 500) (("]") reduce 500) (("^") reduce 500) (("{") reduce 500) (("|") reduce 500)) 7582 ((("%") reduce 495) (("*") reduce 495) (("+") reduce 495) ((",") reduce 495) (("-") reduce 495) ((".") reduce 495) (("/") reduce 495) (("<") reduce 495) ((">") reduce 495) (("?") reduce 495) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_BOOLEAN_AND) reduce 495) ((T_BOOLEAN_OR) reduce 495) ((T_COALESCE) reduce 495) ((T_INSTANCEOF) reduce 495) ((T_IS_EQUAL) reduce 495) ((T_IS_GREATER_OR_EQUAL) reduce 495) ((T_IS_IDENTICAL) reduce 495) ((T_IS_NOT_EQUAL) reduce 495) ((T_IS_NOT_IDENTICAL) reduce 495) ((T_IS_SMALLER_OR_EQUAL) reduce 495) ((T_LOGICAL_AND) reduce 495) ((T_LOGICAL_OR) reduce 495) ((T_LOGICAL_XOR) reduce 495) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 495) ((T_OBJECT_OPERATOR) reduce 495) ((T_POW) reduce 495) ((T_SL) reduce 495) ((T_SPACESHIP) reduce 495) ((T_SR) reduce 495) (("[") reduce 495) (("]") reduce 495) (("^") reduce 495) (("{") reduce 495) (("|") reduce 495)) 7584 ((("%") reduce 486) (("*") reduce 486) (("+") reduce 486) ((",") reduce 486) (("-") reduce 486) ((".") reduce 486) (("/") reduce 486) (("<") reduce 486) ((">") reduce 486) (("?") reduce 486) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_BOOLEAN_AND) reduce 486) ((T_BOOLEAN_OR) reduce 486) ((T_COALESCE) reduce 486) ((T_INSTANCEOF) reduce 486) ((T_IS_EQUAL) reduce 486) ((T_IS_GREATER_OR_EQUAL) reduce 486) ((T_IS_IDENTICAL) reduce 486) ((T_IS_NOT_EQUAL) reduce 486) ((T_IS_NOT_IDENTICAL) reduce 486) ((T_IS_SMALLER_OR_EQUAL) reduce 486) ((T_LOGICAL_AND) reduce 486) ((T_LOGICAL_OR) reduce 486) ((T_LOGICAL_XOR) reduce 486) ((T_POW) reduce 486) ((T_SL) reduce 486) ((T_SPACESHIP) reduce 486) ((T_SR) reduce 486) (("]") reduce 486) (("^") reduce 486) (("|") reduce 486)) 7586 ((("%") reduce 499) (("*") reduce 499) (("+") reduce 499) ((",") reduce 499) (("-") reduce 499) ((".") reduce 499) (("/") reduce 499) (("<") reduce 499) ((">") reduce 499) (("?") reduce 499) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_BOOLEAN_AND) reduce 499) ((T_BOOLEAN_OR) reduce 499) ((T_COALESCE) reduce 499) ((T_INSTANCEOF) reduce 499) ((T_IS_EQUAL) reduce 499) ((T_IS_GREATER_OR_EQUAL) reduce 499) ((T_IS_IDENTICAL) reduce 499) ((T_IS_NOT_EQUAL) reduce 499) ((T_IS_NOT_IDENTICAL) reduce 499) ((T_IS_SMALLER_OR_EQUAL) reduce 499) ((T_LOGICAL_AND) reduce 499) ((T_LOGICAL_OR) reduce 499) ((T_LOGICAL_XOR) reduce 499) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 499) ((T_OBJECT_OPERATOR) reduce 499) ((T_POW) reduce 499) ((T_SL) reduce 499) ((T_SPACESHIP) reduce 499) ((T_SR) reduce 499) (("[") reduce 499) (("]") reduce 499) (("^") reduce 499) (("{") reduce 499) (("|") reduce 499)) 7587 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) ((",") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 93) ((T_OBJECT_OPERATOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("[") reduce 93) (("]") reduce 93) (("^") reduce 93) (("{") reduce 93) (("|") reduce 93)) 7588 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) ((",") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 92) ((T_OBJECT_OPERATOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("[") reduce 92) (("]") reduce 92) (("^") reduce 92) (("{") reduce 92) (("|") reduce 92)) 7589 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) ((",") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 94) ((T_OBJECT_OPERATOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("[") reduce 94) (("]") reduce 94) (("^") reduce 94) (("{") reduce 94) (("|") reduce 94)) 7591 ((("%") reduce 501) (("*") reduce 501) (("+") reduce 501) ((",") reduce 501) (("-") reduce 501) ((".") reduce 501) (("/") reduce 501) (("<") reduce 501) ((">") reduce 501) (("?") reduce 501) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_BOOLEAN_AND) reduce 501) ((T_BOOLEAN_OR) reduce 501) ((T_COALESCE) reduce 501) ((T_INSTANCEOF) reduce 501) ((T_IS_EQUAL) reduce 501) ((T_IS_GREATER_OR_EQUAL) reduce 501) ((T_IS_IDENTICAL) reduce 501) ((T_IS_NOT_EQUAL) reduce 501) ((T_IS_NOT_IDENTICAL) reduce 501) ((T_IS_SMALLER_OR_EQUAL) reduce 501) ((T_LOGICAL_AND) reduce 501) ((T_LOGICAL_OR) reduce 501) ((T_LOGICAL_XOR) reduce 501) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 501) ((T_OBJECT_OPERATOR) reduce 501) ((T_POW) reduce 501) ((T_SL) reduce 501) ((T_SPACESHIP) reduce 501) ((T_SR) reduce 501) (("[") reduce 501) (("]") reduce 501) (("^") reduce 501) (("{") reduce 501) (("|") reduce 501)) 7599 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) ((",") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 91) ((T_OBJECT_OPERATOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("[") reduce 91) (("]") reduce 91) (("^") reduce 91) (("{") reduce 91) (("|") reduce 91)) 7602 ((("%") reduce 498) (("*") reduce 498) (("+") reduce 498) ((",") reduce 498) (("-") reduce 498) ((".") reduce 498) (("/") reduce 498) (("<") reduce 498) ((">") reduce 498) (("?") reduce 498) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_BOOLEAN_AND) reduce 498) ((T_BOOLEAN_OR) reduce 498) ((T_COALESCE) reduce 498) ((T_INSTANCEOF) reduce 498) ((T_IS_EQUAL) reduce 498) ((T_IS_GREATER_OR_EQUAL) reduce 498) ((T_IS_IDENTICAL) reduce 498) ((T_IS_NOT_EQUAL) reduce 498) ((T_IS_NOT_IDENTICAL) reduce 498) ((T_IS_SMALLER_OR_EQUAL) reduce 498) ((T_LOGICAL_AND) reduce 498) ((T_LOGICAL_OR) reduce 498) ((T_LOGICAL_XOR) reduce 498) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 498) ((T_OBJECT_OPERATOR) reduce 498) ((T_POW) reduce 498) ((T_SL) reduce 498) ((T_SPACESHIP) reduce 498) ((T_SR) reduce 498) (("[") reduce 498) (("]") reduce 498) (("^") reduce 498) (("{") reduce 498) (("|") reduce 498)) 7604 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) ((",") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) (("=") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AND_EQUAL) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_COALESCE_EQUAL) reduce 529) ((T_CONCAT_EQUAL) reduce 529) ((T_DEC) reduce 529) ((T_DIV_EQUAL) reduce 529) ((T_INC) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_MINUS_EQUAL) reduce 529) ((T_MOD_EQUAL) reduce 529) ((T_MUL_EQUAL) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_OR_EQUAL) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_PLUS_EQUAL) reduce 529) ((T_POW) reduce 529) ((T_POW_EQUAL) reduce 529) ((T_SL) reduce 529) ((T_SL_EQUAL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) ((T_SR_EQUAL) reduce 529) ((T_XOR_EQUAL) reduce 529) (("[") reduce 529) (("]") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 7605 ((("!") shift) (("\"") shift) (("$") shift) (("%") reduce 440) (("(") shift) (("*") reduce 440) (("+") shift) ((",") reduce 440) (("-") shift) ((".") reduce 440) (("/") reduce 440) (("<") reduce 440) ((">") reduce 440) (("?") reduce 440) (("@") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOLEAN_AND) reduce 440) ((T_BOOLEAN_OR) reduce 440) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_COALESCE) reduce 440) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INSTANCEOF) reduce 440) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_IS_EQUAL) reduce 440) ((T_IS_GREATER_OR_EQUAL) reduce 440) ((T_IS_IDENTICAL) reduce 440) ((T_IS_NOT_EQUAL) reduce 440) ((T_IS_NOT_IDENTICAL) reduce 440) ((T_IS_SMALLER_OR_EQUAL) reduce 440) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_LOGICAL_AND) reduce 440) ((T_LOGICAL_OR) reduce 440) ((T_LOGICAL_XOR) reduce 440) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_POW) reduce 440) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_SL) reduce 440) ((T_SPACESHIP) reduce 440) ((T_SR) reduce 440) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("]") reduce 440) (("^") reduce 440) (("`") shift) (("|") reduce 440) (("~") shift)) 7613 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) ((",") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) (("<") reduce 525) (("=") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AND_EQUAL) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_COALESCE_EQUAL) reduce 525) ((T_CONCAT_EQUAL) reduce 525) ((T_DEC) reduce 525) ((T_DIV_EQUAL) reduce 525) ((T_INC) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_MINUS_EQUAL) reduce 525) ((T_MOD_EQUAL) reduce 525) ((T_MUL_EQUAL) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_OR_EQUAL) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_PLUS_EQUAL) reduce 525) ((T_POW) reduce 525) ((T_POW_EQUAL) reduce 525) ((T_SL) reduce 525) ((T_SL_EQUAL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) ((T_SR_EQUAL) reduce 525) ((T_XOR_EQUAL) reduce 525) (("[") reduce 525) (("]") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 7614 ((("%") reduce 493) (("*") reduce 493) (("+") reduce 493) ((",") reduce 493) (("-") reduce 493) ((".") reduce 493) (("/") reduce 493) (("<") reduce 493) ((">") reduce 493) (("?") reduce 493) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_BOOLEAN_AND) reduce 493) ((T_BOOLEAN_OR) reduce 493) ((T_COALESCE) reduce 493) ((T_INSTANCEOF) reduce 493) ((T_IS_EQUAL) reduce 493) ((T_IS_GREATER_OR_EQUAL) reduce 493) ((T_IS_IDENTICAL) reduce 493) ((T_IS_NOT_EQUAL) reduce 493) ((T_IS_NOT_IDENTICAL) reduce 493) ((T_IS_SMALLER_OR_EQUAL) reduce 493) ((T_LOGICAL_AND) reduce 493) ((T_LOGICAL_OR) reduce 493) ((T_LOGICAL_XOR) reduce 493) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 513) ((T_OBJECT_OPERATOR) reduce 513) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 513) ((T_POW) reduce 493) ((T_SL) reduce 493) ((T_SPACESHIP) reduce 493) ((T_SR) reduce 493) (("[") reduce 513) (("]") reduce 493) (("^") reduce 493) (("{") reduce 513) (("|") reduce 493)) 7616 ((("%") reduce 492) (("*") reduce 492) (("+") reduce 492) ((",") reduce 492) (("-") reduce 492) ((".") reduce 492) (("/") reduce 492) (("<") reduce 492) ((">") reduce 492) (("?") reduce 492) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_BOOLEAN_AND) reduce 492) ((T_BOOLEAN_OR) reduce 492) ((T_COALESCE) reduce 492) ((T_INSTANCEOF) reduce 492) ((T_IS_EQUAL) reduce 492) ((T_IS_GREATER_OR_EQUAL) reduce 492) ((T_IS_IDENTICAL) reduce 492) ((T_IS_NOT_EQUAL) reduce 492) ((T_IS_NOT_IDENTICAL) reduce 492) ((T_IS_SMALLER_OR_EQUAL) reduce 492) ((T_LOGICAL_AND) reduce 492) ((T_LOGICAL_OR) reduce 492) ((T_LOGICAL_XOR) reduce 492) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 515) ((T_OBJECT_OPERATOR) reduce 515) ((T_POW) reduce 492) ((T_SL) reduce 492) ((T_SPACESHIP) reduce 492) ((T_SR) reduce 492) (("[") reduce 515) (("]") reduce 492) (("^") reduce 492) (("{") reduce 515) (("|") reduce 492)) 7617 ((("%") reduce 491) (("(") reduce 518) (("*") reduce 491) (("+") reduce 491) ((",") reduce 491) (("-") reduce 491) ((".") reduce 491) (("/") reduce 491) (("<") reduce 491) ((">") reduce 491) (("?") reduce 491) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_BOOLEAN_AND) reduce 491) ((T_BOOLEAN_OR) reduce 491) ((T_COALESCE) reduce 491) ((T_INSTANCEOF) reduce 491) ((T_IS_EQUAL) reduce 491) ((T_IS_GREATER_OR_EQUAL) reduce 491) ((T_IS_IDENTICAL) reduce 491) ((T_IS_NOT_EQUAL) reduce 491) ((T_IS_NOT_IDENTICAL) reduce 491) ((T_IS_SMALLER_OR_EQUAL) reduce 491) ((T_LOGICAL_AND) reduce 491) ((T_LOGICAL_OR) reduce 491) ((T_LOGICAL_XOR) reduce 491) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 512) ((T_OBJECT_OPERATOR) reduce 512) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 512) ((T_POW) reduce 491) ((T_SL) reduce 491) ((T_SPACESHIP) reduce 491) ((T_SR) reduce 491) (("[") reduce 512) (("]") reduce 491) (("^") reduce 491) (("{") reduce 512) (("|") reduce 491)) 7618 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 552) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 552) (("^") shift) (("|") shift)) 7621 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) ((",") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) (("<") reduce 524) (("=") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AND_EQUAL) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_COALESCE_EQUAL) reduce 524) ((T_CONCAT_EQUAL) reduce 524) ((T_DEC) reduce 524) ((T_DIV_EQUAL) reduce 524) ((T_INC) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_MINUS_EQUAL) reduce 524) ((T_MOD_EQUAL) reduce 524) ((T_MUL_EQUAL) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_OR_EQUAL) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_PLUS_EQUAL) reduce 524) ((T_POW) reduce 524) ((T_POW_EQUAL) reduce 524) ((T_SL) reduce 524) ((T_SL_EQUAL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) ((T_SR_EQUAL) reduce 524) ((T_XOR_EQUAL) reduce 524) (("[") reduce 524) (("]") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 7622 ((("%") reduce 445) (("*") reduce 445) (("+") reduce 445) ((",") reduce 445) (("-") reduce 445) ((".") reduce 445) (("/") reduce 445) (("<") reduce 445) ((">") reduce 445) (("?") reduce 445) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_BOOLEAN_AND) reduce 445) ((T_BOOLEAN_OR) reduce 445) ((T_COALESCE) reduce 445) ((T_INSTANCEOF) reduce 445) ((T_IS_EQUAL) reduce 445) ((T_IS_GREATER_OR_EQUAL) reduce 445) ((T_IS_IDENTICAL) reduce 445) ((T_IS_NOT_EQUAL) reduce 445) ((T_IS_NOT_IDENTICAL) reduce 445) ((T_IS_SMALLER_OR_EQUAL) reduce 445) ((T_LOGICAL_AND) reduce 445) ((T_LOGICAL_OR) reduce 445) ((T_LOGICAL_XOR) reduce 445) ((T_POW) reduce 445) ((T_SL) reduce 445) ((T_SPACESHIP) reduce 445) ((T_SR) reduce 445) (("]") reduce 445) (("^") reduce 445) (("|") reduce 445)) 7623 ((("%") reduce 427) (("*") reduce 427) (("+") reduce 427) ((",") reduce 427) (("-") reduce 427) ((".") reduce 427) (("/") reduce 427) (("<") reduce 427) ((">") reduce 427) (("?") reduce 427) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_BOOLEAN_AND) reduce 427) ((T_BOOLEAN_OR) reduce 427) ((T_COALESCE) reduce 427) ((T_INSTANCEOF) reduce 427) ((T_IS_EQUAL) reduce 427) ((T_IS_GREATER_OR_EQUAL) reduce 427) ((T_IS_IDENTICAL) reduce 427) ((T_IS_NOT_EQUAL) reduce 427) ((T_IS_NOT_IDENTICAL) reduce 427) ((T_IS_SMALLER_OR_EQUAL) reduce 427) ((T_LOGICAL_AND) reduce 427) ((T_LOGICAL_OR) reduce 427) ((T_LOGICAL_XOR) reduce 427) ((T_POW) reduce 427) ((T_SL) reduce 427) ((T_SPACESHIP) reduce 427) ((T_SR) reduce 427) (("]") reduce 427) (("^") reduce 427) (("|") reduce 427)) 7624 ((("%") reduce 449) (("*") reduce 449) (("+") reduce 449) ((",") reduce 449) (("-") reduce 449) ((".") reduce 449) (("/") reduce 449) (("<") reduce 449) ((">") reduce 449) (("?") reduce 449) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_BOOLEAN_AND) reduce 449) ((T_BOOLEAN_OR) reduce 449) ((T_COALESCE) reduce 449) ((T_INSTANCEOF) reduce 449) ((T_IS_EQUAL) reduce 449) ((T_IS_GREATER_OR_EQUAL) reduce 449) ((T_IS_IDENTICAL) reduce 449) ((T_IS_NOT_EQUAL) reduce 449) ((T_IS_NOT_IDENTICAL) reduce 449) ((T_IS_SMALLER_OR_EQUAL) reduce 449) ((T_LOGICAL_AND) reduce 449) ((T_LOGICAL_OR) reduce 449) ((T_LOGICAL_XOR) reduce 449) ((T_POW) reduce 449) ((T_SL) reduce 449) ((T_SPACESHIP) reduce 449) ((T_SR) reduce 449) (("]") reduce 449) (("^") reduce 449) (("|") reduce 449)) 7625 ((("%") reduce 494) (("(") shift) (("*") reduce 494) (("+") reduce 494) ((",") reduce 494) (("-") reduce 494) ((".") reduce 494) (("/") reduce 494) (("<") reduce 494) ((">") reduce 494) (("?") reduce 494) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_BOOLEAN_AND) reduce 494) ((T_BOOLEAN_OR) reduce 494) ((T_COALESCE) reduce 494) ((T_INSTANCEOF) reduce 494) ((T_IS_EQUAL) reduce 494) ((T_IS_GREATER_OR_EQUAL) reduce 494) ((T_IS_IDENTICAL) reduce 494) ((T_IS_NOT_EQUAL) reduce 494) ((T_IS_NOT_IDENTICAL) reduce 494) ((T_IS_SMALLER_OR_EQUAL) reduce 494) ((T_LOGICAL_AND) reduce 494) ((T_LOGICAL_OR) reduce 494) ((T_LOGICAL_XOR) reduce 494) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 494) ((T_OBJECT_OPERATOR) reduce 494) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 494) ((T_SL) reduce 494) ((T_SPACESHIP) reduce 494) ((T_SR) reduce 494) (("[") reduce 494) (("]") reduce 494) (("^") reduce 494) (("{") reduce 494) (("|") reduce 494)) 7626 ((("%") reduce 423) (("*") reduce 423) (("+") reduce 423) ((",") reduce 423) (("-") reduce 423) ((".") reduce 423) (("/") reduce 423) (("<") reduce 423) ((">") reduce 423) (("?") reduce 423) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_BOOLEAN_AND) reduce 423) ((T_BOOLEAN_OR) reduce 423) ((T_COALESCE) reduce 423) ((T_INSTANCEOF) reduce 423) ((T_IS_EQUAL) reduce 423) ((T_IS_GREATER_OR_EQUAL) reduce 423) ((T_IS_IDENTICAL) reduce 423) ((T_IS_NOT_EQUAL) reduce 423) ((T_IS_NOT_IDENTICAL) reduce 423) ((T_IS_SMALLER_OR_EQUAL) reduce 423) ((T_LOGICAL_AND) reduce 423) ((T_LOGICAL_OR) reduce 423) ((T_LOGICAL_XOR) reduce 423) ((T_POW) reduce 423) ((T_SL) reduce 423) ((T_SPACESHIP) reduce 423) ((T_SR) reduce 423) (("]") reduce 423) (("^") reduce 423) (("|") reduce 423)) 7627 ((("%") reduce 437) (("*") reduce 437) (("+") reduce 437) ((",") reduce 437) (("-") reduce 437) ((".") reduce 437) (("/") reduce 437) (("<") reduce 437) ((">") reduce 437) (("?") reduce 437) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_BOOLEAN_AND) reduce 437) ((T_BOOLEAN_OR) reduce 437) ((T_COALESCE) reduce 437) ((T_INSTANCEOF) reduce 437) ((T_IS_EQUAL) reduce 437) ((T_IS_GREATER_OR_EQUAL) reduce 437) ((T_IS_IDENTICAL) reduce 437) ((T_IS_NOT_EQUAL) reduce 437) ((T_IS_NOT_IDENTICAL) reduce 437) ((T_IS_SMALLER_OR_EQUAL) reduce 437) ((T_LOGICAL_AND) reduce 437) ((T_LOGICAL_OR) reduce 437) ((T_LOGICAL_XOR) reduce 437) ((T_POW) reduce 437) ((T_SL) reduce 437) ((T_SPACESHIP) reduce 437) ((T_SR) reduce 437) (("]") reduce 437) (("^") reduce 437) (("|") reduce 437)) 7628 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) ((",") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) (("<") reduce 519) (("=") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AND_EQUAL) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_COALESCE_EQUAL) reduce 519) ((T_CONCAT_EQUAL) reduce 519) ((T_DEC) reduce 519) ((T_DIV_EQUAL) reduce 519) ((T_INC) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_MINUS_EQUAL) reduce 519) ((T_MOD_EQUAL) reduce 519) ((T_MUL_EQUAL) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_OR_EQUAL) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_PLUS_EQUAL) reduce 519) ((T_POW) reduce 519) ((T_POW_EQUAL) reduce 519) ((T_SL) reduce 519) ((T_SL_EQUAL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) ((T_SR_EQUAL) reduce 519) ((T_XOR_EQUAL) reduce 519) (("[") reduce 519) (("]") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 7629 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) ((",") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) (("<") reduce 526) (("=") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AND_EQUAL) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_COALESCE_EQUAL) reduce 526) ((T_CONCAT_EQUAL) reduce 526) ((T_DEC) reduce 526) ((T_DIV_EQUAL) reduce 526) ((T_INC) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_MINUS_EQUAL) reduce 526) ((T_MOD_EQUAL) reduce 526) ((T_MUL_EQUAL) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_OR_EQUAL) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_PLUS_EQUAL) reduce 526) ((T_POW) reduce 526) ((T_POW_EQUAL) reduce 526) ((T_SL) reduce 526) ((T_SL_EQUAL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) ((T_SR_EQUAL) reduce 526) ((T_XOR_EQUAL) reduce 526) (("[") reduce 526) (("]") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 7630 ((("%") reduce 367) (("*") reduce 367) (("+") reduce 367) ((",") reduce 367) (("-") reduce 367) ((".") reduce 367) (("/") reduce 367) (("<") reduce 367) (("=") shift) ((">") reduce 367) (("?") reduce 367) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AND_EQUAL) shift) ((T_BOOLEAN_AND) reduce 367) ((T_BOOLEAN_OR) reduce 367) ((T_COALESCE) reduce 367) ((T_COALESCE_EQUAL) shift) ((T_CONCAT_EQUAL) shift) ((T_DEC) shift) ((T_DIV_EQUAL) shift) ((T_INC) shift) ((T_INSTANCEOF) reduce 367) ((T_IS_EQUAL) reduce 367) ((T_IS_GREATER_OR_EQUAL) reduce 367) ((T_IS_IDENTICAL) reduce 367) ((T_IS_NOT_EQUAL) reduce 367) ((T_IS_NOT_IDENTICAL) reduce 367) ((T_IS_SMALLER_OR_EQUAL) reduce 367) ((T_LOGICAL_AND) reduce 367) ((T_LOGICAL_OR) reduce 367) ((T_LOGICAL_XOR) reduce 367) ((T_MINUS_EQUAL) shift) ((T_MOD_EQUAL) shift) ((T_MUL_EQUAL) shift) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_OR_EQUAL) shift) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_PLUS_EQUAL) shift) ((T_POW) reduce 367) ((T_POW_EQUAL) shift) ((T_SL) reduce 367) ((T_SL_EQUAL) shift) ((T_SPACESHIP) reduce 367) ((T_SR) reduce 367) ((T_SR_EQUAL) shift) ((T_XOR_EQUAL) shift) (("[") reduce 510) (("]") reduce 367) (("^") reduce 367) (("{") reduce 510) (("|") reduce 367)) 7634 ((("%") reduce 411) (("*") reduce 411) (("+") reduce 411) ((",") reduce 411) (("-") reduce 411) ((".") reduce 411) (("/") reduce 411) (("<") reduce 411) ((">") reduce 411) (("?") reduce 411) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_BOOLEAN_AND) reduce 411) ((T_BOOLEAN_OR) reduce 411) ((T_COALESCE) reduce 411) ((T_INSTANCEOF) reduce 411) ((T_IS_EQUAL) reduce 411) ((T_IS_GREATER_OR_EQUAL) reduce 411) ((T_IS_IDENTICAL) reduce 411) ((T_IS_NOT_EQUAL) reduce 411) ((T_IS_NOT_IDENTICAL) reduce 411) ((T_IS_SMALLER_OR_EQUAL) reduce 411) ((T_LOGICAL_AND) reduce 411) ((T_LOGICAL_OR) reduce 411) ((T_LOGICAL_XOR) reduce 411) ((T_POW) shift) ((T_SL) reduce 411) ((T_SPACESHIP) reduce 411) ((T_SR) reduce 411) (("]") reduce 411) (("^") reduce 411) (("|") reduce 411)) 7665 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 395) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 395) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 395) ((T_BOOLEAN_OR) reduce 395) ((T_COALESCE) reduce 395) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 395) ((T_LOGICAL_OR) reduce 395) ((T_LOGICAL_XOR) reduce 395) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 395) (("^") shift) (("|") reduce 395)) 7666 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 398) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 398) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 398) ((T_BOOLEAN_OR) reduce 398) ((T_COALESCE) reduce 398) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 398) ((T_LOGICAL_OR) reduce 398) ((T_LOGICAL_XOR) reduce 398) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 398) (("^") reduce 398) (("|") reduce 398)) 7667 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 407) (("-") shift) ((".") reduce 407) (("/") shift) (("<") reduce 407) ((">") reduce 407) (("?") reduce 407) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_BOOLEAN_AND) reduce 407) ((T_BOOLEAN_OR) reduce 407) ((T_COALESCE) reduce 407) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 407) ((T_IS_GREATER_OR_EQUAL) reduce 407) ((T_IS_IDENTICAL) reduce 407) ((T_IS_NOT_EQUAL) reduce 407) ((T_IS_NOT_IDENTICAL) reduce 407) ((T_IS_SMALLER_OR_EQUAL) reduce 407) ((T_LOGICAL_AND) reduce 407) ((T_LOGICAL_OR) reduce 407) ((T_LOGICAL_XOR) reduce 407) ((T_POW) shift) ((T_SL) reduce 407) ((T_SPACESHIP) reduce 407) ((T_SR) reduce 407) (("]") reduce 407) (("^") reduce 407) (("|") reduce 407)) 7668 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 420) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 420) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_BOOLEAN_AND) reduce 420) ((T_BOOLEAN_OR) reduce 420) ((T_COALESCE) reduce 420) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 420) ((T_LOGICAL_OR) reduce 420) ((T_LOGICAL_XOR) reduce 420) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 420) (("^") reduce 420) (("|") reduce 420)) 7669 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 406) (("-") shift) ((".") reduce 406) (("/") shift) (("<") reduce 406) ((">") reduce 406) (("?") reduce 406) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_BOOLEAN_AND) reduce 406) ((T_BOOLEAN_OR) reduce 406) ((T_COALESCE) reduce 406) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 406) ((T_IS_GREATER_OR_EQUAL) reduce 406) ((T_IS_IDENTICAL) reduce 406) ((T_IS_NOT_EQUAL) reduce 406) ((T_IS_NOT_IDENTICAL) reduce 406) ((T_IS_SMALLER_OR_EQUAL) reduce 406) ((T_LOGICAL_AND) reduce 406) ((T_LOGICAL_OR) reduce 406) ((T_LOGICAL_XOR) reduce 406) ((T_POW) shift) ((T_SL) reduce 406) ((T_SPACESHIP) reduce 406) ((T_SR) reduce 406) (("]") reduce 406) (("^") reduce 406) (("|") reduce 406)) 7670 ((("%") reduce 403) (("*") reduce 403) (("+") reduce 403) ((",") reduce 403) (("-") reduce 403) ((".") reduce 403) (("/") reduce 403) (("<") reduce 403) ((">") reduce 403) (("?") reduce 403) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_BOOLEAN_AND) reduce 403) ((T_BOOLEAN_OR) reduce 403) ((T_COALESCE) reduce 403) ((T_INSTANCEOF) reduce 403) ((T_IS_EQUAL) reduce 403) ((T_IS_GREATER_OR_EQUAL) reduce 403) ((T_IS_IDENTICAL) reduce 403) ((T_IS_NOT_EQUAL) reduce 403) ((T_IS_NOT_IDENTICAL) reduce 403) ((T_IS_SMALLER_OR_EQUAL) reduce 403) ((T_LOGICAL_AND) reduce 403) ((T_LOGICAL_OR) reduce 403) ((T_LOGICAL_XOR) reduce 403) ((T_POW) shift) ((T_SL) reduce 403) ((T_SPACESHIP) reduce 403) ((T_SR) reduce 403) (("]") reduce 403) (("^") reduce 403) (("|") reduce 403)) 7671 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 394) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 394) ((T_LOGICAL_XOR) reduce 394) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 394) (("^") shift) (("|") shift)) 7672 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 392) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 392) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 392) (("^") shift) (("|") shift)) 7673 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 393) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 393) ((T_LOGICAL_OR) reduce 393) ((T_LOGICAL_XOR) reduce 393) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 393) (("^") shift) (("|") shift)) 7674 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 417) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 417) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_BOOLEAN_AND) reduce 417) ((T_BOOLEAN_OR) reduce 417) ((T_COALESCE) reduce 417) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 417) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 417) ((T_IS_NOT_EQUAL) reduce 417) ((T_IS_NOT_IDENTICAL) reduce 417) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 417) ((T_LOGICAL_OR) reduce 417) ((T_LOGICAL_XOR) reduce 417) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 417) ((T_SR) shift) (("]") reduce 417) (("^") reduce 417) (("|") reduce 417)) 7675 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 413) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 413) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_BOOLEAN_AND) reduce 413) ((T_BOOLEAN_OR) reduce 413) ((T_COALESCE) reduce 413) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 413) ((T_LOGICAL_OR) reduce 413) ((T_LOGICAL_XOR) reduce 413) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 413) (("^") reduce 413) (("|") reduce 413)) 7676 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 415) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 415) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_BOOLEAN_AND) reduce 415) ((T_BOOLEAN_OR) reduce 415) ((T_COALESCE) reduce 415) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 415) ((T_LOGICAL_OR) reduce 415) ((T_LOGICAL_XOR) reduce 415) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 415) (("^") reduce 415) (("|") reduce 415)) 7677 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 412) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 412) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_BOOLEAN_AND) reduce 412) ((T_BOOLEAN_OR) reduce 412) ((T_COALESCE) reduce 412) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 412) ((T_LOGICAL_OR) reduce 412) ((T_LOGICAL_XOR) reduce 412) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 412) (("^") reduce 412) (("|") reduce 412)) 7678 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 419) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 419) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_BOOLEAN_AND) reduce 419) ((T_BOOLEAN_OR) reduce 419) ((T_COALESCE) reduce 419) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 419) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 419) ((T_IS_NOT_EQUAL) reduce 419) ((T_IS_NOT_IDENTICAL) reduce 419) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 419) ((T_LOGICAL_OR) reduce 419) ((T_LOGICAL_XOR) reduce 419) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 419) ((T_SR) shift) (("]") reduce 419) (("^") reduce 419) (("|") reduce 419)) 7679 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 414) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 414) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_BOOLEAN_AND) reduce 414) ((T_BOOLEAN_OR) reduce 414) ((T_COALESCE) reduce 414) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 414) ((T_LOGICAL_OR) reduce 414) ((T_LOGICAL_XOR) reduce 414) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 414) (("^") reduce 414) (("|") reduce 414)) 7682 ((("%") reduce 93) (("*") reduce 93) (("+") reduce 93) ((",") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("]") reduce 93) (("^") reduce 93) (("|") reduce 93)) 7683 ((("%") reduce 92) (("*") reduce 92) (("+") reduce 92) ((",") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("]") reduce 92) (("^") reduce 92) (("|") reduce 92)) 7684 ((("%") reduce 94) (("*") reduce 94) (("+") reduce 94) ((",") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("]") reduce 94) (("^") reduce 94) (("|") reduce 94)) 7685 ((("%") reduce 470) (("*") reduce 470) (("+") reduce 470) ((",") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("]") reduce 470) (("^") reduce 470) (("|") reduce 470)) 7686 ((("%") reduce 91) (("*") reduce 91) (("+") reduce 91) ((",") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("]") reduce 91) (("^") reduce 91) (("|") reduce 91)) 7687 ((("%") reduce 529) (("*") reduce 529) (("+") reduce 529) ((",") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("]") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 7688 ((("%") reduce 472) (("*") reduce 472) (("+") reduce 472) ((",") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("]") reduce 472) (("^") reduce 472) (("|") reduce 472)) 7689 ((("%") reduce 421) (("*") reduce 421) (("+") reduce 421) ((",") reduce 421) (("-") reduce 421) ((".") reduce 421) (("/") reduce 421) (("<") reduce 421) ((">") reduce 421) (("?") reduce 421) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_BOOLEAN_AND) reduce 421) ((T_BOOLEAN_OR) reduce 421) ((T_COALESCE) reduce 421) ((T_INSTANCEOF) reduce 421) ((T_IS_EQUAL) reduce 421) ((T_IS_GREATER_OR_EQUAL) reduce 421) ((T_IS_IDENTICAL) reduce 421) ((T_IS_NOT_EQUAL) reduce 421) ((T_IS_NOT_IDENTICAL) reduce 421) ((T_IS_SMALLER_OR_EQUAL) reduce 421) ((T_LOGICAL_AND) reduce 421) ((T_LOGICAL_OR) reduce 421) ((T_LOGICAL_XOR) reduce 421) ((T_POW) reduce 421) ((T_SL) reduce 421) ((T_SPACESHIP) reduce 421) ((T_SR) reduce 421) (("]") reduce 421) (("^") reduce 421) (("|") reduce 421)) 7690 ((("%") reduce 471) (("*") reduce 471) (("+") reduce 471) ((",") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("]") reduce 471) (("^") reduce 471) (("|") reduce 471)) 7691 ((("%") reduce 473) (("*") reduce 473) (("+") reduce 473) ((",") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("]") reduce 473) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 7692 ((("%") reduce 534) (("*") reduce 534) (("+") reduce 534) ((",") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("]") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 7699 ((("%") reduce 536) (("*") reduce 536) (("+") reduce 536) ((",") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("]") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 7701 ((("%") reduce 535) (("*") reduce 535) (("+") reduce 535) ((",") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("]") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 7702 ((("%") reduce 540) (("*") reduce 540) (("+") reduce 540) ((",") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("]") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 7703 ((("%") reduce 544) (("*") reduce 544) (("+") reduce 544) ((",") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("]") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 7704 ((("%") reduce 537) (("*") reduce 537) (("+") reduce 537) ((",") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("]") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 7705 ((("%") reduce 546) (("*") reduce 546) (("+") reduce 546) ((",") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("]") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 7708 ((("%") reduce 545) (("*") reduce 545) (("+") reduce 545) ((",") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("]") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 7709 ((("%") reduce 538) (("*") reduce 538) (("+") reduce 538) ((",") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("]") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 7711 ((("%") reduce 539) (("*") reduce 539) (("+") reduce 539) ((",") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("]") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 7713 ((("%") reduce 474) (("*") reduce 474) (("+") reduce 474) ((",") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("]") reduce 474) (("^") reduce 474) (("|") reduce 474)) 7714 ((("%") reduce 531) (("*") reduce 531) (("+") reduce 531) ((",") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("]") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 7717 ((("%") reduce 530) (("*") reduce 530) (("+") reduce 530) ((",") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("]") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 7718 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 426) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 426) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 426) ((T_LOGICAL_OR) reduce 426) ((T_LOGICAL_XOR) reduce 426) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 426) (("^") shift) (("|") shift)) 7719 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 390) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 390) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) reduce 390) ((T_COALESCE) reduce 390) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 390) ((T_LOGICAL_OR) reduce 390) ((T_LOGICAL_XOR) reduce 390) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 390) (("^") shift) (("|") shift)) 7720 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 391) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 391) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 391) ((T_BOOLEAN_OR) reduce 391) ((T_COALESCE) reduce 391) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 391) ((T_LOGICAL_OR) reduce 391) ((T_LOGICAL_XOR) reduce 391) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 391) (("^") shift) (("|") shift)) 7721 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 396) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 396) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_BOOLEAN_AND) reduce 396) ((T_BOOLEAN_OR) reduce 396) ((T_COALESCE) reduce 396) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 396) ((T_LOGICAL_OR) reduce 396) ((T_LOGICAL_XOR) reduce 396) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 396) (("^") reduce 396) (("|") reduce 396)) 7722 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 397) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 397) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_BOOLEAN_AND) reduce 397) ((T_BOOLEAN_OR) reduce 397) ((T_COALESCE) reduce 397) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 397) ((T_LOGICAL_OR) reduce 397) ((T_LOGICAL_XOR) reduce 397) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 397) (("^") reduce 397) (("|") reduce 397)) 7726 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 424) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 424) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 424) ((T_LOGICAL_OR) reduce 424) ((T_LOGICAL_XOR) reduce 424) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 424) (("^") shift) (("|") shift)) 7727 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 425) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 425) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 425) ((T_LOGICAL_OR) reduce 425) ((T_LOGICAL_XOR) reduce 425) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 425) (("^") shift) (("|") shift)) 7728 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 418) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 418) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_BOOLEAN_AND) reduce 418) ((T_BOOLEAN_OR) reduce 418) ((T_COALESCE) reduce 418) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 418) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 418) ((T_IS_NOT_EQUAL) reduce 418) ((T_IS_NOT_IDENTICAL) reduce 418) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 418) ((T_LOGICAL_OR) reduce 418) ((T_LOGICAL_XOR) reduce 418) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 418) ((T_SR) shift) (("]") reduce 418) (("^") reduce 418) (("|") reduce 418)) 7729 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 416) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 416) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_BOOLEAN_AND) reduce 416) ((T_BOOLEAN_OR) reduce 416) ((T_COALESCE) reduce 416) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 416) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 416) ((T_IS_NOT_EQUAL) reduce 416) ((T_IS_NOT_IDENTICAL) reduce 416) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 416) ((T_LOGICAL_OR) reduce 416) ((T_LOGICAL_XOR) reduce 416) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 416) ((T_SR) shift) (("]") reduce 416) (("^") reduce 416) (("|") reduce 416)) 7730 ((("%") reduce 404) (("*") reduce 404) (("+") reduce 404) ((",") reduce 404) (("-") reduce 404) ((".") reduce 404) (("/") reduce 404) (("<") reduce 404) ((">") reduce 404) (("?") reduce 404) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_BOOLEAN_AND) reduce 404) ((T_BOOLEAN_OR) reduce 404) ((T_COALESCE) reduce 404) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 404) ((T_IS_GREATER_OR_EQUAL) reduce 404) ((T_IS_IDENTICAL) reduce 404) ((T_IS_NOT_EQUAL) reduce 404) ((T_IS_NOT_IDENTICAL) reduce 404) ((T_IS_SMALLER_OR_EQUAL) reduce 404) ((T_LOGICAL_AND) reduce 404) ((T_LOGICAL_OR) reduce 404) ((T_LOGICAL_XOR) reduce 404) ((T_POW) shift) ((T_SL) reduce 404) ((T_SPACESHIP) reduce 404) ((T_SR) reduce 404) (("]") reduce 404) (("^") reduce 404) (("|") reduce 404)) 7731 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 399) (("-") shift) ((".") reduce 399) (("/") shift) (("<") reduce 399) ((">") reduce 399) (("?") reduce 399) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_BOOLEAN_AND) reduce 399) ((T_BOOLEAN_OR) reduce 399) ((T_COALESCE) reduce 399) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 399) ((T_IS_GREATER_OR_EQUAL) reduce 399) ((T_IS_IDENTICAL) reduce 399) ((T_IS_NOT_EQUAL) reduce 399) ((T_IS_NOT_IDENTICAL) reduce 399) ((T_IS_SMALLER_OR_EQUAL) reduce 399) ((T_LOGICAL_AND) reduce 399) ((T_LOGICAL_OR) reduce 399) ((T_LOGICAL_XOR) reduce 399) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 399) ((T_SR) shift) (("]") reduce 399) (("^") reduce 399) (("|") reduce 399)) 7732 ((("%") shift) (("*") shift) (("+") reduce 401) ((",") reduce 401) (("-") reduce 401) ((".") reduce 401) (("/") shift) (("<") reduce 401) ((">") reduce 401) (("?") reduce 401) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_BOOLEAN_AND) reduce 401) ((T_BOOLEAN_OR) reduce 401) ((T_COALESCE) reduce 401) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 401) ((T_IS_GREATER_OR_EQUAL) reduce 401) ((T_IS_IDENTICAL) reduce 401) ((T_IS_NOT_EQUAL) reduce 401) ((T_IS_NOT_IDENTICAL) reduce 401) ((T_IS_SMALLER_OR_EQUAL) reduce 401) ((T_LOGICAL_AND) reduce 401) ((T_LOGICAL_OR) reduce 401) ((T_LOGICAL_XOR) reduce 401) ((T_POW) shift) ((T_SL) reduce 401) ((T_SPACESHIP) reduce 401) ((T_SR) reduce 401) (("]") reduce 401) (("^") reduce 401) (("|") reduce 401)) 7733 ((("%") shift) (("*") shift) (("+") reduce 400) ((",") reduce 400) (("-") reduce 400) ((".") reduce 400) (("/") shift) (("<") reduce 400) ((">") reduce 400) (("?") reduce 400) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_BOOLEAN_AND) reduce 400) ((T_BOOLEAN_OR) reduce 400) ((T_COALESCE) reduce 400) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 400) ((T_IS_GREATER_OR_EQUAL) reduce 400) ((T_IS_IDENTICAL) reduce 400) ((T_IS_NOT_EQUAL) reduce 400) ((T_IS_NOT_IDENTICAL) reduce 400) ((T_IS_SMALLER_OR_EQUAL) reduce 400) ((T_LOGICAL_AND) reduce 400) ((T_LOGICAL_OR) reduce 400) ((T_LOGICAL_XOR) reduce 400) ((T_POW) shift) ((T_SL) reduce 400) ((T_SPACESHIP) reduce 400) ((T_SR) reduce 400) (("]") reduce 400) (("^") reduce 400) (("|") reduce 400)) 7734 ((("%") reduce 402) (("*") reduce 402) (("+") reduce 402) ((",") reduce 402) (("-") reduce 402) ((".") reduce 402) (("/") reduce 402) (("<") reduce 402) ((">") reduce 402) (("?") reduce 402) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_BOOLEAN_AND) reduce 402) ((T_BOOLEAN_OR) reduce 402) ((T_COALESCE) reduce 402) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 402) ((T_IS_GREATER_OR_EQUAL) reduce 402) ((T_IS_IDENTICAL) reduce 402) ((T_IS_NOT_EQUAL) reduce 402) ((T_IS_NOT_IDENTICAL) reduce 402) ((T_IS_SMALLER_OR_EQUAL) reduce 402) ((T_LOGICAL_AND) reduce 402) ((T_LOGICAL_OR) reduce 402) ((T_LOGICAL_XOR) reduce 402) ((T_POW) shift) ((T_SL) reduce 402) ((T_SPACESHIP) reduce 402) ((T_SR) reduce 402) (("]") reduce 402) (("^") reduce 402) (("|") reduce 402)) 7735 ((("%") reduce 405) (("*") reduce 405) (("+") reduce 405) ((",") reduce 405) (("-") reduce 405) ((".") reduce 405) (("/") reduce 405) (("<") reduce 405) ((">") reduce 405) (("?") reduce 405) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_BOOLEAN_AND) reduce 405) ((T_BOOLEAN_OR) reduce 405) ((T_COALESCE) reduce 405) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 405) ((T_IS_GREATER_OR_EQUAL) reduce 405) ((T_IS_IDENTICAL) reduce 405) ((T_IS_NOT_EQUAL) reduce 405) ((T_IS_NOT_IDENTICAL) reduce 405) ((T_IS_SMALLER_OR_EQUAL) reduce 405) ((T_LOGICAL_AND) reduce 405) ((T_LOGICAL_OR) reduce 405) ((T_LOGICAL_XOR) reduce 405) ((T_POW) shift) ((T_SL) reduce 405) ((T_SPACESHIP) reduce 405) ((T_SR) reduce 405) (("]") reduce 405) (("^") reduce 405) (("|") reduce 405)) 7740 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 368) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 368) ((T_LOGICAL_OR) reduce 368) ((T_LOGICAL_XOR) reduce 368) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 368) (("^") shift) (("|") shift)) 7742 ((("%") reduce 73) (("(") reduce 73) (("*") reduce 73) (("+") reduce 73) ((",") reduce 73) (("-") reduce 73) ((".") reduce 73) (("/") reduce 73) (("<") reduce 73) ((">") reduce 73) (("?") reduce 73) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_BOOLEAN_AND) reduce 73) ((T_BOOLEAN_OR) reduce 73) ((T_COALESCE) reduce 73) ((T_INSTANCEOF) reduce 73) ((T_IS_EQUAL) reduce 73) ((T_IS_GREATER_OR_EQUAL) reduce 73) ((T_IS_IDENTICAL) reduce 73) ((T_IS_NOT_EQUAL) reduce 73) ((T_IS_NOT_IDENTICAL) reduce 73) ((T_IS_SMALLER_OR_EQUAL) reduce 73) ((T_LOGICAL_AND) reduce 73) ((T_LOGICAL_OR) reduce 73) ((T_LOGICAL_XOR) reduce 73) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 73) ((T_OBJECT_OPERATOR) reduce 73) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 73) ((T_POW) reduce 73) ((T_SL) reduce 73) ((T_SPACESHIP) reduce 73) ((T_SR) reduce 73) (("[") reduce 73) (("]") reduce 73) (("^") reduce 73) (("{") reduce 73) (("|") reduce 73)) 7743 ((("%") reduce 52) (("(") reduce 52) (("*") reduce 52) (("+") reduce 52) ((",") reduce 52) (("-") reduce 52) ((".") reduce 52) (("/") reduce 52) (("<") reduce 52) ((">") reduce 52) (("?") reduce 52) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_BOOLEAN_AND) reduce 52) ((T_BOOLEAN_OR) reduce 52) ((T_COALESCE) reduce 52) ((T_INSTANCEOF) reduce 52) ((T_IS_EQUAL) reduce 52) ((T_IS_GREATER_OR_EQUAL) reduce 52) ((T_IS_IDENTICAL) reduce 52) ((T_IS_NOT_EQUAL) reduce 52) ((T_IS_NOT_IDENTICAL) reduce 52) ((T_IS_SMALLER_OR_EQUAL) reduce 52) ((T_LOGICAL_AND) reduce 52) ((T_LOGICAL_OR) reduce 52) ((T_LOGICAL_XOR) reduce 52) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 52) ((T_OBJECT_OPERATOR) reduce 52) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 52) ((T_POW) reduce 52) ((T_SL) reduce 52) ((T_SPACESHIP) reduce 52) ((T_SR) reduce 52) (("[") reduce 52) (("]") reduce 52) (("^") reduce 52) (("{") reduce 52) (("|") reduce 52)) 7744 ((("%") reduce 27) (("(") reduce 27) (("*") reduce 27) (("+") reduce 27) ((",") reduce 27) (("-") reduce 27) ((".") reduce 27) (("/") reduce 27) (("<") reduce 27) ((">") reduce 27) (("?") reduce 27) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_BOOLEAN_AND) reduce 27) ((T_BOOLEAN_OR) reduce 27) ((T_COALESCE) reduce 27) ((T_INSTANCEOF) reduce 27) ((T_IS_EQUAL) reduce 27) ((T_IS_GREATER_OR_EQUAL) reduce 27) ((T_IS_IDENTICAL) reduce 27) ((T_IS_NOT_EQUAL) reduce 27) ((T_IS_NOT_IDENTICAL) reduce 27) ((T_IS_SMALLER_OR_EQUAL) reduce 27) ((T_LOGICAL_AND) reduce 27) ((T_LOGICAL_OR) reduce 27) ((T_LOGICAL_XOR) reduce 27) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 27) ((T_OBJECT_OPERATOR) reduce 27) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 27) ((T_POW) reduce 27) ((T_SL) reduce 27) ((T_SPACESHIP) reduce 27) ((T_SR) reduce 27) (("[") reduce 27) (("]") reduce 27) (("^") reduce 27) (("{") reduce 27) (("|") reduce 27)) 7745 ((("%") reduce 51) (("(") reduce 51) (("*") reduce 51) (("+") reduce 51) ((",") reduce 51) (("-") reduce 51) ((".") reduce 51) (("/") reduce 51) (("<") reduce 51) ((">") reduce 51) (("?") reduce 51) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_BOOLEAN_AND) reduce 51) ((T_BOOLEAN_OR) reduce 51) ((T_COALESCE) reduce 51) ((T_INSTANCEOF) reduce 51) ((T_IS_EQUAL) reduce 51) ((T_IS_GREATER_OR_EQUAL) reduce 51) ((T_IS_IDENTICAL) reduce 51) ((T_IS_NOT_EQUAL) reduce 51) ((T_IS_NOT_IDENTICAL) reduce 51) ((T_IS_SMALLER_OR_EQUAL) reduce 51) ((T_LOGICAL_AND) reduce 51) ((T_LOGICAL_OR) reduce 51) ((T_LOGICAL_XOR) reduce 51) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 51) ((T_OBJECT_OPERATOR) reduce 51) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 51) ((T_POW) reduce 51) ((T_SL) reduce 51) ((T_SPACESHIP) reduce 51) ((T_SR) reduce 51) (("[") reduce 51) (("]") reduce 51) (("^") reduce 51) (("{") reduce 51) (("|") reduce 51)) 7746 ((("%") reduce 53) (("(") reduce 53) (("*") reduce 53) (("+") reduce 53) ((",") reduce 53) (("-") reduce 53) ((".") reduce 53) (("/") reduce 53) (("<") reduce 53) ((">") reduce 53) (("?") reduce 53) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_BOOLEAN_AND) reduce 53) ((T_BOOLEAN_OR) reduce 53) ((T_COALESCE) reduce 53) ((T_INSTANCEOF) reduce 53) ((T_IS_EQUAL) reduce 53) ((T_IS_GREATER_OR_EQUAL) reduce 53) ((T_IS_IDENTICAL) reduce 53) ((T_IS_NOT_EQUAL) reduce 53) ((T_IS_NOT_IDENTICAL) reduce 53) ((T_IS_SMALLER_OR_EQUAL) reduce 53) ((T_LOGICAL_AND) reduce 53) ((T_LOGICAL_OR) reduce 53) ((T_LOGICAL_XOR) reduce 53) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 53) ((T_OBJECT_OPERATOR) reduce 53) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 53) ((T_POW) reduce 53) ((T_SL) reduce 53) ((T_SPACESHIP) reduce 53) ((T_SR) reduce 53) (("[") reduce 53) (("]") reduce 53) (("^") reduce 53) (("{") reduce 53) (("|") reduce 53)) 7747 ((("%") reduce 49) (("(") reduce 49) (("*") reduce 49) (("+") reduce 49) ((",") reduce 49) (("-") reduce 49) ((".") reduce 49) (("/") reduce 49) (("<") reduce 49) ((">") reduce 49) (("?") reduce 49) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_BOOLEAN_AND) reduce 49) ((T_BOOLEAN_OR) reduce 49) ((T_COALESCE) reduce 49) ((T_INSTANCEOF) reduce 49) ((T_IS_EQUAL) reduce 49) ((T_IS_GREATER_OR_EQUAL) reduce 49) ((T_IS_IDENTICAL) reduce 49) ((T_IS_NOT_EQUAL) reduce 49) ((T_IS_NOT_IDENTICAL) reduce 49) ((T_IS_SMALLER_OR_EQUAL) reduce 49) ((T_LOGICAL_AND) reduce 49) ((T_LOGICAL_OR) reduce 49) ((T_LOGICAL_XOR) reduce 49) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 49) ((T_OBJECT_OPERATOR) reduce 49) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 49) ((T_POW) reduce 49) ((T_SL) reduce 49) ((T_SPACESHIP) reduce 49) ((T_SR) reduce 49) (("[") reduce 49) (("]") reduce 49) (("^") reduce 49) (("{") reduce 49) (("|") reduce 49)) 7748 ((("%") reduce 29) (("(") reduce 29) (("*") reduce 29) (("+") reduce 29) ((",") reduce 29) (("-") reduce 29) ((".") reduce 29) (("/") reduce 29) (("<") reduce 29) ((">") reduce 29) (("?") reduce 29) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_BOOLEAN_AND) reduce 29) ((T_BOOLEAN_OR) reduce 29) ((T_COALESCE) reduce 29) ((T_INSTANCEOF) reduce 29) ((T_IS_EQUAL) reduce 29) ((T_IS_GREATER_OR_EQUAL) reduce 29) ((T_IS_IDENTICAL) reduce 29) ((T_IS_NOT_EQUAL) reduce 29) ((T_IS_NOT_IDENTICAL) reduce 29) ((T_IS_SMALLER_OR_EQUAL) reduce 29) ((T_LOGICAL_AND) reduce 29) ((T_LOGICAL_OR) reduce 29) ((T_LOGICAL_XOR) reduce 29) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 29) ((T_OBJECT_OPERATOR) reduce 29) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 29) ((T_POW) reduce 29) ((T_SL) reduce 29) ((T_SPACESHIP) reduce 29) ((T_SR) reduce 29) (("[") reduce 29) (("]") reduce 29) (("^") reduce 29) (("{") reduce 29) (("|") reduce 29)) 7749 ((("%") reduce 59) (("(") reduce 59) (("*") reduce 59) (("+") reduce 59) ((",") reduce 59) (("-") reduce 59) ((".") reduce 59) (("/") reduce 59) (("<") reduce 59) ((">") reduce 59) (("?") reduce 59) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_BOOLEAN_AND) reduce 59) ((T_BOOLEAN_OR) reduce 59) ((T_COALESCE) reduce 59) ((T_INSTANCEOF) reduce 59) ((T_IS_EQUAL) reduce 59) ((T_IS_GREATER_OR_EQUAL) reduce 59) ((T_IS_IDENTICAL) reduce 59) ((T_IS_NOT_EQUAL) reduce 59) ((T_IS_NOT_IDENTICAL) reduce 59) ((T_IS_SMALLER_OR_EQUAL) reduce 59) ((T_LOGICAL_AND) reduce 59) ((T_LOGICAL_OR) reduce 59) ((T_LOGICAL_XOR) reduce 59) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 59) ((T_OBJECT_OPERATOR) reduce 59) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 59) ((T_POW) reduce 59) ((T_SL) reduce 59) ((T_SPACESHIP) reduce 59) ((T_SR) reduce 59) (("[") reduce 59) (("]") reduce 59) (("^") reduce 59) (("{") reduce 59) (("|") reduce 59)) 7750 ((("%") reduce 60) (("(") reduce 60) (("*") reduce 60) (("+") reduce 60) ((",") reduce 60) (("-") reduce 60) ((".") reduce 60) (("/") reduce 60) (("<") reduce 60) ((">") reduce 60) (("?") reduce 60) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_BOOLEAN_AND) reduce 60) ((T_BOOLEAN_OR) reduce 60) ((T_COALESCE) reduce 60) ((T_INSTANCEOF) reduce 60) ((T_IS_EQUAL) reduce 60) ((T_IS_GREATER_OR_EQUAL) reduce 60) ((T_IS_IDENTICAL) reduce 60) ((T_IS_NOT_EQUAL) reduce 60) ((T_IS_NOT_IDENTICAL) reduce 60) ((T_IS_SMALLER_OR_EQUAL) reduce 60) ((T_LOGICAL_AND) reduce 60) ((T_LOGICAL_OR) reduce 60) ((T_LOGICAL_XOR) reduce 60) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 60) ((T_OBJECT_OPERATOR) reduce 60) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 60) ((T_POW) reduce 60) ((T_SL) reduce 60) ((T_SPACESHIP) reduce 60) ((T_SR) reduce 60) (("[") reduce 60) (("]") reduce 60) (("^") reduce 60) (("{") reduce 60) (("|") reduce 60)) 7751 ((("%") reduce 11) (("(") reduce 11) (("*") reduce 11) (("+") reduce 11) ((",") reduce 11) (("-") reduce 11) ((".") reduce 11) (("/") reduce 11) (("<") reduce 11) ((">") reduce 11) (("?") reduce 11) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_BOOLEAN_AND) reduce 11) ((T_BOOLEAN_OR) reduce 11) ((T_COALESCE) reduce 11) ((T_INSTANCEOF) reduce 11) ((T_IS_EQUAL) reduce 11) ((T_IS_GREATER_OR_EQUAL) reduce 11) ((T_IS_IDENTICAL) reduce 11) ((T_IS_NOT_EQUAL) reduce 11) ((T_IS_NOT_IDENTICAL) reduce 11) ((T_IS_SMALLER_OR_EQUAL) reduce 11) ((T_LOGICAL_AND) reduce 11) ((T_LOGICAL_OR) reduce 11) ((T_LOGICAL_XOR) reduce 11) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 11) ((T_OBJECT_OPERATOR) reduce 11) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 11) ((T_POW) reduce 11) ((T_SL) reduce 11) ((T_SPACESHIP) reduce 11) ((T_SR) reduce 11) (("[") reduce 11) (("]") reduce 11) (("^") reduce 11) (("{") reduce 11) (("|") reduce 11)) 7752 ((("%") reduce 42) (("(") reduce 42) (("*") reduce 42) (("+") reduce 42) ((",") reduce 42) (("-") reduce 42) ((".") reduce 42) (("/") reduce 42) (("<") reduce 42) ((">") reduce 42) (("?") reduce 42) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_BOOLEAN_AND) reduce 42) ((T_BOOLEAN_OR) reduce 42) ((T_COALESCE) reduce 42) ((T_INSTANCEOF) reduce 42) ((T_IS_EQUAL) reduce 42) ((T_IS_GREATER_OR_EQUAL) reduce 42) ((T_IS_IDENTICAL) reduce 42) ((T_IS_NOT_EQUAL) reduce 42) ((T_IS_NOT_IDENTICAL) reduce 42) ((T_IS_SMALLER_OR_EQUAL) reduce 42) ((T_LOGICAL_AND) reduce 42) ((T_LOGICAL_OR) reduce 42) ((T_LOGICAL_XOR) reduce 42) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 42) ((T_OBJECT_OPERATOR) reduce 42) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 42) ((T_POW) reduce 42) ((T_SL) reduce 42) ((T_SPACESHIP) reduce 42) ((T_SR) reduce 42) (("[") reduce 42) (("]") reduce 42) (("^") reduce 42) (("{") reduce 42) (("|") reduce 42)) 7753 ((("%") reduce 39) (("(") reduce 39) (("*") reduce 39) (("+") reduce 39) ((",") reduce 39) (("-") reduce 39) ((".") reduce 39) (("/") reduce 39) (("<") reduce 39) ((">") reduce 39) (("?") reduce 39) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_BOOLEAN_AND) reduce 39) ((T_BOOLEAN_OR) reduce 39) ((T_COALESCE) reduce 39) ((T_INSTANCEOF) reduce 39) ((T_IS_EQUAL) reduce 39) ((T_IS_GREATER_OR_EQUAL) reduce 39) ((T_IS_IDENTICAL) reduce 39) ((T_IS_NOT_EQUAL) reduce 39) ((T_IS_NOT_IDENTICAL) reduce 39) ((T_IS_SMALLER_OR_EQUAL) reduce 39) ((T_LOGICAL_AND) reduce 39) ((T_LOGICAL_OR) reduce 39) ((T_LOGICAL_XOR) reduce 39) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 39) ((T_OBJECT_OPERATOR) reduce 39) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 39) ((T_POW) reduce 39) ((T_SL) reduce 39) ((T_SPACESHIP) reduce 39) ((T_SR) reduce 39) (("[") reduce 39) (("]") reduce 39) (("^") reduce 39) (("{") reduce 39) (("|") reduce 39)) 7754 ((("%") reduce 25) (("(") reduce 25) (("*") reduce 25) (("+") reduce 25) ((",") reduce 25) (("-") reduce 25) ((".") reduce 25) (("/") reduce 25) (("<") reduce 25) ((">") reduce 25) (("?") reduce 25) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_BOOLEAN_AND) reduce 25) ((T_BOOLEAN_OR) reduce 25) ((T_COALESCE) reduce 25) ((T_INSTANCEOF) reduce 25) ((T_IS_EQUAL) reduce 25) ((T_IS_GREATER_OR_EQUAL) reduce 25) ((T_IS_IDENTICAL) reduce 25) ((T_IS_NOT_EQUAL) reduce 25) ((T_IS_NOT_IDENTICAL) reduce 25) ((T_IS_SMALLER_OR_EQUAL) reduce 25) ((T_LOGICAL_AND) reduce 25) ((T_LOGICAL_OR) reduce 25) ((T_LOGICAL_XOR) reduce 25) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 25) ((T_OBJECT_OPERATOR) reduce 25) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 25) ((T_POW) reduce 25) ((T_SL) reduce 25) ((T_SPACESHIP) reduce 25) ((T_SR) reduce 25) (("[") reduce 25) (("]") reduce 25) (("^") reduce 25) (("{") reduce 25) (("|") reduce 25)) 7755 ((("%") reduce 50) (("(") reduce 50) (("*") reduce 50) (("+") reduce 50) ((",") reduce 50) (("-") reduce 50) ((".") reduce 50) (("/") reduce 50) (("<") reduce 50) ((">") reduce 50) (("?") reduce 50) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_BOOLEAN_AND) reduce 50) ((T_BOOLEAN_OR) reduce 50) ((T_COALESCE) reduce 50) ((T_INSTANCEOF) reduce 50) ((T_IS_EQUAL) reduce 50) ((T_IS_GREATER_OR_EQUAL) reduce 50) ((T_IS_IDENTICAL) reduce 50) ((T_IS_NOT_EQUAL) reduce 50) ((T_IS_NOT_IDENTICAL) reduce 50) ((T_IS_SMALLER_OR_EQUAL) reduce 50) ((T_LOGICAL_AND) reduce 50) ((T_LOGICAL_OR) reduce 50) ((T_LOGICAL_XOR) reduce 50) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 50) ((T_OBJECT_OPERATOR) reduce 50) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 50) ((T_POW) reduce 50) ((T_SL) reduce 50) ((T_SPACESHIP) reduce 50) ((T_SR) reduce 50) (("[") reduce 50) (("]") reduce 50) (("^") reduce 50) (("{") reduce 50) (("|") reduce 50)) 7756 ((("%") reduce 66) (("(") reduce 66) (("*") reduce 66) (("+") reduce 66) ((",") reduce 66) (("-") reduce 66) ((".") reduce 66) (("/") reduce 66) (("<") reduce 66) ((">") reduce 66) (("?") reduce 66) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_BOOLEAN_AND) reduce 66) ((T_BOOLEAN_OR) reduce 66) ((T_COALESCE) reduce 66) ((T_INSTANCEOF) reduce 66) ((T_IS_EQUAL) reduce 66) ((T_IS_GREATER_OR_EQUAL) reduce 66) ((T_IS_IDENTICAL) reduce 66) ((T_IS_NOT_EQUAL) reduce 66) ((T_IS_NOT_IDENTICAL) reduce 66) ((T_IS_SMALLER_OR_EQUAL) reduce 66) ((T_LOGICAL_AND) reduce 66) ((T_LOGICAL_OR) reduce 66) ((T_LOGICAL_XOR) reduce 66) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 66) ((T_OBJECT_OPERATOR) reduce 66) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 66) ((T_POW) reduce 66) ((T_SL) reduce 66) ((T_SPACESHIP) reduce 66) ((T_SR) reduce 66) (("[") reduce 66) (("]") reduce 66) (("^") reduce 66) (("{") reduce 66) (("|") reduce 66)) 7757 ((("%") reduce 18) (("(") reduce 18) (("*") reduce 18) (("+") reduce 18) ((",") reduce 18) (("-") reduce 18) ((".") reduce 18) (("/") reduce 18) (("<") reduce 18) ((">") reduce 18) (("?") reduce 18) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_BOOLEAN_AND) reduce 18) ((T_BOOLEAN_OR) reduce 18) ((T_COALESCE) reduce 18) ((T_INSTANCEOF) reduce 18) ((T_IS_EQUAL) reduce 18) ((T_IS_GREATER_OR_EQUAL) reduce 18) ((T_IS_IDENTICAL) reduce 18) ((T_IS_NOT_EQUAL) reduce 18) ((T_IS_NOT_IDENTICAL) reduce 18) ((T_IS_SMALLER_OR_EQUAL) reduce 18) ((T_LOGICAL_AND) reduce 18) ((T_LOGICAL_OR) reduce 18) ((T_LOGICAL_XOR) reduce 18) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 18) ((T_OBJECT_OPERATOR) reduce 18) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 18) ((T_POW) reduce 18) ((T_SL) reduce 18) ((T_SPACESHIP) reduce 18) ((T_SR) reduce 18) (("[") reduce 18) (("]") reduce 18) (("^") reduce 18) (("{") reduce 18) (("|") reduce 18)) 7758 ((("%") reduce 17) (("(") reduce 17) (("*") reduce 17) (("+") reduce 17) ((",") reduce 17) (("-") reduce 17) ((".") reduce 17) (("/") reduce 17) (("<") reduce 17) ((">") reduce 17) (("?") reduce 17) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_BOOLEAN_AND) reduce 17) ((T_BOOLEAN_OR) reduce 17) ((T_COALESCE) reduce 17) ((T_INSTANCEOF) reduce 17) ((T_IS_EQUAL) reduce 17) ((T_IS_GREATER_OR_EQUAL) reduce 17) ((T_IS_IDENTICAL) reduce 17) ((T_IS_NOT_EQUAL) reduce 17) ((T_IS_NOT_IDENTICAL) reduce 17) ((T_IS_SMALLER_OR_EQUAL) reduce 17) ((T_LOGICAL_AND) reduce 17) ((T_LOGICAL_OR) reduce 17) ((T_LOGICAL_XOR) reduce 17) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 17) ((T_OBJECT_OPERATOR) reduce 17) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 17) ((T_POW) reduce 17) ((T_SL) reduce 17) ((T_SPACESHIP) reduce 17) ((T_SR) reduce 17) (("[") reduce 17) (("]") reduce 17) (("^") reduce 17) (("{") reduce 17) (("|") reduce 17)) 7759 ((("%") reduce 15) (("(") reduce 15) (("*") reduce 15) (("+") reduce 15) ((",") reduce 15) (("-") reduce 15) ((".") reduce 15) (("/") reduce 15) (("<") reduce 15) ((">") reduce 15) (("?") reduce 15) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_BOOLEAN_AND) reduce 15) ((T_BOOLEAN_OR) reduce 15) ((T_COALESCE) reduce 15) ((T_INSTANCEOF) reduce 15) ((T_IS_EQUAL) reduce 15) ((T_IS_GREATER_OR_EQUAL) reduce 15) ((T_IS_IDENTICAL) reduce 15) ((T_IS_NOT_EQUAL) reduce 15) ((T_IS_NOT_IDENTICAL) reduce 15) ((T_IS_SMALLER_OR_EQUAL) reduce 15) ((T_LOGICAL_AND) reduce 15) ((T_LOGICAL_OR) reduce 15) ((T_LOGICAL_XOR) reduce 15) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 15) ((T_OBJECT_OPERATOR) reduce 15) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 15) ((T_POW) reduce 15) ((T_SL) reduce 15) ((T_SPACESHIP) reduce 15) ((T_SR) reduce 15) (("[") reduce 15) (("]") reduce 15) (("^") reduce 15) (("{") reduce 15) (("|") reduce 15)) 7760 ((("%") reduce 14) (("(") reduce 14) (("*") reduce 14) (("+") reduce 14) ((",") reduce 14) (("-") reduce 14) ((".") reduce 14) (("/") reduce 14) (("<") reduce 14) ((">") reduce 14) (("?") reduce 14) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_BOOLEAN_AND) reduce 14) ((T_BOOLEAN_OR) reduce 14) ((T_COALESCE) reduce 14) ((T_INSTANCEOF) reduce 14) ((T_IS_EQUAL) reduce 14) ((T_IS_GREATER_OR_EQUAL) reduce 14) ((T_IS_IDENTICAL) reduce 14) ((T_IS_NOT_EQUAL) reduce 14) ((T_IS_NOT_IDENTICAL) reduce 14) ((T_IS_SMALLER_OR_EQUAL) reduce 14) ((T_LOGICAL_AND) reduce 14) ((T_LOGICAL_OR) reduce 14) ((T_LOGICAL_XOR) reduce 14) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 14) ((T_OBJECT_OPERATOR) reduce 14) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 14) ((T_POW) reduce 14) ((T_SL) reduce 14) ((T_SPACESHIP) reduce 14) ((T_SR) reduce 14) (("[") reduce 14) (("]") reduce 14) (("^") reduce 14) (("{") reduce 14) (("|") reduce 14)) 7761 ((("%") reduce 38) (("(") reduce 38) (("*") reduce 38) (("+") reduce 38) ((",") reduce 38) (("-") reduce 38) ((".") reduce 38) (("/") reduce 38) (("<") reduce 38) ((">") reduce 38) (("?") reduce 38) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_BOOLEAN_AND) reduce 38) ((T_BOOLEAN_OR) reduce 38) ((T_COALESCE) reduce 38) ((T_INSTANCEOF) reduce 38) ((T_IS_EQUAL) reduce 38) ((T_IS_GREATER_OR_EQUAL) reduce 38) ((T_IS_IDENTICAL) reduce 38) ((T_IS_NOT_EQUAL) reduce 38) ((T_IS_NOT_IDENTICAL) reduce 38) ((T_IS_SMALLER_OR_EQUAL) reduce 38) ((T_LOGICAL_AND) reduce 38) ((T_LOGICAL_OR) reduce 38) ((T_LOGICAL_XOR) reduce 38) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 38) ((T_OBJECT_OPERATOR) reduce 38) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 38) ((T_POW) reduce 38) ((T_SL) reduce 38) ((T_SPACESHIP) reduce 38) ((T_SR) reduce 38) (("[") reduce 38) (("]") reduce 38) (("^") reduce 38) (("{") reduce 38) (("|") reduce 38)) 7762 ((("%") reduce 26) (("(") reduce 26) (("*") reduce 26) (("+") reduce 26) ((",") reduce 26) (("-") reduce 26) ((".") reduce 26) (("/") reduce 26) (("<") reduce 26) ((">") reduce 26) (("?") reduce 26) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_BOOLEAN_AND) reduce 26) ((T_BOOLEAN_OR) reduce 26) ((T_COALESCE) reduce 26) ((T_INSTANCEOF) reduce 26) ((T_IS_EQUAL) reduce 26) ((T_IS_GREATER_OR_EQUAL) reduce 26) ((T_IS_IDENTICAL) reduce 26) ((T_IS_NOT_EQUAL) reduce 26) ((T_IS_NOT_IDENTICAL) reduce 26) ((T_IS_SMALLER_OR_EQUAL) reduce 26) ((T_LOGICAL_AND) reduce 26) ((T_LOGICAL_OR) reduce 26) ((T_LOGICAL_XOR) reduce 26) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 26) ((T_OBJECT_OPERATOR) reduce 26) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 26) ((T_POW) reduce 26) ((T_SL) reduce 26) ((T_SPACESHIP) reduce 26) ((T_SR) reduce 26) (("[") reduce 26) (("]") reduce 26) (("^") reduce 26) (("{") reduce 26) (("|") reduce 26)) 7763 ((("%") reduce 22) (("(") reduce 22) (("*") reduce 22) (("+") reduce 22) ((",") reduce 22) (("-") reduce 22) ((".") reduce 22) (("/") reduce 22) (("<") reduce 22) ((">") reduce 22) (("?") reduce 22) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_BOOLEAN_AND) reduce 22) ((T_BOOLEAN_OR) reduce 22) ((T_COALESCE) reduce 22) ((T_INSTANCEOF) reduce 22) ((T_IS_EQUAL) reduce 22) ((T_IS_GREATER_OR_EQUAL) reduce 22) ((T_IS_IDENTICAL) reduce 22) ((T_IS_NOT_EQUAL) reduce 22) ((T_IS_NOT_IDENTICAL) reduce 22) ((T_IS_SMALLER_OR_EQUAL) reduce 22) ((T_LOGICAL_AND) reduce 22) ((T_LOGICAL_OR) reduce 22) ((T_LOGICAL_XOR) reduce 22) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 22) ((T_OBJECT_OPERATOR) reduce 22) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 22) ((T_POW) reduce 22) ((T_SL) reduce 22) ((T_SPACESHIP) reduce 22) ((T_SR) reduce 22) (("[") reduce 22) (("]") reduce 22) (("^") reduce 22) (("{") reduce 22) (("|") reduce 22)) 7764 ((("%") reduce 24) (("(") reduce 24) (("*") reduce 24) (("+") reduce 24) ((",") reduce 24) (("-") reduce 24) ((".") reduce 24) (("/") reduce 24) (("<") reduce 24) ((">") reduce 24) (("?") reduce 24) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_BOOLEAN_AND) reduce 24) ((T_BOOLEAN_OR) reduce 24) ((T_COALESCE) reduce 24) ((T_INSTANCEOF) reduce 24) ((T_IS_EQUAL) reduce 24) ((T_IS_GREATER_OR_EQUAL) reduce 24) ((T_IS_IDENTICAL) reduce 24) ((T_IS_NOT_EQUAL) reduce 24) ((T_IS_NOT_IDENTICAL) reduce 24) ((T_IS_SMALLER_OR_EQUAL) reduce 24) ((T_LOGICAL_AND) reduce 24) ((T_LOGICAL_OR) reduce 24) ((T_LOGICAL_XOR) reduce 24) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 24) ((T_OBJECT_OPERATOR) reduce 24) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 24) ((T_POW) reduce 24) ((T_SL) reduce 24) ((T_SPACESHIP) reduce 24) ((T_SR) reduce 24) (("[") reduce 24) (("]") reduce 24) (("^") reduce 24) (("{") reduce 24) (("|") reduce 24)) 7765 ((("%") reduce 16) (("(") reduce 16) (("*") reduce 16) (("+") reduce 16) ((",") reduce 16) (("-") reduce 16) ((".") reduce 16) (("/") reduce 16) (("<") reduce 16) ((">") reduce 16) (("?") reduce 16) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_BOOLEAN_AND) reduce 16) ((T_BOOLEAN_OR) reduce 16) ((T_COALESCE) reduce 16) ((T_INSTANCEOF) reduce 16) ((T_IS_EQUAL) reduce 16) ((T_IS_GREATER_OR_EQUAL) reduce 16) ((T_IS_IDENTICAL) reduce 16) ((T_IS_NOT_EQUAL) reduce 16) ((T_IS_NOT_IDENTICAL) reduce 16) ((T_IS_SMALLER_OR_EQUAL) reduce 16) ((T_LOGICAL_AND) reduce 16) ((T_LOGICAL_OR) reduce 16) ((T_LOGICAL_XOR) reduce 16) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 16) ((T_OBJECT_OPERATOR) reduce 16) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 16) ((T_POW) reduce 16) ((T_SL) reduce 16) ((T_SPACESHIP) reduce 16) ((T_SR) reduce 16) (("[") reduce 16) (("]") reduce 16) (("^") reduce 16) (("{") reduce 16) (("|") reduce 16)) 7766 ((("%") reduce 48) (("(") reduce 48) (("*") reduce 48) (("+") reduce 48) ((",") reduce 48) (("-") reduce 48) ((".") reduce 48) (("/") reduce 48) (("<") reduce 48) ((">") reduce 48) (("?") reduce 48) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_BOOLEAN_AND) reduce 48) ((T_BOOLEAN_OR) reduce 48) ((T_COALESCE) reduce 48) ((T_INSTANCEOF) reduce 48) ((T_IS_EQUAL) reduce 48) ((T_IS_GREATER_OR_EQUAL) reduce 48) ((T_IS_IDENTICAL) reduce 48) ((T_IS_NOT_EQUAL) reduce 48) ((T_IS_NOT_IDENTICAL) reduce 48) ((T_IS_SMALLER_OR_EQUAL) reduce 48) ((T_LOGICAL_AND) reduce 48) ((T_LOGICAL_OR) reduce 48) ((T_LOGICAL_XOR) reduce 48) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 48) ((T_OBJECT_OPERATOR) reduce 48) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 48) ((T_POW) reduce 48) ((T_SL) reduce 48) ((T_SPACESHIP) reduce 48) ((T_SR) reduce 48) (("[") reduce 48) (("]") reduce 48) (("^") reduce 48) (("{") reduce 48) (("|") reduce 48)) 7767 ((("%") reduce 20) (("(") reduce 20) (("*") reduce 20) (("+") reduce 20) ((",") reduce 20) (("-") reduce 20) ((".") reduce 20) (("/") reduce 20) (("<") reduce 20) ((">") reduce 20) (("?") reduce 20) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_BOOLEAN_AND) reduce 20) ((T_BOOLEAN_OR) reduce 20) ((T_COALESCE) reduce 20) ((T_INSTANCEOF) reduce 20) ((T_IS_EQUAL) reduce 20) ((T_IS_GREATER_OR_EQUAL) reduce 20) ((T_IS_IDENTICAL) reduce 20) ((T_IS_NOT_EQUAL) reduce 20) ((T_IS_NOT_IDENTICAL) reduce 20) ((T_IS_SMALLER_OR_EQUAL) reduce 20) ((T_LOGICAL_AND) reduce 20) ((T_LOGICAL_OR) reduce 20) ((T_LOGICAL_XOR) reduce 20) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 20) ((T_OBJECT_OPERATOR) reduce 20) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 20) ((T_POW) reduce 20) ((T_SL) reduce 20) ((T_SPACESHIP) reduce 20) ((T_SR) reduce 20) (("[") reduce 20) (("]") reduce 20) (("^") reduce 20) (("{") reduce 20) (("|") reduce 20)) 7768 ((("%") reduce 70) (("(") reduce 70) (("*") reduce 70) (("+") reduce 70) ((",") reduce 70) (("-") reduce 70) ((".") reduce 70) (("/") reduce 70) (("<") reduce 70) ((">") reduce 70) (("?") reduce 70) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_BOOLEAN_AND) reduce 70) ((T_BOOLEAN_OR) reduce 70) ((T_COALESCE) reduce 70) ((T_INSTANCEOF) reduce 70) ((T_IS_EQUAL) reduce 70) ((T_IS_GREATER_OR_EQUAL) reduce 70) ((T_IS_IDENTICAL) reduce 70) ((T_IS_NOT_EQUAL) reduce 70) ((T_IS_NOT_IDENTICAL) reduce 70) ((T_IS_SMALLER_OR_EQUAL) reduce 70) ((T_LOGICAL_AND) reduce 70) ((T_LOGICAL_OR) reduce 70) ((T_LOGICAL_XOR) reduce 70) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 70) ((T_OBJECT_OPERATOR) reduce 70) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 70) ((T_POW) reduce 70) ((T_SL) reduce 70) ((T_SPACESHIP) reduce 70) ((T_SR) reduce 70) (("[") reduce 70) (("]") reduce 70) (("^") reduce 70) (("{") reduce 70) (("|") reduce 70)) 7769 ((("%") reduce 3) (("(") reduce 3) (("*") reduce 3) (("+") reduce 3) ((",") reduce 3) (("-") reduce 3) ((".") reduce 3) (("/") reduce 3) (("<") reduce 3) ((">") reduce 3) (("?") reduce 3) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_BOOLEAN_AND) reduce 3) ((T_BOOLEAN_OR) reduce 3) ((T_COALESCE) reduce 3) ((T_INSTANCEOF) reduce 3) ((T_IS_EQUAL) reduce 3) ((T_IS_GREATER_OR_EQUAL) reduce 3) ((T_IS_IDENTICAL) reduce 3) ((T_IS_NOT_EQUAL) reduce 3) ((T_IS_NOT_IDENTICAL) reduce 3) ((T_IS_SMALLER_OR_EQUAL) reduce 3) ((T_LOGICAL_AND) reduce 3) ((T_LOGICAL_OR) reduce 3) ((T_LOGICAL_XOR) reduce 3) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 3) ((T_OBJECT_OPERATOR) reduce 3) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 3) ((T_POW) reduce 3) ((T_SL) reduce 3) ((T_SPACESHIP) reduce 3) ((T_SR) reduce 3) (("[") reduce 3) (("]") reduce 3) (("^") reduce 3) (("{") reduce 3) (("|") reduce 3)) 7770 ((("%") reduce 12) (("(") reduce 12) (("*") reduce 12) (("+") reduce 12) ((",") reduce 12) (("-") reduce 12) ((".") reduce 12) (("/") reduce 12) (("<") reduce 12) ((">") reduce 12) (("?") reduce 12) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_BOOLEAN_AND) reduce 12) ((T_BOOLEAN_OR) reduce 12) ((T_COALESCE) reduce 12) ((T_INSTANCEOF) reduce 12) ((T_IS_EQUAL) reduce 12) ((T_IS_GREATER_OR_EQUAL) reduce 12) ((T_IS_IDENTICAL) reduce 12) ((T_IS_NOT_EQUAL) reduce 12) ((T_IS_NOT_IDENTICAL) reduce 12) ((T_IS_SMALLER_OR_EQUAL) reduce 12) ((T_LOGICAL_AND) reduce 12) ((T_LOGICAL_OR) reduce 12) ((T_LOGICAL_XOR) reduce 12) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 12) ((T_OBJECT_OPERATOR) reduce 12) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 12) ((T_POW) reduce 12) ((T_SL) reduce 12) ((T_SPACESHIP) reduce 12) ((T_SR) reduce 12) (("[") reduce 12) (("]") reduce 12) (("^") reduce 12) (("{") reduce 12) (("|") reduce 12)) 7771 ((("%") reduce 54) (("(") reduce 54) (("*") reduce 54) (("+") reduce 54) ((",") reduce 54) (("-") reduce 54) ((".") reduce 54) (("/") reduce 54) (("<") reduce 54) ((">") reduce 54) (("?") reduce 54) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_BOOLEAN_AND) reduce 54) ((T_BOOLEAN_OR) reduce 54) ((T_COALESCE) reduce 54) ((T_INSTANCEOF) reduce 54) ((T_IS_EQUAL) reduce 54) ((T_IS_GREATER_OR_EQUAL) reduce 54) ((T_IS_IDENTICAL) reduce 54) ((T_IS_NOT_EQUAL) reduce 54) ((T_IS_NOT_IDENTICAL) reduce 54) ((T_IS_SMALLER_OR_EQUAL) reduce 54) ((T_LOGICAL_AND) reduce 54) ((T_LOGICAL_OR) reduce 54) ((T_LOGICAL_XOR) reduce 54) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 54) ((T_OBJECT_OPERATOR) reduce 54) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 54) ((T_POW) reduce 54) ((T_SL) reduce 54) ((T_SPACESHIP) reduce 54) ((T_SR) reduce 54) (("[") reduce 54) (("]") reduce 54) (("^") reduce 54) (("{") reduce 54) (("|") reduce 54)) 7772 ((("%") reduce 65) (("(") reduce 65) (("*") reduce 65) (("+") reduce 65) ((",") reduce 65) (("-") reduce 65) ((".") reduce 65) (("/") reduce 65) (("<") reduce 65) ((">") reduce 65) (("?") reduce 65) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_BOOLEAN_AND) reduce 65) ((T_BOOLEAN_OR) reduce 65) ((T_COALESCE) reduce 65) ((T_INSTANCEOF) reduce 65) ((T_IS_EQUAL) reduce 65) ((T_IS_GREATER_OR_EQUAL) reduce 65) ((T_IS_IDENTICAL) reduce 65) ((T_IS_NOT_EQUAL) reduce 65) ((T_IS_NOT_IDENTICAL) reduce 65) ((T_IS_SMALLER_OR_EQUAL) reduce 65) ((T_LOGICAL_AND) reduce 65) ((T_LOGICAL_OR) reduce 65) ((T_LOGICAL_XOR) reduce 65) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 65) ((T_OBJECT_OPERATOR) reduce 65) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 65) ((T_POW) reduce 65) ((T_SL) reduce 65) ((T_SPACESHIP) reduce 65) ((T_SR) reduce 65) (("[") reduce 65) (("]") reduce 65) (("^") reduce 65) (("{") reduce 65) (("|") reduce 65)) 7773 ((("%") reduce 74) (("(") reduce 74) (("*") reduce 74) (("+") reduce 74) ((",") reduce 74) (("-") reduce 74) ((".") reduce 74) (("/") reduce 74) (("<") reduce 74) ((">") reduce 74) (("?") reduce 74) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_BOOLEAN_AND) reduce 74) ((T_BOOLEAN_OR) reduce 74) ((T_COALESCE) reduce 74) ((T_INSTANCEOF) reduce 74) ((T_IS_EQUAL) reduce 74) ((T_IS_GREATER_OR_EQUAL) reduce 74) ((T_IS_IDENTICAL) reduce 74) ((T_IS_NOT_EQUAL) reduce 74) ((T_IS_NOT_IDENTICAL) reduce 74) ((T_IS_SMALLER_OR_EQUAL) reduce 74) ((T_LOGICAL_AND) reduce 74) ((T_LOGICAL_OR) reduce 74) ((T_LOGICAL_XOR) reduce 74) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 74) ((T_OBJECT_OPERATOR) reduce 74) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 74) ((T_POW) reduce 74) ((T_SL) reduce 74) ((T_SPACESHIP) reduce 74) ((T_SR) reduce 74) (("[") reduce 74) (("]") reduce 74) (("^") reduce 74) (("{") reduce 74) (("|") reduce 74)) 7774 ((("%") reduce 30) (("(") reduce 30) (("*") reduce 30) (("+") reduce 30) ((",") reduce 30) (("-") reduce 30) ((".") reduce 30) (("/") reduce 30) (("<") reduce 30) ((">") reduce 30) (("?") reduce 30) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_BOOLEAN_AND) reduce 30) ((T_BOOLEAN_OR) reduce 30) ((T_COALESCE) reduce 30) ((T_INSTANCEOF) reduce 30) ((T_IS_EQUAL) reduce 30) ((T_IS_GREATER_OR_EQUAL) reduce 30) ((T_IS_IDENTICAL) reduce 30) ((T_IS_NOT_EQUAL) reduce 30) ((T_IS_NOT_IDENTICAL) reduce 30) ((T_IS_SMALLER_OR_EQUAL) reduce 30) ((T_LOGICAL_AND) reduce 30) ((T_LOGICAL_OR) reduce 30) ((T_LOGICAL_XOR) reduce 30) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 30) ((T_OBJECT_OPERATOR) reduce 30) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 30) ((T_POW) reduce 30) ((T_SL) reduce 30) ((T_SPACESHIP) reduce 30) ((T_SR) reduce 30) (("[") reduce 30) (("]") reduce 30) (("^") reduce 30) (("{") reduce 30) (("|") reduce 30)) 7775 ((("%") reduce 68) (("(") reduce 68) (("*") reduce 68) (("+") reduce 68) ((",") reduce 68) (("-") reduce 68) ((".") reduce 68) (("/") reduce 68) (("<") reduce 68) ((">") reduce 68) (("?") reduce 68) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_BOOLEAN_AND) reduce 68) ((T_BOOLEAN_OR) reduce 68) ((T_COALESCE) reduce 68) ((T_INSTANCEOF) reduce 68) ((T_IS_EQUAL) reduce 68) ((T_IS_GREATER_OR_EQUAL) reduce 68) ((T_IS_IDENTICAL) reduce 68) ((T_IS_NOT_EQUAL) reduce 68) ((T_IS_NOT_IDENTICAL) reduce 68) ((T_IS_SMALLER_OR_EQUAL) reduce 68) ((T_LOGICAL_AND) reduce 68) ((T_LOGICAL_OR) reduce 68) ((T_LOGICAL_XOR) reduce 68) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 68) ((T_OBJECT_OPERATOR) reduce 68) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 68) ((T_POW) reduce 68) ((T_SL) reduce 68) ((T_SPACESHIP) reduce 68) ((T_SR) reduce 68) (("[") reduce 68) (("]") reduce 68) (("^") reduce 68) (("{") reduce 68) (("|") reduce 68)) 7776 ((("%") reduce 21) (("(") reduce 21) (("*") reduce 21) (("+") reduce 21) ((",") reduce 21) (("-") reduce 21) ((".") reduce 21) (("/") reduce 21) (("<") reduce 21) ((">") reduce 21) (("?") reduce 21) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_BOOLEAN_AND) reduce 21) ((T_BOOLEAN_OR) reduce 21) ((T_COALESCE) reduce 21) ((T_INSTANCEOF) reduce 21) ((T_IS_EQUAL) reduce 21) ((T_IS_GREATER_OR_EQUAL) reduce 21) ((T_IS_IDENTICAL) reduce 21) ((T_IS_NOT_EQUAL) reduce 21) ((T_IS_NOT_IDENTICAL) reduce 21) ((T_IS_SMALLER_OR_EQUAL) reduce 21) ((T_LOGICAL_AND) reduce 21) ((T_LOGICAL_OR) reduce 21) ((T_LOGICAL_XOR) reduce 21) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 21) ((T_OBJECT_OPERATOR) reduce 21) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 21) ((T_POW) reduce 21) ((T_SL) reduce 21) ((T_SPACESHIP) reduce 21) ((T_SR) reduce 21) (("[") reduce 21) (("]") reduce 21) (("^") reduce 21) (("{") reduce 21) (("|") reduce 21)) 7777 ((("%") reduce 23) (("(") reduce 23) (("*") reduce 23) (("+") reduce 23) ((",") reduce 23) (("-") reduce 23) ((".") reduce 23) (("/") reduce 23) (("<") reduce 23) ((">") reduce 23) (("?") reduce 23) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_BOOLEAN_AND) reduce 23) ((T_BOOLEAN_OR) reduce 23) ((T_COALESCE) reduce 23) ((T_INSTANCEOF) reduce 23) ((T_IS_EQUAL) reduce 23) ((T_IS_GREATER_OR_EQUAL) reduce 23) ((T_IS_IDENTICAL) reduce 23) ((T_IS_NOT_EQUAL) reduce 23) ((T_IS_NOT_IDENTICAL) reduce 23) ((T_IS_SMALLER_OR_EQUAL) reduce 23) ((T_LOGICAL_AND) reduce 23) ((T_LOGICAL_OR) reduce 23) ((T_LOGICAL_XOR) reduce 23) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 23) ((T_OBJECT_OPERATOR) reduce 23) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 23) ((T_POW) reduce 23) ((T_SL) reduce 23) ((T_SPACESHIP) reduce 23) ((T_SR) reduce 23) (("[") reduce 23) (("]") reduce 23) (("^") reduce 23) (("{") reduce 23) (("|") reduce 23)) 7778 ((("%") reduce 41) (("(") reduce 41) (("*") reduce 41) (("+") reduce 41) ((",") reduce 41) (("-") reduce 41) ((".") reduce 41) (("/") reduce 41) (("<") reduce 41) ((">") reduce 41) (("?") reduce 41) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_BOOLEAN_AND) reduce 41) ((T_BOOLEAN_OR) reduce 41) ((T_COALESCE) reduce 41) ((T_INSTANCEOF) reduce 41) ((T_IS_EQUAL) reduce 41) ((T_IS_GREATER_OR_EQUAL) reduce 41) ((T_IS_IDENTICAL) reduce 41) ((T_IS_NOT_EQUAL) reduce 41) ((T_IS_NOT_IDENTICAL) reduce 41) ((T_IS_SMALLER_OR_EQUAL) reduce 41) ((T_LOGICAL_AND) reduce 41) ((T_LOGICAL_OR) reduce 41) ((T_LOGICAL_XOR) reduce 41) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 41) ((T_OBJECT_OPERATOR) reduce 41) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 41) ((T_POW) reduce 41) ((T_SL) reduce 41) ((T_SPACESHIP) reduce 41) ((T_SR) reduce 41) (("[") reduce 41) (("]") reduce 41) (("^") reduce 41) (("{") reduce 41) (("|") reduce 41)) 7779 ((("%") reduce 62) (("(") reduce 62) (("*") reduce 62) (("+") reduce 62) ((",") reduce 62) (("-") reduce 62) ((".") reduce 62) (("/") reduce 62) (("<") reduce 62) ((">") reduce 62) (("?") reduce 62) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_BOOLEAN_AND) reduce 62) ((T_BOOLEAN_OR) reduce 62) ((T_COALESCE) reduce 62) ((T_INSTANCEOF) reduce 62) ((T_IS_EQUAL) reduce 62) ((T_IS_GREATER_OR_EQUAL) reduce 62) ((T_IS_IDENTICAL) reduce 62) ((T_IS_NOT_EQUAL) reduce 62) ((T_IS_NOT_IDENTICAL) reduce 62) ((T_IS_SMALLER_OR_EQUAL) reduce 62) ((T_LOGICAL_AND) reduce 62) ((T_LOGICAL_OR) reduce 62) ((T_LOGICAL_XOR) reduce 62) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 62) ((T_OBJECT_OPERATOR) reduce 62) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 62) ((T_POW) reduce 62) ((T_SL) reduce 62) ((T_SPACESHIP) reduce 62) ((T_SR) reduce 62) (("[") reduce 62) (("]") reduce 62) (("^") reduce 62) (("{") reduce 62) (("|") reduce 62)) 7780 ((("%") reduce 34) (("(") reduce 34) (("*") reduce 34) (("+") reduce 34) ((",") reduce 34) (("-") reduce 34) ((".") reduce 34) (("/") reduce 34) (("<") reduce 34) ((">") reduce 34) (("?") reduce 34) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_BOOLEAN_AND) reduce 34) ((T_BOOLEAN_OR) reduce 34) ((T_COALESCE) reduce 34) ((T_INSTANCEOF) reduce 34) ((T_IS_EQUAL) reduce 34) ((T_IS_GREATER_OR_EQUAL) reduce 34) ((T_IS_IDENTICAL) reduce 34) ((T_IS_NOT_EQUAL) reduce 34) ((T_IS_NOT_IDENTICAL) reduce 34) ((T_IS_SMALLER_OR_EQUAL) reduce 34) ((T_LOGICAL_AND) reduce 34) ((T_LOGICAL_OR) reduce 34) ((T_LOGICAL_XOR) reduce 34) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 34) ((T_OBJECT_OPERATOR) reduce 34) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 34) ((T_POW) reduce 34) ((T_SL) reduce 34) ((T_SPACESHIP) reduce 34) ((T_SR) reduce 34) (("[") reduce 34) (("]") reduce 34) (("^") reduce 34) (("{") reduce 34) (("|") reduce 34)) 7781 ((("%") reduce 40) (("(") reduce 40) (("*") reduce 40) (("+") reduce 40) ((",") reduce 40) (("-") reduce 40) ((".") reduce 40) (("/") reduce 40) (("<") reduce 40) ((">") reduce 40) (("?") reduce 40) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_BOOLEAN_AND) reduce 40) ((T_BOOLEAN_OR) reduce 40) ((T_COALESCE) reduce 40) ((T_INSTANCEOF) reduce 40) ((T_IS_EQUAL) reduce 40) ((T_IS_GREATER_OR_EQUAL) reduce 40) ((T_IS_IDENTICAL) reduce 40) ((T_IS_NOT_EQUAL) reduce 40) ((T_IS_NOT_IDENTICAL) reduce 40) ((T_IS_SMALLER_OR_EQUAL) reduce 40) ((T_LOGICAL_AND) reduce 40) ((T_LOGICAL_OR) reduce 40) ((T_LOGICAL_XOR) reduce 40) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 40) ((T_OBJECT_OPERATOR) reduce 40) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 40) ((T_POW) reduce 40) ((T_SL) reduce 40) ((T_SPACESHIP) reduce 40) ((T_SR) reduce 40) (("[") reduce 40) (("]") reduce 40) (("^") reduce 40) (("{") reduce 40) (("|") reduce 40)) 7782 ((("%") reduce 13) (("(") reduce 13) (("*") reduce 13) (("+") reduce 13) ((",") reduce 13) (("-") reduce 13) ((".") reduce 13) (("/") reduce 13) (("<") reduce 13) ((">") reduce 13) (("?") reduce 13) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_BOOLEAN_AND) reduce 13) ((T_BOOLEAN_OR) reduce 13) ((T_COALESCE) reduce 13) ((T_INSTANCEOF) reduce 13) ((T_IS_EQUAL) reduce 13) ((T_IS_GREATER_OR_EQUAL) reduce 13) ((T_IS_IDENTICAL) reduce 13) ((T_IS_NOT_EQUAL) reduce 13) ((T_IS_NOT_IDENTICAL) reduce 13) ((T_IS_SMALLER_OR_EQUAL) reduce 13) ((T_LOGICAL_AND) reduce 13) ((T_LOGICAL_OR) reduce 13) ((T_LOGICAL_XOR) reduce 13) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 13) ((T_OBJECT_OPERATOR) reduce 13) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 13) ((T_POW) reduce 13) ((T_SL) reduce 13) ((T_SPACESHIP) reduce 13) ((T_SR) reduce 13) (("[") reduce 13) (("]") reduce 13) (("^") reduce 13) (("{") reduce 13) (("|") reduce 13)) 7783 ((("%") reduce 55) (("(") reduce 55) (("*") reduce 55) (("+") reduce 55) ((",") reduce 55) (("-") reduce 55) ((".") reduce 55) (("/") reduce 55) (("<") reduce 55) ((">") reduce 55) (("?") reduce 55) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_BOOLEAN_AND) reduce 55) ((T_BOOLEAN_OR) reduce 55) ((T_COALESCE) reduce 55) ((T_INSTANCEOF) reduce 55) ((T_IS_EQUAL) reduce 55) ((T_IS_GREATER_OR_EQUAL) reduce 55) ((T_IS_IDENTICAL) reduce 55) ((T_IS_NOT_EQUAL) reduce 55) ((T_IS_NOT_IDENTICAL) reduce 55) ((T_IS_SMALLER_OR_EQUAL) reduce 55) ((T_LOGICAL_AND) reduce 55) ((T_LOGICAL_OR) reduce 55) ((T_LOGICAL_XOR) reduce 55) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 55) ((T_OBJECT_OPERATOR) reduce 55) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 55) ((T_POW) reduce 55) ((T_SL) reduce 55) ((T_SPACESHIP) reduce 55) ((T_SR) reduce 55) (("[") reduce 55) (("]") reduce 55) (("^") reduce 55) (("{") reduce 55) (("|") reduce 55)) 7784 ((("%") reduce 1) (("(") reduce 1) (("*") reduce 1) (("+") reduce 1) ((",") reduce 1) (("-") reduce 1) ((".") reduce 1) (("/") reduce 1) (("<") reduce 1) ((">") reduce 1) (("?") reduce 1) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_BOOLEAN_AND) reduce 1) ((T_BOOLEAN_OR) reduce 1) ((T_COALESCE) reduce 1) ((T_INSTANCEOF) reduce 1) ((T_IS_EQUAL) reduce 1) ((T_IS_GREATER_OR_EQUAL) reduce 1) ((T_IS_IDENTICAL) reduce 1) ((T_IS_NOT_EQUAL) reduce 1) ((T_IS_NOT_IDENTICAL) reduce 1) ((T_IS_SMALLER_OR_EQUAL) reduce 1) ((T_LOGICAL_AND) reduce 1) ((T_LOGICAL_OR) reduce 1) ((T_LOGICAL_XOR) reduce 1) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 1) ((T_OBJECT_OPERATOR) reduce 1) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 1) ((T_POW) reduce 1) ((T_SL) reduce 1) ((T_SPACESHIP) reduce 1) ((T_SR) reduce 1) (("[") reduce 1) (("]") reduce 1) (("^") reduce 1) (("{") reduce 1) (("|") reduce 1)) 7785 ((("%") reduce 2) (("(") reduce 2) (("*") reduce 2) (("+") reduce 2) ((",") reduce 2) (("-") reduce 2) ((".") reduce 2) (("/") reduce 2) (("<") reduce 2) ((">") reduce 2) (("?") reduce 2) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_BOOLEAN_AND) reduce 2) ((T_BOOLEAN_OR) reduce 2) ((T_COALESCE) reduce 2) ((T_INSTANCEOF) reduce 2) ((T_IS_EQUAL) reduce 2) ((T_IS_GREATER_OR_EQUAL) reduce 2) ((T_IS_IDENTICAL) reduce 2) ((T_IS_NOT_EQUAL) reduce 2) ((T_IS_NOT_IDENTICAL) reduce 2) ((T_IS_SMALLER_OR_EQUAL) reduce 2) ((T_LOGICAL_AND) reduce 2) ((T_LOGICAL_OR) reduce 2) ((T_LOGICAL_XOR) reduce 2) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 2) ((T_OBJECT_OPERATOR) reduce 2) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 2) ((T_POW) reduce 2) ((T_SL) reduce 2) ((T_SPACESHIP) reduce 2) ((T_SR) reduce 2) (("[") reduce 2) (("]") reduce 2) (("^") reduce 2) (("{") reduce 2) (("|") reduce 2)) 7786 ((("%") reduce 9) (("(") reduce 9) (("*") reduce 9) (("+") reduce 9) ((",") reduce 9) (("-") reduce 9) ((".") reduce 9) (("/") reduce 9) (("<") reduce 9) ((">") reduce 9) (("?") reduce 9) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_BOOLEAN_AND) reduce 9) ((T_BOOLEAN_OR) reduce 9) ((T_COALESCE) reduce 9) ((T_INSTANCEOF) reduce 9) ((T_IS_EQUAL) reduce 9) ((T_IS_GREATER_OR_EQUAL) reduce 9) ((T_IS_IDENTICAL) reduce 9) ((T_IS_NOT_EQUAL) reduce 9) ((T_IS_NOT_IDENTICAL) reduce 9) ((T_IS_SMALLER_OR_EQUAL) reduce 9) ((T_LOGICAL_AND) reduce 9) ((T_LOGICAL_OR) reduce 9) ((T_LOGICAL_XOR) reduce 9) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 9) ((T_OBJECT_OPERATOR) reduce 9) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 9) ((T_POW) reduce 9) ((T_SL) reduce 9) ((T_SPACESHIP) reduce 9) ((T_SR) reduce 9) (("[") reduce 9) (("]") reduce 9) (("^") reduce 9) (("{") reduce 9) (("|") reduce 9)) 7787 ((("%") reduce 33) (("(") reduce 33) (("*") reduce 33) (("+") reduce 33) ((",") reduce 33) (("-") reduce 33) ((".") reduce 33) (("/") reduce 33) (("<") reduce 33) ((">") reduce 33) (("?") reduce 33) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_BOOLEAN_AND) reduce 33) ((T_BOOLEAN_OR) reduce 33) ((T_COALESCE) reduce 33) ((T_INSTANCEOF) reduce 33) ((T_IS_EQUAL) reduce 33) ((T_IS_GREATER_OR_EQUAL) reduce 33) ((T_IS_IDENTICAL) reduce 33) ((T_IS_NOT_EQUAL) reduce 33) ((T_IS_NOT_IDENTICAL) reduce 33) ((T_IS_SMALLER_OR_EQUAL) reduce 33) ((T_LOGICAL_AND) reduce 33) ((T_LOGICAL_OR) reduce 33) ((T_LOGICAL_XOR) reduce 33) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 33) ((T_OBJECT_OPERATOR) reduce 33) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 33) ((T_POW) reduce 33) ((T_SL) reduce 33) ((T_SPACESHIP) reduce 33) ((T_SR) reduce 33) (("[") reduce 33) (("]") reduce 33) (("^") reduce 33) (("{") reduce 33) (("|") reduce 33)) 7788 ((("%") reduce 58) (("(") reduce 58) (("*") reduce 58) (("+") reduce 58) ((",") reduce 58) (("-") reduce 58) ((".") reduce 58) (("/") reduce 58) (("<") reduce 58) ((">") reduce 58) (("?") reduce 58) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_BOOLEAN_AND) reduce 58) ((T_BOOLEAN_OR) reduce 58) ((T_COALESCE) reduce 58) ((T_INSTANCEOF) reduce 58) ((T_IS_EQUAL) reduce 58) ((T_IS_GREATER_OR_EQUAL) reduce 58) ((T_IS_IDENTICAL) reduce 58) ((T_IS_NOT_EQUAL) reduce 58) ((T_IS_NOT_IDENTICAL) reduce 58) ((T_IS_SMALLER_OR_EQUAL) reduce 58) ((T_LOGICAL_AND) reduce 58) ((T_LOGICAL_OR) reduce 58) ((T_LOGICAL_XOR) reduce 58) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 58) ((T_OBJECT_OPERATOR) reduce 58) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 58) ((T_POW) reduce 58) ((T_SL) reduce 58) ((T_SPACESHIP) reduce 58) ((T_SR) reduce 58) (("[") reduce 58) (("]") reduce 58) (("^") reduce 58) (("{") reduce 58) (("|") reduce 58)) 7789 ((("%") reduce 37) (("(") reduce 37) (("*") reduce 37) (("+") reduce 37) ((",") reduce 37) (("-") reduce 37) ((".") reduce 37) (("/") reduce 37) (("<") reduce 37) ((">") reduce 37) (("?") reduce 37) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_BOOLEAN_AND) reduce 37) ((T_BOOLEAN_OR) reduce 37) ((T_COALESCE) reduce 37) ((T_INSTANCEOF) reduce 37) ((T_IS_EQUAL) reduce 37) ((T_IS_GREATER_OR_EQUAL) reduce 37) ((T_IS_IDENTICAL) reduce 37) ((T_IS_NOT_EQUAL) reduce 37) ((T_IS_NOT_IDENTICAL) reduce 37) ((T_IS_SMALLER_OR_EQUAL) reduce 37) ((T_LOGICAL_AND) reduce 37) ((T_LOGICAL_OR) reduce 37) ((T_LOGICAL_XOR) reduce 37) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 37) ((T_OBJECT_OPERATOR) reduce 37) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 37) ((T_POW) reduce 37) ((T_SL) reduce 37) ((T_SPACESHIP) reduce 37) ((T_SR) reduce 37) (("[") reduce 37) (("]") reduce 37) (("^") reduce 37) (("{") reduce 37) (("|") reduce 37)) 7790 ((("%") reduce 64) (("(") reduce 64) (("*") reduce 64) (("+") reduce 64) ((",") reduce 64) (("-") reduce 64) ((".") reduce 64) (("/") reduce 64) (("<") reduce 64) ((">") reduce 64) (("?") reduce 64) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_BOOLEAN_AND) reduce 64) ((T_BOOLEAN_OR) reduce 64) ((T_COALESCE) reduce 64) ((T_INSTANCEOF) reduce 64) ((T_IS_EQUAL) reduce 64) ((T_IS_GREATER_OR_EQUAL) reduce 64) ((T_IS_IDENTICAL) reduce 64) ((T_IS_NOT_EQUAL) reduce 64) ((T_IS_NOT_IDENTICAL) reduce 64) ((T_IS_SMALLER_OR_EQUAL) reduce 64) ((T_LOGICAL_AND) reduce 64) ((T_LOGICAL_OR) reduce 64) ((T_LOGICAL_XOR) reduce 64) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 64) ((T_OBJECT_OPERATOR) reduce 64) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 64) ((T_POW) reduce 64) ((T_SL) reduce 64) ((T_SPACESHIP) reduce 64) ((T_SR) reduce 64) (("[") reduce 64) (("]") reduce 64) (("^") reduce 64) (("{") reduce 64) (("|") reduce 64)) 7791 ((("%") reduce 46) (("(") reduce 46) (("*") reduce 46) (("+") reduce 46) ((",") reduce 46) (("-") reduce 46) ((".") reduce 46) (("/") reduce 46) (("<") reduce 46) ((">") reduce 46) (("?") reduce 46) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_BOOLEAN_AND) reduce 46) ((T_BOOLEAN_OR) reduce 46) ((T_COALESCE) reduce 46) ((T_INSTANCEOF) reduce 46) ((T_IS_EQUAL) reduce 46) ((T_IS_GREATER_OR_EQUAL) reduce 46) ((T_IS_IDENTICAL) reduce 46) ((T_IS_NOT_EQUAL) reduce 46) ((T_IS_NOT_IDENTICAL) reduce 46) ((T_IS_SMALLER_OR_EQUAL) reduce 46) ((T_LOGICAL_AND) reduce 46) ((T_LOGICAL_OR) reduce 46) ((T_LOGICAL_XOR) reduce 46) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 46) ((T_OBJECT_OPERATOR) reduce 46) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 46) ((T_POW) reduce 46) ((T_SL) reduce 46) ((T_SPACESHIP) reduce 46) ((T_SR) reduce 46) (("[") reduce 46) (("]") reduce 46) (("^") reduce 46) (("{") reduce 46) (("|") reduce 46)) 7792 ((("%") reduce 8) (("(") reduce 8) (("*") reduce 8) (("+") reduce 8) ((",") reduce 8) (("-") reduce 8) ((".") reduce 8) (("/") reduce 8) (("<") reduce 8) ((">") reduce 8) (("?") reduce 8) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_BOOLEAN_AND) reduce 8) ((T_BOOLEAN_OR) reduce 8) ((T_COALESCE) reduce 8) ((T_INSTANCEOF) reduce 8) ((T_IS_EQUAL) reduce 8) ((T_IS_GREATER_OR_EQUAL) reduce 8) ((T_IS_IDENTICAL) reduce 8) ((T_IS_NOT_EQUAL) reduce 8) ((T_IS_NOT_IDENTICAL) reduce 8) ((T_IS_SMALLER_OR_EQUAL) reduce 8) ((T_LOGICAL_AND) reduce 8) ((T_LOGICAL_OR) reduce 8) ((T_LOGICAL_XOR) reduce 8) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 8) ((T_OBJECT_OPERATOR) reduce 8) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 8) ((T_POW) reduce 8) ((T_SL) reduce 8) ((T_SPACESHIP) reduce 8) ((T_SR) reduce 8) (("[") reduce 8) (("]") reduce 8) (("^") reduce 8) (("{") reduce 8) (("|") reduce 8)) 7793 ((("%") reduce 6) (("(") reduce 6) (("*") reduce 6) (("+") reduce 6) ((",") reduce 6) (("-") reduce 6) ((".") reduce 6) (("/") reduce 6) (("<") reduce 6) ((">") reduce 6) (("?") reduce 6) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_BOOLEAN_AND) reduce 6) ((T_BOOLEAN_OR) reduce 6) ((T_COALESCE) reduce 6) ((T_INSTANCEOF) reduce 6) ((T_IS_EQUAL) reduce 6) ((T_IS_GREATER_OR_EQUAL) reduce 6) ((T_IS_IDENTICAL) reduce 6) ((T_IS_NOT_EQUAL) reduce 6) ((T_IS_NOT_IDENTICAL) reduce 6) ((T_IS_SMALLER_OR_EQUAL) reduce 6) ((T_LOGICAL_AND) reduce 6) ((T_LOGICAL_OR) reduce 6) ((T_LOGICAL_XOR) reduce 6) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 6) ((T_OBJECT_OPERATOR) reduce 6) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 6) ((T_POW) reduce 6) ((T_SL) reduce 6) ((T_SPACESHIP) reduce 6) ((T_SR) reduce 6) (("[") reduce 6) (("]") reduce 6) (("^") reduce 6) (("{") reduce 6) (("|") reduce 6)) 7794 ((("%") reduce 7) (("(") reduce 7) (("*") reduce 7) (("+") reduce 7) ((",") reduce 7) (("-") reduce 7) ((".") reduce 7) (("/") reduce 7) (("<") reduce 7) ((">") reduce 7) (("?") reduce 7) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_BOOLEAN_AND) reduce 7) ((T_BOOLEAN_OR) reduce 7) ((T_COALESCE) reduce 7) ((T_INSTANCEOF) reduce 7) ((T_IS_EQUAL) reduce 7) ((T_IS_GREATER_OR_EQUAL) reduce 7) ((T_IS_IDENTICAL) reduce 7) ((T_IS_NOT_EQUAL) reduce 7) ((T_IS_NOT_IDENTICAL) reduce 7) ((T_IS_SMALLER_OR_EQUAL) reduce 7) ((T_LOGICAL_AND) reduce 7) ((T_LOGICAL_OR) reduce 7) ((T_LOGICAL_XOR) reduce 7) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 7) ((T_OBJECT_OPERATOR) reduce 7) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 7) ((T_POW) reduce 7) ((T_SL) reduce 7) ((T_SPACESHIP) reduce 7) ((T_SR) reduce 7) (("[") reduce 7) (("]") reduce 7) (("^") reduce 7) (("{") reduce 7) (("|") reduce 7)) 7795 ((("%") reduce 69) (("(") reduce 69) (("*") reduce 69) (("+") reduce 69) ((",") reduce 69) (("-") reduce 69) ((".") reduce 69) (("/") reduce 69) (("<") reduce 69) ((">") reduce 69) (("?") reduce 69) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_BOOLEAN_AND) reduce 69) ((T_BOOLEAN_OR) reduce 69) ((T_COALESCE) reduce 69) ((T_INSTANCEOF) reduce 69) ((T_IS_EQUAL) reduce 69) ((T_IS_GREATER_OR_EQUAL) reduce 69) ((T_IS_IDENTICAL) reduce 69) ((T_IS_NOT_EQUAL) reduce 69) ((T_IS_NOT_IDENTICAL) reduce 69) ((T_IS_SMALLER_OR_EQUAL) reduce 69) ((T_LOGICAL_AND) reduce 69) ((T_LOGICAL_OR) reduce 69) ((T_LOGICAL_XOR) reduce 69) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 69) ((T_OBJECT_OPERATOR) reduce 69) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 69) ((T_POW) reduce 69) ((T_SL) reduce 69) ((T_SPACESHIP) reduce 69) ((T_SR) reduce 69) (("[") reduce 69) (("]") reduce 69) (("^") reduce 69) (("{") reduce 69) (("|") reduce 69)) 7796 ((("%") reduce 63) (("(") reduce 63) (("*") reduce 63) (("+") reduce 63) ((",") reduce 63) (("-") reduce 63) ((".") reduce 63) (("/") reduce 63) (("<") reduce 63) ((">") reduce 63) (("?") reduce 63) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_BOOLEAN_AND) reduce 63) ((T_BOOLEAN_OR) reduce 63) ((T_COALESCE) reduce 63) ((T_INSTANCEOF) reduce 63) ((T_IS_EQUAL) reduce 63) ((T_IS_GREATER_OR_EQUAL) reduce 63) ((T_IS_IDENTICAL) reduce 63) ((T_IS_NOT_EQUAL) reduce 63) ((T_IS_NOT_IDENTICAL) reduce 63) ((T_IS_SMALLER_OR_EQUAL) reduce 63) ((T_LOGICAL_AND) reduce 63) ((T_LOGICAL_OR) reduce 63) ((T_LOGICAL_XOR) reduce 63) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 63) ((T_OBJECT_OPERATOR) reduce 63) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 63) ((T_POW) reduce 63) ((T_SL) reduce 63) ((T_SPACESHIP) reduce 63) ((T_SR) reduce 63) (("[") reduce 63) (("]") reduce 63) (("^") reduce 63) (("{") reduce 63) (("|") reduce 63)) 7797 ((("%") reduce 56) (("(") reduce 56) (("*") reduce 56) (("+") reduce 56) ((",") reduce 56) (("-") reduce 56) ((".") reduce 56) (("/") reduce 56) (("<") reduce 56) ((">") reduce 56) (("?") reduce 56) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_BOOLEAN_AND) reduce 56) ((T_BOOLEAN_OR) reduce 56) ((T_COALESCE) reduce 56) ((T_INSTANCEOF) reduce 56) ((T_IS_EQUAL) reduce 56) ((T_IS_GREATER_OR_EQUAL) reduce 56) ((T_IS_IDENTICAL) reduce 56) ((T_IS_NOT_EQUAL) reduce 56) ((T_IS_NOT_IDENTICAL) reduce 56) ((T_IS_SMALLER_OR_EQUAL) reduce 56) ((T_LOGICAL_AND) reduce 56) ((T_LOGICAL_OR) reduce 56) ((T_LOGICAL_XOR) reduce 56) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 56) ((T_OBJECT_OPERATOR) reduce 56) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 56) ((T_POW) reduce 56) ((T_SL) reduce 56) ((T_SPACESHIP) reduce 56) ((T_SR) reduce 56) (("[") reduce 56) (("]") reduce 56) (("^") reduce 56) (("{") reduce 56) (("|") reduce 56)) 7798 ((("%") reduce 10) (("(") reduce 10) (("*") reduce 10) (("+") reduce 10) ((",") reduce 10) (("-") reduce 10) ((".") reduce 10) (("/") reduce 10) (("<") reduce 10) ((">") reduce 10) (("?") reduce 10) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_BOOLEAN_AND) reduce 10) ((T_BOOLEAN_OR) reduce 10) ((T_COALESCE) reduce 10) ((T_INSTANCEOF) reduce 10) ((T_IS_EQUAL) reduce 10) ((T_IS_GREATER_OR_EQUAL) reduce 10) ((T_IS_IDENTICAL) reduce 10) ((T_IS_NOT_EQUAL) reduce 10) ((T_IS_NOT_IDENTICAL) reduce 10) ((T_IS_SMALLER_OR_EQUAL) reduce 10) ((T_LOGICAL_AND) reduce 10) ((T_LOGICAL_OR) reduce 10) ((T_LOGICAL_XOR) reduce 10) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 10) ((T_OBJECT_OPERATOR) reduce 10) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 10) ((T_POW) reduce 10) ((T_SL) reduce 10) ((T_SPACESHIP) reduce 10) ((T_SR) reduce 10) (("[") reduce 10) (("]") reduce 10) (("^") reduce 10) (("{") reduce 10) (("|") reduce 10)) 7799 ((("%") reduce 67) (("(") reduce 67) (("*") reduce 67) (("+") reduce 67) ((",") reduce 67) (("-") reduce 67) ((".") reduce 67) (("/") reduce 67) (("<") reduce 67) ((">") reduce 67) (("?") reduce 67) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_BOOLEAN_AND) reduce 67) ((T_BOOLEAN_OR) reduce 67) ((T_COALESCE) reduce 67) ((T_INSTANCEOF) reduce 67) ((T_IS_EQUAL) reduce 67) ((T_IS_GREATER_OR_EQUAL) reduce 67) ((T_IS_IDENTICAL) reduce 67) ((T_IS_NOT_EQUAL) reduce 67) ((T_IS_NOT_IDENTICAL) reduce 67) ((T_IS_SMALLER_OR_EQUAL) reduce 67) ((T_LOGICAL_AND) reduce 67) ((T_LOGICAL_OR) reduce 67) ((T_LOGICAL_XOR) reduce 67) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 67) ((T_OBJECT_OPERATOR) reduce 67) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 67) ((T_POW) reduce 67) ((T_SL) reduce 67) ((T_SPACESHIP) reduce 67) ((T_SR) reduce 67) (("[") reduce 67) (("]") reduce 67) (("^") reduce 67) (("{") reduce 67) (("|") reduce 67)) 7800 ((("%") reduce 44) (("(") reduce 44) (("*") reduce 44) (("+") reduce 44) ((",") reduce 44) (("-") reduce 44) ((".") reduce 44) (("/") reduce 44) (("<") reduce 44) ((">") reduce 44) (("?") reduce 44) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_BOOLEAN_AND) reduce 44) ((T_BOOLEAN_OR) reduce 44) ((T_COALESCE) reduce 44) ((T_INSTANCEOF) reduce 44) ((T_IS_EQUAL) reduce 44) ((T_IS_GREATER_OR_EQUAL) reduce 44) ((T_IS_IDENTICAL) reduce 44) ((T_IS_NOT_EQUAL) reduce 44) ((T_IS_NOT_IDENTICAL) reduce 44) ((T_IS_SMALLER_OR_EQUAL) reduce 44) ((T_LOGICAL_AND) reduce 44) ((T_LOGICAL_OR) reduce 44) ((T_LOGICAL_XOR) reduce 44) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 44) ((T_OBJECT_OPERATOR) reduce 44) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 44) ((T_POW) reduce 44) ((T_SL) reduce 44) ((T_SPACESHIP) reduce 44) ((T_SR) reduce 44) (("[") reduce 44) (("]") reduce 44) (("^") reduce 44) (("{") reduce 44) (("|") reduce 44)) 7801 ((("%") reduce 75) (("(") reduce 75) (("*") reduce 75) (("+") reduce 75) ((",") reduce 75) (("-") reduce 75) ((".") reduce 75) (("/") reduce 75) (("<") reduce 75) ((">") reduce 75) (("?") reduce 75) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_BOOLEAN_AND) reduce 75) ((T_BOOLEAN_OR) reduce 75) ((T_COALESCE) reduce 75) ((T_INSTANCEOF) reduce 75) ((T_IS_EQUAL) reduce 75) ((T_IS_GREATER_OR_EQUAL) reduce 75) ((T_IS_IDENTICAL) reduce 75) ((T_IS_NOT_EQUAL) reduce 75) ((T_IS_NOT_IDENTICAL) reduce 75) ((T_IS_SMALLER_OR_EQUAL) reduce 75) ((T_LOGICAL_AND) reduce 75) ((T_LOGICAL_OR) reduce 75) ((T_LOGICAL_XOR) reduce 75) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 75) ((T_OBJECT_OPERATOR) reduce 75) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 75) ((T_POW) reduce 75) ((T_SL) reduce 75) ((T_SPACESHIP) reduce 75) ((T_SR) reduce 75) (("[") reduce 75) (("]") reduce 75) (("^") reduce 75) (("{") reduce 75) (("|") reduce 75)) 7802 ((("%") reduce 76) (("(") reduce 76) (("*") reduce 76) (("+") reduce 76) ((",") reduce 76) (("-") reduce 76) ((".") reduce 76) (("/") reduce 76) (("<") reduce 76) ((">") reduce 76) (("?") reduce 76) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_BOOLEAN_AND) reduce 76) ((T_BOOLEAN_OR) reduce 76) ((T_COALESCE) reduce 76) ((T_INSTANCEOF) reduce 76) ((T_IS_EQUAL) reduce 76) ((T_IS_GREATER_OR_EQUAL) reduce 76) ((T_IS_IDENTICAL) reduce 76) ((T_IS_NOT_EQUAL) reduce 76) ((T_IS_NOT_IDENTICAL) reduce 76) ((T_IS_SMALLER_OR_EQUAL) reduce 76) ((T_LOGICAL_AND) reduce 76) ((T_LOGICAL_OR) reduce 76) ((T_LOGICAL_XOR) reduce 76) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 76) ((T_OBJECT_OPERATOR) reduce 76) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 76) ((T_POW) reduce 76) ((T_SL) reduce 76) ((T_SPACESHIP) reduce 76) ((T_SR) reduce 76) (("[") reduce 76) (("]") reduce 76) (("^") reduce 76) (("{") reduce 76) (("|") reduce 76)) 7803 ((("%") reduce 77) (("(") reduce 77) (("*") reduce 77) (("+") reduce 77) ((",") reduce 77) (("-") reduce 77) ((".") reduce 77) (("/") reduce 77) (("<") reduce 77) ((">") reduce 77) (("?") reduce 77) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_BOOLEAN_AND) reduce 77) ((T_BOOLEAN_OR) reduce 77) ((T_COALESCE) reduce 77) ((T_INSTANCEOF) reduce 77) ((T_IS_EQUAL) reduce 77) ((T_IS_GREATER_OR_EQUAL) reduce 77) ((T_IS_IDENTICAL) reduce 77) ((T_IS_NOT_EQUAL) reduce 77) ((T_IS_NOT_IDENTICAL) reduce 77) ((T_IS_SMALLER_OR_EQUAL) reduce 77) ((T_LOGICAL_AND) reduce 77) ((T_LOGICAL_OR) reduce 77) ((T_LOGICAL_XOR) reduce 77) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 77) ((T_OBJECT_OPERATOR) reduce 77) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 77) ((T_POW) reduce 77) ((T_SL) reduce 77) ((T_SPACESHIP) reduce 77) ((T_SR) reduce 77) (("[") reduce 77) (("]") reduce 77) (("^") reduce 77) (("{") reduce 77) (("|") reduce 77)) 7804 ((("%") reduce 78) (("(") reduce 78) (("*") reduce 78) (("+") reduce 78) ((",") reduce 78) (("-") reduce 78) ((".") reduce 78) (("/") reduce 78) (("<") reduce 78) ((">") reduce 78) (("?") reduce 78) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_BOOLEAN_AND) reduce 78) ((T_BOOLEAN_OR) reduce 78) ((T_COALESCE) reduce 78) ((T_INSTANCEOF) reduce 78) ((T_IS_EQUAL) reduce 78) ((T_IS_GREATER_OR_EQUAL) reduce 78) ((T_IS_IDENTICAL) reduce 78) ((T_IS_NOT_EQUAL) reduce 78) ((T_IS_NOT_IDENTICAL) reduce 78) ((T_IS_SMALLER_OR_EQUAL) reduce 78) ((T_LOGICAL_AND) reduce 78) ((T_LOGICAL_OR) reduce 78) ((T_LOGICAL_XOR) reduce 78) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 78) ((T_OBJECT_OPERATOR) reduce 78) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 78) ((T_POW) reduce 78) ((T_SL) reduce 78) ((T_SPACESHIP) reduce 78) ((T_SR) reduce 78) (("[") reduce 78) (("]") reduce 78) (("^") reduce 78) (("{") reduce 78) (("|") reduce 78)) 7805 ((("%") reduce 4) (("(") reduce 4) (("*") reduce 4) (("+") reduce 4) ((",") reduce 4) (("-") reduce 4) ((".") reduce 4) (("/") reduce 4) (("<") reduce 4) ((">") reduce 4) (("?") reduce 4) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_BOOLEAN_AND) reduce 4) ((T_BOOLEAN_OR) reduce 4) ((T_COALESCE) reduce 4) ((T_INSTANCEOF) reduce 4) ((T_IS_EQUAL) reduce 4) ((T_IS_GREATER_OR_EQUAL) reduce 4) ((T_IS_IDENTICAL) reduce 4) ((T_IS_NOT_EQUAL) reduce 4) ((T_IS_NOT_IDENTICAL) reduce 4) ((T_IS_SMALLER_OR_EQUAL) reduce 4) ((T_LOGICAL_AND) reduce 4) ((T_LOGICAL_OR) reduce 4) ((T_LOGICAL_XOR) reduce 4) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 4) ((T_OBJECT_OPERATOR) reduce 4) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 4) ((T_POW) reduce 4) ((T_SL) reduce 4) ((T_SPACESHIP) reduce 4) ((T_SR) reduce 4) (("[") reduce 4) (("]") reduce 4) (("^") reduce 4) (("{") reduce 4) (("|") reduce 4)) 7806 ((("%") reduce 5) (("(") reduce 5) (("*") reduce 5) (("+") reduce 5) ((",") reduce 5) (("-") reduce 5) ((".") reduce 5) (("/") reduce 5) (("<") reduce 5) ((">") reduce 5) (("?") reduce 5) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_BOOLEAN_AND) reduce 5) ((T_BOOLEAN_OR) reduce 5) ((T_COALESCE) reduce 5) ((T_INSTANCEOF) reduce 5) ((T_IS_EQUAL) reduce 5) ((T_IS_GREATER_OR_EQUAL) reduce 5) ((T_IS_IDENTICAL) reduce 5) ((T_IS_NOT_EQUAL) reduce 5) ((T_IS_NOT_IDENTICAL) reduce 5) ((T_IS_SMALLER_OR_EQUAL) reduce 5) ((T_LOGICAL_AND) reduce 5) ((T_LOGICAL_OR) reduce 5) ((T_LOGICAL_XOR) reduce 5) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 5) ((T_OBJECT_OPERATOR) reduce 5) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 5) ((T_POW) reduce 5) ((T_SL) reduce 5) ((T_SPACESHIP) reduce 5) ((T_SR) reduce 5) (("[") reduce 5) (("]") reduce 5) (("^") reduce 5) (("{") reduce 5) (("|") reduce 5)) 7807 ((("%") reduce 43) (("(") reduce 43) (("*") reduce 43) (("+") reduce 43) ((",") reduce 43) (("-") reduce 43) ((".") reduce 43) (("/") reduce 43) (("<") reduce 43) ((">") reduce 43) (("?") reduce 43) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_BOOLEAN_AND) reduce 43) ((T_BOOLEAN_OR) reduce 43) ((T_COALESCE) reduce 43) ((T_INSTANCEOF) reduce 43) ((T_IS_EQUAL) reduce 43) ((T_IS_GREATER_OR_EQUAL) reduce 43) ((T_IS_IDENTICAL) reduce 43) ((T_IS_NOT_EQUAL) reduce 43) ((T_IS_NOT_IDENTICAL) reduce 43) ((T_IS_SMALLER_OR_EQUAL) reduce 43) ((T_LOGICAL_AND) reduce 43) ((T_LOGICAL_OR) reduce 43) ((T_LOGICAL_XOR) reduce 43) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 43) ((T_OBJECT_OPERATOR) reduce 43) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 43) ((T_POW) reduce 43) ((T_SL) reduce 43) ((T_SPACESHIP) reduce 43) ((T_SR) reduce 43) (("[") reduce 43) (("]") reduce 43) (("^") reduce 43) (("{") reduce 43) (("|") reduce 43)) 7808 ((("%") reduce 72) (("(") reduce 72) (("*") reduce 72) (("+") reduce 72) ((",") reduce 72) (("-") reduce 72) ((".") reduce 72) (("/") reduce 72) (("<") reduce 72) ((">") reduce 72) (("?") reduce 72) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_BOOLEAN_AND) reduce 72) ((T_BOOLEAN_OR) reduce 72) ((T_COALESCE) reduce 72) ((T_INSTANCEOF) reduce 72) ((T_IS_EQUAL) reduce 72) ((T_IS_GREATER_OR_EQUAL) reduce 72) ((T_IS_IDENTICAL) reduce 72) ((T_IS_NOT_EQUAL) reduce 72) ((T_IS_NOT_IDENTICAL) reduce 72) ((T_IS_SMALLER_OR_EQUAL) reduce 72) ((T_LOGICAL_AND) reduce 72) ((T_LOGICAL_OR) reduce 72) ((T_LOGICAL_XOR) reduce 72) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 72) ((T_OBJECT_OPERATOR) reduce 72) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 72) ((T_POW) reduce 72) ((T_SL) reduce 72) ((T_SPACESHIP) reduce 72) ((T_SR) reduce 72) (("[") reduce 72) (("]") reduce 72) (("^") reduce 72) (("{") reduce 72) (("|") reduce 72)) 7809 ((("%") reduce 81) (("(") reduce 81) (("*") reduce 81) (("+") reduce 81) ((",") reduce 81) (("-") reduce 81) ((".") reduce 81) (("/") reduce 81) (("<") reduce 81) ((">") reduce 81) (("?") reduce 81) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_BOOLEAN_AND) reduce 81) ((T_BOOLEAN_OR) reduce 81) ((T_COALESCE) reduce 81) ((T_INSTANCEOF) reduce 81) ((T_IS_EQUAL) reduce 81) ((T_IS_GREATER_OR_EQUAL) reduce 81) ((T_IS_IDENTICAL) reduce 81) ((T_IS_NOT_EQUAL) reduce 81) ((T_IS_NOT_IDENTICAL) reduce 81) ((T_IS_SMALLER_OR_EQUAL) reduce 81) ((T_LOGICAL_AND) reduce 81) ((T_LOGICAL_OR) reduce 81) ((T_LOGICAL_XOR) reduce 81) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 81) ((T_OBJECT_OPERATOR) reduce 81) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 81) ((T_POW) reduce 81) ((T_SL) reduce 81) ((T_SPACESHIP) reduce 81) ((T_SR) reduce 81) (("[") reduce 81) (("]") reduce 81) (("^") reduce 81) (("{") reduce 81) (("|") reduce 81)) 7810 ((("%") reduce 47) (("(") reduce 47) (("*") reduce 47) (("+") reduce 47) ((",") reduce 47) (("-") reduce 47) ((".") reduce 47) (("/") reduce 47) (("<") reduce 47) ((">") reduce 47) (("?") reduce 47) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_BOOLEAN_AND) reduce 47) ((T_BOOLEAN_OR) reduce 47) ((T_COALESCE) reduce 47) ((T_INSTANCEOF) reduce 47) ((T_IS_EQUAL) reduce 47) ((T_IS_GREATER_OR_EQUAL) reduce 47) ((T_IS_IDENTICAL) reduce 47) ((T_IS_NOT_EQUAL) reduce 47) ((T_IS_NOT_IDENTICAL) reduce 47) ((T_IS_SMALLER_OR_EQUAL) reduce 47) ((T_LOGICAL_AND) reduce 47) ((T_LOGICAL_OR) reduce 47) ((T_LOGICAL_XOR) reduce 47) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 47) ((T_OBJECT_OPERATOR) reduce 47) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 47) ((T_POW) reduce 47) ((T_SL) reduce 47) ((T_SPACESHIP) reduce 47) ((T_SR) reduce 47) (("[") reduce 47) (("]") reduce 47) (("^") reduce 47) (("{") reduce 47) (("|") reduce 47)) 7811 ((("%") reduce 31) (("(") reduce 31) (("*") reduce 31) (("+") reduce 31) ((",") reduce 31) (("-") reduce 31) ((".") reduce 31) (("/") reduce 31) (("<") reduce 31) ((">") reduce 31) (("?") reduce 31) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_BOOLEAN_AND) reduce 31) ((T_BOOLEAN_OR) reduce 31) ((T_COALESCE) reduce 31) ((T_INSTANCEOF) reduce 31) ((T_IS_EQUAL) reduce 31) ((T_IS_GREATER_OR_EQUAL) reduce 31) ((T_IS_IDENTICAL) reduce 31) ((T_IS_NOT_EQUAL) reduce 31) ((T_IS_NOT_IDENTICAL) reduce 31) ((T_IS_SMALLER_OR_EQUAL) reduce 31) ((T_LOGICAL_AND) reduce 31) ((T_LOGICAL_OR) reduce 31) ((T_LOGICAL_XOR) reduce 31) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 31) ((T_OBJECT_OPERATOR) reduce 31) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 31) ((T_POW) reduce 31) ((T_SL) reduce 31) ((T_SPACESHIP) reduce 31) ((T_SR) reduce 31) (("[") reduce 31) (("]") reduce 31) (("^") reduce 31) (("{") reduce 31) (("|") reduce 31)) 7812 ((("%") reduce 57) (("(") reduce 57) (("*") reduce 57) (("+") reduce 57) ((",") reduce 57) (("-") reduce 57) ((".") reduce 57) (("/") reduce 57) (("<") reduce 57) ((">") reduce 57) (("?") reduce 57) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_BOOLEAN_AND) reduce 57) ((T_BOOLEAN_OR) reduce 57) ((T_COALESCE) reduce 57) ((T_INSTANCEOF) reduce 57) ((T_IS_EQUAL) reduce 57) ((T_IS_GREATER_OR_EQUAL) reduce 57) ((T_IS_IDENTICAL) reduce 57) ((T_IS_NOT_EQUAL) reduce 57) ((T_IS_NOT_IDENTICAL) reduce 57) ((T_IS_SMALLER_OR_EQUAL) reduce 57) ((T_LOGICAL_AND) reduce 57) ((T_LOGICAL_OR) reduce 57) ((T_LOGICAL_XOR) reduce 57) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 57) ((T_OBJECT_OPERATOR) reduce 57) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 57) ((T_POW) reduce 57) ((T_SL) reduce 57) ((T_SPACESHIP) reduce 57) ((T_SR) reduce 57) (("[") reduce 57) (("]") reduce 57) (("^") reduce 57) (("{") reduce 57) (("|") reduce 57)) 7813 ((("%") reduce 61) (("(") reduce 61) (("*") reduce 61) (("+") reduce 61) ((",") reduce 61) (("-") reduce 61) ((".") reduce 61) (("/") reduce 61) (("<") reduce 61) ((">") reduce 61) (("?") reduce 61) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_BOOLEAN_AND) reduce 61) ((T_BOOLEAN_OR) reduce 61) ((T_COALESCE) reduce 61) ((T_INSTANCEOF) reduce 61) ((T_IS_EQUAL) reduce 61) ((T_IS_GREATER_OR_EQUAL) reduce 61) ((T_IS_IDENTICAL) reduce 61) ((T_IS_NOT_EQUAL) reduce 61) ((T_IS_NOT_IDENTICAL) reduce 61) ((T_IS_SMALLER_OR_EQUAL) reduce 61) ((T_LOGICAL_AND) reduce 61) ((T_LOGICAL_OR) reduce 61) ((T_LOGICAL_XOR) reduce 61) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 61) ((T_OBJECT_OPERATOR) reduce 61) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 61) ((T_POW) reduce 61) ((T_SL) reduce 61) ((T_SPACESHIP) reduce 61) ((T_SR) reduce 61) (("[") reduce 61) (("]") reduce 61) (("^") reduce 61) (("{") reduce 61) (("|") reduce 61)) 7814 ((("%") reduce 28) (("(") reduce 28) (("*") reduce 28) (("+") reduce 28) ((",") reduce 28) (("-") reduce 28) ((".") reduce 28) (("/") reduce 28) (("<") reduce 28) ((">") reduce 28) (("?") reduce 28) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_BOOLEAN_AND) reduce 28) ((T_BOOLEAN_OR) reduce 28) ((T_COALESCE) reduce 28) ((T_INSTANCEOF) reduce 28) ((T_IS_EQUAL) reduce 28) ((T_IS_GREATER_OR_EQUAL) reduce 28) ((T_IS_IDENTICAL) reduce 28) ((T_IS_NOT_EQUAL) reduce 28) ((T_IS_NOT_IDENTICAL) reduce 28) ((T_IS_SMALLER_OR_EQUAL) reduce 28) ((T_LOGICAL_AND) reduce 28) ((T_LOGICAL_OR) reduce 28) ((T_LOGICAL_XOR) reduce 28) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 28) ((T_OBJECT_OPERATOR) reduce 28) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 28) ((T_POW) reduce 28) ((T_SL) reduce 28) ((T_SPACESHIP) reduce 28) ((T_SR) reduce 28) (("[") reduce 28) (("]") reduce 28) (("^") reduce 28) (("{") reduce 28) (("|") reduce 28)) 7815 ((("%") reduce 36) (("(") reduce 36) (("*") reduce 36) (("+") reduce 36) ((",") reduce 36) (("-") reduce 36) ((".") reduce 36) (("/") reduce 36) (("<") reduce 36) ((">") reduce 36) (("?") reduce 36) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_BOOLEAN_AND) reduce 36) ((T_BOOLEAN_OR) reduce 36) ((T_COALESCE) reduce 36) ((T_INSTANCEOF) reduce 36) ((T_IS_EQUAL) reduce 36) ((T_IS_GREATER_OR_EQUAL) reduce 36) ((T_IS_IDENTICAL) reduce 36) ((T_IS_NOT_EQUAL) reduce 36) ((T_IS_NOT_IDENTICAL) reduce 36) ((T_IS_SMALLER_OR_EQUAL) reduce 36) ((T_LOGICAL_AND) reduce 36) ((T_LOGICAL_OR) reduce 36) ((T_LOGICAL_XOR) reduce 36) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 36) ((T_OBJECT_OPERATOR) reduce 36) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 36) ((T_POW) reduce 36) ((T_SL) reduce 36) ((T_SPACESHIP) reduce 36) ((T_SR) reduce 36) (("[") reduce 36) (("]") reduce 36) (("^") reduce 36) (("{") reduce 36) (("|") reduce 36)) 7816 ((("%") reduce 32) (("(") reduce 32) (("*") reduce 32) (("+") reduce 32) ((",") reduce 32) (("-") reduce 32) ((".") reduce 32) (("/") reduce 32) (("<") reduce 32) ((">") reduce 32) (("?") reduce 32) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_BOOLEAN_AND) reduce 32) ((T_BOOLEAN_OR) reduce 32) ((T_COALESCE) reduce 32) ((T_INSTANCEOF) reduce 32) ((T_IS_EQUAL) reduce 32) ((T_IS_GREATER_OR_EQUAL) reduce 32) ((T_IS_IDENTICAL) reduce 32) ((T_IS_NOT_EQUAL) reduce 32) ((T_IS_NOT_IDENTICAL) reduce 32) ((T_IS_SMALLER_OR_EQUAL) reduce 32) ((T_LOGICAL_AND) reduce 32) ((T_LOGICAL_OR) reduce 32) ((T_LOGICAL_XOR) reduce 32) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 32) ((T_OBJECT_OPERATOR) reduce 32) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 32) ((T_POW) reduce 32) ((T_SL) reduce 32) ((T_SPACESHIP) reduce 32) ((T_SR) reduce 32) (("[") reduce 32) (("]") reduce 32) (("^") reduce 32) (("{") reduce 32) (("|") reduce 32)) 7817 ((("%") reduce 35) (("(") reduce 35) (("*") reduce 35) (("+") reduce 35) ((",") reduce 35) (("-") reduce 35) ((".") reduce 35) (("/") reduce 35) (("<") reduce 35) ((">") reduce 35) (("?") reduce 35) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_BOOLEAN_AND) reduce 35) ((T_BOOLEAN_OR) reduce 35) ((T_COALESCE) reduce 35) ((T_INSTANCEOF) reduce 35) ((T_IS_EQUAL) reduce 35) ((T_IS_GREATER_OR_EQUAL) reduce 35) ((T_IS_IDENTICAL) reduce 35) ((T_IS_NOT_EQUAL) reduce 35) ((T_IS_NOT_IDENTICAL) reduce 35) ((T_IS_SMALLER_OR_EQUAL) reduce 35) ((T_LOGICAL_AND) reduce 35) ((T_LOGICAL_OR) reduce 35) ((T_LOGICAL_XOR) reduce 35) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 35) ((T_OBJECT_OPERATOR) reduce 35) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 35) ((T_POW) reduce 35) ((T_SL) reduce 35) ((T_SPACESHIP) reduce 35) ((T_SR) reduce 35) (("[") reduce 35) (("]") reduce 35) (("^") reduce 35) (("{") reduce 35) (("|") reduce 35)) 7818 ((("%") reduce 19) (("(") reduce 19) (("*") reduce 19) (("+") reduce 19) ((",") reduce 19) (("-") reduce 19) ((".") reduce 19) (("/") reduce 19) (("<") reduce 19) ((">") reduce 19) (("?") reduce 19) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_BOOLEAN_AND) reduce 19) ((T_BOOLEAN_OR) reduce 19) ((T_COALESCE) reduce 19) ((T_INSTANCEOF) reduce 19) ((T_IS_EQUAL) reduce 19) ((T_IS_GREATER_OR_EQUAL) reduce 19) ((T_IS_IDENTICAL) reduce 19) ((T_IS_NOT_EQUAL) reduce 19) ((T_IS_NOT_IDENTICAL) reduce 19) ((T_IS_SMALLER_OR_EQUAL) reduce 19) ((T_LOGICAL_AND) reduce 19) ((T_LOGICAL_OR) reduce 19) ((T_LOGICAL_XOR) reduce 19) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 19) ((T_OBJECT_OPERATOR) reduce 19) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 19) ((T_POW) reduce 19) ((T_SL) reduce 19) ((T_SPACESHIP) reduce 19) ((T_SR) reduce 19) (("[") reduce 19) (("]") reduce 19) (("^") reduce 19) (("{") reduce 19) (("|") reduce 19)) 7819 ((("%") reduce 45) (("(") reduce 45) (("*") reduce 45) (("+") reduce 45) ((",") reduce 45) (("-") reduce 45) ((".") reduce 45) (("/") reduce 45) (("<") reduce 45) ((">") reduce 45) (("?") reduce 45) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_BOOLEAN_AND) reduce 45) ((T_BOOLEAN_OR) reduce 45) ((T_COALESCE) reduce 45) ((T_INSTANCEOF) reduce 45) ((T_IS_EQUAL) reduce 45) ((T_IS_GREATER_OR_EQUAL) reduce 45) ((T_IS_IDENTICAL) reduce 45) ((T_IS_NOT_EQUAL) reduce 45) ((T_IS_NOT_IDENTICAL) reduce 45) ((T_IS_SMALLER_OR_EQUAL) reduce 45) ((T_LOGICAL_AND) reduce 45) ((T_LOGICAL_OR) reduce 45) ((T_LOGICAL_XOR) reduce 45) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 45) ((T_OBJECT_OPERATOR) reduce 45) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 45) ((T_POW) reduce 45) ((T_SL) reduce 45) ((T_SPACESHIP) reduce 45) ((T_SR) reduce 45) (("[") reduce 45) (("]") reduce 45) (("^") reduce 45) (("{") reduce 45) (("|") reduce 45)) 7820 ((("%") reduce 504) (("(") reduce 541) (("*") reduce 504) (("+") reduce 504) ((",") reduce 504) (("-") reduce 504) ((".") reduce 504) (("/") reduce 504) (("<") reduce 504) ((">") reduce 504) (("?") reduce 504) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_BOOLEAN_AND) reduce 504) ((T_BOOLEAN_OR) reduce 504) ((T_COALESCE) reduce 504) ((T_INSTANCEOF) reduce 504) ((T_IS_EQUAL) reduce 504) ((T_IS_GREATER_OR_EQUAL) reduce 504) ((T_IS_IDENTICAL) reduce 504) ((T_IS_NOT_EQUAL) reduce 504) ((T_IS_NOT_IDENTICAL) reduce 504) ((T_IS_SMALLER_OR_EQUAL) reduce 504) ((T_LOGICAL_AND) reduce 504) ((T_LOGICAL_OR) reduce 504) ((T_LOGICAL_XOR) reduce 504) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 504) ((T_OBJECT_OPERATOR) reduce 504) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 504) ((T_POW) reduce 504) ((T_SL) reduce 504) ((T_SPACESHIP) reduce 504) ((T_SR) reduce 504) (("[") reduce 504) (("]") reduce 504) (("^") reduce 504) (("{") reduce 504) (("|") reduce 504)) 7822 ((("%") reduce 71) (("(") reduce 71) (("*") reduce 71) (("+") reduce 71) ((",") reduce 71) (("-") reduce 71) ((".") reduce 71) (("/") reduce 71) (("<") reduce 71) ((">") reduce 71) (("?") reduce 71) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_BOOLEAN_AND) reduce 71) ((T_BOOLEAN_OR) reduce 71) ((T_COALESCE) reduce 71) ((T_INSTANCEOF) reduce 71) ((T_IS_EQUAL) reduce 71) ((T_IS_GREATER_OR_EQUAL) reduce 71) ((T_IS_IDENTICAL) reduce 71) ((T_IS_NOT_EQUAL) reduce 71) ((T_IS_NOT_IDENTICAL) reduce 71) ((T_IS_SMALLER_OR_EQUAL) reduce 71) ((T_LOGICAL_AND) reduce 71) ((T_LOGICAL_OR) reduce 71) ((T_LOGICAL_XOR) reduce 71) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 71) ((T_OBJECT_OPERATOR) reduce 71) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 71) ((T_POW) reduce 71) ((T_SL) reduce 71) ((T_SPACESHIP) reduce 71) ((T_SR) reduce 71) (("[") reduce 71) (("]") reduce 71) (("^") reduce 71) (("{") reduce 71) (("|") reduce 71)) 7823 ((("%") reduce 82) (("(") reduce 82) (("*") reduce 82) (("+") reduce 82) ((",") reduce 82) (("-") reduce 82) ((".") reduce 82) (("/") reduce 82) (("<") reduce 82) ((">") reduce 82) (("?") reduce 82) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_BOOLEAN_AND) reduce 82) ((T_BOOLEAN_OR) reduce 82) ((T_COALESCE) reduce 82) ((T_INSTANCEOF) reduce 82) ((T_IS_EQUAL) reduce 82) ((T_IS_GREATER_OR_EQUAL) reduce 82) ((T_IS_IDENTICAL) reduce 82) ((T_IS_NOT_EQUAL) reduce 82) ((T_IS_NOT_IDENTICAL) reduce 82) ((T_IS_SMALLER_OR_EQUAL) reduce 82) ((T_LOGICAL_AND) reduce 82) ((T_LOGICAL_OR) reduce 82) ((T_LOGICAL_XOR) reduce 82) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 82) ((T_OBJECT_OPERATOR) reduce 82) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 82) ((T_POW) reduce 82) ((T_SL) reduce 82) ((T_SPACESHIP) reduce 82) ((T_SR) reduce 82) (("[") reduce 82) (("]") reduce 82) (("^") reduce 82) (("{") reduce 82) (("|") reduce 82)) 7824 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) ((",") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) (("<") reduce 533) (("=") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AND_EQUAL) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_COALESCE_EQUAL) reduce 533) ((T_CONCAT_EQUAL) reduce 533) ((T_DEC) reduce 533) ((T_DIV_EQUAL) reduce 533) ((T_INC) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_MINUS_EQUAL) reduce 533) ((T_MOD_EQUAL) reduce 533) ((T_MUL_EQUAL) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_OR_EQUAL) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_PLUS_EQUAL) reduce 533) ((T_POW) reduce 533) ((T_POW_EQUAL) reduce 533) ((T_SL) reduce 533) ((T_SL_EQUAL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) ((T_SR_EQUAL) reduce 533) ((T_XOR_EQUAL) reduce 533) (("[") reduce 533) (("]") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 7827 ((("%") reduce 506) (("(") reduce 542) (("*") reduce 506) (("+") reduce 506) ((",") reduce 506) (("-") reduce 506) ((".") reduce 506) (("/") reduce 506) (("<") reduce 506) ((">") reduce 506) (("?") reduce 506) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_BOOLEAN_AND) reduce 506) ((T_BOOLEAN_OR) reduce 506) ((T_COALESCE) reduce 506) ((T_INSTANCEOF) reduce 506) ((T_IS_EQUAL) reduce 506) ((T_IS_GREATER_OR_EQUAL) reduce 506) ((T_IS_IDENTICAL) reduce 506) ((T_IS_NOT_EQUAL) reduce 506) ((T_IS_NOT_IDENTICAL) reduce 506) ((T_IS_SMALLER_OR_EQUAL) reduce 506) ((T_LOGICAL_AND) reduce 506) ((T_LOGICAL_OR) reduce 506) ((T_LOGICAL_XOR) reduce 506) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 506) ((T_OBJECT_OPERATOR) reduce 506) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 506) ((T_POW) reduce 506) ((T_SL) reduce 506) ((T_SPACESHIP) reduce 506) ((T_SR) reduce 506) (("[") reduce 506) (("]") reduce 506) (("^") reduce 506) (("{") reduce 506) (("|") reduce 506)) 7829 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) ((",") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) (("<") reduce 468) (("=") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AND_EQUAL) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_COALESCE_EQUAL) reduce 468) ((T_CONCAT_EQUAL) reduce 468) ((T_DEC) reduce 468) ((T_DIV_EQUAL) reduce 468) ((T_INC) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_MINUS_EQUAL) reduce 468) ((T_MOD_EQUAL) reduce 468) ((T_MUL_EQUAL) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_OR_EQUAL) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_PLUS_EQUAL) reduce 468) ((T_POW) reduce 468) ((T_POW_EQUAL) reduce 468) ((T_SL) reduce 468) ((T_SL_EQUAL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) ((T_SR_EQUAL) reduce 468) ((T_XOR_EQUAL) reduce 468) (("[") reduce 468) (("]") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 7830 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) ((",") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) (("=") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AND_EQUAL) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_COALESCE_EQUAL) reduce 288) ((T_CONCAT_EQUAL) reduce 288) ((T_DEC) reduce 288) ((T_DIV_EQUAL) reduce 288) ((T_INC) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_MINUS_EQUAL) reduce 288) ((T_MOD_EQUAL) reduce 288) ((T_MUL_EQUAL) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_OR_EQUAL) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_PLUS_EQUAL) reduce 288) ((T_POW) reduce 288) ((T_POW_EQUAL) reduce 288) ((T_SL) reduce 288) ((T_SL_EQUAL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) ((T_SR_EQUAL) reduce 288) ((T_XOR_EQUAL) reduce 288) (("[") reduce 288) (("]") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 7834 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) ((",") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) (("=") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AND_EQUAL) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_COALESCE_EQUAL) reduce 289) ((T_CONCAT_EQUAL) reduce 289) ((T_DEC) reduce 289) ((T_DIV_EQUAL) reduce 289) ((T_INC) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_MINUS_EQUAL) reduce 289) ((T_MOD_EQUAL) reduce 289) ((T_MUL_EQUAL) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_OR_EQUAL) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_PLUS_EQUAL) reduce 289) ((T_POW) reduce 289) ((T_POW_EQUAL) reduce 289) ((T_SL) reduce 289) ((T_SL_EQUAL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) ((T_SR_EQUAL) reduce 289) ((T_XOR_EQUAL) reduce 289) (("[") reduce 289) (("]") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 7835 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) ((",") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) (("=") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AND_EQUAL) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_COALESCE_EQUAL) reduce 290) ((T_CONCAT_EQUAL) reduce 290) ((T_DEC) reduce 290) ((T_DIV_EQUAL) reduce 290) ((T_INC) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_MINUS_EQUAL) reduce 290) ((T_MOD_EQUAL) reduce 290) ((T_MUL_EQUAL) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_OR_EQUAL) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_PLUS_EQUAL) reduce 290) ((T_POW) reduce 290) ((T_POW_EQUAL) reduce 290) ((T_SL) reduce 290) ((T_SL_EQUAL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) ((T_SR_EQUAL) reduce 290) ((T_XOR_EQUAL) reduce 290) (("[") reduce 290) (("]") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 7840 ((("%") reduce 388) (("*") reduce 388) (("+") reduce 388) ((",") reduce 388) (("-") reduce 388) ((".") reduce 388) (("/") reduce 388) (("<") reduce 388) ((">") reduce 388) (("?") reduce 388) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_BOOLEAN_AND) reduce 388) ((T_BOOLEAN_OR) reduce 388) ((T_COALESCE) reduce 388) ((T_INSTANCEOF) reduce 388) ((T_IS_EQUAL) reduce 388) ((T_IS_GREATER_OR_EQUAL) reduce 388) ((T_IS_IDENTICAL) reduce 388) ((T_IS_NOT_EQUAL) reduce 388) ((T_IS_NOT_IDENTICAL) reduce 388) ((T_IS_SMALLER_OR_EQUAL) reduce 388) ((T_LOGICAL_AND) reduce 388) ((T_LOGICAL_OR) reduce 388) ((T_LOGICAL_XOR) reduce 388) ((T_POW) reduce 388) ((T_SL) reduce 388) ((T_SPACESHIP) reduce 388) ((T_SR) reduce 388) (("]") reduce 388) (("^") reduce 388) (("|") reduce 388)) 7842 ((("%") reduce 386) (("*") reduce 386) (("+") reduce 386) ((",") reduce 386) (("-") reduce 386) ((".") reduce 386) (("/") reduce 386) (("<") reduce 386) ((">") reduce 386) (("?") reduce 386) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_BOOLEAN_AND) reduce 386) ((T_BOOLEAN_OR) reduce 386) ((T_COALESCE) reduce 386) ((T_INSTANCEOF) reduce 386) ((T_IS_EQUAL) reduce 386) ((T_IS_GREATER_OR_EQUAL) reduce 386) ((T_IS_IDENTICAL) reduce 386) ((T_IS_NOT_EQUAL) reduce 386) ((T_IS_NOT_IDENTICAL) reduce 386) ((T_IS_SMALLER_OR_EQUAL) reduce 386) ((T_LOGICAL_AND) reduce 386) ((T_LOGICAL_OR) reduce 386) ((T_LOGICAL_XOR) reduce 386) ((T_POW) reduce 386) ((T_SL) reduce 386) ((T_SPACESHIP) reduce 386) ((T_SR) reduce 386) (("]") reduce 386) (("^") reduce 386) (("|") reduce 386)) 7852 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 382) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 382) ((T_LOGICAL_OR) reduce 382) ((T_LOGICAL_XOR) reduce 382) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 382) (("^") shift) (("|") shift)) 7853 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 384) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 384) ((T_LOGICAL_OR) reduce 384) ((T_LOGICAL_XOR) reduce 384) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 384) (("^") shift) (("|") shift)) 7854 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 383) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 383) ((T_LOGICAL_OR) reduce 383) ((T_LOGICAL_XOR) reduce 383) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 383) (("^") shift) (("|") shift)) 7855 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 376) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 376) ((T_LOGICAL_OR) reduce 376) ((T_LOGICAL_XOR) reduce 376) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 376) (("^") shift) (("|") shift)) 7856 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 373) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 373) ((T_LOGICAL_OR) reduce 373) ((T_LOGICAL_XOR) reduce 373) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 373) (("^") shift) (("|") shift)) 7857 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 381) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 381) ((T_LOGICAL_OR) reduce 381) ((T_LOGICAL_XOR) reduce 381) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 381) (("^") shift) (("|") shift)) 7858 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 375) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 375) ((T_LOGICAL_OR) reduce 375) ((T_LOGICAL_XOR) reduce 375) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 375) (("^") shift) (("|") shift)) 7859 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 379) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 379) ((T_LOGICAL_OR) reduce 379) ((T_LOGICAL_XOR) reduce 379) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 379) (("^") shift) (("|") shift)) 7860 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 374) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 374) ((T_LOGICAL_OR) reduce 374) ((T_LOGICAL_XOR) reduce 374) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 374) (("^") shift) (("|") shift)) 7861 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 377) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 377) ((T_LOGICAL_OR) reduce 377) ((T_LOGICAL_XOR) reduce 377) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 377) (("^") shift) (("|") shift)) 7862 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 378) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 378) ((T_LOGICAL_OR) reduce 378) ((T_LOGICAL_XOR) reduce 378) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 378) (("^") shift) (("|") shift)) 7863 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 385) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 385) ((T_LOGICAL_OR) reduce 385) ((T_LOGICAL_XOR) reduce 385) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 385) (("^") shift) (("|") shift)) 7864 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 380) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 380) ((T_LOGICAL_OR) reduce 380) ((T_LOGICAL_XOR) reduce 380) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 380) (("^") shift) (("|") shift)) 7866 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 370) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 370) ((T_LOGICAL_OR) reduce 370) ((T_LOGICAL_XOR) reduce 370) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 370) (("^") shift) (("|") shift)) 7869 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) ((",") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("]") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 7872 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) ((",") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) (("<") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_POW) reduce 525) ((T_SL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) (("[") reduce 525) (("]") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 7874 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) ((",") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) (("<") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_POW) reduce 524) ((T_SL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) (("[") reduce 524) (("]") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 7876 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) ((",") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) (("<") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_POW) reduce 519) ((T_SL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) (("[") reduce 519) (("]") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 7877 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) ((",") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) (("<") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_POW) reduce 526) ((T_SL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) (("[") reduce 526) (("]") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 7878 ((("%") reduce 371) (("*") reduce 371) (("+") reduce 371) ((",") reduce 371) (("-") reduce 371) ((".") reduce 371) (("/") reduce 371) (("<") reduce 371) ((">") reduce 371) (("?") reduce 371) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_BOOLEAN_AND) reduce 371) ((T_BOOLEAN_OR) reduce 371) ((T_COALESCE) reduce 371) ((T_INSTANCEOF) reduce 371) ((T_IS_EQUAL) reduce 371) ((T_IS_GREATER_OR_EQUAL) reduce 371) ((T_IS_IDENTICAL) reduce 371) ((T_IS_NOT_EQUAL) reduce 371) ((T_IS_NOT_IDENTICAL) reduce 371) ((T_IS_SMALLER_OR_EQUAL) reduce 371) ((T_LOGICAL_AND) reduce 371) ((T_LOGICAL_OR) reduce 371) ((T_LOGICAL_XOR) reduce 371) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 371) ((T_SL) reduce 371) ((T_SPACESHIP) reduce 371) ((T_SR) reduce 371) (("[") reduce 510) (("]") reduce 371) (("^") reduce 371) (("{") reduce 510) (("|") reduce 371)) 7882 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) ((",") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) (("<") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_POW) reduce 533) ((T_SL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) (("[") reduce 533) (("]") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 7884 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) ((",") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) (("<") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_POW) reduce 468) ((T_SL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) (("[") reduce 468) (("]") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 7885 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) ((",") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("[") reduce 288) (("]") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 7889 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) ((",") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("[") reduce 289) (("]") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 7890 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) ((",") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("[") reduce 290) (("]") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 7891 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) ((",") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) (("<") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_POW) reduce 465) ((T_SL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) (("[") reduce 465) (("]") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 7894 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) ((",") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) (("<") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_POW) reduce 532) ((T_SL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) (("[") reduce 532) (("]") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 7895 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) ((",") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) (("<") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_POW) reduce 467) ((T_SL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) (("[") reduce 467) (("]") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 7896 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) ((",") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) (("<") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_POW) reduce 469) ((T_SL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) (("[") reduce 469) (("]") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 7902 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) ((",") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) (("<") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_POW) reduce 521) ((T_SL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) (("[") reduce 521) (("]") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 7904 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) ((",") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) (("<") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_POW) reduce 520) ((T_SL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) (("[") reduce 520) (("]") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 7905 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) ((",") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("]") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 7906 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) ((",") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) (("<") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_POW) reduce 527) ((T_SL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) (("[") reduce 527) (("]") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 7907 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) ((",") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("]") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 7910 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) ((",") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("]") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 7911 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) ((",") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) (("<") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_POW) reduce 522) ((T_SL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) (("[") reduce 522) (("]") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 7912 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) ((",") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) (("<") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_POW) reduce 528) ((T_SL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) (("[") reduce 528) (("]") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 7913 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) ((",") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) (("<") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_POW) reduce 523) ((T_SL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) (("[") reduce 523) (("]") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 7914 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) ((",") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) (("<") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_POW) reduce 466) ((T_SL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) (("[") reduce 466) (("]") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 7915 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) ((",") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("]") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 7918 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) ((",") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("]") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 7919 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) ((",") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) (("<") reduce 465) (("=") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AND_EQUAL) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_COALESCE_EQUAL) reduce 465) ((T_CONCAT_EQUAL) reduce 465) ((T_DEC) reduce 465) ((T_DIV_EQUAL) reduce 465) ((T_INC) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_MINUS_EQUAL) reduce 465) ((T_MOD_EQUAL) reduce 465) ((T_MUL_EQUAL) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_OR_EQUAL) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_PLUS_EQUAL) reduce 465) ((T_POW) reduce 465) ((T_POW_EQUAL) reduce 465) ((T_SL) reduce 465) ((T_SL_EQUAL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) ((T_SR_EQUAL) reduce 465) ((T_XOR_EQUAL) reduce 465) (("[") reduce 465) (("]") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 7930 ((("%") reduce 455) (("*") reduce 455) (("+") reduce 455) ((",") reduce 455) (("-") reduce 455) ((".") reduce 455) (("/") reduce 455) (("<") reduce 455) ((">") reduce 455) (("?") reduce 455) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_BOOLEAN_AND) reduce 455) ((T_BOOLEAN_OR) reduce 455) ((T_COALESCE) reduce 455) ((T_INSTANCEOF) reduce 455) ((T_IS_EQUAL) reduce 455) ((T_IS_GREATER_OR_EQUAL) reduce 455) ((T_IS_IDENTICAL) reduce 455) ((T_IS_NOT_EQUAL) reduce 455) ((T_IS_NOT_IDENTICAL) reduce 455) ((T_IS_SMALLER_OR_EQUAL) reduce 455) ((T_LOGICAL_AND) reduce 455) ((T_LOGICAL_OR) reduce 455) ((T_LOGICAL_XOR) reduce 455) ((T_POW) reduce 455) ((T_SL) reduce 455) ((T_SPACESHIP) reduce 455) ((T_SR) reduce 455) (("]") reduce 455) (("^") reduce 455) (("|") reduce 455)) 7931 ((("%") reduce 450) (("*") reduce 450) (("+") reduce 450) ((",") reduce 450) (("-") reduce 450) ((".") reduce 450) (("/") reduce 450) (("<") reduce 450) ((">") reduce 450) (("?") reduce 450) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_BOOLEAN_AND) reduce 450) ((T_BOOLEAN_OR) reduce 450) ((T_COALESCE) reduce 450) ((T_INSTANCEOF) reduce 450) ((T_IS_EQUAL) reduce 450) ((T_IS_GREATER_OR_EQUAL) reduce 450) ((T_IS_IDENTICAL) reduce 450) ((T_IS_NOT_EQUAL) reduce 450) ((T_IS_NOT_IDENTICAL) reduce 450) ((T_IS_SMALLER_OR_EQUAL) reduce 450) ((T_LOGICAL_AND) reduce 450) ((T_LOGICAL_OR) reduce 450) ((T_LOGICAL_XOR) reduce 450) ((T_POW) reduce 450) ((T_SL) reduce 450) ((T_SPACESHIP) reduce 450) ((T_SR) reduce 450) (("]") reduce 450) (("^") reduce 450) (("|") reduce 450)) 8003 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 455) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 455) (("^") shift) (("|") shift)) 8321 ((("%") reduce 451) (("*") reduce 451) (("+") reduce 451) ((",") reduce 451) (("-") reduce 451) ((".") reduce 451) (("/") reduce 451) (("<") reduce 451) ((">") reduce 451) (("?") reduce 451) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_BOOLEAN_AND) reduce 451) ((T_BOOLEAN_OR) reduce 451) ((T_COALESCE) reduce 451) ((T_INSTANCEOF) reduce 451) ((T_IS_EQUAL) reduce 451) ((T_IS_GREATER_OR_EQUAL) reduce 451) ((T_IS_IDENTICAL) reduce 451) ((T_IS_NOT_EQUAL) reduce 451) ((T_IS_NOT_IDENTICAL) reduce 451) ((T_IS_SMALLER_OR_EQUAL) reduce 451) ((T_LOGICAL_AND) reduce 451) ((T_LOGICAL_OR) reduce 451) ((T_LOGICAL_XOR) reduce 451) ((T_POW) reduce 451) ((T_SL) reduce 451) ((T_SPACESHIP) reduce 451) ((T_SR) reduce 451) (("]") reduce 451) (("^") reduce 451) (("|") reduce 451)) 8324 ((("%") reduce 503) (("(") reduce 541) (("*") reduce 503) (("+") reduce 503) ((",") reduce 503) (("-") reduce 503) ((".") reduce 503) (("/") reduce 503) (("<") reduce 503) ((">") reduce 503) (("?") reduce 503) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_BOOLEAN_AND) reduce 503) ((T_BOOLEAN_OR) reduce 503) ((T_COALESCE) reduce 503) ((T_INSTANCEOF) reduce 503) ((T_IS_EQUAL) reduce 503) ((T_IS_GREATER_OR_EQUAL) reduce 503) ((T_IS_IDENTICAL) reduce 503) ((T_IS_NOT_EQUAL) reduce 503) ((T_IS_NOT_IDENTICAL) reduce 503) ((T_IS_SMALLER_OR_EQUAL) reduce 503) ((T_LOGICAL_AND) reduce 503) ((T_LOGICAL_OR) reduce 503) ((T_LOGICAL_XOR) reduce 503) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 503) ((T_OBJECT_OPERATOR) reduce 503) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 503) ((T_POW) reduce 503) ((T_SL) reduce 503) ((T_SPACESHIP) reduce 503) ((T_SR) reduce 503) (("[") reduce 503) (("]") reduce 503) (("^") reduce 503) (("{") reduce 503) (("|") reduce 503)) 8326 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) ((",") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) (("<") reduce 532) (("=") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AND_EQUAL) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_COALESCE_EQUAL) reduce 532) ((T_CONCAT_EQUAL) reduce 532) ((T_DEC) reduce 532) ((T_DIV_EQUAL) reduce 532) ((T_INC) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_MINUS_EQUAL) reduce 532) ((T_MOD_EQUAL) reduce 532) ((T_MUL_EQUAL) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_OR_EQUAL) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_PLUS_EQUAL) reduce 532) ((T_POW) reduce 532) ((T_POW_EQUAL) reduce 532) ((T_SL) reduce 532) ((T_SL_EQUAL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) ((T_SR_EQUAL) reduce 532) ((T_XOR_EQUAL) reduce 532) (("[") reduce 532) (("]") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 8329 ((("%") reduce 505) (("(") reduce 542) (("*") reduce 505) (("+") reduce 505) ((",") reduce 505) (("-") reduce 505) ((".") reduce 505) (("/") reduce 505) (("<") reduce 505) ((">") reduce 505) (("?") reduce 505) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_BOOLEAN_AND) reduce 505) ((T_BOOLEAN_OR) reduce 505) ((T_COALESCE) reduce 505) ((T_INSTANCEOF) reduce 505) ((T_IS_EQUAL) reduce 505) ((T_IS_GREATER_OR_EQUAL) reduce 505) ((T_IS_IDENTICAL) reduce 505) ((T_IS_NOT_EQUAL) reduce 505) ((T_IS_NOT_IDENTICAL) reduce 505) ((T_IS_SMALLER_OR_EQUAL) reduce 505) ((T_LOGICAL_AND) reduce 505) ((T_LOGICAL_OR) reduce 505) ((T_LOGICAL_XOR) reduce 505) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 505) ((T_OBJECT_OPERATOR) reduce 505) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 505) ((T_POW) reduce 505) ((T_SL) reduce 505) ((T_SPACESHIP) reduce 505) ((T_SR) reduce 505) (("[") reduce 505) (("]") reduce 505) (("^") reduce 505) (("{") reduce 505) (("|") reduce 505)) 8330 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) ((",") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) (("<") reduce 467) (("=") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AND_EQUAL) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_COALESCE_EQUAL) reduce 467) ((T_CONCAT_EQUAL) reduce 467) ((T_DEC) reduce 467) ((T_DIV_EQUAL) reduce 467) ((T_INC) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_MINUS_EQUAL) reduce 467) ((T_MOD_EQUAL) reduce 467) ((T_MUL_EQUAL) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_OR_EQUAL) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_PLUS_EQUAL) reduce 467) ((T_POW) reduce 467) ((T_POW_EQUAL) reduce 467) ((T_SL) reduce 467) ((T_SL_EQUAL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) ((T_SR_EQUAL) reduce 467) ((T_XOR_EQUAL) reduce 467) (("[") reduce 467) (("]") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 8331 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) ((",") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) (("<") reduce 469) (("=") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AND_EQUAL) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_COALESCE_EQUAL) reduce 469) ((T_CONCAT_EQUAL) reduce 469) ((T_DEC) reduce 469) ((T_DIV_EQUAL) reduce 469) ((T_INC) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_MINUS_EQUAL) reduce 469) ((T_MOD_EQUAL) reduce 469) ((T_MUL_EQUAL) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_OR_EQUAL) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_PLUS_EQUAL) reduce 469) ((T_POW) reduce 469) ((T_POW_EQUAL) reduce 469) ((T_SL) reduce 469) ((T_SL_EQUAL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) ((T_SR_EQUAL) reduce 469) ((T_XOR_EQUAL) reduce 469) (("[") reduce 469) (("]") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 8333 ((("%") reduce 446) (("*") reduce 446) (("+") reduce 446) ((",") reduce 446) (("-") reduce 446) ((".") reduce 446) (("/") reduce 446) (("<") reduce 446) ((">") reduce 446) (("?") reduce 446) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_BOOLEAN_AND) reduce 446) ((T_BOOLEAN_OR) reduce 446) ((T_COALESCE) reduce 446) ((T_INSTANCEOF) reduce 446) ((T_IS_EQUAL) reduce 446) ((T_IS_GREATER_OR_EQUAL) reduce 446) ((T_IS_IDENTICAL) reduce 446) ((T_IS_NOT_EQUAL) reduce 446) ((T_IS_NOT_IDENTICAL) reduce 446) ((T_IS_SMALLER_OR_EQUAL) reduce 446) ((T_LOGICAL_AND) reduce 446) ((T_LOGICAL_OR) reduce 446) ((T_LOGICAL_XOR) reduce 446) ((T_POW) reduce 446) ((T_SL) reduce 446) ((T_SPACESHIP) reduce 446) ((T_SR) reduce 446) (("]") reduce 446) (("^") reduce 446) (("|") reduce 446)) 8334 ((("%") reduce 448) (("*") reduce 448) (("+") reduce 448) ((",") reduce 448) (("-") reduce 448) ((".") reduce 448) (("/") reduce 448) (("<") reduce 448) ((">") reduce 448) (("?") reduce 448) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_BOOLEAN_AND) reduce 448) ((T_BOOLEAN_OR) reduce 448) ((T_COALESCE) reduce 448) ((T_INSTANCEOF) reduce 448) ((T_IS_EQUAL) reduce 448) ((T_IS_GREATER_OR_EQUAL) reduce 448) ((T_IS_IDENTICAL) reduce 448) ((T_IS_NOT_EQUAL) reduce 448) ((T_IS_NOT_IDENTICAL) reduce 448) ((T_IS_SMALLER_OR_EQUAL) reduce 448) ((T_LOGICAL_AND) reduce 448) ((T_LOGICAL_OR) reduce 448) ((T_LOGICAL_XOR) reduce 448) ((T_POW) reduce 448) ((T_SL) reduce 448) ((T_SPACESHIP) reduce 448) ((T_SR) reduce 448) (("]") reduce 448) (("^") reduce 448) (("|") reduce 448)) 8340 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) ((",") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) (("<") reduce 521) (("=") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AND_EQUAL) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_COALESCE_EQUAL) reduce 521) ((T_CONCAT_EQUAL) reduce 521) ((T_DEC) reduce 521) ((T_DIV_EQUAL) reduce 521) ((T_INC) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_MINUS_EQUAL) reduce 521) ((T_MOD_EQUAL) reduce 521) ((T_MUL_EQUAL) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_OR_EQUAL) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_PLUS_EQUAL) reduce 521) ((T_POW) reduce 521) ((T_POW_EQUAL) reduce 521) ((T_SL) reduce 521) ((T_SL_EQUAL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) ((T_SR_EQUAL) reduce 521) ((T_XOR_EQUAL) reduce 521) (("[") reduce 521) (("]") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 8342 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) ((",") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) (("<") reduce 520) (("=") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AND_EQUAL) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_COALESCE_EQUAL) reduce 520) ((T_CONCAT_EQUAL) reduce 520) ((T_DEC) reduce 520) ((T_DIV_EQUAL) reduce 520) ((T_INC) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_MINUS_EQUAL) reduce 520) ((T_MOD_EQUAL) reduce 520) ((T_MUL_EQUAL) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_OR_EQUAL) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_PLUS_EQUAL) reduce 520) ((T_POW) reduce 520) ((T_POW_EQUAL) reduce 520) ((T_SL) reduce 520) ((T_SL_EQUAL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) ((T_SR_EQUAL) reduce 520) ((T_XOR_EQUAL) reduce 520) (("[") reduce 520) (("]") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 8343 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) ((",") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) (("=") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AND_EQUAL) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_COALESCE_EQUAL) reduce 544) ((T_CONCAT_EQUAL) reduce 544) ((T_DEC) reduce 544) ((T_DIV_EQUAL) reduce 544) ((T_INC) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_MINUS_EQUAL) reduce 544) ((T_MOD_EQUAL) reduce 544) ((T_MUL_EQUAL) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_OR_EQUAL) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_PLUS_EQUAL) reduce 544) ((T_POW) reduce 544) ((T_POW_EQUAL) reduce 544) ((T_SL) reduce 544) ((T_SL_EQUAL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) ((T_SR_EQUAL) reduce 544) ((T_XOR_EQUAL) reduce 544) (("[") reduce 544) (("]") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 8344 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) ((",") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) (("<") reduce 527) (("=") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AND_EQUAL) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_COALESCE_EQUAL) reduce 527) ((T_CONCAT_EQUAL) reduce 527) ((T_DEC) reduce 527) ((T_DIV_EQUAL) reduce 527) ((T_INC) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_MINUS_EQUAL) reduce 527) ((T_MOD_EQUAL) reduce 527) ((T_MUL_EQUAL) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_OR_EQUAL) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_PLUS_EQUAL) reduce 527) ((T_POW) reduce 527) ((T_POW_EQUAL) reduce 527) ((T_SL) reduce 527) ((T_SL_EQUAL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) ((T_SR_EQUAL) reduce 527) ((T_XOR_EQUAL) reduce 527) (("[") reduce 527) (("]") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 8345 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) ((",") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) (("=") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AND_EQUAL) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_COALESCE_EQUAL) reduce 546) ((T_CONCAT_EQUAL) reduce 546) ((T_DEC) reduce 546) ((T_DIV_EQUAL) reduce 546) ((T_INC) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_MINUS_EQUAL) reduce 546) ((T_MOD_EQUAL) reduce 546) ((T_MUL_EQUAL) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_OR_EQUAL) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_PLUS_EQUAL) reduce 546) ((T_POW) reduce 546) ((T_POW_EQUAL) reduce 546) ((T_SL) reduce 546) ((T_SL_EQUAL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) ((T_SR_EQUAL) reduce 546) ((T_XOR_EQUAL) reduce 546) (("[") reduce 546) (("]") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 8348 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) ((",") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) (("=") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AND_EQUAL) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_COALESCE_EQUAL) reduce 545) ((T_CONCAT_EQUAL) reduce 545) ((T_DEC) reduce 545) ((T_DIV_EQUAL) reduce 545) ((T_INC) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_MINUS_EQUAL) reduce 545) ((T_MOD_EQUAL) reduce 545) ((T_MUL_EQUAL) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_OR_EQUAL) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_PLUS_EQUAL) reduce 545) ((T_POW) reduce 545) ((T_POW_EQUAL) reduce 545) ((T_SL) reduce 545) ((T_SL_EQUAL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) ((T_SR_EQUAL) reduce 545) ((T_XOR_EQUAL) reduce 545) (("[") reduce 545) (("]") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 8349 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) ((",") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) (("<") reduce 522) (("=") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AND_EQUAL) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_COALESCE_EQUAL) reduce 522) ((T_CONCAT_EQUAL) reduce 522) ((T_DEC) reduce 522) ((T_DIV_EQUAL) reduce 522) ((T_INC) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_MINUS_EQUAL) reduce 522) ((T_MOD_EQUAL) reduce 522) ((T_MUL_EQUAL) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_OR_EQUAL) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_PLUS_EQUAL) reduce 522) ((T_POW) reduce 522) ((T_POW_EQUAL) reduce 522) ((T_SL) reduce 522) ((T_SL_EQUAL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) ((T_SR_EQUAL) reduce 522) ((T_XOR_EQUAL) reduce 522) (("[") reduce 522) (("]") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 8350 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) ((",") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) (("<") reduce 528) (("=") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AND_EQUAL) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_COALESCE_EQUAL) reduce 528) ((T_CONCAT_EQUAL) reduce 528) ((T_DEC) reduce 528) ((T_DIV_EQUAL) reduce 528) ((T_INC) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_MINUS_EQUAL) reduce 528) ((T_MOD_EQUAL) reduce 528) ((T_MUL_EQUAL) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_OR_EQUAL) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_PLUS_EQUAL) reduce 528) ((T_POW) reduce 528) ((T_POW_EQUAL) reduce 528) ((T_SL) reduce 528) ((T_SL_EQUAL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) ((T_SR_EQUAL) reduce 528) ((T_XOR_EQUAL) reduce 528) (("[") reduce 528) (("]") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 8351 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) ((",") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) (("<") reduce 523) (("=") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AND_EQUAL) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_COALESCE_EQUAL) reduce 523) ((T_CONCAT_EQUAL) reduce 523) ((T_DEC) reduce 523) ((T_DIV_EQUAL) reduce 523) ((T_INC) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_MINUS_EQUAL) reduce 523) ((T_MOD_EQUAL) reduce 523) ((T_MUL_EQUAL) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_OR_EQUAL) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_PLUS_EQUAL) reduce 523) ((T_POW) reduce 523) ((T_POW_EQUAL) reduce 523) ((T_SL) reduce 523) ((T_SL_EQUAL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) ((T_SR_EQUAL) reduce 523) ((T_XOR_EQUAL) reduce 523) (("[") reduce 523) (("]") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 8353 ((("%") reduce 438) (("*") reduce 438) (("+") reduce 438) ((",") reduce 438) (("-") reduce 438) ((".") reduce 438) (("/") reduce 438) (("<") reduce 438) ((">") reduce 438) (("?") reduce 438) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_BOOLEAN_AND) reduce 438) ((T_BOOLEAN_OR) reduce 438) ((T_COALESCE) reduce 438) ((T_INSTANCEOF) reduce 438) ((T_IS_EQUAL) reduce 438) ((T_IS_GREATER_OR_EQUAL) reduce 438) ((T_IS_IDENTICAL) reduce 438) ((T_IS_NOT_EQUAL) reduce 438) ((T_IS_NOT_IDENTICAL) reduce 438) ((T_IS_SMALLER_OR_EQUAL) reduce 438) ((T_LOGICAL_AND) reduce 438) ((T_LOGICAL_OR) reduce 438) ((T_LOGICAL_XOR) reduce 438) ((T_POW) reduce 438) ((T_SL) reduce 438) ((T_SPACESHIP) reduce 438) ((T_SR) reduce 438) (("]") reduce 438) (("^") reduce 438) (("|") reduce 438)) 8355 ((("%") reduce 483) (("(") reduce 483) (("*") reduce 483) (("+") reduce 483) ((",") reduce 483) (("-") reduce 483) ((".") reduce 483) (("/") reduce 483) (("<") reduce 483) (("=") shift) ((">") reduce 483) (("?") reduce 483) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_BOOLEAN_AND) reduce 483) ((T_BOOLEAN_OR) reduce 483) ((T_COALESCE) reduce 483) ((T_INSTANCEOF) reduce 483) ((T_IS_EQUAL) reduce 483) ((T_IS_GREATER_OR_EQUAL) reduce 483) ((T_IS_IDENTICAL) reduce 483) ((T_IS_NOT_EQUAL) reduce 483) ((T_IS_NOT_IDENTICAL) reduce 483) ((T_IS_SMALLER_OR_EQUAL) reduce 483) ((T_LOGICAL_AND) reduce 483) ((T_LOGICAL_OR) reduce 483) ((T_LOGICAL_XOR) reduce 483) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 483) ((T_OBJECT_OPERATOR) reduce 483) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 483) ((T_POW) reduce 483) ((T_SL) reduce 483) ((T_SPACESHIP) reduce 483) ((T_SR) reduce 483) (("[") reduce 483) (("]") reduce 483) (("^") reduce 483) (("{") reduce 483) (("|") reduce 483)) 8357 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 369) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 369) ((T_LOGICAL_OR) reduce 369) ((T_LOGICAL_XOR) reduce 369) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 369) (("^") shift) (("|") shift)) 8358 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 443) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 443) ((T_LOGICAL_OR) reduce 443) ((T_LOGICAL_XOR) reduce 443) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 443) (("^") shift) (("|") shift)) 8361 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 442) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 442) ((T_LOGICAL_OR) reduce 442) ((T_LOGICAL_XOR) reduce 442) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 442) (("^") shift) (("|") shift)) 8362 ((("%") reduce 434) (("*") reduce 434) (("+") reduce 434) ((",") reduce 434) (("-") reduce 434) ((".") reduce 434) (("/") reduce 434) (("<") reduce 434) ((">") reduce 434) (("?") reduce 434) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_BOOLEAN_AND) reduce 434) ((T_BOOLEAN_OR) reduce 434) ((T_COALESCE) reduce 434) ((T_INSTANCEOF) reduce 434) ((T_IS_EQUAL) reduce 434) ((T_IS_GREATER_OR_EQUAL) reduce 434) ((T_IS_IDENTICAL) reduce 434) ((T_IS_NOT_EQUAL) reduce 434) ((T_IS_NOT_IDENTICAL) reduce 434) ((T_IS_SMALLER_OR_EQUAL) reduce 434) ((T_LOGICAL_AND) reduce 434) ((T_LOGICAL_OR) reduce 434) ((T_LOGICAL_XOR) reduce 434) ((T_POW) shift) ((T_SL) reduce 434) ((T_SPACESHIP) reduce 434) ((T_SR) reduce 434) (("]") reduce 434) (("^") reduce 434) (("|") reduce 434)) 8363 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 444) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 444) (("^") shift) (("|") shift)) 8364 ((("%") reduce 430) (("*") reduce 430) (("+") reduce 430) ((",") reduce 430) (("-") reduce 430) ((".") reduce 430) (("/") reduce 430) (("<") reduce 430) ((">") reduce 430) (("?") reduce 430) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_BOOLEAN_AND) reduce 430) ((T_BOOLEAN_OR) reduce 430) ((T_COALESCE) reduce 430) ((T_INSTANCEOF) reduce 430) ((T_IS_EQUAL) reduce 430) ((T_IS_GREATER_OR_EQUAL) reduce 430) ((T_IS_IDENTICAL) reduce 430) ((T_IS_NOT_EQUAL) reduce 430) ((T_IS_NOT_IDENTICAL) reduce 430) ((T_IS_SMALLER_OR_EQUAL) reduce 430) ((T_LOGICAL_AND) reduce 430) ((T_LOGICAL_OR) reduce 430) ((T_LOGICAL_XOR) reduce 430) ((T_POW) shift) ((T_SL) reduce 430) ((T_SPACESHIP) reduce 430) ((T_SR) reduce 430) (("]") reduce 430) (("^") reduce 430) (("|") reduce 430)) 8365 ((("%") reduce 447) (("*") reduce 447) (("+") reduce 447) ((",") reduce 447) (("-") reduce 447) ((".") reduce 447) (("/") reduce 447) (("<") reduce 447) ((">") reduce 447) (("?") reduce 447) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_BOOLEAN_AND) reduce 447) ((T_BOOLEAN_OR) reduce 447) ((T_COALESCE) reduce 447) ((T_INSTANCEOF) reduce 447) ((T_IS_EQUAL) reduce 447) ((T_IS_GREATER_OR_EQUAL) reduce 447) ((T_IS_IDENTICAL) reduce 447) ((T_IS_NOT_EQUAL) reduce 447) ((T_IS_NOT_IDENTICAL) reduce 447) ((T_IS_SMALLER_OR_EQUAL) reduce 447) ((T_LOGICAL_AND) reduce 447) ((T_LOGICAL_OR) reduce 447) ((T_LOGICAL_XOR) reduce 447) ((T_POW) reduce 447) ((T_SL) reduce 447) ((T_SPACESHIP) reduce 447) ((T_SR) reduce 447) (("]") reduce 447) (("^") reduce 447) (("|") reduce 447)) 8367 ((("%") reduce 489) (("*") reduce 489) (("+") reduce 489) ((",") reduce 489) (("-") reduce 489) ((".") reduce 489) (("/") reduce 489) (("<") reduce 489) ((">") reduce 489) (("?") reduce 489) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_BOOLEAN_AND) reduce 489) ((T_BOOLEAN_OR) reduce 489) ((T_COALESCE) reduce 489) ((T_INSTANCEOF) reduce 489) ((T_IS_EQUAL) reduce 489) ((T_IS_GREATER_OR_EQUAL) reduce 489) ((T_IS_IDENTICAL) reduce 489) ((T_IS_NOT_EQUAL) reduce 489) ((T_IS_NOT_IDENTICAL) reduce 489) ((T_IS_SMALLER_OR_EQUAL) reduce 489) ((T_LOGICAL_AND) reduce 489) ((T_LOGICAL_OR) reduce 489) ((T_LOGICAL_XOR) reduce 489) ((T_POW) reduce 489) ((T_SL) reduce 489) ((T_SPACESHIP) reduce 489) ((T_SR) reduce 489) (("]") reduce 489) (("^") reduce 489) (("|") reduce 489)) 8369 ((("%") reduce 490) (("*") reduce 490) (("+") reduce 490) ((",") reduce 490) (("-") reduce 490) ((".") reduce 490) (("/") reduce 490) (("<") reduce 490) ((">") reduce 490) (("?") reduce 490) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_BOOLEAN_AND) reduce 490) ((T_BOOLEAN_OR) reduce 490) ((T_COALESCE) reduce 490) ((T_INSTANCEOF) reduce 490) ((T_IS_EQUAL) reduce 490) ((T_IS_GREATER_OR_EQUAL) reduce 490) ((T_IS_IDENTICAL) reduce 490) ((T_IS_NOT_EQUAL) reduce 490) ((T_IS_NOT_IDENTICAL) reduce 490) ((T_IS_SMALLER_OR_EQUAL) reduce 490) ((T_LOGICAL_AND) reduce 490) ((T_LOGICAL_OR) reduce 490) ((T_LOGICAL_XOR) reduce 490) ((T_POW) reduce 490) ((T_SL) reduce 490) ((T_SPACESHIP) reduce 490) ((T_SR) reduce 490) (("]") reduce 490) (("^") reduce 490) (("|") reduce 490)) 8370 ((("%") reduce 488) (("*") reduce 488) (("+") reduce 488) ((",") reduce 488) (("-") reduce 488) ((".") reduce 488) (("/") reduce 488) (("<") reduce 488) ((">") reduce 488) (("?") reduce 488) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_BOOLEAN_AND) reduce 488) ((T_BOOLEAN_OR) reduce 488) ((T_COALESCE) reduce 488) ((T_INSTANCEOF) reduce 488) ((T_IS_EQUAL) reduce 488) ((T_IS_GREATER_OR_EQUAL) reduce 488) ((T_IS_IDENTICAL) reduce 488) ((T_IS_NOT_EQUAL) reduce 488) ((T_IS_NOT_IDENTICAL) reduce 488) ((T_IS_SMALLER_OR_EQUAL) reduce 488) ((T_LOGICAL_AND) reduce 488) ((T_LOGICAL_OR) reduce 488) ((T_LOGICAL_XOR) reduce 488) ((T_POW) reduce 488) ((T_SL) reduce 488) ((T_SPACESHIP) reduce 488) ((T_SR) reduce 488) (("]") reduce 488) (("^") reduce 488) (("|") reduce 488)) 8371 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 581) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 581) (("^") shift) (("|") shift)) 8372 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 580) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 580) (("^") shift) (("|") shift)) 8373 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) ((",") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) (("<") reduce 466) (("=") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AND_EQUAL) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_COALESCE_EQUAL) reduce 466) ((T_CONCAT_EQUAL) reduce 466) ((T_DEC) reduce 466) ((T_DIV_EQUAL) reduce 466) ((T_INC) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_MINUS_EQUAL) reduce 466) ((T_MOD_EQUAL) reduce 466) ((T_MUL_EQUAL) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_OR_EQUAL) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_PLUS_EQUAL) reduce 466) ((T_POW) reduce 466) ((T_POW_EQUAL) reduce 466) ((T_SL) reduce 466) ((T_SL_EQUAL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) ((T_SR_EQUAL) reduce 466) ((T_XOR_EQUAL) reduce 466) (("[") reduce 466) (("]") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 8374 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 439) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 439) ((T_LOGICAL_OR) reduce 439) ((T_LOGICAL_XOR) reduce 439) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 439) (("^") shift) (("|") shift)) 8375 ((("%") reduce 432) (("*") reduce 432) (("+") reduce 432) ((",") reduce 432) (("-") reduce 432) ((".") reduce 432) (("/") reduce 432) (("<") reduce 432) ((">") reduce 432) (("?") reduce 432) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_BOOLEAN_AND) reduce 432) ((T_BOOLEAN_OR) reduce 432) ((T_COALESCE) reduce 432) ((T_INSTANCEOF) reduce 432) ((T_IS_EQUAL) reduce 432) ((T_IS_GREATER_OR_EQUAL) reduce 432) ((T_IS_IDENTICAL) reduce 432) ((T_IS_NOT_EQUAL) reduce 432) ((T_IS_NOT_IDENTICAL) reduce 432) ((T_IS_SMALLER_OR_EQUAL) reduce 432) ((T_LOGICAL_AND) reduce 432) ((T_LOGICAL_OR) reduce 432) ((T_LOGICAL_XOR) reduce 432) ((T_POW) shift) ((T_SL) reduce 432) ((T_SPACESHIP) reduce 432) ((T_SR) reduce 432) (("]") reduce 432) (("^") reduce 432) (("|") reduce 432)) 8377 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) ((",") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("]") reduce 93) (("^") reduce 93) (("|") reduce 93)) 8378 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) ((",") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("]") reduce 92) (("^") reduce 92) (("|") reduce 92)) 8379 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) ((",") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("]") reduce 94) (("^") reduce 94) (("|") reduce 94)) 8380 ((("%") reduce 470) (("(") reduce 470) (("*") reduce 470) (("+") reduce 470) ((",") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("]") reduce 470) (("^") reduce 470) (("|") reduce 470)) 8381 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) ((",") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("]") reduce 91) (("^") reduce 91) (("|") reduce 91)) 8382 ((("%") reduce 365) (("*") reduce 365) (("+") reduce 365) ((",") reduce 365) (("-") reduce 365) ((".") reduce 365) (("/") reduce 365) (("<") reduce 365) ((">") reduce 365) (("?") reduce 365) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_BOOLEAN_AND) reduce 365) ((T_BOOLEAN_OR) reduce 365) ((T_COALESCE) reduce 365) ((T_INSTANCEOF) reduce 365) ((T_IS_EQUAL) reduce 365) ((T_IS_GREATER_OR_EQUAL) reduce 365) ((T_IS_IDENTICAL) reduce 365) ((T_IS_NOT_EQUAL) reduce 365) ((T_IS_NOT_IDENTICAL) reduce 365) ((T_IS_SMALLER_OR_EQUAL) reduce 365) ((T_LOGICAL_AND) reduce 365) ((T_LOGICAL_OR) reduce 365) ((T_LOGICAL_XOR) reduce 365) ((T_POW) reduce 365) ((T_SL) reduce 365) ((T_SPACESHIP) reduce 365) ((T_SR) reduce 365) (("]") reduce 365) (("^") reduce 365) (("|") reduce 365)) 8385 ((("%") reduce 472) (("(") reduce 472) (("*") reduce 472) (("+") reduce 472) ((",") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("]") reduce 472) (("^") reduce 472) (("|") reduce 472)) 8386 ((("%") reduce 480) (("(") shift) (("*") reduce 480) (("+") reduce 480) ((",") reduce 480) (("-") reduce 480) ((".") reduce 480) (("/") reduce 480) (("<") reduce 480) ((">") reduce 480) (("?") reduce 480) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_BOOLEAN_AND) reduce 480) ((T_BOOLEAN_OR) reduce 480) ((T_COALESCE) reduce 480) ((T_INSTANCEOF) reduce 480) ((T_IS_EQUAL) reduce 480) ((T_IS_GREATER_OR_EQUAL) reduce 480) ((T_IS_IDENTICAL) reduce 480) ((T_IS_NOT_EQUAL) reduce 480) ((T_IS_NOT_IDENTICAL) reduce 480) ((T_IS_SMALLER_OR_EQUAL) reduce 480) ((T_LOGICAL_AND) reduce 480) ((T_LOGICAL_OR) reduce 480) ((T_LOGICAL_XOR) reduce 480) ((T_POW) reduce 480) ((T_SL) reduce 480) ((T_SPACESHIP) reduce 480) ((T_SR) reduce 480) (("]") reduce 480) (("^") reduce 480) (("|") reduce 480)) 8387 ((("%") reduce 471) (("(") reduce 471) (("*") reduce 471) (("+") reduce 471) ((",") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("]") reduce 471) (("^") reduce 471) (("|") reduce 471)) 8388 ((("%") reduce 473) (("(") reduce 473) (("*") reduce 473) (("+") reduce 473) ((",") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("]") reduce 473) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 8389 ((("%") reduce 534) (("(") reduce 534) (("*") reduce 534) (("+") reduce 534) ((",") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("]") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 8396 ((("%") reduce 536) (("(") reduce 536) (("*") reduce 536) (("+") reduce 536) ((",") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("]") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 8398 ((("%") reduce 535) (("(") reduce 535) (("*") reduce 535) (("+") reduce 535) ((",") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("]") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 8399 ((("%") reduce 540) (("(") reduce 540) (("*") reduce 540) (("+") reduce 540) ((",") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("]") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 8400 ((("%") reduce 537) (("(") reduce 537) (("*") reduce 537) (("+") reduce 537) ((",") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("]") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 8401 ((("%") reduce 538) (("(") reduce 538) (("*") reduce 538) (("+") reduce 538) ((",") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("]") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 8403 ((("%") reduce 481) (("*") reduce 481) (("+") reduce 481) ((",") reduce 481) (("-") reduce 481) ((".") reduce 481) (("/") reduce 481) (("<") reduce 481) ((">") reduce 481) (("?") reduce 481) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_BOOLEAN_AND) reduce 481) ((T_BOOLEAN_OR) reduce 481) ((T_COALESCE) reduce 481) ((T_INSTANCEOF) reduce 481) ((T_IS_EQUAL) reduce 481) ((T_IS_GREATER_OR_EQUAL) reduce 481) ((T_IS_IDENTICAL) reduce 481) ((T_IS_NOT_EQUAL) reduce 481) ((T_IS_NOT_IDENTICAL) reduce 481) ((T_IS_SMALLER_OR_EQUAL) reduce 481) ((T_LOGICAL_AND) reduce 481) ((T_LOGICAL_OR) reduce 481) ((T_LOGICAL_XOR) reduce 481) ((T_POW) reduce 481) ((T_SL) reduce 481) ((T_SPACESHIP) reduce 481) ((T_SR) reduce 481) (("]") reduce 481) (("^") reduce 481) (("|") reduce 481)) 8404 ((("%") reduce 364) (("*") reduce 364) (("+") reduce 364) ((",") reduce 364) (("-") reduce 364) ((".") reduce 364) (("/") reduce 364) (("<") reduce 364) ((">") reduce 364) (("?") reduce 364) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_BOOLEAN_AND) reduce 364) ((T_BOOLEAN_OR) reduce 364) ((T_COALESCE) reduce 364) ((T_INSTANCEOF) reduce 364) ((T_IS_EQUAL) reduce 364) ((T_IS_GREATER_OR_EQUAL) reduce 364) ((T_IS_IDENTICAL) reduce 364) ((T_IS_NOT_EQUAL) reduce 364) ((T_IS_NOT_IDENTICAL) reduce 364) ((T_IS_SMALLER_OR_EQUAL) reduce 364) ((T_LOGICAL_AND) reduce 364) ((T_LOGICAL_OR) reduce 364) ((T_LOGICAL_XOR) reduce 364) ((T_POW) reduce 364) ((T_SL) reduce 364) ((T_SPACESHIP) reduce 364) ((T_SR) reduce 364) (("]") reduce 364) (("^") reduce 364) (("|") reduce 364)) 8405 ((("%") reduce 288) (("*") reduce 288) (("+") reduce 288) ((",") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("]") reduce 288) (("^") reduce 288) (("|") reduce 288)) 8409 ((("%") reduce 289) (("*") reduce 289) (("+") reduce 289) ((",") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("]") reduce 289) (("^") reduce 289) (("|") reduce 289)) 8410 ((("%") reduce 290) (("*") reduce 290) (("+") reduce 290) ((",") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("]") reduce 290) (("^") reduce 290) (("|") reduce 290)) 8412 ((("%") reduce 539) (("(") reduce 539) (("*") reduce 539) (("+") reduce 539) ((",") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("]") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 8413 ((("%") reduce 366) (("*") reduce 366) (("+") reduce 366) ((",") reduce 366) (("-") reduce 366) ((".") reduce 366) (("/") reduce 366) (("<") reduce 366) ((">") reduce 366) (("?") reduce 366) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_BOOLEAN_AND) reduce 366) ((T_BOOLEAN_OR) reduce 366) ((T_COALESCE) reduce 366) ((T_INSTANCEOF) reduce 366) ((T_IS_EQUAL) reduce 366) ((T_IS_GREATER_OR_EQUAL) reduce 366) ((T_IS_IDENTICAL) reduce 366) ((T_IS_NOT_EQUAL) reduce 366) ((T_IS_NOT_IDENTICAL) reduce 366) ((T_IS_SMALLER_OR_EQUAL) reduce 366) ((T_LOGICAL_AND) reduce 366) ((T_LOGICAL_OR) reduce 366) ((T_LOGICAL_XOR) reduce 366) ((T_POW) reduce 366) ((T_SL) reduce 366) ((T_SPACESHIP) reduce 366) ((T_SR) reduce 366) (("]") reduce 366) (("^") reduce 366) (("|") reduce 366)) 8421 ((("%") reduce 363) (("*") reduce 363) (("+") reduce 363) ((",") reduce 363) (("-") reduce 363) ((".") reduce 363) (("/") reduce 363) (("<") reduce 363) ((">") reduce 363) (("?") reduce 363) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_BOOLEAN_AND) reduce 363) ((T_BOOLEAN_OR) reduce 363) ((T_COALESCE) reduce 363) ((T_INSTANCEOF) reduce 363) ((T_IS_EQUAL) reduce 363) ((T_IS_GREATER_OR_EQUAL) reduce 363) ((T_IS_IDENTICAL) reduce 363) ((T_IS_NOT_EQUAL) reduce 363) ((T_IS_NOT_IDENTICAL) reduce 363) ((T_IS_SMALLER_OR_EQUAL) reduce 363) ((T_LOGICAL_AND) reduce 363) ((T_LOGICAL_OR) reduce 363) ((T_LOGICAL_XOR) reduce 363) ((T_POW) reduce 363) ((T_SL) reduce 363) ((T_SPACESHIP) reduce 363) ((T_SR) reduce 363) (("]") reduce 363) (("^") reduce 363) (("|") reduce 363)) 8423 ((("%") reduce 474) (("(") reduce 474) (("*") reduce 474) (("+") reduce 474) ((",") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("]") reduce 474) (("^") reduce 474) (("|") reduce 474)) 8429 ((("%") reduce 230) (("*") reduce 230) (("+") reduce 230) ((",") reduce 230) (("-") reduce 230) ((".") reduce 230) (("/") reduce 230) (("<") reduce 230) ((">") reduce 230) (("?") reduce 230) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_BOOLEAN_AND) reduce 230) ((T_BOOLEAN_OR) reduce 230) ((T_COALESCE) reduce 230) ((T_INSTANCEOF) reduce 230) ((T_IS_EQUAL) reduce 230) ((T_IS_GREATER_OR_EQUAL) reduce 230) ((T_IS_IDENTICAL) reduce 230) ((T_IS_NOT_EQUAL) reduce 230) ((T_IS_NOT_IDENTICAL) reduce 230) ((T_IS_SMALLER_OR_EQUAL) reduce 230) ((T_LOGICAL_AND) reduce 230) ((T_LOGICAL_OR) reduce 230) ((T_LOGICAL_XOR) reduce 230) ((T_POW) reduce 230) ((T_SL) reduce 230) ((T_SPACESHIP) reduce 230) ((T_SR) reduce 230) (("]") reduce 230) (("^") reduce 230) (("|") reduce 230)) 8438 ((("%") reduce 575) (("*") reduce 575) (("+") reduce 575) ((",") reduce 575) (("-") reduce 575) ((".") reduce 575) (("/") reduce 575) (("<") reduce 575) ((">") reduce 575) (("?") reduce 575) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_BOOLEAN_AND) reduce 575) ((T_BOOLEAN_OR) reduce 575) ((T_COALESCE) reduce 575) ((T_INSTANCEOF) reduce 575) ((T_IS_EQUAL) reduce 575) ((T_IS_GREATER_OR_EQUAL) reduce 575) ((T_IS_IDENTICAL) reduce 575) ((T_IS_NOT_EQUAL) reduce 575) ((T_IS_NOT_IDENTICAL) reduce 575) ((T_IS_SMALLER_OR_EQUAL) reduce 575) ((T_LOGICAL_AND) reduce 575) ((T_LOGICAL_OR) reduce 575) ((T_LOGICAL_XOR) reduce 575) ((T_POW) reduce 575) ((T_SL) reduce 575) ((T_SPACESHIP) reduce 575) ((T_SR) reduce 575) (("]") reduce 575) (("^") reduce 575) (("|") reduce 575)) 8439 ((("%") reduce 428) (("*") reduce 428) (("+") reduce 428) ((",") reduce 428) (("-") reduce 428) ((".") reduce 428) (("/") reduce 428) (("<") reduce 428) ((">") reduce 428) (("?") reduce 428) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_BOOLEAN_AND) reduce 428) ((T_BOOLEAN_OR) reduce 428) ((T_COALESCE) reduce 428) ((T_INSTANCEOF) reduce 428) ((T_IS_EQUAL) reduce 428) ((T_IS_GREATER_OR_EQUAL) reduce 428) ((T_IS_IDENTICAL) reduce 428) ((T_IS_NOT_EQUAL) reduce 428) ((T_IS_NOT_IDENTICAL) reduce 428) ((T_IS_SMALLER_OR_EQUAL) reduce 428) ((T_LOGICAL_AND) reduce 428) ((T_LOGICAL_OR) reduce 428) ((T_LOGICAL_XOR) reduce 428) ((T_POW) shift) ((T_SL) reduce 428) ((T_SPACESHIP) reduce 428) ((T_SR) reduce 428) (("]") reduce 428) (("^") reduce 428) (("|") reduce 428)) 8440 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 578) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 578) (("^") shift) (("|") shift)) 8441 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 577) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 577) (("^") shift) (("|") shift)) 8442 ((("%") reduce 387) (("*") reduce 387) (("+") reduce 387) ((",") reduce 387) (("-") reduce 387) ((".") reduce 387) (("/") reduce 387) (("<") reduce 387) ((">") reduce 387) (("?") reduce 387) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_BOOLEAN_AND) reduce 387) ((T_BOOLEAN_OR) reduce 387) ((T_COALESCE) reduce 387) ((T_INSTANCEOF) reduce 387) ((T_IS_EQUAL) reduce 387) ((T_IS_GREATER_OR_EQUAL) reduce 387) ((T_IS_IDENTICAL) reduce 387) ((T_IS_NOT_EQUAL) reduce 387) ((T_IS_NOT_IDENTICAL) reduce 387) ((T_IS_SMALLER_OR_EQUAL) reduce 387) ((T_LOGICAL_AND) reduce 387) ((T_LOGICAL_OR) reduce 387) ((T_LOGICAL_XOR) reduce 387) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 387) ((T_SL) reduce 387) ((T_SPACESHIP) reduce 387) ((T_SR) reduce 387) (("[") reduce 510) (("]") reduce 387) (("^") reduce 387) (("{") reduce 510) (("|") reduce 387)) 8444 ((("%") reduce 435) (("*") reduce 435) (("+") reduce 435) ((",") reduce 435) (("-") reduce 435) ((".") reduce 435) (("/") reduce 435) (("<") reduce 435) ((">") reduce 435) (("?") reduce 435) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_BOOLEAN_AND) reduce 435) ((T_BOOLEAN_OR) reduce 435) ((T_COALESCE) reduce 435) ((T_INSTANCEOF) reduce 435) ((T_IS_EQUAL) reduce 435) ((T_IS_GREATER_OR_EQUAL) reduce 435) ((T_IS_IDENTICAL) reduce 435) ((T_IS_NOT_EQUAL) reduce 435) ((T_IS_NOT_IDENTICAL) reduce 435) ((T_IS_SMALLER_OR_EQUAL) reduce 435) ((T_LOGICAL_AND) reduce 435) ((T_LOGICAL_OR) reduce 435) ((T_LOGICAL_XOR) reduce 435) ((T_POW) reduce 435) ((T_SL) reduce 435) ((T_SPACESHIP) reduce 435) ((T_SR) reduce 435) (("]") reduce 435) (("^") reduce 435) (("|") reduce 435)) 8446 ((("%") reduce 476) (("*") reduce 476) (("+") reduce 476) ((",") reduce 476) (("-") reduce 476) ((".") reduce 476) (("/") reduce 476) (("<") reduce 476) ((">") reduce 476) (("?") reduce 476) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_BOOLEAN_AND) reduce 476) ((T_BOOLEAN_OR) reduce 476) ((T_COALESCE) reduce 476) ((T_INSTANCEOF) reduce 476) ((T_IS_EQUAL) reduce 476) ((T_IS_GREATER_OR_EQUAL) reduce 476) ((T_IS_IDENTICAL) reduce 476) ((T_IS_NOT_EQUAL) reduce 476) ((T_IS_NOT_IDENTICAL) reduce 476) ((T_IS_SMALLER_OR_EQUAL) reduce 476) ((T_LOGICAL_AND) reduce 476) ((T_LOGICAL_OR) reduce 476) ((T_LOGICAL_XOR) reduce 476) ((T_POW) reduce 476) ((T_SL) reduce 476) ((T_SPACESHIP) reduce 476) ((T_SR) reduce 476) (("]") reduce 476) (("^") reduce 476) (("|") reduce 476)) 8449 ((("%") reduce 579) (("*") reduce 579) (("+") reduce 579) ((",") reduce 579) (("-") reduce 579) ((".") reduce 579) (("/") reduce 579) (("<") reduce 579) ((">") reduce 579) (("?") reduce 579) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_BOOLEAN_AND) reduce 579) ((T_BOOLEAN_OR) reduce 579) ((T_COALESCE) reduce 579) ((T_INSTANCEOF) reduce 579) ((T_IS_EQUAL) reduce 579) ((T_IS_GREATER_OR_EQUAL) reduce 579) ((T_IS_IDENTICAL) reduce 579) ((T_IS_NOT_EQUAL) reduce 579) ((T_IS_NOT_IDENTICAL) reduce 579) ((T_IS_SMALLER_OR_EQUAL) reduce 579) ((T_LOGICAL_AND) reduce 579) ((T_LOGICAL_OR) reduce 579) ((T_LOGICAL_XOR) reduce 579) ((T_POW) reduce 579) ((T_SL) reduce 579) ((T_SPACESHIP) reduce 579) ((T_SR) reduce 579) (("]") reduce 579) (("^") reduce 579) (("|") reduce 579)) 8452 ((("%") reduce 576) (("*") reduce 576) (("+") reduce 576) ((",") reduce 576) (("-") reduce 576) ((".") reduce 576) (("/") reduce 576) (("<") reduce 576) ((">") reduce 576) (("?") reduce 576) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_BOOLEAN_AND) reduce 576) ((T_BOOLEAN_OR) reduce 576) ((T_COALESCE) reduce 576) ((T_INSTANCEOF) reduce 576) ((T_IS_EQUAL) reduce 576) ((T_IS_GREATER_OR_EQUAL) reduce 576) ((T_IS_IDENTICAL) reduce 576) ((T_IS_NOT_EQUAL) reduce 576) ((T_IS_NOT_IDENTICAL) reduce 576) ((T_IS_SMALLER_OR_EQUAL) reduce 576) ((T_LOGICAL_AND) reduce 576) ((T_LOGICAL_OR) reduce 576) ((T_LOGICAL_XOR) reduce 576) ((T_POW) reduce 576) ((T_SL) reduce 576) ((T_SPACESHIP) reduce 576) ((T_SR) reduce 576) (("]") reduce 576) (("^") reduce 576) (("|") reduce 576)) 8453 ((("%") reduce 429) (("*") reduce 429) (("+") reduce 429) ((",") reduce 429) (("-") reduce 429) ((".") reduce 429) (("/") reduce 429) (("<") reduce 429) ((">") reduce 429) (("?") reduce 429) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_BOOLEAN_AND) reduce 429) ((T_BOOLEAN_OR) reduce 429) ((T_COALESCE) reduce 429) ((T_INSTANCEOF) reduce 429) ((T_IS_EQUAL) reduce 429) ((T_IS_GREATER_OR_EQUAL) reduce 429) ((T_IS_IDENTICAL) reduce 429) ((T_IS_NOT_EQUAL) reduce 429) ((T_IS_NOT_IDENTICAL) reduce 429) ((T_IS_SMALLER_OR_EQUAL) reduce 429) ((T_LOGICAL_AND) reduce 429) ((T_LOGICAL_OR) reduce 429) ((T_LOGICAL_XOR) reduce 429) ((T_POW) shift) ((T_SL) reduce 429) ((T_SPACESHIP) reduce 429) ((T_SR) reduce 429) (("]") reduce 429) (("^") reduce 429) (("|") reduce 429)) 8454 ((("%") reduce 389) (("*") reduce 389) (("+") reduce 389) ((",") reduce 389) (("-") reduce 389) ((".") reduce 389) (("/") reduce 389) (("<") reduce 389) ((">") reduce 389) (("?") reduce 389) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_BOOLEAN_AND) reduce 389) ((T_BOOLEAN_OR) reduce 389) ((T_COALESCE) reduce 389) ((T_INSTANCEOF) reduce 389) ((T_IS_EQUAL) reduce 389) ((T_IS_GREATER_OR_EQUAL) reduce 389) ((T_IS_IDENTICAL) reduce 389) ((T_IS_NOT_EQUAL) reduce 389) ((T_IS_NOT_IDENTICAL) reduce 389) ((T_IS_SMALLER_OR_EQUAL) reduce 389) ((T_LOGICAL_AND) reduce 389) ((T_LOGICAL_OR) reduce 389) ((T_LOGICAL_XOR) reduce 389) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 389) ((T_SL) reduce 389) ((T_SPACESHIP) reduce 389) ((T_SR) reduce 389) (("[") reduce 510) (("]") reduce 389) (("^") reduce 389) (("{") reduce 510) (("|") reduce 389)) 8455 ((("%") reduce 372) (("*") reduce 372) (("+") reduce 372) ((",") reduce 372) (("-") reduce 372) ((".") reduce 372) (("/") reduce 372) (("<") reduce 372) ((">") reduce 372) (("?") reduce 372) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_BOOLEAN_AND) reduce 372) ((T_BOOLEAN_OR) reduce 372) ((T_COALESCE) reduce 372) ((T_INSTANCEOF) reduce 372) ((T_IS_EQUAL) reduce 372) ((T_IS_GREATER_OR_EQUAL) reduce 372) ((T_IS_IDENTICAL) reduce 372) ((T_IS_NOT_EQUAL) reduce 372) ((T_IS_NOT_IDENTICAL) reduce 372) ((T_IS_SMALLER_OR_EQUAL) reduce 372) ((T_LOGICAL_AND) reduce 372) ((T_LOGICAL_OR) reduce 372) ((T_LOGICAL_XOR) reduce 372) ((T_POW) reduce 372) ((T_SL) reduce 372) ((T_SPACESHIP) reduce 372) ((T_SR) reduce 372) (("]") reduce 372) (("^") reduce 372) (("|") reduce 372)) 8456 ((("%") reduce 433) (("*") reduce 433) (("+") reduce 433) ((",") reduce 433) (("-") reduce 433) ((".") reduce 433) (("/") reduce 433) (("<") reduce 433) ((">") reduce 433) (("?") reduce 433) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_BOOLEAN_AND) reduce 433) ((T_BOOLEAN_OR) reduce 433) ((T_COALESCE) reduce 433) ((T_INSTANCEOF) reduce 433) ((T_IS_EQUAL) reduce 433) ((T_IS_GREATER_OR_EQUAL) reduce 433) ((T_IS_IDENTICAL) reduce 433) ((T_IS_NOT_EQUAL) reduce 433) ((T_IS_NOT_IDENTICAL) reduce 433) ((T_IS_SMALLER_OR_EQUAL) reduce 433) ((T_LOGICAL_AND) reduce 433) ((T_LOGICAL_OR) reduce 433) ((T_LOGICAL_XOR) reduce 433) ((T_POW) shift) ((T_SL) reduce 433) ((T_SPACESHIP) reduce 433) ((T_SR) reduce 433) (("]") reduce 433) (("^") reduce 433) (("|") reduce 433)) 8457 ((("%") reduce 431) (("*") reduce 431) (("+") reduce 431) ((",") reduce 431) (("-") reduce 431) ((".") reduce 431) (("/") reduce 431) (("<") reduce 431) ((">") reduce 431) (("?") reduce 431) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_BOOLEAN_AND) reduce 431) ((T_BOOLEAN_OR) reduce 431) ((T_COALESCE) reduce 431) ((T_INSTANCEOF) reduce 431) ((T_IS_EQUAL) reduce 431) ((T_IS_GREATER_OR_EQUAL) reduce 431) ((T_IS_IDENTICAL) reduce 431) ((T_IS_NOT_EQUAL) reduce 431) ((T_IS_NOT_IDENTICAL) reduce 431) ((T_IS_SMALLER_OR_EQUAL) reduce 431) ((T_LOGICAL_AND) reduce 431) ((T_LOGICAL_OR) reduce 431) ((T_LOGICAL_XOR) reduce 431) ((T_POW) shift) ((T_SL) reduce 431) ((T_SPACESHIP) reduce 431) ((T_SR) reduce 431) (("]") reduce 431) (("^") reduce 431) (("|") reduce 431)) 8460 ((("%") reduce 482) (("(") reduce 482) (("*") reduce 482) (("+") reduce 482) ((",") reduce 482) (("-") reduce 482) ((".") reduce 482) (("/") reduce 482) (("<") reduce 482) ((">") reduce 482) (("?") reduce 482) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_BOOLEAN_AND) reduce 482) ((T_BOOLEAN_OR) reduce 482) ((T_COALESCE) reduce 482) ((T_INSTANCEOF) reduce 482) ((T_IS_EQUAL) reduce 482) ((T_IS_GREATER_OR_EQUAL) reduce 482) ((T_IS_IDENTICAL) reduce 482) ((T_IS_NOT_EQUAL) reduce 482) ((T_IS_NOT_IDENTICAL) reduce 482) ((T_IS_SMALLER_OR_EQUAL) reduce 482) ((T_LOGICAL_AND) reduce 482) ((T_LOGICAL_OR) reduce 482) ((T_LOGICAL_XOR) reduce 482) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 482) ((T_OBJECT_OPERATOR) reduce 482) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 482) ((T_POW) reduce 482) ((T_SL) reduce 482) ((T_SPACESHIP) reduce 482) ((T_SR) reduce 482) (("[") reduce 482) (("]") reduce 482) (("^") reduce 482) (("{") reduce 482) (("|") reduce 482)) 8461 ((("%") reduce 436) (("*") reduce 436) (("+") reduce 436) ((",") reduce 436) (("-") reduce 436) ((".") reduce 436) (("/") reduce 436) (("<") reduce 436) ((">") reduce 436) (("?") reduce 436) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_BOOLEAN_AND) reduce 436) ((T_BOOLEAN_OR) reduce 436) ((T_COALESCE) reduce 436) ((T_INSTANCEOF) reduce 436) ((T_IS_EQUAL) reduce 436) ((T_IS_GREATER_OR_EQUAL) reduce 436) ((T_IS_IDENTICAL) reduce 436) ((T_IS_NOT_EQUAL) reduce 436) ((T_IS_NOT_IDENTICAL) reduce 436) ((T_IS_SMALLER_OR_EQUAL) reduce 436) ((T_LOGICAL_AND) reduce 436) ((T_LOGICAL_OR) reduce 436) ((T_LOGICAL_XOR) reduce 436) ((T_POW) shift) ((T_SL) reduce 436) ((T_SPACESHIP) reduce 436) ((T_SR) reduce 436) (("]") reduce 436) (("^") reduce 436) (("|") reduce 436)) 8462 ((("%") reduce 409) (("*") reduce 409) (("+") reduce 409) ((",") reduce 409) (("-") reduce 409) ((".") reduce 409) (("/") reduce 409) (("<") reduce 409) ((">") reduce 409) (("?") reduce 409) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_BOOLEAN_AND) reduce 409) ((T_BOOLEAN_OR) reduce 409) ((T_COALESCE) reduce 409) ((T_INSTANCEOF) reduce 409) ((T_IS_EQUAL) reduce 409) ((T_IS_GREATER_OR_EQUAL) reduce 409) ((T_IS_IDENTICAL) reduce 409) ((T_IS_NOT_EQUAL) reduce 409) ((T_IS_NOT_IDENTICAL) reduce 409) ((T_IS_SMALLER_OR_EQUAL) reduce 409) ((T_LOGICAL_AND) reduce 409) ((T_LOGICAL_OR) reduce 409) ((T_LOGICAL_XOR) reduce 409) ((T_POW) shift) ((T_SL) reduce 409) ((T_SPACESHIP) reduce 409) ((T_SR) reduce 409) (("]") reduce 409) (("^") reduce 409) (("|") reduce 409)) 8463 ((("%") reduce 408) (("*") reduce 408) (("+") reduce 408) ((",") reduce 408) (("-") reduce 408) ((".") reduce 408) (("/") reduce 408) (("<") reduce 408) ((">") reduce 408) (("?") reduce 408) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_BOOLEAN_AND) reduce 408) ((T_BOOLEAN_OR) reduce 408) ((T_COALESCE) reduce 408) ((T_INSTANCEOF) reduce 408) ((T_IS_EQUAL) reduce 408) ((T_IS_GREATER_OR_EQUAL) reduce 408) ((T_IS_IDENTICAL) reduce 408) ((T_IS_NOT_EQUAL) reduce 408) ((T_IS_NOT_IDENTICAL) reduce 408) ((T_IS_SMALLER_OR_EQUAL) reduce 408) ((T_LOGICAL_AND) reduce 408) ((T_LOGICAL_OR) reduce 408) ((T_LOGICAL_XOR) reduce 408) ((T_POW) shift) ((T_SL) reduce 408) ((T_SPACESHIP) reduce 408) ((T_SR) reduce 408) (("]") reduce 408) (("^") reduce 408) (("|") reduce 408)) 8465 ((("%") reduce 422) (("(") reduce 517) (("*") reduce 422) (("+") reduce 422) ((",") reduce 422) (("-") reduce 422) ((".") reduce 422) (("/") reduce 422) (("<") reduce 422) ((">") reduce 422) (("?") reduce 422) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_BOOLEAN_AND) reduce 422) ((T_BOOLEAN_OR) reduce 422) ((T_COALESCE) reduce 422) ((T_INSTANCEOF) reduce 422) ((T_IS_EQUAL) reduce 422) ((T_IS_GREATER_OR_EQUAL) reduce 422) ((T_IS_IDENTICAL) reduce 422) ((T_IS_NOT_EQUAL) reduce 422) ((T_IS_NOT_IDENTICAL) reduce 422) ((T_IS_SMALLER_OR_EQUAL) reduce 422) ((T_LOGICAL_AND) reduce 422) ((T_LOGICAL_OR) reduce 422) ((T_LOGICAL_XOR) reduce 422) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 511) ((T_OBJECT_OPERATOR) reduce 511) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 511) ((T_POW) reduce 422) ((T_SL) reduce 422) ((T_SPACESHIP) reduce 422) ((T_SR) reduce 422) (("[") reduce 511) (("]") reduce 422) (("^") reduce 422) (("{") reduce 511) (("|") reduce 422)) 8466 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) ((",") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) (("=") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AND_EQUAL) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_COALESCE_EQUAL) reduce 531) ((T_CONCAT_EQUAL) reduce 531) ((T_DEC) reduce 531) ((T_DIV_EQUAL) reduce 531) ((T_INC) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_MINUS_EQUAL) reduce 531) ((T_MOD_EQUAL) reduce 531) ((T_MUL_EQUAL) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_OR_EQUAL) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_PLUS_EQUAL) reduce 531) ((T_POW) reduce 531) ((T_POW_EQUAL) reduce 531) ((T_SL) reduce 531) ((T_SL_EQUAL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) ((T_SR_EQUAL) reduce 531) ((T_XOR_EQUAL) reduce 531) (("[") reduce 531) (("]") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 8469 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) ((",") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) (("=") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AND_EQUAL) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_COALESCE_EQUAL) reduce 530) ((T_CONCAT_EQUAL) reduce 530) ((T_DEC) reduce 530) ((T_DIV_EQUAL) reduce 530) ((T_INC) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_MINUS_EQUAL) reduce 530) ((T_MOD_EQUAL) reduce 530) ((T_MUL_EQUAL) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_OR_EQUAL) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_PLUS_EQUAL) reduce 530) ((T_POW) reduce 530) ((T_POW_EQUAL) reduce 530) ((T_SL) reduce 530) ((T_SL_EQUAL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) ((T_SR_EQUAL) reduce 530) ((T_XOR_EQUAL) reduce 530) (("[") reduce 530) (("]") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 8471 ((("%") reduce 485) (("(") reduce 485) (("*") reduce 485) (("+") reduce 485) ((",") reduce 485) (("-") reduce 485) ((".") reduce 485) (("/") reduce 485) (("<") reduce 485) ((">") reduce 485) (("?") reduce 485) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_BOOLEAN_AND) reduce 485) ((T_BOOLEAN_OR) reduce 485) ((T_COALESCE) reduce 485) ((T_INSTANCEOF) reduce 485) ((T_IS_EQUAL) reduce 485) ((T_IS_GREATER_OR_EQUAL) reduce 485) ((T_IS_IDENTICAL) reduce 485) ((T_IS_NOT_EQUAL) reduce 485) ((T_IS_NOT_IDENTICAL) reduce 485) ((T_IS_SMALLER_OR_EQUAL) reduce 485) ((T_LOGICAL_AND) reduce 485) ((T_LOGICAL_OR) reduce 485) ((T_LOGICAL_XOR) reduce 485) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 485) ((T_OBJECT_OPERATOR) reduce 485) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 485) ((T_POW) reduce 485) ((T_SL) reduce 485) ((T_SPACESHIP) reduce 485) ((T_SR) reduce 485) (("[") reduce 485) (("]") reduce 485) (("^") reduce 485) (("{") reduce 485) (("|") reduce 485)) 8472 ((("%") reduce 410) (("*") reduce 410) (("+") reduce 410) ((",") reduce 410) (("-") reduce 410) ((".") reduce 410) (("/") reduce 410) (("<") reduce 410) ((">") reduce 410) (("?") reduce 410) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_BOOLEAN_AND) reduce 410) ((T_BOOLEAN_OR) reduce 410) ((T_COALESCE) reduce 410) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 410) ((T_IS_GREATER_OR_EQUAL) reduce 410) ((T_IS_IDENTICAL) reduce 410) ((T_IS_NOT_EQUAL) reduce 410) ((T_IS_NOT_IDENTICAL) reduce 410) ((T_IS_SMALLER_OR_EQUAL) reduce 410) ((T_LOGICAL_AND) reduce 410) ((T_LOGICAL_OR) reduce 410) ((T_LOGICAL_XOR) reduce 410) ((T_POW) shift) ((T_SL) reduce 410) ((T_SPACESHIP) reduce 410) ((T_SR) reduce 410) (("]") reduce 410) (("^") reduce 410) (("|") reduce 410)) 8504 ((("(") reduce 529) ((",") reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) (("[") reduce 529) (("]") reduce 529) (("{") reduce 529)) 8507 ((("(") reduce 516) ((",") reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) (("[") reduce 525) (("]") reduce 525) (("{") reduce 525)) 8509 ((("(") reduce 524) ((",") reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) (("[") reduce 524) (("]") reduce 524) (("{") reduce 524)) 8511 ((("(") reduce 519) ((",") reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) (("[") reduce 519) (("]") reduce 519) (("{") reduce 519)) 8512 (((",") reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) (("[") reduce 526) (("]") reduce 526) (("{") reduce 526)) 8513 (((",") reduce 554) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) (("[") reduce 510) (("]") reduce 554) (("{") reduce 510)) 8517 ((("(") reduce 543) ((",") reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) (("[") reduce 533) (("]") reduce 533) (("{") reduce 533)) 8519 ((("(") reduce 468) ((",") reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) (("[") reduce 468) (("]") reduce 468) (("{") reduce 468)) 8520 ((("(") reduce 288) ((",") reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) (("[") reduce 288) (("]") reduce 288) (("{") reduce 288)) 8524 ((("(") reduce 289) ((",") reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) (("[") reduce 289) (("]") reduce 289) (("{") reduce 289)) 8525 ((("(") reduce 290) ((",") reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) (("[") reduce 290) (("]") reduce 290) (("{") reduce 290)) 8526 ((("(") reduce 465) ((",") reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) (("[") reduce 465) (("]") reduce 465) (("{") reduce 465)) 8529 ((("(") reduce 543) ((",") reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) (("[") reduce 532) (("]") reduce 532) (("{") reduce 532)) 8530 ((("(") reduce 467) ((",") reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) (("[") reduce 467) (("]") reduce 467) (("{") reduce 467)) 8531 ((("(") reduce 469) ((",") reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) (("[") reduce 469) (("]") reduce 469) (("{") reduce 469)) 8537 ((("(") reduce 521) ((",") reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) (("[") reduce 521) (("]") reduce 521) (("{") reduce 521)) 8539 ((("(") reduce 520) ((",") reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) (("[") reduce 520) (("]") reduce 520) (("{") reduce 520)) 8540 ((("(") reduce 544) ((",") reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) (("[") reduce 544) (("]") reduce 544) (("{") reduce 544)) 8541 ((("(") shift) ((",") reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) (("[") reduce 527) (("]") reduce 527) (("{") reduce 527)) 8542 ((("(") reduce 546) ((",") reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) (("[") reduce 546) (("]") reduce 546) (("{") reduce 546)) 8545 ((("(") reduce 545) ((",") reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) (("[") reduce 545) (("]") reduce 545) (("{") reduce 545)) 8546 ((("(") reduce 522) ((",") reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) (("[") reduce 522) (("]") reduce 522) (("{") reduce 522)) 8547 ((("(") shift) ((",") reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) (("[") reduce 528) (("]") reduce 528) (("{") reduce 528)) 8548 ((("(") reduce 523) ((",") reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) (("[") reduce 523) (("]") reduce 523) (("{") reduce 523)) 8549 ((("(") reduce 466) ((",") reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) (("[") reduce 466) (("]") reduce 466) (("{") reduce 466)) 8550 ((("(") reduce 531) ((",") reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) (("[") reduce 531) (("]") reduce 531) (("{") reduce 531)) 8553 ((("(") reduce 530) ((",") reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) (("[") reduce 530) (("]") reduce 530) (("{") reduce 530)) 8608 (((",") reduce 557) (("=") shift) (("]") reduce 557)) 8659 ((("(") reduce 483) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 483) ((T_OBJECT_OPERATOR) reduce 483) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 483) (("[") reduce 483) (("{") reduce 483)) 8677 (((",") reduce 555) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) (("[") reduce 510) (("]") reduce 555) (("{") reduce 510)) 8732 (((",") reduce 558) (("=") shift) (("]") reduce 558)) 8751 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 556) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 556) (("^") shift) (("|") shift)) 8775 ((("(") reduce 482) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 482) ((T_OBJECT_OPERATOR) reduce 482) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 482) (("[") reduce 482) (("{") reduce 482)) 8777 ((("(") reduce 517) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 511) ((T_OBJECT_OPERATOR) reduce 511) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 511) (("[") reduce 511) (("{") reduce 511)) 8783 ((("(") reduce 485) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 485) ((T_OBJECT_OPERATOR) reduce 485) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 485) (("[") reduce 485) (("{") reduce 485)) 9161 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) ((":") reduce 289) (("<") reduce 289) (("=") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AND_EQUAL) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_COALESCE_EQUAL) reduce 289) ((T_CONCAT_EQUAL) reduce 289) ((T_DEC) reduce 289) ((T_DIV_EQUAL) reduce 289) ((T_INC) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_MINUS_EQUAL) reduce 289) ((T_MOD_EQUAL) reduce 289) ((T_MUL_EQUAL) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_OR_EQUAL) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_PLUS_EQUAL) reduce 289) ((T_POW) reduce 289) ((T_POW_EQUAL) reduce 289) ((T_SL) reduce 289) ((T_SL_EQUAL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) ((T_SR_EQUAL) reduce 289) ((T_XOR_EQUAL) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 9164 ((("%") shift) ((")") reduce 294) (("*") shift) (("+") shift) ((",") reduce 294) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 9234 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) ((":") reduce 290) (("<") reduce 290) (("=") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AND_EQUAL) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_COALESCE_EQUAL) reduce 290) ((T_CONCAT_EQUAL) reduce 290) ((T_DEC) reduce 290) ((T_DIV_EQUAL) reduce 290) ((T_INC) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_MINUS_EQUAL) reduce 290) ((T_MOD_EQUAL) reduce 290) ((T_MUL_EQUAL) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_OR_EQUAL) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_PLUS_EQUAL) reduce 290) ((T_POW) reduce 290) ((T_POW_EQUAL) reduce 290) ((T_SL) reduce 290) ((T_SL_EQUAL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) ((T_SR_EQUAL) reduce 290) ((T_XOR_EQUAL) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 9255 ((("%") reduce 388) (("*") reduce 388) (("+") reduce 388) (("-") reduce 388) ((".") reduce 388) (("/") reduce 388) ((":") reduce 388) (("<") reduce 388) ((">") reduce 388) (("?") reduce 388) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_BOOLEAN_AND) reduce 388) ((T_BOOLEAN_OR) reduce 388) ((T_COALESCE) reduce 388) ((T_INSTANCEOF) reduce 388) ((T_IS_EQUAL) reduce 388) ((T_IS_GREATER_OR_EQUAL) reduce 388) ((T_IS_IDENTICAL) reduce 388) ((T_IS_NOT_EQUAL) reduce 388) ((T_IS_NOT_IDENTICAL) reduce 388) ((T_IS_SMALLER_OR_EQUAL) reduce 388) ((T_LOGICAL_AND) reduce 388) ((T_LOGICAL_OR) reduce 388) ((T_LOGICAL_XOR) reduce 388) ((T_POW) reduce 388) ((T_SL) reduce 388) ((T_SPACESHIP) reduce 388) ((T_SR) reduce 388) (("^") reduce 388) (("|") reduce 388)) 9257 ((("%") reduce 386) (("*") reduce 386) (("+") reduce 386) (("-") reduce 386) ((".") reduce 386) (("/") reduce 386) ((":") reduce 386) (("<") reduce 386) ((">") reduce 386) (("?") reduce 386) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_BOOLEAN_AND) reduce 386) ((T_BOOLEAN_OR) reduce 386) ((T_COALESCE) reduce 386) ((T_INSTANCEOF) reduce 386) ((T_IS_EQUAL) reduce 386) ((T_IS_GREATER_OR_EQUAL) reduce 386) ((T_IS_IDENTICAL) reduce 386) ((T_IS_NOT_EQUAL) reduce 386) ((T_IS_NOT_IDENTICAL) reduce 386) ((T_IS_SMALLER_OR_EQUAL) reduce 386) ((T_LOGICAL_AND) reduce 386) ((T_LOGICAL_OR) reduce 386) ((T_LOGICAL_XOR) reduce 386) ((T_POW) reduce 386) ((T_SL) reduce 386) ((T_SPACESHIP) reduce 386) ((T_SR) reduce 386) (("^") reduce 386) (("|") reduce 386)) 9267 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 382) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 382) ((T_LOGICAL_OR) reduce 382) ((T_LOGICAL_XOR) reduce 382) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 9268 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 384) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 384) ((T_LOGICAL_OR) reduce 384) ((T_LOGICAL_XOR) reduce 384) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 9269 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 383) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 383) ((T_LOGICAL_OR) reduce 383) ((T_LOGICAL_XOR) reduce 383) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 9270 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 376) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 376) ((T_LOGICAL_OR) reduce 376) ((T_LOGICAL_XOR) reduce 376) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 9271 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 373) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 373) ((T_LOGICAL_OR) reduce 373) ((T_LOGICAL_XOR) reduce 373) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 9272 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 381) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 381) ((T_LOGICAL_OR) reduce 381) ((T_LOGICAL_XOR) reduce 381) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 9273 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 375) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 375) ((T_LOGICAL_OR) reduce 375) ((T_LOGICAL_XOR) reduce 375) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 9274 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 379) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 379) ((T_LOGICAL_OR) reduce 379) ((T_LOGICAL_XOR) reduce 379) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 9275 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 374) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 374) ((T_LOGICAL_OR) reduce 374) ((T_LOGICAL_XOR) reduce 374) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 9276 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 377) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 377) ((T_LOGICAL_OR) reduce 377) ((T_LOGICAL_XOR) reduce 377) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 9277 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 378) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 378) ((T_LOGICAL_OR) reduce 378) ((T_LOGICAL_XOR) reduce 378) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 9278 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 385) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 385) ((T_LOGICAL_OR) reduce 385) ((T_LOGICAL_XOR) reduce 385) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 9279 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 380) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 380) ((T_LOGICAL_OR) reduce 380) ((T_LOGICAL_XOR) reduce 380) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 9281 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 370) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 370) ((T_LOGICAL_OR) reduce 370) ((T_LOGICAL_XOR) reduce 370) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 9284 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) ((":") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 9287 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) ((":") reduce 525) (("<") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_POW) reduce 525) ((T_SL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 9289 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) ((":") reduce 524) (("<") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_POW) reduce 524) ((T_SL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 9291 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) ((":") reduce 519) (("<") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_POW) reduce 519) ((T_SL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 9292 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) ((":") reduce 526) (("<") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_POW) reduce 526) ((T_SL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 9293 ((("%") reduce 371) (("*") reduce 371) (("+") reduce 371) (("-") reduce 371) ((".") reduce 371) (("/") reduce 371) ((":") reduce 371) (("<") reduce 371) ((">") reduce 371) (("?") reduce 371) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_BOOLEAN_AND) reduce 371) ((T_BOOLEAN_OR) reduce 371) ((T_COALESCE) reduce 371) ((T_INSTANCEOF) reduce 371) ((T_IS_EQUAL) reduce 371) ((T_IS_GREATER_OR_EQUAL) reduce 371) ((T_IS_IDENTICAL) reduce 371) ((T_IS_NOT_EQUAL) reduce 371) ((T_IS_NOT_IDENTICAL) reduce 371) ((T_IS_SMALLER_OR_EQUAL) reduce 371) ((T_LOGICAL_AND) reduce 371) ((T_LOGICAL_OR) reduce 371) ((T_LOGICAL_XOR) reduce 371) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 371) ((T_SL) reduce 371) ((T_SPACESHIP) reduce 371) ((T_SR) reduce 371) (("[") reduce 510) (("^") reduce 371) (("{") reduce 510) (("|") reduce 371)) 9297 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) ((":") reduce 533) (("<") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_POW) reduce 533) ((T_SL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 9299 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) ((":") reduce 468) (("<") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_POW) reduce 468) ((T_SL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 9300 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) ((":") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 9304 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) ((":") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 9305 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) ((":") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 9306 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) ((":") reduce 465) (("<") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_POW) reduce 465) ((T_SL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 9309 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) ((":") reduce 532) (("<") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_POW) reduce 532) ((T_SL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 9310 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) ((":") reduce 467) (("<") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_POW) reduce 467) ((T_SL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 9311 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) ((":") reduce 469) (("<") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_POW) reduce 469) ((T_SL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 9317 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) ((":") reduce 521) (("<") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_POW) reduce 521) ((T_SL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 9319 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) ((":") reduce 520) (("<") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_POW) reduce 520) ((T_SL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 9320 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) ((":") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 9321 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) ((":") reduce 527) (("<") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_POW) reduce 527) ((T_SL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 9322 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) ((":") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 9325 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) ((":") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 9326 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) ((":") reduce 522) (("<") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_POW) reduce 522) ((T_SL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 9327 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) ((":") reduce 528) (("<") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_POW) reduce 528) ((T_SL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 9328 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) ((":") reduce 523) (("<") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_POW) reduce 523) ((T_SL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 9329 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) ((":") reduce 466) (("<") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_POW) reduce 466) ((T_SL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 9330 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) ((":") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 9333 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) ((":") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 9334 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) ((":") reduce 465) (("<") reduce 465) (("=") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AND_EQUAL) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_COALESCE_EQUAL) reduce 465) ((T_CONCAT_EQUAL) reduce 465) ((T_DEC) reduce 465) ((T_DIV_EQUAL) reduce 465) ((T_INC) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_MINUS_EQUAL) reduce 465) ((T_MOD_EQUAL) reduce 465) ((T_MUL_EQUAL) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_OR_EQUAL) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_PLUS_EQUAL) reduce 465) ((T_POW) reduce 465) ((T_POW_EQUAL) reduce 465) ((T_SL) reduce 465) ((T_SL_EQUAL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) ((T_SR_EQUAL) reduce 465) ((T_XOR_EQUAL) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 9345 ((("%") reduce 455) (("*") reduce 455) (("+") reduce 455) (("-") reduce 455) ((".") reduce 455) (("/") reduce 455) ((":") reduce 455) (("<") reduce 455) ((">") reduce 455) (("?") reduce 455) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_BOOLEAN_AND) reduce 455) ((T_BOOLEAN_OR) reduce 455) ((T_COALESCE) reduce 455) ((T_INSTANCEOF) reduce 455) ((T_IS_EQUAL) reduce 455) ((T_IS_GREATER_OR_EQUAL) reduce 455) ((T_IS_IDENTICAL) reduce 455) ((T_IS_NOT_EQUAL) reduce 455) ((T_IS_NOT_IDENTICAL) reduce 455) ((T_IS_SMALLER_OR_EQUAL) reduce 455) ((T_LOGICAL_AND) reduce 455) ((T_LOGICAL_OR) reduce 455) ((T_LOGICAL_XOR) reduce 455) ((T_POW) reduce 455) ((T_SL) reduce 455) ((T_SPACESHIP) reduce 455) ((T_SR) reduce 455) (("^") reduce 455) (("|") reduce 455)) 9346 ((("%") reduce 450) (("*") reduce 450) (("+") reduce 450) (("-") reduce 450) ((".") reduce 450) (("/") reduce 450) ((":") reduce 450) (("<") reduce 450) ((">") reduce 450) (("?") reduce 450) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_BOOLEAN_AND) reduce 450) ((T_BOOLEAN_OR) reduce 450) ((T_COALESCE) reduce 450) ((T_INSTANCEOF) reduce 450) ((T_IS_EQUAL) reduce 450) ((T_IS_GREATER_OR_EQUAL) reduce 450) ((T_IS_IDENTICAL) reduce 450) ((T_IS_NOT_EQUAL) reduce 450) ((T_IS_NOT_IDENTICAL) reduce 450) ((T_IS_SMALLER_OR_EQUAL) reduce 450) ((T_LOGICAL_AND) reduce 450) ((T_LOGICAL_OR) reduce 450) ((T_LOGICAL_XOR) reduce 450) ((T_POW) reduce 450) ((T_SL) reduce 450) ((T_SPACESHIP) reduce 450) ((T_SR) reduce 450) (("^") reduce 450) (("|") reduce 450)) 9418 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 455) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 9736 ((("%") reduce 451) (("*") reduce 451) (("+") reduce 451) (("-") reduce 451) ((".") reduce 451) (("/") reduce 451) ((":") reduce 451) (("<") reduce 451) ((">") reduce 451) (("?") reduce 451) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_BOOLEAN_AND) reduce 451) ((T_BOOLEAN_OR) reduce 451) ((T_COALESCE) reduce 451) ((T_INSTANCEOF) reduce 451) ((T_IS_EQUAL) reduce 451) ((T_IS_GREATER_OR_EQUAL) reduce 451) ((T_IS_IDENTICAL) reduce 451) ((T_IS_NOT_EQUAL) reduce 451) ((T_IS_NOT_IDENTICAL) reduce 451) ((T_IS_SMALLER_OR_EQUAL) reduce 451) ((T_LOGICAL_AND) reduce 451) ((T_LOGICAL_OR) reduce 451) ((T_LOGICAL_XOR) reduce 451) ((T_POW) reduce 451) ((T_SL) reduce 451) ((T_SPACESHIP) reduce 451) ((T_SR) reduce 451) (("^") reduce 451) (("|") reduce 451)) 9739 ((("%") reduce 503) (("(") reduce 541) (("*") reduce 503) (("+") reduce 503) (("-") reduce 503) ((".") reduce 503) (("/") reduce 503) ((":") reduce 503) (("<") reduce 503) ((">") reduce 503) (("?") reduce 503) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_BOOLEAN_AND) reduce 503) ((T_BOOLEAN_OR) reduce 503) ((T_COALESCE) reduce 503) ((T_INSTANCEOF) reduce 503) ((T_IS_EQUAL) reduce 503) ((T_IS_GREATER_OR_EQUAL) reduce 503) ((T_IS_IDENTICAL) reduce 503) ((T_IS_NOT_EQUAL) reduce 503) ((T_IS_NOT_IDENTICAL) reduce 503) ((T_IS_SMALLER_OR_EQUAL) reduce 503) ((T_LOGICAL_AND) reduce 503) ((T_LOGICAL_OR) reduce 503) ((T_LOGICAL_XOR) reduce 503) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 503) ((T_OBJECT_OPERATOR) reduce 503) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 503) ((T_POW) reduce 503) ((T_SL) reduce 503) ((T_SPACESHIP) reduce 503) ((T_SR) reduce 503) (("[") reduce 503) (("^") reduce 503) (("{") reduce 503) (("|") reduce 503)) 9741 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) ((":") reduce 532) (("<") reduce 532) (("=") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AND_EQUAL) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_COALESCE_EQUAL) reduce 532) ((T_CONCAT_EQUAL) reduce 532) ((T_DEC) reduce 532) ((T_DIV_EQUAL) reduce 532) ((T_INC) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_MINUS_EQUAL) reduce 532) ((T_MOD_EQUAL) reduce 532) ((T_MUL_EQUAL) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_OR_EQUAL) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_PLUS_EQUAL) reduce 532) ((T_POW) reduce 532) ((T_POW_EQUAL) reduce 532) ((T_SL) reduce 532) ((T_SL_EQUAL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) ((T_SR_EQUAL) reduce 532) ((T_XOR_EQUAL) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 9744 ((("%") reduce 505) (("(") reduce 542) (("*") reduce 505) (("+") reduce 505) (("-") reduce 505) ((".") reduce 505) (("/") reduce 505) ((":") reduce 505) (("<") reduce 505) ((">") reduce 505) (("?") reduce 505) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_BOOLEAN_AND) reduce 505) ((T_BOOLEAN_OR) reduce 505) ((T_COALESCE) reduce 505) ((T_INSTANCEOF) reduce 505) ((T_IS_EQUAL) reduce 505) ((T_IS_GREATER_OR_EQUAL) reduce 505) ((T_IS_IDENTICAL) reduce 505) ((T_IS_NOT_EQUAL) reduce 505) ((T_IS_NOT_IDENTICAL) reduce 505) ((T_IS_SMALLER_OR_EQUAL) reduce 505) ((T_LOGICAL_AND) reduce 505) ((T_LOGICAL_OR) reduce 505) ((T_LOGICAL_XOR) reduce 505) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 505) ((T_OBJECT_OPERATOR) reduce 505) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 505) ((T_POW) reduce 505) ((T_SL) reduce 505) ((T_SPACESHIP) reduce 505) ((T_SR) reduce 505) (("[") reduce 505) (("^") reduce 505) (("{") reduce 505) (("|") reduce 505)) 9745 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) ((":") reduce 467) (("<") reduce 467) (("=") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AND_EQUAL) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_COALESCE_EQUAL) reduce 467) ((T_CONCAT_EQUAL) reduce 467) ((T_DEC) reduce 467) ((T_DIV_EQUAL) reduce 467) ((T_INC) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_MINUS_EQUAL) reduce 467) ((T_MOD_EQUAL) reduce 467) ((T_MUL_EQUAL) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_OR_EQUAL) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_PLUS_EQUAL) reduce 467) ((T_POW) reduce 467) ((T_POW_EQUAL) reduce 467) ((T_SL) reduce 467) ((T_SL_EQUAL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) ((T_SR_EQUAL) reduce 467) ((T_XOR_EQUAL) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 9746 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) ((":") reduce 469) (("<") reduce 469) (("=") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AND_EQUAL) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_COALESCE_EQUAL) reduce 469) ((T_CONCAT_EQUAL) reduce 469) ((T_DEC) reduce 469) ((T_DIV_EQUAL) reduce 469) ((T_INC) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_MINUS_EQUAL) reduce 469) ((T_MOD_EQUAL) reduce 469) ((T_MUL_EQUAL) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_OR_EQUAL) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_PLUS_EQUAL) reduce 469) ((T_POW) reduce 469) ((T_POW_EQUAL) reduce 469) ((T_SL) reduce 469) ((T_SL_EQUAL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) ((T_SR_EQUAL) reduce 469) ((T_XOR_EQUAL) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 9748 ((("%") reduce 446) (("*") reduce 446) (("+") reduce 446) (("-") reduce 446) ((".") reduce 446) (("/") reduce 446) ((":") reduce 446) (("<") reduce 446) ((">") reduce 446) (("?") reduce 446) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_BOOLEAN_AND) reduce 446) ((T_BOOLEAN_OR) reduce 446) ((T_COALESCE) reduce 446) ((T_INSTANCEOF) reduce 446) ((T_IS_EQUAL) reduce 446) ((T_IS_GREATER_OR_EQUAL) reduce 446) ((T_IS_IDENTICAL) reduce 446) ((T_IS_NOT_EQUAL) reduce 446) ((T_IS_NOT_IDENTICAL) reduce 446) ((T_IS_SMALLER_OR_EQUAL) reduce 446) ((T_LOGICAL_AND) reduce 446) ((T_LOGICAL_OR) reduce 446) ((T_LOGICAL_XOR) reduce 446) ((T_POW) reduce 446) ((T_SL) reduce 446) ((T_SPACESHIP) reduce 446) ((T_SR) reduce 446) (("^") reduce 446) (("|") reduce 446)) 9749 ((("%") reduce 448) (("*") reduce 448) (("+") reduce 448) (("-") reduce 448) ((".") reduce 448) (("/") reduce 448) ((":") reduce 448) (("<") reduce 448) ((">") reduce 448) (("?") reduce 448) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_BOOLEAN_AND) reduce 448) ((T_BOOLEAN_OR) reduce 448) ((T_COALESCE) reduce 448) ((T_INSTANCEOF) reduce 448) ((T_IS_EQUAL) reduce 448) ((T_IS_GREATER_OR_EQUAL) reduce 448) ((T_IS_IDENTICAL) reduce 448) ((T_IS_NOT_EQUAL) reduce 448) ((T_IS_NOT_IDENTICAL) reduce 448) ((T_IS_SMALLER_OR_EQUAL) reduce 448) ((T_LOGICAL_AND) reduce 448) ((T_LOGICAL_OR) reduce 448) ((T_LOGICAL_XOR) reduce 448) ((T_POW) reduce 448) ((T_SL) reduce 448) ((T_SPACESHIP) reduce 448) ((T_SR) reduce 448) (("^") reduce 448) (("|") reduce 448)) 9755 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) ((":") reduce 521) (("<") reduce 521) (("=") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AND_EQUAL) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_COALESCE_EQUAL) reduce 521) ((T_CONCAT_EQUAL) reduce 521) ((T_DEC) reduce 521) ((T_DIV_EQUAL) reduce 521) ((T_INC) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_MINUS_EQUAL) reduce 521) ((T_MOD_EQUAL) reduce 521) ((T_MUL_EQUAL) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_OR_EQUAL) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_PLUS_EQUAL) reduce 521) ((T_POW) reduce 521) ((T_POW_EQUAL) reduce 521) ((T_SL) reduce 521) ((T_SL_EQUAL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) ((T_SR_EQUAL) reduce 521) ((T_XOR_EQUAL) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 9757 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) ((":") reduce 520) (("<") reduce 520) (("=") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AND_EQUAL) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_COALESCE_EQUAL) reduce 520) ((T_CONCAT_EQUAL) reduce 520) ((T_DEC) reduce 520) ((T_DIV_EQUAL) reduce 520) ((T_INC) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_MINUS_EQUAL) reduce 520) ((T_MOD_EQUAL) reduce 520) ((T_MUL_EQUAL) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_OR_EQUAL) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_PLUS_EQUAL) reduce 520) ((T_POW) reduce 520) ((T_POW_EQUAL) reduce 520) ((T_SL) reduce 520) ((T_SL_EQUAL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) ((T_SR_EQUAL) reduce 520) ((T_XOR_EQUAL) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 9758 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) ((":") reduce 544) (("<") reduce 544) (("=") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AND_EQUAL) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_COALESCE_EQUAL) reduce 544) ((T_CONCAT_EQUAL) reduce 544) ((T_DEC) reduce 544) ((T_DIV_EQUAL) reduce 544) ((T_INC) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_MINUS_EQUAL) reduce 544) ((T_MOD_EQUAL) reduce 544) ((T_MUL_EQUAL) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_OR_EQUAL) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_PLUS_EQUAL) reduce 544) ((T_POW) reduce 544) ((T_POW_EQUAL) reduce 544) ((T_SL) reduce 544) ((T_SL_EQUAL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) ((T_SR_EQUAL) reduce 544) ((T_XOR_EQUAL) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 9759 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) ((":") reduce 527) (("<") reduce 527) (("=") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AND_EQUAL) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_COALESCE_EQUAL) reduce 527) ((T_CONCAT_EQUAL) reduce 527) ((T_DEC) reduce 527) ((T_DIV_EQUAL) reduce 527) ((T_INC) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_MINUS_EQUAL) reduce 527) ((T_MOD_EQUAL) reduce 527) ((T_MUL_EQUAL) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_OR_EQUAL) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_PLUS_EQUAL) reduce 527) ((T_POW) reduce 527) ((T_POW_EQUAL) reduce 527) ((T_SL) reduce 527) ((T_SL_EQUAL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) ((T_SR_EQUAL) reduce 527) ((T_XOR_EQUAL) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 9760 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) ((":") reduce 546) (("<") reduce 546) (("=") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AND_EQUAL) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_COALESCE_EQUAL) reduce 546) ((T_CONCAT_EQUAL) reduce 546) ((T_DEC) reduce 546) ((T_DIV_EQUAL) reduce 546) ((T_INC) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_MINUS_EQUAL) reduce 546) ((T_MOD_EQUAL) reduce 546) ((T_MUL_EQUAL) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_OR_EQUAL) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_PLUS_EQUAL) reduce 546) ((T_POW) reduce 546) ((T_POW_EQUAL) reduce 546) ((T_SL) reduce 546) ((T_SL_EQUAL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) ((T_SR_EQUAL) reduce 546) ((T_XOR_EQUAL) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 9763 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) ((":") reduce 545) (("<") reduce 545) (("=") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AND_EQUAL) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_COALESCE_EQUAL) reduce 545) ((T_CONCAT_EQUAL) reduce 545) ((T_DEC) reduce 545) ((T_DIV_EQUAL) reduce 545) ((T_INC) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_MINUS_EQUAL) reduce 545) ((T_MOD_EQUAL) reduce 545) ((T_MUL_EQUAL) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_OR_EQUAL) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_PLUS_EQUAL) reduce 545) ((T_POW) reduce 545) ((T_POW_EQUAL) reduce 545) ((T_SL) reduce 545) ((T_SL_EQUAL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) ((T_SR_EQUAL) reduce 545) ((T_XOR_EQUAL) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 9764 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) ((":") reduce 522) (("<") reduce 522) (("=") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AND_EQUAL) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_COALESCE_EQUAL) reduce 522) ((T_CONCAT_EQUAL) reduce 522) ((T_DEC) reduce 522) ((T_DIV_EQUAL) reduce 522) ((T_INC) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_MINUS_EQUAL) reduce 522) ((T_MOD_EQUAL) reduce 522) ((T_MUL_EQUAL) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_OR_EQUAL) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_PLUS_EQUAL) reduce 522) ((T_POW) reduce 522) ((T_POW_EQUAL) reduce 522) ((T_SL) reduce 522) ((T_SL_EQUAL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) ((T_SR_EQUAL) reduce 522) ((T_XOR_EQUAL) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 9765 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) ((":") reduce 528) (("<") reduce 528) (("=") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AND_EQUAL) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_COALESCE_EQUAL) reduce 528) ((T_CONCAT_EQUAL) reduce 528) ((T_DEC) reduce 528) ((T_DIV_EQUAL) reduce 528) ((T_INC) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_MINUS_EQUAL) reduce 528) ((T_MOD_EQUAL) reduce 528) ((T_MUL_EQUAL) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_OR_EQUAL) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_PLUS_EQUAL) reduce 528) ((T_POW) reduce 528) ((T_POW_EQUAL) reduce 528) ((T_SL) reduce 528) ((T_SL_EQUAL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) ((T_SR_EQUAL) reduce 528) ((T_XOR_EQUAL) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 9766 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) ((":") reduce 523) (("<") reduce 523) (("=") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AND_EQUAL) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_COALESCE_EQUAL) reduce 523) ((T_CONCAT_EQUAL) reduce 523) ((T_DEC) reduce 523) ((T_DIV_EQUAL) reduce 523) ((T_INC) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_MINUS_EQUAL) reduce 523) ((T_MOD_EQUAL) reduce 523) ((T_MUL_EQUAL) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_OR_EQUAL) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_PLUS_EQUAL) reduce 523) ((T_POW) reduce 523) ((T_POW_EQUAL) reduce 523) ((T_SL) reduce 523) ((T_SL_EQUAL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) ((T_SR_EQUAL) reduce 523) ((T_XOR_EQUAL) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 9768 ((("%") reduce 438) (("*") reduce 438) (("+") reduce 438) (("-") reduce 438) ((".") reduce 438) (("/") reduce 438) ((":") reduce 438) (("<") reduce 438) ((">") reduce 438) (("?") reduce 438) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_BOOLEAN_AND) reduce 438) ((T_BOOLEAN_OR) reduce 438) ((T_COALESCE) reduce 438) ((T_INSTANCEOF) reduce 438) ((T_IS_EQUAL) reduce 438) ((T_IS_GREATER_OR_EQUAL) reduce 438) ((T_IS_IDENTICAL) reduce 438) ((T_IS_NOT_EQUAL) reduce 438) ((T_IS_NOT_IDENTICAL) reduce 438) ((T_IS_SMALLER_OR_EQUAL) reduce 438) ((T_LOGICAL_AND) reduce 438) ((T_LOGICAL_OR) reduce 438) ((T_LOGICAL_XOR) reduce 438) ((T_POW) reduce 438) ((T_SL) reduce 438) ((T_SPACESHIP) reduce 438) ((T_SR) reduce 438) (("^") reduce 438) (("|") reduce 438)) 9770 ((("%") reduce 483) (("(") reduce 483) (("*") reduce 483) (("+") reduce 483) (("-") reduce 483) ((".") reduce 483) (("/") reduce 483) ((":") reduce 483) (("<") reduce 483) (("=") shift) ((">") reduce 483) (("?") reduce 483) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_BOOLEAN_AND) reduce 483) ((T_BOOLEAN_OR) reduce 483) ((T_COALESCE) reduce 483) ((T_INSTANCEOF) reduce 483) ((T_IS_EQUAL) reduce 483) ((T_IS_GREATER_OR_EQUAL) reduce 483) ((T_IS_IDENTICAL) reduce 483) ((T_IS_NOT_EQUAL) reduce 483) ((T_IS_NOT_IDENTICAL) reduce 483) ((T_IS_SMALLER_OR_EQUAL) reduce 483) ((T_LOGICAL_AND) reduce 483) ((T_LOGICAL_OR) reduce 483) ((T_LOGICAL_XOR) reduce 483) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 483) ((T_OBJECT_OPERATOR) reduce 483) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 483) ((T_POW) reduce 483) ((T_SL) reduce 483) ((T_SPACESHIP) reduce 483) ((T_SR) reduce 483) (("[") reduce 483) (("^") reduce 483) (("{") reduce 483) (("|") reduce 483)) 9772 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 369) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 369) ((T_LOGICAL_OR) reduce 369) ((T_LOGICAL_XOR) reduce 369) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 9773 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 443) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 443) ((T_LOGICAL_OR) reduce 443) ((T_LOGICAL_XOR) reduce 443) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 9784 ((("%") reduce 502) (("*") reduce 502) (("+") reduce 502) (("-") reduce 502) ((".") reduce 502) (("/") reduce 502) ((":") reduce 502) (("<") reduce 502) ((">") reduce 502) (("?") reduce 502) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_BOOLEAN_AND) reduce 502) ((T_BOOLEAN_OR) reduce 502) ((T_COALESCE) reduce 502) ((T_DOUBLE_ARROW) reduce 502) ((T_INSTANCEOF) reduce 502) ((T_IS_EQUAL) reduce 502) ((T_IS_GREATER_OR_EQUAL) reduce 502) ((T_IS_IDENTICAL) reduce 502) ((T_IS_NOT_EQUAL) reduce 502) ((T_IS_NOT_IDENTICAL) reduce 502) ((T_IS_SMALLER_OR_EQUAL) reduce 502) ((T_LOGICAL_AND) reduce 502) ((T_LOGICAL_OR) reduce 502) ((T_LOGICAL_XOR) reduce 502) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 502) ((T_OBJECT_OPERATOR) reduce 502) ((T_POW) reduce 502) ((T_SL) reduce 502) ((T_SPACESHIP) reduce 502) ((T_SR) reduce 502) (("[") reduce 502) (("^") reduce 502) (("{") reduce 502) (("|") reduce 502)) 9786 ((("%") reduce 484) (("(") reduce 484) (("*") reduce 484) (("+") reduce 484) (("-") reduce 484) ((".") reduce 484) (("/") reduce 484) ((":") reduce 484) (("<") reduce 484) ((">") reduce 484) (("?") reduce 484) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_BOOLEAN_AND) reduce 484) ((T_BOOLEAN_OR) reduce 484) ((T_COALESCE) reduce 484) ((T_DOUBLE_ARROW) reduce 484) ((T_INSTANCEOF) reduce 484) ((T_IS_EQUAL) reduce 484) ((T_IS_GREATER_OR_EQUAL) reduce 484) ((T_IS_IDENTICAL) reduce 484) ((T_IS_NOT_EQUAL) reduce 484) ((T_IS_NOT_IDENTICAL) reduce 484) ((T_IS_SMALLER_OR_EQUAL) reduce 484) ((T_LOGICAL_AND) reduce 484) ((T_LOGICAL_OR) reduce 484) ((T_LOGICAL_XOR) reduce 484) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 484) ((T_OBJECT_OPERATOR) reduce 484) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 484) ((T_POW) reduce 484) ((T_SL) reduce 484) ((T_SPACESHIP) reduce 484) ((T_SR) reduce 484) (("[") reduce 484) (("^") reduce 484) (("{") reduce 484) (("|") reduce 484)) 9788 ((("%") reduce 497) (("*") reduce 497) (("+") reduce 497) (("-") reduce 497) ((".") reduce 497) (("/") reduce 497) ((":") reduce 497) (("<") reduce 497) ((">") reduce 497) (("?") reduce 497) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_BOOLEAN_AND) reduce 497) ((T_BOOLEAN_OR) reduce 497) ((T_COALESCE) reduce 497) ((T_DOUBLE_ARROW) reduce 497) ((T_INSTANCEOF) reduce 497) ((T_IS_EQUAL) reduce 497) ((T_IS_GREATER_OR_EQUAL) reduce 497) ((T_IS_IDENTICAL) reduce 497) ((T_IS_NOT_EQUAL) reduce 497) ((T_IS_NOT_IDENTICAL) reduce 497) ((T_IS_SMALLER_OR_EQUAL) reduce 497) ((T_LOGICAL_AND) reduce 497) ((T_LOGICAL_OR) reduce 497) ((T_LOGICAL_XOR) reduce 497) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 497) ((T_OBJECT_OPERATOR) reduce 497) ((T_POW) reduce 497) ((T_SL) reduce 497) ((T_SPACESHIP) reduce 497) ((T_SR) reduce 497) (("[") reduce 497) (("^") reduce 497) (("{") reduce 497) (("|") reduce 497)) 9789 ((("%") reduce 487) (("*") reduce 487) (("+") reduce 487) (("-") reduce 487) ((".") reduce 487) (("/") reduce 487) ((":") reduce 487) (("<") reduce 487) ((">") reduce 487) (("?") reduce 487) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_BOOLEAN_AND) reduce 487) ((T_BOOLEAN_OR) reduce 487) ((T_COALESCE) reduce 487) ((T_DOUBLE_ARROW) reduce 487) ((T_INSTANCEOF) reduce 487) ((T_IS_EQUAL) reduce 487) ((T_IS_GREATER_OR_EQUAL) reduce 487) ((T_IS_IDENTICAL) reduce 487) ((T_IS_NOT_EQUAL) reduce 487) ((T_IS_NOT_IDENTICAL) reduce 487) ((T_IS_SMALLER_OR_EQUAL) reduce 487) ((T_LOGICAL_AND) reduce 487) ((T_LOGICAL_OR) reduce 487) ((T_LOGICAL_XOR) reduce 487) ((T_POW) reduce 487) ((T_SL) reduce 487) ((T_SPACESHIP) reduce 487) ((T_SR) reduce 487) (("^") reduce 487) (("|") reduce 487)) 9793 ((("%") reduce 475) (("(") shift) (("*") reduce 475) (("+") reduce 475) (("-") reduce 475) ((".") reduce 475) (("/") reduce 475) ((":") reduce 475) (("<") reduce 475) ((">") reduce 475) (("?") reduce 475) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_BOOLEAN_AND) reduce 475) ((T_BOOLEAN_OR) reduce 475) ((T_COALESCE) reduce 475) ((T_DOUBLE_ARROW) reduce 475) ((T_INSTANCEOF) reduce 475) ((T_IS_EQUAL) reduce 475) ((T_IS_GREATER_OR_EQUAL) reduce 475) ((T_IS_IDENTICAL) reduce 475) ((T_IS_NOT_EQUAL) reduce 475) ((T_IS_NOT_IDENTICAL) reduce 475) ((T_IS_SMALLER_OR_EQUAL) reduce 475) ((T_LOGICAL_AND) reduce 475) ((T_LOGICAL_OR) reduce 475) ((T_LOGICAL_XOR) reduce 475) ((T_POW) reduce 475) ((T_SL) reduce 475) ((T_SPACESHIP) reduce 475) ((T_SR) reduce 475) (("^") reduce 475) (("|") reduce 475)) 9794 ((("%") reduce 496) (("*") reduce 496) (("+") reduce 496) (("-") reduce 496) ((".") reduce 496) (("/") reduce 496) ((":") reduce 496) (("<") reduce 496) ((">") reduce 496) (("?") reduce 496) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_BOOLEAN_AND) reduce 496) ((T_BOOLEAN_OR) reduce 496) ((T_COALESCE) reduce 496) ((T_DOUBLE_ARROW) reduce 496) ((T_INSTANCEOF) reduce 496) ((T_IS_EQUAL) reduce 496) ((T_IS_GREATER_OR_EQUAL) reduce 496) ((T_IS_IDENTICAL) reduce 496) ((T_IS_NOT_EQUAL) reduce 496) ((T_IS_NOT_IDENTICAL) reduce 496) ((T_IS_SMALLER_OR_EQUAL) reduce 496) ((T_LOGICAL_AND) reduce 496) ((T_LOGICAL_OR) reduce 496) ((T_LOGICAL_XOR) reduce 496) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 496) ((T_OBJECT_OPERATOR) reduce 496) ((T_POW) reduce 496) ((T_SL) reduce 496) ((T_SPACESHIP) reduce 496) ((T_SR) reduce 496) (("[") reduce 496) (("^") reduce 496) (("{") reduce 496) (("|") reduce 496)) 9795 ((("%") reduce 500) (("*") reduce 500) (("+") reduce 500) (("-") reduce 500) ((".") reduce 500) (("/") reduce 500) ((":") reduce 500) (("<") reduce 500) ((">") reduce 500) (("?") reduce 500) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_BOOLEAN_AND) reduce 500) ((T_BOOLEAN_OR) reduce 500) ((T_COALESCE) reduce 500) ((T_DOUBLE_ARROW) reduce 500) ((T_INSTANCEOF) reduce 500) ((T_IS_EQUAL) reduce 500) ((T_IS_GREATER_OR_EQUAL) reduce 500) ((T_IS_IDENTICAL) reduce 500) ((T_IS_NOT_EQUAL) reduce 500) ((T_IS_NOT_IDENTICAL) reduce 500) ((T_IS_SMALLER_OR_EQUAL) reduce 500) ((T_LOGICAL_AND) reduce 500) ((T_LOGICAL_OR) reduce 500) ((T_LOGICAL_XOR) reduce 500) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 500) ((T_OBJECT_OPERATOR) reduce 500) ((T_POW) reduce 500) ((T_SL) reduce 500) ((T_SPACESHIP) reduce 500) ((T_SR) reduce 500) (("[") reduce 500) (("^") reduce 500) (("{") reduce 500) (("|") reduce 500)) 9801 ((("%") reduce 495) (("*") reduce 495) (("+") reduce 495) (("-") reduce 495) ((".") reduce 495) (("/") reduce 495) ((":") reduce 495) (("<") reduce 495) ((">") reduce 495) (("?") reduce 495) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_BOOLEAN_AND) reduce 495) ((T_BOOLEAN_OR) reduce 495) ((T_COALESCE) reduce 495) ((T_DOUBLE_ARROW) reduce 495) ((T_INSTANCEOF) reduce 495) ((T_IS_EQUAL) reduce 495) ((T_IS_GREATER_OR_EQUAL) reduce 495) ((T_IS_IDENTICAL) reduce 495) ((T_IS_NOT_EQUAL) reduce 495) ((T_IS_NOT_IDENTICAL) reduce 495) ((T_IS_SMALLER_OR_EQUAL) reduce 495) ((T_LOGICAL_AND) reduce 495) ((T_LOGICAL_OR) reduce 495) ((T_LOGICAL_XOR) reduce 495) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 495) ((T_OBJECT_OPERATOR) reduce 495) ((T_POW) reduce 495) ((T_SL) reduce 495) ((T_SPACESHIP) reduce 495) ((T_SR) reduce 495) (("[") reduce 495) (("^") reduce 495) (("{") reduce 495) (("|") reduce 495)) 9803 ((("%") reduce 486) (("*") reduce 486) (("+") reduce 486) (("-") reduce 486) ((".") reduce 486) (("/") reduce 486) ((":") reduce 486) (("<") reduce 486) ((">") reduce 486) (("?") reduce 486) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_BOOLEAN_AND) reduce 486) ((T_BOOLEAN_OR) reduce 486) ((T_COALESCE) reduce 486) ((T_DOUBLE_ARROW) reduce 486) ((T_INSTANCEOF) reduce 486) ((T_IS_EQUAL) reduce 486) ((T_IS_GREATER_OR_EQUAL) reduce 486) ((T_IS_IDENTICAL) reduce 486) ((T_IS_NOT_EQUAL) reduce 486) ((T_IS_NOT_IDENTICAL) reduce 486) ((T_IS_SMALLER_OR_EQUAL) reduce 486) ((T_LOGICAL_AND) reduce 486) ((T_LOGICAL_OR) reduce 486) ((T_LOGICAL_XOR) reduce 486) ((T_POW) reduce 486) ((T_SL) reduce 486) ((T_SPACESHIP) reduce 486) ((T_SR) reduce 486) (("^") reduce 486) (("|") reduce 486)) 9805 ((("%") reduce 499) (("*") reduce 499) (("+") reduce 499) (("-") reduce 499) ((".") reduce 499) (("/") reduce 499) ((":") reduce 499) (("<") reduce 499) ((">") reduce 499) (("?") reduce 499) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_BOOLEAN_AND) reduce 499) ((T_BOOLEAN_OR) reduce 499) ((T_COALESCE) reduce 499) ((T_DOUBLE_ARROW) reduce 499) ((T_INSTANCEOF) reduce 499) ((T_IS_EQUAL) reduce 499) ((T_IS_GREATER_OR_EQUAL) reduce 499) ((T_IS_IDENTICAL) reduce 499) ((T_IS_NOT_EQUAL) reduce 499) ((T_IS_NOT_IDENTICAL) reduce 499) ((T_IS_SMALLER_OR_EQUAL) reduce 499) ((T_LOGICAL_AND) reduce 499) ((T_LOGICAL_OR) reduce 499) ((T_LOGICAL_XOR) reduce 499) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 499) ((T_OBJECT_OPERATOR) reduce 499) ((T_POW) reduce 499) ((T_SL) reduce 499) ((T_SPACESHIP) reduce 499) ((T_SR) reduce 499) (("[") reduce 499) (("^") reduce 499) (("{") reduce 499) (("|") reduce 499)) 9806 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) ((":") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 93) ((T_OBJECT_OPERATOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("[") reduce 93) (("^") reduce 93) (("{") reduce 93) (("|") reduce 93)) 9807 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) ((":") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 92) ((T_OBJECT_OPERATOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("[") reduce 92) (("^") reduce 92) (("{") reduce 92) (("|") reduce 92)) 9808 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) ((":") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 94) ((T_OBJECT_OPERATOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("[") reduce 94) (("^") reduce 94) (("{") reduce 94) (("|") reduce 94)) 9810 ((("%") reduce 501) (("*") reduce 501) (("+") reduce 501) (("-") reduce 501) ((".") reduce 501) (("/") reduce 501) ((":") reduce 501) (("<") reduce 501) ((">") reduce 501) (("?") reduce 501) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_BOOLEAN_AND) reduce 501) ((T_BOOLEAN_OR) reduce 501) ((T_COALESCE) reduce 501) ((T_DOUBLE_ARROW) reduce 501) ((T_INSTANCEOF) reduce 501) ((T_IS_EQUAL) reduce 501) ((T_IS_GREATER_OR_EQUAL) reduce 501) ((T_IS_IDENTICAL) reduce 501) ((T_IS_NOT_EQUAL) reduce 501) ((T_IS_NOT_IDENTICAL) reduce 501) ((T_IS_SMALLER_OR_EQUAL) reduce 501) ((T_LOGICAL_AND) reduce 501) ((T_LOGICAL_OR) reduce 501) ((T_LOGICAL_XOR) reduce 501) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 501) ((T_OBJECT_OPERATOR) reduce 501) ((T_POW) reduce 501) ((T_SL) reduce 501) ((T_SPACESHIP) reduce 501) ((T_SR) reduce 501) (("[") reduce 501) (("^") reduce 501) (("{") reduce 501) (("|") reduce 501)) 9818 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) ((":") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 91) ((T_OBJECT_OPERATOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("[") reduce 91) (("^") reduce 91) (("{") reduce 91) (("|") reduce 91)) 9821 ((("%") reduce 498) (("*") reduce 498) (("+") reduce 498) (("-") reduce 498) ((".") reduce 498) (("/") reduce 498) ((":") reduce 498) (("<") reduce 498) ((">") reduce 498) (("?") reduce 498) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_BOOLEAN_AND) reduce 498) ((T_BOOLEAN_OR) reduce 498) ((T_COALESCE) reduce 498) ((T_DOUBLE_ARROW) reduce 498) ((T_INSTANCEOF) reduce 498) ((T_IS_EQUAL) reduce 498) ((T_IS_GREATER_OR_EQUAL) reduce 498) ((T_IS_IDENTICAL) reduce 498) ((T_IS_NOT_EQUAL) reduce 498) ((T_IS_NOT_IDENTICAL) reduce 498) ((T_IS_SMALLER_OR_EQUAL) reduce 498) ((T_LOGICAL_AND) reduce 498) ((T_LOGICAL_OR) reduce 498) ((T_LOGICAL_XOR) reduce 498) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 498) ((T_OBJECT_OPERATOR) reduce 498) ((T_POW) reduce 498) ((T_SL) reduce 498) ((T_SPACESHIP) reduce 498) ((T_SR) reduce 498) (("[") reduce 498) (("^") reduce 498) (("{") reduce 498) (("|") reduce 498)) 9823 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) ((":") reduce 529) (("<") reduce 529) (("=") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AND_EQUAL) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_COALESCE_EQUAL) reduce 529) ((T_CONCAT_EQUAL) reduce 529) ((T_DEC) reduce 529) ((T_DIV_EQUAL) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INC) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_MINUS_EQUAL) reduce 529) ((T_MOD_EQUAL) reduce 529) ((T_MUL_EQUAL) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_OR_EQUAL) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_PLUS_EQUAL) reduce 529) ((T_POW) reduce 529) ((T_POW_EQUAL) reduce 529) ((T_SL) reduce 529) ((T_SL_EQUAL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) ((T_SR_EQUAL) reduce 529) ((T_XOR_EQUAL) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 9824 ((("!") shift) (("\"") shift) (("$") shift) (("%") reduce 440) (("(") shift) (("*") reduce 440) (("+") shift) (("-") shift) ((".") reduce 440) (("/") reduce 440) ((":") reduce 440) (("<") reduce 440) ((">") reduce 440) (("?") reduce 440) (("@") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOLEAN_AND) reduce 440) ((T_BOOLEAN_OR) reduce 440) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_COALESCE) reduce 440) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_ARROW) reduce 440) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INSTANCEOF) reduce 440) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_IS_EQUAL) reduce 440) ((T_IS_GREATER_OR_EQUAL) reduce 440) ((T_IS_IDENTICAL) reduce 440) ((T_IS_NOT_EQUAL) reduce 440) ((T_IS_NOT_IDENTICAL) reduce 440) ((T_IS_SMALLER_OR_EQUAL) reduce 440) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_LOGICAL_AND) reduce 440) ((T_LOGICAL_OR) reduce 440) ((T_LOGICAL_XOR) reduce 440) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_POW) reduce 440) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_SL) reduce 440) ((T_SPACESHIP) reduce 440) ((T_SR) reduce 440) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("^") reduce 440) (("`") shift) (("|") reduce 440) (("~") shift)) 9831 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) ((":") reduce 525) (("<") reduce 525) (("=") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AND_EQUAL) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_COALESCE_EQUAL) reduce 525) ((T_CONCAT_EQUAL) reduce 525) ((T_DEC) reduce 525) ((T_DIV_EQUAL) reduce 525) ((T_DOUBLE_ARROW) reduce 525) ((T_INC) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_MINUS_EQUAL) reduce 525) ((T_MOD_EQUAL) reduce 525) ((T_MUL_EQUAL) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_OR_EQUAL) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_PLUS_EQUAL) reduce 525) ((T_POW) reduce 525) ((T_POW_EQUAL) reduce 525) ((T_SL) reduce 525) ((T_SL_EQUAL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) ((T_SR_EQUAL) reduce 525) ((T_XOR_EQUAL) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 9832 ((("%") reduce 493) (("*") reduce 493) (("+") reduce 493) (("-") reduce 493) ((".") reduce 493) (("/") reduce 493) ((":") reduce 493) (("<") reduce 493) ((">") reduce 493) (("?") reduce 493) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_BOOLEAN_AND) reduce 493) ((T_BOOLEAN_OR) reduce 493) ((T_COALESCE) reduce 493) ((T_DOUBLE_ARROW) reduce 493) ((T_INSTANCEOF) reduce 493) ((T_IS_EQUAL) reduce 493) ((T_IS_GREATER_OR_EQUAL) reduce 493) ((T_IS_IDENTICAL) reduce 493) ((T_IS_NOT_EQUAL) reduce 493) ((T_IS_NOT_IDENTICAL) reduce 493) ((T_IS_SMALLER_OR_EQUAL) reduce 493) ((T_LOGICAL_AND) reduce 493) ((T_LOGICAL_OR) reduce 493) ((T_LOGICAL_XOR) reduce 493) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 513) ((T_OBJECT_OPERATOR) reduce 513) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 513) ((T_POW) reduce 493) ((T_SL) reduce 493) ((T_SPACESHIP) reduce 493) ((T_SR) reduce 493) (("[") reduce 513) (("^") reduce 493) (("{") reduce 513) (("|") reduce 493)) 9834 ((("%") reduce 492) (("*") reduce 492) (("+") reduce 492) (("-") reduce 492) ((".") reduce 492) (("/") reduce 492) ((":") reduce 492) (("<") reduce 492) ((">") reduce 492) (("?") reduce 492) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_BOOLEAN_AND) reduce 492) ((T_BOOLEAN_OR) reduce 492) ((T_COALESCE) reduce 492) ((T_DOUBLE_ARROW) reduce 492) ((T_INSTANCEOF) reduce 492) ((T_IS_EQUAL) reduce 492) ((T_IS_GREATER_OR_EQUAL) reduce 492) ((T_IS_IDENTICAL) reduce 492) ((T_IS_NOT_EQUAL) reduce 492) ((T_IS_NOT_IDENTICAL) reduce 492) ((T_IS_SMALLER_OR_EQUAL) reduce 492) ((T_LOGICAL_AND) reduce 492) ((T_LOGICAL_OR) reduce 492) ((T_LOGICAL_XOR) reduce 492) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 515) ((T_OBJECT_OPERATOR) reduce 515) ((T_POW) reduce 492) ((T_SL) reduce 492) ((T_SPACESHIP) reduce 492) ((T_SR) reduce 492) (("[") reduce 515) (("^") reduce 492) (("{") reduce 515) (("|") reduce 492)) 9835 ((("%") reduce 491) (("(") reduce 518) (("*") reduce 491) (("+") reduce 491) (("-") reduce 491) ((".") reduce 491) (("/") reduce 491) ((":") reduce 491) (("<") reduce 491) ((">") reduce 491) (("?") reduce 491) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_BOOLEAN_AND) reduce 491) ((T_BOOLEAN_OR) reduce 491) ((T_COALESCE) reduce 491) ((T_DOUBLE_ARROW) reduce 491) ((T_INSTANCEOF) reduce 491) ((T_IS_EQUAL) reduce 491) ((T_IS_GREATER_OR_EQUAL) reduce 491) ((T_IS_IDENTICAL) reduce 491) ((T_IS_NOT_EQUAL) reduce 491) ((T_IS_NOT_IDENTICAL) reduce 491) ((T_IS_SMALLER_OR_EQUAL) reduce 491) ((T_LOGICAL_AND) reduce 491) ((T_LOGICAL_OR) reduce 491) ((T_LOGICAL_XOR) reduce 491) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 512) ((T_OBJECT_OPERATOR) reduce 512) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 512) ((T_POW) reduce 491) ((T_SL) reduce 491) ((T_SPACESHIP) reduce 491) ((T_SR) reduce 491) (("[") reduce 512) (("^") reduce 491) (("{") reduce 512) (("|") reduce 491)) 9836 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 441) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 441) ((T_LOGICAL_OR) reduce 441) ((T_LOGICAL_XOR) reduce 441) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 9839 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) ((":") reduce 524) (("<") reduce 524) (("=") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AND_EQUAL) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_COALESCE_EQUAL) reduce 524) ((T_CONCAT_EQUAL) reduce 524) ((T_DEC) reduce 524) ((T_DIV_EQUAL) reduce 524) ((T_DOUBLE_ARROW) reduce 524) ((T_INC) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_MINUS_EQUAL) reduce 524) ((T_MOD_EQUAL) reduce 524) ((T_MUL_EQUAL) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_OR_EQUAL) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_PLUS_EQUAL) reduce 524) ((T_POW) reduce 524) ((T_POW_EQUAL) reduce 524) ((T_SL) reduce 524) ((T_SL_EQUAL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) ((T_SR_EQUAL) reduce 524) ((T_XOR_EQUAL) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 9840 ((("%") reduce 445) (("*") reduce 445) (("+") reduce 445) (("-") reduce 445) ((".") reduce 445) (("/") reduce 445) ((":") reduce 445) (("<") reduce 445) ((">") reduce 445) (("?") reduce 445) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_BOOLEAN_AND) reduce 445) ((T_BOOLEAN_OR) reduce 445) ((T_COALESCE) reduce 445) ((T_DOUBLE_ARROW) reduce 445) ((T_INSTANCEOF) reduce 445) ((T_IS_EQUAL) reduce 445) ((T_IS_GREATER_OR_EQUAL) reduce 445) ((T_IS_IDENTICAL) reduce 445) ((T_IS_NOT_EQUAL) reduce 445) ((T_IS_NOT_IDENTICAL) reduce 445) ((T_IS_SMALLER_OR_EQUAL) reduce 445) ((T_LOGICAL_AND) reduce 445) ((T_LOGICAL_OR) reduce 445) ((T_LOGICAL_XOR) reduce 445) ((T_POW) reduce 445) ((T_SL) reduce 445) ((T_SPACESHIP) reduce 445) ((T_SR) reduce 445) (("^") reduce 445) (("|") reduce 445)) 9841 ((("%") reduce 427) (("*") reduce 427) (("+") reduce 427) (("-") reduce 427) ((".") reduce 427) (("/") reduce 427) ((":") reduce 427) (("<") reduce 427) ((">") reduce 427) (("?") reduce 427) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_BOOLEAN_AND) reduce 427) ((T_BOOLEAN_OR) reduce 427) ((T_COALESCE) reduce 427) ((T_DOUBLE_ARROW) reduce 427) ((T_INSTANCEOF) reduce 427) ((T_IS_EQUAL) reduce 427) ((T_IS_GREATER_OR_EQUAL) reduce 427) ((T_IS_IDENTICAL) reduce 427) ((T_IS_NOT_EQUAL) reduce 427) ((T_IS_NOT_IDENTICAL) reduce 427) ((T_IS_SMALLER_OR_EQUAL) reduce 427) ((T_LOGICAL_AND) reduce 427) ((T_LOGICAL_OR) reduce 427) ((T_LOGICAL_XOR) reduce 427) ((T_POW) reduce 427) ((T_SL) reduce 427) ((T_SPACESHIP) reduce 427) ((T_SR) reduce 427) (("^") reduce 427) (("|") reduce 427)) 9842 ((("%") reduce 449) (("*") reduce 449) (("+") reduce 449) (("-") reduce 449) ((".") reduce 449) (("/") reduce 449) ((":") reduce 449) (("<") reduce 449) ((">") reduce 449) (("?") reduce 449) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_BOOLEAN_AND) reduce 449) ((T_BOOLEAN_OR) reduce 449) ((T_COALESCE) reduce 449) ((T_DOUBLE_ARROW) reduce 449) ((T_INSTANCEOF) reduce 449) ((T_IS_EQUAL) reduce 449) ((T_IS_GREATER_OR_EQUAL) reduce 449) ((T_IS_IDENTICAL) reduce 449) ((T_IS_NOT_EQUAL) reduce 449) ((T_IS_NOT_IDENTICAL) reduce 449) ((T_IS_SMALLER_OR_EQUAL) reduce 449) ((T_LOGICAL_AND) reduce 449) ((T_LOGICAL_OR) reduce 449) ((T_LOGICAL_XOR) reduce 449) ((T_POW) reduce 449) ((T_SL) reduce 449) ((T_SPACESHIP) reduce 449) ((T_SR) reduce 449) (("^") reduce 449) (("|") reduce 449)) 9843 ((("%") reduce 494) (("(") shift) (("*") reduce 494) (("+") reduce 494) (("-") reduce 494) ((".") reduce 494) (("/") reduce 494) ((":") reduce 494) (("<") reduce 494) ((">") reduce 494) (("?") reduce 494) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_BOOLEAN_AND) reduce 494) ((T_BOOLEAN_OR) reduce 494) ((T_COALESCE) reduce 494) ((T_DOUBLE_ARROW) reduce 494) ((T_INSTANCEOF) reduce 494) ((T_IS_EQUAL) reduce 494) ((T_IS_GREATER_OR_EQUAL) reduce 494) ((T_IS_IDENTICAL) reduce 494) ((T_IS_NOT_EQUAL) reduce 494) ((T_IS_NOT_IDENTICAL) reduce 494) ((T_IS_SMALLER_OR_EQUAL) reduce 494) ((T_LOGICAL_AND) reduce 494) ((T_LOGICAL_OR) reduce 494) ((T_LOGICAL_XOR) reduce 494) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 494) ((T_OBJECT_OPERATOR) reduce 494) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 494) ((T_SL) reduce 494) ((T_SPACESHIP) reduce 494) ((T_SR) reduce 494) (("[") reduce 494) (("^") reduce 494) (("{") reduce 494) (("|") reduce 494)) 9844 ((("%") reduce 423) (("*") reduce 423) (("+") reduce 423) (("-") reduce 423) ((".") reduce 423) (("/") reduce 423) ((":") reduce 423) (("<") reduce 423) ((">") reduce 423) (("?") reduce 423) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_BOOLEAN_AND) reduce 423) ((T_BOOLEAN_OR) reduce 423) ((T_COALESCE) reduce 423) ((T_DOUBLE_ARROW) reduce 423) ((T_INSTANCEOF) reduce 423) ((T_IS_EQUAL) reduce 423) ((T_IS_GREATER_OR_EQUAL) reduce 423) ((T_IS_IDENTICAL) reduce 423) ((T_IS_NOT_EQUAL) reduce 423) ((T_IS_NOT_IDENTICAL) reduce 423) ((T_IS_SMALLER_OR_EQUAL) reduce 423) ((T_LOGICAL_AND) reduce 423) ((T_LOGICAL_OR) reduce 423) ((T_LOGICAL_XOR) reduce 423) ((T_POW) reduce 423) ((T_SL) reduce 423) ((T_SPACESHIP) reduce 423) ((T_SR) reduce 423) (("^") reduce 423) (("|") reduce 423)) 9845 ((("%") reduce 437) (("*") reduce 437) (("+") reduce 437) (("-") reduce 437) ((".") reduce 437) (("/") reduce 437) ((":") reduce 437) (("<") reduce 437) ((">") reduce 437) (("?") reduce 437) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_BOOLEAN_AND) reduce 437) ((T_BOOLEAN_OR) reduce 437) ((T_COALESCE) reduce 437) ((T_DOUBLE_ARROW) reduce 437) ((T_INSTANCEOF) reduce 437) ((T_IS_EQUAL) reduce 437) ((T_IS_GREATER_OR_EQUAL) reduce 437) ((T_IS_IDENTICAL) reduce 437) ((T_IS_NOT_EQUAL) reduce 437) ((T_IS_NOT_IDENTICAL) reduce 437) ((T_IS_SMALLER_OR_EQUAL) reduce 437) ((T_LOGICAL_AND) reduce 437) ((T_LOGICAL_OR) reduce 437) ((T_LOGICAL_XOR) reduce 437) ((T_POW) reduce 437) ((T_SL) reduce 437) ((T_SPACESHIP) reduce 437) ((T_SR) reduce 437) (("^") reduce 437) (("|") reduce 437)) 9846 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) ((":") reduce 519) (("<") reduce 519) (("=") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AND_EQUAL) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_COALESCE_EQUAL) reduce 519) ((T_CONCAT_EQUAL) reduce 519) ((T_DEC) reduce 519) ((T_DIV_EQUAL) reduce 519) ((T_DOUBLE_ARROW) reduce 519) ((T_INC) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_MINUS_EQUAL) reduce 519) ((T_MOD_EQUAL) reduce 519) ((T_MUL_EQUAL) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_OR_EQUAL) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_PLUS_EQUAL) reduce 519) ((T_POW) reduce 519) ((T_POW_EQUAL) reduce 519) ((T_SL) reduce 519) ((T_SL_EQUAL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) ((T_SR_EQUAL) reduce 519) ((T_XOR_EQUAL) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 9847 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) ((":") reduce 526) (("<") reduce 526) (("=") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AND_EQUAL) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_COALESCE_EQUAL) reduce 526) ((T_CONCAT_EQUAL) reduce 526) ((T_DEC) reduce 526) ((T_DIV_EQUAL) reduce 526) ((T_DOUBLE_ARROW) reduce 526) ((T_INC) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_MINUS_EQUAL) reduce 526) ((T_MOD_EQUAL) reduce 526) ((T_MUL_EQUAL) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_OR_EQUAL) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_PLUS_EQUAL) reduce 526) ((T_POW) reduce 526) ((T_POW_EQUAL) reduce 526) ((T_SL) reduce 526) ((T_SL_EQUAL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) ((T_SR_EQUAL) reduce 526) ((T_XOR_EQUAL) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 9848 ((("%") reduce 367) (("*") reduce 367) (("+") reduce 367) (("-") reduce 367) ((".") reduce 367) (("/") reduce 367) ((":") reduce 367) (("<") reduce 367) (("=") shift) ((">") reduce 367) (("?") reduce 367) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AND_EQUAL) shift) ((T_BOOLEAN_AND) reduce 367) ((T_BOOLEAN_OR) reduce 367) ((T_COALESCE) reduce 367) ((T_COALESCE_EQUAL) shift) ((T_CONCAT_EQUAL) shift) ((T_DEC) shift) ((T_DIV_EQUAL) shift) ((T_DOUBLE_ARROW) reduce 367) ((T_INC) shift) ((T_INSTANCEOF) reduce 367) ((T_IS_EQUAL) reduce 367) ((T_IS_GREATER_OR_EQUAL) reduce 367) ((T_IS_IDENTICAL) reduce 367) ((T_IS_NOT_EQUAL) reduce 367) ((T_IS_NOT_IDENTICAL) reduce 367) ((T_IS_SMALLER_OR_EQUAL) reduce 367) ((T_LOGICAL_AND) reduce 367) ((T_LOGICAL_OR) reduce 367) ((T_LOGICAL_XOR) reduce 367) ((T_MINUS_EQUAL) shift) ((T_MOD_EQUAL) shift) ((T_MUL_EQUAL) shift) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_OR_EQUAL) shift) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_PLUS_EQUAL) shift) ((T_POW) reduce 367) ((T_POW_EQUAL) shift) ((T_SL) reduce 367) ((T_SL_EQUAL) shift) ((T_SPACESHIP) reduce 367) ((T_SR) reduce 367) ((T_SR_EQUAL) shift) ((T_XOR_EQUAL) shift) (("[") reduce 510) (("^") reduce 367) (("{") reduce 510) (("|") reduce 367)) 9851 ((("%") reduce 411) (("*") reduce 411) (("+") reduce 411) (("-") reduce 411) ((".") reduce 411) (("/") reduce 411) ((":") reduce 411) (("<") reduce 411) ((">") reduce 411) (("?") reduce 411) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_BOOLEAN_AND) reduce 411) ((T_BOOLEAN_OR) reduce 411) ((T_COALESCE) reduce 411) ((T_DOUBLE_ARROW) reduce 411) ((T_INSTANCEOF) reduce 411) ((T_IS_EQUAL) reduce 411) ((T_IS_GREATER_OR_EQUAL) reduce 411) ((T_IS_IDENTICAL) reduce 411) ((T_IS_NOT_EQUAL) reduce 411) ((T_IS_NOT_IDENTICAL) reduce 411) ((T_IS_SMALLER_OR_EQUAL) reduce 411) ((T_LOGICAL_AND) reduce 411) ((T_LOGICAL_OR) reduce 411) ((T_LOGICAL_XOR) reduce 411) ((T_POW) shift) ((T_SL) reduce 411) ((T_SPACESHIP) reduce 411) ((T_SR) reduce 411) (("^") reduce 411) (("|") reduce 411)) 9882 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 395) (("<") shift) ((">") shift) (("?") reduce 395) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 395) ((T_BOOLEAN_OR) reduce 395) ((T_COALESCE) reduce 395) ((T_DOUBLE_ARROW) reduce 395) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 395) ((T_LOGICAL_OR) reduce 395) ((T_LOGICAL_XOR) reduce 395) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") reduce 395)) 9883 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 398) (("<") shift) ((">") shift) (("?") reduce 398) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 398) ((T_BOOLEAN_OR) reduce 398) ((T_COALESCE) reduce 398) ((T_DOUBLE_ARROW) reduce 398) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 398) ((T_LOGICAL_OR) reduce 398) ((T_LOGICAL_XOR) reduce 398) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 398) (("|") reduce 398)) 9884 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 407) (("/") shift) ((":") reduce 407) (("<") reduce 407) ((">") reduce 407) (("?") reduce 407) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_BOOLEAN_AND) reduce 407) ((T_BOOLEAN_OR) reduce 407) ((T_COALESCE) reduce 407) ((T_DOUBLE_ARROW) reduce 407) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 407) ((T_IS_GREATER_OR_EQUAL) reduce 407) ((T_IS_IDENTICAL) reduce 407) ((T_IS_NOT_EQUAL) reduce 407) ((T_IS_NOT_IDENTICAL) reduce 407) ((T_IS_SMALLER_OR_EQUAL) reduce 407) ((T_LOGICAL_AND) reduce 407) ((T_LOGICAL_OR) reduce 407) ((T_LOGICAL_XOR) reduce 407) ((T_POW) shift) ((T_SL) reduce 407) ((T_SPACESHIP) reduce 407) ((T_SR) reduce 407) (("^") reduce 407) (("|") reduce 407)) 9885 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 420) (("<") shift) ((">") shift) (("?") reduce 420) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_BOOLEAN_AND) reduce 420) ((T_BOOLEAN_OR) reduce 420) ((T_COALESCE) reduce 420) ((T_DOUBLE_ARROW) reduce 420) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 420) ((T_LOGICAL_OR) reduce 420) ((T_LOGICAL_XOR) reduce 420) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 420) (("|") reduce 420)) 9886 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 406) (("/") shift) ((":") reduce 406) (("<") reduce 406) ((">") reduce 406) (("?") reduce 406) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_BOOLEAN_AND) reduce 406) ((T_BOOLEAN_OR) reduce 406) ((T_COALESCE) reduce 406) ((T_DOUBLE_ARROW) reduce 406) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 406) ((T_IS_GREATER_OR_EQUAL) reduce 406) ((T_IS_IDENTICAL) reduce 406) ((T_IS_NOT_EQUAL) reduce 406) ((T_IS_NOT_IDENTICAL) reduce 406) ((T_IS_SMALLER_OR_EQUAL) reduce 406) ((T_LOGICAL_AND) reduce 406) ((T_LOGICAL_OR) reduce 406) ((T_LOGICAL_XOR) reduce 406) ((T_POW) shift) ((T_SL) reduce 406) ((T_SPACESHIP) reduce 406) ((T_SR) reduce 406) (("^") reduce 406) (("|") reduce 406)) 9887 ((("%") reduce 403) (("*") reduce 403) (("+") reduce 403) (("-") reduce 403) ((".") reduce 403) (("/") reduce 403) ((":") reduce 403) (("<") reduce 403) ((">") reduce 403) (("?") reduce 403) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_BOOLEAN_AND) reduce 403) ((T_BOOLEAN_OR) reduce 403) ((T_COALESCE) reduce 403) ((T_DOUBLE_ARROW) reduce 403) ((T_INSTANCEOF) reduce 403) ((T_IS_EQUAL) reduce 403) ((T_IS_GREATER_OR_EQUAL) reduce 403) ((T_IS_IDENTICAL) reduce 403) ((T_IS_NOT_EQUAL) reduce 403) ((T_IS_NOT_IDENTICAL) reduce 403) ((T_IS_SMALLER_OR_EQUAL) reduce 403) ((T_LOGICAL_AND) reduce 403) ((T_LOGICAL_OR) reduce 403) ((T_LOGICAL_XOR) reduce 403) ((T_POW) shift) ((T_SL) reduce 403) ((T_SPACESHIP) reduce 403) ((T_SR) reduce 403) (("^") reduce 403) (("|") reduce 403)) 9888 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 394) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 394) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 394) ((T_LOGICAL_XOR) reduce 394) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 9889 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 392) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 392) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 392) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 9890 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 393) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 393) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 393) ((T_LOGICAL_OR) reduce 393) ((T_LOGICAL_XOR) reduce 393) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 9891 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 417) (("<") shift) ((">") shift) (("?") reduce 417) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_BOOLEAN_AND) reduce 417) ((T_BOOLEAN_OR) reduce 417) ((T_COALESCE) reduce 417) ((T_DOUBLE_ARROW) reduce 417) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 417) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 417) ((T_IS_NOT_EQUAL) reduce 417) ((T_IS_NOT_IDENTICAL) reduce 417) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 417) ((T_LOGICAL_OR) reduce 417) ((T_LOGICAL_XOR) reduce 417) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 417) ((T_SR) shift) (("^") reduce 417) (("|") reduce 417)) 9892 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 413) (("<") shift) ((">") shift) (("?") reduce 413) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_BOOLEAN_AND) reduce 413) ((T_BOOLEAN_OR) reduce 413) ((T_COALESCE) reduce 413) ((T_DOUBLE_ARROW) reduce 413) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 413) ((T_LOGICAL_OR) reduce 413) ((T_LOGICAL_XOR) reduce 413) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 413) (("|") reduce 413)) 9893 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 415) (("<") shift) ((">") shift) (("?") reduce 415) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_BOOLEAN_AND) reduce 415) ((T_BOOLEAN_OR) reduce 415) ((T_COALESCE) reduce 415) ((T_DOUBLE_ARROW) reduce 415) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 415) ((T_LOGICAL_OR) reduce 415) ((T_LOGICAL_XOR) reduce 415) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 415) (("|") reduce 415)) 9894 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 412) (("<") shift) ((">") shift) (("?") reduce 412) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_BOOLEAN_AND) reduce 412) ((T_BOOLEAN_OR) reduce 412) ((T_COALESCE) reduce 412) ((T_DOUBLE_ARROW) reduce 412) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 412) ((T_LOGICAL_OR) reduce 412) ((T_LOGICAL_XOR) reduce 412) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 412) (("|") reduce 412)) 9895 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 419) (("<") shift) ((">") shift) (("?") reduce 419) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_BOOLEAN_AND) reduce 419) ((T_BOOLEAN_OR) reduce 419) ((T_COALESCE) reduce 419) ((T_DOUBLE_ARROW) reduce 419) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 419) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 419) ((T_IS_NOT_EQUAL) reduce 419) ((T_IS_NOT_IDENTICAL) reduce 419) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 419) ((T_LOGICAL_OR) reduce 419) ((T_LOGICAL_XOR) reduce 419) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 419) ((T_SR) shift) (("^") reduce 419) (("|") reduce 419)) 9896 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 414) (("<") shift) ((">") shift) (("?") reduce 414) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_BOOLEAN_AND) reduce 414) ((T_BOOLEAN_OR) reduce 414) ((T_COALESCE) reduce 414) ((T_DOUBLE_ARROW) reduce 414) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 414) ((T_LOGICAL_OR) reduce 414) ((T_LOGICAL_XOR) reduce 414) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 414) (("|") reduce 414)) 9899 ((("%") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) ((":") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93)) 9900 ((("%") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) ((":") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92)) 9901 ((("%") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) ((":") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94)) 9902 ((("%") reduce 470) (("*") reduce 470) (("+") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) ((":") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_DOUBLE_ARROW) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470)) 9903 ((("%") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) ((":") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91)) 9904 ((("%") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) ((":") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 9905 ((("%") reduce 472) (("*") reduce 472) (("+") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) ((":") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_DOUBLE_ARROW) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472)) 9906 ((("%") reduce 421) (("*") reduce 421) (("+") reduce 421) (("-") reduce 421) ((".") reduce 421) (("/") reduce 421) ((":") reduce 421) (("<") reduce 421) ((">") reduce 421) (("?") reduce 421) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_BOOLEAN_AND) reduce 421) ((T_BOOLEAN_OR) reduce 421) ((T_COALESCE) reduce 421) ((T_DOUBLE_ARROW) reduce 421) ((T_INSTANCEOF) reduce 421) ((T_IS_EQUAL) reduce 421) ((T_IS_GREATER_OR_EQUAL) reduce 421) ((T_IS_IDENTICAL) reduce 421) ((T_IS_NOT_EQUAL) reduce 421) ((T_IS_NOT_IDENTICAL) reduce 421) ((T_IS_SMALLER_OR_EQUAL) reduce 421) ((T_LOGICAL_AND) reduce 421) ((T_LOGICAL_OR) reduce 421) ((T_LOGICAL_XOR) reduce 421) ((T_POW) reduce 421) ((T_SL) reduce 421) ((T_SPACESHIP) reduce 421) ((T_SR) reduce 421) (("^") reduce 421) (("|") reduce 421)) 9907 ((("%") reduce 471) (("*") reduce 471) (("+") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) ((":") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_DOUBLE_ARROW) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471)) 9908 ((("%") reduce 473) (("*") reduce 473) (("+") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) ((":") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_DOUBLE_ARROW) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 9909 ((("%") reduce 534) (("*") reduce 534) (("+") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) ((":") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_DOUBLE_ARROW) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 9916 ((("%") reduce 536) (("*") reduce 536) (("+") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) ((":") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_DOUBLE_ARROW) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 9918 ((("%") reduce 535) (("*") reduce 535) (("+") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) ((":") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_DOUBLE_ARROW) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 9919 ((("%") reduce 540) (("*") reduce 540) (("+") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) ((":") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_DOUBLE_ARROW) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 9920 ((("%") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) ((":") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 9921 ((("%") reduce 537) (("*") reduce 537) (("+") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) ((":") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_DOUBLE_ARROW) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 9922 ((("%") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) ((":") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 9925 ((("%") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) ((":") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 9926 ((("%") reduce 538) (("*") reduce 538) (("+") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) ((":") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_DOUBLE_ARROW) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 9928 ((("%") reduce 539) (("*") reduce 539) (("+") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) ((":") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_DOUBLE_ARROW) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 9930 ((("%") reduce 474) (("*") reduce 474) (("+") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) ((":") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_DOUBLE_ARROW) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474)) 9931 ((("%") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) ((":") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 9934 ((("%") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) ((":") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 9935 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 426) (("<") shift) ((">") shift) (("?") reduce 426) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 426) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 426) ((T_LOGICAL_OR) reduce 426) ((T_LOGICAL_XOR) reduce 426) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 9936 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 390) (("<") shift) ((">") shift) (("?") reduce 390) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) reduce 390) ((T_COALESCE) reduce 390) ((T_DOUBLE_ARROW) reduce 390) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 390) ((T_LOGICAL_OR) reduce 390) ((T_LOGICAL_XOR) reduce 390) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 9937 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 391) (("<") shift) ((">") shift) (("?") reduce 391) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 391) ((T_BOOLEAN_OR) reduce 391) ((T_COALESCE) reduce 391) ((T_DOUBLE_ARROW) reduce 391) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 391) ((T_LOGICAL_OR) reduce 391) ((T_LOGICAL_XOR) reduce 391) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 9938 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 396) (("<") shift) ((">") shift) (("?") reduce 396) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_BOOLEAN_AND) reduce 396) ((T_BOOLEAN_OR) reduce 396) ((T_COALESCE) reduce 396) ((T_DOUBLE_ARROW) reduce 396) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 396) ((T_LOGICAL_OR) reduce 396) ((T_LOGICAL_XOR) reduce 396) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 396) (("|") reduce 396)) 9939 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 397) (("<") shift) ((">") shift) (("?") reduce 397) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_BOOLEAN_AND) reduce 397) ((T_BOOLEAN_OR) reduce 397) ((T_COALESCE) reduce 397) ((T_DOUBLE_ARROW) reduce 397) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 397) ((T_LOGICAL_OR) reduce 397) ((T_LOGICAL_XOR) reduce 397) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 397) (("|") reduce 397)) 9943 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 424) (("<") shift) ((">") shift) (("?") reduce 424) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 424) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 424) ((T_LOGICAL_OR) reduce 424) ((T_LOGICAL_XOR) reduce 424) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 9944 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 425) (("<") shift) ((">") shift) (("?") reduce 425) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 425) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 425) ((T_LOGICAL_OR) reduce 425) ((T_LOGICAL_XOR) reduce 425) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 9945 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 418) (("<") shift) ((">") shift) (("?") reduce 418) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_BOOLEAN_AND) reduce 418) ((T_BOOLEAN_OR) reduce 418) ((T_COALESCE) reduce 418) ((T_DOUBLE_ARROW) reduce 418) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 418) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 418) ((T_IS_NOT_EQUAL) reduce 418) ((T_IS_NOT_IDENTICAL) reduce 418) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 418) ((T_LOGICAL_OR) reduce 418) ((T_LOGICAL_XOR) reduce 418) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 418) ((T_SR) shift) (("^") reduce 418) (("|") reduce 418)) 9946 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 416) (("<") shift) ((">") shift) (("?") reduce 416) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_BOOLEAN_AND) reduce 416) ((T_BOOLEAN_OR) reduce 416) ((T_COALESCE) reduce 416) ((T_DOUBLE_ARROW) reduce 416) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 416) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 416) ((T_IS_NOT_EQUAL) reduce 416) ((T_IS_NOT_IDENTICAL) reduce 416) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 416) ((T_LOGICAL_OR) reduce 416) ((T_LOGICAL_XOR) reduce 416) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 416) ((T_SR) shift) (("^") reduce 416) (("|") reduce 416)) 9947 ((("%") reduce 404) (("*") reduce 404) (("+") reduce 404) (("-") reduce 404) ((".") reduce 404) (("/") reduce 404) ((":") reduce 404) (("<") reduce 404) ((">") reduce 404) (("?") reduce 404) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_BOOLEAN_AND) reduce 404) ((T_BOOLEAN_OR) reduce 404) ((T_COALESCE) reduce 404) ((T_DOUBLE_ARROW) reduce 404) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 404) ((T_IS_GREATER_OR_EQUAL) reduce 404) ((T_IS_IDENTICAL) reduce 404) ((T_IS_NOT_EQUAL) reduce 404) ((T_IS_NOT_IDENTICAL) reduce 404) ((T_IS_SMALLER_OR_EQUAL) reduce 404) ((T_LOGICAL_AND) reduce 404) ((T_LOGICAL_OR) reduce 404) ((T_LOGICAL_XOR) reduce 404) ((T_POW) shift) ((T_SL) reduce 404) ((T_SPACESHIP) reduce 404) ((T_SR) reduce 404) (("^") reduce 404) (("|") reduce 404)) 9948 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 399) (("/") shift) ((":") reduce 399) (("<") reduce 399) ((">") reduce 399) (("?") reduce 399) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_BOOLEAN_AND) reduce 399) ((T_BOOLEAN_OR) reduce 399) ((T_COALESCE) reduce 399) ((T_DOUBLE_ARROW) reduce 399) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 399) ((T_IS_GREATER_OR_EQUAL) reduce 399) ((T_IS_IDENTICAL) reduce 399) ((T_IS_NOT_EQUAL) reduce 399) ((T_IS_NOT_IDENTICAL) reduce 399) ((T_IS_SMALLER_OR_EQUAL) reduce 399) ((T_LOGICAL_AND) reduce 399) ((T_LOGICAL_OR) reduce 399) ((T_LOGICAL_XOR) reduce 399) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 399) ((T_SR) shift) (("^") reduce 399) (("|") reduce 399)) 9949 ((("%") shift) (("*") shift) (("+") reduce 401) (("-") reduce 401) ((".") reduce 401) (("/") shift) ((":") reduce 401) (("<") reduce 401) ((">") reduce 401) (("?") reduce 401) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_BOOLEAN_AND) reduce 401) ((T_BOOLEAN_OR) reduce 401) ((T_COALESCE) reduce 401) ((T_DOUBLE_ARROW) reduce 401) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 401) ((T_IS_GREATER_OR_EQUAL) reduce 401) ((T_IS_IDENTICAL) reduce 401) ((T_IS_NOT_EQUAL) reduce 401) ((T_IS_NOT_IDENTICAL) reduce 401) ((T_IS_SMALLER_OR_EQUAL) reduce 401) ((T_LOGICAL_AND) reduce 401) ((T_LOGICAL_OR) reduce 401) ((T_LOGICAL_XOR) reduce 401) ((T_POW) shift) ((T_SL) reduce 401) ((T_SPACESHIP) reduce 401) ((T_SR) reduce 401) (("^") reduce 401) (("|") reduce 401)) 9950 ((("%") shift) (("*") shift) (("+") reduce 400) (("-") reduce 400) ((".") reduce 400) (("/") shift) ((":") reduce 400) (("<") reduce 400) ((">") reduce 400) (("?") reduce 400) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_BOOLEAN_AND) reduce 400) ((T_BOOLEAN_OR) reduce 400) ((T_COALESCE) reduce 400) ((T_DOUBLE_ARROW) reduce 400) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 400) ((T_IS_GREATER_OR_EQUAL) reduce 400) ((T_IS_IDENTICAL) reduce 400) ((T_IS_NOT_EQUAL) reduce 400) ((T_IS_NOT_IDENTICAL) reduce 400) ((T_IS_SMALLER_OR_EQUAL) reduce 400) ((T_LOGICAL_AND) reduce 400) ((T_LOGICAL_OR) reduce 400) ((T_LOGICAL_XOR) reduce 400) ((T_POW) shift) ((T_SL) reduce 400) ((T_SPACESHIP) reduce 400) ((T_SR) reduce 400) (("^") reduce 400) (("|") reduce 400)) 9951 ((("%") reduce 402) (("*") reduce 402) (("+") reduce 402) (("-") reduce 402) ((".") reduce 402) (("/") reduce 402) ((":") reduce 402) (("<") reduce 402) ((">") reduce 402) (("?") reduce 402) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_BOOLEAN_AND) reduce 402) ((T_BOOLEAN_OR) reduce 402) ((T_COALESCE) reduce 402) ((T_DOUBLE_ARROW) reduce 402) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 402) ((T_IS_GREATER_OR_EQUAL) reduce 402) ((T_IS_IDENTICAL) reduce 402) ((T_IS_NOT_EQUAL) reduce 402) ((T_IS_NOT_IDENTICAL) reduce 402) ((T_IS_SMALLER_OR_EQUAL) reduce 402) ((T_LOGICAL_AND) reduce 402) ((T_LOGICAL_OR) reduce 402) ((T_LOGICAL_XOR) reduce 402) ((T_POW) shift) ((T_SL) reduce 402) ((T_SPACESHIP) reduce 402) ((T_SR) reduce 402) (("^") reduce 402) (("|") reduce 402)) 9952 ((("%") reduce 405) (("*") reduce 405) (("+") reduce 405) (("-") reduce 405) ((".") reduce 405) (("/") reduce 405) ((":") reduce 405) (("<") reduce 405) ((">") reduce 405) (("?") reduce 405) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_BOOLEAN_AND) reduce 405) ((T_BOOLEAN_OR) reduce 405) ((T_COALESCE) reduce 405) ((T_DOUBLE_ARROW) reduce 405) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 405) ((T_IS_GREATER_OR_EQUAL) reduce 405) ((T_IS_IDENTICAL) reduce 405) ((T_IS_NOT_EQUAL) reduce 405) ((T_IS_NOT_IDENTICAL) reduce 405) ((T_IS_SMALLER_OR_EQUAL) reduce 405) ((T_LOGICAL_AND) reduce 405) ((T_LOGICAL_OR) reduce 405) ((T_LOGICAL_XOR) reduce 405) ((T_POW) shift) ((T_SL) reduce 405) ((T_SPACESHIP) reduce 405) ((T_SR) reduce 405) (("^") reduce 405) (("|") reduce 405)) 9954 ((("%") reduce 73) (("(") reduce 73) (("*") reduce 73) (("+") reduce 73) (("-") reduce 73) ((".") reduce 73) (("/") reduce 73) ((":") reduce 73) (("<") reduce 73) ((">") reduce 73) (("?") reduce 73) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_BOOLEAN_AND) reduce 73) ((T_BOOLEAN_OR) reduce 73) ((T_COALESCE) reduce 73) ((T_DOUBLE_ARROW) reduce 73) ((T_INSTANCEOF) reduce 73) ((T_IS_EQUAL) reduce 73) ((T_IS_GREATER_OR_EQUAL) reduce 73) ((T_IS_IDENTICAL) reduce 73) ((T_IS_NOT_EQUAL) reduce 73) ((T_IS_NOT_IDENTICAL) reduce 73) ((T_IS_SMALLER_OR_EQUAL) reduce 73) ((T_LOGICAL_AND) reduce 73) ((T_LOGICAL_OR) reduce 73) ((T_LOGICAL_XOR) reduce 73) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 73) ((T_OBJECT_OPERATOR) reduce 73) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 73) ((T_POW) reduce 73) ((T_SL) reduce 73) ((T_SPACESHIP) reduce 73) ((T_SR) reduce 73) (("[") reduce 73) (("^") reduce 73) (("{") reduce 73) (("|") reduce 73)) 9955 ((("%") reduce 52) (("(") reduce 52) (("*") reduce 52) (("+") reduce 52) (("-") reduce 52) ((".") reduce 52) (("/") reduce 52) ((":") reduce 52) (("<") reduce 52) ((">") reduce 52) (("?") reduce 52) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_BOOLEAN_AND) reduce 52) ((T_BOOLEAN_OR) reduce 52) ((T_COALESCE) reduce 52) ((T_DOUBLE_ARROW) reduce 52) ((T_INSTANCEOF) reduce 52) ((T_IS_EQUAL) reduce 52) ((T_IS_GREATER_OR_EQUAL) reduce 52) ((T_IS_IDENTICAL) reduce 52) ((T_IS_NOT_EQUAL) reduce 52) ((T_IS_NOT_IDENTICAL) reduce 52) ((T_IS_SMALLER_OR_EQUAL) reduce 52) ((T_LOGICAL_AND) reduce 52) ((T_LOGICAL_OR) reduce 52) ((T_LOGICAL_XOR) reduce 52) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 52) ((T_OBJECT_OPERATOR) reduce 52) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 52) ((T_POW) reduce 52) ((T_SL) reduce 52) ((T_SPACESHIP) reduce 52) ((T_SR) reduce 52) (("[") reduce 52) (("^") reduce 52) (("{") reduce 52) (("|") reduce 52)) 9956 ((("%") reduce 27) (("(") reduce 27) (("*") reduce 27) (("+") reduce 27) (("-") reduce 27) ((".") reduce 27) (("/") reduce 27) ((":") reduce 27) (("<") reduce 27) ((">") reduce 27) (("?") reduce 27) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_BOOLEAN_AND) reduce 27) ((T_BOOLEAN_OR) reduce 27) ((T_COALESCE) reduce 27) ((T_DOUBLE_ARROW) reduce 27) ((T_INSTANCEOF) reduce 27) ((T_IS_EQUAL) reduce 27) ((T_IS_GREATER_OR_EQUAL) reduce 27) ((T_IS_IDENTICAL) reduce 27) ((T_IS_NOT_EQUAL) reduce 27) ((T_IS_NOT_IDENTICAL) reduce 27) ((T_IS_SMALLER_OR_EQUAL) reduce 27) ((T_LOGICAL_AND) reduce 27) ((T_LOGICAL_OR) reduce 27) ((T_LOGICAL_XOR) reduce 27) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 27) ((T_OBJECT_OPERATOR) reduce 27) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 27) ((T_POW) reduce 27) ((T_SL) reduce 27) ((T_SPACESHIP) reduce 27) ((T_SR) reduce 27) (("[") reduce 27) (("^") reduce 27) (("{") reduce 27) (("|") reduce 27)) 9957 ((("%") reduce 51) (("(") reduce 51) (("*") reduce 51) (("+") reduce 51) (("-") reduce 51) ((".") reduce 51) (("/") reduce 51) ((":") reduce 51) (("<") reduce 51) ((">") reduce 51) (("?") reduce 51) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_BOOLEAN_AND) reduce 51) ((T_BOOLEAN_OR) reduce 51) ((T_COALESCE) reduce 51) ((T_DOUBLE_ARROW) reduce 51) ((T_INSTANCEOF) reduce 51) ((T_IS_EQUAL) reduce 51) ((T_IS_GREATER_OR_EQUAL) reduce 51) ((T_IS_IDENTICAL) reduce 51) ((T_IS_NOT_EQUAL) reduce 51) ((T_IS_NOT_IDENTICAL) reduce 51) ((T_IS_SMALLER_OR_EQUAL) reduce 51) ((T_LOGICAL_AND) reduce 51) ((T_LOGICAL_OR) reduce 51) ((T_LOGICAL_XOR) reduce 51) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 51) ((T_OBJECT_OPERATOR) reduce 51) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 51) ((T_POW) reduce 51) ((T_SL) reduce 51) ((T_SPACESHIP) reduce 51) ((T_SR) reduce 51) (("[") reduce 51) (("^") reduce 51) (("{") reduce 51) (("|") reduce 51)) 9958 ((("%") reduce 53) (("(") reduce 53) (("*") reduce 53) (("+") reduce 53) (("-") reduce 53) ((".") reduce 53) (("/") reduce 53) ((":") reduce 53) (("<") reduce 53) ((">") reduce 53) (("?") reduce 53) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_BOOLEAN_AND) reduce 53) ((T_BOOLEAN_OR) reduce 53) ((T_COALESCE) reduce 53) ((T_DOUBLE_ARROW) reduce 53) ((T_INSTANCEOF) reduce 53) ((T_IS_EQUAL) reduce 53) ((T_IS_GREATER_OR_EQUAL) reduce 53) ((T_IS_IDENTICAL) reduce 53) ((T_IS_NOT_EQUAL) reduce 53) ((T_IS_NOT_IDENTICAL) reduce 53) ((T_IS_SMALLER_OR_EQUAL) reduce 53) ((T_LOGICAL_AND) reduce 53) ((T_LOGICAL_OR) reduce 53) ((T_LOGICAL_XOR) reduce 53) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 53) ((T_OBJECT_OPERATOR) reduce 53) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 53) ((T_POW) reduce 53) ((T_SL) reduce 53) ((T_SPACESHIP) reduce 53) ((T_SR) reduce 53) (("[") reduce 53) (("^") reduce 53) (("{") reduce 53) (("|") reduce 53)) 9959 ((("%") reduce 49) (("(") reduce 49) (("*") reduce 49) (("+") reduce 49) (("-") reduce 49) ((".") reduce 49) (("/") reduce 49) ((":") reduce 49) (("<") reduce 49) ((">") reduce 49) (("?") reduce 49) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_BOOLEAN_AND) reduce 49) ((T_BOOLEAN_OR) reduce 49) ((T_COALESCE) reduce 49) ((T_DOUBLE_ARROW) reduce 49) ((T_INSTANCEOF) reduce 49) ((T_IS_EQUAL) reduce 49) ((T_IS_GREATER_OR_EQUAL) reduce 49) ((T_IS_IDENTICAL) reduce 49) ((T_IS_NOT_EQUAL) reduce 49) ((T_IS_NOT_IDENTICAL) reduce 49) ((T_IS_SMALLER_OR_EQUAL) reduce 49) ((T_LOGICAL_AND) reduce 49) ((T_LOGICAL_OR) reduce 49) ((T_LOGICAL_XOR) reduce 49) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 49) ((T_OBJECT_OPERATOR) reduce 49) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 49) ((T_POW) reduce 49) ((T_SL) reduce 49) ((T_SPACESHIP) reduce 49) ((T_SR) reduce 49) (("[") reduce 49) (("^") reduce 49) (("{") reduce 49) (("|") reduce 49)) 9960 ((("%") reduce 29) (("(") reduce 29) (("*") reduce 29) (("+") reduce 29) (("-") reduce 29) ((".") reduce 29) (("/") reduce 29) ((":") reduce 29) (("<") reduce 29) ((">") reduce 29) (("?") reduce 29) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_BOOLEAN_AND) reduce 29) ((T_BOOLEAN_OR) reduce 29) ((T_COALESCE) reduce 29) ((T_DOUBLE_ARROW) reduce 29) ((T_INSTANCEOF) reduce 29) ((T_IS_EQUAL) reduce 29) ((T_IS_GREATER_OR_EQUAL) reduce 29) ((T_IS_IDENTICAL) reduce 29) ((T_IS_NOT_EQUAL) reduce 29) ((T_IS_NOT_IDENTICAL) reduce 29) ((T_IS_SMALLER_OR_EQUAL) reduce 29) ((T_LOGICAL_AND) reduce 29) ((T_LOGICAL_OR) reduce 29) ((T_LOGICAL_XOR) reduce 29) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 29) ((T_OBJECT_OPERATOR) reduce 29) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 29) ((T_POW) reduce 29) ((T_SL) reduce 29) ((T_SPACESHIP) reduce 29) ((T_SR) reduce 29) (("[") reduce 29) (("^") reduce 29) (("{") reduce 29) (("|") reduce 29)) 9961 ((("%") reduce 59) (("(") reduce 59) (("*") reduce 59) (("+") reduce 59) (("-") reduce 59) ((".") reduce 59) (("/") reduce 59) ((":") reduce 59) (("<") reduce 59) ((">") reduce 59) (("?") reduce 59) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_BOOLEAN_AND) reduce 59) ((T_BOOLEAN_OR) reduce 59) ((T_COALESCE) reduce 59) ((T_DOUBLE_ARROW) reduce 59) ((T_INSTANCEOF) reduce 59) ((T_IS_EQUAL) reduce 59) ((T_IS_GREATER_OR_EQUAL) reduce 59) ((T_IS_IDENTICAL) reduce 59) ((T_IS_NOT_EQUAL) reduce 59) ((T_IS_NOT_IDENTICAL) reduce 59) ((T_IS_SMALLER_OR_EQUAL) reduce 59) ((T_LOGICAL_AND) reduce 59) ((T_LOGICAL_OR) reduce 59) ((T_LOGICAL_XOR) reduce 59) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 59) ((T_OBJECT_OPERATOR) reduce 59) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 59) ((T_POW) reduce 59) ((T_SL) reduce 59) ((T_SPACESHIP) reduce 59) ((T_SR) reduce 59) (("[") reduce 59) (("^") reduce 59) (("{") reduce 59) (("|") reduce 59)) 9962 ((("%") reduce 60) (("(") reduce 60) (("*") reduce 60) (("+") reduce 60) (("-") reduce 60) ((".") reduce 60) (("/") reduce 60) ((":") reduce 60) (("<") reduce 60) ((">") reduce 60) (("?") reduce 60) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_BOOLEAN_AND) reduce 60) ((T_BOOLEAN_OR) reduce 60) ((T_COALESCE) reduce 60) ((T_DOUBLE_ARROW) reduce 60) ((T_INSTANCEOF) reduce 60) ((T_IS_EQUAL) reduce 60) ((T_IS_GREATER_OR_EQUAL) reduce 60) ((T_IS_IDENTICAL) reduce 60) ((T_IS_NOT_EQUAL) reduce 60) ((T_IS_NOT_IDENTICAL) reduce 60) ((T_IS_SMALLER_OR_EQUAL) reduce 60) ((T_LOGICAL_AND) reduce 60) ((T_LOGICAL_OR) reduce 60) ((T_LOGICAL_XOR) reduce 60) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 60) ((T_OBJECT_OPERATOR) reduce 60) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 60) ((T_POW) reduce 60) ((T_SL) reduce 60) ((T_SPACESHIP) reduce 60) ((T_SR) reduce 60) (("[") reduce 60) (("^") reduce 60) (("{") reduce 60) (("|") reduce 60)) 9963 ((("%") reduce 11) (("(") reduce 11) (("*") reduce 11) (("+") reduce 11) (("-") reduce 11) ((".") reduce 11) (("/") reduce 11) ((":") reduce 11) (("<") reduce 11) ((">") reduce 11) (("?") reduce 11) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_BOOLEAN_AND) reduce 11) ((T_BOOLEAN_OR) reduce 11) ((T_COALESCE) reduce 11) ((T_DOUBLE_ARROW) reduce 11) ((T_INSTANCEOF) reduce 11) ((T_IS_EQUAL) reduce 11) ((T_IS_GREATER_OR_EQUAL) reduce 11) ((T_IS_IDENTICAL) reduce 11) ((T_IS_NOT_EQUAL) reduce 11) ((T_IS_NOT_IDENTICAL) reduce 11) ((T_IS_SMALLER_OR_EQUAL) reduce 11) ((T_LOGICAL_AND) reduce 11) ((T_LOGICAL_OR) reduce 11) ((T_LOGICAL_XOR) reduce 11) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 11) ((T_OBJECT_OPERATOR) reduce 11) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 11) ((T_POW) reduce 11) ((T_SL) reduce 11) ((T_SPACESHIP) reduce 11) ((T_SR) reduce 11) (("[") reduce 11) (("^") reduce 11) (("{") reduce 11) (("|") reduce 11)) 9964 ((("%") reduce 42) (("(") reduce 42) (("*") reduce 42) (("+") reduce 42) (("-") reduce 42) ((".") reduce 42) (("/") reduce 42) ((":") reduce 42) (("<") reduce 42) ((">") reduce 42) (("?") reduce 42) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_BOOLEAN_AND) reduce 42) ((T_BOOLEAN_OR) reduce 42) ((T_COALESCE) reduce 42) ((T_DOUBLE_ARROW) reduce 42) ((T_INSTANCEOF) reduce 42) ((T_IS_EQUAL) reduce 42) ((T_IS_GREATER_OR_EQUAL) reduce 42) ((T_IS_IDENTICAL) reduce 42) ((T_IS_NOT_EQUAL) reduce 42) ((T_IS_NOT_IDENTICAL) reduce 42) ((T_IS_SMALLER_OR_EQUAL) reduce 42) ((T_LOGICAL_AND) reduce 42) ((T_LOGICAL_OR) reduce 42) ((T_LOGICAL_XOR) reduce 42) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 42) ((T_OBJECT_OPERATOR) reduce 42) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 42) ((T_POW) reduce 42) ((T_SL) reduce 42) ((T_SPACESHIP) reduce 42) ((T_SR) reduce 42) (("[") reduce 42) (("^") reduce 42) (("{") reduce 42) (("|") reduce 42)) 9965 ((("%") reduce 39) (("(") reduce 39) (("*") reduce 39) (("+") reduce 39) (("-") reduce 39) ((".") reduce 39) (("/") reduce 39) ((":") reduce 39) (("<") reduce 39) ((">") reduce 39) (("?") reduce 39) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_BOOLEAN_AND) reduce 39) ((T_BOOLEAN_OR) reduce 39) ((T_COALESCE) reduce 39) ((T_DOUBLE_ARROW) reduce 39) ((T_INSTANCEOF) reduce 39) ((T_IS_EQUAL) reduce 39) ((T_IS_GREATER_OR_EQUAL) reduce 39) ((T_IS_IDENTICAL) reduce 39) ((T_IS_NOT_EQUAL) reduce 39) ((T_IS_NOT_IDENTICAL) reduce 39) ((T_IS_SMALLER_OR_EQUAL) reduce 39) ((T_LOGICAL_AND) reduce 39) ((T_LOGICAL_OR) reduce 39) ((T_LOGICAL_XOR) reduce 39) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 39) ((T_OBJECT_OPERATOR) reduce 39) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 39) ((T_POW) reduce 39) ((T_SL) reduce 39) ((T_SPACESHIP) reduce 39) ((T_SR) reduce 39) (("[") reduce 39) (("^") reduce 39) (("{") reduce 39) (("|") reduce 39)) 9966 ((("%") reduce 25) (("(") reduce 25) (("*") reduce 25) (("+") reduce 25) (("-") reduce 25) ((".") reduce 25) (("/") reduce 25) ((":") reduce 25) (("<") reduce 25) ((">") reduce 25) (("?") reduce 25) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_BOOLEAN_AND) reduce 25) ((T_BOOLEAN_OR) reduce 25) ((T_COALESCE) reduce 25) ((T_DOUBLE_ARROW) reduce 25) ((T_INSTANCEOF) reduce 25) ((T_IS_EQUAL) reduce 25) ((T_IS_GREATER_OR_EQUAL) reduce 25) ((T_IS_IDENTICAL) reduce 25) ((T_IS_NOT_EQUAL) reduce 25) ((T_IS_NOT_IDENTICAL) reduce 25) ((T_IS_SMALLER_OR_EQUAL) reduce 25) ((T_LOGICAL_AND) reduce 25) ((T_LOGICAL_OR) reduce 25) ((T_LOGICAL_XOR) reduce 25) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 25) ((T_OBJECT_OPERATOR) reduce 25) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 25) ((T_POW) reduce 25) ((T_SL) reduce 25) ((T_SPACESHIP) reduce 25) ((T_SR) reduce 25) (("[") reduce 25) (("^") reduce 25) (("{") reduce 25) (("|") reduce 25)) 9967 ((("%") reduce 50) (("(") reduce 50) (("*") reduce 50) (("+") reduce 50) (("-") reduce 50) ((".") reduce 50) (("/") reduce 50) ((":") reduce 50) (("<") reduce 50) ((">") reduce 50) (("?") reduce 50) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_BOOLEAN_AND) reduce 50) ((T_BOOLEAN_OR) reduce 50) ((T_COALESCE) reduce 50) ((T_DOUBLE_ARROW) reduce 50) ((T_INSTANCEOF) reduce 50) ((T_IS_EQUAL) reduce 50) ((T_IS_GREATER_OR_EQUAL) reduce 50) ((T_IS_IDENTICAL) reduce 50) ((T_IS_NOT_EQUAL) reduce 50) ((T_IS_NOT_IDENTICAL) reduce 50) ((T_IS_SMALLER_OR_EQUAL) reduce 50) ((T_LOGICAL_AND) reduce 50) ((T_LOGICAL_OR) reduce 50) ((T_LOGICAL_XOR) reduce 50) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 50) ((T_OBJECT_OPERATOR) reduce 50) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 50) ((T_POW) reduce 50) ((T_SL) reduce 50) ((T_SPACESHIP) reduce 50) ((T_SR) reduce 50) (("[") reduce 50) (("^") reduce 50) (("{") reduce 50) (("|") reduce 50)) 9968 ((("%") reduce 66) (("(") reduce 66) (("*") reduce 66) (("+") reduce 66) (("-") reduce 66) ((".") reduce 66) (("/") reduce 66) ((":") reduce 66) (("<") reduce 66) ((">") reduce 66) (("?") reduce 66) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_BOOLEAN_AND) reduce 66) ((T_BOOLEAN_OR) reduce 66) ((T_COALESCE) reduce 66) ((T_DOUBLE_ARROW) reduce 66) ((T_INSTANCEOF) reduce 66) ((T_IS_EQUAL) reduce 66) ((T_IS_GREATER_OR_EQUAL) reduce 66) ((T_IS_IDENTICAL) reduce 66) ((T_IS_NOT_EQUAL) reduce 66) ((T_IS_NOT_IDENTICAL) reduce 66) ((T_IS_SMALLER_OR_EQUAL) reduce 66) ((T_LOGICAL_AND) reduce 66) ((T_LOGICAL_OR) reduce 66) ((T_LOGICAL_XOR) reduce 66) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 66) ((T_OBJECT_OPERATOR) reduce 66) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 66) ((T_POW) reduce 66) ((T_SL) reduce 66) ((T_SPACESHIP) reduce 66) ((T_SR) reduce 66) (("[") reduce 66) (("^") reduce 66) (("{") reduce 66) (("|") reduce 66)) 9969 ((("%") reduce 18) (("(") reduce 18) (("*") reduce 18) (("+") reduce 18) (("-") reduce 18) ((".") reduce 18) (("/") reduce 18) ((":") reduce 18) (("<") reduce 18) ((">") reduce 18) (("?") reduce 18) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_BOOLEAN_AND) reduce 18) ((T_BOOLEAN_OR) reduce 18) ((T_COALESCE) reduce 18) ((T_DOUBLE_ARROW) reduce 18) ((T_INSTANCEOF) reduce 18) ((T_IS_EQUAL) reduce 18) ((T_IS_GREATER_OR_EQUAL) reduce 18) ((T_IS_IDENTICAL) reduce 18) ((T_IS_NOT_EQUAL) reduce 18) ((T_IS_NOT_IDENTICAL) reduce 18) ((T_IS_SMALLER_OR_EQUAL) reduce 18) ((T_LOGICAL_AND) reduce 18) ((T_LOGICAL_OR) reduce 18) ((T_LOGICAL_XOR) reduce 18) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 18) ((T_OBJECT_OPERATOR) reduce 18) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 18) ((T_POW) reduce 18) ((T_SL) reduce 18) ((T_SPACESHIP) reduce 18) ((T_SR) reduce 18) (("[") reduce 18) (("^") reduce 18) (("{") reduce 18) (("|") reduce 18)) 9970 ((("%") reduce 17) (("(") reduce 17) (("*") reduce 17) (("+") reduce 17) (("-") reduce 17) ((".") reduce 17) (("/") reduce 17) ((":") reduce 17) (("<") reduce 17) ((">") reduce 17) (("?") reduce 17) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_BOOLEAN_AND) reduce 17) ((T_BOOLEAN_OR) reduce 17) ((T_COALESCE) reduce 17) ((T_DOUBLE_ARROW) reduce 17) ((T_INSTANCEOF) reduce 17) ((T_IS_EQUAL) reduce 17) ((T_IS_GREATER_OR_EQUAL) reduce 17) ((T_IS_IDENTICAL) reduce 17) ((T_IS_NOT_EQUAL) reduce 17) ((T_IS_NOT_IDENTICAL) reduce 17) ((T_IS_SMALLER_OR_EQUAL) reduce 17) ((T_LOGICAL_AND) reduce 17) ((T_LOGICAL_OR) reduce 17) ((T_LOGICAL_XOR) reduce 17) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 17) ((T_OBJECT_OPERATOR) reduce 17) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 17) ((T_POW) reduce 17) ((T_SL) reduce 17) ((T_SPACESHIP) reduce 17) ((T_SR) reduce 17) (("[") reduce 17) (("^") reduce 17) (("{") reduce 17) (("|") reduce 17)) 9971 ((("%") reduce 15) (("(") reduce 15) (("*") reduce 15) (("+") reduce 15) (("-") reduce 15) ((".") reduce 15) (("/") reduce 15) ((":") reduce 15) (("<") reduce 15) ((">") reduce 15) (("?") reduce 15) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_BOOLEAN_AND) reduce 15) ((T_BOOLEAN_OR) reduce 15) ((T_COALESCE) reduce 15) ((T_DOUBLE_ARROW) reduce 15) ((T_INSTANCEOF) reduce 15) ((T_IS_EQUAL) reduce 15) ((T_IS_GREATER_OR_EQUAL) reduce 15) ((T_IS_IDENTICAL) reduce 15) ((T_IS_NOT_EQUAL) reduce 15) ((T_IS_NOT_IDENTICAL) reduce 15) ((T_IS_SMALLER_OR_EQUAL) reduce 15) ((T_LOGICAL_AND) reduce 15) ((T_LOGICAL_OR) reduce 15) ((T_LOGICAL_XOR) reduce 15) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 15) ((T_OBJECT_OPERATOR) reduce 15) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 15) ((T_POW) reduce 15) ((T_SL) reduce 15) ((T_SPACESHIP) reduce 15) ((T_SR) reduce 15) (("[") reduce 15) (("^") reduce 15) (("{") reduce 15) (("|") reduce 15)) 9972 ((("%") reduce 14) (("(") reduce 14) (("*") reduce 14) (("+") reduce 14) (("-") reduce 14) ((".") reduce 14) (("/") reduce 14) ((":") reduce 14) (("<") reduce 14) ((">") reduce 14) (("?") reduce 14) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_BOOLEAN_AND) reduce 14) ((T_BOOLEAN_OR) reduce 14) ((T_COALESCE) reduce 14) ((T_DOUBLE_ARROW) reduce 14) ((T_INSTANCEOF) reduce 14) ((T_IS_EQUAL) reduce 14) ((T_IS_GREATER_OR_EQUAL) reduce 14) ((T_IS_IDENTICAL) reduce 14) ((T_IS_NOT_EQUAL) reduce 14) ((T_IS_NOT_IDENTICAL) reduce 14) ((T_IS_SMALLER_OR_EQUAL) reduce 14) ((T_LOGICAL_AND) reduce 14) ((T_LOGICAL_OR) reduce 14) ((T_LOGICAL_XOR) reduce 14) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 14) ((T_OBJECT_OPERATOR) reduce 14) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 14) ((T_POW) reduce 14) ((T_SL) reduce 14) ((T_SPACESHIP) reduce 14) ((T_SR) reduce 14) (("[") reduce 14) (("^") reduce 14) (("{") reduce 14) (("|") reduce 14)) 9973 ((("%") reduce 38) (("(") reduce 38) (("*") reduce 38) (("+") reduce 38) (("-") reduce 38) ((".") reduce 38) (("/") reduce 38) ((":") reduce 38) (("<") reduce 38) ((">") reduce 38) (("?") reduce 38) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_BOOLEAN_AND) reduce 38) ((T_BOOLEAN_OR) reduce 38) ((T_COALESCE) reduce 38) ((T_DOUBLE_ARROW) reduce 38) ((T_INSTANCEOF) reduce 38) ((T_IS_EQUAL) reduce 38) ((T_IS_GREATER_OR_EQUAL) reduce 38) ((T_IS_IDENTICAL) reduce 38) ((T_IS_NOT_EQUAL) reduce 38) ((T_IS_NOT_IDENTICAL) reduce 38) ((T_IS_SMALLER_OR_EQUAL) reduce 38) ((T_LOGICAL_AND) reduce 38) ((T_LOGICAL_OR) reduce 38) ((T_LOGICAL_XOR) reduce 38) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 38) ((T_OBJECT_OPERATOR) reduce 38) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 38) ((T_POW) reduce 38) ((T_SL) reduce 38) ((T_SPACESHIP) reduce 38) ((T_SR) reduce 38) (("[") reduce 38) (("^") reduce 38) (("{") reduce 38) (("|") reduce 38)) 9974 ((("%") reduce 26) (("(") reduce 26) (("*") reduce 26) (("+") reduce 26) (("-") reduce 26) ((".") reduce 26) (("/") reduce 26) ((":") reduce 26) (("<") reduce 26) ((">") reduce 26) (("?") reduce 26) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_BOOLEAN_AND) reduce 26) ((T_BOOLEAN_OR) reduce 26) ((T_COALESCE) reduce 26) ((T_DOUBLE_ARROW) reduce 26) ((T_INSTANCEOF) reduce 26) ((T_IS_EQUAL) reduce 26) ((T_IS_GREATER_OR_EQUAL) reduce 26) ((T_IS_IDENTICAL) reduce 26) ((T_IS_NOT_EQUAL) reduce 26) ((T_IS_NOT_IDENTICAL) reduce 26) ((T_IS_SMALLER_OR_EQUAL) reduce 26) ((T_LOGICAL_AND) reduce 26) ((T_LOGICAL_OR) reduce 26) ((T_LOGICAL_XOR) reduce 26) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 26) ((T_OBJECT_OPERATOR) reduce 26) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 26) ((T_POW) reduce 26) ((T_SL) reduce 26) ((T_SPACESHIP) reduce 26) ((T_SR) reduce 26) (("[") reduce 26) (("^") reduce 26) (("{") reduce 26) (("|") reduce 26)) 9975 ((("%") reduce 22) (("(") reduce 22) (("*") reduce 22) (("+") reduce 22) (("-") reduce 22) ((".") reduce 22) (("/") reduce 22) ((":") reduce 22) (("<") reduce 22) ((">") reduce 22) (("?") reduce 22) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_BOOLEAN_AND) reduce 22) ((T_BOOLEAN_OR) reduce 22) ((T_COALESCE) reduce 22) ((T_DOUBLE_ARROW) reduce 22) ((T_INSTANCEOF) reduce 22) ((T_IS_EQUAL) reduce 22) ((T_IS_GREATER_OR_EQUAL) reduce 22) ((T_IS_IDENTICAL) reduce 22) ((T_IS_NOT_EQUAL) reduce 22) ((T_IS_NOT_IDENTICAL) reduce 22) ((T_IS_SMALLER_OR_EQUAL) reduce 22) ((T_LOGICAL_AND) reduce 22) ((T_LOGICAL_OR) reduce 22) ((T_LOGICAL_XOR) reduce 22) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 22) ((T_OBJECT_OPERATOR) reduce 22) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 22) ((T_POW) reduce 22) ((T_SL) reduce 22) ((T_SPACESHIP) reduce 22) ((T_SR) reduce 22) (("[") reduce 22) (("^") reduce 22) (("{") reduce 22) (("|") reduce 22)) 9976 ((("%") reduce 24) (("(") reduce 24) (("*") reduce 24) (("+") reduce 24) (("-") reduce 24) ((".") reduce 24) (("/") reduce 24) ((":") reduce 24) (("<") reduce 24) ((">") reduce 24) (("?") reduce 24) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_BOOLEAN_AND) reduce 24) ((T_BOOLEAN_OR) reduce 24) ((T_COALESCE) reduce 24) ((T_DOUBLE_ARROW) reduce 24) ((T_INSTANCEOF) reduce 24) ((T_IS_EQUAL) reduce 24) ((T_IS_GREATER_OR_EQUAL) reduce 24) ((T_IS_IDENTICAL) reduce 24) ((T_IS_NOT_EQUAL) reduce 24) ((T_IS_NOT_IDENTICAL) reduce 24) ((T_IS_SMALLER_OR_EQUAL) reduce 24) ((T_LOGICAL_AND) reduce 24) ((T_LOGICAL_OR) reduce 24) ((T_LOGICAL_XOR) reduce 24) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 24) ((T_OBJECT_OPERATOR) reduce 24) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 24) ((T_POW) reduce 24) ((T_SL) reduce 24) ((T_SPACESHIP) reduce 24) ((T_SR) reduce 24) (("[") reduce 24) (("^") reduce 24) (("{") reduce 24) (("|") reduce 24)) 9977 ((("%") reduce 16) (("(") reduce 16) (("*") reduce 16) (("+") reduce 16) (("-") reduce 16) ((".") reduce 16) (("/") reduce 16) ((":") reduce 16) (("<") reduce 16) ((">") reduce 16) (("?") reduce 16) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_BOOLEAN_AND) reduce 16) ((T_BOOLEAN_OR) reduce 16) ((T_COALESCE) reduce 16) ((T_DOUBLE_ARROW) reduce 16) ((T_INSTANCEOF) reduce 16) ((T_IS_EQUAL) reduce 16) ((T_IS_GREATER_OR_EQUAL) reduce 16) ((T_IS_IDENTICAL) reduce 16) ((T_IS_NOT_EQUAL) reduce 16) ((T_IS_NOT_IDENTICAL) reduce 16) ((T_IS_SMALLER_OR_EQUAL) reduce 16) ((T_LOGICAL_AND) reduce 16) ((T_LOGICAL_OR) reduce 16) ((T_LOGICAL_XOR) reduce 16) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 16) ((T_OBJECT_OPERATOR) reduce 16) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 16) ((T_POW) reduce 16) ((T_SL) reduce 16) ((T_SPACESHIP) reduce 16) ((T_SR) reduce 16) (("[") reduce 16) (("^") reduce 16) (("{") reduce 16) (("|") reduce 16)) 9978 ((("%") reduce 48) (("(") reduce 48) (("*") reduce 48) (("+") reduce 48) (("-") reduce 48) ((".") reduce 48) (("/") reduce 48) ((":") reduce 48) (("<") reduce 48) ((">") reduce 48) (("?") reduce 48) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_BOOLEAN_AND) reduce 48) ((T_BOOLEAN_OR) reduce 48) ((T_COALESCE) reduce 48) ((T_DOUBLE_ARROW) reduce 48) ((T_INSTANCEOF) reduce 48) ((T_IS_EQUAL) reduce 48) ((T_IS_GREATER_OR_EQUAL) reduce 48) ((T_IS_IDENTICAL) reduce 48) ((T_IS_NOT_EQUAL) reduce 48) ((T_IS_NOT_IDENTICAL) reduce 48) ((T_IS_SMALLER_OR_EQUAL) reduce 48) ((T_LOGICAL_AND) reduce 48) ((T_LOGICAL_OR) reduce 48) ((T_LOGICAL_XOR) reduce 48) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 48) ((T_OBJECT_OPERATOR) reduce 48) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 48) ((T_POW) reduce 48) ((T_SL) reduce 48) ((T_SPACESHIP) reduce 48) ((T_SR) reduce 48) (("[") reduce 48) (("^") reduce 48) (("{") reduce 48) (("|") reduce 48)) 9979 ((("%") reduce 20) (("(") reduce 20) (("*") reduce 20) (("+") reduce 20) (("-") reduce 20) ((".") reduce 20) (("/") reduce 20) ((":") reduce 20) (("<") reduce 20) ((">") reduce 20) (("?") reduce 20) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_BOOLEAN_AND) reduce 20) ((T_BOOLEAN_OR) reduce 20) ((T_COALESCE) reduce 20) ((T_DOUBLE_ARROW) reduce 20) ((T_INSTANCEOF) reduce 20) ((T_IS_EQUAL) reduce 20) ((T_IS_GREATER_OR_EQUAL) reduce 20) ((T_IS_IDENTICAL) reduce 20) ((T_IS_NOT_EQUAL) reduce 20) ((T_IS_NOT_IDENTICAL) reduce 20) ((T_IS_SMALLER_OR_EQUAL) reduce 20) ((T_LOGICAL_AND) reduce 20) ((T_LOGICAL_OR) reduce 20) ((T_LOGICAL_XOR) reduce 20) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 20) ((T_OBJECT_OPERATOR) reduce 20) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 20) ((T_POW) reduce 20) ((T_SL) reduce 20) ((T_SPACESHIP) reduce 20) ((T_SR) reduce 20) (("[") reduce 20) (("^") reduce 20) (("{") reduce 20) (("|") reduce 20)) 9980 ((("%") reduce 70) (("(") reduce 70) (("*") reduce 70) (("+") reduce 70) (("-") reduce 70) ((".") reduce 70) (("/") reduce 70) ((":") reduce 70) (("<") reduce 70) ((">") reduce 70) (("?") reduce 70) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_BOOLEAN_AND) reduce 70) ((T_BOOLEAN_OR) reduce 70) ((T_COALESCE) reduce 70) ((T_DOUBLE_ARROW) reduce 70) ((T_INSTANCEOF) reduce 70) ((T_IS_EQUAL) reduce 70) ((T_IS_GREATER_OR_EQUAL) reduce 70) ((T_IS_IDENTICAL) reduce 70) ((T_IS_NOT_EQUAL) reduce 70) ((T_IS_NOT_IDENTICAL) reduce 70) ((T_IS_SMALLER_OR_EQUAL) reduce 70) ((T_LOGICAL_AND) reduce 70) ((T_LOGICAL_OR) reduce 70) ((T_LOGICAL_XOR) reduce 70) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 70) ((T_OBJECT_OPERATOR) reduce 70) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 70) ((T_POW) reduce 70) ((T_SL) reduce 70) ((T_SPACESHIP) reduce 70) ((T_SR) reduce 70) (("[") reduce 70) (("^") reduce 70) (("{") reduce 70) (("|") reduce 70)) 9981 ((("%") reduce 3) (("(") reduce 3) (("*") reduce 3) (("+") reduce 3) (("-") reduce 3) ((".") reduce 3) (("/") reduce 3) ((":") reduce 3) (("<") reduce 3) ((">") reduce 3) (("?") reduce 3) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_BOOLEAN_AND) reduce 3) ((T_BOOLEAN_OR) reduce 3) ((T_COALESCE) reduce 3) ((T_DOUBLE_ARROW) reduce 3) ((T_INSTANCEOF) reduce 3) ((T_IS_EQUAL) reduce 3) ((T_IS_GREATER_OR_EQUAL) reduce 3) ((T_IS_IDENTICAL) reduce 3) ((T_IS_NOT_EQUAL) reduce 3) ((T_IS_NOT_IDENTICAL) reduce 3) ((T_IS_SMALLER_OR_EQUAL) reduce 3) ((T_LOGICAL_AND) reduce 3) ((T_LOGICAL_OR) reduce 3) ((T_LOGICAL_XOR) reduce 3) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 3) ((T_OBJECT_OPERATOR) reduce 3) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 3) ((T_POW) reduce 3) ((T_SL) reduce 3) ((T_SPACESHIP) reduce 3) ((T_SR) reduce 3) (("[") reduce 3) (("^") reduce 3) (("{") reduce 3) (("|") reduce 3)) 9982 ((("%") reduce 12) (("(") reduce 12) (("*") reduce 12) (("+") reduce 12) (("-") reduce 12) ((".") reduce 12) (("/") reduce 12) ((":") reduce 12) (("<") reduce 12) ((">") reduce 12) (("?") reduce 12) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_BOOLEAN_AND) reduce 12) ((T_BOOLEAN_OR) reduce 12) ((T_COALESCE) reduce 12) ((T_DOUBLE_ARROW) reduce 12) ((T_INSTANCEOF) reduce 12) ((T_IS_EQUAL) reduce 12) ((T_IS_GREATER_OR_EQUAL) reduce 12) ((T_IS_IDENTICAL) reduce 12) ((T_IS_NOT_EQUAL) reduce 12) ((T_IS_NOT_IDENTICAL) reduce 12) ((T_IS_SMALLER_OR_EQUAL) reduce 12) ((T_LOGICAL_AND) reduce 12) ((T_LOGICAL_OR) reduce 12) ((T_LOGICAL_XOR) reduce 12) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 12) ((T_OBJECT_OPERATOR) reduce 12) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 12) ((T_POW) reduce 12) ((T_SL) reduce 12) ((T_SPACESHIP) reduce 12) ((T_SR) reduce 12) (("[") reduce 12) (("^") reduce 12) (("{") reduce 12) (("|") reduce 12)) 9983 ((("%") reduce 54) (("(") reduce 54) (("*") reduce 54) (("+") reduce 54) (("-") reduce 54) ((".") reduce 54) (("/") reduce 54) ((":") reduce 54) (("<") reduce 54) ((">") reduce 54) (("?") reduce 54) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_BOOLEAN_AND) reduce 54) ((T_BOOLEAN_OR) reduce 54) ((T_COALESCE) reduce 54) ((T_DOUBLE_ARROW) reduce 54) ((T_INSTANCEOF) reduce 54) ((T_IS_EQUAL) reduce 54) ((T_IS_GREATER_OR_EQUAL) reduce 54) ((T_IS_IDENTICAL) reduce 54) ((T_IS_NOT_EQUAL) reduce 54) ((T_IS_NOT_IDENTICAL) reduce 54) ((T_IS_SMALLER_OR_EQUAL) reduce 54) ((T_LOGICAL_AND) reduce 54) ((T_LOGICAL_OR) reduce 54) ((T_LOGICAL_XOR) reduce 54) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 54) ((T_OBJECT_OPERATOR) reduce 54) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 54) ((T_POW) reduce 54) ((T_SL) reduce 54) ((T_SPACESHIP) reduce 54) ((T_SR) reduce 54) (("[") reduce 54) (("^") reduce 54) (("{") reduce 54) (("|") reduce 54)) 9984 ((("%") reduce 65) (("(") reduce 65) (("*") reduce 65) (("+") reduce 65) (("-") reduce 65) ((".") reduce 65) (("/") reduce 65) ((":") reduce 65) (("<") reduce 65) ((">") reduce 65) (("?") reduce 65) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_BOOLEAN_AND) reduce 65) ((T_BOOLEAN_OR) reduce 65) ((T_COALESCE) reduce 65) ((T_DOUBLE_ARROW) reduce 65) ((T_INSTANCEOF) reduce 65) ((T_IS_EQUAL) reduce 65) ((T_IS_GREATER_OR_EQUAL) reduce 65) ((T_IS_IDENTICAL) reduce 65) ((T_IS_NOT_EQUAL) reduce 65) ((T_IS_NOT_IDENTICAL) reduce 65) ((T_IS_SMALLER_OR_EQUAL) reduce 65) ((T_LOGICAL_AND) reduce 65) ((T_LOGICAL_OR) reduce 65) ((T_LOGICAL_XOR) reduce 65) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 65) ((T_OBJECT_OPERATOR) reduce 65) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 65) ((T_POW) reduce 65) ((T_SL) reduce 65) ((T_SPACESHIP) reduce 65) ((T_SR) reduce 65) (("[") reduce 65) (("^") reduce 65) (("{") reduce 65) (("|") reduce 65)) 9985 ((("%") reduce 74) (("(") reduce 74) (("*") reduce 74) (("+") reduce 74) (("-") reduce 74) ((".") reduce 74) (("/") reduce 74) ((":") reduce 74) (("<") reduce 74) ((">") reduce 74) (("?") reduce 74) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_BOOLEAN_AND) reduce 74) ((T_BOOLEAN_OR) reduce 74) ((T_COALESCE) reduce 74) ((T_DOUBLE_ARROW) reduce 74) ((T_INSTANCEOF) reduce 74) ((T_IS_EQUAL) reduce 74) ((T_IS_GREATER_OR_EQUAL) reduce 74) ((T_IS_IDENTICAL) reduce 74) ((T_IS_NOT_EQUAL) reduce 74) ((T_IS_NOT_IDENTICAL) reduce 74) ((T_IS_SMALLER_OR_EQUAL) reduce 74) ((T_LOGICAL_AND) reduce 74) ((T_LOGICAL_OR) reduce 74) ((T_LOGICAL_XOR) reduce 74) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 74) ((T_OBJECT_OPERATOR) reduce 74) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 74) ((T_POW) reduce 74) ((T_SL) reduce 74) ((T_SPACESHIP) reduce 74) ((T_SR) reduce 74) (("[") reduce 74) (("^") reduce 74) (("{") reduce 74) (("|") reduce 74)) 9986 ((("%") reduce 30) (("(") reduce 30) (("*") reduce 30) (("+") reduce 30) (("-") reduce 30) ((".") reduce 30) (("/") reduce 30) ((":") reduce 30) (("<") reduce 30) ((">") reduce 30) (("?") reduce 30) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_BOOLEAN_AND) reduce 30) ((T_BOOLEAN_OR) reduce 30) ((T_COALESCE) reduce 30) ((T_DOUBLE_ARROW) reduce 30) ((T_INSTANCEOF) reduce 30) ((T_IS_EQUAL) reduce 30) ((T_IS_GREATER_OR_EQUAL) reduce 30) ((T_IS_IDENTICAL) reduce 30) ((T_IS_NOT_EQUAL) reduce 30) ((T_IS_NOT_IDENTICAL) reduce 30) ((T_IS_SMALLER_OR_EQUAL) reduce 30) ((T_LOGICAL_AND) reduce 30) ((T_LOGICAL_OR) reduce 30) ((T_LOGICAL_XOR) reduce 30) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 30) ((T_OBJECT_OPERATOR) reduce 30) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 30) ((T_POW) reduce 30) ((T_SL) reduce 30) ((T_SPACESHIP) reduce 30) ((T_SR) reduce 30) (("[") reduce 30) (("^") reduce 30) (("{") reduce 30) (("|") reduce 30)) 9987 ((("%") reduce 68) (("(") reduce 68) (("*") reduce 68) (("+") reduce 68) (("-") reduce 68) ((".") reduce 68) (("/") reduce 68) ((":") reduce 68) (("<") reduce 68) ((">") reduce 68) (("?") reduce 68) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_BOOLEAN_AND) reduce 68) ((T_BOOLEAN_OR) reduce 68) ((T_COALESCE) reduce 68) ((T_DOUBLE_ARROW) reduce 68) ((T_INSTANCEOF) reduce 68) ((T_IS_EQUAL) reduce 68) ((T_IS_GREATER_OR_EQUAL) reduce 68) ((T_IS_IDENTICAL) reduce 68) ((T_IS_NOT_EQUAL) reduce 68) ((T_IS_NOT_IDENTICAL) reduce 68) ((T_IS_SMALLER_OR_EQUAL) reduce 68) ((T_LOGICAL_AND) reduce 68) ((T_LOGICAL_OR) reduce 68) ((T_LOGICAL_XOR) reduce 68) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 68) ((T_OBJECT_OPERATOR) reduce 68) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 68) ((T_POW) reduce 68) ((T_SL) reduce 68) ((T_SPACESHIP) reduce 68) ((T_SR) reduce 68) (("[") reduce 68) (("^") reduce 68) (("{") reduce 68) (("|") reduce 68)) 9988 ((("%") reduce 21) (("(") reduce 21) (("*") reduce 21) (("+") reduce 21) (("-") reduce 21) ((".") reduce 21) (("/") reduce 21) ((":") reduce 21) (("<") reduce 21) ((">") reduce 21) (("?") reduce 21) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_BOOLEAN_AND) reduce 21) ((T_BOOLEAN_OR) reduce 21) ((T_COALESCE) reduce 21) ((T_DOUBLE_ARROW) reduce 21) ((T_INSTANCEOF) reduce 21) ((T_IS_EQUAL) reduce 21) ((T_IS_GREATER_OR_EQUAL) reduce 21) ((T_IS_IDENTICAL) reduce 21) ((T_IS_NOT_EQUAL) reduce 21) ((T_IS_NOT_IDENTICAL) reduce 21) ((T_IS_SMALLER_OR_EQUAL) reduce 21) ((T_LOGICAL_AND) reduce 21) ((T_LOGICAL_OR) reduce 21) ((T_LOGICAL_XOR) reduce 21) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 21) ((T_OBJECT_OPERATOR) reduce 21) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 21) ((T_POW) reduce 21) ((T_SL) reduce 21) ((T_SPACESHIP) reduce 21) ((T_SR) reduce 21) (("[") reduce 21) (("^") reduce 21) (("{") reduce 21) (("|") reduce 21)) 9989 ((("%") reduce 23) (("(") reduce 23) (("*") reduce 23) (("+") reduce 23) (("-") reduce 23) ((".") reduce 23) (("/") reduce 23) ((":") reduce 23) (("<") reduce 23) ((">") reduce 23) (("?") reduce 23) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_BOOLEAN_AND) reduce 23) ((T_BOOLEAN_OR) reduce 23) ((T_COALESCE) reduce 23) ((T_DOUBLE_ARROW) reduce 23) ((T_INSTANCEOF) reduce 23) ((T_IS_EQUAL) reduce 23) ((T_IS_GREATER_OR_EQUAL) reduce 23) ((T_IS_IDENTICAL) reduce 23) ((T_IS_NOT_EQUAL) reduce 23) ((T_IS_NOT_IDENTICAL) reduce 23) ((T_IS_SMALLER_OR_EQUAL) reduce 23) ((T_LOGICAL_AND) reduce 23) ((T_LOGICAL_OR) reduce 23) ((T_LOGICAL_XOR) reduce 23) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 23) ((T_OBJECT_OPERATOR) reduce 23) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 23) ((T_POW) reduce 23) ((T_SL) reduce 23) ((T_SPACESHIP) reduce 23) ((T_SR) reduce 23) (("[") reduce 23) (("^") reduce 23) (("{") reduce 23) (("|") reduce 23)) 9990 ((("%") reduce 41) (("(") reduce 41) (("*") reduce 41) (("+") reduce 41) (("-") reduce 41) ((".") reduce 41) (("/") reduce 41) ((":") reduce 41) (("<") reduce 41) ((">") reduce 41) (("?") reduce 41) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_BOOLEAN_AND) reduce 41) ((T_BOOLEAN_OR) reduce 41) ((T_COALESCE) reduce 41) ((T_DOUBLE_ARROW) reduce 41) ((T_INSTANCEOF) reduce 41) ((T_IS_EQUAL) reduce 41) ((T_IS_GREATER_OR_EQUAL) reduce 41) ((T_IS_IDENTICAL) reduce 41) ((T_IS_NOT_EQUAL) reduce 41) ((T_IS_NOT_IDENTICAL) reduce 41) ((T_IS_SMALLER_OR_EQUAL) reduce 41) ((T_LOGICAL_AND) reduce 41) ((T_LOGICAL_OR) reduce 41) ((T_LOGICAL_XOR) reduce 41) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 41) ((T_OBJECT_OPERATOR) reduce 41) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 41) ((T_POW) reduce 41) ((T_SL) reduce 41) ((T_SPACESHIP) reduce 41) ((T_SR) reduce 41) (("[") reduce 41) (("^") reduce 41) (("{") reduce 41) (("|") reduce 41)) 9991 ((("%") reduce 62) (("(") reduce 62) (("*") reduce 62) (("+") reduce 62) (("-") reduce 62) ((".") reduce 62) (("/") reduce 62) ((":") reduce 62) (("<") reduce 62) ((">") reduce 62) (("?") reduce 62) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_BOOLEAN_AND) reduce 62) ((T_BOOLEAN_OR) reduce 62) ((T_COALESCE) reduce 62) ((T_DOUBLE_ARROW) reduce 62) ((T_INSTANCEOF) reduce 62) ((T_IS_EQUAL) reduce 62) ((T_IS_GREATER_OR_EQUAL) reduce 62) ((T_IS_IDENTICAL) reduce 62) ((T_IS_NOT_EQUAL) reduce 62) ((T_IS_NOT_IDENTICAL) reduce 62) ((T_IS_SMALLER_OR_EQUAL) reduce 62) ((T_LOGICAL_AND) reduce 62) ((T_LOGICAL_OR) reduce 62) ((T_LOGICAL_XOR) reduce 62) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 62) ((T_OBJECT_OPERATOR) reduce 62) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 62) ((T_POW) reduce 62) ((T_SL) reduce 62) ((T_SPACESHIP) reduce 62) ((T_SR) reduce 62) (("[") reduce 62) (("^") reduce 62) (("{") reduce 62) (("|") reduce 62)) 9992 ((("%") reduce 34) (("(") reduce 34) (("*") reduce 34) (("+") reduce 34) (("-") reduce 34) ((".") reduce 34) (("/") reduce 34) ((":") reduce 34) (("<") reduce 34) ((">") reduce 34) (("?") reduce 34) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_BOOLEAN_AND) reduce 34) ((T_BOOLEAN_OR) reduce 34) ((T_COALESCE) reduce 34) ((T_DOUBLE_ARROW) reduce 34) ((T_INSTANCEOF) reduce 34) ((T_IS_EQUAL) reduce 34) ((T_IS_GREATER_OR_EQUAL) reduce 34) ((T_IS_IDENTICAL) reduce 34) ((T_IS_NOT_EQUAL) reduce 34) ((T_IS_NOT_IDENTICAL) reduce 34) ((T_IS_SMALLER_OR_EQUAL) reduce 34) ((T_LOGICAL_AND) reduce 34) ((T_LOGICAL_OR) reduce 34) ((T_LOGICAL_XOR) reduce 34) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 34) ((T_OBJECT_OPERATOR) reduce 34) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 34) ((T_POW) reduce 34) ((T_SL) reduce 34) ((T_SPACESHIP) reduce 34) ((T_SR) reduce 34) (("[") reduce 34) (("^") reduce 34) (("{") reduce 34) (("|") reduce 34)) 9993 ((("%") reduce 40) (("(") reduce 40) (("*") reduce 40) (("+") reduce 40) (("-") reduce 40) ((".") reduce 40) (("/") reduce 40) ((":") reduce 40) (("<") reduce 40) ((">") reduce 40) (("?") reduce 40) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_BOOLEAN_AND) reduce 40) ((T_BOOLEAN_OR) reduce 40) ((T_COALESCE) reduce 40) ((T_DOUBLE_ARROW) reduce 40) ((T_INSTANCEOF) reduce 40) ((T_IS_EQUAL) reduce 40) ((T_IS_GREATER_OR_EQUAL) reduce 40) ((T_IS_IDENTICAL) reduce 40) ((T_IS_NOT_EQUAL) reduce 40) ((T_IS_NOT_IDENTICAL) reduce 40) ((T_IS_SMALLER_OR_EQUAL) reduce 40) ((T_LOGICAL_AND) reduce 40) ((T_LOGICAL_OR) reduce 40) ((T_LOGICAL_XOR) reduce 40) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 40) ((T_OBJECT_OPERATOR) reduce 40) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 40) ((T_POW) reduce 40) ((T_SL) reduce 40) ((T_SPACESHIP) reduce 40) ((T_SR) reduce 40) (("[") reduce 40) (("^") reduce 40) (("{") reduce 40) (("|") reduce 40)) 9994 ((("%") reduce 13) (("(") reduce 13) (("*") reduce 13) (("+") reduce 13) (("-") reduce 13) ((".") reduce 13) (("/") reduce 13) ((":") reduce 13) (("<") reduce 13) ((">") reduce 13) (("?") reduce 13) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_BOOLEAN_AND) reduce 13) ((T_BOOLEAN_OR) reduce 13) ((T_COALESCE) reduce 13) ((T_DOUBLE_ARROW) reduce 13) ((T_INSTANCEOF) reduce 13) ((T_IS_EQUAL) reduce 13) ((T_IS_GREATER_OR_EQUAL) reduce 13) ((T_IS_IDENTICAL) reduce 13) ((T_IS_NOT_EQUAL) reduce 13) ((T_IS_NOT_IDENTICAL) reduce 13) ((T_IS_SMALLER_OR_EQUAL) reduce 13) ((T_LOGICAL_AND) reduce 13) ((T_LOGICAL_OR) reduce 13) ((T_LOGICAL_XOR) reduce 13) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 13) ((T_OBJECT_OPERATOR) reduce 13) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 13) ((T_POW) reduce 13) ((T_SL) reduce 13) ((T_SPACESHIP) reduce 13) ((T_SR) reduce 13) (("[") reduce 13) (("^") reduce 13) (("{") reduce 13) (("|") reduce 13)) 9995 ((("%") reduce 55) (("(") reduce 55) (("*") reduce 55) (("+") reduce 55) (("-") reduce 55) ((".") reduce 55) (("/") reduce 55) ((":") reduce 55) (("<") reduce 55) ((">") reduce 55) (("?") reduce 55) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_BOOLEAN_AND) reduce 55) ((T_BOOLEAN_OR) reduce 55) ((T_COALESCE) reduce 55) ((T_DOUBLE_ARROW) reduce 55) ((T_INSTANCEOF) reduce 55) ((T_IS_EQUAL) reduce 55) ((T_IS_GREATER_OR_EQUAL) reduce 55) ((T_IS_IDENTICAL) reduce 55) ((T_IS_NOT_EQUAL) reduce 55) ((T_IS_NOT_IDENTICAL) reduce 55) ((T_IS_SMALLER_OR_EQUAL) reduce 55) ((T_LOGICAL_AND) reduce 55) ((T_LOGICAL_OR) reduce 55) ((T_LOGICAL_XOR) reduce 55) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 55) ((T_OBJECT_OPERATOR) reduce 55) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 55) ((T_POW) reduce 55) ((T_SL) reduce 55) ((T_SPACESHIP) reduce 55) ((T_SR) reduce 55) (("[") reduce 55) (("^") reduce 55) (("{") reduce 55) (("|") reduce 55)) 9996 ((("%") reduce 1) (("(") reduce 1) (("*") reduce 1) (("+") reduce 1) (("-") reduce 1) ((".") reduce 1) (("/") reduce 1) ((":") reduce 1) (("<") reduce 1) ((">") reduce 1) (("?") reduce 1) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_BOOLEAN_AND) reduce 1) ((T_BOOLEAN_OR) reduce 1) ((T_COALESCE) reduce 1) ((T_DOUBLE_ARROW) reduce 1) ((T_INSTANCEOF) reduce 1) ((T_IS_EQUAL) reduce 1) ((T_IS_GREATER_OR_EQUAL) reduce 1) ((T_IS_IDENTICAL) reduce 1) ((T_IS_NOT_EQUAL) reduce 1) ((T_IS_NOT_IDENTICAL) reduce 1) ((T_IS_SMALLER_OR_EQUAL) reduce 1) ((T_LOGICAL_AND) reduce 1) ((T_LOGICAL_OR) reduce 1) ((T_LOGICAL_XOR) reduce 1) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 1) ((T_OBJECT_OPERATOR) reduce 1) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 1) ((T_POW) reduce 1) ((T_SL) reduce 1) ((T_SPACESHIP) reduce 1) ((T_SR) reduce 1) (("[") reduce 1) (("^") reduce 1) (("{") reduce 1) (("|") reduce 1)) 9997 ((("%") reduce 2) (("(") reduce 2) (("*") reduce 2) (("+") reduce 2) (("-") reduce 2) ((".") reduce 2) (("/") reduce 2) ((":") reduce 2) (("<") reduce 2) ((">") reduce 2) (("?") reduce 2) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_BOOLEAN_AND) reduce 2) ((T_BOOLEAN_OR) reduce 2) ((T_COALESCE) reduce 2) ((T_DOUBLE_ARROW) reduce 2) ((T_INSTANCEOF) reduce 2) ((T_IS_EQUAL) reduce 2) ((T_IS_GREATER_OR_EQUAL) reduce 2) ((T_IS_IDENTICAL) reduce 2) ((T_IS_NOT_EQUAL) reduce 2) ((T_IS_NOT_IDENTICAL) reduce 2) ((T_IS_SMALLER_OR_EQUAL) reduce 2) ((T_LOGICAL_AND) reduce 2) ((T_LOGICAL_OR) reduce 2) ((T_LOGICAL_XOR) reduce 2) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 2) ((T_OBJECT_OPERATOR) reduce 2) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 2) ((T_POW) reduce 2) ((T_SL) reduce 2) ((T_SPACESHIP) reduce 2) ((T_SR) reduce 2) (("[") reduce 2) (("^") reduce 2) (("{") reduce 2) (("|") reduce 2)) 9998 ((("%") reduce 9) (("(") reduce 9) (("*") reduce 9) (("+") reduce 9) (("-") reduce 9) ((".") reduce 9) (("/") reduce 9) ((":") reduce 9) (("<") reduce 9) ((">") reduce 9) (("?") reduce 9) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_BOOLEAN_AND) reduce 9) ((T_BOOLEAN_OR) reduce 9) ((T_COALESCE) reduce 9) ((T_DOUBLE_ARROW) reduce 9) ((T_INSTANCEOF) reduce 9) ((T_IS_EQUAL) reduce 9) ((T_IS_GREATER_OR_EQUAL) reduce 9) ((T_IS_IDENTICAL) reduce 9) ((T_IS_NOT_EQUAL) reduce 9) ((T_IS_NOT_IDENTICAL) reduce 9) ((T_IS_SMALLER_OR_EQUAL) reduce 9) ((T_LOGICAL_AND) reduce 9) ((T_LOGICAL_OR) reduce 9) ((T_LOGICAL_XOR) reduce 9) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 9) ((T_OBJECT_OPERATOR) reduce 9) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 9) ((T_POW) reduce 9) ((T_SL) reduce 9) ((T_SPACESHIP) reduce 9) ((T_SR) reduce 9) (("[") reduce 9) (("^") reduce 9) (("{") reduce 9) (("|") reduce 9)) 9999 ((("%") reduce 33) (("(") reduce 33) (("*") reduce 33) (("+") reduce 33) (("-") reduce 33) ((".") reduce 33) (("/") reduce 33) ((":") reduce 33) (("<") reduce 33) ((">") reduce 33) (("?") reduce 33) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_BOOLEAN_AND) reduce 33) ((T_BOOLEAN_OR) reduce 33) ((T_COALESCE) reduce 33) ((T_DOUBLE_ARROW) reduce 33) ((T_INSTANCEOF) reduce 33) ((T_IS_EQUAL) reduce 33) ((T_IS_GREATER_OR_EQUAL) reduce 33) ((T_IS_IDENTICAL) reduce 33) ((T_IS_NOT_EQUAL) reduce 33) ((T_IS_NOT_IDENTICAL) reduce 33) ((T_IS_SMALLER_OR_EQUAL) reduce 33) ((T_LOGICAL_AND) reduce 33) ((T_LOGICAL_OR) reduce 33) ((T_LOGICAL_XOR) reduce 33) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 33) ((T_OBJECT_OPERATOR) reduce 33) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 33) ((T_POW) reduce 33) ((T_SL) reduce 33) ((T_SPACESHIP) reduce 33) ((T_SR) reduce 33) (("[") reduce 33) (("^") reduce 33) (("{") reduce 33) (("|") reduce 33)) 10000 ((("%") reduce 58) (("(") reduce 58) (("*") reduce 58) (("+") reduce 58) (("-") reduce 58) ((".") reduce 58) (("/") reduce 58) ((":") reduce 58) (("<") reduce 58) ((">") reduce 58) (("?") reduce 58) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_BOOLEAN_AND) reduce 58) ((T_BOOLEAN_OR) reduce 58) ((T_COALESCE) reduce 58) ((T_DOUBLE_ARROW) reduce 58) ((T_INSTANCEOF) reduce 58) ((T_IS_EQUAL) reduce 58) ((T_IS_GREATER_OR_EQUAL) reduce 58) ((T_IS_IDENTICAL) reduce 58) ((T_IS_NOT_EQUAL) reduce 58) ((T_IS_NOT_IDENTICAL) reduce 58) ((T_IS_SMALLER_OR_EQUAL) reduce 58) ((T_LOGICAL_AND) reduce 58) ((T_LOGICAL_OR) reduce 58) ((T_LOGICAL_XOR) reduce 58) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 58) ((T_OBJECT_OPERATOR) reduce 58) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 58) ((T_POW) reduce 58) ((T_SL) reduce 58) ((T_SPACESHIP) reduce 58) ((T_SR) reduce 58) (("[") reduce 58) (("^") reduce 58) (("{") reduce 58) (("|") reduce 58)) 10001 ((("%") reduce 37) (("(") reduce 37) (("*") reduce 37) (("+") reduce 37) (("-") reduce 37) ((".") reduce 37) (("/") reduce 37) ((":") reduce 37) (("<") reduce 37) ((">") reduce 37) (("?") reduce 37) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_BOOLEAN_AND) reduce 37) ((T_BOOLEAN_OR) reduce 37) ((T_COALESCE) reduce 37) ((T_DOUBLE_ARROW) reduce 37) ((T_INSTANCEOF) reduce 37) ((T_IS_EQUAL) reduce 37) ((T_IS_GREATER_OR_EQUAL) reduce 37) ((T_IS_IDENTICAL) reduce 37) ((T_IS_NOT_EQUAL) reduce 37) ((T_IS_NOT_IDENTICAL) reduce 37) ((T_IS_SMALLER_OR_EQUAL) reduce 37) ((T_LOGICAL_AND) reduce 37) ((T_LOGICAL_OR) reduce 37) ((T_LOGICAL_XOR) reduce 37) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 37) ((T_OBJECT_OPERATOR) reduce 37) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 37) ((T_POW) reduce 37) ((T_SL) reduce 37) ((T_SPACESHIP) reduce 37) ((T_SR) reduce 37) (("[") reduce 37) (("^") reduce 37) (("{") reduce 37) (("|") reduce 37)) 10002 ((("%") reduce 64) (("(") reduce 64) (("*") reduce 64) (("+") reduce 64) (("-") reduce 64) ((".") reduce 64) (("/") reduce 64) ((":") reduce 64) (("<") reduce 64) ((">") reduce 64) (("?") reduce 64) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_BOOLEAN_AND) reduce 64) ((T_BOOLEAN_OR) reduce 64) ((T_COALESCE) reduce 64) ((T_DOUBLE_ARROW) reduce 64) ((T_INSTANCEOF) reduce 64) ((T_IS_EQUAL) reduce 64) ((T_IS_GREATER_OR_EQUAL) reduce 64) ((T_IS_IDENTICAL) reduce 64) ((T_IS_NOT_EQUAL) reduce 64) ((T_IS_NOT_IDENTICAL) reduce 64) ((T_IS_SMALLER_OR_EQUAL) reduce 64) ((T_LOGICAL_AND) reduce 64) ((T_LOGICAL_OR) reduce 64) ((T_LOGICAL_XOR) reduce 64) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 64) ((T_OBJECT_OPERATOR) reduce 64) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 64) ((T_POW) reduce 64) ((T_SL) reduce 64) ((T_SPACESHIP) reduce 64) ((T_SR) reduce 64) (("[") reduce 64) (("^") reduce 64) (("{") reduce 64) (("|") reduce 64)) 10003 ((("%") reduce 46) (("(") reduce 46) (("*") reduce 46) (("+") reduce 46) (("-") reduce 46) ((".") reduce 46) (("/") reduce 46) ((":") reduce 46) (("<") reduce 46) ((">") reduce 46) (("?") reduce 46) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_BOOLEAN_AND) reduce 46) ((T_BOOLEAN_OR) reduce 46) ((T_COALESCE) reduce 46) ((T_DOUBLE_ARROW) reduce 46) ((T_INSTANCEOF) reduce 46) ((T_IS_EQUAL) reduce 46) ((T_IS_GREATER_OR_EQUAL) reduce 46) ((T_IS_IDENTICAL) reduce 46) ((T_IS_NOT_EQUAL) reduce 46) ((T_IS_NOT_IDENTICAL) reduce 46) ((T_IS_SMALLER_OR_EQUAL) reduce 46) ((T_LOGICAL_AND) reduce 46) ((T_LOGICAL_OR) reduce 46) ((T_LOGICAL_XOR) reduce 46) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 46) ((T_OBJECT_OPERATOR) reduce 46) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 46) ((T_POW) reduce 46) ((T_SL) reduce 46) ((T_SPACESHIP) reduce 46) ((T_SR) reduce 46) (("[") reduce 46) (("^") reduce 46) (("{") reduce 46) (("|") reduce 46)) 10004 ((("%") reduce 8) (("(") reduce 8) (("*") reduce 8) (("+") reduce 8) (("-") reduce 8) ((".") reduce 8) (("/") reduce 8) ((":") reduce 8) (("<") reduce 8) ((">") reduce 8) (("?") reduce 8) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_BOOLEAN_AND) reduce 8) ((T_BOOLEAN_OR) reduce 8) ((T_COALESCE) reduce 8) ((T_DOUBLE_ARROW) reduce 8) ((T_INSTANCEOF) reduce 8) ((T_IS_EQUAL) reduce 8) ((T_IS_GREATER_OR_EQUAL) reduce 8) ((T_IS_IDENTICAL) reduce 8) ((T_IS_NOT_EQUAL) reduce 8) ((T_IS_NOT_IDENTICAL) reduce 8) ((T_IS_SMALLER_OR_EQUAL) reduce 8) ((T_LOGICAL_AND) reduce 8) ((T_LOGICAL_OR) reduce 8) ((T_LOGICAL_XOR) reduce 8) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 8) ((T_OBJECT_OPERATOR) reduce 8) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 8) ((T_POW) reduce 8) ((T_SL) reduce 8) ((T_SPACESHIP) reduce 8) ((T_SR) reduce 8) (("[") reduce 8) (("^") reduce 8) (("{") reduce 8) (("|") reduce 8)) 10005 ((("%") reduce 6) (("(") reduce 6) (("*") reduce 6) (("+") reduce 6) (("-") reduce 6) ((".") reduce 6) (("/") reduce 6) ((":") reduce 6) (("<") reduce 6) ((">") reduce 6) (("?") reduce 6) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_BOOLEAN_AND) reduce 6) ((T_BOOLEAN_OR) reduce 6) ((T_COALESCE) reduce 6) ((T_DOUBLE_ARROW) reduce 6) ((T_INSTANCEOF) reduce 6) ((T_IS_EQUAL) reduce 6) ((T_IS_GREATER_OR_EQUAL) reduce 6) ((T_IS_IDENTICAL) reduce 6) ((T_IS_NOT_EQUAL) reduce 6) ((T_IS_NOT_IDENTICAL) reduce 6) ((T_IS_SMALLER_OR_EQUAL) reduce 6) ((T_LOGICAL_AND) reduce 6) ((T_LOGICAL_OR) reduce 6) ((T_LOGICAL_XOR) reduce 6) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 6) ((T_OBJECT_OPERATOR) reduce 6) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 6) ((T_POW) reduce 6) ((T_SL) reduce 6) ((T_SPACESHIP) reduce 6) ((T_SR) reduce 6) (("[") reduce 6) (("^") reduce 6) (("{") reduce 6) (("|") reduce 6)) 10006 ((("%") reduce 7) (("(") reduce 7) (("*") reduce 7) (("+") reduce 7) (("-") reduce 7) ((".") reduce 7) (("/") reduce 7) ((":") reduce 7) (("<") reduce 7) ((">") reduce 7) (("?") reduce 7) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_BOOLEAN_AND) reduce 7) ((T_BOOLEAN_OR) reduce 7) ((T_COALESCE) reduce 7) ((T_DOUBLE_ARROW) reduce 7) ((T_INSTANCEOF) reduce 7) ((T_IS_EQUAL) reduce 7) ((T_IS_GREATER_OR_EQUAL) reduce 7) ((T_IS_IDENTICAL) reduce 7) ((T_IS_NOT_EQUAL) reduce 7) ((T_IS_NOT_IDENTICAL) reduce 7) ((T_IS_SMALLER_OR_EQUAL) reduce 7) ((T_LOGICAL_AND) reduce 7) ((T_LOGICAL_OR) reduce 7) ((T_LOGICAL_XOR) reduce 7) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 7) ((T_OBJECT_OPERATOR) reduce 7) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 7) ((T_POW) reduce 7) ((T_SL) reduce 7) ((T_SPACESHIP) reduce 7) ((T_SR) reduce 7) (("[") reduce 7) (("^") reduce 7) (("{") reduce 7) (("|") reduce 7)) 10007 ((("%") reduce 69) (("(") reduce 69) (("*") reduce 69) (("+") reduce 69) (("-") reduce 69) ((".") reduce 69) (("/") reduce 69) ((":") reduce 69) (("<") reduce 69) ((">") reduce 69) (("?") reduce 69) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_BOOLEAN_AND) reduce 69) ((T_BOOLEAN_OR) reduce 69) ((T_COALESCE) reduce 69) ((T_DOUBLE_ARROW) reduce 69) ((T_INSTANCEOF) reduce 69) ((T_IS_EQUAL) reduce 69) ((T_IS_GREATER_OR_EQUAL) reduce 69) ((T_IS_IDENTICAL) reduce 69) ((T_IS_NOT_EQUAL) reduce 69) ((T_IS_NOT_IDENTICAL) reduce 69) ((T_IS_SMALLER_OR_EQUAL) reduce 69) ((T_LOGICAL_AND) reduce 69) ((T_LOGICAL_OR) reduce 69) ((T_LOGICAL_XOR) reduce 69) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 69) ((T_OBJECT_OPERATOR) reduce 69) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 69) ((T_POW) reduce 69) ((T_SL) reduce 69) ((T_SPACESHIP) reduce 69) ((T_SR) reduce 69) (("[") reduce 69) (("^") reduce 69) (("{") reduce 69) (("|") reduce 69)) 10008 ((("%") reduce 63) (("(") reduce 63) (("*") reduce 63) (("+") reduce 63) (("-") reduce 63) ((".") reduce 63) (("/") reduce 63) ((":") reduce 63) (("<") reduce 63) ((">") reduce 63) (("?") reduce 63) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_BOOLEAN_AND) reduce 63) ((T_BOOLEAN_OR) reduce 63) ((T_COALESCE) reduce 63) ((T_DOUBLE_ARROW) reduce 63) ((T_INSTANCEOF) reduce 63) ((T_IS_EQUAL) reduce 63) ((T_IS_GREATER_OR_EQUAL) reduce 63) ((T_IS_IDENTICAL) reduce 63) ((T_IS_NOT_EQUAL) reduce 63) ((T_IS_NOT_IDENTICAL) reduce 63) ((T_IS_SMALLER_OR_EQUAL) reduce 63) ((T_LOGICAL_AND) reduce 63) ((T_LOGICAL_OR) reduce 63) ((T_LOGICAL_XOR) reduce 63) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 63) ((T_OBJECT_OPERATOR) reduce 63) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 63) ((T_POW) reduce 63) ((T_SL) reduce 63) ((T_SPACESHIP) reduce 63) ((T_SR) reduce 63) (("[") reduce 63) (("^") reduce 63) (("{") reduce 63) (("|") reduce 63)) 10009 ((("%") reduce 56) (("(") reduce 56) (("*") reduce 56) (("+") reduce 56) (("-") reduce 56) ((".") reduce 56) (("/") reduce 56) ((":") reduce 56) (("<") reduce 56) ((">") reduce 56) (("?") reduce 56) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_BOOLEAN_AND) reduce 56) ((T_BOOLEAN_OR) reduce 56) ((T_COALESCE) reduce 56) ((T_DOUBLE_ARROW) reduce 56) ((T_INSTANCEOF) reduce 56) ((T_IS_EQUAL) reduce 56) ((T_IS_GREATER_OR_EQUAL) reduce 56) ((T_IS_IDENTICAL) reduce 56) ((T_IS_NOT_EQUAL) reduce 56) ((T_IS_NOT_IDENTICAL) reduce 56) ((T_IS_SMALLER_OR_EQUAL) reduce 56) ((T_LOGICAL_AND) reduce 56) ((T_LOGICAL_OR) reduce 56) ((T_LOGICAL_XOR) reduce 56) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 56) ((T_OBJECT_OPERATOR) reduce 56) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 56) ((T_POW) reduce 56) ((T_SL) reduce 56) ((T_SPACESHIP) reduce 56) ((T_SR) reduce 56) (("[") reduce 56) (("^") reduce 56) (("{") reduce 56) (("|") reduce 56)) 10010 ((("%") reduce 10) (("(") reduce 10) (("*") reduce 10) (("+") reduce 10) (("-") reduce 10) ((".") reduce 10) (("/") reduce 10) ((":") reduce 10) (("<") reduce 10) ((">") reduce 10) (("?") reduce 10) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_BOOLEAN_AND) reduce 10) ((T_BOOLEAN_OR) reduce 10) ((T_COALESCE) reduce 10) ((T_DOUBLE_ARROW) reduce 10) ((T_INSTANCEOF) reduce 10) ((T_IS_EQUAL) reduce 10) ((T_IS_GREATER_OR_EQUAL) reduce 10) ((T_IS_IDENTICAL) reduce 10) ((T_IS_NOT_EQUAL) reduce 10) ((T_IS_NOT_IDENTICAL) reduce 10) ((T_IS_SMALLER_OR_EQUAL) reduce 10) ((T_LOGICAL_AND) reduce 10) ((T_LOGICAL_OR) reduce 10) ((T_LOGICAL_XOR) reduce 10) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 10) ((T_OBJECT_OPERATOR) reduce 10) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 10) ((T_POW) reduce 10) ((T_SL) reduce 10) ((T_SPACESHIP) reduce 10) ((T_SR) reduce 10) (("[") reduce 10) (("^") reduce 10) (("{") reduce 10) (("|") reduce 10)) 10011 ((("%") reduce 67) (("(") reduce 67) (("*") reduce 67) (("+") reduce 67) (("-") reduce 67) ((".") reduce 67) (("/") reduce 67) ((":") reduce 67) (("<") reduce 67) ((">") reduce 67) (("?") reduce 67) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_BOOLEAN_AND) reduce 67) ((T_BOOLEAN_OR) reduce 67) ((T_COALESCE) reduce 67) ((T_DOUBLE_ARROW) reduce 67) ((T_INSTANCEOF) reduce 67) ((T_IS_EQUAL) reduce 67) ((T_IS_GREATER_OR_EQUAL) reduce 67) ((T_IS_IDENTICAL) reduce 67) ((T_IS_NOT_EQUAL) reduce 67) ((T_IS_NOT_IDENTICAL) reduce 67) ((T_IS_SMALLER_OR_EQUAL) reduce 67) ((T_LOGICAL_AND) reduce 67) ((T_LOGICAL_OR) reduce 67) ((T_LOGICAL_XOR) reduce 67) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 67) ((T_OBJECT_OPERATOR) reduce 67) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 67) ((T_POW) reduce 67) ((T_SL) reduce 67) ((T_SPACESHIP) reduce 67) ((T_SR) reduce 67) (("[") reduce 67) (("^") reduce 67) (("{") reduce 67) (("|") reduce 67)) 10012 ((("%") reduce 44) (("(") reduce 44) (("*") reduce 44) (("+") reduce 44) (("-") reduce 44) ((".") reduce 44) (("/") reduce 44) ((":") reduce 44) (("<") reduce 44) ((">") reduce 44) (("?") reduce 44) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_BOOLEAN_AND) reduce 44) ((T_BOOLEAN_OR) reduce 44) ((T_COALESCE) reduce 44) ((T_DOUBLE_ARROW) reduce 44) ((T_INSTANCEOF) reduce 44) ((T_IS_EQUAL) reduce 44) ((T_IS_GREATER_OR_EQUAL) reduce 44) ((T_IS_IDENTICAL) reduce 44) ((T_IS_NOT_EQUAL) reduce 44) ((T_IS_NOT_IDENTICAL) reduce 44) ((T_IS_SMALLER_OR_EQUAL) reduce 44) ((T_LOGICAL_AND) reduce 44) ((T_LOGICAL_OR) reduce 44) ((T_LOGICAL_XOR) reduce 44) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 44) ((T_OBJECT_OPERATOR) reduce 44) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 44) ((T_POW) reduce 44) ((T_SL) reduce 44) ((T_SPACESHIP) reduce 44) ((T_SR) reduce 44) (("[") reduce 44) (("^") reduce 44) (("{") reduce 44) (("|") reduce 44)) 10013 ((("%") reduce 75) (("(") reduce 75) (("*") reduce 75) (("+") reduce 75) (("-") reduce 75) ((".") reduce 75) (("/") reduce 75) ((":") reduce 75) (("<") reduce 75) ((">") reduce 75) (("?") reduce 75) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_BOOLEAN_AND) reduce 75) ((T_BOOLEAN_OR) reduce 75) ((T_COALESCE) reduce 75) ((T_DOUBLE_ARROW) reduce 75) ((T_INSTANCEOF) reduce 75) ((T_IS_EQUAL) reduce 75) ((T_IS_GREATER_OR_EQUAL) reduce 75) ((T_IS_IDENTICAL) reduce 75) ((T_IS_NOT_EQUAL) reduce 75) ((T_IS_NOT_IDENTICAL) reduce 75) ((T_IS_SMALLER_OR_EQUAL) reduce 75) ((T_LOGICAL_AND) reduce 75) ((T_LOGICAL_OR) reduce 75) ((T_LOGICAL_XOR) reduce 75) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 75) ((T_OBJECT_OPERATOR) reduce 75) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 75) ((T_POW) reduce 75) ((T_SL) reduce 75) ((T_SPACESHIP) reduce 75) ((T_SR) reduce 75) (("[") reduce 75) (("^") reduce 75) (("{") reduce 75) (("|") reduce 75)) 10014 ((("%") reduce 76) (("(") reduce 76) (("*") reduce 76) (("+") reduce 76) (("-") reduce 76) ((".") reduce 76) (("/") reduce 76) ((":") reduce 76) (("<") reduce 76) ((">") reduce 76) (("?") reduce 76) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_BOOLEAN_AND) reduce 76) ((T_BOOLEAN_OR) reduce 76) ((T_COALESCE) reduce 76) ((T_DOUBLE_ARROW) reduce 76) ((T_INSTANCEOF) reduce 76) ((T_IS_EQUAL) reduce 76) ((T_IS_GREATER_OR_EQUAL) reduce 76) ((T_IS_IDENTICAL) reduce 76) ((T_IS_NOT_EQUAL) reduce 76) ((T_IS_NOT_IDENTICAL) reduce 76) ((T_IS_SMALLER_OR_EQUAL) reduce 76) ((T_LOGICAL_AND) reduce 76) ((T_LOGICAL_OR) reduce 76) ((T_LOGICAL_XOR) reduce 76) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 76) ((T_OBJECT_OPERATOR) reduce 76) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 76) ((T_POW) reduce 76) ((T_SL) reduce 76) ((T_SPACESHIP) reduce 76) ((T_SR) reduce 76) (("[") reduce 76) (("^") reduce 76) (("{") reduce 76) (("|") reduce 76)) 10015 ((("%") reduce 77) (("(") reduce 77) (("*") reduce 77) (("+") reduce 77) (("-") reduce 77) ((".") reduce 77) (("/") reduce 77) ((":") reduce 77) (("<") reduce 77) ((">") reduce 77) (("?") reduce 77) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_BOOLEAN_AND) reduce 77) ((T_BOOLEAN_OR) reduce 77) ((T_COALESCE) reduce 77) ((T_DOUBLE_ARROW) reduce 77) ((T_INSTANCEOF) reduce 77) ((T_IS_EQUAL) reduce 77) ((T_IS_GREATER_OR_EQUAL) reduce 77) ((T_IS_IDENTICAL) reduce 77) ((T_IS_NOT_EQUAL) reduce 77) ((T_IS_NOT_IDENTICAL) reduce 77) ((T_IS_SMALLER_OR_EQUAL) reduce 77) ((T_LOGICAL_AND) reduce 77) ((T_LOGICAL_OR) reduce 77) ((T_LOGICAL_XOR) reduce 77) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 77) ((T_OBJECT_OPERATOR) reduce 77) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 77) ((T_POW) reduce 77) ((T_SL) reduce 77) ((T_SPACESHIP) reduce 77) ((T_SR) reduce 77) (("[") reduce 77) (("^") reduce 77) (("{") reduce 77) (("|") reduce 77)) 10016 ((("%") reduce 78) (("(") reduce 78) (("*") reduce 78) (("+") reduce 78) (("-") reduce 78) ((".") reduce 78) (("/") reduce 78) ((":") reduce 78) (("<") reduce 78) ((">") reduce 78) (("?") reduce 78) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_BOOLEAN_AND) reduce 78) ((T_BOOLEAN_OR) reduce 78) ((T_COALESCE) reduce 78) ((T_DOUBLE_ARROW) reduce 78) ((T_INSTANCEOF) reduce 78) ((T_IS_EQUAL) reduce 78) ((T_IS_GREATER_OR_EQUAL) reduce 78) ((T_IS_IDENTICAL) reduce 78) ((T_IS_NOT_EQUAL) reduce 78) ((T_IS_NOT_IDENTICAL) reduce 78) ((T_IS_SMALLER_OR_EQUAL) reduce 78) ((T_LOGICAL_AND) reduce 78) ((T_LOGICAL_OR) reduce 78) ((T_LOGICAL_XOR) reduce 78) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 78) ((T_OBJECT_OPERATOR) reduce 78) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 78) ((T_POW) reduce 78) ((T_SL) reduce 78) ((T_SPACESHIP) reduce 78) ((T_SR) reduce 78) (("[") reduce 78) (("^") reduce 78) (("{") reduce 78) (("|") reduce 78)) 10017 ((("%") reduce 4) (("(") reduce 4) (("*") reduce 4) (("+") reduce 4) (("-") reduce 4) ((".") reduce 4) (("/") reduce 4) ((":") reduce 4) (("<") reduce 4) ((">") reduce 4) (("?") reduce 4) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_BOOLEAN_AND) reduce 4) ((T_BOOLEAN_OR) reduce 4) ((T_COALESCE) reduce 4) ((T_DOUBLE_ARROW) reduce 4) ((T_INSTANCEOF) reduce 4) ((T_IS_EQUAL) reduce 4) ((T_IS_GREATER_OR_EQUAL) reduce 4) ((T_IS_IDENTICAL) reduce 4) ((T_IS_NOT_EQUAL) reduce 4) ((T_IS_NOT_IDENTICAL) reduce 4) ((T_IS_SMALLER_OR_EQUAL) reduce 4) ((T_LOGICAL_AND) reduce 4) ((T_LOGICAL_OR) reduce 4) ((T_LOGICAL_XOR) reduce 4) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 4) ((T_OBJECT_OPERATOR) reduce 4) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 4) ((T_POW) reduce 4) ((T_SL) reduce 4) ((T_SPACESHIP) reduce 4) ((T_SR) reduce 4) (("[") reduce 4) (("^") reduce 4) (("{") reduce 4) (("|") reduce 4)) 10018 ((("%") reduce 5) (("(") reduce 5) (("*") reduce 5) (("+") reduce 5) (("-") reduce 5) ((".") reduce 5) (("/") reduce 5) ((":") reduce 5) (("<") reduce 5) ((">") reduce 5) (("?") reduce 5) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_BOOLEAN_AND) reduce 5) ((T_BOOLEAN_OR) reduce 5) ((T_COALESCE) reduce 5) ((T_DOUBLE_ARROW) reduce 5) ((T_INSTANCEOF) reduce 5) ((T_IS_EQUAL) reduce 5) ((T_IS_GREATER_OR_EQUAL) reduce 5) ((T_IS_IDENTICAL) reduce 5) ((T_IS_NOT_EQUAL) reduce 5) ((T_IS_NOT_IDENTICAL) reduce 5) ((T_IS_SMALLER_OR_EQUAL) reduce 5) ((T_LOGICAL_AND) reduce 5) ((T_LOGICAL_OR) reduce 5) ((T_LOGICAL_XOR) reduce 5) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 5) ((T_OBJECT_OPERATOR) reduce 5) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 5) ((T_POW) reduce 5) ((T_SL) reduce 5) ((T_SPACESHIP) reduce 5) ((T_SR) reduce 5) (("[") reduce 5) (("^") reduce 5) (("{") reduce 5) (("|") reduce 5)) 10019 ((("%") reduce 43) (("(") reduce 43) (("*") reduce 43) (("+") reduce 43) (("-") reduce 43) ((".") reduce 43) (("/") reduce 43) ((":") reduce 43) (("<") reduce 43) ((">") reduce 43) (("?") reduce 43) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_BOOLEAN_AND) reduce 43) ((T_BOOLEAN_OR) reduce 43) ((T_COALESCE) reduce 43) ((T_DOUBLE_ARROW) reduce 43) ((T_INSTANCEOF) reduce 43) ((T_IS_EQUAL) reduce 43) ((T_IS_GREATER_OR_EQUAL) reduce 43) ((T_IS_IDENTICAL) reduce 43) ((T_IS_NOT_EQUAL) reduce 43) ((T_IS_NOT_IDENTICAL) reduce 43) ((T_IS_SMALLER_OR_EQUAL) reduce 43) ((T_LOGICAL_AND) reduce 43) ((T_LOGICAL_OR) reduce 43) ((T_LOGICAL_XOR) reduce 43) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 43) ((T_OBJECT_OPERATOR) reduce 43) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 43) ((T_POW) reduce 43) ((T_SL) reduce 43) ((T_SPACESHIP) reduce 43) ((T_SR) reduce 43) (("[") reduce 43) (("^") reduce 43) (("{") reduce 43) (("|") reduce 43)) 10020 ((("%") reduce 72) (("(") reduce 72) (("*") reduce 72) (("+") reduce 72) (("-") reduce 72) ((".") reduce 72) (("/") reduce 72) ((":") reduce 72) (("<") reduce 72) ((">") reduce 72) (("?") reduce 72) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_BOOLEAN_AND) reduce 72) ((T_BOOLEAN_OR) reduce 72) ((T_COALESCE) reduce 72) ((T_DOUBLE_ARROW) reduce 72) ((T_INSTANCEOF) reduce 72) ((T_IS_EQUAL) reduce 72) ((T_IS_GREATER_OR_EQUAL) reduce 72) ((T_IS_IDENTICAL) reduce 72) ((T_IS_NOT_EQUAL) reduce 72) ((T_IS_NOT_IDENTICAL) reduce 72) ((T_IS_SMALLER_OR_EQUAL) reduce 72) ((T_LOGICAL_AND) reduce 72) ((T_LOGICAL_OR) reduce 72) ((T_LOGICAL_XOR) reduce 72) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 72) ((T_OBJECT_OPERATOR) reduce 72) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 72) ((T_POW) reduce 72) ((T_SL) reduce 72) ((T_SPACESHIP) reduce 72) ((T_SR) reduce 72) (("[") reduce 72) (("^") reduce 72) (("{") reduce 72) (("|") reduce 72)) 10021 ((("%") reduce 81) (("(") reduce 81) (("*") reduce 81) (("+") reduce 81) (("-") reduce 81) ((".") reduce 81) (("/") reduce 81) ((":") reduce 81) (("<") reduce 81) ((">") reduce 81) (("?") reduce 81) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_BOOLEAN_AND) reduce 81) ((T_BOOLEAN_OR) reduce 81) ((T_COALESCE) reduce 81) ((T_DOUBLE_ARROW) reduce 81) ((T_INSTANCEOF) reduce 81) ((T_IS_EQUAL) reduce 81) ((T_IS_GREATER_OR_EQUAL) reduce 81) ((T_IS_IDENTICAL) reduce 81) ((T_IS_NOT_EQUAL) reduce 81) ((T_IS_NOT_IDENTICAL) reduce 81) ((T_IS_SMALLER_OR_EQUAL) reduce 81) ((T_LOGICAL_AND) reduce 81) ((T_LOGICAL_OR) reduce 81) ((T_LOGICAL_XOR) reduce 81) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 81) ((T_OBJECT_OPERATOR) reduce 81) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 81) ((T_POW) reduce 81) ((T_SL) reduce 81) ((T_SPACESHIP) reduce 81) ((T_SR) reduce 81) (("[") reduce 81) (("^") reduce 81) (("{") reduce 81) (("|") reduce 81)) 10022 ((("%") reduce 47) (("(") reduce 47) (("*") reduce 47) (("+") reduce 47) (("-") reduce 47) ((".") reduce 47) (("/") reduce 47) ((":") reduce 47) (("<") reduce 47) ((">") reduce 47) (("?") reduce 47) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_BOOLEAN_AND) reduce 47) ((T_BOOLEAN_OR) reduce 47) ((T_COALESCE) reduce 47) ((T_DOUBLE_ARROW) reduce 47) ((T_INSTANCEOF) reduce 47) ((T_IS_EQUAL) reduce 47) ((T_IS_GREATER_OR_EQUAL) reduce 47) ((T_IS_IDENTICAL) reduce 47) ((T_IS_NOT_EQUAL) reduce 47) ((T_IS_NOT_IDENTICAL) reduce 47) ((T_IS_SMALLER_OR_EQUAL) reduce 47) ((T_LOGICAL_AND) reduce 47) ((T_LOGICAL_OR) reduce 47) ((T_LOGICAL_XOR) reduce 47) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 47) ((T_OBJECT_OPERATOR) reduce 47) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 47) ((T_POW) reduce 47) ((T_SL) reduce 47) ((T_SPACESHIP) reduce 47) ((T_SR) reduce 47) (("[") reduce 47) (("^") reduce 47) (("{") reduce 47) (("|") reduce 47)) 10023 ((("%") reduce 31) (("(") reduce 31) (("*") reduce 31) (("+") reduce 31) (("-") reduce 31) ((".") reduce 31) (("/") reduce 31) ((":") reduce 31) (("<") reduce 31) ((">") reduce 31) (("?") reduce 31) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_BOOLEAN_AND) reduce 31) ((T_BOOLEAN_OR) reduce 31) ((T_COALESCE) reduce 31) ((T_DOUBLE_ARROW) reduce 31) ((T_INSTANCEOF) reduce 31) ((T_IS_EQUAL) reduce 31) ((T_IS_GREATER_OR_EQUAL) reduce 31) ((T_IS_IDENTICAL) reduce 31) ((T_IS_NOT_EQUAL) reduce 31) ((T_IS_NOT_IDENTICAL) reduce 31) ((T_IS_SMALLER_OR_EQUAL) reduce 31) ((T_LOGICAL_AND) reduce 31) ((T_LOGICAL_OR) reduce 31) ((T_LOGICAL_XOR) reduce 31) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 31) ((T_OBJECT_OPERATOR) reduce 31) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 31) ((T_POW) reduce 31) ((T_SL) reduce 31) ((T_SPACESHIP) reduce 31) ((T_SR) reduce 31) (("[") reduce 31) (("^") reduce 31) (("{") reduce 31) (("|") reduce 31)) 10024 ((("%") reduce 57) (("(") reduce 57) (("*") reduce 57) (("+") reduce 57) (("-") reduce 57) ((".") reduce 57) (("/") reduce 57) ((":") reduce 57) (("<") reduce 57) ((">") reduce 57) (("?") reduce 57) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_BOOLEAN_AND) reduce 57) ((T_BOOLEAN_OR) reduce 57) ((T_COALESCE) reduce 57) ((T_DOUBLE_ARROW) reduce 57) ((T_INSTANCEOF) reduce 57) ((T_IS_EQUAL) reduce 57) ((T_IS_GREATER_OR_EQUAL) reduce 57) ((T_IS_IDENTICAL) reduce 57) ((T_IS_NOT_EQUAL) reduce 57) ((T_IS_NOT_IDENTICAL) reduce 57) ((T_IS_SMALLER_OR_EQUAL) reduce 57) ((T_LOGICAL_AND) reduce 57) ((T_LOGICAL_OR) reduce 57) ((T_LOGICAL_XOR) reduce 57) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 57) ((T_OBJECT_OPERATOR) reduce 57) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 57) ((T_POW) reduce 57) ((T_SL) reduce 57) ((T_SPACESHIP) reduce 57) ((T_SR) reduce 57) (("[") reduce 57) (("^") reduce 57) (("{") reduce 57) (("|") reduce 57)) 10025 ((("%") reduce 61) (("(") reduce 61) (("*") reduce 61) (("+") reduce 61) (("-") reduce 61) ((".") reduce 61) (("/") reduce 61) ((":") reduce 61) (("<") reduce 61) ((">") reduce 61) (("?") reduce 61) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_BOOLEAN_AND) reduce 61) ((T_BOOLEAN_OR) reduce 61) ((T_COALESCE) reduce 61) ((T_DOUBLE_ARROW) reduce 61) ((T_INSTANCEOF) reduce 61) ((T_IS_EQUAL) reduce 61) ((T_IS_GREATER_OR_EQUAL) reduce 61) ((T_IS_IDENTICAL) reduce 61) ((T_IS_NOT_EQUAL) reduce 61) ((T_IS_NOT_IDENTICAL) reduce 61) ((T_IS_SMALLER_OR_EQUAL) reduce 61) ((T_LOGICAL_AND) reduce 61) ((T_LOGICAL_OR) reduce 61) ((T_LOGICAL_XOR) reduce 61) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 61) ((T_OBJECT_OPERATOR) reduce 61) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 61) ((T_POW) reduce 61) ((T_SL) reduce 61) ((T_SPACESHIP) reduce 61) ((T_SR) reduce 61) (("[") reduce 61) (("^") reduce 61) (("{") reduce 61) (("|") reduce 61)) 10026 ((("%") reduce 28) (("(") reduce 28) (("*") reduce 28) (("+") reduce 28) (("-") reduce 28) ((".") reduce 28) (("/") reduce 28) ((":") reduce 28) (("<") reduce 28) ((">") reduce 28) (("?") reduce 28) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_BOOLEAN_AND) reduce 28) ((T_BOOLEAN_OR) reduce 28) ((T_COALESCE) reduce 28) ((T_DOUBLE_ARROW) reduce 28) ((T_INSTANCEOF) reduce 28) ((T_IS_EQUAL) reduce 28) ((T_IS_GREATER_OR_EQUAL) reduce 28) ((T_IS_IDENTICAL) reduce 28) ((T_IS_NOT_EQUAL) reduce 28) ((T_IS_NOT_IDENTICAL) reduce 28) ((T_IS_SMALLER_OR_EQUAL) reduce 28) ((T_LOGICAL_AND) reduce 28) ((T_LOGICAL_OR) reduce 28) ((T_LOGICAL_XOR) reduce 28) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 28) ((T_OBJECT_OPERATOR) reduce 28) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 28) ((T_POW) reduce 28) ((T_SL) reduce 28) ((T_SPACESHIP) reduce 28) ((T_SR) reduce 28) (("[") reduce 28) (("^") reduce 28) (("{") reduce 28) (("|") reduce 28)) 10027 ((("%") reduce 36) (("(") reduce 36) (("*") reduce 36) (("+") reduce 36) (("-") reduce 36) ((".") reduce 36) (("/") reduce 36) ((":") reduce 36) (("<") reduce 36) ((">") reduce 36) (("?") reduce 36) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_BOOLEAN_AND) reduce 36) ((T_BOOLEAN_OR) reduce 36) ((T_COALESCE) reduce 36) ((T_DOUBLE_ARROW) reduce 36) ((T_INSTANCEOF) reduce 36) ((T_IS_EQUAL) reduce 36) ((T_IS_GREATER_OR_EQUAL) reduce 36) ((T_IS_IDENTICAL) reduce 36) ((T_IS_NOT_EQUAL) reduce 36) ((T_IS_NOT_IDENTICAL) reduce 36) ((T_IS_SMALLER_OR_EQUAL) reduce 36) ((T_LOGICAL_AND) reduce 36) ((T_LOGICAL_OR) reduce 36) ((T_LOGICAL_XOR) reduce 36) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 36) ((T_OBJECT_OPERATOR) reduce 36) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 36) ((T_POW) reduce 36) ((T_SL) reduce 36) ((T_SPACESHIP) reduce 36) ((T_SR) reduce 36) (("[") reduce 36) (("^") reduce 36) (("{") reduce 36) (("|") reduce 36)) 10028 ((("%") reduce 32) (("(") reduce 32) (("*") reduce 32) (("+") reduce 32) (("-") reduce 32) ((".") reduce 32) (("/") reduce 32) ((":") reduce 32) (("<") reduce 32) ((">") reduce 32) (("?") reduce 32) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_BOOLEAN_AND) reduce 32) ((T_BOOLEAN_OR) reduce 32) ((T_COALESCE) reduce 32) ((T_DOUBLE_ARROW) reduce 32) ((T_INSTANCEOF) reduce 32) ((T_IS_EQUAL) reduce 32) ((T_IS_GREATER_OR_EQUAL) reduce 32) ((T_IS_IDENTICAL) reduce 32) ((T_IS_NOT_EQUAL) reduce 32) ((T_IS_NOT_IDENTICAL) reduce 32) ((T_IS_SMALLER_OR_EQUAL) reduce 32) ((T_LOGICAL_AND) reduce 32) ((T_LOGICAL_OR) reduce 32) ((T_LOGICAL_XOR) reduce 32) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 32) ((T_OBJECT_OPERATOR) reduce 32) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 32) ((T_POW) reduce 32) ((T_SL) reduce 32) ((T_SPACESHIP) reduce 32) ((T_SR) reduce 32) (("[") reduce 32) (("^") reduce 32) (("{") reduce 32) (("|") reduce 32)) 10029 ((("%") reduce 35) (("(") reduce 35) (("*") reduce 35) (("+") reduce 35) (("-") reduce 35) ((".") reduce 35) (("/") reduce 35) ((":") reduce 35) (("<") reduce 35) ((">") reduce 35) (("?") reduce 35) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_BOOLEAN_AND) reduce 35) ((T_BOOLEAN_OR) reduce 35) ((T_COALESCE) reduce 35) ((T_DOUBLE_ARROW) reduce 35) ((T_INSTANCEOF) reduce 35) ((T_IS_EQUAL) reduce 35) ((T_IS_GREATER_OR_EQUAL) reduce 35) ((T_IS_IDENTICAL) reduce 35) ((T_IS_NOT_EQUAL) reduce 35) ((T_IS_NOT_IDENTICAL) reduce 35) ((T_IS_SMALLER_OR_EQUAL) reduce 35) ((T_LOGICAL_AND) reduce 35) ((T_LOGICAL_OR) reduce 35) ((T_LOGICAL_XOR) reduce 35) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 35) ((T_OBJECT_OPERATOR) reduce 35) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 35) ((T_POW) reduce 35) ((T_SL) reduce 35) ((T_SPACESHIP) reduce 35) ((T_SR) reduce 35) (("[") reduce 35) (("^") reduce 35) (("{") reduce 35) (("|") reduce 35)) 10030 ((("%") reduce 19) (("(") reduce 19) (("*") reduce 19) (("+") reduce 19) (("-") reduce 19) ((".") reduce 19) (("/") reduce 19) ((":") reduce 19) (("<") reduce 19) ((">") reduce 19) (("?") reduce 19) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_BOOLEAN_AND) reduce 19) ((T_BOOLEAN_OR) reduce 19) ((T_COALESCE) reduce 19) ((T_DOUBLE_ARROW) reduce 19) ((T_INSTANCEOF) reduce 19) ((T_IS_EQUAL) reduce 19) ((T_IS_GREATER_OR_EQUAL) reduce 19) ((T_IS_IDENTICAL) reduce 19) ((T_IS_NOT_EQUAL) reduce 19) ((T_IS_NOT_IDENTICAL) reduce 19) ((T_IS_SMALLER_OR_EQUAL) reduce 19) ((T_LOGICAL_AND) reduce 19) ((T_LOGICAL_OR) reduce 19) ((T_LOGICAL_XOR) reduce 19) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 19) ((T_OBJECT_OPERATOR) reduce 19) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 19) ((T_POW) reduce 19) ((T_SL) reduce 19) ((T_SPACESHIP) reduce 19) ((T_SR) reduce 19) (("[") reduce 19) (("^") reduce 19) (("{") reduce 19) (("|") reduce 19)) 10031 ((("%") reduce 45) (("(") reduce 45) (("*") reduce 45) (("+") reduce 45) (("-") reduce 45) ((".") reduce 45) (("/") reduce 45) ((":") reduce 45) (("<") reduce 45) ((">") reduce 45) (("?") reduce 45) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_BOOLEAN_AND) reduce 45) ((T_BOOLEAN_OR) reduce 45) ((T_COALESCE) reduce 45) ((T_DOUBLE_ARROW) reduce 45) ((T_INSTANCEOF) reduce 45) ((T_IS_EQUAL) reduce 45) ((T_IS_GREATER_OR_EQUAL) reduce 45) ((T_IS_IDENTICAL) reduce 45) ((T_IS_NOT_EQUAL) reduce 45) ((T_IS_NOT_IDENTICAL) reduce 45) ((T_IS_SMALLER_OR_EQUAL) reduce 45) ((T_LOGICAL_AND) reduce 45) ((T_LOGICAL_OR) reduce 45) ((T_LOGICAL_XOR) reduce 45) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 45) ((T_OBJECT_OPERATOR) reduce 45) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 45) ((T_POW) reduce 45) ((T_SL) reduce 45) ((T_SPACESHIP) reduce 45) ((T_SR) reduce 45) (("[") reduce 45) (("^") reduce 45) (("{") reduce 45) (("|") reduce 45)) 10032 ((("%") reduce 504) (("(") reduce 541) (("*") reduce 504) (("+") reduce 504) (("-") reduce 504) ((".") reduce 504) (("/") reduce 504) ((":") reduce 504) (("<") reduce 504) ((">") reduce 504) (("?") reduce 504) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_BOOLEAN_AND) reduce 504) ((T_BOOLEAN_OR) reduce 504) ((T_COALESCE) reduce 504) ((T_DOUBLE_ARROW) reduce 504) ((T_INSTANCEOF) reduce 504) ((T_IS_EQUAL) reduce 504) ((T_IS_GREATER_OR_EQUAL) reduce 504) ((T_IS_IDENTICAL) reduce 504) ((T_IS_NOT_EQUAL) reduce 504) ((T_IS_NOT_IDENTICAL) reduce 504) ((T_IS_SMALLER_OR_EQUAL) reduce 504) ((T_LOGICAL_AND) reduce 504) ((T_LOGICAL_OR) reduce 504) ((T_LOGICAL_XOR) reduce 504) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 504) ((T_OBJECT_OPERATOR) reduce 504) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 504) ((T_POW) reduce 504) ((T_SL) reduce 504) ((T_SPACESHIP) reduce 504) ((T_SR) reduce 504) (("[") reduce 504) (("^") reduce 504) (("{") reduce 504) (("|") reduce 504)) 10034 ((("%") reduce 71) (("(") reduce 71) (("*") reduce 71) (("+") reduce 71) (("-") reduce 71) ((".") reduce 71) (("/") reduce 71) ((":") reduce 71) (("<") reduce 71) ((">") reduce 71) (("?") reduce 71) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_BOOLEAN_AND) reduce 71) ((T_BOOLEAN_OR) reduce 71) ((T_COALESCE) reduce 71) ((T_DOUBLE_ARROW) reduce 71) ((T_INSTANCEOF) reduce 71) ((T_IS_EQUAL) reduce 71) ((T_IS_GREATER_OR_EQUAL) reduce 71) ((T_IS_IDENTICAL) reduce 71) ((T_IS_NOT_EQUAL) reduce 71) ((T_IS_NOT_IDENTICAL) reduce 71) ((T_IS_SMALLER_OR_EQUAL) reduce 71) ((T_LOGICAL_AND) reduce 71) ((T_LOGICAL_OR) reduce 71) ((T_LOGICAL_XOR) reduce 71) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 71) ((T_OBJECT_OPERATOR) reduce 71) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 71) ((T_POW) reduce 71) ((T_SL) reduce 71) ((T_SPACESHIP) reduce 71) ((T_SR) reduce 71) (("[") reduce 71) (("^") reduce 71) (("{") reduce 71) (("|") reduce 71)) 10035 ((("%") reduce 82) (("(") reduce 82) (("*") reduce 82) (("+") reduce 82) (("-") reduce 82) ((".") reduce 82) (("/") reduce 82) ((":") reduce 82) (("<") reduce 82) ((">") reduce 82) (("?") reduce 82) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_BOOLEAN_AND) reduce 82) ((T_BOOLEAN_OR) reduce 82) ((T_COALESCE) reduce 82) ((T_DOUBLE_ARROW) reduce 82) ((T_INSTANCEOF) reduce 82) ((T_IS_EQUAL) reduce 82) ((T_IS_GREATER_OR_EQUAL) reduce 82) ((T_IS_IDENTICAL) reduce 82) ((T_IS_NOT_EQUAL) reduce 82) ((T_IS_NOT_IDENTICAL) reduce 82) ((T_IS_SMALLER_OR_EQUAL) reduce 82) ((T_LOGICAL_AND) reduce 82) ((T_LOGICAL_OR) reduce 82) ((T_LOGICAL_XOR) reduce 82) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 82) ((T_OBJECT_OPERATOR) reduce 82) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 82) ((T_POW) reduce 82) ((T_SL) reduce 82) ((T_SPACESHIP) reduce 82) ((T_SR) reduce 82) (("[") reduce 82) (("^") reduce 82) (("{") reduce 82) (("|") reduce 82)) 10036 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) ((":") reduce 533) (("<") reduce 533) (("=") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AND_EQUAL) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_COALESCE_EQUAL) reduce 533) ((T_CONCAT_EQUAL) reduce 533) ((T_DEC) reduce 533) ((T_DIV_EQUAL) reduce 533) ((T_DOUBLE_ARROW) reduce 533) ((T_INC) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_MINUS_EQUAL) reduce 533) ((T_MOD_EQUAL) reduce 533) ((T_MUL_EQUAL) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_OR_EQUAL) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_PLUS_EQUAL) reduce 533) ((T_POW) reduce 533) ((T_POW_EQUAL) reduce 533) ((T_SL) reduce 533) ((T_SL_EQUAL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) ((T_SR_EQUAL) reduce 533) ((T_XOR_EQUAL) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 10039 ((("%") reduce 506) (("(") reduce 542) (("*") reduce 506) (("+") reduce 506) (("-") reduce 506) ((".") reduce 506) (("/") reduce 506) ((":") reduce 506) (("<") reduce 506) ((">") reduce 506) (("?") reduce 506) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_BOOLEAN_AND) reduce 506) ((T_BOOLEAN_OR) reduce 506) ((T_COALESCE) reduce 506) ((T_DOUBLE_ARROW) reduce 506) ((T_INSTANCEOF) reduce 506) ((T_IS_EQUAL) reduce 506) ((T_IS_GREATER_OR_EQUAL) reduce 506) ((T_IS_IDENTICAL) reduce 506) ((T_IS_NOT_EQUAL) reduce 506) ((T_IS_NOT_IDENTICAL) reduce 506) ((T_IS_SMALLER_OR_EQUAL) reduce 506) ((T_LOGICAL_AND) reduce 506) ((T_LOGICAL_OR) reduce 506) ((T_LOGICAL_XOR) reduce 506) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 506) ((T_OBJECT_OPERATOR) reduce 506) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 506) ((T_POW) reduce 506) ((T_SL) reduce 506) ((T_SPACESHIP) reduce 506) ((T_SR) reduce 506) (("[") reduce 506) (("^") reduce 506) (("{") reduce 506) (("|") reduce 506)) 10041 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) ((":") reduce 468) (("<") reduce 468) (("=") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AND_EQUAL) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_COALESCE_EQUAL) reduce 468) ((T_CONCAT_EQUAL) reduce 468) ((T_DEC) reduce 468) ((T_DIV_EQUAL) reduce 468) ((T_DOUBLE_ARROW) reduce 468) ((T_INC) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_MINUS_EQUAL) reduce 468) ((T_MOD_EQUAL) reduce 468) ((T_MUL_EQUAL) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_OR_EQUAL) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_PLUS_EQUAL) reduce 468) ((T_POW) reduce 468) ((T_POW_EQUAL) reduce 468) ((T_SL) reduce 468) ((T_SL_EQUAL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) ((T_SR_EQUAL) reduce 468) ((T_XOR_EQUAL) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 10042 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) ((":") reduce 288) (("<") reduce 288) (("=") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AND_EQUAL) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_COALESCE_EQUAL) reduce 288) ((T_CONCAT_EQUAL) reduce 288) ((T_DEC) reduce 288) ((T_DIV_EQUAL) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INC) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_MINUS_EQUAL) reduce 288) ((T_MOD_EQUAL) reduce 288) ((T_MUL_EQUAL) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_OR_EQUAL) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_PLUS_EQUAL) reduce 288) ((T_POW) reduce 288) ((T_POW_EQUAL) reduce 288) ((T_SL) reduce 288) ((T_SL_EQUAL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) ((T_SR_EQUAL) reduce 288) ((T_XOR_EQUAL) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 10046 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) ((":") reduce 289) (("<") reduce 289) (("=") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AND_EQUAL) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_COALESCE_EQUAL) reduce 289) ((T_CONCAT_EQUAL) reduce 289) ((T_DEC) reduce 289) ((T_DIV_EQUAL) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INC) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_MINUS_EQUAL) reduce 289) ((T_MOD_EQUAL) reduce 289) ((T_MUL_EQUAL) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_OR_EQUAL) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_PLUS_EQUAL) reduce 289) ((T_POW) reduce 289) ((T_POW_EQUAL) reduce 289) ((T_SL) reduce 289) ((T_SL_EQUAL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) ((T_SR_EQUAL) reduce 289) ((T_XOR_EQUAL) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 10047 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) ((":") reduce 290) (("<") reduce 290) (("=") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AND_EQUAL) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_COALESCE_EQUAL) reduce 290) ((T_CONCAT_EQUAL) reduce 290) ((T_DEC) reduce 290) ((T_DIV_EQUAL) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INC) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_MINUS_EQUAL) reduce 290) ((T_MOD_EQUAL) reduce 290) ((T_MUL_EQUAL) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_OR_EQUAL) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_PLUS_EQUAL) reduce 290) ((T_POW) reduce 290) ((T_POW_EQUAL) reduce 290) ((T_SL) reduce 290) ((T_SL_EQUAL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) ((T_SR_EQUAL) reduce 290) ((T_XOR_EQUAL) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 10052 ((("%") reduce 388) (("*") reduce 388) (("+") reduce 388) (("-") reduce 388) ((".") reduce 388) (("/") reduce 388) ((":") reduce 388) (("<") reduce 388) ((">") reduce 388) (("?") reduce 388) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_BOOLEAN_AND) reduce 388) ((T_BOOLEAN_OR) reduce 388) ((T_COALESCE) reduce 388) ((T_DOUBLE_ARROW) reduce 388) ((T_INSTANCEOF) reduce 388) ((T_IS_EQUAL) reduce 388) ((T_IS_GREATER_OR_EQUAL) reduce 388) ((T_IS_IDENTICAL) reduce 388) ((T_IS_NOT_EQUAL) reduce 388) ((T_IS_NOT_IDENTICAL) reduce 388) ((T_IS_SMALLER_OR_EQUAL) reduce 388) ((T_LOGICAL_AND) reduce 388) ((T_LOGICAL_OR) reduce 388) ((T_LOGICAL_XOR) reduce 388) ((T_POW) reduce 388) ((T_SL) reduce 388) ((T_SPACESHIP) reduce 388) ((T_SR) reduce 388) (("^") reduce 388) (("|") reduce 388)) 10054 ((("%") reduce 386) (("*") reduce 386) (("+") reduce 386) (("-") reduce 386) ((".") reduce 386) (("/") reduce 386) ((":") reduce 386) (("<") reduce 386) ((">") reduce 386) (("?") reduce 386) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_BOOLEAN_AND) reduce 386) ((T_BOOLEAN_OR) reduce 386) ((T_COALESCE) reduce 386) ((T_DOUBLE_ARROW) reduce 386) ((T_INSTANCEOF) reduce 386) ((T_IS_EQUAL) reduce 386) ((T_IS_GREATER_OR_EQUAL) reduce 386) ((T_IS_IDENTICAL) reduce 386) ((T_IS_NOT_EQUAL) reduce 386) ((T_IS_NOT_IDENTICAL) reduce 386) ((T_IS_SMALLER_OR_EQUAL) reduce 386) ((T_LOGICAL_AND) reduce 386) ((T_LOGICAL_OR) reduce 386) ((T_LOGICAL_XOR) reduce 386) ((T_POW) reduce 386) ((T_SL) reduce 386) ((T_SPACESHIP) reduce 386) ((T_SR) reduce 386) (("^") reduce 386) (("|") reduce 386)) 10064 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 382) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 382) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 382) ((T_LOGICAL_OR) reduce 382) ((T_LOGICAL_XOR) reduce 382) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 10065 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 384) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 384) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 384) ((T_LOGICAL_OR) reduce 384) ((T_LOGICAL_XOR) reduce 384) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 10066 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 383) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 383) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 383) ((T_LOGICAL_OR) reduce 383) ((T_LOGICAL_XOR) reduce 383) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 10067 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 376) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 376) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 376) ((T_LOGICAL_OR) reduce 376) ((T_LOGICAL_XOR) reduce 376) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 10068 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 373) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 373) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 373) ((T_LOGICAL_OR) reduce 373) ((T_LOGICAL_XOR) reduce 373) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 10069 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 381) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 381) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 381) ((T_LOGICAL_OR) reduce 381) ((T_LOGICAL_XOR) reduce 381) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 10070 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 375) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 375) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 375) ((T_LOGICAL_OR) reduce 375) ((T_LOGICAL_XOR) reduce 375) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 10071 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 379) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 379) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 379) ((T_LOGICAL_OR) reduce 379) ((T_LOGICAL_XOR) reduce 379) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 10072 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 374) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 374) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 374) ((T_LOGICAL_OR) reduce 374) ((T_LOGICAL_XOR) reduce 374) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 10073 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 377) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 377) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 377) ((T_LOGICAL_OR) reduce 377) ((T_LOGICAL_XOR) reduce 377) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 10074 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 378) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 378) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 378) ((T_LOGICAL_OR) reduce 378) ((T_LOGICAL_XOR) reduce 378) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 10075 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 385) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 385) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 385) ((T_LOGICAL_OR) reduce 385) ((T_LOGICAL_XOR) reduce 385) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 10076 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 380) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 380) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 380) ((T_LOGICAL_OR) reduce 380) ((T_LOGICAL_XOR) reduce 380) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 10078 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 370) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 370) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 370) ((T_LOGICAL_OR) reduce 370) ((T_LOGICAL_XOR) reduce 370) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 10081 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) ((":") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 10084 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) ((":") reduce 525) (("<") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_DOUBLE_ARROW) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_POW) reduce 525) ((T_SL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 10086 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) ((":") reduce 524) (("<") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_DOUBLE_ARROW) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_POW) reduce 524) ((T_SL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 10088 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) ((":") reduce 519) (("<") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_DOUBLE_ARROW) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_POW) reduce 519) ((T_SL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 10089 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) ((":") reduce 526) (("<") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_DOUBLE_ARROW) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_POW) reduce 526) ((T_SL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 10090 ((("%") reduce 371) (("*") reduce 371) (("+") reduce 371) (("-") reduce 371) ((".") reduce 371) (("/") reduce 371) ((":") reduce 371) (("<") reduce 371) ((">") reduce 371) (("?") reduce 371) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_BOOLEAN_AND) reduce 371) ((T_BOOLEAN_OR) reduce 371) ((T_COALESCE) reduce 371) ((T_DOUBLE_ARROW) reduce 371) ((T_INSTANCEOF) reduce 371) ((T_IS_EQUAL) reduce 371) ((T_IS_GREATER_OR_EQUAL) reduce 371) ((T_IS_IDENTICAL) reduce 371) ((T_IS_NOT_EQUAL) reduce 371) ((T_IS_NOT_IDENTICAL) reduce 371) ((T_IS_SMALLER_OR_EQUAL) reduce 371) ((T_LOGICAL_AND) reduce 371) ((T_LOGICAL_OR) reduce 371) ((T_LOGICAL_XOR) reduce 371) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 371) ((T_SL) reduce 371) ((T_SPACESHIP) reduce 371) ((T_SR) reduce 371) (("[") reduce 510) (("^") reduce 371) (("{") reduce 510) (("|") reduce 371)) 10094 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) ((":") reduce 533) (("<") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_DOUBLE_ARROW) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_POW) reduce 533) ((T_SL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 10096 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) ((":") reduce 468) (("<") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_DOUBLE_ARROW) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_POW) reduce 468) ((T_SL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 10097 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) ((":") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 10101 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) ((":") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 10102 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) ((":") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 10103 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) ((":") reduce 465) (("<") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_DOUBLE_ARROW) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_POW) reduce 465) ((T_SL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 10106 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) ((":") reduce 532) (("<") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_DOUBLE_ARROW) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_POW) reduce 532) ((T_SL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 10107 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) ((":") reduce 467) (("<") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_DOUBLE_ARROW) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_POW) reduce 467) ((T_SL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 10108 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) ((":") reduce 469) (("<") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_DOUBLE_ARROW) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_POW) reduce 469) ((T_SL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 10114 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) ((":") reduce 521) (("<") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_DOUBLE_ARROW) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_POW) reduce 521) ((T_SL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 10116 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) ((":") reduce 520) (("<") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_DOUBLE_ARROW) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_POW) reduce 520) ((T_SL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 10117 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) ((":") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 10118 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) ((":") reduce 527) (("<") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_DOUBLE_ARROW) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_POW) reduce 527) ((T_SL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 10119 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) ((":") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 10122 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) ((":") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 10123 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) ((":") reduce 522) (("<") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_DOUBLE_ARROW) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_POW) reduce 522) ((T_SL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 10124 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) ((":") reduce 528) (("<") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_DOUBLE_ARROW) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_POW) reduce 528) ((T_SL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 10125 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) ((":") reduce 523) (("<") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_DOUBLE_ARROW) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_POW) reduce 523) ((T_SL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 10126 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) ((":") reduce 466) (("<") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_DOUBLE_ARROW) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_POW) reduce 466) ((T_SL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 10127 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) ((":") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 10130 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) ((":") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 10131 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) ((":") reduce 465) (("<") reduce 465) (("=") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AND_EQUAL) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_COALESCE_EQUAL) reduce 465) ((T_CONCAT_EQUAL) reduce 465) ((T_DEC) reduce 465) ((T_DIV_EQUAL) reduce 465) ((T_DOUBLE_ARROW) reduce 465) ((T_INC) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_MINUS_EQUAL) reduce 465) ((T_MOD_EQUAL) reduce 465) ((T_MUL_EQUAL) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_OR_EQUAL) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_PLUS_EQUAL) reduce 465) ((T_POW) reduce 465) ((T_POW_EQUAL) reduce 465) ((T_SL) reduce 465) ((T_SL_EQUAL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) ((T_SR_EQUAL) reduce 465) ((T_XOR_EQUAL) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 10142 ((("%") reduce 455) (("*") reduce 455) (("+") reduce 455) (("-") reduce 455) ((".") reduce 455) (("/") reduce 455) ((":") reduce 455) (("<") reduce 455) ((">") reduce 455) (("?") reduce 455) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_BOOLEAN_AND) reduce 455) ((T_BOOLEAN_OR) reduce 455) ((T_COALESCE) reduce 455) ((T_DOUBLE_ARROW) reduce 455) ((T_INSTANCEOF) reduce 455) ((T_IS_EQUAL) reduce 455) ((T_IS_GREATER_OR_EQUAL) reduce 455) ((T_IS_IDENTICAL) reduce 455) ((T_IS_NOT_EQUAL) reduce 455) ((T_IS_NOT_IDENTICAL) reduce 455) ((T_IS_SMALLER_OR_EQUAL) reduce 455) ((T_LOGICAL_AND) reduce 455) ((T_LOGICAL_OR) reduce 455) ((T_LOGICAL_XOR) reduce 455) ((T_POW) reduce 455) ((T_SL) reduce 455) ((T_SPACESHIP) reduce 455) ((T_SR) reduce 455) (("^") reduce 455) (("|") reduce 455)) 10143 ((("%") reduce 450) (("*") reduce 450) (("+") reduce 450) (("-") reduce 450) ((".") reduce 450) (("/") reduce 450) ((":") reduce 450) (("<") reduce 450) ((">") reduce 450) (("?") reduce 450) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_BOOLEAN_AND) reduce 450) ((T_BOOLEAN_OR) reduce 450) ((T_COALESCE) reduce 450) ((T_DOUBLE_ARROW) reduce 450) ((T_INSTANCEOF) reduce 450) ((T_IS_EQUAL) reduce 450) ((T_IS_GREATER_OR_EQUAL) reduce 450) ((T_IS_IDENTICAL) reduce 450) ((T_IS_NOT_EQUAL) reduce 450) ((T_IS_NOT_IDENTICAL) reduce 450) ((T_IS_SMALLER_OR_EQUAL) reduce 450) ((T_LOGICAL_AND) reduce 450) ((T_LOGICAL_OR) reduce 450) ((T_LOGICAL_XOR) reduce 450) ((T_POW) reduce 450) ((T_SL) reduce 450) ((T_SPACESHIP) reduce 450) ((T_SR) reduce 450) (("^") reduce 450) (("|") reduce 450)) 10153 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 455) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 455) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 10154 ((("%") reduce 451) (("*") reduce 451) (("+") reduce 451) (("-") reduce 451) ((".") reduce 451) (("/") reduce 451) ((":") reduce 451) (("<") reduce 451) ((">") reduce 451) (("?") reduce 451) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_BOOLEAN_AND) reduce 451) ((T_BOOLEAN_OR) reduce 451) ((T_COALESCE) reduce 451) ((T_DOUBLE_ARROW) reduce 451) ((T_INSTANCEOF) reduce 451) ((T_IS_EQUAL) reduce 451) ((T_IS_GREATER_OR_EQUAL) reduce 451) ((T_IS_IDENTICAL) reduce 451) ((T_IS_NOT_EQUAL) reduce 451) ((T_IS_NOT_IDENTICAL) reduce 451) ((T_IS_SMALLER_OR_EQUAL) reduce 451) ((T_LOGICAL_AND) reduce 451) ((T_LOGICAL_OR) reduce 451) ((T_LOGICAL_XOR) reduce 451) ((T_POW) reduce 451) ((T_SL) reduce 451) ((T_SPACESHIP) reduce 451) ((T_SR) reduce 451) (("^") reduce 451) (("|") reduce 451)) 10156 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 442) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 442) ((T_LOGICAL_OR) reduce 442) ((T_LOGICAL_XOR) reduce 442) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 10158 ((("%") reduce 503) (("(") reduce 541) (("*") reduce 503) (("+") reduce 503) (("-") reduce 503) ((".") reduce 503) (("/") reduce 503) ((":") reduce 503) (("<") reduce 503) ((">") reduce 503) (("?") reduce 503) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_BOOLEAN_AND) reduce 503) ((T_BOOLEAN_OR) reduce 503) ((T_COALESCE) reduce 503) ((T_DOUBLE_ARROW) reduce 503) ((T_INSTANCEOF) reduce 503) ((T_IS_EQUAL) reduce 503) ((T_IS_GREATER_OR_EQUAL) reduce 503) ((T_IS_IDENTICAL) reduce 503) ((T_IS_NOT_EQUAL) reduce 503) ((T_IS_NOT_IDENTICAL) reduce 503) ((T_IS_SMALLER_OR_EQUAL) reduce 503) ((T_LOGICAL_AND) reduce 503) ((T_LOGICAL_OR) reduce 503) ((T_LOGICAL_XOR) reduce 503) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 503) ((T_OBJECT_OPERATOR) reduce 503) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 503) ((T_POW) reduce 503) ((T_SL) reduce 503) ((T_SPACESHIP) reduce 503) ((T_SR) reduce 503) (("[") reduce 503) (("^") reduce 503) (("{") reduce 503) (("|") reduce 503)) 10160 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) ((":") reduce 532) (("<") reduce 532) (("=") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AND_EQUAL) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_COALESCE_EQUAL) reduce 532) ((T_CONCAT_EQUAL) reduce 532) ((T_DEC) reduce 532) ((T_DIV_EQUAL) reduce 532) ((T_DOUBLE_ARROW) reduce 532) ((T_INC) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_MINUS_EQUAL) reduce 532) ((T_MOD_EQUAL) reduce 532) ((T_MUL_EQUAL) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_OR_EQUAL) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_PLUS_EQUAL) reduce 532) ((T_POW) reduce 532) ((T_POW_EQUAL) reduce 532) ((T_SL) reduce 532) ((T_SL_EQUAL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) ((T_SR_EQUAL) reduce 532) ((T_XOR_EQUAL) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 10163 ((("%") reduce 505) (("(") reduce 542) (("*") reduce 505) (("+") reduce 505) (("-") reduce 505) ((".") reduce 505) (("/") reduce 505) ((":") reduce 505) (("<") reduce 505) ((">") reduce 505) (("?") reduce 505) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_BOOLEAN_AND) reduce 505) ((T_BOOLEAN_OR) reduce 505) ((T_COALESCE) reduce 505) ((T_DOUBLE_ARROW) reduce 505) ((T_INSTANCEOF) reduce 505) ((T_IS_EQUAL) reduce 505) ((T_IS_GREATER_OR_EQUAL) reduce 505) ((T_IS_IDENTICAL) reduce 505) ((T_IS_NOT_EQUAL) reduce 505) ((T_IS_NOT_IDENTICAL) reduce 505) ((T_IS_SMALLER_OR_EQUAL) reduce 505) ((T_LOGICAL_AND) reduce 505) ((T_LOGICAL_OR) reduce 505) ((T_LOGICAL_XOR) reduce 505) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 505) ((T_OBJECT_OPERATOR) reduce 505) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 505) ((T_POW) reduce 505) ((T_SL) reduce 505) ((T_SPACESHIP) reduce 505) ((T_SR) reduce 505) (("[") reduce 505) (("^") reduce 505) (("{") reduce 505) (("|") reduce 505)) 10164 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) ((":") reduce 467) (("<") reduce 467) (("=") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AND_EQUAL) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_COALESCE_EQUAL) reduce 467) ((T_CONCAT_EQUAL) reduce 467) ((T_DEC) reduce 467) ((T_DIV_EQUAL) reduce 467) ((T_DOUBLE_ARROW) reduce 467) ((T_INC) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_MINUS_EQUAL) reduce 467) ((T_MOD_EQUAL) reduce 467) ((T_MUL_EQUAL) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_OR_EQUAL) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_PLUS_EQUAL) reduce 467) ((T_POW) reduce 467) ((T_POW_EQUAL) reduce 467) ((T_SL) reduce 467) ((T_SL_EQUAL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) ((T_SR_EQUAL) reduce 467) ((T_XOR_EQUAL) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 10165 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) ((":") reduce 469) (("<") reduce 469) (("=") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AND_EQUAL) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_COALESCE_EQUAL) reduce 469) ((T_CONCAT_EQUAL) reduce 469) ((T_DEC) reduce 469) ((T_DIV_EQUAL) reduce 469) ((T_DOUBLE_ARROW) reduce 469) ((T_INC) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_MINUS_EQUAL) reduce 469) ((T_MOD_EQUAL) reduce 469) ((T_MUL_EQUAL) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_OR_EQUAL) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_PLUS_EQUAL) reduce 469) ((T_POW) reduce 469) ((T_POW_EQUAL) reduce 469) ((T_SL) reduce 469) ((T_SL_EQUAL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) ((T_SR_EQUAL) reduce 469) ((T_XOR_EQUAL) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 10167 ((("%") reduce 446) (("*") reduce 446) (("+") reduce 446) (("-") reduce 446) ((".") reduce 446) (("/") reduce 446) ((":") reduce 446) (("<") reduce 446) ((">") reduce 446) (("?") reduce 446) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_BOOLEAN_AND) reduce 446) ((T_BOOLEAN_OR) reduce 446) ((T_COALESCE) reduce 446) ((T_DOUBLE_ARROW) reduce 446) ((T_INSTANCEOF) reduce 446) ((T_IS_EQUAL) reduce 446) ((T_IS_GREATER_OR_EQUAL) reduce 446) ((T_IS_IDENTICAL) reduce 446) ((T_IS_NOT_EQUAL) reduce 446) ((T_IS_NOT_IDENTICAL) reduce 446) ((T_IS_SMALLER_OR_EQUAL) reduce 446) ((T_LOGICAL_AND) reduce 446) ((T_LOGICAL_OR) reduce 446) ((T_LOGICAL_XOR) reduce 446) ((T_POW) reduce 446) ((T_SL) reduce 446) ((T_SPACESHIP) reduce 446) ((T_SR) reduce 446) (("^") reduce 446) (("|") reduce 446)) 10168 ((("%") reduce 448) (("*") reduce 448) (("+") reduce 448) (("-") reduce 448) ((".") reduce 448) (("/") reduce 448) ((":") reduce 448) (("<") reduce 448) ((">") reduce 448) (("?") reduce 448) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_BOOLEAN_AND) reduce 448) ((T_BOOLEAN_OR) reduce 448) ((T_COALESCE) reduce 448) ((T_DOUBLE_ARROW) reduce 448) ((T_INSTANCEOF) reduce 448) ((T_IS_EQUAL) reduce 448) ((T_IS_GREATER_OR_EQUAL) reduce 448) ((T_IS_IDENTICAL) reduce 448) ((T_IS_NOT_EQUAL) reduce 448) ((T_IS_NOT_IDENTICAL) reduce 448) ((T_IS_SMALLER_OR_EQUAL) reduce 448) ((T_LOGICAL_AND) reduce 448) ((T_LOGICAL_OR) reduce 448) ((T_LOGICAL_XOR) reduce 448) ((T_POW) reduce 448) ((T_SL) reduce 448) ((T_SPACESHIP) reduce 448) ((T_SR) reduce 448) (("^") reduce 448) (("|") reduce 448)) 10174 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) ((":") reduce 521) (("<") reduce 521) (("=") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AND_EQUAL) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_COALESCE_EQUAL) reduce 521) ((T_CONCAT_EQUAL) reduce 521) ((T_DEC) reduce 521) ((T_DIV_EQUAL) reduce 521) ((T_DOUBLE_ARROW) reduce 521) ((T_INC) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_MINUS_EQUAL) reduce 521) ((T_MOD_EQUAL) reduce 521) ((T_MUL_EQUAL) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_OR_EQUAL) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_PLUS_EQUAL) reduce 521) ((T_POW) reduce 521) ((T_POW_EQUAL) reduce 521) ((T_SL) reduce 521) ((T_SL_EQUAL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) ((T_SR_EQUAL) reduce 521) ((T_XOR_EQUAL) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 10176 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) ((":") reduce 520) (("<") reduce 520) (("=") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AND_EQUAL) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_COALESCE_EQUAL) reduce 520) ((T_CONCAT_EQUAL) reduce 520) ((T_DEC) reduce 520) ((T_DIV_EQUAL) reduce 520) ((T_DOUBLE_ARROW) reduce 520) ((T_INC) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_MINUS_EQUAL) reduce 520) ((T_MOD_EQUAL) reduce 520) ((T_MUL_EQUAL) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_OR_EQUAL) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_PLUS_EQUAL) reduce 520) ((T_POW) reduce 520) ((T_POW_EQUAL) reduce 520) ((T_SL) reduce 520) ((T_SL_EQUAL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) ((T_SR_EQUAL) reduce 520) ((T_XOR_EQUAL) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 10177 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) ((":") reduce 544) (("<") reduce 544) (("=") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AND_EQUAL) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_COALESCE_EQUAL) reduce 544) ((T_CONCAT_EQUAL) reduce 544) ((T_DEC) reduce 544) ((T_DIV_EQUAL) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INC) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_MINUS_EQUAL) reduce 544) ((T_MOD_EQUAL) reduce 544) ((T_MUL_EQUAL) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_OR_EQUAL) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_PLUS_EQUAL) reduce 544) ((T_POW) reduce 544) ((T_POW_EQUAL) reduce 544) ((T_SL) reduce 544) ((T_SL_EQUAL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) ((T_SR_EQUAL) reduce 544) ((T_XOR_EQUAL) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 10178 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) ((":") reduce 527) (("<") reduce 527) (("=") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AND_EQUAL) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_COALESCE_EQUAL) reduce 527) ((T_CONCAT_EQUAL) reduce 527) ((T_DEC) reduce 527) ((T_DIV_EQUAL) reduce 527) ((T_DOUBLE_ARROW) reduce 527) ((T_INC) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_MINUS_EQUAL) reduce 527) ((T_MOD_EQUAL) reduce 527) ((T_MUL_EQUAL) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_OR_EQUAL) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_PLUS_EQUAL) reduce 527) ((T_POW) reduce 527) ((T_POW_EQUAL) reduce 527) ((T_SL) reduce 527) ((T_SL_EQUAL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) ((T_SR_EQUAL) reduce 527) ((T_XOR_EQUAL) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 10179 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) ((":") reduce 546) (("<") reduce 546) (("=") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AND_EQUAL) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_COALESCE_EQUAL) reduce 546) ((T_CONCAT_EQUAL) reduce 546) ((T_DEC) reduce 546) ((T_DIV_EQUAL) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INC) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_MINUS_EQUAL) reduce 546) ((T_MOD_EQUAL) reduce 546) ((T_MUL_EQUAL) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_OR_EQUAL) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_PLUS_EQUAL) reduce 546) ((T_POW) reduce 546) ((T_POW_EQUAL) reduce 546) ((T_SL) reduce 546) ((T_SL_EQUAL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) ((T_SR_EQUAL) reduce 546) ((T_XOR_EQUAL) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 10182 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) ((":") reduce 545) (("<") reduce 545) (("=") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AND_EQUAL) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_COALESCE_EQUAL) reduce 545) ((T_CONCAT_EQUAL) reduce 545) ((T_DEC) reduce 545) ((T_DIV_EQUAL) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INC) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_MINUS_EQUAL) reduce 545) ((T_MOD_EQUAL) reduce 545) ((T_MUL_EQUAL) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_OR_EQUAL) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_PLUS_EQUAL) reduce 545) ((T_POW) reduce 545) ((T_POW_EQUAL) reduce 545) ((T_SL) reduce 545) ((T_SL_EQUAL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) ((T_SR_EQUAL) reduce 545) ((T_XOR_EQUAL) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 10183 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) ((":") reduce 522) (("<") reduce 522) (("=") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AND_EQUAL) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_COALESCE_EQUAL) reduce 522) ((T_CONCAT_EQUAL) reduce 522) ((T_DEC) reduce 522) ((T_DIV_EQUAL) reduce 522) ((T_DOUBLE_ARROW) reduce 522) ((T_INC) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_MINUS_EQUAL) reduce 522) ((T_MOD_EQUAL) reduce 522) ((T_MUL_EQUAL) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_OR_EQUAL) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_PLUS_EQUAL) reduce 522) ((T_POW) reduce 522) ((T_POW_EQUAL) reduce 522) ((T_SL) reduce 522) ((T_SL_EQUAL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) ((T_SR_EQUAL) reduce 522) ((T_XOR_EQUAL) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 10184 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) ((":") reduce 528) (("<") reduce 528) (("=") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AND_EQUAL) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_COALESCE_EQUAL) reduce 528) ((T_CONCAT_EQUAL) reduce 528) ((T_DEC) reduce 528) ((T_DIV_EQUAL) reduce 528) ((T_DOUBLE_ARROW) reduce 528) ((T_INC) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_MINUS_EQUAL) reduce 528) ((T_MOD_EQUAL) reduce 528) ((T_MUL_EQUAL) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_OR_EQUAL) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_PLUS_EQUAL) reduce 528) ((T_POW) reduce 528) ((T_POW_EQUAL) reduce 528) ((T_SL) reduce 528) ((T_SL_EQUAL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) ((T_SR_EQUAL) reduce 528) ((T_XOR_EQUAL) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 10185 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) ((":") reduce 523) (("<") reduce 523) (("=") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AND_EQUAL) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_COALESCE_EQUAL) reduce 523) ((T_CONCAT_EQUAL) reduce 523) ((T_DEC) reduce 523) ((T_DIV_EQUAL) reduce 523) ((T_DOUBLE_ARROW) reduce 523) ((T_INC) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_MINUS_EQUAL) reduce 523) ((T_MOD_EQUAL) reduce 523) ((T_MUL_EQUAL) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_OR_EQUAL) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_PLUS_EQUAL) reduce 523) ((T_POW) reduce 523) ((T_POW_EQUAL) reduce 523) ((T_SL) reduce 523) ((T_SL_EQUAL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) ((T_SR_EQUAL) reduce 523) ((T_XOR_EQUAL) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 10187 ((("%") reduce 438) (("*") reduce 438) (("+") reduce 438) (("-") reduce 438) ((".") reduce 438) (("/") reduce 438) ((":") reduce 438) (("<") reduce 438) ((">") reduce 438) (("?") reduce 438) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_BOOLEAN_AND) reduce 438) ((T_BOOLEAN_OR) reduce 438) ((T_COALESCE) reduce 438) ((T_DOUBLE_ARROW) reduce 438) ((T_INSTANCEOF) reduce 438) ((T_IS_EQUAL) reduce 438) ((T_IS_GREATER_OR_EQUAL) reduce 438) ((T_IS_IDENTICAL) reduce 438) ((T_IS_NOT_EQUAL) reduce 438) ((T_IS_NOT_IDENTICAL) reduce 438) ((T_IS_SMALLER_OR_EQUAL) reduce 438) ((T_LOGICAL_AND) reduce 438) ((T_LOGICAL_OR) reduce 438) ((T_LOGICAL_XOR) reduce 438) ((T_POW) reduce 438) ((T_SL) reduce 438) ((T_SPACESHIP) reduce 438) ((T_SR) reduce 438) (("^") reduce 438) (("|") reduce 438)) 10189 ((("%") reduce 483) (("(") reduce 483) (("*") reduce 483) (("+") reduce 483) (("-") reduce 483) ((".") reduce 483) (("/") reduce 483) ((":") reduce 483) (("<") reduce 483) (("=") shift) ((">") reduce 483) (("?") reduce 483) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_BOOLEAN_AND) reduce 483) ((T_BOOLEAN_OR) reduce 483) ((T_COALESCE) reduce 483) ((T_DOUBLE_ARROW) reduce 483) ((T_INSTANCEOF) reduce 483) ((T_IS_EQUAL) reduce 483) ((T_IS_GREATER_OR_EQUAL) reduce 483) ((T_IS_IDENTICAL) reduce 483) ((T_IS_NOT_EQUAL) reduce 483) ((T_IS_NOT_IDENTICAL) reduce 483) ((T_IS_SMALLER_OR_EQUAL) reduce 483) ((T_LOGICAL_AND) reduce 483) ((T_LOGICAL_OR) reduce 483) ((T_LOGICAL_XOR) reduce 483) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 483) ((T_OBJECT_OPERATOR) reduce 483) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 483) ((T_POW) reduce 483) ((T_SL) reduce 483) ((T_SPACESHIP) reduce 483) ((T_SR) reduce 483) (("[") reduce 483) (("^") reduce 483) (("{") reduce 483) (("|") reduce 483)) 10191 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 369) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 369) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 369) ((T_LOGICAL_OR) reduce 369) ((T_LOGICAL_XOR) reduce 369) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 10192 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 443) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 443) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 443) ((T_LOGICAL_OR) reduce 443) ((T_LOGICAL_XOR) reduce 443) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 10195 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 442) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 442) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 442) ((T_LOGICAL_OR) reduce 442) ((T_LOGICAL_XOR) reduce 442) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 10196 ((("%") reduce 434) (("*") reduce 434) (("+") reduce 434) (("-") reduce 434) ((".") reduce 434) (("/") reduce 434) ((":") reduce 434) (("<") reduce 434) ((">") reduce 434) (("?") reduce 434) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_BOOLEAN_AND) reduce 434) ((T_BOOLEAN_OR) reduce 434) ((T_COALESCE) reduce 434) ((T_DOUBLE_ARROW) reduce 434) ((T_INSTANCEOF) reduce 434) ((T_IS_EQUAL) reduce 434) ((T_IS_GREATER_OR_EQUAL) reduce 434) ((T_IS_IDENTICAL) reduce 434) ((T_IS_NOT_EQUAL) reduce 434) ((T_IS_NOT_IDENTICAL) reduce 434) ((T_IS_SMALLER_OR_EQUAL) reduce 434) ((T_LOGICAL_AND) reduce 434) ((T_LOGICAL_OR) reduce 434) ((T_LOGICAL_XOR) reduce 434) ((T_POW) shift) ((T_SL) reduce 434) ((T_SPACESHIP) reduce 434) ((T_SR) reduce 434) (("^") reduce 434) (("|") reduce 434)) 10197 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 444) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 444) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 10198 ((("%") reduce 430) (("*") reduce 430) (("+") reduce 430) (("-") reduce 430) ((".") reduce 430) (("/") reduce 430) ((":") reduce 430) (("<") reduce 430) ((">") reduce 430) (("?") reduce 430) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_BOOLEAN_AND) reduce 430) ((T_BOOLEAN_OR) reduce 430) ((T_COALESCE) reduce 430) ((T_DOUBLE_ARROW) reduce 430) ((T_INSTANCEOF) reduce 430) ((T_IS_EQUAL) reduce 430) ((T_IS_GREATER_OR_EQUAL) reduce 430) ((T_IS_IDENTICAL) reduce 430) ((T_IS_NOT_EQUAL) reduce 430) ((T_IS_NOT_IDENTICAL) reduce 430) ((T_IS_SMALLER_OR_EQUAL) reduce 430) ((T_LOGICAL_AND) reduce 430) ((T_LOGICAL_OR) reduce 430) ((T_LOGICAL_XOR) reduce 430) ((T_POW) shift) ((T_SL) reduce 430) ((T_SPACESHIP) reduce 430) ((T_SR) reduce 430) (("^") reduce 430) (("|") reduce 430)) 10199 ((("%") reduce 447) (("*") reduce 447) (("+") reduce 447) (("-") reduce 447) ((".") reduce 447) (("/") reduce 447) ((":") reduce 447) (("<") reduce 447) ((">") reduce 447) (("?") reduce 447) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_BOOLEAN_AND) reduce 447) ((T_BOOLEAN_OR) reduce 447) ((T_COALESCE) reduce 447) ((T_DOUBLE_ARROW) reduce 447) ((T_INSTANCEOF) reduce 447) ((T_IS_EQUAL) reduce 447) ((T_IS_GREATER_OR_EQUAL) reduce 447) ((T_IS_IDENTICAL) reduce 447) ((T_IS_NOT_EQUAL) reduce 447) ((T_IS_NOT_IDENTICAL) reduce 447) ((T_IS_SMALLER_OR_EQUAL) reduce 447) ((T_LOGICAL_AND) reduce 447) ((T_LOGICAL_OR) reduce 447) ((T_LOGICAL_XOR) reduce 447) ((T_POW) reduce 447) ((T_SL) reduce 447) ((T_SPACESHIP) reduce 447) ((T_SR) reduce 447) (("^") reduce 447) (("|") reduce 447)) 10201 ((("%") reduce 489) (("*") reduce 489) (("+") reduce 489) (("-") reduce 489) ((".") reduce 489) (("/") reduce 489) ((":") reduce 489) (("<") reduce 489) ((">") reduce 489) (("?") reduce 489) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_BOOLEAN_AND) reduce 489) ((T_BOOLEAN_OR) reduce 489) ((T_COALESCE) reduce 489) ((T_DOUBLE_ARROW) reduce 489) ((T_INSTANCEOF) reduce 489) ((T_IS_EQUAL) reduce 489) ((T_IS_GREATER_OR_EQUAL) reduce 489) ((T_IS_IDENTICAL) reduce 489) ((T_IS_NOT_EQUAL) reduce 489) ((T_IS_NOT_IDENTICAL) reduce 489) ((T_IS_SMALLER_OR_EQUAL) reduce 489) ((T_LOGICAL_AND) reduce 489) ((T_LOGICAL_OR) reduce 489) ((T_LOGICAL_XOR) reduce 489) ((T_POW) reduce 489) ((T_SL) reduce 489) ((T_SPACESHIP) reduce 489) ((T_SR) reduce 489) (("^") reduce 489) (("|") reduce 489)) 10203 ((("%") reduce 490) (("*") reduce 490) (("+") reduce 490) (("-") reduce 490) ((".") reduce 490) (("/") reduce 490) ((":") reduce 490) (("<") reduce 490) ((">") reduce 490) (("?") reduce 490) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_BOOLEAN_AND) reduce 490) ((T_BOOLEAN_OR) reduce 490) ((T_COALESCE) reduce 490) ((T_DOUBLE_ARROW) reduce 490) ((T_INSTANCEOF) reduce 490) ((T_IS_EQUAL) reduce 490) ((T_IS_GREATER_OR_EQUAL) reduce 490) ((T_IS_IDENTICAL) reduce 490) ((T_IS_NOT_EQUAL) reduce 490) ((T_IS_NOT_IDENTICAL) reduce 490) ((T_IS_SMALLER_OR_EQUAL) reduce 490) ((T_LOGICAL_AND) reduce 490) ((T_LOGICAL_OR) reduce 490) ((T_LOGICAL_XOR) reduce 490) ((T_POW) reduce 490) ((T_SL) reduce 490) ((T_SPACESHIP) reduce 490) ((T_SR) reduce 490) (("^") reduce 490) (("|") reduce 490)) 10204 ((("%") reduce 488) (("*") reduce 488) (("+") reduce 488) (("-") reduce 488) ((".") reduce 488) (("/") reduce 488) ((":") reduce 488) (("<") reduce 488) ((">") reduce 488) (("?") reduce 488) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_BOOLEAN_AND) reduce 488) ((T_BOOLEAN_OR) reduce 488) ((T_COALESCE) reduce 488) ((T_DOUBLE_ARROW) reduce 488) ((T_INSTANCEOF) reduce 488) ((T_IS_EQUAL) reduce 488) ((T_IS_GREATER_OR_EQUAL) reduce 488) ((T_IS_IDENTICAL) reduce 488) ((T_IS_NOT_EQUAL) reduce 488) ((T_IS_NOT_IDENTICAL) reduce 488) ((T_IS_SMALLER_OR_EQUAL) reduce 488) ((T_LOGICAL_AND) reduce 488) ((T_LOGICAL_OR) reduce 488) ((T_LOGICAL_XOR) reduce 488) ((T_POW) reduce 488) ((T_SL) reduce 488) ((T_SPACESHIP) reduce 488) ((T_SR) reduce 488) (("^") reduce 488) (("|") reduce 488)) 10205 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 581) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 581) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 10206 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 580) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 580) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 10207 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) ((":") reduce 466) (("<") reduce 466) (("=") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AND_EQUAL) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_COALESCE_EQUAL) reduce 466) ((T_CONCAT_EQUAL) reduce 466) ((T_DEC) reduce 466) ((T_DIV_EQUAL) reduce 466) ((T_DOUBLE_ARROW) reduce 466) ((T_INC) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_MINUS_EQUAL) reduce 466) ((T_MOD_EQUAL) reduce 466) ((T_MUL_EQUAL) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_OR_EQUAL) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_PLUS_EQUAL) reduce 466) ((T_POW) reduce 466) ((T_POW_EQUAL) reduce 466) ((T_SL) reduce 466) ((T_SL_EQUAL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) ((T_SR_EQUAL) reduce 466) ((T_XOR_EQUAL) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 10208 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 439) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 439) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 439) ((T_LOGICAL_OR) reduce 439) ((T_LOGICAL_XOR) reduce 439) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 10209 ((("%") reduce 432) (("*") reduce 432) (("+") reduce 432) (("-") reduce 432) ((".") reduce 432) (("/") reduce 432) ((":") reduce 432) (("<") reduce 432) ((">") reduce 432) (("?") reduce 432) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_BOOLEAN_AND) reduce 432) ((T_BOOLEAN_OR) reduce 432) ((T_COALESCE) reduce 432) ((T_DOUBLE_ARROW) reduce 432) ((T_INSTANCEOF) reduce 432) ((T_IS_EQUAL) reduce 432) ((T_IS_GREATER_OR_EQUAL) reduce 432) ((T_IS_IDENTICAL) reduce 432) ((T_IS_NOT_EQUAL) reduce 432) ((T_IS_NOT_IDENTICAL) reduce 432) ((T_IS_SMALLER_OR_EQUAL) reduce 432) ((T_LOGICAL_AND) reduce 432) ((T_LOGICAL_OR) reduce 432) ((T_LOGICAL_XOR) reduce 432) ((T_POW) shift) ((T_SL) reduce 432) ((T_SPACESHIP) reduce 432) ((T_SR) reduce 432) (("^") reduce 432) (("|") reduce 432)) 10211 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) ((":") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93)) 10212 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) ((":") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92)) 10213 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) ((":") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94)) 10214 ((("%") reduce 470) (("(") reduce 470) (("*") reduce 470) (("+") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) ((":") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_DOUBLE_ARROW) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470)) 10215 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) ((":") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91)) 10216 ((("%") reduce 365) (("*") reduce 365) (("+") reduce 365) (("-") reduce 365) ((".") reduce 365) (("/") reduce 365) ((":") reduce 365) (("<") reduce 365) ((">") reduce 365) (("?") reduce 365) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_BOOLEAN_AND) reduce 365) ((T_BOOLEAN_OR) reduce 365) ((T_COALESCE) reduce 365) ((T_DOUBLE_ARROW) reduce 365) ((T_INSTANCEOF) reduce 365) ((T_IS_EQUAL) reduce 365) ((T_IS_GREATER_OR_EQUAL) reduce 365) ((T_IS_IDENTICAL) reduce 365) ((T_IS_NOT_EQUAL) reduce 365) ((T_IS_NOT_IDENTICAL) reduce 365) ((T_IS_SMALLER_OR_EQUAL) reduce 365) ((T_LOGICAL_AND) reduce 365) ((T_LOGICAL_OR) reduce 365) ((T_LOGICAL_XOR) reduce 365) ((T_POW) reduce 365) ((T_SL) reduce 365) ((T_SPACESHIP) reduce 365) ((T_SR) reduce 365) (("^") reduce 365) (("|") reduce 365)) 10219 ((("%") reduce 472) (("(") reduce 472) (("*") reduce 472) (("+") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) ((":") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_DOUBLE_ARROW) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472)) 10220 ((("%") reduce 480) (("(") shift) (("*") reduce 480) (("+") reduce 480) (("-") reduce 480) ((".") reduce 480) (("/") reduce 480) ((":") reduce 480) (("<") reduce 480) ((">") reduce 480) (("?") reduce 480) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_BOOLEAN_AND) reduce 480) ((T_BOOLEAN_OR) reduce 480) ((T_COALESCE) reduce 480) ((T_DOUBLE_ARROW) reduce 480) ((T_INSTANCEOF) reduce 480) ((T_IS_EQUAL) reduce 480) ((T_IS_GREATER_OR_EQUAL) reduce 480) ((T_IS_IDENTICAL) reduce 480) ((T_IS_NOT_EQUAL) reduce 480) ((T_IS_NOT_IDENTICAL) reduce 480) ((T_IS_SMALLER_OR_EQUAL) reduce 480) ((T_LOGICAL_AND) reduce 480) ((T_LOGICAL_OR) reduce 480) ((T_LOGICAL_XOR) reduce 480) ((T_POW) reduce 480) ((T_SL) reduce 480) ((T_SPACESHIP) reduce 480) ((T_SR) reduce 480) (("^") reduce 480) (("|") reduce 480)) 10221 ((("%") reduce 471) (("(") reduce 471) (("*") reduce 471) (("+") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) ((":") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_DOUBLE_ARROW) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471)) 10222 ((("%") reduce 473) (("(") reduce 473) (("*") reduce 473) (("+") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) ((":") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_DOUBLE_ARROW) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 10223 ((("%") reduce 534) (("(") reduce 534) (("*") reduce 534) (("+") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) ((":") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_DOUBLE_ARROW) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 10230 ((("%") reduce 536) (("(") reduce 536) (("*") reduce 536) (("+") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) ((":") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_DOUBLE_ARROW) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 10232 ((("%") reduce 535) (("(") reduce 535) (("*") reduce 535) (("+") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) ((":") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_DOUBLE_ARROW) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 10233 ((("%") reduce 540) (("(") reduce 540) (("*") reduce 540) (("+") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) ((":") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_DOUBLE_ARROW) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 10234 ((("%") reduce 537) (("(") reduce 537) (("*") reduce 537) (("+") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) ((":") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_DOUBLE_ARROW) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 10235 ((("%") reduce 538) (("(") reduce 538) (("*") reduce 538) (("+") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) ((":") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_DOUBLE_ARROW) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 10237 ((("%") reduce 481) (("*") reduce 481) (("+") reduce 481) (("-") reduce 481) ((".") reduce 481) (("/") reduce 481) ((":") reduce 481) (("<") reduce 481) ((">") reduce 481) (("?") reduce 481) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_BOOLEAN_AND) reduce 481) ((T_BOOLEAN_OR) reduce 481) ((T_COALESCE) reduce 481) ((T_DOUBLE_ARROW) reduce 481) ((T_INSTANCEOF) reduce 481) ((T_IS_EQUAL) reduce 481) ((T_IS_GREATER_OR_EQUAL) reduce 481) ((T_IS_IDENTICAL) reduce 481) ((T_IS_NOT_EQUAL) reduce 481) ((T_IS_NOT_IDENTICAL) reduce 481) ((T_IS_SMALLER_OR_EQUAL) reduce 481) ((T_LOGICAL_AND) reduce 481) ((T_LOGICAL_OR) reduce 481) ((T_LOGICAL_XOR) reduce 481) ((T_POW) reduce 481) ((T_SL) reduce 481) ((T_SPACESHIP) reduce 481) ((T_SR) reduce 481) (("^") reduce 481) (("|") reduce 481)) 10238 ((("%") reduce 364) (("*") reduce 364) (("+") reduce 364) (("-") reduce 364) ((".") reduce 364) (("/") reduce 364) ((":") reduce 364) (("<") reduce 364) ((">") reduce 364) (("?") reduce 364) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_BOOLEAN_AND) reduce 364) ((T_BOOLEAN_OR) reduce 364) ((T_COALESCE) reduce 364) ((T_DOUBLE_ARROW) reduce 364) ((T_INSTANCEOF) reduce 364) ((T_IS_EQUAL) reduce 364) ((T_IS_GREATER_OR_EQUAL) reduce 364) ((T_IS_IDENTICAL) reduce 364) ((T_IS_NOT_EQUAL) reduce 364) ((T_IS_NOT_IDENTICAL) reduce 364) ((T_IS_SMALLER_OR_EQUAL) reduce 364) ((T_LOGICAL_AND) reduce 364) ((T_LOGICAL_OR) reduce 364) ((T_LOGICAL_XOR) reduce 364) ((T_POW) reduce 364) ((T_SL) reduce 364) ((T_SPACESHIP) reduce 364) ((T_SR) reduce 364) (("^") reduce 364) (("|") reduce 364)) 10239 ((("%") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) ((":") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("^") reduce 288) (("|") reduce 288)) 10243 ((("%") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) ((":") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("^") reduce 289) (("|") reduce 289)) 10244 ((("%") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) ((":") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("^") reduce 290) (("|") reduce 290)) 10246 ((("%") reduce 539) (("(") reduce 539) (("*") reduce 539) (("+") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) ((":") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_DOUBLE_ARROW) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 10247 ((("%") reduce 366) (("*") reduce 366) (("+") reduce 366) (("-") reduce 366) ((".") reduce 366) (("/") reduce 366) ((":") reduce 366) (("<") reduce 366) ((">") reduce 366) (("?") reduce 366) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_BOOLEAN_AND) reduce 366) ((T_BOOLEAN_OR) reduce 366) ((T_COALESCE) reduce 366) ((T_DOUBLE_ARROW) reduce 366) ((T_INSTANCEOF) reduce 366) ((T_IS_EQUAL) reduce 366) ((T_IS_GREATER_OR_EQUAL) reduce 366) ((T_IS_IDENTICAL) reduce 366) ((T_IS_NOT_EQUAL) reduce 366) ((T_IS_NOT_IDENTICAL) reduce 366) ((T_IS_SMALLER_OR_EQUAL) reduce 366) ((T_LOGICAL_AND) reduce 366) ((T_LOGICAL_OR) reduce 366) ((T_LOGICAL_XOR) reduce 366) ((T_POW) reduce 366) ((T_SL) reduce 366) ((T_SPACESHIP) reduce 366) ((T_SR) reduce 366) (("^") reduce 366) (("|") reduce 366)) 10255 ((("%") reduce 363) (("*") reduce 363) (("+") reduce 363) (("-") reduce 363) ((".") reduce 363) (("/") reduce 363) ((":") reduce 363) (("<") reduce 363) ((">") reduce 363) (("?") reduce 363) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_BOOLEAN_AND) reduce 363) ((T_BOOLEAN_OR) reduce 363) ((T_COALESCE) reduce 363) ((T_DOUBLE_ARROW) reduce 363) ((T_INSTANCEOF) reduce 363) ((T_IS_EQUAL) reduce 363) ((T_IS_GREATER_OR_EQUAL) reduce 363) ((T_IS_IDENTICAL) reduce 363) ((T_IS_NOT_EQUAL) reduce 363) ((T_IS_NOT_IDENTICAL) reduce 363) ((T_IS_SMALLER_OR_EQUAL) reduce 363) ((T_LOGICAL_AND) reduce 363) ((T_LOGICAL_OR) reduce 363) ((T_LOGICAL_XOR) reduce 363) ((T_POW) reduce 363) ((T_SL) reduce 363) ((T_SPACESHIP) reduce 363) ((T_SR) reduce 363) (("^") reduce 363) (("|") reduce 363)) 10257 ((("%") reduce 474) (("(") reduce 474) (("*") reduce 474) (("+") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) ((":") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_DOUBLE_ARROW) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474)) 10263 ((("%") reduce 230) (("*") reduce 230) (("+") reduce 230) (("-") reduce 230) ((".") reduce 230) (("/") reduce 230) ((":") reduce 230) (("<") reduce 230) ((">") reduce 230) (("?") reduce 230) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_BOOLEAN_AND) reduce 230) ((T_BOOLEAN_OR) reduce 230) ((T_COALESCE) reduce 230) ((T_DOUBLE_ARROW) reduce 230) ((T_INSTANCEOF) reduce 230) ((T_IS_EQUAL) reduce 230) ((T_IS_GREATER_OR_EQUAL) reduce 230) ((T_IS_IDENTICAL) reduce 230) ((T_IS_NOT_EQUAL) reduce 230) ((T_IS_NOT_IDENTICAL) reduce 230) ((T_IS_SMALLER_OR_EQUAL) reduce 230) ((T_LOGICAL_AND) reduce 230) ((T_LOGICAL_OR) reduce 230) ((T_LOGICAL_XOR) reduce 230) ((T_POW) reduce 230) ((T_SL) reduce 230) ((T_SPACESHIP) reduce 230) ((T_SR) reduce 230) (("^") reduce 230) (("|") reduce 230)) 10268 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 368) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 368) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 368) ((T_LOGICAL_OR) reduce 368) ((T_LOGICAL_XOR) reduce 368) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 10272 ((("%") reduce 575) (("*") reduce 575) (("+") reduce 575) (("-") reduce 575) ((".") reduce 575) (("/") reduce 575) ((":") reduce 575) (("<") reduce 575) ((">") reduce 575) (("?") reduce 575) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_BOOLEAN_AND) reduce 575) ((T_BOOLEAN_OR) reduce 575) ((T_COALESCE) reduce 575) ((T_DOUBLE_ARROW) reduce 575) ((T_INSTANCEOF) reduce 575) ((T_IS_EQUAL) reduce 575) ((T_IS_GREATER_OR_EQUAL) reduce 575) ((T_IS_IDENTICAL) reduce 575) ((T_IS_NOT_EQUAL) reduce 575) ((T_IS_NOT_IDENTICAL) reduce 575) ((T_IS_SMALLER_OR_EQUAL) reduce 575) ((T_LOGICAL_AND) reduce 575) ((T_LOGICAL_OR) reduce 575) ((T_LOGICAL_XOR) reduce 575) ((T_POW) reduce 575) ((T_SL) reduce 575) ((T_SPACESHIP) reduce 575) ((T_SR) reduce 575) (("^") reduce 575) (("|") reduce 575)) 10273 ((("%") reduce 428) (("*") reduce 428) (("+") reduce 428) (("-") reduce 428) ((".") reduce 428) (("/") reduce 428) ((":") reduce 428) (("<") reduce 428) ((">") reduce 428) (("?") reduce 428) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_BOOLEAN_AND) reduce 428) ((T_BOOLEAN_OR) reduce 428) ((T_COALESCE) reduce 428) ((T_DOUBLE_ARROW) reduce 428) ((T_INSTANCEOF) reduce 428) ((T_IS_EQUAL) reduce 428) ((T_IS_GREATER_OR_EQUAL) reduce 428) ((T_IS_IDENTICAL) reduce 428) ((T_IS_NOT_EQUAL) reduce 428) ((T_IS_NOT_IDENTICAL) reduce 428) ((T_IS_SMALLER_OR_EQUAL) reduce 428) ((T_LOGICAL_AND) reduce 428) ((T_LOGICAL_OR) reduce 428) ((T_LOGICAL_XOR) reduce 428) ((T_POW) shift) ((T_SL) reduce 428) ((T_SPACESHIP) reduce 428) ((T_SR) reduce 428) (("^") reduce 428) (("|") reduce 428)) 10274 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 578) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 578) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 10275 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 577) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 577) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 10276 ((("%") reduce 387) (("*") reduce 387) (("+") reduce 387) (("-") reduce 387) ((".") reduce 387) (("/") reduce 387) ((":") reduce 387) (("<") reduce 387) ((">") reduce 387) (("?") reduce 387) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_BOOLEAN_AND) reduce 387) ((T_BOOLEAN_OR) reduce 387) ((T_COALESCE) reduce 387) ((T_DOUBLE_ARROW) reduce 387) ((T_INSTANCEOF) reduce 387) ((T_IS_EQUAL) reduce 387) ((T_IS_GREATER_OR_EQUAL) reduce 387) ((T_IS_IDENTICAL) reduce 387) ((T_IS_NOT_EQUAL) reduce 387) ((T_IS_NOT_IDENTICAL) reduce 387) ((T_IS_SMALLER_OR_EQUAL) reduce 387) ((T_LOGICAL_AND) reduce 387) ((T_LOGICAL_OR) reduce 387) ((T_LOGICAL_XOR) reduce 387) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 387) ((T_SL) reduce 387) ((T_SPACESHIP) reduce 387) ((T_SR) reduce 387) (("[") reduce 510) (("^") reduce 387) (("{") reduce 510) (("|") reduce 387)) 10278 ((("%") reduce 435) (("*") reduce 435) (("+") reduce 435) (("-") reduce 435) ((".") reduce 435) (("/") reduce 435) ((":") reduce 435) (("<") reduce 435) ((">") reduce 435) (("?") reduce 435) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_BOOLEAN_AND) reduce 435) ((T_BOOLEAN_OR) reduce 435) ((T_COALESCE) reduce 435) ((T_DOUBLE_ARROW) reduce 435) ((T_INSTANCEOF) reduce 435) ((T_IS_EQUAL) reduce 435) ((T_IS_GREATER_OR_EQUAL) reduce 435) ((T_IS_IDENTICAL) reduce 435) ((T_IS_NOT_EQUAL) reduce 435) ((T_IS_NOT_IDENTICAL) reduce 435) ((T_IS_SMALLER_OR_EQUAL) reduce 435) ((T_LOGICAL_AND) reduce 435) ((T_LOGICAL_OR) reduce 435) ((T_LOGICAL_XOR) reduce 435) ((T_POW) reduce 435) ((T_SL) reduce 435) ((T_SPACESHIP) reduce 435) ((T_SR) reduce 435) (("^") reduce 435) (("|") reduce 435)) 10280 ((("%") reduce 476) (("*") reduce 476) (("+") reduce 476) (("-") reduce 476) ((".") reduce 476) (("/") reduce 476) ((":") reduce 476) (("<") reduce 476) ((">") reduce 476) (("?") reduce 476) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_BOOLEAN_AND) reduce 476) ((T_BOOLEAN_OR) reduce 476) ((T_COALESCE) reduce 476) ((T_DOUBLE_ARROW) reduce 476) ((T_INSTANCEOF) reduce 476) ((T_IS_EQUAL) reduce 476) ((T_IS_GREATER_OR_EQUAL) reduce 476) ((T_IS_IDENTICAL) reduce 476) ((T_IS_NOT_EQUAL) reduce 476) ((T_IS_NOT_IDENTICAL) reduce 476) ((T_IS_SMALLER_OR_EQUAL) reduce 476) ((T_LOGICAL_AND) reduce 476) ((T_LOGICAL_OR) reduce 476) ((T_LOGICAL_XOR) reduce 476) ((T_POW) reduce 476) ((T_SL) reduce 476) ((T_SPACESHIP) reduce 476) ((T_SR) reduce 476) (("^") reduce 476) (("|") reduce 476)) 10283 ((("%") reduce 579) (("*") reduce 579) (("+") reduce 579) (("-") reduce 579) ((".") reduce 579) (("/") reduce 579) ((":") reduce 579) (("<") reduce 579) ((">") reduce 579) (("?") reduce 579) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_BOOLEAN_AND) reduce 579) ((T_BOOLEAN_OR) reduce 579) ((T_COALESCE) reduce 579) ((T_DOUBLE_ARROW) reduce 579) ((T_INSTANCEOF) reduce 579) ((T_IS_EQUAL) reduce 579) ((T_IS_GREATER_OR_EQUAL) reduce 579) ((T_IS_IDENTICAL) reduce 579) ((T_IS_NOT_EQUAL) reduce 579) ((T_IS_NOT_IDENTICAL) reduce 579) ((T_IS_SMALLER_OR_EQUAL) reduce 579) ((T_LOGICAL_AND) reduce 579) ((T_LOGICAL_OR) reduce 579) ((T_LOGICAL_XOR) reduce 579) ((T_POW) reduce 579) ((T_SL) reduce 579) ((T_SPACESHIP) reduce 579) ((T_SR) reduce 579) (("^") reduce 579) (("|") reduce 579)) 10286 ((("%") reduce 576) (("*") reduce 576) (("+") reduce 576) (("-") reduce 576) ((".") reduce 576) (("/") reduce 576) ((":") reduce 576) (("<") reduce 576) ((">") reduce 576) (("?") reduce 576) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_BOOLEAN_AND) reduce 576) ((T_BOOLEAN_OR) reduce 576) ((T_COALESCE) reduce 576) ((T_DOUBLE_ARROW) reduce 576) ((T_INSTANCEOF) reduce 576) ((T_IS_EQUAL) reduce 576) ((T_IS_GREATER_OR_EQUAL) reduce 576) ((T_IS_IDENTICAL) reduce 576) ((T_IS_NOT_EQUAL) reduce 576) ((T_IS_NOT_IDENTICAL) reduce 576) ((T_IS_SMALLER_OR_EQUAL) reduce 576) ((T_LOGICAL_AND) reduce 576) ((T_LOGICAL_OR) reduce 576) ((T_LOGICAL_XOR) reduce 576) ((T_POW) reduce 576) ((T_SL) reduce 576) ((T_SPACESHIP) reduce 576) ((T_SR) reduce 576) (("^") reduce 576) (("|") reduce 576)) 10287 ((("%") reduce 429) (("*") reduce 429) (("+") reduce 429) (("-") reduce 429) ((".") reduce 429) (("/") reduce 429) ((":") reduce 429) (("<") reduce 429) ((">") reduce 429) (("?") reduce 429) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_BOOLEAN_AND) reduce 429) ((T_BOOLEAN_OR) reduce 429) ((T_COALESCE) reduce 429) ((T_DOUBLE_ARROW) reduce 429) ((T_INSTANCEOF) reduce 429) ((T_IS_EQUAL) reduce 429) ((T_IS_GREATER_OR_EQUAL) reduce 429) ((T_IS_IDENTICAL) reduce 429) ((T_IS_NOT_EQUAL) reduce 429) ((T_IS_NOT_IDENTICAL) reduce 429) ((T_IS_SMALLER_OR_EQUAL) reduce 429) ((T_LOGICAL_AND) reduce 429) ((T_LOGICAL_OR) reduce 429) ((T_LOGICAL_XOR) reduce 429) ((T_POW) shift) ((T_SL) reduce 429) ((T_SPACESHIP) reduce 429) ((T_SR) reduce 429) (("^") reduce 429) (("|") reduce 429)) 10288 ((("%") reduce 389) (("*") reduce 389) (("+") reduce 389) (("-") reduce 389) ((".") reduce 389) (("/") reduce 389) ((":") reduce 389) (("<") reduce 389) ((">") reduce 389) (("?") reduce 389) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_BOOLEAN_AND) reduce 389) ((T_BOOLEAN_OR) reduce 389) ((T_COALESCE) reduce 389) ((T_DOUBLE_ARROW) reduce 389) ((T_INSTANCEOF) reduce 389) ((T_IS_EQUAL) reduce 389) ((T_IS_GREATER_OR_EQUAL) reduce 389) ((T_IS_IDENTICAL) reduce 389) ((T_IS_NOT_EQUAL) reduce 389) ((T_IS_NOT_IDENTICAL) reduce 389) ((T_IS_SMALLER_OR_EQUAL) reduce 389) ((T_LOGICAL_AND) reduce 389) ((T_LOGICAL_OR) reduce 389) ((T_LOGICAL_XOR) reduce 389) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 389) ((T_SL) reduce 389) ((T_SPACESHIP) reduce 389) ((T_SR) reduce 389) (("[") reduce 510) (("^") reduce 389) (("{") reduce 510) (("|") reduce 389)) 10289 ((("%") reduce 372) (("*") reduce 372) (("+") reduce 372) (("-") reduce 372) ((".") reduce 372) (("/") reduce 372) ((":") reduce 372) (("<") reduce 372) ((">") reduce 372) (("?") reduce 372) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_BOOLEAN_AND) reduce 372) ((T_BOOLEAN_OR) reduce 372) ((T_COALESCE) reduce 372) ((T_DOUBLE_ARROW) reduce 372) ((T_INSTANCEOF) reduce 372) ((T_IS_EQUAL) reduce 372) ((T_IS_GREATER_OR_EQUAL) reduce 372) ((T_IS_IDENTICAL) reduce 372) ((T_IS_NOT_EQUAL) reduce 372) ((T_IS_NOT_IDENTICAL) reduce 372) ((T_IS_SMALLER_OR_EQUAL) reduce 372) ((T_LOGICAL_AND) reduce 372) ((T_LOGICAL_OR) reduce 372) ((T_LOGICAL_XOR) reduce 372) ((T_POW) reduce 372) ((T_SL) reduce 372) ((T_SPACESHIP) reduce 372) ((T_SR) reduce 372) (("^") reduce 372) (("|") reduce 372)) 10290 ((("%") reduce 433) (("*") reduce 433) (("+") reduce 433) (("-") reduce 433) ((".") reduce 433) (("/") reduce 433) ((":") reduce 433) (("<") reduce 433) ((">") reduce 433) (("?") reduce 433) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_BOOLEAN_AND) reduce 433) ((T_BOOLEAN_OR) reduce 433) ((T_COALESCE) reduce 433) ((T_DOUBLE_ARROW) reduce 433) ((T_INSTANCEOF) reduce 433) ((T_IS_EQUAL) reduce 433) ((T_IS_GREATER_OR_EQUAL) reduce 433) ((T_IS_IDENTICAL) reduce 433) ((T_IS_NOT_EQUAL) reduce 433) ((T_IS_NOT_IDENTICAL) reduce 433) ((T_IS_SMALLER_OR_EQUAL) reduce 433) ((T_LOGICAL_AND) reduce 433) ((T_LOGICAL_OR) reduce 433) ((T_LOGICAL_XOR) reduce 433) ((T_POW) shift) ((T_SL) reduce 433) ((T_SPACESHIP) reduce 433) ((T_SR) reduce 433) (("^") reduce 433) (("|") reduce 433)) 10291 ((("%") reduce 431) (("*") reduce 431) (("+") reduce 431) (("-") reduce 431) ((".") reduce 431) (("/") reduce 431) ((":") reduce 431) (("<") reduce 431) ((">") reduce 431) (("?") reduce 431) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_BOOLEAN_AND) reduce 431) ((T_BOOLEAN_OR) reduce 431) ((T_COALESCE) reduce 431) ((T_DOUBLE_ARROW) reduce 431) ((T_INSTANCEOF) reduce 431) ((T_IS_EQUAL) reduce 431) ((T_IS_GREATER_OR_EQUAL) reduce 431) ((T_IS_IDENTICAL) reduce 431) ((T_IS_NOT_EQUAL) reduce 431) ((T_IS_NOT_IDENTICAL) reduce 431) ((T_IS_SMALLER_OR_EQUAL) reduce 431) ((T_LOGICAL_AND) reduce 431) ((T_LOGICAL_OR) reduce 431) ((T_LOGICAL_XOR) reduce 431) ((T_POW) shift) ((T_SL) reduce 431) ((T_SPACESHIP) reduce 431) ((T_SR) reduce 431) (("^") reduce 431) (("|") reduce 431)) 10294 ((("%") reduce 482) (("(") reduce 482) (("*") reduce 482) (("+") reduce 482) (("-") reduce 482) ((".") reduce 482) (("/") reduce 482) ((":") reduce 482) (("<") reduce 482) ((">") reduce 482) (("?") reduce 482) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_BOOLEAN_AND) reduce 482) ((T_BOOLEAN_OR) reduce 482) ((T_COALESCE) reduce 482) ((T_DOUBLE_ARROW) reduce 482) ((T_INSTANCEOF) reduce 482) ((T_IS_EQUAL) reduce 482) ((T_IS_GREATER_OR_EQUAL) reduce 482) ((T_IS_IDENTICAL) reduce 482) ((T_IS_NOT_EQUAL) reduce 482) ((T_IS_NOT_IDENTICAL) reduce 482) ((T_IS_SMALLER_OR_EQUAL) reduce 482) ((T_LOGICAL_AND) reduce 482) ((T_LOGICAL_OR) reduce 482) ((T_LOGICAL_XOR) reduce 482) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 482) ((T_OBJECT_OPERATOR) reduce 482) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 482) ((T_POW) reduce 482) ((T_SL) reduce 482) ((T_SPACESHIP) reduce 482) ((T_SR) reduce 482) (("[") reduce 482) (("^") reduce 482) (("{") reduce 482) (("|") reduce 482)) 10295 ((("%") reduce 436) (("*") reduce 436) (("+") reduce 436) (("-") reduce 436) ((".") reduce 436) (("/") reduce 436) ((":") reduce 436) (("<") reduce 436) ((">") reduce 436) (("?") reduce 436) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_BOOLEAN_AND) reduce 436) ((T_BOOLEAN_OR) reduce 436) ((T_COALESCE) reduce 436) ((T_DOUBLE_ARROW) reduce 436) ((T_INSTANCEOF) reduce 436) ((T_IS_EQUAL) reduce 436) ((T_IS_GREATER_OR_EQUAL) reduce 436) ((T_IS_IDENTICAL) reduce 436) ((T_IS_NOT_EQUAL) reduce 436) ((T_IS_NOT_IDENTICAL) reduce 436) ((T_IS_SMALLER_OR_EQUAL) reduce 436) ((T_LOGICAL_AND) reduce 436) ((T_LOGICAL_OR) reduce 436) ((T_LOGICAL_XOR) reduce 436) ((T_POW) shift) ((T_SL) reduce 436) ((T_SPACESHIP) reduce 436) ((T_SR) reduce 436) (("^") reduce 436) (("|") reduce 436)) 10296 ((("%") reduce 409) (("*") reduce 409) (("+") reduce 409) (("-") reduce 409) ((".") reduce 409) (("/") reduce 409) ((":") reduce 409) (("<") reduce 409) ((">") reduce 409) (("?") reduce 409) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_BOOLEAN_AND) reduce 409) ((T_BOOLEAN_OR) reduce 409) ((T_COALESCE) reduce 409) ((T_DOUBLE_ARROW) reduce 409) ((T_INSTANCEOF) reduce 409) ((T_IS_EQUAL) reduce 409) ((T_IS_GREATER_OR_EQUAL) reduce 409) ((T_IS_IDENTICAL) reduce 409) ((T_IS_NOT_EQUAL) reduce 409) ((T_IS_NOT_IDENTICAL) reduce 409) ((T_IS_SMALLER_OR_EQUAL) reduce 409) ((T_LOGICAL_AND) reduce 409) ((T_LOGICAL_OR) reduce 409) ((T_LOGICAL_XOR) reduce 409) ((T_POW) shift) ((T_SL) reduce 409) ((T_SPACESHIP) reduce 409) ((T_SR) reduce 409) (("^") reduce 409) (("|") reduce 409)) 10297 ((("%") reduce 408) (("*") reduce 408) (("+") reduce 408) (("-") reduce 408) ((".") reduce 408) (("/") reduce 408) ((":") reduce 408) (("<") reduce 408) ((">") reduce 408) (("?") reduce 408) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_BOOLEAN_AND) reduce 408) ((T_BOOLEAN_OR) reduce 408) ((T_COALESCE) reduce 408) ((T_DOUBLE_ARROW) reduce 408) ((T_INSTANCEOF) reduce 408) ((T_IS_EQUAL) reduce 408) ((T_IS_GREATER_OR_EQUAL) reduce 408) ((T_IS_IDENTICAL) reduce 408) ((T_IS_NOT_EQUAL) reduce 408) ((T_IS_NOT_IDENTICAL) reduce 408) ((T_IS_SMALLER_OR_EQUAL) reduce 408) ((T_LOGICAL_AND) reduce 408) ((T_LOGICAL_OR) reduce 408) ((T_LOGICAL_XOR) reduce 408) ((T_POW) shift) ((T_SL) reduce 408) ((T_SPACESHIP) reduce 408) ((T_SR) reduce 408) (("^") reduce 408) (("|") reduce 408)) 10299 ((("%") reduce 422) (("(") reduce 517) (("*") reduce 422) (("+") reduce 422) (("-") reduce 422) ((".") reduce 422) (("/") reduce 422) ((":") reduce 422) (("<") reduce 422) ((">") reduce 422) (("?") reduce 422) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_BOOLEAN_AND) reduce 422) ((T_BOOLEAN_OR) reduce 422) ((T_COALESCE) reduce 422) ((T_DOUBLE_ARROW) reduce 422) ((T_INSTANCEOF) reduce 422) ((T_IS_EQUAL) reduce 422) ((T_IS_GREATER_OR_EQUAL) reduce 422) ((T_IS_IDENTICAL) reduce 422) ((T_IS_NOT_EQUAL) reduce 422) ((T_IS_NOT_IDENTICAL) reduce 422) ((T_IS_SMALLER_OR_EQUAL) reduce 422) ((T_LOGICAL_AND) reduce 422) ((T_LOGICAL_OR) reduce 422) ((T_LOGICAL_XOR) reduce 422) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 511) ((T_OBJECT_OPERATOR) reduce 511) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 511) ((T_POW) reduce 422) ((T_SL) reduce 422) ((T_SPACESHIP) reduce 422) ((T_SR) reduce 422) (("[") reduce 511) (("^") reduce 422) (("{") reduce 511) (("|") reduce 422)) 10300 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) ((":") reduce 531) (("<") reduce 531) (("=") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AND_EQUAL) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_COALESCE_EQUAL) reduce 531) ((T_CONCAT_EQUAL) reduce 531) ((T_DEC) reduce 531) ((T_DIV_EQUAL) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INC) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_MINUS_EQUAL) reduce 531) ((T_MOD_EQUAL) reduce 531) ((T_MUL_EQUAL) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_OR_EQUAL) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_PLUS_EQUAL) reduce 531) ((T_POW) reduce 531) ((T_POW_EQUAL) reduce 531) ((T_SL) reduce 531) ((T_SL_EQUAL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) ((T_SR_EQUAL) reduce 531) ((T_XOR_EQUAL) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 10303 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) ((":") reduce 530) (("<") reduce 530) (("=") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AND_EQUAL) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_COALESCE_EQUAL) reduce 530) ((T_CONCAT_EQUAL) reduce 530) ((T_DEC) reduce 530) ((T_DIV_EQUAL) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INC) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_MINUS_EQUAL) reduce 530) ((T_MOD_EQUAL) reduce 530) ((T_MUL_EQUAL) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_OR_EQUAL) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_PLUS_EQUAL) reduce 530) ((T_POW) reduce 530) ((T_POW_EQUAL) reduce 530) ((T_SL) reduce 530) ((T_SL_EQUAL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) ((T_SR_EQUAL) reduce 530) ((T_XOR_EQUAL) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 10305 ((("%") reduce 485) (("(") reduce 485) (("*") reduce 485) (("+") reduce 485) (("-") reduce 485) ((".") reduce 485) (("/") reduce 485) ((":") reduce 485) (("<") reduce 485) ((">") reduce 485) (("?") reduce 485) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_BOOLEAN_AND) reduce 485) ((T_BOOLEAN_OR) reduce 485) ((T_COALESCE) reduce 485) ((T_DOUBLE_ARROW) reduce 485) ((T_INSTANCEOF) reduce 485) ((T_IS_EQUAL) reduce 485) ((T_IS_GREATER_OR_EQUAL) reduce 485) ((T_IS_IDENTICAL) reduce 485) ((T_IS_NOT_EQUAL) reduce 485) ((T_IS_NOT_IDENTICAL) reduce 485) ((T_IS_SMALLER_OR_EQUAL) reduce 485) ((T_LOGICAL_AND) reduce 485) ((T_LOGICAL_OR) reduce 485) ((T_LOGICAL_XOR) reduce 485) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 485) ((T_OBJECT_OPERATOR) reduce 485) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 485) ((T_POW) reduce 485) ((T_SL) reduce 485) ((T_SPACESHIP) reduce 485) ((T_SR) reduce 485) (("[") reduce 485) (("^") reduce 485) (("{") reduce 485) (("|") reduce 485)) 10306 ((("%") reduce 410) (("*") reduce 410) (("+") reduce 410) (("-") reduce 410) ((".") reduce 410) (("/") reduce 410) ((":") reduce 410) (("<") reduce 410) ((">") reduce 410) (("?") reduce 410) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_BOOLEAN_AND) reduce 410) ((T_BOOLEAN_OR) reduce 410) ((T_COALESCE) reduce 410) ((T_DOUBLE_ARROW) reduce 410) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 410) ((T_IS_GREATER_OR_EQUAL) reduce 410) ((T_IS_IDENTICAL) reduce 410) ((T_IS_NOT_EQUAL) reduce 410) ((T_IS_NOT_IDENTICAL) reduce 410) ((T_IS_SMALLER_OR_EQUAL) reduce 410) ((T_LOGICAL_AND) reduce 410) ((T_LOGICAL_OR) reduce 410) ((T_LOGICAL_XOR) reduce 410) ((T_POW) shift) ((T_SL) reduce 410) ((T_SPACESHIP) reduce 410) ((T_SR) reduce 410) (("^") reduce 410) (("|") reduce 410)) 10307 ((("%") reduce 434) (("*") reduce 434) (("+") reduce 434) (("-") reduce 434) ((".") reduce 434) (("/") reduce 434) ((":") reduce 434) (("<") reduce 434) ((">") reduce 434) (("?") reduce 434) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_BOOLEAN_AND) reduce 434) ((T_BOOLEAN_OR) reduce 434) ((T_COALESCE) reduce 434) ((T_INSTANCEOF) reduce 434) ((T_IS_EQUAL) reduce 434) ((T_IS_GREATER_OR_EQUAL) reduce 434) ((T_IS_IDENTICAL) reduce 434) ((T_IS_NOT_EQUAL) reduce 434) ((T_IS_NOT_IDENTICAL) reduce 434) ((T_IS_SMALLER_OR_EQUAL) reduce 434) ((T_LOGICAL_AND) reduce 434) ((T_LOGICAL_OR) reduce 434) ((T_LOGICAL_XOR) reduce 434) ((T_POW) shift) ((T_SL) reduce 434) ((T_SPACESHIP) reduce 434) ((T_SR) reduce 434) (("^") reduce 434) (("|") reduce 434)) 10308 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 444) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 10309 ((("%") reduce 430) (("*") reduce 430) (("+") reduce 430) (("-") reduce 430) ((".") reduce 430) (("/") reduce 430) ((":") reduce 430) (("<") reduce 430) ((">") reduce 430) (("?") reduce 430) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_BOOLEAN_AND) reduce 430) ((T_BOOLEAN_OR) reduce 430) ((T_COALESCE) reduce 430) ((T_INSTANCEOF) reduce 430) ((T_IS_EQUAL) reduce 430) ((T_IS_GREATER_OR_EQUAL) reduce 430) ((T_IS_IDENTICAL) reduce 430) ((T_IS_NOT_EQUAL) reduce 430) ((T_IS_NOT_IDENTICAL) reduce 430) ((T_IS_SMALLER_OR_EQUAL) reduce 430) ((T_LOGICAL_AND) reduce 430) ((T_LOGICAL_OR) reduce 430) ((T_LOGICAL_XOR) reduce 430) ((T_POW) shift) ((T_SL) reduce 430) ((T_SPACESHIP) reduce 430) ((T_SR) reduce 430) (("^") reduce 430) (("|") reduce 430)) 10310 ((("%") reduce 447) (("*") reduce 447) (("+") reduce 447) (("-") reduce 447) ((".") reduce 447) (("/") reduce 447) ((":") reduce 447) (("<") reduce 447) ((">") reduce 447) (("?") reduce 447) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_BOOLEAN_AND) reduce 447) ((T_BOOLEAN_OR) reduce 447) ((T_COALESCE) reduce 447) ((T_INSTANCEOF) reduce 447) ((T_IS_EQUAL) reduce 447) ((T_IS_GREATER_OR_EQUAL) reduce 447) ((T_IS_IDENTICAL) reduce 447) ((T_IS_NOT_EQUAL) reduce 447) ((T_IS_NOT_IDENTICAL) reduce 447) ((T_IS_SMALLER_OR_EQUAL) reduce 447) ((T_LOGICAL_AND) reduce 447) ((T_LOGICAL_OR) reduce 447) ((T_LOGICAL_XOR) reduce 447) ((T_POW) reduce 447) ((T_SL) reduce 447) ((T_SPACESHIP) reduce 447) ((T_SR) reduce 447) (("^") reduce 447) (("|") reduce 447)) 10312 ((("%") reduce 489) (("*") reduce 489) (("+") reduce 489) (("-") reduce 489) ((".") reduce 489) (("/") reduce 489) ((":") reduce 489) (("<") reduce 489) ((">") reduce 489) (("?") reduce 489) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_BOOLEAN_AND) reduce 489) ((T_BOOLEAN_OR) reduce 489) ((T_COALESCE) reduce 489) ((T_INSTANCEOF) reduce 489) ((T_IS_EQUAL) reduce 489) ((T_IS_GREATER_OR_EQUAL) reduce 489) ((T_IS_IDENTICAL) reduce 489) ((T_IS_NOT_EQUAL) reduce 489) ((T_IS_NOT_IDENTICAL) reduce 489) ((T_IS_SMALLER_OR_EQUAL) reduce 489) ((T_LOGICAL_AND) reduce 489) ((T_LOGICAL_OR) reduce 489) ((T_LOGICAL_XOR) reduce 489) ((T_POW) reduce 489) ((T_SL) reduce 489) ((T_SPACESHIP) reduce 489) ((T_SR) reduce 489) (("^") reduce 489) (("|") reduce 489)) 10314 ((("%") reduce 490) (("*") reduce 490) (("+") reduce 490) (("-") reduce 490) ((".") reduce 490) (("/") reduce 490) ((":") reduce 490) (("<") reduce 490) ((">") reduce 490) (("?") reduce 490) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_BOOLEAN_AND) reduce 490) ((T_BOOLEAN_OR) reduce 490) ((T_COALESCE) reduce 490) ((T_INSTANCEOF) reduce 490) ((T_IS_EQUAL) reduce 490) ((T_IS_GREATER_OR_EQUAL) reduce 490) ((T_IS_IDENTICAL) reduce 490) ((T_IS_NOT_EQUAL) reduce 490) ((T_IS_NOT_IDENTICAL) reduce 490) ((T_IS_SMALLER_OR_EQUAL) reduce 490) ((T_LOGICAL_AND) reduce 490) ((T_LOGICAL_OR) reduce 490) ((T_LOGICAL_XOR) reduce 490) ((T_POW) reduce 490) ((T_SL) reduce 490) ((T_SPACESHIP) reduce 490) ((T_SR) reduce 490) (("^") reduce 490) (("|") reduce 490)) 10315 ((("%") reduce 488) (("*") reduce 488) (("+") reduce 488) (("-") reduce 488) ((".") reduce 488) (("/") reduce 488) ((":") reduce 488) (("<") reduce 488) ((">") reduce 488) (("?") reduce 488) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_BOOLEAN_AND) reduce 488) ((T_BOOLEAN_OR) reduce 488) ((T_COALESCE) reduce 488) ((T_INSTANCEOF) reduce 488) ((T_IS_EQUAL) reduce 488) ((T_IS_GREATER_OR_EQUAL) reduce 488) ((T_IS_IDENTICAL) reduce 488) ((T_IS_NOT_EQUAL) reduce 488) ((T_IS_NOT_IDENTICAL) reduce 488) ((T_IS_SMALLER_OR_EQUAL) reduce 488) ((T_LOGICAL_AND) reduce 488) ((T_LOGICAL_OR) reduce 488) ((T_LOGICAL_XOR) reduce 488) ((T_POW) reduce 488) ((T_SL) reduce 488) ((T_SPACESHIP) reduce 488) ((T_SR) reduce 488) (("^") reduce 488) (("|") reduce 488)) 10316 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 581) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 10317 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 580) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 10318 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) ((":") reduce 466) (("<") reduce 466) (("=") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AND_EQUAL) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_COALESCE_EQUAL) reduce 466) ((T_CONCAT_EQUAL) reduce 466) ((T_DEC) reduce 466) ((T_DIV_EQUAL) reduce 466) ((T_INC) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_MINUS_EQUAL) reduce 466) ((T_MOD_EQUAL) reduce 466) ((T_MUL_EQUAL) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_OR_EQUAL) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_PLUS_EQUAL) reduce 466) ((T_POW) reduce 466) ((T_POW_EQUAL) reduce 466) ((T_SL) reduce 466) ((T_SL_EQUAL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) ((T_SR_EQUAL) reduce 466) ((T_XOR_EQUAL) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 10319 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 439) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 439) ((T_LOGICAL_OR) reduce 439) ((T_LOGICAL_XOR) reduce 439) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 10320 ((("%") reduce 432) (("*") reduce 432) (("+") reduce 432) (("-") reduce 432) ((".") reduce 432) (("/") reduce 432) ((":") reduce 432) (("<") reduce 432) ((">") reduce 432) (("?") reduce 432) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_BOOLEAN_AND) reduce 432) ((T_BOOLEAN_OR) reduce 432) ((T_COALESCE) reduce 432) ((T_INSTANCEOF) reduce 432) ((T_IS_EQUAL) reduce 432) ((T_IS_GREATER_OR_EQUAL) reduce 432) ((T_IS_IDENTICAL) reduce 432) ((T_IS_NOT_EQUAL) reduce 432) ((T_IS_NOT_IDENTICAL) reduce 432) ((T_IS_SMALLER_OR_EQUAL) reduce 432) ((T_LOGICAL_AND) reduce 432) ((T_LOGICAL_OR) reduce 432) ((T_LOGICAL_XOR) reduce 432) ((T_POW) shift) ((T_SL) reduce 432) ((T_SPACESHIP) reduce 432) ((T_SR) reduce 432) (("^") reduce 432) (("|") reduce 432)) 10322 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) ((":") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93)) 10323 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) ((":") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92)) 10324 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) ((":") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94)) 10325 ((("%") reduce 470) (("(") reduce 470) (("*") reduce 470) (("+") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) ((":") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470)) 10326 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) ((":") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91)) 10327 ((("%") reduce 365) (("*") reduce 365) (("+") reduce 365) (("-") reduce 365) ((".") reduce 365) (("/") reduce 365) ((":") reduce 365) (("<") reduce 365) ((">") reduce 365) (("?") reduce 365) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_BOOLEAN_AND) reduce 365) ((T_BOOLEAN_OR) reduce 365) ((T_COALESCE) reduce 365) ((T_INSTANCEOF) reduce 365) ((T_IS_EQUAL) reduce 365) ((T_IS_GREATER_OR_EQUAL) reduce 365) ((T_IS_IDENTICAL) reduce 365) ((T_IS_NOT_EQUAL) reduce 365) ((T_IS_NOT_IDENTICAL) reduce 365) ((T_IS_SMALLER_OR_EQUAL) reduce 365) ((T_LOGICAL_AND) reduce 365) ((T_LOGICAL_OR) reduce 365) ((T_LOGICAL_XOR) reduce 365) ((T_POW) reduce 365) ((T_SL) reduce 365) ((T_SPACESHIP) reduce 365) ((T_SR) reduce 365) (("^") reduce 365) (("|") reduce 365)) 10330 ((("%") reduce 472) (("(") reduce 472) (("*") reduce 472) (("+") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) ((":") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472)) 10331 ((("%") reduce 480) (("(") shift) (("*") reduce 480) (("+") reduce 480) (("-") reduce 480) ((".") reduce 480) (("/") reduce 480) ((":") reduce 480) (("<") reduce 480) ((">") reduce 480) (("?") reduce 480) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_BOOLEAN_AND) reduce 480) ((T_BOOLEAN_OR) reduce 480) ((T_COALESCE) reduce 480) ((T_INSTANCEOF) reduce 480) ((T_IS_EQUAL) reduce 480) ((T_IS_GREATER_OR_EQUAL) reduce 480) ((T_IS_IDENTICAL) reduce 480) ((T_IS_NOT_EQUAL) reduce 480) ((T_IS_NOT_IDENTICAL) reduce 480) ((T_IS_SMALLER_OR_EQUAL) reduce 480) ((T_LOGICAL_AND) reduce 480) ((T_LOGICAL_OR) reduce 480) ((T_LOGICAL_XOR) reduce 480) ((T_POW) reduce 480) ((T_SL) reduce 480) ((T_SPACESHIP) reduce 480) ((T_SR) reduce 480) (("^") reduce 480) (("|") reduce 480)) 10332 ((("%") reduce 471) (("(") reduce 471) (("*") reduce 471) (("+") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) ((":") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471)) 10333 ((("%") reduce 473) (("(") reduce 473) (("*") reduce 473) (("+") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) ((":") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 10334 ((("%") reduce 534) (("(") reduce 534) (("*") reduce 534) (("+") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) ((":") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 10341 ((("%") reduce 536) (("(") reduce 536) (("*") reduce 536) (("+") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) ((":") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 10343 ((("%") reduce 535) (("(") reduce 535) (("*") reduce 535) (("+") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) ((":") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 10344 ((("%") reduce 540) (("(") reduce 540) (("*") reduce 540) (("+") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) ((":") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 10345 ((("%") reduce 537) (("(") reduce 537) (("*") reduce 537) (("+") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) ((":") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 10346 ((("%") reduce 538) (("(") reduce 538) (("*") reduce 538) (("+") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) ((":") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 10348 ((("%") reduce 481) (("*") reduce 481) (("+") reduce 481) (("-") reduce 481) ((".") reduce 481) (("/") reduce 481) ((":") reduce 481) (("<") reduce 481) ((">") reduce 481) (("?") reduce 481) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_BOOLEAN_AND) reduce 481) ((T_BOOLEAN_OR) reduce 481) ((T_COALESCE) reduce 481) ((T_INSTANCEOF) reduce 481) ((T_IS_EQUAL) reduce 481) ((T_IS_GREATER_OR_EQUAL) reduce 481) ((T_IS_IDENTICAL) reduce 481) ((T_IS_NOT_EQUAL) reduce 481) ((T_IS_NOT_IDENTICAL) reduce 481) ((T_IS_SMALLER_OR_EQUAL) reduce 481) ((T_LOGICAL_AND) reduce 481) ((T_LOGICAL_OR) reduce 481) ((T_LOGICAL_XOR) reduce 481) ((T_POW) reduce 481) ((T_SL) reduce 481) ((T_SPACESHIP) reduce 481) ((T_SR) reduce 481) (("^") reduce 481) (("|") reduce 481)) 10349 ((("%") reduce 364) (("*") reduce 364) (("+") reduce 364) (("-") reduce 364) ((".") reduce 364) (("/") reduce 364) ((":") reduce 364) (("<") reduce 364) ((">") reduce 364) (("?") reduce 364) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_BOOLEAN_AND) reduce 364) ((T_BOOLEAN_OR) reduce 364) ((T_COALESCE) reduce 364) ((T_INSTANCEOF) reduce 364) ((T_IS_EQUAL) reduce 364) ((T_IS_GREATER_OR_EQUAL) reduce 364) ((T_IS_IDENTICAL) reduce 364) ((T_IS_NOT_EQUAL) reduce 364) ((T_IS_NOT_IDENTICAL) reduce 364) ((T_IS_SMALLER_OR_EQUAL) reduce 364) ((T_LOGICAL_AND) reduce 364) ((T_LOGICAL_OR) reduce 364) ((T_LOGICAL_XOR) reduce 364) ((T_POW) reduce 364) ((T_SL) reduce 364) ((T_SPACESHIP) reduce 364) ((T_SR) reduce 364) (("^") reduce 364) (("|") reduce 364)) 10350 ((("%") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) ((":") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("^") reduce 288) (("|") reduce 288)) 10354 ((("%") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) ((":") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("^") reduce 289) (("|") reduce 289)) 10355 ((("%") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) ((":") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("^") reduce 290) (("|") reduce 290)) 10357 ((("%") reduce 539) (("(") reduce 539) (("*") reduce 539) (("+") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) ((":") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 10358 ((("%") reduce 366) (("*") reduce 366) (("+") reduce 366) (("-") reduce 366) ((".") reduce 366) (("/") reduce 366) ((":") reduce 366) (("<") reduce 366) ((">") reduce 366) (("?") reduce 366) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_BOOLEAN_AND) reduce 366) ((T_BOOLEAN_OR) reduce 366) ((T_COALESCE) reduce 366) ((T_INSTANCEOF) reduce 366) ((T_IS_EQUAL) reduce 366) ((T_IS_GREATER_OR_EQUAL) reduce 366) ((T_IS_IDENTICAL) reduce 366) ((T_IS_NOT_EQUAL) reduce 366) ((T_IS_NOT_IDENTICAL) reduce 366) ((T_IS_SMALLER_OR_EQUAL) reduce 366) ((T_LOGICAL_AND) reduce 366) ((T_LOGICAL_OR) reduce 366) ((T_LOGICAL_XOR) reduce 366) ((T_POW) reduce 366) ((T_SL) reduce 366) ((T_SPACESHIP) reduce 366) ((T_SR) reduce 366) (("^") reduce 366) (("|") reduce 366)) 10366 ((("%") reduce 363) (("*") reduce 363) (("+") reduce 363) (("-") reduce 363) ((".") reduce 363) (("/") reduce 363) ((":") reduce 363) (("<") reduce 363) ((">") reduce 363) (("?") reduce 363) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_BOOLEAN_AND) reduce 363) ((T_BOOLEAN_OR) reduce 363) ((T_COALESCE) reduce 363) ((T_INSTANCEOF) reduce 363) ((T_IS_EQUAL) reduce 363) ((T_IS_GREATER_OR_EQUAL) reduce 363) ((T_IS_IDENTICAL) reduce 363) ((T_IS_NOT_EQUAL) reduce 363) ((T_IS_NOT_IDENTICAL) reduce 363) ((T_IS_SMALLER_OR_EQUAL) reduce 363) ((T_LOGICAL_AND) reduce 363) ((T_LOGICAL_OR) reduce 363) ((T_LOGICAL_XOR) reduce 363) ((T_POW) reduce 363) ((T_SL) reduce 363) ((T_SPACESHIP) reduce 363) ((T_SR) reduce 363) (("^") reduce 363) (("|") reduce 363)) 10368 ((("%") reduce 474) (("(") reduce 474) (("*") reduce 474) (("+") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) ((":") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474)) 10374 ((("%") reduce 230) (("*") reduce 230) (("+") reduce 230) (("-") reduce 230) ((".") reduce 230) (("/") reduce 230) ((":") reduce 230) (("<") reduce 230) ((">") reduce 230) (("?") reduce 230) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_BOOLEAN_AND) reduce 230) ((T_BOOLEAN_OR) reduce 230) ((T_COALESCE) reduce 230) ((T_INSTANCEOF) reduce 230) ((T_IS_EQUAL) reduce 230) ((T_IS_GREATER_OR_EQUAL) reduce 230) ((T_IS_IDENTICAL) reduce 230) ((T_IS_NOT_EQUAL) reduce 230) ((T_IS_NOT_IDENTICAL) reduce 230) ((T_IS_SMALLER_OR_EQUAL) reduce 230) ((T_LOGICAL_AND) reduce 230) ((T_LOGICAL_OR) reduce 230) ((T_LOGICAL_XOR) reduce 230) ((T_POW) reduce 230) ((T_SL) reduce 230) ((T_SPACESHIP) reduce 230) ((T_SR) reduce 230) (("^") reduce 230) (("|") reduce 230)) 10379 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 368) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 368) ((T_LOGICAL_OR) reduce 368) ((T_LOGICAL_XOR) reduce 368) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 10383 ((("%") reduce 575) (("*") reduce 575) (("+") reduce 575) (("-") reduce 575) ((".") reduce 575) (("/") reduce 575) ((":") reduce 575) (("<") reduce 575) ((">") reduce 575) (("?") reduce 575) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_BOOLEAN_AND) reduce 575) ((T_BOOLEAN_OR) reduce 575) ((T_COALESCE) reduce 575) ((T_INSTANCEOF) reduce 575) ((T_IS_EQUAL) reduce 575) ((T_IS_GREATER_OR_EQUAL) reduce 575) ((T_IS_IDENTICAL) reduce 575) ((T_IS_NOT_EQUAL) reduce 575) ((T_IS_NOT_IDENTICAL) reduce 575) ((T_IS_SMALLER_OR_EQUAL) reduce 575) ((T_LOGICAL_AND) reduce 575) ((T_LOGICAL_OR) reduce 575) ((T_LOGICAL_XOR) reduce 575) ((T_POW) reduce 575) ((T_SL) reduce 575) ((T_SPACESHIP) reduce 575) ((T_SR) reduce 575) (("^") reduce 575) (("|") reduce 575)) 10384 ((("%") reduce 428) (("*") reduce 428) (("+") reduce 428) (("-") reduce 428) ((".") reduce 428) (("/") reduce 428) ((":") reduce 428) (("<") reduce 428) ((">") reduce 428) (("?") reduce 428) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_BOOLEAN_AND) reduce 428) ((T_BOOLEAN_OR) reduce 428) ((T_COALESCE) reduce 428) ((T_INSTANCEOF) reduce 428) ((T_IS_EQUAL) reduce 428) ((T_IS_GREATER_OR_EQUAL) reduce 428) ((T_IS_IDENTICAL) reduce 428) ((T_IS_NOT_EQUAL) reduce 428) ((T_IS_NOT_IDENTICAL) reduce 428) ((T_IS_SMALLER_OR_EQUAL) reduce 428) ((T_LOGICAL_AND) reduce 428) ((T_LOGICAL_OR) reduce 428) ((T_LOGICAL_XOR) reduce 428) ((T_POW) shift) ((T_SL) reduce 428) ((T_SPACESHIP) reduce 428) ((T_SR) reduce 428) (("^") reduce 428) (("|") reduce 428)) 10385 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 578) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 10386 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 577) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 10387 ((("%") reduce 387) (("*") reduce 387) (("+") reduce 387) (("-") reduce 387) ((".") reduce 387) (("/") reduce 387) ((":") reduce 387) (("<") reduce 387) ((">") reduce 387) (("?") reduce 387) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_BOOLEAN_AND) reduce 387) ((T_BOOLEAN_OR) reduce 387) ((T_COALESCE) reduce 387) ((T_INSTANCEOF) reduce 387) ((T_IS_EQUAL) reduce 387) ((T_IS_GREATER_OR_EQUAL) reduce 387) ((T_IS_IDENTICAL) reduce 387) ((T_IS_NOT_EQUAL) reduce 387) ((T_IS_NOT_IDENTICAL) reduce 387) ((T_IS_SMALLER_OR_EQUAL) reduce 387) ((T_LOGICAL_AND) reduce 387) ((T_LOGICAL_OR) reduce 387) ((T_LOGICAL_XOR) reduce 387) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 387) ((T_SL) reduce 387) ((T_SPACESHIP) reduce 387) ((T_SR) reduce 387) (("[") reduce 510) (("^") reduce 387) (("{") reduce 510) (("|") reduce 387)) 10389 ((("%") reduce 435) (("*") reduce 435) (("+") reduce 435) (("-") reduce 435) ((".") reduce 435) (("/") reduce 435) ((":") reduce 435) (("<") reduce 435) ((">") reduce 435) (("?") reduce 435) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_BOOLEAN_AND) reduce 435) ((T_BOOLEAN_OR) reduce 435) ((T_COALESCE) reduce 435) ((T_INSTANCEOF) reduce 435) ((T_IS_EQUAL) reduce 435) ((T_IS_GREATER_OR_EQUAL) reduce 435) ((T_IS_IDENTICAL) reduce 435) ((T_IS_NOT_EQUAL) reduce 435) ((T_IS_NOT_IDENTICAL) reduce 435) ((T_IS_SMALLER_OR_EQUAL) reduce 435) ((T_LOGICAL_AND) reduce 435) ((T_LOGICAL_OR) reduce 435) ((T_LOGICAL_XOR) reduce 435) ((T_POW) reduce 435) ((T_SL) reduce 435) ((T_SPACESHIP) reduce 435) ((T_SR) reduce 435) (("^") reduce 435) (("|") reduce 435)) 10391 ((("%") reduce 476) (("*") reduce 476) (("+") reduce 476) (("-") reduce 476) ((".") reduce 476) (("/") reduce 476) ((":") reduce 476) (("<") reduce 476) ((">") reduce 476) (("?") reduce 476) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_BOOLEAN_AND) reduce 476) ((T_BOOLEAN_OR) reduce 476) ((T_COALESCE) reduce 476) ((T_INSTANCEOF) reduce 476) ((T_IS_EQUAL) reduce 476) ((T_IS_GREATER_OR_EQUAL) reduce 476) ((T_IS_IDENTICAL) reduce 476) ((T_IS_NOT_EQUAL) reduce 476) ((T_IS_NOT_IDENTICAL) reduce 476) ((T_IS_SMALLER_OR_EQUAL) reduce 476) ((T_LOGICAL_AND) reduce 476) ((T_LOGICAL_OR) reduce 476) ((T_LOGICAL_XOR) reduce 476) ((T_POW) reduce 476) ((T_SL) reduce 476) ((T_SPACESHIP) reduce 476) ((T_SR) reduce 476) (("^") reduce 476) (("|") reduce 476)) 10394 ((("%") reduce 579) (("*") reduce 579) (("+") reduce 579) (("-") reduce 579) ((".") reduce 579) (("/") reduce 579) ((":") reduce 579) (("<") reduce 579) ((">") reduce 579) (("?") reduce 579) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_BOOLEAN_AND) reduce 579) ((T_BOOLEAN_OR) reduce 579) ((T_COALESCE) reduce 579) ((T_INSTANCEOF) reduce 579) ((T_IS_EQUAL) reduce 579) ((T_IS_GREATER_OR_EQUAL) reduce 579) ((T_IS_IDENTICAL) reduce 579) ((T_IS_NOT_EQUAL) reduce 579) ((T_IS_NOT_IDENTICAL) reduce 579) ((T_IS_SMALLER_OR_EQUAL) reduce 579) ((T_LOGICAL_AND) reduce 579) ((T_LOGICAL_OR) reduce 579) ((T_LOGICAL_XOR) reduce 579) ((T_POW) reduce 579) ((T_SL) reduce 579) ((T_SPACESHIP) reduce 579) ((T_SR) reduce 579) (("^") reduce 579) (("|") reduce 579)) 10397 ((("%") reduce 576) (("*") reduce 576) (("+") reduce 576) (("-") reduce 576) ((".") reduce 576) (("/") reduce 576) ((":") reduce 576) (("<") reduce 576) ((">") reduce 576) (("?") reduce 576) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_BOOLEAN_AND) reduce 576) ((T_BOOLEAN_OR) reduce 576) ((T_COALESCE) reduce 576) ((T_INSTANCEOF) reduce 576) ((T_IS_EQUAL) reduce 576) ((T_IS_GREATER_OR_EQUAL) reduce 576) ((T_IS_IDENTICAL) reduce 576) ((T_IS_NOT_EQUAL) reduce 576) ((T_IS_NOT_IDENTICAL) reduce 576) ((T_IS_SMALLER_OR_EQUAL) reduce 576) ((T_LOGICAL_AND) reduce 576) ((T_LOGICAL_OR) reduce 576) ((T_LOGICAL_XOR) reduce 576) ((T_POW) reduce 576) ((T_SL) reduce 576) ((T_SPACESHIP) reduce 576) ((T_SR) reduce 576) (("^") reduce 576) (("|") reduce 576)) 10398 ((("%") reduce 429) (("*") reduce 429) (("+") reduce 429) (("-") reduce 429) ((".") reduce 429) (("/") reduce 429) ((":") reduce 429) (("<") reduce 429) ((">") reduce 429) (("?") reduce 429) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_BOOLEAN_AND) reduce 429) ((T_BOOLEAN_OR) reduce 429) ((T_COALESCE) reduce 429) ((T_INSTANCEOF) reduce 429) ((T_IS_EQUAL) reduce 429) ((T_IS_GREATER_OR_EQUAL) reduce 429) ((T_IS_IDENTICAL) reduce 429) ((T_IS_NOT_EQUAL) reduce 429) ((T_IS_NOT_IDENTICAL) reduce 429) ((T_IS_SMALLER_OR_EQUAL) reduce 429) ((T_LOGICAL_AND) reduce 429) ((T_LOGICAL_OR) reduce 429) ((T_LOGICAL_XOR) reduce 429) ((T_POW) shift) ((T_SL) reduce 429) ((T_SPACESHIP) reduce 429) ((T_SR) reduce 429) (("^") reduce 429) (("|") reduce 429)) 10399 ((("%") reduce 389) (("*") reduce 389) (("+") reduce 389) (("-") reduce 389) ((".") reduce 389) (("/") reduce 389) ((":") reduce 389) (("<") reduce 389) ((">") reduce 389) (("?") reduce 389) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_BOOLEAN_AND) reduce 389) ((T_BOOLEAN_OR) reduce 389) ((T_COALESCE) reduce 389) ((T_INSTANCEOF) reduce 389) ((T_IS_EQUAL) reduce 389) ((T_IS_GREATER_OR_EQUAL) reduce 389) ((T_IS_IDENTICAL) reduce 389) ((T_IS_NOT_EQUAL) reduce 389) ((T_IS_NOT_IDENTICAL) reduce 389) ((T_IS_SMALLER_OR_EQUAL) reduce 389) ((T_LOGICAL_AND) reduce 389) ((T_LOGICAL_OR) reduce 389) ((T_LOGICAL_XOR) reduce 389) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 389) ((T_SL) reduce 389) ((T_SPACESHIP) reduce 389) ((T_SR) reduce 389) (("[") reduce 510) (("^") reduce 389) (("{") reduce 510) (("|") reduce 389)) 10400 ((("%") reduce 372) (("*") reduce 372) (("+") reduce 372) (("-") reduce 372) ((".") reduce 372) (("/") reduce 372) ((":") reduce 372) (("<") reduce 372) ((">") reduce 372) (("?") reduce 372) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_BOOLEAN_AND) reduce 372) ((T_BOOLEAN_OR) reduce 372) ((T_COALESCE) reduce 372) ((T_INSTANCEOF) reduce 372) ((T_IS_EQUAL) reduce 372) ((T_IS_GREATER_OR_EQUAL) reduce 372) ((T_IS_IDENTICAL) reduce 372) ((T_IS_NOT_EQUAL) reduce 372) ((T_IS_NOT_IDENTICAL) reduce 372) ((T_IS_SMALLER_OR_EQUAL) reduce 372) ((T_LOGICAL_AND) reduce 372) ((T_LOGICAL_OR) reduce 372) ((T_LOGICAL_XOR) reduce 372) ((T_POW) reduce 372) ((T_SL) reduce 372) ((T_SPACESHIP) reduce 372) ((T_SR) reduce 372) (("^") reduce 372) (("|") reduce 372)) 10401 ((("%") reduce 433) (("*") reduce 433) (("+") reduce 433) (("-") reduce 433) ((".") reduce 433) (("/") reduce 433) ((":") reduce 433) (("<") reduce 433) ((">") reduce 433) (("?") reduce 433) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_BOOLEAN_AND) reduce 433) ((T_BOOLEAN_OR) reduce 433) ((T_COALESCE) reduce 433) ((T_INSTANCEOF) reduce 433) ((T_IS_EQUAL) reduce 433) ((T_IS_GREATER_OR_EQUAL) reduce 433) ((T_IS_IDENTICAL) reduce 433) ((T_IS_NOT_EQUAL) reduce 433) ((T_IS_NOT_IDENTICAL) reduce 433) ((T_IS_SMALLER_OR_EQUAL) reduce 433) ((T_LOGICAL_AND) reduce 433) ((T_LOGICAL_OR) reduce 433) ((T_LOGICAL_XOR) reduce 433) ((T_POW) shift) ((T_SL) reduce 433) ((T_SPACESHIP) reduce 433) ((T_SR) reduce 433) (("^") reduce 433) (("|") reduce 433)) 10402 ((("%") reduce 431) (("*") reduce 431) (("+") reduce 431) (("-") reduce 431) ((".") reduce 431) (("/") reduce 431) ((":") reduce 431) (("<") reduce 431) ((">") reduce 431) (("?") reduce 431) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_BOOLEAN_AND) reduce 431) ((T_BOOLEAN_OR) reduce 431) ((T_COALESCE) reduce 431) ((T_INSTANCEOF) reduce 431) ((T_IS_EQUAL) reduce 431) ((T_IS_GREATER_OR_EQUAL) reduce 431) ((T_IS_IDENTICAL) reduce 431) ((T_IS_NOT_EQUAL) reduce 431) ((T_IS_NOT_IDENTICAL) reduce 431) ((T_IS_SMALLER_OR_EQUAL) reduce 431) ((T_LOGICAL_AND) reduce 431) ((T_LOGICAL_OR) reduce 431) ((T_LOGICAL_XOR) reduce 431) ((T_POW) shift) ((T_SL) reduce 431) ((T_SPACESHIP) reduce 431) ((T_SR) reduce 431) (("^") reduce 431) (("|") reduce 431)) 10405 ((("%") reduce 482) (("(") reduce 482) (("*") reduce 482) (("+") reduce 482) (("-") reduce 482) ((".") reduce 482) (("/") reduce 482) ((":") reduce 482) (("<") reduce 482) ((">") reduce 482) (("?") reduce 482) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_BOOLEAN_AND) reduce 482) ((T_BOOLEAN_OR) reduce 482) ((T_COALESCE) reduce 482) ((T_INSTANCEOF) reduce 482) ((T_IS_EQUAL) reduce 482) ((T_IS_GREATER_OR_EQUAL) reduce 482) ((T_IS_IDENTICAL) reduce 482) ((T_IS_NOT_EQUAL) reduce 482) ((T_IS_NOT_IDENTICAL) reduce 482) ((T_IS_SMALLER_OR_EQUAL) reduce 482) ((T_LOGICAL_AND) reduce 482) ((T_LOGICAL_OR) reduce 482) ((T_LOGICAL_XOR) reduce 482) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 482) ((T_OBJECT_OPERATOR) reduce 482) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 482) ((T_POW) reduce 482) ((T_SL) reduce 482) ((T_SPACESHIP) reduce 482) ((T_SR) reduce 482) (("[") reduce 482) (("^") reduce 482) (("{") reduce 482) (("|") reduce 482)) 10406 ((("%") reduce 436) (("*") reduce 436) (("+") reduce 436) (("-") reduce 436) ((".") reduce 436) (("/") reduce 436) ((":") reduce 436) (("<") reduce 436) ((">") reduce 436) (("?") reduce 436) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_BOOLEAN_AND) reduce 436) ((T_BOOLEAN_OR) reduce 436) ((T_COALESCE) reduce 436) ((T_INSTANCEOF) reduce 436) ((T_IS_EQUAL) reduce 436) ((T_IS_GREATER_OR_EQUAL) reduce 436) ((T_IS_IDENTICAL) reduce 436) ((T_IS_NOT_EQUAL) reduce 436) ((T_IS_NOT_IDENTICAL) reduce 436) ((T_IS_SMALLER_OR_EQUAL) reduce 436) ((T_LOGICAL_AND) reduce 436) ((T_LOGICAL_OR) reduce 436) ((T_LOGICAL_XOR) reduce 436) ((T_POW) shift) ((T_SL) reduce 436) ((T_SPACESHIP) reduce 436) ((T_SR) reduce 436) (("^") reduce 436) (("|") reduce 436)) 10407 ((("%") reduce 409) (("*") reduce 409) (("+") reduce 409) (("-") reduce 409) ((".") reduce 409) (("/") reduce 409) ((":") reduce 409) (("<") reduce 409) ((">") reduce 409) (("?") reduce 409) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_BOOLEAN_AND) reduce 409) ((T_BOOLEAN_OR) reduce 409) ((T_COALESCE) reduce 409) ((T_INSTANCEOF) reduce 409) ((T_IS_EQUAL) reduce 409) ((T_IS_GREATER_OR_EQUAL) reduce 409) ((T_IS_IDENTICAL) reduce 409) ((T_IS_NOT_EQUAL) reduce 409) ((T_IS_NOT_IDENTICAL) reduce 409) ((T_IS_SMALLER_OR_EQUAL) reduce 409) ((T_LOGICAL_AND) reduce 409) ((T_LOGICAL_OR) reduce 409) ((T_LOGICAL_XOR) reduce 409) ((T_POW) shift) ((T_SL) reduce 409) ((T_SPACESHIP) reduce 409) ((T_SR) reduce 409) (("^") reduce 409) (("|") reduce 409)) 10408 ((("%") reduce 408) (("*") reduce 408) (("+") reduce 408) (("-") reduce 408) ((".") reduce 408) (("/") reduce 408) ((":") reduce 408) (("<") reduce 408) ((">") reduce 408) (("?") reduce 408) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_BOOLEAN_AND) reduce 408) ((T_BOOLEAN_OR) reduce 408) ((T_COALESCE) reduce 408) ((T_INSTANCEOF) reduce 408) ((T_IS_EQUAL) reduce 408) ((T_IS_GREATER_OR_EQUAL) reduce 408) ((T_IS_IDENTICAL) reduce 408) ((T_IS_NOT_EQUAL) reduce 408) ((T_IS_NOT_IDENTICAL) reduce 408) ((T_IS_SMALLER_OR_EQUAL) reduce 408) ((T_LOGICAL_AND) reduce 408) ((T_LOGICAL_OR) reduce 408) ((T_LOGICAL_XOR) reduce 408) ((T_POW) shift) ((T_SL) reduce 408) ((T_SPACESHIP) reduce 408) ((T_SR) reduce 408) (("^") reduce 408) (("|") reduce 408)) 10410 ((("%") reduce 422) (("(") reduce 517) (("*") reduce 422) (("+") reduce 422) (("-") reduce 422) ((".") reduce 422) (("/") reduce 422) ((":") reduce 422) (("<") reduce 422) ((">") reduce 422) (("?") reduce 422) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_BOOLEAN_AND) reduce 422) ((T_BOOLEAN_OR) reduce 422) ((T_COALESCE) reduce 422) ((T_INSTANCEOF) reduce 422) ((T_IS_EQUAL) reduce 422) ((T_IS_GREATER_OR_EQUAL) reduce 422) ((T_IS_IDENTICAL) reduce 422) ((T_IS_NOT_EQUAL) reduce 422) ((T_IS_NOT_IDENTICAL) reduce 422) ((T_IS_SMALLER_OR_EQUAL) reduce 422) ((T_LOGICAL_AND) reduce 422) ((T_LOGICAL_OR) reduce 422) ((T_LOGICAL_XOR) reduce 422) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 511) ((T_OBJECT_OPERATOR) reduce 511) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 511) ((T_POW) reduce 422) ((T_SL) reduce 422) ((T_SPACESHIP) reduce 422) ((T_SR) reduce 422) (("[") reduce 511) (("^") reduce 422) (("{") reduce 511) (("|") reduce 422)) 10411 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) ((":") reduce 531) (("<") reduce 531) (("=") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AND_EQUAL) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_COALESCE_EQUAL) reduce 531) ((T_CONCAT_EQUAL) reduce 531) ((T_DEC) reduce 531) ((T_DIV_EQUAL) reduce 531) ((T_INC) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_MINUS_EQUAL) reduce 531) ((T_MOD_EQUAL) reduce 531) ((T_MUL_EQUAL) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_OR_EQUAL) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_PLUS_EQUAL) reduce 531) ((T_POW) reduce 531) ((T_POW_EQUAL) reduce 531) ((T_SL) reduce 531) ((T_SL_EQUAL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) ((T_SR_EQUAL) reduce 531) ((T_XOR_EQUAL) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 10414 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) ((":") reduce 530) (("<") reduce 530) (("=") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AND_EQUAL) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_COALESCE_EQUAL) reduce 530) ((T_CONCAT_EQUAL) reduce 530) ((T_DEC) reduce 530) ((T_DIV_EQUAL) reduce 530) ((T_INC) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_MINUS_EQUAL) reduce 530) ((T_MOD_EQUAL) reduce 530) ((T_MUL_EQUAL) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_OR_EQUAL) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_PLUS_EQUAL) reduce 530) ((T_POW) reduce 530) ((T_POW_EQUAL) reduce 530) ((T_SL) reduce 530) ((T_SL_EQUAL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) ((T_SR_EQUAL) reduce 530) ((T_XOR_EQUAL) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 10416 ((("%") reduce 485) (("(") reduce 485) (("*") reduce 485) (("+") reduce 485) (("-") reduce 485) ((".") reduce 485) (("/") reduce 485) ((":") reduce 485) (("<") reduce 485) ((">") reduce 485) (("?") reduce 485) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_BOOLEAN_AND) reduce 485) ((T_BOOLEAN_OR) reduce 485) ((T_COALESCE) reduce 485) ((T_INSTANCEOF) reduce 485) ((T_IS_EQUAL) reduce 485) ((T_IS_GREATER_OR_EQUAL) reduce 485) ((T_IS_IDENTICAL) reduce 485) ((T_IS_NOT_EQUAL) reduce 485) ((T_IS_NOT_IDENTICAL) reduce 485) ((T_IS_SMALLER_OR_EQUAL) reduce 485) ((T_LOGICAL_AND) reduce 485) ((T_LOGICAL_OR) reduce 485) ((T_LOGICAL_XOR) reduce 485) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 485) ((T_OBJECT_OPERATOR) reduce 485) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 485) ((T_POW) reduce 485) ((T_SL) reduce 485) ((T_SPACESHIP) reduce 485) ((T_SR) reduce 485) (("[") reduce 485) (("^") reduce 485) (("{") reduce 485) (("|") reduce 485)) 10417 ((("%") reduce 410) (("*") reduce 410) (("+") reduce 410) (("-") reduce 410) ((".") reduce 410) (("/") reduce 410) ((":") reduce 410) (("<") reduce 410) ((">") reduce 410) (("?") reduce 410) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_BOOLEAN_AND) reduce 410) ((T_BOOLEAN_OR) reduce 410) ((T_COALESCE) reduce 410) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 410) ((T_IS_GREATER_OR_EQUAL) reduce 410) ((T_IS_IDENTICAL) reduce 410) ((T_IS_NOT_EQUAL) reduce 410) ((T_IS_NOT_IDENTICAL) reduce 410) ((T_IS_SMALLER_OR_EQUAL) reduce 410) ((T_LOGICAL_AND) reduce 410) ((T_LOGICAL_OR) reduce 410) ((T_LOGICAL_XOR) reduce 410) ((T_POW) shift) ((T_SL) reduce 410) ((T_SPACESHIP) reduce 410) ((T_SR) reduce 410) (("^") reduce 410) (("|") reduce 410)) 10419 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 424) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 424) ((T_LOGICAL_OR) reduce 424) ((T_LOGICAL_XOR) reduce 424) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 424) (("^") shift) (("|") shift)) 11037 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 425) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 425) ((T_LOGICAL_OR) reduce 425) ((T_LOGICAL_XOR) reduce 425) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 425) (("^") shift) (("|") shift)) 11049 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 418) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_BOOLEAN_AND) reduce 418) ((T_BOOLEAN_OR) reduce 418) ((T_COALESCE) reduce 418) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 418) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 418) ((T_IS_NOT_EQUAL) reduce 418) ((T_IS_NOT_IDENTICAL) reduce 418) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 418) ((T_LOGICAL_OR) reduce 418) ((T_LOGICAL_XOR) reduce 418) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 418) ((T_SR) shift) (("]") reduce 418) (("^") reduce 418) (("|") reduce 418)) 11050 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 416) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_BOOLEAN_AND) reduce 416) ((T_BOOLEAN_OR) reduce 416) ((T_COALESCE) reduce 416) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 416) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 416) ((T_IS_NOT_EQUAL) reduce 416) ((T_IS_NOT_IDENTICAL) reduce 416) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 416) ((T_LOGICAL_OR) reduce 416) ((T_LOGICAL_XOR) reduce 416) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 416) ((T_SR) shift) (("]") reduce 416) (("^") reduce 416) (("|") reduce 416)) 11051 ((("%") reduce 404) (("*") reduce 404) (("+") reduce 404) (("-") reduce 404) ((".") reduce 404) (("/") reduce 404) (("<") reduce 404) ((">") reduce 404) (("?") reduce 404) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_BOOLEAN_AND) reduce 404) ((T_BOOLEAN_OR) reduce 404) ((T_COALESCE) reduce 404) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 404) ((T_IS_GREATER_OR_EQUAL) reduce 404) ((T_IS_IDENTICAL) reduce 404) ((T_IS_NOT_EQUAL) reduce 404) ((T_IS_NOT_IDENTICAL) reduce 404) ((T_IS_SMALLER_OR_EQUAL) reduce 404) ((T_LOGICAL_AND) reduce 404) ((T_LOGICAL_OR) reduce 404) ((T_LOGICAL_XOR) reduce 404) ((T_POW) shift) ((T_SL) reduce 404) ((T_SPACESHIP) reduce 404) ((T_SR) reduce 404) (("]") reduce 404) (("^") reduce 404) (("|") reduce 404)) 11052 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 399) (("/") shift) (("<") reduce 399) ((">") reduce 399) (("?") reduce 399) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_BOOLEAN_AND) reduce 399) ((T_BOOLEAN_OR) reduce 399) ((T_COALESCE) reduce 399) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 399) ((T_IS_GREATER_OR_EQUAL) reduce 399) ((T_IS_IDENTICAL) reduce 399) ((T_IS_NOT_EQUAL) reduce 399) ((T_IS_NOT_IDENTICAL) reduce 399) ((T_IS_SMALLER_OR_EQUAL) reduce 399) ((T_LOGICAL_AND) reduce 399) ((T_LOGICAL_OR) reduce 399) ((T_LOGICAL_XOR) reduce 399) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 399) ((T_SR) shift) (("]") reduce 399) (("^") reduce 399) (("|") reduce 399)) 11053 ((("%") shift) (("*") shift) (("+") reduce 401) (("-") reduce 401) ((".") reduce 401) (("/") shift) (("<") reduce 401) ((">") reduce 401) (("?") reduce 401) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_BOOLEAN_AND) reduce 401) ((T_BOOLEAN_OR) reduce 401) ((T_COALESCE) reduce 401) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 401) ((T_IS_GREATER_OR_EQUAL) reduce 401) ((T_IS_IDENTICAL) reduce 401) ((T_IS_NOT_EQUAL) reduce 401) ((T_IS_NOT_IDENTICAL) reduce 401) ((T_IS_SMALLER_OR_EQUAL) reduce 401) ((T_LOGICAL_AND) reduce 401) ((T_LOGICAL_OR) reduce 401) ((T_LOGICAL_XOR) reduce 401) ((T_POW) shift) ((T_SL) reduce 401) ((T_SPACESHIP) reduce 401) ((T_SR) reduce 401) (("]") reduce 401) (("^") reduce 401) (("|") reduce 401)) 11054 ((("%") shift) (("*") shift) (("+") reduce 400) (("-") reduce 400) ((".") reduce 400) (("/") shift) (("<") reduce 400) ((">") reduce 400) (("?") reduce 400) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_BOOLEAN_AND) reduce 400) ((T_BOOLEAN_OR) reduce 400) ((T_COALESCE) reduce 400) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 400) ((T_IS_GREATER_OR_EQUAL) reduce 400) ((T_IS_IDENTICAL) reduce 400) ((T_IS_NOT_EQUAL) reduce 400) ((T_IS_NOT_IDENTICAL) reduce 400) ((T_IS_SMALLER_OR_EQUAL) reduce 400) ((T_LOGICAL_AND) reduce 400) ((T_LOGICAL_OR) reduce 400) ((T_LOGICAL_XOR) reduce 400) ((T_POW) shift) ((T_SL) reduce 400) ((T_SPACESHIP) reduce 400) ((T_SR) reduce 400) (("]") reduce 400) (("^") reduce 400) (("|") reduce 400)) 11055 ((("%") reduce 402) (("*") reduce 402) (("+") reduce 402) (("-") reduce 402) ((".") reduce 402) (("/") reduce 402) (("<") reduce 402) ((">") reduce 402) (("?") reduce 402) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_BOOLEAN_AND) reduce 402) ((T_BOOLEAN_OR) reduce 402) ((T_COALESCE) reduce 402) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 402) ((T_IS_GREATER_OR_EQUAL) reduce 402) ((T_IS_IDENTICAL) reduce 402) ((T_IS_NOT_EQUAL) reduce 402) ((T_IS_NOT_IDENTICAL) reduce 402) ((T_IS_SMALLER_OR_EQUAL) reduce 402) ((T_LOGICAL_AND) reduce 402) ((T_LOGICAL_OR) reduce 402) ((T_LOGICAL_XOR) reduce 402) ((T_POW) shift) ((T_SL) reduce 402) ((T_SPACESHIP) reduce 402) ((T_SR) reduce 402) (("]") reduce 402) (("^") reduce 402) (("|") reduce 402)) 11056 ((("%") reduce 405) (("*") reduce 405) (("+") reduce 405) (("-") reduce 405) ((".") reduce 405) (("/") reduce 405) (("<") reduce 405) ((">") reduce 405) (("?") reduce 405) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_BOOLEAN_AND) reduce 405) ((T_BOOLEAN_OR) reduce 405) ((T_COALESCE) reduce 405) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 405) ((T_IS_GREATER_OR_EQUAL) reduce 405) ((T_IS_IDENTICAL) reduce 405) ((T_IS_NOT_EQUAL) reduce 405) ((T_IS_NOT_IDENTICAL) reduce 405) ((T_IS_SMALLER_OR_EQUAL) reduce 405) ((T_LOGICAL_AND) reduce 405) ((T_LOGICAL_OR) reduce 405) ((T_LOGICAL_XOR) reduce 405) ((T_POW) shift) ((T_SL) reduce 405) ((T_SPACESHIP) reduce 405) ((T_SR) reduce 405) (("]") reduce 405) (("^") reduce 405) (("|") reduce 405)) 11058 ((("%") reduce 73) (("(") reduce 73) (("*") reduce 73) (("+") reduce 73) (("-") reduce 73) ((".") reduce 73) (("/") reduce 73) (("<") reduce 73) ((">") reduce 73) (("?") reduce 73) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_BOOLEAN_AND) reduce 73) ((T_BOOLEAN_OR) reduce 73) ((T_COALESCE) reduce 73) ((T_INSTANCEOF) reduce 73) ((T_IS_EQUAL) reduce 73) ((T_IS_GREATER_OR_EQUAL) reduce 73) ((T_IS_IDENTICAL) reduce 73) ((T_IS_NOT_EQUAL) reduce 73) ((T_IS_NOT_IDENTICAL) reduce 73) ((T_IS_SMALLER_OR_EQUAL) reduce 73) ((T_LOGICAL_AND) reduce 73) ((T_LOGICAL_OR) reduce 73) ((T_LOGICAL_XOR) reduce 73) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 73) ((T_OBJECT_OPERATOR) reduce 73) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 73) ((T_POW) reduce 73) ((T_SL) reduce 73) ((T_SPACESHIP) reduce 73) ((T_SR) reduce 73) (("[") reduce 73) (("]") reduce 73) (("^") reduce 73) (("{") reduce 73) (("|") reduce 73)) 11059 ((("%") reduce 52) (("(") reduce 52) (("*") reduce 52) (("+") reduce 52) (("-") reduce 52) ((".") reduce 52) (("/") reduce 52) (("<") reduce 52) ((">") reduce 52) (("?") reduce 52) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_BOOLEAN_AND) reduce 52) ((T_BOOLEAN_OR) reduce 52) ((T_COALESCE) reduce 52) ((T_INSTANCEOF) reduce 52) ((T_IS_EQUAL) reduce 52) ((T_IS_GREATER_OR_EQUAL) reduce 52) ((T_IS_IDENTICAL) reduce 52) ((T_IS_NOT_EQUAL) reduce 52) ((T_IS_NOT_IDENTICAL) reduce 52) ((T_IS_SMALLER_OR_EQUAL) reduce 52) ((T_LOGICAL_AND) reduce 52) ((T_LOGICAL_OR) reduce 52) ((T_LOGICAL_XOR) reduce 52) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 52) ((T_OBJECT_OPERATOR) reduce 52) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 52) ((T_POW) reduce 52) ((T_SL) reduce 52) ((T_SPACESHIP) reduce 52) ((T_SR) reduce 52) (("[") reduce 52) (("]") reduce 52) (("^") reduce 52) (("{") reduce 52) (("|") reduce 52)) 11060 ((("%") reduce 27) (("(") reduce 27) (("*") reduce 27) (("+") reduce 27) (("-") reduce 27) ((".") reduce 27) (("/") reduce 27) (("<") reduce 27) ((">") reduce 27) (("?") reduce 27) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_BOOLEAN_AND) reduce 27) ((T_BOOLEAN_OR) reduce 27) ((T_COALESCE) reduce 27) ((T_INSTANCEOF) reduce 27) ((T_IS_EQUAL) reduce 27) ((T_IS_GREATER_OR_EQUAL) reduce 27) ((T_IS_IDENTICAL) reduce 27) ((T_IS_NOT_EQUAL) reduce 27) ((T_IS_NOT_IDENTICAL) reduce 27) ((T_IS_SMALLER_OR_EQUAL) reduce 27) ((T_LOGICAL_AND) reduce 27) ((T_LOGICAL_OR) reduce 27) ((T_LOGICAL_XOR) reduce 27) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 27) ((T_OBJECT_OPERATOR) reduce 27) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 27) ((T_POW) reduce 27) ((T_SL) reduce 27) ((T_SPACESHIP) reduce 27) ((T_SR) reduce 27) (("[") reduce 27) (("]") reduce 27) (("^") reduce 27) (("{") reduce 27) (("|") reduce 27)) 11061 ((("%") reduce 51) (("(") reduce 51) (("*") reduce 51) (("+") reduce 51) (("-") reduce 51) ((".") reduce 51) (("/") reduce 51) (("<") reduce 51) ((">") reduce 51) (("?") reduce 51) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_BOOLEAN_AND) reduce 51) ((T_BOOLEAN_OR) reduce 51) ((T_COALESCE) reduce 51) ((T_INSTANCEOF) reduce 51) ((T_IS_EQUAL) reduce 51) ((T_IS_GREATER_OR_EQUAL) reduce 51) ((T_IS_IDENTICAL) reduce 51) ((T_IS_NOT_EQUAL) reduce 51) ((T_IS_NOT_IDENTICAL) reduce 51) ((T_IS_SMALLER_OR_EQUAL) reduce 51) ((T_LOGICAL_AND) reduce 51) ((T_LOGICAL_OR) reduce 51) ((T_LOGICAL_XOR) reduce 51) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 51) ((T_OBJECT_OPERATOR) reduce 51) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 51) ((T_POW) reduce 51) ((T_SL) reduce 51) ((T_SPACESHIP) reduce 51) ((T_SR) reduce 51) (("[") reduce 51) (("]") reduce 51) (("^") reduce 51) (("{") reduce 51) (("|") reduce 51)) 11062 ((("%") reduce 53) (("(") reduce 53) (("*") reduce 53) (("+") reduce 53) (("-") reduce 53) ((".") reduce 53) (("/") reduce 53) (("<") reduce 53) ((">") reduce 53) (("?") reduce 53) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_BOOLEAN_AND) reduce 53) ((T_BOOLEAN_OR) reduce 53) ((T_COALESCE) reduce 53) ((T_INSTANCEOF) reduce 53) ((T_IS_EQUAL) reduce 53) ((T_IS_GREATER_OR_EQUAL) reduce 53) ((T_IS_IDENTICAL) reduce 53) ((T_IS_NOT_EQUAL) reduce 53) ((T_IS_NOT_IDENTICAL) reduce 53) ((T_IS_SMALLER_OR_EQUAL) reduce 53) ((T_LOGICAL_AND) reduce 53) ((T_LOGICAL_OR) reduce 53) ((T_LOGICAL_XOR) reduce 53) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 53) ((T_OBJECT_OPERATOR) reduce 53) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 53) ((T_POW) reduce 53) ((T_SL) reduce 53) ((T_SPACESHIP) reduce 53) ((T_SR) reduce 53) (("[") reduce 53) (("]") reduce 53) (("^") reduce 53) (("{") reduce 53) (("|") reduce 53)) 11063 ((("%") reduce 49) (("(") reduce 49) (("*") reduce 49) (("+") reduce 49) (("-") reduce 49) ((".") reduce 49) (("/") reduce 49) (("<") reduce 49) ((">") reduce 49) (("?") reduce 49) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_BOOLEAN_AND) reduce 49) ((T_BOOLEAN_OR) reduce 49) ((T_COALESCE) reduce 49) ((T_INSTANCEOF) reduce 49) ((T_IS_EQUAL) reduce 49) ((T_IS_GREATER_OR_EQUAL) reduce 49) ((T_IS_IDENTICAL) reduce 49) ((T_IS_NOT_EQUAL) reduce 49) ((T_IS_NOT_IDENTICAL) reduce 49) ((T_IS_SMALLER_OR_EQUAL) reduce 49) ((T_LOGICAL_AND) reduce 49) ((T_LOGICAL_OR) reduce 49) ((T_LOGICAL_XOR) reduce 49) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 49) ((T_OBJECT_OPERATOR) reduce 49) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 49) ((T_POW) reduce 49) ((T_SL) reduce 49) ((T_SPACESHIP) reduce 49) ((T_SR) reduce 49) (("[") reduce 49) (("]") reduce 49) (("^") reduce 49) (("{") reduce 49) (("|") reduce 49)) 11064 ((("%") reduce 29) (("(") reduce 29) (("*") reduce 29) (("+") reduce 29) (("-") reduce 29) ((".") reduce 29) (("/") reduce 29) (("<") reduce 29) ((">") reduce 29) (("?") reduce 29) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_BOOLEAN_AND) reduce 29) ((T_BOOLEAN_OR) reduce 29) ((T_COALESCE) reduce 29) ((T_INSTANCEOF) reduce 29) ((T_IS_EQUAL) reduce 29) ((T_IS_GREATER_OR_EQUAL) reduce 29) ((T_IS_IDENTICAL) reduce 29) ((T_IS_NOT_EQUAL) reduce 29) ((T_IS_NOT_IDENTICAL) reduce 29) ((T_IS_SMALLER_OR_EQUAL) reduce 29) ((T_LOGICAL_AND) reduce 29) ((T_LOGICAL_OR) reduce 29) ((T_LOGICAL_XOR) reduce 29) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 29) ((T_OBJECT_OPERATOR) reduce 29) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 29) ((T_POW) reduce 29) ((T_SL) reduce 29) ((T_SPACESHIP) reduce 29) ((T_SR) reduce 29) (("[") reduce 29) (("]") reduce 29) (("^") reduce 29) (("{") reduce 29) (("|") reduce 29)) 11065 ((("%") reduce 59) (("(") reduce 59) (("*") reduce 59) (("+") reduce 59) (("-") reduce 59) ((".") reduce 59) (("/") reduce 59) (("<") reduce 59) ((">") reduce 59) (("?") reduce 59) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_BOOLEAN_AND) reduce 59) ((T_BOOLEAN_OR) reduce 59) ((T_COALESCE) reduce 59) ((T_INSTANCEOF) reduce 59) ((T_IS_EQUAL) reduce 59) ((T_IS_GREATER_OR_EQUAL) reduce 59) ((T_IS_IDENTICAL) reduce 59) ((T_IS_NOT_EQUAL) reduce 59) ((T_IS_NOT_IDENTICAL) reduce 59) ((T_IS_SMALLER_OR_EQUAL) reduce 59) ((T_LOGICAL_AND) reduce 59) ((T_LOGICAL_OR) reduce 59) ((T_LOGICAL_XOR) reduce 59) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 59) ((T_OBJECT_OPERATOR) reduce 59) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 59) ((T_POW) reduce 59) ((T_SL) reduce 59) ((T_SPACESHIP) reduce 59) ((T_SR) reduce 59) (("[") reduce 59) (("]") reduce 59) (("^") reduce 59) (("{") reduce 59) (("|") reduce 59)) 11066 ((("%") reduce 60) (("(") reduce 60) (("*") reduce 60) (("+") reduce 60) (("-") reduce 60) ((".") reduce 60) (("/") reduce 60) (("<") reduce 60) ((">") reduce 60) (("?") reduce 60) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_BOOLEAN_AND) reduce 60) ((T_BOOLEAN_OR) reduce 60) ((T_COALESCE) reduce 60) ((T_INSTANCEOF) reduce 60) ((T_IS_EQUAL) reduce 60) ((T_IS_GREATER_OR_EQUAL) reduce 60) ((T_IS_IDENTICAL) reduce 60) ((T_IS_NOT_EQUAL) reduce 60) ((T_IS_NOT_IDENTICAL) reduce 60) ((T_IS_SMALLER_OR_EQUAL) reduce 60) ((T_LOGICAL_AND) reduce 60) ((T_LOGICAL_OR) reduce 60) ((T_LOGICAL_XOR) reduce 60) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 60) ((T_OBJECT_OPERATOR) reduce 60) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 60) ((T_POW) reduce 60) ((T_SL) reduce 60) ((T_SPACESHIP) reduce 60) ((T_SR) reduce 60) (("[") reduce 60) (("]") reduce 60) (("^") reduce 60) (("{") reduce 60) (("|") reduce 60)) 11067 ((("%") reduce 11) (("(") reduce 11) (("*") reduce 11) (("+") reduce 11) (("-") reduce 11) ((".") reduce 11) (("/") reduce 11) (("<") reduce 11) ((">") reduce 11) (("?") reduce 11) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_BOOLEAN_AND) reduce 11) ((T_BOOLEAN_OR) reduce 11) ((T_COALESCE) reduce 11) ((T_INSTANCEOF) reduce 11) ((T_IS_EQUAL) reduce 11) ((T_IS_GREATER_OR_EQUAL) reduce 11) ((T_IS_IDENTICAL) reduce 11) ((T_IS_NOT_EQUAL) reduce 11) ((T_IS_NOT_IDENTICAL) reduce 11) ((T_IS_SMALLER_OR_EQUAL) reduce 11) ((T_LOGICAL_AND) reduce 11) ((T_LOGICAL_OR) reduce 11) ((T_LOGICAL_XOR) reduce 11) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 11) ((T_OBJECT_OPERATOR) reduce 11) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 11) ((T_POW) reduce 11) ((T_SL) reduce 11) ((T_SPACESHIP) reduce 11) ((T_SR) reduce 11) (("[") reduce 11) (("]") reduce 11) (("^") reduce 11) (("{") reduce 11) (("|") reduce 11)) 11068 ((("%") reduce 42) (("(") reduce 42) (("*") reduce 42) (("+") reduce 42) (("-") reduce 42) ((".") reduce 42) (("/") reduce 42) (("<") reduce 42) ((">") reduce 42) (("?") reduce 42) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_BOOLEAN_AND) reduce 42) ((T_BOOLEAN_OR) reduce 42) ((T_COALESCE) reduce 42) ((T_INSTANCEOF) reduce 42) ((T_IS_EQUAL) reduce 42) ((T_IS_GREATER_OR_EQUAL) reduce 42) ((T_IS_IDENTICAL) reduce 42) ((T_IS_NOT_EQUAL) reduce 42) ((T_IS_NOT_IDENTICAL) reduce 42) ((T_IS_SMALLER_OR_EQUAL) reduce 42) ((T_LOGICAL_AND) reduce 42) ((T_LOGICAL_OR) reduce 42) ((T_LOGICAL_XOR) reduce 42) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 42) ((T_OBJECT_OPERATOR) reduce 42) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 42) ((T_POW) reduce 42) ((T_SL) reduce 42) ((T_SPACESHIP) reduce 42) ((T_SR) reduce 42) (("[") reduce 42) (("]") reduce 42) (("^") reduce 42) (("{") reduce 42) (("|") reduce 42)) 11069 ((("%") reduce 39) (("(") reduce 39) (("*") reduce 39) (("+") reduce 39) (("-") reduce 39) ((".") reduce 39) (("/") reduce 39) (("<") reduce 39) ((">") reduce 39) (("?") reduce 39) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_BOOLEAN_AND) reduce 39) ((T_BOOLEAN_OR) reduce 39) ((T_COALESCE) reduce 39) ((T_INSTANCEOF) reduce 39) ((T_IS_EQUAL) reduce 39) ((T_IS_GREATER_OR_EQUAL) reduce 39) ((T_IS_IDENTICAL) reduce 39) ((T_IS_NOT_EQUAL) reduce 39) ((T_IS_NOT_IDENTICAL) reduce 39) ((T_IS_SMALLER_OR_EQUAL) reduce 39) ((T_LOGICAL_AND) reduce 39) ((T_LOGICAL_OR) reduce 39) ((T_LOGICAL_XOR) reduce 39) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 39) ((T_OBJECT_OPERATOR) reduce 39) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 39) ((T_POW) reduce 39) ((T_SL) reduce 39) ((T_SPACESHIP) reduce 39) ((T_SR) reduce 39) (("[") reduce 39) (("]") reduce 39) (("^") reduce 39) (("{") reduce 39) (("|") reduce 39)) 11070 ((("%") reduce 25) (("(") reduce 25) (("*") reduce 25) (("+") reduce 25) (("-") reduce 25) ((".") reduce 25) (("/") reduce 25) (("<") reduce 25) ((">") reduce 25) (("?") reduce 25) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_BOOLEAN_AND) reduce 25) ((T_BOOLEAN_OR) reduce 25) ((T_COALESCE) reduce 25) ((T_INSTANCEOF) reduce 25) ((T_IS_EQUAL) reduce 25) ((T_IS_GREATER_OR_EQUAL) reduce 25) ((T_IS_IDENTICAL) reduce 25) ((T_IS_NOT_EQUAL) reduce 25) ((T_IS_NOT_IDENTICAL) reduce 25) ((T_IS_SMALLER_OR_EQUAL) reduce 25) ((T_LOGICAL_AND) reduce 25) ((T_LOGICAL_OR) reduce 25) ((T_LOGICAL_XOR) reduce 25) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 25) ((T_OBJECT_OPERATOR) reduce 25) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 25) ((T_POW) reduce 25) ((T_SL) reduce 25) ((T_SPACESHIP) reduce 25) ((T_SR) reduce 25) (("[") reduce 25) (("]") reduce 25) (("^") reduce 25) (("{") reduce 25) (("|") reduce 25)) 11071 ((("%") reduce 50) (("(") reduce 50) (("*") reduce 50) (("+") reduce 50) (("-") reduce 50) ((".") reduce 50) (("/") reduce 50) (("<") reduce 50) ((">") reduce 50) (("?") reduce 50) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_BOOLEAN_AND) reduce 50) ((T_BOOLEAN_OR) reduce 50) ((T_COALESCE) reduce 50) ((T_INSTANCEOF) reduce 50) ((T_IS_EQUAL) reduce 50) ((T_IS_GREATER_OR_EQUAL) reduce 50) ((T_IS_IDENTICAL) reduce 50) ((T_IS_NOT_EQUAL) reduce 50) ((T_IS_NOT_IDENTICAL) reduce 50) ((T_IS_SMALLER_OR_EQUAL) reduce 50) ((T_LOGICAL_AND) reduce 50) ((T_LOGICAL_OR) reduce 50) ((T_LOGICAL_XOR) reduce 50) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 50) ((T_OBJECT_OPERATOR) reduce 50) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 50) ((T_POW) reduce 50) ((T_SL) reduce 50) ((T_SPACESHIP) reduce 50) ((T_SR) reduce 50) (("[") reduce 50) (("]") reduce 50) (("^") reduce 50) (("{") reduce 50) (("|") reduce 50)) 11072 ((("%") reduce 66) (("(") reduce 66) (("*") reduce 66) (("+") reduce 66) (("-") reduce 66) ((".") reduce 66) (("/") reduce 66) (("<") reduce 66) ((">") reduce 66) (("?") reduce 66) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_BOOLEAN_AND) reduce 66) ((T_BOOLEAN_OR) reduce 66) ((T_COALESCE) reduce 66) ((T_INSTANCEOF) reduce 66) ((T_IS_EQUAL) reduce 66) ((T_IS_GREATER_OR_EQUAL) reduce 66) ((T_IS_IDENTICAL) reduce 66) ((T_IS_NOT_EQUAL) reduce 66) ((T_IS_NOT_IDENTICAL) reduce 66) ((T_IS_SMALLER_OR_EQUAL) reduce 66) ((T_LOGICAL_AND) reduce 66) ((T_LOGICAL_OR) reduce 66) ((T_LOGICAL_XOR) reduce 66) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 66) ((T_OBJECT_OPERATOR) reduce 66) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 66) ((T_POW) reduce 66) ((T_SL) reduce 66) ((T_SPACESHIP) reduce 66) ((T_SR) reduce 66) (("[") reduce 66) (("]") reduce 66) (("^") reduce 66) (("{") reduce 66) (("|") reduce 66)) 11073 ((("%") reduce 18) (("(") reduce 18) (("*") reduce 18) (("+") reduce 18) (("-") reduce 18) ((".") reduce 18) (("/") reduce 18) (("<") reduce 18) ((">") reduce 18) (("?") reduce 18) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_BOOLEAN_AND) reduce 18) ((T_BOOLEAN_OR) reduce 18) ((T_COALESCE) reduce 18) ((T_INSTANCEOF) reduce 18) ((T_IS_EQUAL) reduce 18) ((T_IS_GREATER_OR_EQUAL) reduce 18) ((T_IS_IDENTICAL) reduce 18) ((T_IS_NOT_EQUAL) reduce 18) ((T_IS_NOT_IDENTICAL) reduce 18) ((T_IS_SMALLER_OR_EQUAL) reduce 18) ((T_LOGICAL_AND) reduce 18) ((T_LOGICAL_OR) reduce 18) ((T_LOGICAL_XOR) reduce 18) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 18) ((T_OBJECT_OPERATOR) reduce 18) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 18) ((T_POW) reduce 18) ((T_SL) reduce 18) ((T_SPACESHIP) reduce 18) ((T_SR) reduce 18) (("[") reduce 18) (("]") reduce 18) (("^") reduce 18) (("{") reduce 18) (("|") reduce 18)) 11074 ((("%") reduce 17) (("(") reduce 17) (("*") reduce 17) (("+") reduce 17) (("-") reduce 17) ((".") reduce 17) (("/") reduce 17) (("<") reduce 17) ((">") reduce 17) (("?") reduce 17) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_BOOLEAN_AND) reduce 17) ((T_BOOLEAN_OR) reduce 17) ((T_COALESCE) reduce 17) ((T_INSTANCEOF) reduce 17) ((T_IS_EQUAL) reduce 17) ((T_IS_GREATER_OR_EQUAL) reduce 17) ((T_IS_IDENTICAL) reduce 17) ((T_IS_NOT_EQUAL) reduce 17) ((T_IS_NOT_IDENTICAL) reduce 17) ((T_IS_SMALLER_OR_EQUAL) reduce 17) ((T_LOGICAL_AND) reduce 17) ((T_LOGICAL_OR) reduce 17) ((T_LOGICAL_XOR) reduce 17) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 17) ((T_OBJECT_OPERATOR) reduce 17) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 17) ((T_POW) reduce 17) ((T_SL) reduce 17) ((T_SPACESHIP) reduce 17) ((T_SR) reduce 17) (("[") reduce 17) (("]") reduce 17) (("^") reduce 17) (("{") reduce 17) (("|") reduce 17)) 11075 ((("%") reduce 15) (("(") reduce 15) (("*") reduce 15) (("+") reduce 15) (("-") reduce 15) ((".") reduce 15) (("/") reduce 15) (("<") reduce 15) ((">") reduce 15) (("?") reduce 15) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_BOOLEAN_AND) reduce 15) ((T_BOOLEAN_OR) reduce 15) ((T_COALESCE) reduce 15) ((T_INSTANCEOF) reduce 15) ((T_IS_EQUAL) reduce 15) ((T_IS_GREATER_OR_EQUAL) reduce 15) ((T_IS_IDENTICAL) reduce 15) ((T_IS_NOT_EQUAL) reduce 15) ((T_IS_NOT_IDENTICAL) reduce 15) ((T_IS_SMALLER_OR_EQUAL) reduce 15) ((T_LOGICAL_AND) reduce 15) ((T_LOGICAL_OR) reduce 15) ((T_LOGICAL_XOR) reduce 15) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 15) ((T_OBJECT_OPERATOR) reduce 15) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 15) ((T_POW) reduce 15) ((T_SL) reduce 15) ((T_SPACESHIP) reduce 15) ((T_SR) reduce 15) (("[") reduce 15) (("]") reduce 15) (("^") reduce 15) (("{") reduce 15) (("|") reduce 15)) 11076 ((("%") reduce 14) (("(") reduce 14) (("*") reduce 14) (("+") reduce 14) (("-") reduce 14) ((".") reduce 14) (("/") reduce 14) (("<") reduce 14) ((">") reduce 14) (("?") reduce 14) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_BOOLEAN_AND) reduce 14) ((T_BOOLEAN_OR) reduce 14) ((T_COALESCE) reduce 14) ((T_INSTANCEOF) reduce 14) ((T_IS_EQUAL) reduce 14) ((T_IS_GREATER_OR_EQUAL) reduce 14) ((T_IS_IDENTICAL) reduce 14) ((T_IS_NOT_EQUAL) reduce 14) ((T_IS_NOT_IDENTICAL) reduce 14) ((T_IS_SMALLER_OR_EQUAL) reduce 14) ((T_LOGICAL_AND) reduce 14) ((T_LOGICAL_OR) reduce 14) ((T_LOGICAL_XOR) reduce 14) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 14) ((T_OBJECT_OPERATOR) reduce 14) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 14) ((T_POW) reduce 14) ((T_SL) reduce 14) ((T_SPACESHIP) reduce 14) ((T_SR) reduce 14) (("[") reduce 14) (("]") reduce 14) (("^") reduce 14) (("{") reduce 14) (("|") reduce 14)) 11077 ((("%") reduce 38) (("(") reduce 38) (("*") reduce 38) (("+") reduce 38) (("-") reduce 38) ((".") reduce 38) (("/") reduce 38) (("<") reduce 38) ((">") reduce 38) (("?") reduce 38) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_BOOLEAN_AND) reduce 38) ((T_BOOLEAN_OR) reduce 38) ((T_COALESCE) reduce 38) ((T_INSTANCEOF) reduce 38) ((T_IS_EQUAL) reduce 38) ((T_IS_GREATER_OR_EQUAL) reduce 38) ((T_IS_IDENTICAL) reduce 38) ((T_IS_NOT_EQUAL) reduce 38) ((T_IS_NOT_IDENTICAL) reduce 38) ((T_IS_SMALLER_OR_EQUAL) reduce 38) ((T_LOGICAL_AND) reduce 38) ((T_LOGICAL_OR) reduce 38) ((T_LOGICAL_XOR) reduce 38) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 38) ((T_OBJECT_OPERATOR) reduce 38) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 38) ((T_POW) reduce 38) ((T_SL) reduce 38) ((T_SPACESHIP) reduce 38) ((T_SR) reduce 38) (("[") reduce 38) (("]") reduce 38) (("^") reduce 38) (("{") reduce 38) (("|") reduce 38)) 11078 ((("%") reduce 26) (("(") reduce 26) (("*") reduce 26) (("+") reduce 26) (("-") reduce 26) ((".") reduce 26) (("/") reduce 26) (("<") reduce 26) ((">") reduce 26) (("?") reduce 26) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_BOOLEAN_AND) reduce 26) ((T_BOOLEAN_OR) reduce 26) ((T_COALESCE) reduce 26) ((T_INSTANCEOF) reduce 26) ((T_IS_EQUAL) reduce 26) ((T_IS_GREATER_OR_EQUAL) reduce 26) ((T_IS_IDENTICAL) reduce 26) ((T_IS_NOT_EQUAL) reduce 26) ((T_IS_NOT_IDENTICAL) reduce 26) ((T_IS_SMALLER_OR_EQUAL) reduce 26) ((T_LOGICAL_AND) reduce 26) ((T_LOGICAL_OR) reduce 26) ((T_LOGICAL_XOR) reduce 26) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 26) ((T_OBJECT_OPERATOR) reduce 26) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 26) ((T_POW) reduce 26) ((T_SL) reduce 26) ((T_SPACESHIP) reduce 26) ((T_SR) reduce 26) (("[") reduce 26) (("]") reduce 26) (("^") reduce 26) (("{") reduce 26) (("|") reduce 26)) 11079 ((("%") reduce 22) (("(") reduce 22) (("*") reduce 22) (("+") reduce 22) (("-") reduce 22) ((".") reduce 22) (("/") reduce 22) (("<") reduce 22) ((">") reduce 22) (("?") reduce 22) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_BOOLEAN_AND) reduce 22) ((T_BOOLEAN_OR) reduce 22) ((T_COALESCE) reduce 22) ((T_INSTANCEOF) reduce 22) ((T_IS_EQUAL) reduce 22) ((T_IS_GREATER_OR_EQUAL) reduce 22) ((T_IS_IDENTICAL) reduce 22) ((T_IS_NOT_EQUAL) reduce 22) ((T_IS_NOT_IDENTICAL) reduce 22) ((T_IS_SMALLER_OR_EQUAL) reduce 22) ((T_LOGICAL_AND) reduce 22) ((T_LOGICAL_OR) reduce 22) ((T_LOGICAL_XOR) reduce 22) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 22) ((T_OBJECT_OPERATOR) reduce 22) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 22) ((T_POW) reduce 22) ((T_SL) reduce 22) ((T_SPACESHIP) reduce 22) ((T_SR) reduce 22) (("[") reduce 22) (("]") reduce 22) (("^") reduce 22) (("{") reduce 22) (("|") reduce 22)) 11080 ((("%") reduce 24) (("(") reduce 24) (("*") reduce 24) (("+") reduce 24) (("-") reduce 24) ((".") reduce 24) (("/") reduce 24) (("<") reduce 24) ((">") reduce 24) (("?") reduce 24) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_BOOLEAN_AND) reduce 24) ((T_BOOLEAN_OR) reduce 24) ((T_COALESCE) reduce 24) ((T_INSTANCEOF) reduce 24) ((T_IS_EQUAL) reduce 24) ((T_IS_GREATER_OR_EQUAL) reduce 24) ((T_IS_IDENTICAL) reduce 24) ((T_IS_NOT_EQUAL) reduce 24) ((T_IS_NOT_IDENTICAL) reduce 24) ((T_IS_SMALLER_OR_EQUAL) reduce 24) ((T_LOGICAL_AND) reduce 24) ((T_LOGICAL_OR) reduce 24) ((T_LOGICAL_XOR) reduce 24) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 24) ((T_OBJECT_OPERATOR) reduce 24) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 24) ((T_POW) reduce 24) ((T_SL) reduce 24) ((T_SPACESHIP) reduce 24) ((T_SR) reduce 24) (("[") reduce 24) (("]") reduce 24) (("^") reduce 24) (("{") reduce 24) (("|") reduce 24)) 11081 ((("%") reduce 16) (("(") reduce 16) (("*") reduce 16) (("+") reduce 16) (("-") reduce 16) ((".") reduce 16) (("/") reduce 16) (("<") reduce 16) ((">") reduce 16) (("?") reduce 16) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_BOOLEAN_AND) reduce 16) ((T_BOOLEAN_OR) reduce 16) ((T_COALESCE) reduce 16) ((T_INSTANCEOF) reduce 16) ((T_IS_EQUAL) reduce 16) ((T_IS_GREATER_OR_EQUAL) reduce 16) ((T_IS_IDENTICAL) reduce 16) ((T_IS_NOT_EQUAL) reduce 16) ((T_IS_NOT_IDENTICAL) reduce 16) ((T_IS_SMALLER_OR_EQUAL) reduce 16) ((T_LOGICAL_AND) reduce 16) ((T_LOGICAL_OR) reduce 16) ((T_LOGICAL_XOR) reduce 16) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 16) ((T_OBJECT_OPERATOR) reduce 16) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 16) ((T_POW) reduce 16) ((T_SL) reduce 16) ((T_SPACESHIP) reduce 16) ((T_SR) reduce 16) (("[") reduce 16) (("]") reduce 16) (("^") reduce 16) (("{") reduce 16) (("|") reduce 16)) 11082 ((("%") reduce 48) (("(") reduce 48) (("*") reduce 48) (("+") reduce 48) (("-") reduce 48) ((".") reduce 48) (("/") reduce 48) (("<") reduce 48) ((">") reduce 48) (("?") reduce 48) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_BOOLEAN_AND) reduce 48) ((T_BOOLEAN_OR) reduce 48) ((T_COALESCE) reduce 48) ((T_INSTANCEOF) reduce 48) ((T_IS_EQUAL) reduce 48) ((T_IS_GREATER_OR_EQUAL) reduce 48) ((T_IS_IDENTICAL) reduce 48) ((T_IS_NOT_EQUAL) reduce 48) ((T_IS_NOT_IDENTICAL) reduce 48) ((T_IS_SMALLER_OR_EQUAL) reduce 48) ((T_LOGICAL_AND) reduce 48) ((T_LOGICAL_OR) reduce 48) ((T_LOGICAL_XOR) reduce 48) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 48) ((T_OBJECT_OPERATOR) reduce 48) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 48) ((T_POW) reduce 48) ((T_SL) reduce 48) ((T_SPACESHIP) reduce 48) ((T_SR) reduce 48) (("[") reduce 48) (("]") reduce 48) (("^") reduce 48) (("{") reduce 48) (("|") reduce 48)) 11083 ((("%") reduce 20) (("(") reduce 20) (("*") reduce 20) (("+") reduce 20) (("-") reduce 20) ((".") reduce 20) (("/") reduce 20) (("<") reduce 20) ((">") reduce 20) (("?") reduce 20) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_BOOLEAN_AND) reduce 20) ((T_BOOLEAN_OR) reduce 20) ((T_COALESCE) reduce 20) ((T_INSTANCEOF) reduce 20) ((T_IS_EQUAL) reduce 20) ((T_IS_GREATER_OR_EQUAL) reduce 20) ((T_IS_IDENTICAL) reduce 20) ((T_IS_NOT_EQUAL) reduce 20) ((T_IS_NOT_IDENTICAL) reduce 20) ((T_IS_SMALLER_OR_EQUAL) reduce 20) ((T_LOGICAL_AND) reduce 20) ((T_LOGICAL_OR) reduce 20) ((T_LOGICAL_XOR) reduce 20) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 20) ((T_OBJECT_OPERATOR) reduce 20) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 20) ((T_POW) reduce 20) ((T_SL) reduce 20) ((T_SPACESHIP) reduce 20) ((T_SR) reduce 20) (("[") reduce 20) (("]") reduce 20) (("^") reduce 20) (("{") reduce 20) (("|") reduce 20)) 11084 ((("%") reduce 70) (("(") reduce 70) (("*") reduce 70) (("+") reduce 70) (("-") reduce 70) ((".") reduce 70) (("/") reduce 70) (("<") reduce 70) ((">") reduce 70) (("?") reduce 70) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_BOOLEAN_AND) reduce 70) ((T_BOOLEAN_OR) reduce 70) ((T_COALESCE) reduce 70) ((T_INSTANCEOF) reduce 70) ((T_IS_EQUAL) reduce 70) ((T_IS_GREATER_OR_EQUAL) reduce 70) ((T_IS_IDENTICAL) reduce 70) ((T_IS_NOT_EQUAL) reduce 70) ((T_IS_NOT_IDENTICAL) reduce 70) ((T_IS_SMALLER_OR_EQUAL) reduce 70) ((T_LOGICAL_AND) reduce 70) ((T_LOGICAL_OR) reduce 70) ((T_LOGICAL_XOR) reduce 70) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 70) ((T_OBJECT_OPERATOR) reduce 70) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 70) ((T_POW) reduce 70) ((T_SL) reduce 70) ((T_SPACESHIP) reduce 70) ((T_SR) reduce 70) (("[") reduce 70) (("]") reduce 70) (("^") reduce 70) (("{") reduce 70) (("|") reduce 70)) 11085 ((("%") reduce 3) (("(") reduce 3) (("*") reduce 3) (("+") reduce 3) (("-") reduce 3) ((".") reduce 3) (("/") reduce 3) (("<") reduce 3) ((">") reduce 3) (("?") reduce 3) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_BOOLEAN_AND) reduce 3) ((T_BOOLEAN_OR) reduce 3) ((T_COALESCE) reduce 3) ((T_INSTANCEOF) reduce 3) ((T_IS_EQUAL) reduce 3) ((T_IS_GREATER_OR_EQUAL) reduce 3) ((T_IS_IDENTICAL) reduce 3) ((T_IS_NOT_EQUAL) reduce 3) ((T_IS_NOT_IDENTICAL) reduce 3) ((T_IS_SMALLER_OR_EQUAL) reduce 3) ((T_LOGICAL_AND) reduce 3) ((T_LOGICAL_OR) reduce 3) ((T_LOGICAL_XOR) reduce 3) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 3) ((T_OBJECT_OPERATOR) reduce 3) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 3) ((T_POW) reduce 3) ((T_SL) reduce 3) ((T_SPACESHIP) reduce 3) ((T_SR) reduce 3) (("[") reduce 3) (("]") reduce 3) (("^") reduce 3) (("{") reduce 3) (("|") reduce 3)) 11086 ((("%") reduce 12) (("(") reduce 12) (("*") reduce 12) (("+") reduce 12) (("-") reduce 12) ((".") reduce 12) (("/") reduce 12) (("<") reduce 12) ((">") reduce 12) (("?") reduce 12) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_BOOLEAN_AND) reduce 12) ((T_BOOLEAN_OR) reduce 12) ((T_COALESCE) reduce 12) ((T_INSTANCEOF) reduce 12) ((T_IS_EQUAL) reduce 12) ((T_IS_GREATER_OR_EQUAL) reduce 12) ((T_IS_IDENTICAL) reduce 12) ((T_IS_NOT_EQUAL) reduce 12) ((T_IS_NOT_IDENTICAL) reduce 12) ((T_IS_SMALLER_OR_EQUAL) reduce 12) ((T_LOGICAL_AND) reduce 12) ((T_LOGICAL_OR) reduce 12) ((T_LOGICAL_XOR) reduce 12) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 12) ((T_OBJECT_OPERATOR) reduce 12) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 12) ((T_POW) reduce 12) ((T_SL) reduce 12) ((T_SPACESHIP) reduce 12) ((T_SR) reduce 12) (("[") reduce 12) (("]") reduce 12) (("^") reduce 12) (("{") reduce 12) (("|") reduce 12)) 11087 ((("%") reduce 54) (("(") reduce 54) (("*") reduce 54) (("+") reduce 54) (("-") reduce 54) ((".") reduce 54) (("/") reduce 54) (("<") reduce 54) ((">") reduce 54) (("?") reduce 54) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_BOOLEAN_AND) reduce 54) ((T_BOOLEAN_OR) reduce 54) ((T_COALESCE) reduce 54) ((T_INSTANCEOF) reduce 54) ((T_IS_EQUAL) reduce 54) ((T_IS_GREATER_OR_EQUAL) reduce 54) ((T_IS_IDENTICAL) reduce 54) ((T_IS_NOT_EQUAL) reduce 54) ((T_IS_NOT_IDENTICAL) reduce 54) ((T_IS_SMALLER_OR_EQUAL) reduce 54) ((T_LOGICAL_AND) reduce 54) ((T_LOGICAL_OR) reduce 54) ((T_LOGICAL_XOR) reduce 54) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 54) ((T_OBJECT_OPERATOR) reduce 54) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 54) ((T_POW) reduce 54) ((T_SL) reduce 54) ((T_SPACESHIP) reduce 54) ((T_SR) reduce 54) (("[") reduce 54) (("]") reduce 54) (("^") reduce 54) (("{") reduce 54) (("|") reduce 54)) 11088 ((("%") reduce 65) (("(") reduce 65) (("*") reduce 65) (("+") reduce 65) (("-") reduce 65) ((".") reduce 65) (("/") reduce 65) (("<") reduce 65) ((">") reduce 65) (("?") reduce 65) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_BOOLEAN_AND) reduce 65) ((T_BOOLEAN_OR) reduce 65) ((T_COALESCE) reduce 65) ((T_INSTANCEOF) reduce 65) ((T_IS_EQUAL) reduce 65) ((T_IS_GREATER_OR_EQUAL) reduce 65) ((T_IS_IDENTICAL) reduce 65) ((T_IS_NOT_EQUAL) reduce 65) ((T_IS_NOT_IDENTICAL) reduce 65) ((T_IS_SMALLER_OR_EQUAL) reduce 65) ((T_LOGICAL_AND) reduce 65) ((T_LOGICAL_OR) reduce 65) ((T_LOGICAL_XOR) reduce 65) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 65) ((T_OBJECT_OPERATOR) reduce 65) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 65) ((T_POW) reduce 65) ((T_SL) reduce 65) ((T_SPACESHIP) reduce 65) ((T_SR) reduce 65) (("[") reduce 65) (("]") reduce 65) (("^") reduce 65) (("{") reduce 65) (("|") reduce 65)) 11089 ((("%") reduce 74) (("(") reduce 74) (("*") reduce 74) (("+") reduce 74) (("-") reduce 74) ((".") reduce 74) (("/") reduce 74) (("<") reduce 74) ((">") reduce 74) (("?") reduce 74) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_BOOLEAN_AND) reduce 74) ((T_BOOLEAN_OR) reduce 74) ((T_COALESCE) reduce 74) ((T_INSTANCEOF) reduce 74) ((T_IS_EQUAL) reduce 74) ((T_IS_GREATER_OR_EQUAL) reduce 74) ((T_IS_IDENTICAL) reduce 74) ((T_IS_NOT_EQUAL) reduce 74) ((T_IS_NOT_IDENTICAL) reduce 74) ((T_IS_SMALLER_OR_EQUAL) reduce 74) ((T_LOGICAL_AND) reduce 74) ((T_LOGICAL_OR) reduce 74) ((T_LOGICAL_XOR) reduce 74) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 74) ((T_OBJECT_OPERATOR) reduce 74) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 74) ((T_POW) reduce 74) ((T_SL) reduce 74) ((T_SPACESHIP) reduce 74) ((T_SR) reduce 74) (("[") reduce 74) (("]") reduce 74) (("^") reduce 74) (("{") reduce 74) (("|") reduce 74)) 11090 ((("%") reduce 30) (("(") reduce 30) (("*") reduce 30) (("+") reduce 30) (("-") reduce 30) ((".") reduce 30) (("/") reduce 30) (("<") reduce 30) ((">") reduce 30) (("?") reduce 30) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_BOOLEAN_AND) reduce 30) ((T_BOOLEAN_OR) reduce 30) ((T_COALESCE) reduce 30) ((T_INSTANCEOF) reduce 30) ((T_IS_EQUAL) reduce 30) ((T_IS_GREATER_OR_EQUAL) reduce 30) ((T_IS_IDENTICAL) reduce 30) ((T_IS_NOT_EQUAL) reduce 30) ((T_IS_NOT_IDENTICAL) reduce 30) ((T_IS_SMALLER_OR_EQUAL) reduce 30) ((T_LOGICAL_AND) reduce 30) ((T_LOGICAL_OR) reduce 30) ((T_LOGICAL_XOR) reduce 30) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 30) ((T_OBJECT_OPERATOR) reduce 30) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 30) ((T_POW) reduce 30) ((T_SL) reduce 30) ((T_SPACESHIP) reduce 30) ((T_SR) reduce 30) (("[") reduce 30) (("]") reduce 30) (("^") reduce 30) (("{") reduce 30) (("|") reduce 30)) 11091 ((("%") reduce 68) (("(") reduce 68) (("*") reduce 68) (("+") reduce 68) (("-") reduce 68) ((".") reduce 68) (("/") reduce 68) (("<") reduce 68) ((">") reduce 68) (("?") reduce 68) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_BOOLEAN_AND) reduce 68) ((T_BOOLEAN_OR) reduce 68) ((T_COALESCE) reduce 68) ((T_INSTANCEOF) reduce 68) ((T_IS_EQUAL) reduce 68) ((T_IS_GREATER_OR_EQUAL) reduce 68) ((T_IS_IDENTICAL) reduce 68) ((T_IS_NOT_EQUAL) reduce 68) ((T_IS_NOT_IDENTICAL) reduce 68) ((T_IS_SMALLER_OR_EQUAL) reduce 68) ((T_LOGICAL_AND) reduce 68) ((T_LOGICAL_OR) reduce 68) ((T_LOGICAL_XOR) reduce 68) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 68) ((T_OBJECT_OPERATOR) reduce 68) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 68) ((T_POW) reduce 68) ((T_SL) reduce 68) ((T_SPACESHIP) reduce 68) ((T_SR) reduce 68) (("[") reduce 68) (("]") reduce 68) (("^") reduce 68) (("{") reduce 68) (("|") reduce 68)) 11092 ((("%") reduce 21) (("(") reduce 21) (("*") reduce 21) (("+") reduce 21) (("-") reduce 21) ((".") reduce 21) (("/") reduce 21) (("<") reduce 21) ((">") reduce 21) (("?") reduce 21) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_BOOLEAN_AND) reduce 21) ((T_BOOLEAN_OR) reduce 21) ((T_COALESCE) reduce 21) ((T_INSTANCEOF) reduce 21) ((T_IS_EQUAL) reduce 21) ((T_IS_GREATER_OR_EQUAL) reduce 21) ((T_IS_IDENTICAL) reduce 21) ((T_IS_NOT_EQUAL) reduce 21) ((T_IS_NOT_IDENTICAL) reduce 21) ((T_IS_SMALLER_OR_EQUAL) reduce 21) ((T_LOGICAL_AND) reduce 21) ((T_LOGICAL_OR) reduce 21) ((T_LOGICAL_XOR) reduce 21) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 21) ((T_OBJECT_OPERATOR) reduce 21) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 21) ((T_POW) reduce 21) ((T_SL) reduce 21) ((T_SPACESHIP) reduce 21) ((T_SR) reduce 21) (("[") reduce 21) (("]") reduce 21) (("^") reduce 21) (("{") reduce 21) (("|") reduce 21)) 11093 ((("%") reduce 23) (("(") reduce 23) (("*") reduce 23) (("+") reduce 23) (("-") reduce 23) ((".") reduce 23) (("/") reduce 23) (("<") reduce 23) ((">") reduce 23) (("?") reduce 23) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_BOOLEAN_AND) reduce 23) ((T_BOOLEAN_OR) reduce 23) ((T_COALESCE) reduce 23) ((T_INSTANCEOF) reduce 23) ((T_IS_EQUAL) reduce 23) ((T_IS_GREATER_OR_EQUAL) reduce 23) ((T_IS_IDENTICAL) reduce 23) ((T_IS_NOT_EQUAL) reduce 23) ((T_IS_NOT_IDENTICAL) reduce 23) ((T_IS_SMALLER_OR_EQUAL) reduce 23) ((T_LOGICAL_AND) reduce 23) ((T_LOGICAL_OR) reduce 23) ((T_LOGICAL_XOR) reduce 23) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 23) ((T_OBJECT_OPERATOR) reduce 23) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 23) ((T_POW) reduce 23) ((T_SL) reduce 23) ((T_SPACESHIP) reduce 23) ((T_SR) reduce 23) (("[") reduce 23) (("]") reduce 23) (("^") reduce 23) (("{") reduce 23) (("|") reduce 23)) 11094 ((("%") reduce 41) (("(") reduce 41) (("*") reduce 41) (("+") reduce 41) (("-") reduce 41) ((".") reduce 41) (("/") reduce 41) (("<") reduce 41) ((">") reduce 41) (("?") reduce 41) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_BOOLEAN_AND) reduce 41) ((T_BOOLEAN_OR) reduce 41) ((T_COALESCE) reduce 41) ((T_INSTANCEOF) reduce 41) ((T_IS_EQUAL) reduce 41) ((T_IS_GREATER_OR_EQUAL) reduce 41) ((T_IS_IDENTICAL) reduce 41) ((T_IS_NOT_EQUAL) reduce 41) ((T_IS_NOT_IDENTICAL) reduce 41) ((T_IS_SMALLER_OR_EQUAL) reduce 41) ((T_LOGICAL_AND) reduce 41) ((T_LOGICAL_OR) reduce 41) ((T_LOGICAL_XOR) reduce 41) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 41) ((T_OBJECT_OPERATOR) reduce 41) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 41) ((T_POW) reduce 41) ((T_SL) reduce 41) ((T_SPACESHIP) reduce 41) ((T_SR) reduce 41) (("[") reduce 41) (("]") reduce 41) (("^") reduce 41) (("{") reduce 41) (("|") reduce 41)) 11095 ((("%") reduce 62) (("(") reduce 62) (("*") reduce 62) (("+") reduce 62) (("-") reduce 62) ((".") reduce 62) (("/") reduce 62) (("<") reduce 62) ((">") reduce 62) (("?") reduce 62) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_BOOLEAN_AND) reduce 62) ((T_BOOLEAN_OR) reduce 62) ((T_COALESCE) reduce 62) ((T_INSTANCEOF) reduce 62) ((T_IS_EQUAL) reduce 62) ((T_IS_GREATER_OR_EQUAL) reduce 62) ((T_IS_IDENTICAL) reduce 62) ((T_IS_NOT_EQUAL) reduce 62) ((T_IS_NOT_IDENTICAL) reduce 62) ((T_IS_SMALLER_OR_EQUAL) reduce 62) ((T_LOGICAL_AND) reduce 62) ((T_LOGICAL_OR) reduce 62) ((T_LOGICAL_XOR) reduce 62) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 62) ((T_OBJECT_OPERATOR) reduce 62) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 62) ((T_POW) reduce 62) ((T_SL) reduce 62) ((T_SPACESHIP) reduce 62) ((T_SR) reduce 62) (("[") reduce 62) (("]") reduce 62) (("^") reduce 62) (("{") reduce 62) (("|") reduce 62)) 11096 ((("%") reduce 34) (("(") reduce 34) (("*") reduce 34) (("+") reduce 34) (("-") reduce 34) ((".") reduce 34) (("/") reduce 34) (("<") reduce 34) ((">") reduce 34) (("?") reduce 34) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_BOOLEAN_AND) reduce 34) ((T_BOOLEAN_OR) reduce 34) ((T_COALESCE) reduce 34) ((T_INSTANCEOF) reduce 34) ((T_IS_EQUAL) reduce 34) ((T_IS_GREATER_OR_EQUAL) reduce 34) ((T_IS_IDENTICAL) reduce 34) ((T_IS_NOT_EQUAL) reduce 34) ((T_IS_NOT_IDENTICAL) reduce 34) ((T_IS_SMALLER_OR_EQUAL) reduce 34) ((T_LOGICAL_AND) reduce 34) ((T_LOGICAL_OR) reduce 34) ((T_LOGICAL_XOR) reduce 34) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 34) ((T_OBJECT_OPERATOR) reduce 34) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 34) ((T_POW) reduce 34) ((T_SL) reduce 34) ((T_SPACESHIP) reduce 34) ((T_SR) reduce 34) (("[") reduce 34) (("]") reduce 34) (("^") reduce 34) (("{") reduce 34) (("|") reduce 34)) 11097 ((("%") reduce 40) (("(") reduce 40) (("*") reduce 40) (("+") reduce 40) (("-") reduce 40) ((".") reduce 40) (("/") reduce 40) (("<") reduce 40) ((">") reduce 40) (("?") reduce 40) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_BOOLEAN_AND) reduce 40) ((T_BOOLEAN_OR) reduce 40) ((T_COALESCE) reduce 40) ((T_INSTANCEOF) reduce 40) ((T_IS_EQUAL) reduce 40) ((T_IS_GREATER_OR_EQUAL) reduce 40) ((T_IS_IDENTICAL) reduce 40) ((T_IS_NOT_EQUAL) reduce 40) ((T_IS_NOT_IDENTICAL) reduce 40) ((T_IS_SMALLER_OR_EQUAL) reduce 40) ((T_LOGICAL_AND) reduce 40) ((T_LOGICAL_OR) reduce 40) ((T_LOGICAL_XOR) reduce 40) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 40) ((T_OBJECT_OPERATOR) reduce 40) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 40) ((T_POW) reduce 40) ((T_SL) reduce 40) ((T_SPACESHIP) reduce 40) ((T_SR) reduce 40) (("[") reduce 40) (("]") reduce 40) (("^") reduce 40) (("{") reduce 40) (("|") reduce 40)) 11098 ((("%") reduce 13) (("(") reduce 13) (("*") reduce 13) (("+") reduce 13) (("-") reduce 13) ((".") reduce 13) (("/") reduce 13) (("<") reduce 13) ((">") reduce 13) (("?") reduce 13) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_BOOLEAN_AND) reduce 13) ((T_BOOLEAN_OR) reduce 13) ((T_COALESCE) reduce 13) ((T_INSTANCEOF) reduce 13) ((T_IS_EQUAL) reduce 13) ((T_IS_GREATER_OR_EQUAL) reduce 13) ((T_IS_IDENTICAL) reduce 13) ((T_IS_NOT_EQUAL) reduce 13) ((T_IS_NOT_IDENTICAL) reduce 13) ((T_IS_SMALLER_OR_EQUAL) reduce 13) ((T_LOGICAL_AND) reduce 13) ((T_LOGICAL_OR) reduce 13) ((T_LOGICAL_XOR) reduce 13) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 13) ((T_OBJECT_OPERATOR) reduce 13) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 13) ((T_POW) reduce 13) ((T_SL) reduce 13) ((T_SPACESHIP) reduce 13) ((T_SR) reduce 13) (("[") reduce 13) (("]") reduce 13) (("^") reduce 13) (("{") reduce 13) (("|") reduce 13)) 11099 ((("%") reduce 55) (("(") reduce 55) (("*") reduce 55) (("+") reduce 55) (("-") reduce 55) ((".") reduce 55) (("/") reduce 55) (("<") reduce 55) ((">") reduce 55) (("?") reduce 55) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_BOOLEAN_AND) reduce 55) ((T_BOOLEAN_OR) reduce 55) ((T_COALESCE) reduce 55) ((T_INSTANCEOF) reduce 55) ((T_IS_EQUAL) reduce 55) ((T_IS_GREATER_OR_EQUAL) reduce 55) ((T_IS_IDENTICAL) reduce 55) ((T_IS_NOT_EQUAL) reduce 55) ((T_IS_NOT_IDENTICAL) reduce 55) ((T_IS_SMALLER_OR_EQUAL) reduce 55) ((T_LOGICAL_AND) reduce 55) ((T_LOGICAL_OR) reduce 55) ((T_LOGICAL_XOR) reduce 55) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 55) ((T_OBJECT_OPERATOR) reduce 55) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 55) ((T_POW) reduce 55) ((T_SL) reduce 55) ((T_SPACESHIP) reduce 55) ((T_SR) reduce 55) (("[") reduce 55) (("]") reduce 55) (("^") reduce 55) (("{") reduce 55) (("|") reduce 55)) 11100 ((("%") reduce 1) (("(") reduce 1) (("*") reduce 1) (("+") reduce 1) (("-") reduce 1) ((".") reduce 1) (("/") reduce 1) (("<") reduce 1) ((">") reduce 1) (("?") reduce 1) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_BOOLEAN_AND) reduce 1) ((T_BOOLEAN_OR) reduce 1) ((T_COALESCE) reduce 1) ((T_INSTANCEOF) reduce 1) ((T_IS_EQUAL) reduce 1) ((T_IS_GREATER_OR_EQUAL) reduce 1) ((T_IS_IDENTICAL) reduce 1) ((T_IS_NOT_EQUAL) reduce 1) ((T_IS_NOT_IDENTICAL) reduce 1) ((T_IS_SMALLER_OR_EQUAL) reduce 1) ((T_LOGICAL_AND) reduce 1) ((T_LOGICAL_OR) reduce 1) ((T_LOGICAL_XOR) reduce 1) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 1) ((T_OBJECT_OPERATOR) reduce 1) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 1) ((T_POW) reduce 1) ((T_SL) reduce 1) ((T_SPACESHIP) reduce 1) ((T_SR) reduce 1) (("[") reduce 1) (("]") reduce 1) (("^") reduce 1) (("{") reduce 1) (("|") reduce 1)) 11101 ((("%") reduce 2) (("(") reduce 2) (("*") reduce 2) (("+") reduce 2) (("-") reduce 2) ((".") reduce 2) (("/") reduce 2) (("<") reduce 2) ((">") reduce 2) (("?") reduce 2) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_BOOLEAN_AND) reduce 2) ((T_BOOLEAN_OR) reduce 2) ((T_COALESCE) reduce 2) ((T_INSTANCEOF) reduce 2) ((T_IS_EQUAL) reduce 2) ((T_IS_GREATER_OR_EQUAL) reduce 2) ((T_IS_IDENTICAL) reduce 2) ((T_IS_NOT_EQUAL) reduce 2) ((T_IS_NOT_IDENTICAL) reduce 2) ((T_IS_SMALLER_OR_EQUAL) reduce 2) ((T_LOGICAL_AND) reduce 2) ((T_LOGICAL_OR) reduce 2) ((T_LOGICAL_XOR) reduce 2) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 2) ((T_OBJECT_OPERATOR) reduce 2) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 2) ((T_POW) reduce 2) ((T_SL) reduce 2) ((T_SPACESHIP) reduce 2) ((T_SR) reduce 2) (("[") reduce 2) (("]") reduce 2) (("^") reduce 2) (("{") reduce 2) (("|") reduce 2)) 11102 ((("%") reduce 9) (("(") reduce 9) (("*") reduce 9) (("+") reduce 9) (("-") reduce 9) ((".") reduce 9) (("/") reduce 9) (("<") reduce 9) ((">") reduce 9) (("?") reduce 9) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_BOOLEAN_AND) reduce 9) ((T_BOOLEAN_OR) reduce 9) ((T_COALESCE) reduce 9) ((T_INSTANCEOF) reduce 9) ((T_IS_EQUAL) reduce 9) ((T_IS_GREATER_OR_EQUAL) reduce 9) ((T_IS_IDENTICAL) reduce 9) ((T_IS_NOT_EQUAL) reduce 9) ((T_IS_NOT_IDENTICAL) reduce 9) ((T_IS_SMALLER_OR_EQUAL) reduce 9) ((T_LOGICAL_AND) reduce 9) ((T_LOGICAL_OR) reduce 9) ((T_LOGICAL_XOR) reduce 9) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 9) ((T_OBJECT_OPERATOR) reduce 9) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 9) ((T_POW) reduce 9) ((T_SL) reduce 9) ((T_SPACESHIP) reduce 9) ((T_SR) reduce 9) (("[") reduce 9) (("]") reduce 9) (("^") reduce 9) (("{") reduce 9) (("|") reduce 9)) 11103 ((("%") reduce 33) (("(") reduce 33) (("*") reduce 33) (("+") reduce 33) (("-") reduce 33) ((".") reduce 33) (("/") reduce 33) (("<") reduce 33) ((">") reduce 33) (("?") reduce 33) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_BOOLEAN_AND) reduce 33) ((T_BOOLEAN_OR) reduce 33) ((T_COALESCE) reduce 33) ((T_INSTANCEOF) reduce 33) ((T_IS_EQUAL) reduce 33) ((T_IS_GREATER_OR_EQUAL) reduce 33) ((T_IS_IDENTICAL) reduce 33) ((T_IS_NOT_EQUAL) reduce 33) ((T_IS_NOT_IDENTICAL) reduce 33) ((T_IS_SMALLER_OR_EQUAL) reduce 33) ((T_LOGICAL_AND) reduce 33) ((T_LOGICAL_OR) reduce 33) ((T_LOGICAL_XOR) reduce 33) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 33) ((T_OBJECT_OPERATOR) reduce 33) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 33) ((T_POW) reduce 33) ((T_SL) reduce 33) ((T_SPACESHIP) reduce 33) ((T_SR) reduce 33) (("[") reduce 33) (("]") reduce 33) (("^") reduce 33) (("{") reduce 33) (("|") reduce 33)) 11104 ((("%") reduce 58) (("(") reduce 58) (("*") reduce 58) (("+") reduce 58) (("-") reduce 58) ((".") reduce 58) (("/") reduce 58) (("<") reduce 58) ((">") reduce 58) (("?") reduce 58) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_BOOLEAN_AND) reduce 58) ((T_BOOLEAN_OR) reduce 58) ((T_COALESCE) reduce 58) ((T_INSTANCEOF) reduce 58) ((T_IS_EQUAL) reduce 58) ((T_IS_GREATER_OR_EQUAL) reduce 58) ((T_IS_IDENTICAL) reduce 58) ((T_IS_NOT_EQUAL) reduce 58) ((T_IS_NOT_IDENTICAL) reduce 58) ((T_IS_SMALLER_OR_EQUAL) reduce 58) ((T_LOGICAL_AND) reduce 58) ((T_LOGICAL_OR) reduce 58) ((T_LOGICAL_XOR) reduce 58) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 58) ((T_OBJECT_OPERATOR) reduce 58) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 58) ((T_POW) reduce 58) ((T_SL) reduce 58) ((T_SPACESHIP) reduce 58) ((T_SR) reduce 58) (("[") reduce 58) (("]") reduce 58) (("^") reduce 58) (("{") reduce 58) (("|") reduce 58)) 11105 ((("%") reduce 37) (("(") reduce 37) (("*") reduce 37) (("+") reduce 37) (("-") reduce 37) ((".") reduce 37) (("/") reduce 37) (("<") reduce 37) ((">") reduce 37) (("?") reduce 37) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_BOOLEAN_AND) reduce 37) ((T_BOOLEAN_OR) reduce 37) ((T_COALESCE) reduce 37) ((T_INSTANCEOF) reduce 37) ((T_IS_EQUAL) reduce 37) ((T_IS_GREATER_OR_EQUAL) reduce 37) ((T_IS_IDENTICAL) reduce 37) ((T_IS_NOT_EQUAL) reduce 37) ((T_IS_NOT_IDENTICAL) reduce 37) ((T_IS_SMALLER_OR_EQUAL) reduce 37) ((T_LOGICAL_AND) reduce 37) ((T_LOGICAL_OR) reduce 37) ((T_LOGICAL_XOR) reduce 37) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 37) ((T_OBJECT_OPERATOR) reduce 37) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 37) ((T_POW) reduce 37) ((T_SL) reduce 37) ((T_SPACESHIP) reduce 37) ((T_SR) reduce 37) (("[") reduce 37) (("]") reduce 37) (("^") reduce 37) (("{") reduce 37) (("|") reduce 37)) 11106 ((("%") reduce 64) (("(") reduce 64) (("*") reduce 64) (("+") reduce 64) (("-") reduce 64) ((".") reduce 64) (("/") reduce 64) (("<") reduce 64) ((">") reduce 64) (("?") reduce 64) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_BOOLEAN_AND) reduce 64) ((T_BOOLEAN_OR) reduce 64) ((T_COALESCE) reduce 64) ((T_INSTANCEOF) reduce 64) ((T_IS_EQUAL) reduce 64) ((T_IS_GREATER_OR_EQUAL) reduce 64) ((T_IS_IDENTICAL) reduce 64) ((T_IS_NOT_EQUAL) reduce 64) ((T_IS_NOT_IDENTICAL) reduce 64) ((T_IS_SMALLER_OR_EQUAL) reduce 64) ((T_LOGICAL_AND) reduce 64) ((T_LOGICAL_OR) reduce 64) ((T_LOGICAL_XOR) reduce 64) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 64) ((T_OBJECT_OPERATOR) reduce 64) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 64) ((T_POW) reduce 64) ((T_SL) reduce 64) ((T_SPACESHIP) reduce 64) ((T_SR) reduce 64) (("[") reduce 64) (("]") reduce 64) (("^") reduce 64) (("{") reduce 64) (("|") reduce 64)) 11107 ((("%") reduce 46) (("(") reduce 46) (("*") reduce 46) (("+") reduce 46) (("-") reduce 46) ((".") reduce 46) (("/") reduce 46) (("<") reduce 46) ((">") reduce 46) (("?") reduce 46) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_BOOLEAN_AND) reduce 46) ((T_BOOLEAN_OR) reduce 46) ((T_COALESCE) reduce 46) ((T_INSTANCEOF) reduce 46) ((T_IS_EQUAL) reduce 46) ((T_IS_GREATER_OR_EQUAL) reduce 46) ((T_IS_IDENTICAL) reduce 46) ((T_IS_NOT_EQUAL) reduce 46) ((T_IS_NOT_IDENTICAL) reduce 46) ((T_IS_SMALLER_OR_EQUAL) reduce 46) ((T_LOGICAL_AND) reduce 46) ((T_LOGICAL_OR) reduce 46) ((T_LOGICAL_XOR) reduce 46) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 46) ((T_OBJECT_OPERATOR) reduce 46) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 46) ((T_POW) reduce 46) ((T_SL) reduce 46) ((T_SPACESHIP) reduce 46) ((T_SR) reduce 46) (("[") reduce 46) (("]") reduce 46) (("^") reduce 46) (("{") reduce 46) (("|") reduce 46)) 11108 ((("%") reduce 8) (("(") reduce 8) (("*") reduce 8) (("+") reduce 8) (("-") reduce 8) ((".") reduce 8) (("/") reduce 8) (("<") reduce 8) ((">") reduce 8) (("?") reduce 8) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_BOOLEAN_AND) reduce 8) ((T_BOOLEAN_OR) reduce 8) ((T_COALESCE) reduce 8) ((T_INSTANCEOF) reduce 8) ((T_IS_EQUAL) reduce 8) ((T_IS_GREATER_OR_EQUAL) reduce 8) ((T_IS_IDENTICAL) reduce 8) ((T_IS_NOT_EQUAL) reduce 8) ((T_IS_NOT_IDENTICAL) reduce 8) ((T_IS_SMALLER_OR_EQUAL) reduce 8) ((T_LOGICAL_AND) reduce 8) ((T_LOGICAL_OR) reduce 8) ((T_LOGICAL_XOR) reduce 8) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 8) ((T_OBJECT_OPERATOR) reduce 8) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 8) ((T_POW) reduce 8) ((T_SL) reduce 8) ((T_SPACESHIP) reduce 8) ((T_SR) reduce 8) (("[") reduce 8) (("]") reduce 8) (("^") reduce 8) (("{") reduce 8) (("|") reduce 8)) 11109 ((("%") reduce 6) (("(") reduce 6) (("*") reduce 6) (("+") reduce 6) (("-") reduce 6) ((".") reduce 6) (("/") reduce 6) (("<") reduce 6) ((">") reduce 6) (("?") reduce 6) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_BOOLEAN_AND) reduce 6) ((T_BOOLEAN_OR) reduce 6) ((T_COALESCE) reduce 6) ((T_INSTANCEOF) reduce 6) ((T_IS_EQUAL) reduce 6) ((T_IS_GREATER_OR_EQUAL) reduce 6) ((T_IS_IDENTICAL) reduce 6) ((T_IS_NOT_EQUAL) reduce 6) ((T_IS_NOT_IDENTICAL) reduce 6) ((T_IS_SMALLER_OR_EQUAL) reduce 6) ((T_LOGICAL_AND) reduce 6) ((T_LOGICAL_OR) reduce 6) ((T_LOGICAL_XOR) reduce 6) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 6) ((T_OBJECT_OPERATOR) reduce 6) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 6) ((T_POW) reduce 6) ((T_SL) reduce 6) ((T_SPACESHIP) reduce 6) ((T_SR) reduce 6) (("[") reduce 6) (("]") reduce 6) (("^") reduce 6) (("{") reduce 6) (("|") reduce 6)) 11110 ((("%") reduce 7) (("(") reduce 7) (("*") reduce 7) (("+") reduce 7) (("-") reduce 7) ((".") reduce 7) (("/") reduce 7) (("<") reduce 7) ((">") reduce 7) (("?") reduce 7) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_BOOLEAN_AND) reduce 7) ((T_BOOLEAN_OR) reduce 7) ((T_COALESCE) reduce 7) ((T_INSTANCEOF) reduce 7) ((T_IS_EQUAL) reduce 7) ((T_IS_GREATER_OR_EQUAL) reduce 7) ((T_IS_IDENTICAL) reduce 7) ((T_IS_NOT_EQUAL) reduce 7) ((T_IS_NOT_IDENTICAL) reduce 7) ((T_IS_SMALLER_OR_EQUAL) reduce 7) ((T_LOGICAL_AND) reduce 7) ((T_LOGICAL_OR) reduce 7) ((T_LOGICAL_XOR) reduce 7) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 7) ((T_OBJECT_OPERATOR) reduce 7) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 7) ((T_POW) reduce 7) ((T_SL) reduce 7) ((T_SPACESHIP) reduce 7) ((T_SR) reduce 7) (("[") reduce 7) (("]") reduce 7) (("^") reduce 7) (("{") reduce 7) (("|") reduce 7)) 11111 ((("%") reduce 69) (("(") reduce 69) (("*") reduce 69) (("+") reduce 69) (("-") reduce 69) ((".") reduce 69) (("/") reduce 69) (("<") reduce 69) ((">") reduce 69) (("?") reduce 69) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_BOOLEAN_AND) reduce 69) ((T_BOOLEAN_OR) reduce 69) ((T_COALESCE) reduce 69) ((T_INSTANCEOF) reduce 69) ((T_IS_EQUAL) reduce 69) ((T_IS_GREATER_OR_EQUAL) reduce 69) ((T_IS_IDENTICAL) reduce 69) ((T_IS_NOT_EQUAL) reduce 69) ((T_IS_NOT_IDENTICAL) reduce 69) ((T_IS_SMALLER_OR_EQUAL) reduce 69) ((T_LOGICAL_AND) reduce 69) ((T_LOGICAL_OR) reduce 69) ((T_LOGICAL_XOR) reduce 69) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 69) ((T_OBJECT_OPERATOR) reduce 69) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 69) ((T_POW) reduce 69) ((T_SL) reduce 69) ((T_SPACESHIP) reduce 69) ((T_SR) reduce 69) (("[") reduce 69) (("]") reduce 69) (("^") reduce 69) (("{") reduce 69) (("|") reduce 69)) 11112 ((("%") reduce 63) (("(") reduce 63) (("*") reduce 63) (("+") reduce 63) (("-") reduce 63) ((".") reduce 63) (("/") reduce 63) (("<") reduce 63) ((">") reduce 63) (("?") reduce 63) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_BOOLEAN_AND) reduce 63) ((T_BOOLEAN_OR) reduce 63) ((T_COALESCE) reduce 63) ((T_INSTANCEOF) reduce 63) ((T_IS_EQUAL) reduce 63) ((T_IS_GREATER_OR_EQUAL) reduce 63) ((T_IS_IDENTICAL) reduce 63) ((T_IS_NOT_EQUAL) reduce 63) ((T_IS_NOT_IDENTICAL) reduce 63) ((T_IS_SMALLER_OR_EQUAL) reduce 63) ((T_LOGICAL_AND) reduce 63) ((T_LOGICAL_OR) reduce 63) ((T_LOGICAL_XOR) reduce 63) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 63) ((T_OBJECT_OPERATOR) reduce 63) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 63) ((T_POW) reduce 63) ((T_SL) reduce 63) ((T_SPACESHIP) reduce 63) ((T_SR) reduce 63) (("[") reduce 63) (("]") reduce 63) (("^") reduce 63) (("{") reduce 63) (("|") reduce 63)) 11113 ((("%") reduce 56) (("(") reduce 56) (("*") reduce 56) (("+") reduce 56) (("-") reduce 56) ((".") reduce 56) (("/") reduce 56) (("<") reduce 56) ((">") reduce 56) (("?") reduce 56) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_BOOLEAN_AND) reduce 56) ((T_BOOLEAN_OR) reduce 56) ((T_COALESCE) reduce 56) ((T_INSTANCEOF) reduce 56) ((T_IS_EQUAL) reduce 56) ((T_IS_GREATER_OR_EQUAL) reduce 56) ((T_IS_IDENTICAL) reduce 56) ((T_IS_NOT_EQUAL) reduce 56) ((T_IS_NOT_IDENTICAL) reduce 56) ((T_IS_SMALLER_OR_EQUAL) reduce 56) ((T_LOGICAL_AND) reduce 56) ((T_LOGICAL_OR) reduce 56) ((T_LOGICAL_XOR) reduce 56) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 56) ((T_OBJECT_OPERATOR) reduce 56) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 56) ((T_POW) reduce 56) ((T_SL) reduce 56) ((T_SPACESHIP) reduce 56) ((T_SR) reduce 56) (("[") reduce 56) (("]") reduce 56) (("^") reduce 56) (("{") reduce 56) (("|") reduce 56)) 11114 ((("%") reduce 10) (("(") reduce 10) (("*") reduce 10) (("+") reduce 10) (("-") reduce 10) ((".") reduce 10) (("/") reduce 10) (("<") reduce 10) ((">") reduce 10) (("?") reduce 10) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_BOOLEAN_AND) reduce 10) ((T_BOOLEAN_OR) reduce 10) ((T_COALESCE) reduce 10) ((T_INSTANCEOF) reduce 10) ((T_IS_EQUAL) reduce 10) ((T_IS_GREATER_OR_EQUAL) reduce 10) ((T_IS_IDENTICAL) reduce 10) ((T_IS_NOT_EQUAL) reduce 10) ((T_IS_NOT_IDENTICAL) reduce 10) ((T_IS_SMALLER_OR_EQUAL) reduce 10) ((T_LOGICAL_AND) reduce 10) ((T_LOGICAL_OR) reduce 10) ((T_LOGICAL_XOR) reduce 10) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 10) ((T_OBJECT_OPERATOR) reduce 10) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 10) ((T_POW) reduce 10) ((T_SL) reduce 10) ((T_SPACESHIP) reduce 10) ((T_SR) reduce 10) (("[") reduce 10) (("]") reduce 10) (("^") reduce 10) (("{") reduce 10) (("|") reduce 10)) 11115 ((("%") reduce 67) (("(") reduce 67) (("*") reduce 67) (("+") reduce 67) (("-") reduce 67) ((".") reduce 67) (("/") reduce 67) (("<") reduce 67) ((">") reduce 67) (("?") reduce 67) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_BOOLEAN_AND) reduce 67) ((T_BOOLEAN_OR) reduce 67) ((T_COALESCE) reduce 67) ((T_INSTANCEOF) reduce 67) ((T_IS_EQUAL) reduce 67) ((T_IS_GREATER_OR_EQUAL) reduce 67) ((T_IS_IDENTICAL) reduce 67) ((T_IS_NOT_EQUAL) reduce 67) ((T_IS_NOT_IDENTICAL) reduce 67) ((T_IS_SMALLER_OR_EQUAL) reduce 67) ((T_LOGICAL_AND) reduce 67) ((T_LOGICAL_OR) reduce 67) ((T_LOGICAL_XOR) reduce 67) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 67) ((T_OBJECT_OPERATOR) reduce 67) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 67) ((T_POW) reduce 67) ((T_SL) reduce 67) ((T_SPACESHIP) reduce 67) ((T_SR) reduce 67) (("[") reduce 67) (("]") reduce 67) (("^") reduce 67) (("{") reduce 67) (("|") reduce 67)) 11116 ((("%") reduce 44) (("(") reduce 44) (("*") reduce 44) (("+") reduce 44) (("-") reduce 44) ((".") reduce 44) (("/") reduce 44) (("<") reduce 44) ((">") reduce 44) (("?") reduce 44) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_BOOLEAN_AND) reduce 44) ((T_BOOLEAN_OR) reduce 44) ((T_COALESCE) reduce 44) ((T_INSTANCEOF) reduce 44) ((T_IS_EQUAL) reduce 44) ((T_IS_GREATER_OR_EQUAL) reduce 44) ((T_IS_IDENTICAL) reduce 44) ((T_IS_NOT_EQUAL) reduce 44) ((T_IS_NOT_IDENTICAL) reduce 44) ((T_IS_SMALLER_OR_EQUAL) reduce 44) ((T_LOGICAL_AND) reduce 44) ((T_LOGICAL_OR) reduce 44) ((T_LOGICAL_XOR) reduce 44) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 44) ((T_OBJECT_OPERATOR) reduce 44) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 44) ((T_POW) reduce 44) ((T_SL) reduce 44) ((T_SPACESHIP) reduce 44) ((T_SR) reduce 44) (("[") reduce 44) (("]") reduce 44) (("^") reduce 44) (("{") reduce 44) (("|") reduce 44)) 11117 ((("%") reduce 75) (("(") reduce 75) (("*") reduce 75) (("+") reduce 75) (("-") reduce 75) ((".") reduce 75) (("/") reduce 75) (("<") reduce 75) ((">") reduce 75) (("?") reduce 75) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_BOOLEAN_AND) reduce 75) ((T_BOOLEAN_OR) reduce 75) ((T_COALESCE) reduce 75) ((T_INSTANCEOF) reduce 75) ((T_IS_EQUAL) reduce 75) ((T_IS_GREATER_OR_EQUAL) reduce 75) ((T_IS_IDENTICAL) reduce 75) ((T_IS_NOT_EQUAL) reduce 75) ((T_IS_NOT_IDENTICAL) reduce 75) ((T_IS_SMALLER_OR_EQUAL) reduce 75) ((T_LOGICAL_AND) reduce 75) ((T_LOGICAL_OR) reduce 75) ((T_LOGICAL_XOR) reduce 75) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 75) ((T_OBJECT_OPERATOR) reduce 75) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 75) ((T_POW) reduce 75) ((T_SL) reduce 75) ((T_SPACESHIP) reduce 75) ((T_SR) reduce 75) (("[") reduce 75) (("]") reduce 75) (("^") reduce 75) (("{") reduce 75) (("|") reduce 75)) 11118 ((("%") reduce 76) (("(") reduce 76) (("*") reduce 76) (("+") reduce 76) (("-") reduce 76) ((".") reduce 76) (("/") reduce 76) (("<") reduce 76) ((">") reduce 76) (("?") reduce 76) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_BOOLEAN_AND) reduce 76) ((T_BOOLEAN_OR) reduce 76) ((T_COALESCE) reduce 76) ((T_INSTANCEOF) reduce 76) ((T_IS_EQUAL) reduce 76) ((T_IS_GREATER_OR_EQUAL) reduce 76) ((T_IS_IDENTICAL) reduce 76) ((T_IS_NOT_EQUAL) reduce 76) ((T_IS_NOT_IDENTICAL) reduce 76) ((T_IS_SMALLER_OR_EQUAL) reduce 76) ((T_LOGICAL_AND) reduce 76) ((T_LOGICAL_OR) reduce 76) ((T_LOGICAL_XOR) reduce 76) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 76) ((T_OBJECT_OPERATOR) reduce 76) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 76) ((T_POW) reduce 76) ((T_SL) reduce 76) ((T_SPACESHIP) reduce 76) ((T_SR) reduce 76) (("[") reduce 76) (("]") reduce 76) (("^") reduce 76) (("{") reduce 76) (("|") reduce 76)) 11119 ((("%") reduce 77) (("(") reduce 77) (("*") reduce 77) (("+") reduce 77) (("-") reduce 77) ((".") reduce 77) (("/") reduce 77) (("<") reduce 77) ((">") reduce 77) (("?") reduce 77) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_BOOLEAN_AND) reduce 77) ((T_BOOLEAN_OR) reduce 77) ((T_COALESCE) reduce 77) ((T_INSTANCEOF) reduce 77) ((T_IS_EQUAL) reduce 77) ((T_IS_GREATER_OR_EQUAL) reduce 77) ((T_IS_IDENTICAL) reduce 77) ((T_IS_NOT_EQUAL) reduce 77) ((T_IS_NOT_IDENTICAL) reduce 77) ((T_IS_SMALLER_OR_EQUAL) reduce 77) ((T_LOGICAL_AND) reduce 77) ((T_LOGICAL_OR) reduce 77) ((T_LOGICAL_XOR) reduce 77) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 77) ((T_OBJECT_OPERATOR) reduce 77) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 77) ((T_POW) reduce 77) ((T_SL) reduce 77) ((T_SPACESHIP) reduce 77) ((T_SR) reduce 77) (("[") reduce 77) (("]") reduce 77) (("^") reduce 77) (("{") reduce 77) (("|") reduce 77)) 11120 ((("%") reduce 78) (("(") reduce 78) (("*") reduce 78) (("+") reduce 78) (("-") reduce 78) ((".") reduce 78) (("/") reduce 78) (("<") reduce 78) ((">") reduce 78) (("?") reduce 78) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_BOOLEAN_AND) reduce 78) ((T_BOOLEAN_OR) reduce 78) ((T_COALESCE) reduce 78) ((T_INSTANCEOF) reduce 78) ((T_IS_EQUAL) reduce 78) ((T_IS_GREATER_OR_EQUAL) reduce 78) ((T_IS_IDENTICAL) reduce 78) ((T_IS_NOT_EQUAL) reduce 78) ((T_IS_NOT_IDENTICAL) reduce 78) ((T_IS_SMALLER_OR_EQUAL) reduce 78) ((T_LOGICAL_AND) reduce 78) ((T_LOGICAL_OR) reduce 78) ((T_LOGICAL_XOR) reduce 78) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 78) ((T_OBJECT_OPERATOR) reduce 78) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 78) ((T_POW) reduce 78) ((T_SL) reduce 78) ((T_SPACESHIP) reduce 78) ((T_SR) reduce 78) (("[") reduce 78) (("]") reduce 78) (("^") reduce 78) (("{") reduce 78) (("|") reduce 78)) 11121 ((("%") reduce 4) (("(") reduce 4) (("*") reduce 4) (("+") reduce 4) (("-") reduce 4) ((".") reduce 4) (("/") reduce 4) (("<") reduce 4) ((">") reduce 4) (("?") reduce 4) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_BOOLEAN_AND) reduce 4) ((T_BOOLEAN_OR) reduce 4) ((T_COALESCE) reduce 4) ((T_INSTANCEOF) reduce 4) ((T_IS_EQUAL) reduce 4) ((T_IS_GREATER_OR_EQUAL) reduce 4) ((T_IS_IDENTICAL) reduce 4) ((T_IS_NOT_EQUAL) reduce 4) ((T_IS_NOT_IDENTICAL) reduce 4) ((T_IS_SMALLER_OR_EQUAL) reduce 4) ((T_LOGICAL_AND) reduce 4) ((T_LOGICAL_OR) reduce 4) ((T_LOGICAL_XOR) reduce 4) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 4) ((T_OBJECT_OPERATOR) reduce 4) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 4) ((T_POW) reduce 4) ((T_SL) reduce 4) ((T_SPACESHIP) reduce 4) ((T_SR) reduce 4) (("[") reduce 4) (("]") reduce 4) (("^") reduce 4) (("{") reduce 4) (("|") reduce 4)) 11122 ((("%") reduce 5) (("(") reduce 5) (("*") reduce 5) (("+") reduce 5) (("-") reduce 5) ((".") reduce 5) (("/") reduce 5) (("<") reduce 5) ((">") reduce 5) (("?") reduce 5) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_BOOLEAN_AND) reduce 5) ((T_BOOLEAN_OR) reduce 5) ((T_COALESCE) reduce 5) ((T_INSTANCEOF) reduce 5) ((T_IS_EQUAL) reduce 5) ((T_IS_GREATER_OR_EQUAL) reduce 5) ((T_IS_IDENTICAL) reduce 5) ((T_IS_NOT_EQUAL) reduce 5) ((T_IS_NOT_IDENTICAL) reduce 5) ((T_IS_SMALLER_OR_EQUAL) reduce 5) ((T_LOGICAL_AND) reduce 5) ((T_LOGICAL_OR) reduce 5) ((T_LOGICAL_XOR) reduce 5) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 5) ((T_OBJECT_OPERATOR) reduce 5) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 5) ((T_POW) reduce 5) ((T_SL) reduce 5) ((T_SPACESHIP) reduce 5) ((T_SR) reduce 5) (("[") reduce 5) (("]") reduce 5) (("^") reduce 5) (("{") reduce 5) (("|") reduce 5)) 11123 ((("%") reduce 43) (("(") reduce 43) (("*") reduce 43) (("+") reduce 43) (("-") reduce 43) ((".") reduce 43) (("/") reduce 43) (("<") reduce 43) ((">") reduce 43) (("?") reduce 43) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_BOOLEAN_AND) reduce 43) ((T_BOOLEAN_OR) reduce 43) ((T_COALESCE) reduce 43) ((T_INSTANCEOF) reduce 43) ((T_IS_EQUAL) reduce 43) ((T_IS_GREATER_OR_EQUAL) reduce 43) ((T_IS_IDENTICAL) reduce 43) ((T_IS_NOT_EQUAL) reduce 43) ((T_IS_NOT_IDENTICAL) reduce 43) ((T_IS_SMALLER_OR_EQUAL) reduce 43) ((T_LOGICAL_AND) reduce 43) ((T_LOGICAL_OR) reduce 43) ((T_LOGICAL_XOR) reduce 43) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 43) ((T_OBJECT_OPERATOR) reduce 43) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 43) ((T_POW) reduce 43) ((T_SL) reduce 43) ((T_SPACESHIP) reduce 43) ((T_SR) reduce 43) (("[") reduce 43) (("]") reduce 43) (("^") reduce 43) (("{") reduce 43) (("|") reduce 43)) 11124 ((("%") reduce 72) (("(") reduce 72) (("*") reduce 72) (("+") reduce 72) (("-") reduce 72) ((".") reduce 72) (("/") reduce 72) (("<") reduce 72) ((">") reduce 72) (("?") reduce 72) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_BOOLEAN_AND) reduce 72) ((T_BOOLEAN_OR) reduce 72) ((T_COALESCE) reduce 72) ((T_INSTANCEOF) reduce 72) ((T_IS_EQUAL) reduce 72) ((T_IS_GREATER_OR_EQUAL) reduce 72) ((T_IS_IDENTICAL) reduce 72) ((T_IS_NOT_EQUAL) reduce 72) ((T_IS_NOT_IDENTICAL) reduce 72) ((T_IS_SMALLER_OR_EQUAL) reduce 72) ((T_LOGICAL_AND) reduce 72) ((T_LOGICAL_OR) reduce 72) ((T_LOGICAL_XOR) reduce 72) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 72) ((T_OBJECT_OPERATOR) reduce 72) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 72) ((T_POW) reduce 72) ((T_SL) reduce 72) ((T_SPACESHIP) reduce 72) ((T_SR) reduce 72) (("[") reduce 72) (("]") reduce 72) (("^") reduce 72) (("{") reduce 72) (("|") reduce 72)) 11125 ((("%") reduce 81) (("(") reduce 81) (("*") reduce 81) (("+") reduce 81) (("-") reduce 81) ((".") reduce 81) (("/") reduce 81) (("<") reduce 81) ((">") reduce 81) (("?") reduce 81) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_BOOLEAN_AND) reduce 81) ((T_BOOLEAN_OR) reduce 81) ((T_COALESCE) reduce 81) ((T_INSTANCEOF) reduce 81) ((T_IS_EQUAL) reduce 81) ((T_IS_GREATER_OR_EQUAL) reduce 81) ((T_IS_IDENTICAL) reduce 81) ((T_IS_NOT_EQUAL) reduce 81) ((T_IS_NOT_IDENTICAL) reduce 81) ((T_IS_SMALLER_OR_EQUAL) reduce 81) ((T_LOGICAL_AND) reduce 81) ((T_LOGICAL_OR) reduce 81) ((T_LOGICAL_XOR) reduce 81) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 81) ((T_OBJECT_OPERATOR) reduce 81) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 81) ((T_POW) reduce 81) ((T_SL) reduce 81) ((T_SPACESHIP) reduce 81) ((T_SR) reduce 81) (("[") reduce 81) (("]") reduce 81) (("^") reduce 81) (("{") reduce 81) (("|") reduce 81)) 11126 ((("%") reduce 47) (("(") reduce 47) (("*") reduce 47) (("+") reduce 47) (("-") reduce 47) ((".") reduce 47) (("/") reduce 47) (("<") reduce 47) ((">") reduce 47) (("?") reduce 47) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_BOOLEAN_AND) reduce 47) ((T_BOOLEAN_OR) reduce 47) ((T_COALESCE) reduce 47) ((T_INSTANCEOF) reduce 47) ((T_IS_EQUAL) reduce 47) ((T_IS_GREATER_OR_EQUAL) reduce 47) ((T_IS_IDENTICAL) reduce 47) ((T_IS_NOT_EQUAL) reduce 47) ((T_IS_NOT_IDENTICAL) reduce 47) ((T_IS_SMALLER_OR_EQUAL) reduce 47) ((T_LOGICAL_AND) reduce 47) ((T_LOGICAL_OR) reduce 47) ((T_LOGICAL_XOR) reduce 47) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 47) ((T_OBJECT_OPERATOR) reduce 47) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 47) ((T_POW) reduce 47) ((T_SL) reduce 47) ((T_SPACESHIP) reduce 47) ((T_SR) reduce 47) (("[") reduce 47) (("]") reduce 47) (("^") reduce 47) (("{") reduce 47) (("|") reduce 47)) 11127 ((("%") reduce 31) (("(") reduce 31) (("*") reduce 31) (("+") reduce 31) (("-") reduce 31) ((".") reduce 31) (("/") reduce 31) (("<") reduce 31) ((">") reduce 31) (("?") reduce 31) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_BOOLEAN_AND) reduce 31) ((T_BOOLEAN_OR) reduce 31) ((T_COALESCE) reduce 31) ((T_INSTANCEOF) reduce 31) ((T_IS_EQUAL) reduce 31) ((T_IS_GREATER_OR_EQUAL) reduce 31) ((T_IS_IDENTICAL) reduce 31) ((T_IS_NOT_EQUAL) reduce 31) ((T_IS_NOT_IDENTICAL) reduce 31) ((T_IS_SMALLER_OR_EQUAL) reduce 31) ((T_LOGICAL_AND) reduce 31) ((T_LOGICAL_OR) reduce 31) ((T_LOGICAL_XOR) reduce 31) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 31) ((T_OBJECT_OPERATOR) reduce 31) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 31) ((T_POW) reduce 31) ((T_SL) reduce 31) ((T_SPACESHIP) reduce 31) ((T_SR) reduce 31) (("[") reduce 31) (("]") reduce 31) (("^") reduce 31) (("{") reduce 31) (("|") reduce 31)) 11128 ((("%") reduce 57) (("(") reduce 57) (("*") reduce 57) (("+") reduce 57) (("-") reduce 57) ((".") reduce 57) (("/") reduce 57) (("<") reduce 57) ((">") reduce 57) (("?") reduce 57) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_BOOLEAN_AND) reduce 57) ((T_BOOLEAN_OR) reduce 57) ((T_COALESCE) reduce 57) ((T_INSTANCEOF) reduce 57) ((T_IS_EQUAL) reduce 57) ((T_IS_GREATER_OR_EQUAL) reduce 57) ((T_IS_IDENTICAL) reduce 57) ((T_IS_NOT_EQUAL) reduce 57) ((T_IS_NOT_IDENTICAL) reduce 57) ((T_IS_SMALLER_OR_EQUAL) reduce 57) ((T_LOGICAL_AND) reduce 57) ((T_LOGICAL_OR) reduce 57) ((T_LOGICAL_XOR) reduce 57) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 57) ((T_OBJECT_OPERATOR) reduce 57) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 57) ((T_POW) reduce 57) ((T_SL) reduce 57) ((T_SPACESHIP) reduce 57) ((T_SR) reduce 57) (("[") reduce 57) (("]") reduce 57) (("^") reduce 57) (("{") reduce 57) (("|") reduce 57)) 11129 ((("%") reduce 61) (("(") reduce 61) (("*") reduce 61) (("+") reduce 61) (("-") reduce 61) ((".") reduce 61) (("/") reduce 61) (("<") reduce 61) ((">") reduce 61) (("?") reduce 61) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_BOOLEAN_AND) reduce 61) ((T_BOOLEAN_OR) reduce 61) ((T_COALESCE) reduce 61) ((T_INSTANCEOF) reduce 61) ((T_IS_EQUAL) reduce 61) ((T_IS_GREATER_OR_EQUAL) reduce 61) ((T_IS_IDENTICAL) reduce 61) ((T_IS_NOT_EQUAL) reduce 61) ((T_IS_NOT_IDENTICAL) reduce 61) ((T_IS_SMALLER_OR_EQUAL) reduce 61) ((T_LOGICAL_AND) reduce 61) ((T_LOGICAL_OR) reduce 61) ((T_LOGICAL_XOR) reduce 61) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 61) ((T_OBJECT_OPERATOR) reduce 61) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 61) ((T_POW) reduce 61) ((T_SL) reduce 61) ((T_SPACESHIP) reduce 61) ((T_SR) reduce 61) (("[") reduce 61) (("]") reduce 61) (("^") reduce 61) (("{") reduce 61) (("|") reduce 61)) 11130 ((("%") reduce 28) (("(") reduce 28) (("*") reduce 28) (("+") reduce 28) (("-") reduce 28) ((".") reduce 28) (("/") reduce 28) (("<") reduce 28) ((">") reduce 28) (("?") reduce 28) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_BOOLEAN_AND) reduce 28) ((T_BOOLEAN_OR) reduce 28) ((T_COALESCE) reduce 28) ((T_INSTANCEOF) reduce 28) ((T_IS_EQUAL) reduce 28) ((T_IS_GREATER_OR_EQUAL) reduce 28) ((T_IS_IDENTICAL) reduce 28) ((T_IS_NOT_EQUAL) reduce 28) ((T_IS_NOT_IDENTICAL) reduce 28) ((T_IS_SMALLER_OR_EQUAL) reduce 28) ((T_LOGICAL_AND) reduce 28) ((T_LOGICAL_OR) reduce 28) ((T_LOGICAL_XOR) reduce 28) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 28) ((T_OBJECT_OPERATOR) reduce 28) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 28) ((T_POW) reduce 28) ((T_SL) reduce 28) ((T_SPACESHIP) reduce 28) ((T_SR) reduce 28) (("[") reduce 28) (("]") reduce 28) (("^") reduce 28) (("{") reduce 28) (("|") reduce 28)) 11131 ((("%") reduce 36) (("(") reduce 36) (("*") reduce 36) (("+") reduce 36) (("-") reduce 36) ((".") reduce 36) (("/") reduce 36) (("<") reduce 36) ((">") reduce 36) (("?") reduce 36) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_BOOLEAN_AND) reduce 36) ((T_BOOLEAN_OR) reduce 36) ((T_COALESCE) reduce 36) ((T_INSTANCEOF) reduce 36) ((T_IS_EQUAL) reduce 36) ((T_IS_GREATER_OR_EQUAL) reduce 36) ((T_IS_IDENTICAL) reduce 36) ((T_IS_NOT_EQUAL) reduce 36) ((T_IS_NOT_IDENTICAL) reduce 36) ((T_IS_SMALLER_OR_EQUAL) reduce 36) ((T_LOGICAL_AND) reduce 36) ((T_LOGICAL_OR) reduce 36) ((T_LOGICAL_XOR) reduce 36) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 36) ((T_OBJECT_OPERATOR) reduce 36) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 36) ((T_POW) reduce 36) ((T_SL) reduce 36) ((T_SPACESHIP) reduce 36) ((T_SR) reduce 36) (("[") reduce 36) (("]") reduce 36) (("^") reduce 36) (("{") reduce 36) (("|") reduce 36)) 11132 ((("%") reduce 32) (("(") reduce 32) (("*") reduce 32) (("+") reduce 32) (("-") reduce 32) ((".") reduce 32) (("/") reduce 32) (("<") reduce 32) ((">") reduce 32) (("?") reduce 32) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_BOOLEAN_AND) reduce 32) ((T_BOOLEAN_OR) reduce 32) ((T_COALESCE) reduce 32) ((T_INSTANCEOF) reduce 32) ((T_IS_EQUAL) reduce 32) ((T_IS_GREATER_OR_EQUAL) reduce 32) ((T_IS_IDENTICAL) reduce 32) ((T_IS_NOT_EQUAL) reduce 32) ((T_IS_NOT_IDENTICAL) reduce 32) ((T_IS_SMALLER_OR_EQUAL) reduce 32) ((T_LOGICAL_AND) reduce 32) ((T_LOGICAL_OR) reduce 32) ((T_LOGICAL_XOR) reduce 32) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 32) ((T_OBJECT_OPERATOR) reduce 32) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 32) ((T_POW) reduce 32) ((T_SL) reduce 32) ((T_SPACESHIP) reduce 32) ((T_SR) reduce 32) (("[") reduce 32) (("]") reduce 32) (("^") reduce 32) (("{") reduce 32) (("|") reduce 32)) 11133 ((("%") reduce 35) (("(") reduce 35) (("*") reduce 35) (("+") reduce 35) (("-") reduce 35) ((".") reduce 35) (("/") reduce 35) (("<") reduce 35) ((">") reduce 35) (("?") reduce 35) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_BOOLEAN_AND) reduce 35) ((T_BOOLEAN_OR) reduce 35) ((T_COALESCE) reduce 35) ((T_INSTANCEOF) reduce 35) ((T_IS_EQUAL) reduce 35) ((T_IS_GREATER_OR_EQUAL) reduce 35) ((T_IS_IDENTICAL) reduce 35) ((T_IS_NOT_EQUAL) reduce 35) ((T_IS_NOT_IDENTICAL) reduce 35) ((T_IS_SMALLER_OR_EQUAL) reduce 35) ((T_LOGICAL_AND) reduce 35) ((T_LOGICAL_OR) reduce 35) ((T_LOGICAL_XOR) reduce 35) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 35) ((T_OBJECT_OPERATOR) reduce 35) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 35) ((T_POW) reduce 35) ((T_SL) reduce 35) ((T_SPACESHIP) reduce 35) ((T_SR) reduce 35) (("[") reduce 35) (("]") reduce 35) (("^") reduce 35) (("{") reduce 35) (("|") reduce 35)) 11134 ((("%") reduce 19) (("(") reduce 19) (("*") reduce 19) (("+") reduce 19) (("-") reduce 19) ((".") reduce 19) (("/") reduce 19) (("<") reduce 19) ((">") reduce 19) (("?") reduce 19) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_BOOLEAN_AND) reduce 19) ((T_BOOLEAN_OR) reduce 19) ((T_COALESCE) reduce 19) ((T_INSTANCEOF) reduce 19) ((T_IS_EQUAL) reduce 19) ((T_IS_GREATER_OR_EQUAL) reduce 19) ((T_IS_IDENTICAL) reduce 19) ((T_IS_NOT_EQUAL) reduce 19) ((T_IS_NOT_IDENTICAL) reduce 19) ((T_IS_SMALLER_OR_EQUAL) reduce 19) ((T_LOGICAL_AND) reduce 19) ((T_LOGICAL_OR) reduce 19) ((T_LOGICAL_XOR) reduce 19) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 19) ((T_OBJECT_OPERATOR) reduce 19) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 19) ((T_POW) reduce 19) ((T_SL) reduce 19) ((T_SPACESHIP) reduce 19) ((T_SR) reduce 19) (("[") reduce 19) (("]") reduce 19) (("^") reduce 19) (("{") reduce 19) (("|") reduce 19)) 11135 ((("%") reduce 45) (("(") reduce 45) (("*") reduce 45) (("+") reduce 45) (("-") reduce 45) ((".") reduce 45) (("/") reduce 45) (("<") reduce 45) ((">") reduce 45) (("?") reduce 45) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_BOOLEAN_AND) reduce 45) ((T_BOOLEAN_OR) reduce 45) ((T_COALESCE) reduce 45) ((T_INSTANCEOF) reduce 45) ((T_IS_EQUAL) reduce 45) ((T_IS_GREATER_OR_EQUAL) reduce 45) ((T_IS_IDENTICAL) reduce 45) ((T_IS_NOT_EQUAL) reduce 45) ((T_IS_NOT_IDENTICAL) reduce 45) ((T_IS_SMALLER_OR_EQUAL) reduce 45) ((T_LOGICAL_AND) reduce 45) ((T_LOGICAL_OR) reduce 45) ((T_LOGICAL_XOR) reduce 45) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 45) ((T_OBJECT_OPERATOR) reduce 45) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 45) ((T_POW) reduce 45) ((T_SL) reduce 45) ((T_SPACESHIP) reduce 45) ((T_SR) reduce 45) (("[") reduce 45) (("]") reduce 45) (("^") reduce 45) (("{") reduce 45) (("|") reduce 45)) 11136 ((("%") reduce 504) (("(") reduce 541) (("*") reduce 504) (("+") reduce 504) (("-") reduce 504) ((".") reduce 504) (("/") reduce 504) (("<") reduce 504) ((">") reduce 504) (("?") reduce 504) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_BOOLEAN_AND) reduce 504) ((T_BOOLEAN_OR) reduce 504) ((T_COALESCE) reduce 504) ((T_INSTANCEOF) reduce 504) ((T_IS_EQUAL) reduce 504) ((T_IS_GREATER_OR_EQUAL) reduce 504) ((T_IS_IDENTICAL) reduce 504) ((T_IS_NOT_EQUAL) reduce 504) ((T_IS_NOT_IDENTICAL) reduce 504) ((T_IS_SMALLER_OR_EQUAL) reduce 504) ((T_LOGICAL_AND) reduce 504) ((T_LOGICAL_OR) reduce 504) ((T_LOGICAL_XOR) reduce 504) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 504) ((T_OBJECT_OPERATOR) reduce 504) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 504) ((T_POW) reduce 504) ((T_SL) reduce 504) ((T_SPACESHIP) reduce 504) ((T_SR) reduce 504) (("[") reduce 504) (("]") reduce 504) (("^") reduce 504) (("{") reduce 504) (("|") reduce 504)) 11138 ((("%") reduce 71) (("(") reduce 71) (("*") reduce 71) (("+") reduce 71) (("-") reduce 71) ((".") reduce 71) (("/") reduce 71) (("<") reduce 71) ((">") reduce 71) (("?") reduce 71) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_BOOLEAN_AND) reduce 71) ((T_BOOLEAN_OR) reduce 71) ((T_COALESCE) reduce 71) ((T_INSTANCEOF) reduce 71) ((T_IS_EQUAL) reduce 71) ((T_IS_GREATER_OR_EQUAL) reduce 71) ((T_IS_IDENTICAL) reduce 71) ((T_IS_NOT_EQUAL) reduce 71) ((T_IS_NOT_IDENTICAL) reduce 71) ((T_IS_SMALLER_OR_EQUAL) reduce 71) ((T_LOGICAL_AND) reduce 71) ((T_LOGICAL_OR) reduce 71) ((T_LOGICAL_XOR) reduce 71) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 71) ((T_OBJECT_OPERATOR) reduce 71) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 71) ((T_POW) reduce 71) ((T_SL) reduce 71) ((T_SPACESHIP) reduce 71) ((T_SR) reduce 71) (("[") reduce 71) (("]") reduce 71) (("^") reduce 71) (("{") reduce 71) (("|") reduce 71)) 11139 ((("%") reduce 82) (("(") reduce 82) (("*") reduce 82) (("+") reduce 82) (("-") reduce 82) ((".") reduce 82) (("/") reduce 82) (("<") reduce 82) ((">") reduce 82) (("?") reduce 82) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_BOOLEAN_AND) reduce 82) ((T_BOOLEAN_OR) reduce 82) ((T_COALESCE) reduce 82) ((T_INSTANCEOF) reduce 82) ((T_IS_EQUAL) reduce 82) ((T_IS_GREATER_OR_EQUAL) reduce 82) ((T_IS_IDENTICAL) reduce 82) ((T_IS_NOT_EQUAL) reduce 82) ((T_IS_NOT_IDENTICAL) reduce 82) ((T_IS_SMALLER_OR_EQUAL) reduce 82) ((T_LOGICAL_AND) reduce 82) ((T_LOGICAL_OR) reduce 82) ((T_LOGICAL_XOR) reduce 82) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 82) ((T_OBJECT_OPERATOR) reduce 82) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 82) ((T_POW) reduce 82) ((T_SL) reduce 82) ((T_SPACESHIP) reduce 82) ((T_SR) reduce 82) (("[") reduce 82) (("]") reduce 82) (("^") reduce 82) (("{") reduce 82) (("|") reduce 82)) 11140 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) (("<") reduce 533) (("=") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AND_EQUAL) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_COALESCE_EQUAL) reduce 533) ((T_CONCAT_EQUAL) reduce 533) ((T_DEC) reduce 533) ((T_DIV_EQUAL) reduce 533) ((T_INC) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_MINUS_EQUAL) reduce 533) ((T_MOD_EQUAL) reduce 533) ((T_MUL_EQUAL) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_OR_EQUAL) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_PLUS_EQUAL) reduce 533) ((T_POW) reduce 533) ((T_POW_EQUAL) reduce 533) ((T_SL) reduce 533) ((T_SL_EQUAL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) ((T_SR_EQUAL) reduce 533) ((T_XOR_EQUAL) reduce 533) (("[") reduce 533) (("]") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 11143 ((("%") reduce 506) (("(") reduce 542) (("*") reduce 506) (("+") reduce 506) (("-") reduce 506) ((".") reduce 506) (("/") reduce 506) (("<") reduce 506) ((">") reduce 506) (("?") reduce 506) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_BOOLEAN_AND) reduce 506) ((T_BOOLEAN_OR) reduce 506) ((T_COALESCE) reduce 506) ((T_INSTANCEOF) reduce 506) ((T_IS_EQUAL) reduce 506) ((T_IS_GREATER_OR_EQUAL) reduce 506) ((T_IS_IDENTICAL) reduce 506) ((T_IS_NOT_EQUAL) reduce 506) ((T_IS_NOT_IDENTICAL) reduce 506) ((T_IS_SMALLER_OR_EQUAL) reduce 506) ((T_LOGICAL_AND) reduce 506) ((T_LOGICAL_OR) reduce 506) ((T_LOGICAL_XOR) reduce 506) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 506) ((T_OBJECT_OPERATOR) reduce 506) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 506) ((T_POW) reduce 506) ((T_SL) reduce 506) ((T_SPACESHIP) reduce 506) ((T_SR) reduce 506) (("[") reduce 506) (("]") reduce 506) (("^") reduce 506) (("{") reduce 506) (("|") reduce 506)) 11145 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) (("<") reduce 468) (("=") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AND_EQUAL) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_COALESCE_EQUAL) reduce 468) ((T_CONCAT_EQUAL) reduce 468) ((T_DEC) reduce 468) ((T_DIV_EQUAL) reduce 468) ((T_INC) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_MINUS_EQUAL) reduce 468) ((T_MOD_EQUAL) reduce 468) ((T_MUL_EQUAL) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_OR_EQUAL) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_PLUS_EQUAL) reduce 468) ((T_POW) reduce 468) ((T_POW_EQUAL) reduce 468) ((T_SL) reduce 468) ((T_SL_EQUAL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) ((T_SR_EQUAL) reduce 468) ((T_XOR_EQUAL) reduce 468) (("[") reduce 468) (("]") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 11146 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) (("=") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AND_EQUAL) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_COALESCE_EQUAL) reduce 288) ((T_CONCAT_EQUAL) reduce 288) ((T_DEC) reduce 288) ((T_DIV_EQUAL) reduce 288) ((T_INC) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_MINUS_EQUAL) reduce 288) ((T_MOD_EQUAL) reduce 288) ((T_MUL_EQUAL) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_OR_EQUAL) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_PLUS_EQUAL) reduce 288) ((T_POW) reduce 288) ((T_POW_EQUAL) reduce 288) ((T_SL) reduce 288) ((T_SL_EQUAL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) ((T_SR_EQUAL) reduce 288) ((T_XOR_EQUAL) reduce 288) (("[") reduce 288) (("]") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 11150 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) (("=") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AND_EQUAL) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_COALESCE_EQUAL) reduce 289) ((T_CONCAT_EQUAL) reduce 289) ((T_DEC) reduce 289) ((T_DIV_EQUAL) reduce 289) ((T_INC) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_MINUS_EQUAL) reduce 289) ((T_MOD_EQUAL) reduce 289) ((T_MUL_EQUAL) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_OR_EQUAL) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_PLUS_EQUAL) reduce 289) ((T_POW) reduce 289) ((T_POW_EQUAL) reduce 289) ((T_SL) reduce 289) ((T_SL_EQUAL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) ((T_SR_EQUAL) reduce 289) ((T_XOR_EQUAL) reduce 289) (("[") reduce 289) (("]") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 11151 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) (("=") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AND_EQUAL) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_COALESCE_EQUAL) reduce 290) ((T_CONCAT_EQUAL) reduce 290) ((T_DEC) reduce 290) ((T_DIV_EQUAL) reduce 290) ((T_INC) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_MINUS_EQUAL) reduce 290) ((T_MOD_EQUAL) reduce 290) ((T_MUL_EQUAL) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_OR_EQUAL) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_PLUS_EQUAL) reduce 290) ((T_POW) reduce 290) ((T_POW_EQUAL) reduce 290) ((T_SL) reduce 290) ((T_SL_EQUAL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) ((T_SR_EQUAL) reduce 290) ((T_XOR_EQUAL) reduce 290) (("[") reduce 290) (("]") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 11156 ((("%") reduce 388) (("*") reduce 388) (("+") reduce 388) (("-") reduce 388) ((".") reduce 388) (("/") reduce 388) (("<") reduce 388) ((">") reduce 388) (("?") reduce 388) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_BOOLEAN_AND) reduce 388) ((T_BOOLEAN_OR) reduce 388) ((T_COALESCE) reduce 388) ((T_INSTANCEOF) reduce 388) ((T_IS_EQUAL) reduce 388) ((T_IS_GREATER_OR_EQUAL) reduce 388) ((T_IS_IDENTICAL) reduce 388) ((T_IS_NOT_EQUAL) reduce 388) ((T_IS_NOT_IDENTICAL) reduce 388) ((T_IS_SMALLER_OR_EQUAL) reduce 388) ((T_LOGICAL_AND) reduce 388) ((T_LOGICAL_OR) reduce 388) ((T_LOGICAL_XOR) reduce 388) ((T_POW) reduce 388) ((T_SL) reduce 388) ((T_SPACESHIP) reduce 388) ((T_SR) reduce 388) (("]") reduce 388) (("^") reduce 388) (("|") reduce 388)) 11158 ((("%") reduce 386) (("*") reduce 386) (("+") reduce 386) (("-") reduce 386) ((".") reduce 386) (("/") reduce 386) (("<") reduce 386) ((">") reduce 386) (("?") reduce 386) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_BOOLEAN_AND) reduce 386) ((T_BOOLEAN_OR) reduce 386) ((T_COALESCE) reduce 386) ((T_INSTANCEOF) reduce 386) ((T_IS_EQUAL) reduce 386) ((T_IS_GREATER_OR_EQUAL) reduce 386) ((T_IS_IDENTICAL) reduce 386) ((T_IS_NOT_EQUAL) reduce 386) ((T_IS_NOT_IDENTICAL) reduce 386) ((T_IS_SMALLER_OR_EQUAL) reduce 386) ((T_LOGICAL_AND) reduce 386) ((T_LOGICAL_OR) reduce 386) ((T_LOGICAL_XOR) reduce 386) ((T_POW) reduce 386) ((T_SL) reduce 386) ((T_SPACESHIP) reduce 386) ((T_SR) reduce 386) (("]") reduce 386) (("^") reduce 386) (("|") reduce 386)) 11168 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 382) ((T_LOGICAL_OR) reduce 382) ((T_LOGICAL_XOR) reduce 382) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 382) (("^") shift) (("|") shift)) 11169 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 384) ((T_LOGICAL_OR) reduce 384) ((T_LOGICAL_XOR) reduce 384) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 384) (("^") shift) (("|") shift)) 11170 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 383) ((T_LOGICAL_OR) reduce 383) ((T_LOGICAL_XOR) reduce 383) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 383) (("^") shift) (("|") shift)) 11171 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 376) ((T_LOGICAL_OR) reduce 376) ((T_LOGICAL_XOR) reduce 376) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 376) (("^") shift) (("|") shift)) 11172 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 373) ((T_LOGICAL_OR) reduce 373) ((T_LOGICAL_XOR) reduce 373) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 373) (("^") shift) (("|") shift)) 11173 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 381) ((T_LOGICAL_OR) reduce 381) ((T_LOGICAL_XOR) reduce 381) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 381) (("^") shift) (("|") shift)) 11174 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 375) ((T_LOGICAL_OR) reduce 375) ((T_LOGICAL_XOR) reduce 375) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 375) (("^") shift) (("|") shift)) 11175 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 379) ((T_LOGICAL_OR) reduce 379) ((T_LOGICAL_XOR) reduce 379) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 379) (("^") shift) (("|") shift)) 11176 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 374) ((T_LOGICAL_OR) reduce 374) ((T_LOGICAL_XOR) reduce 374) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 374) (("^") shift) (("|") shift)) 11177 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 377) ((T_LOGICAL_OR) reduce 377) ((T_LOGICAL_XOR) reduce 377) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 377) (("^") shift) (("|") shift)) 11178 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 378) ((T_LOGICAL_OR) reduce 378) ((T_LOGICAL_XOR) reduce 378) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 378) (("^") shift) (("|") shift)) 11179 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 385) ((T_LOGICAL_OR) reduce 385) ((T_LOGICAL_XOR) reduce 385) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 385) (("^") shift) (("|") shift)) 11180 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 380) ((T_LOGICAL_OR) reduce 380) ((T_LOGICAL_XOR) reduce 380) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 380) (("^") shift) (("|") shift)) 11182 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 370) ((T_LOGICAL_OR) reduce 370) ((T_LOGICAL_XOR) reduce 370) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 370) (("^") shift) (("|") shift)) 11185 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("]") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 11188 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) (("<") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_POW) reduce 525) ((T_SL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) (("[") reduce 525) (("]") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 11190 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) (("<") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_POW) reduce 524) ((T_SL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) (("[") reduce 524) (("]") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 11192 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) (("<") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_POW) reduce 519) ((T_SL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) (("[") reduce 519) (("]") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 11193 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) (("<") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_POW) reduce 526) ((T_SL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) (("[") reduce 526) (("]") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 11194 ((("%") reduce 371) (("*") reduce 371) (("+") reduce 371) (("-") reduce 371) ((".") reduce 371) (("/") reduce 371) (("<") reduce 371) ((">") reduce 371) (("?") reduce 371) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_BOOLEAN_AND) reduce 371) ((T_BOOLEAN_OR) reduce 371) ((T_COALESCE) reduce 371) ((T_INSTANCEOF) reduce 371) ((T_IS_EQUAL) reduce 371) ((T_IS_GREATER_OR_EQUAL) reduce 371) ((T_IS_IDENTICAL) reduce 371) ((T_IS_NOT_EQUAL) reduce 371) ((T_IS_NOT_IDENTICAL) reduce 371) ((T_IS_SMALLER_OR_EQUAL) reduce 371) ((T_LOGICAL_AND) reduce 371) ((T_LOGICAL_OR) reduce 371) ((T_LOGICAL_XOR) reduce 371) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 371) ((T_SL) reduce 371) ((T_SPACESHIP) reduce 371) ((T_SR) reduce 371) (("[") reduce 510) (("]") reduce 371) (("^") reduce 371) (("{") reduce 510) (("|") reduce 371)) 11198 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) (("<") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_POW) reduce 533) ((T_SL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) (("[") reduce 533) (("]") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 11200 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) (("<") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_POW) reduce 468) ((T_SL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) (("[") reduce 468) (("]") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 11201 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("[") reduce 288) (("]") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 11205 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("[") reduce 289) (("]") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 11206 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("[") reduce 290) (("]") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 11207 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) (("<") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_POW) reduce 465) ((T_SL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) (("[") reduce 465) (("]") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 11210 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) (("<") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_POW) reduce 532) ((T_SL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) (("[") reduce 532) (("]") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 11211 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) (("<") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_POW) reduce 467) ((T_SL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) (("[") reduce 467) (("]") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 11212 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) (("<") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_POW) reduce 469) ((T_SL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) (("[") reduce 469) (("]") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 11218 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) (("<") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_POW) reduce 521) ((T_SL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) (("[") reduce 521) (("]") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 11220 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) (("<") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_POW) reduce 520) ((T_SL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) (("[") reduce 520) (("]") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 11221 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("]") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 11222 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) (("<") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_POW) reduce 527) ((T_SL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) (("[") reduce 527) (("]") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 11223 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("]") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 11226 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("]") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 11227 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) (("<") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_POW) reduce 522) ((T_SL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) (("[") reduce 522) (("]") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 11228 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) (("<") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_POW) reduce 528) ((T_SL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) (("[") reduce 528) (("]") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 11229 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) (("<") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_POW) reduce 523) ((T_SL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) (("[") reduce 523) (("]") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 11230 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) (("<") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_POW) reduce 466) ((T_SL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) (("[") reduce 466) (("]") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 11231 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("]") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 11234 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("]") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 11235 ((("%") reduce 535) (("*") reduce 535) (("+") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535) (("}") reduce 535)) 11236 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) (("<") reduce 465) (("=") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AND_EQUAL) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_COALESCE_EQUAL) reduce 465) ((T_CONCAT_EQUAL) reduce 465) ((T_DEC) reduce 465) ((T_DIV_EQUAL) reduce 465) ((T_INC) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_MINUS_EQUAL) reduce 465) ((T_MOD_EQUAL) reduce 465) ((T_MUL_EQUAL) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_OR_EQUAL) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_PLUS_EQUAL) reduce 465) ((T_POW) reduce 465) ((T_POW_EQUAL) reduce 465) ((T_SL) reduce 465) ((T_SL_EQUAL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) ((T_SR_EQUAL) reduce 465) ((T_XOR_EQUAL) reduce 465) (("[") reduce 465) (("]") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 11247 ((("%") reduce 455) (("*") reduce 455) (("+") reduce 455) (("-") reduce 455) ((".") reduce 455) (("/") reduce 455) (("<") reduce 455) ((">") reduce 455) (("?") reduce 455) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_BOOLEAN_AND) reduce 455) ((T_BOOLEAN_OR) reduce 455) ((T_COALESCE) reduce 455) ((T_INSTANCEOF) reduce 455) ((T_IS_EQUAL) reduce 455) ((T_IS_GREATER_OR_EQUAL) reduce 455) ((T_IS_IDENTICAL) reduce 455) ((T_IS_NOT_EQUAL) reduce 455) ((T_IS_NOT_IDENTICAL) reduce 455) ((T_IS_SMALLER_OR_EQUAL) reduce 455) ((T_LOGICAL_AND) reduce 455) ((T_LOGICAL_OR) reduce 455) ((T_LOGICAL_XOR) reduce 455) ((T_POW) reduce 455) ((T_SL) reduce 455) ((T_SPACESHIP) reduce 455) ((T_SR) reduce 455) (("]") reduce 455) (("^") reduce 455) (("|") reduce 455)) 11248 ((("%") reduce 450) (("*") reduce 450) (("+") reduce 450) (("-") reduce 450) ((".") reduce 450) (("/") reduce 450) (("<") reduce 450) ((">") reduce 450) (("?") reduce 450) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_BOOLEAN_AND) reduce 450) ((T_BOOLEAN_OR) reduce 450) ((T_COALESCE) reduce 450) ((T_INSTANCEOF) reduce 450) ((T_IS_EQUAL) reduce 450) ((T_IS_GREATER_OR_EQUAL) reduce 450) ((T_IS_IDENTICAL) reduce 450) ((T_IS_NOT_EQUAL) reduce 450) ((T_IS_NOT_IDENTICAL) reduce 450) ((T_IS_SMALLER_OR_EQUAL) reduce 450) ((T_LOGICAL_AND) reduce 450) ((T_LOGICAL_OR) reduce 450) ((T_LOGICAL_XOR) reduce 450) ((T_POW) reduce 450) ((T_SL) reduce 450) ((T_SPACESHIP) reduce 450) ((T_SR) reduce 450) (("]") reduce 450) (("^") reduce 450) (("|") reduce 450)) 11320 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 455) (("^") shift) (("|") shift)) 11638 ((("%") reduce 451) (("*") reduce 451) (("+") reduce 451) (("-") reduce 451) ((".") reduce 451) (("/") reduce 451) (("<") reduce 451) ((">") reduce 451) (("?") reduce 451) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_BOOLEAN_AND) reduce 451) ((T_BOOLEAN_OR) reduce 451) ((T_COALESCE) reduce 451) ((T_INSTANCEOF) reduce 451) ((T_IS_EQUAL) reduce 451) ((T_IS_GREATER_OR_EQUAL) reduce 451) ((T_IS_IDENTICAL) reduce 451) ((T_IS_NOT_EQUAL) reduce 451) ((T_IS_NOT_IDENTICAL) reduce 451) ((T_IS_SMALLER_OR_EQUAL) reduce 451) ((T_LOGICAL_AND) reduce 451) ((T_LOGICAL_OR) reduce 451) ((T_LOGICAL_XOR) reduce 451) ((T_POW) reduce 451) ((T_SL) reduce 451) ((T_SPACESHIP) reduce 451) ((T_SR) reduce 451) (("]") reduce 451) (("^") reduce 451) (("|") reduce 451)) 11641 ((("%") reduce 503) (("(") reduce 541) (("*") reduce 503) (("+") reduce 503) (("-") reduce 503) ((".") reduce 503) (("/") reduce 503) (("<") reduce 503) ((">") reduce 503) (("?") reduce 503) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_BOOLEAN_AND) reduce 503) ((T_BOOLEAN_OR) reduce 503) ((T_COALESCE) reduce 503) ((T_INSTANCEOF) reduce 503) ((T_IS_EQUAL) reduce 503) ((T_IS_GREATER_OR_EQUAL) reduce 503) ((T_IS_IDENTICAL) reduce 503) ((T_IS_NOT_EQUAL) reduce 503) ((T_IS_NOT_IDENTICAL) reduce 503) ((T_IS_SMALLER_OR_EQUAL) reduce 503) ((T_LOGICAL_AND) reduce 503) ((T_LOGICAL_OR) reduce 503) ((T_LOGICAL_XOR) reduce 503) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 503) ((T_OBJECT_OPERATOR) reduce 503) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 503) ((T_POW) reduce 503) ((T_SL) reduce 503) ((T_SPACESHIP) reduce 503) ((T_SR) reduce 503) (("[") reduce 503) (("]") reduce 503) (("^") reduce 503) (("{") reduce 503) (("|") reduce 503)) 11643 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) (("<") reduce 532) (("=") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AND_EQUAL) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_COALESCE_EQUAL) reduce 532) ((T_CONCAT_EQUAL) reduce 532) ((T_DEC) reduce 532) ((T_DIV_EQUAL) reduce 532) ((T_INC) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_MINUS_EQUAL) reduce 532) ((T_MOD_EQUAL) reduce 532) ((T_MUL_EQUAL) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_OR_EQUAL) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_PLUS_EQUAL) reduce 532) ((T_POW) reduce 532) ((T_POW_EQUAL) reduce 532) ((T_SL) reduce 532) ((T_SL_EQUAL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) ((T_SR_EQUAL) reduce 532) ((T_XOR_EQUAL) reduce 532) (("[") reduce 532) (("]") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 11646 ((("%") reduce 505) (("(") reduce 542) (("*") reduce 505) (("+") reduce 505) (("-") reduce 505) ((".") reduce 505) (("/") reduce 505) (("<") reduce 505) ((">") reduce 505) (("?") reduce 505) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_BOOLEAN_AND) reduce 505) ((T_BOOLEAN_OR) reduce 505) ((T_COALESCE) reduce 505) ((T_INSTANCEOF) reduce 505) ((T_IS_EQUAL) reduce 505) ((T_IS_GREATER_OR_EQUAL) reduce 505) ((T_IS_IDENTICAL) reduce 505) ((T_IS_NOT_EQUAL) reduce 505) ((T_IS_NOT_IDENTICAL) reduce 505) ((T_IS_SMALLER_OR_EQUAL) reduce 505) ((T_LOGICAL_AND) reduce 505) ((T_LOGICAL_OR) reduce 505) ((T_LOGICAL_XOR) reduce 505) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 505) ((T_OBJECT_OPERATOR) reduce 505) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 505) ((T_POW) reduce 505) ((T_SL) reduce 505) ((T_SPACESHIP) reduce 505) ((T_SR) reduce 505) (("[") reduce 505) (("]") reduce 505) (("^") reduce 505) (("{") reduce 505) (("|") reduce 505)) 11647 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) (("<") reduce 467) (("=") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AND_EQUAL) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_COALESCE_EQUAL) reduce 467) ((T_CONCAT_EQUAL) reduce 467) ((T_DEC) reduce 467) ((T_DIV_EQUAL) reduce 467) ((T_INC) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_MINUS_EQUAL) reduce 467) ((T_MOD_EQUAL) reduce 467) ((T_MUL_EQUAL) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_OR_EQUAL) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_PLUS_EQUAL) reduce 467) ((T_POW) reduce 467) ((T_POW_EQUAL) reduce 467) ((T_SL) reduce 467) ((T_SL_EQUAL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) ((T_SR_EQUAL) reduce 467) ((T_XOR_EQUAL) reduce 467) (("[") reduce 467) (("]") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 11648 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) (("<") reduce 469) (("=") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AND_EQUAL) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_COALESCE_EQUAL) reduce 469) ((T_CONCAT_EQUAL) reduce 469) ((T_DEC) reduce 469) ((T_DIV_EQUAL) reduce 469) ((T_INC) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_MINUS_EQUAL) reduce 469) ((T_MOD_EQUAL) reduce 469) ((T_MUL_EQUAL) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_OR_EQUAL) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_PLUS_EQUAL) reduce 469) ((T_POW) reduce 469) ((T_POW_EQUAL) reduce 469) ((T_SL) reduce 469) ((T_SL_EQUAL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) ((T_SR_EQUAL) reduce 469) ((T_XOR_EQUAL) reduce 469) (("[") reduce 469) (("]") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 11650 ((("%") reduce 446) (("*") reduce 446) (("+") reduce 446) (("-") reduce 446) ((".") reduce 446) (("/") reduce 446) (("<") reduce 446) ((">") reduce 446) (("?") reduce 446) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_BOOLEAN_AND) reduce 446) ((T_BOOLEAN_OR) reduce 446) ((T_COALESCE) reduce 446) ((T_INSTANCEOF) reduce 446) ((T_IS_EQUAL) reduce 446) ((T_IS_GREATER_OR_EQUAL) reduce 446) ((T_IS_IDENTICAL) reduce 446) ((T_IS_NOT_EQUAL) reduce 446) ((T_IS_NOT_IDENTICAL) reduce 446) ((T_IS_SMALLER_OR_EQUAL) reduce 446) ((T_LOGICAL_AND) reduce 446) ((T_LOGICAL_OR) reduce 446) ((T_LOGICAL_XOR) reduce 446) ((T_POW) reduce 446) ((T_SL) reduce 446) ((T_SPACESHIP) reduce 446) ((T_SR) reduce 446) (("]") reduce 446) (("^") reduce 446) (("|") reduce 446)) 11651 ((("%") reduce 448) (("*") reduce 448) (("+") reduce 448) (("-") reduce 448) ((".") reduce 448) (("/") reduce 448) (("<") reduce 448) ((">") reduce 448) (("?") reduce 448) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_BOOLEAN_AND) reduce 448) ((T_BOOLEAN_OR) reduce 448) ((T_COALESCE) reduce 448) ((T_INSTANCEOF) reduce 448) ((T_IS_EQUAL) reduce 448) ((T_IS_GREATER_OR_EQUAL) reduce 448) ((T_IS_IDENTICAL) reduce 448) ((T_IS_NOT_EQUAL) reduce 448) ((T_IS_NOT_IDENTICAL) reduce 448) ((T_IS_SMALLER_OR_EQUAL) reduce 448) ((T_LOGICAL_AND) reduce 448) ((T_LOGICAL_OR) reduce 448) ((T_LOGICAL_XOR) reduce 448) ((T_POW) reduce 448) ((T_SL) reduce 448) ((T_SPACESHIP) reduce 448) ((T_SR) reduce 448) (("]") reduce 448) (("^") reduce 448) (("|") reduce 448)) 11657 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) (("<") reduce 521) (("=") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AND_EQUAL) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_COALESCE_EQUAL) reduce 521) ((T_CONCAT_EQUAL) reduce 521) ((T_DEC) reduce 521) ((T_DIV_EQUAL) reduce 521) ((T_INC) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_MINUS_EQUAL) reduce 521) ((T_MOD_EQUAL) reduce 521) ((T_MUL_EQUAL) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_OR_EQUAL) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_PLUS_EQUAL) reduce 521) ((T_POW) reduce 521) ((T_POW_EQUAL) reduce 521) ((T_SL) reduce 521) ((T_SL_EQUAL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) ((T_SR_EQUAL) reduce 521) ((T_XOR_EQUAL) reduce 521) (("[") reduce 521) (("]") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 11659 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) (("<") reduce 520) (("=") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AND_EQUAL) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_COALESCE_EQUAL) reduce 520) ((T_CONCAT_EQUAL) reduce 520) ((T_DEC) reduce 520) ((T_DIV_EQUAL) reduce 520) ((T_INC) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_MINUS_EQUAL) reduce 520) ((T_MOD_EQUAL) reduce 520) ((T_MUL_EQUAL) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_OR_EQUAL) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_PLUS_EQUAL) reduce 520) ((T_POW) reduce 520) ((T_POW_EQUAL) reduce 520) ((T_SL) reduce 520) ((T_SL_EQUAL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) ((T_SR_EQUAL) reduce 520) ((T_XOR_EQUAL) reduce 520) (("[") reduce 520) (("]") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 11660 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) (("=") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AND_EQUAL) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_COALESCE_EQUAL) reduce 544) ((T_CONCAT_EQUAL) reduce 544) ((T_DEC) reduce 544) ((T_DIV_EQUAL) reduce 544) ((T_INC) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_MINUS_EQUAL) reduce 544) ((T_MOD_EQUAL) reduce 544) ((T_MUL_EQUAL) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_OR_EQUAL) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_PLUS_EQUAL) reduce 544) ((T_POW) reduce 544) ((T_POW_EQUAL) reduce 544) ((T_SL) reduce 544) ((T_SL_EQUAL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) ((T_SR_EQUAL) reduce 544) ((T_XOR_EQUAL) reduce 544) (("[") reduce 544) (("]") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 11661 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) (("<") reduce 527) (("=") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AND_EQUAL) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_COALESCE_EQUAL) reduce 527) ((T_CONCAT_EQUAL) reduce 527) ((T_DEC) reduce 527) ((T_DIV_EQUAL) reduce 527) ((T_INC) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_MINUS_EQUAL) reduce 527) ((T_MOD_EQUAL) reduce 527) ((T_MUL_EQUAL) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_OR_EQUAL) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_PLUS_EQUAL) reduce 527) ((T_POW) reduce 527) ((T_POW_EQUAL) reduce 527) ((T_SL) reduce 527) ((T_SL_EQUAL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) ((T_SR_EQUAL) reduce 527) ((T_XOR_EQUAL) reduce 527) (("[") reduce 527) (("]") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 11662 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) (("=") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AND_EQUAL) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_COALESCE_EQUAL) reduce 546) ((T_CONCAT_EQUAL) reduce 546) ((T_DEC) reduce 546) ((T_DIV_EQUAL) reduce 546) ((T_INC) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_MINUS_EQUAL) reduce 546) ((T_MOD_EQUAL) reduce 546) ((T_MUL_EQUAL) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_OR_EQUAL) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_PLUS_EQUAL) reduce 546) ((T_POW) reduce 546) ((T_POW_EQUAL) reduce 546) ((T_SL) reduce 546) ((T_SL_EQUAL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) ((T_SR_EQUAL) reduce 546) ((T_XOR_EQUAL) reduce 546) (("[") reduce 546) (("]") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 11665 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) (("=") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AND_EQUAL) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_COALESCE_EQUAL) reduce 545) ((T_CONCAT_EQUAL) reduce 545) ((T_DEC) reduce 545) ((T_DIV_EQUAL) reduce 545) ((T_INC) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_MINUS_EQUAL) reduce 545) ((T_MOD_EQUAL) reduce 545) ((T_MUL_EQUAL) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_OR_EQUAL) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_PLUS_EQUAL) reduce 545) ((T_POW) reduce 545) ((T_POW_EQUAL) reduce 545) ((T_SL) reduce 545) ((T_SL_EQUAL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) ((T_SR_EQUAL) reduce 545) ((T_XOR_EQUAL) reduce 545) (("[") reduce 545) (("]") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 11666 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) (("<") reduce 522) (("=") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AND_EQUAL) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_COALESCE_EQUAL) reduce 522) ((T_CONCAT_EQUAL) reduce 522) ((T_DEC) reduce 522) ((T_DIV_EQUAL) reduce 522) ((T_INC) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_MINUS_EQUAL) reduce 522) ((T_MOD_EQUAL) reduce 522) ((T_MUL_EQUAL) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_OR_EQUAL) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_PLUS_EQUAL) reduce 522) ((T_POW) reduce 522) ((T_POW_EQUAL) reduce 522) ((T_SL) reduce 522) ((T_SL_EQUAL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) ((T_SR_EQUAL) reduce 522) ((T_XOR_EQUAL) reduce 522) (("[") reduce 522) (("]") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 11667 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) (("<") reduce 528) (("=") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AND_EQUAL) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_COALESCE_EQUAL) reduce 528) ((T_CONCAT_EQUAL) reduce 528) ((T_DEC) reduce 528) ((T_DIV_EQUAL) reduce 528) ((T_INC) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_MINUS_EQUAL) reduce 528) ((T_MOD_EQUAL) reduce 528) ((T_MUL_EQUAL) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_OR_EQUAL) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_PLUS_EQUAL) reduce 528) ((T_POW) reduce 528) ((T_POW_EQUAL) reduce 528) ((T_SL) reduce 528) ((T_SL_EQUAL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) ((T_SR_EQUAL) reduce 528) ((T_XOR_EQUAL) reduce 528) (("[") reduce 528) (("]") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 11668 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) (("<") reduce 523) (("=") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AND_EQUAL) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_COALESCE_EQUAL) reduce 523) ((T_CONCAT_EQUAL) reduce 523) ((T_DEC) reduce 523) ((T_DIV_EQUAL) reduce 523) ((T_INC) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_MINUS_EQUAL) reduce 523) ((T_MOD_EQUAL) reduce 523) ((T_MUL_EQUAL) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_OR_EQUAL) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_PLUS_EQUAL) reduce 523) ((T_POW) reduce 523) ((T_POW_EQUAL) reduce 523) ((T_SL) reduce 523) ((T_SL_EQUAL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) ((T_SR_EQUAL) reduce 523) ((T_XOR_EQUAL) reduce 523) (("[") reduce 523) (("]") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 11670 ((("%") reduce 438) (("*") reduce 438) (("+") reduce 438) (("-") reduce 438) ((".") reduce 438) (("/") reduce 438) (("<") reduce 438) ((">") reduce 438) (("?") reduce 438) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_BOOLEAN_AND) reduce 438) ((T_BOOLEAN_OR) reduce 438) ((T_COALESCE) reduce 438) ((T_INSTANCEOF) reduce 438) ((T_IS_EQUAL) reduce 438) ((T_IS_GREATER_OR_EQUAL) reduce 438) ((T_IS_IDENTICAL) reduce 438) ((T_IS_NOT_EQUAL) reduce 438) ((T_IS_NOT_IDENTICAL) reduce 438) ((T_IS_SMALLER_OR_EQUAL) reduce 438) ((T_LOGICAL_AND) reduce 438) ((T_LOGICAL_OR) reduce 438) ((T_LOGICAL_XOR) reduce 438) ((T_POW) reduce 438) ((T_SL) reduce 438) ((T_SPACESHIP) reduce 438) ((T_SR) reduce 438) (("]") reduce 438) (("^") reduce 438) (("|") reduce 438)) 11672 ((("%") reduce 483) (("(") reduce 483) (("*") reduce 483) (("+") reduce 483) (("-") reduce 483) ((".") reduce 483) (("/") reduce 483) (("<") reduce 483) (("=") shift) ((">") reduce 483) (("?") reduce 483) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_BOOLEAN_AND) reduce 483) ((T_BOOLEAN_OR) reduce 483) ((T_COALESCE) reduce 483) ((T_INSTANCEOF) reduce 483) ((T_IS_EQUAL) reduce 483) ((T_IS_GREATER_OR_EQUAL) reduce 483) ((T_IS_IDENTICAL) reduce 483) ((T_IS_NOT_EQUAL) reduce 483) ((T_IS_NOT_IDENTICAL) reduce 483) ((T_IS_SMALLER_OR_EQUAL) reduce 483) ((T_LOGICAL_AND) reduce 483) ((T_LOGICAL_OR) reduce 483) ((T_LOGICAL_XOR) reduce 483) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 483) ((T_OBJECT_OPERATOR) reduce 483) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 483) ((T_POW) reduce 483) ((T_SL) reduce 483) ((T_SPACESHIP) reduce 483) ((T_SR) reduce 483) (("[") reduce 483) (("]") reduce 483) (("^") reduce 483) (("{") reduce 483) (("|") reduce 483)) 11674 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 369) ((T_LOGICAL_OR) reduce 369) ((T_LOGICAL_XOR) reduce 369) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 369) (("^") shift) (("|") shift)) 11675 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 443) ((T_LOGICAL_OR) reduce 443) ((T_LOGICAL_XOR) reduce 443) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 443) (("^") shift) (("|") shift)) 11686 ((("%") reduce 502) (("*") reduce 502) (("+") reduce 502) (("-") reduce 502) ((".") reduce 502) (("/") reduce 502) (("<") reduce 502) ((">") reduce 502) (("?") reduce 502) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_BOOLEAN_AND) reduce 502) ((T_BOOLEAN_OR) reduce 502) ((T_COALESCE) reduce 502) ((T_DOUBLE_ARROW) reduce 502) ((T_INSTANCEOF) reduce 502) ((T_IS_EQUAL) reduce 502) ((T_IS_GREATER_OR_EQUAL) reduce 502) ((T_IS_IDENTICAL) reduce 502) ((T_IS_NOT_EQUAL) reduce 502) ((T_IS_NOT_IDENTICAL) reduce 502) ((T_IS_SMALLER_OR_EQUAL) reduce 502) ((T_LOGICAL_AND) reduce 502) ((T_LOGICAL_OR) reduce 502) ((T_LOGICAL_XOR) reduce 502) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 502) ((T_OBJECT_OPERATOR) reduce 502) ((T_POW) reduce 502) ((T_SL) reduce 502) ((T_SPACESHIP) reduce 502) ((T_SR) reduce 502) (("[") reduce 502) (("]") reduce 502) (("^") reduce 502) (("{") reduce 502) (("|") reduce 502)) 11688 ((("%") reduce 484) (("(") reduce 484) (("*") reduce 484) (("+") reduce 484) (("-") reduce 484) ((".") reduce 484) (("/") reduce 484) (("<") reduce 484) ((">") reduce 484) (("?") reduce 484) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_BOOLEAN_AND) reduce 484) ((T_BOOLEAN_OR) reduce 484) ((T_COALESCE) reduce 484) ((T_DOUBLE_ARROW) reduce 484) ((T_INSTANCEOF) reduce 484) ((T_IS_EQUAL) reduce 484) ((T_IS_GREATER_OR_EQUAL) reduce 484) ((T_IS_IDENTICAL) reduce 484) ((T_IS_NOT_EQUAL) reduce 484) ((T_IS_NOT_IDENTICAL) reduce 484) ((T_IS_SMALLER_OR_EQUAL) reduce 484) ((T_LOGICAL_AND) reduce 484) ((T_LOGICAL_OR) reduce 484) ((T_LOGICAL_XOR) reduce 484) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 484) ((T_OBJECT_OPERATOR) reduce 484) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 484) ((T_POW) reduce 484) ((T_SL) reduce 484) ((T_SPACESHIP) reduce 484) ((T_SR) reduce 484) (("[") reduce 484) (("]") reduce 484) (("^") reduce 484) (("{") reduce 484) (("|") reduce 484)) 11690 ((("%") reduce 497) (("*") reduce 497) (("+") reduce 497) (("-") reduce 497) ((".") reduce 497) (("/") reduce 497) (("<") reduce 497) ((">") reduce 497) (("?") reduce 497) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_BOOLEAN_AND) reduce 497) ((T_BOOLEAN_OR) reduce 497) ((T_COALESCE) reduce 497) ((T_DOUBLE_ARROW) reduce 497) ((T_INSTANCEOF) reduce 497) ((T_IS_EQUAL) reduce 497) ((T_IS_GREATER_OR_EQUAL) reduce 497) ((T_IS_IDENTICAL) reduce 497) ((T_IS_NOT_EQUAL) reduce 497) ((T_IS_NOT_IDENTICAL) reduce 497) ((T_IS_SMALLER_OR_EQUAL) reduce 497) ((T_LOGICAL_AND) reduce 497) ((T_LOGICAL_OR) reduce 497) ((T_LOGICAL_XOR) reduce 497) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 497) ((T_OBJECT_OPERATOR) reduce 497) ((T_POW) reduce 497) ((T_SL) reduce 497) ((T_SPACESHIP) reduce 497) ((T_SR) reduce 497) (("[") reduce 497) (("]") reduce 497) (("^") reduce 497) (("{") reduce 497) (("|") reduce 497)) 11691 ((("%") reduce 487) (("*") reduce 487) (("+") reduce 487) (("-") reduce 487) ((".") reduce 487) (("/") reduce 487) (("<") reduce 487) ((">") reduce 487) (("?") reduce 487) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_BOOLEAN_AND) reduce 487) ((T_BOOLEAN_OR) reduce 487) ((T_COALESCE) reduce 487) ((T_DOUBLE_ARROW) reduce 487) ((T_INSTANCEOF) reduce 487) ((T_IS_EQUAL) reduce 487) ((T_IS_GREATER_OR_EQUAL) reduce 487) ((T_IS_IDENTICAL) reduce 487) ((T_IS_NOT_EQUAL) reduce 487) ((T_IS_NOT_IDENTICAL) reduce 487) ((T_IS_SMALLER_OR_EQUAL) reduce 487) ((T_LOGICAL_AND) reduce 487) ((T_LOGICAL_OR) reduce 487) ((T_LOGICAL_XOR) reduce 487) ((T_POW) reduce 487) ((T_SL) reduce 487) ((T_SPACESHIP) reduce 487) ((T_SR) reduce 487) (("]") reduce 487) (("^") reduce 487) (("|") reduce 487)) 11695 ((("%") reduce 475) (("(") shift) (("*") reduce 475) (("+") reduce 475) (("-") reduce 475) ((".") reduce 475) (("/") reduce 475) (("<") reduce 475) ((">") reduce 475) (("?") reduce 475) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_BOOLEAN_AND) reduce 475) ((T_BOOLEAN_OR) reduce 475) ((T_COALESCE) reduce 475) ((T_DOUBLE_ARROW) reduce 475) ((T_INSTANCEOF) reduce 475) ((T_IS_EQUAL) reduce 475) ((T_IS_GREATER_OR_EQUAL) reduce 475) ((T_IS_IDENTICAL) reduce 475) ((T_IS_NOT_EQUAL) reduce 475) ((T_IS_NOT_IDENTICAL) reduce 475) ((T_IS_SMALLER_OR_EQUAL) reduce 475) ((T_LOGICAL_AND) reduce 475) ((T_LOGICAL_OR) reduce 475) ((T_LOGICAL_XOR) reduce 475) ((T_POW) reduce 475) ((T_SL) reduce 475) ((T_SPACESHIP) reduce 475) ((T_SR) reduce 475) (("]") reduce 475) (("^") reduce 475) (("|") reduce 475)) 11696 ((("%") reduce 496) (("*") reduce 496) (("+") reduce 496) (("-") reduce 496) ((".") reduce 496) (("/") reduce 496) (("<") reduce 496) ((">") reduce 496) (("?") reduce 496) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_BOOLEAN_AND) reduce 496) ((T_BOOLEAN_OR) reduce 496) ((T_COALESCE) reduce 496) ((T_DOUBLE_ARROW) reduce 496) ((T_INSTANCEOF) reduce 496) ((T_IS_EQUAL) reduce 496) ((T_IS_GREATER_OR_EQUAL) reduce 496) ((T_IS_IDENTICAL) reduce 496) ((T_IS_NOT_EQUAL) reduce 496) ((T_IS_NOT_IDENTICAL) reduce 496) ((T_IS_SMALLER_OR_EQUAL) reduce 496) ((T_LOGICAL_AND) reduce 496) ((T_LOGICAL_OR) reduce 496) ((T_LOGICAL_XOR) reduce 496) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 496) ((T_OBJECT_OPERATOR) reduce 496) ((T_POW) reduce 496) ((T_SL) reduce 496) ((T_SPACESHIP) reduce 496) ((T_SR) reduce 496) (("[") reduce 496) (("]") reduce 496) (("^") reduce 496) (("{") reduce 496) (("|") reduce 496)) 11697 ((("%") reduce 500) (("*") reduce 500) (("+") reduce 500) (("-") reduce 500) ((".") reduce 500) (("/") reduce 500) (("<") reduce 500) ((">") reduce 500) (("?") reduce 500) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_BOOLEAN_AND) reduce 500) ((T_BOOLEAN_OR) reduce 500) ((T_COALESCE) reduce 500) ((T_DOUBLE_ARROW) reduce 500) ((T_INSTANCEOF) reduce 500) ((T_IS_EQUAL) reduce 500) ((T_IS_GREATER_OR_EQUAL) reduce 500) ((T_IS_IDENTICAL) reduce 500) ((T_IS_NOT_EQUAL) reduce 500) ((T_IS_NOT_IDENTICAL) reduce 500) ((T_IS_SMALLER_OR_EQUAL) reduce 500) ((T_LOGICAL_AND) reduce 500) ((T_LOGICAL_OR) reduce 500) ((T_LOGICAL_XOR) reduce 500) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 500) ((T_OBJECT_OPERATOR) reduce 500) ((T_POW) reduce 500) ((T_SL) reduce 500) ((T_SPACESHIP) reduce 500) ((T_SR) reduce 500) (("[") reduce 500) (("]") reduce 500) (("^") reduce 500) (("{") reduce 500) (("|") reduce 500)) 11703 ((("%") reduce 495) (("*") reduce 495) (("+") reduce 495) (("-") reduce 495) ((".") reduce 495) (("/") reduce 495) (("<") reduce 495) ((">") reduce 495) (("?") reduce 495) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_BOOLEAN_AND) reduce 495) ((T_BOOLEAN_OR) reduce 495) ((T_COALESCE) reduce 495) ((T_DOUBLE_ARROW) reduce 495) ((T_INSTANCEOF) reduce 495) ((T_IS_EQUAL) reduce 495) ((T_IS_GREATER_OR_EQUAL) reduce 495) ((T_IS_IDENTICAL) reduce 495) ((T_IS_NOT_EQUAL) reduce 495) ((T_IS_NOT_IDENTICAL) reduce 495) ((T_IS_SMALLER_OR_EQUAL) reduce 495) ((T_LOGICAL_AND) reduce 495) ((T_LOGICAL_OR) reduce 495) ((T_LOGICAL_XOR) reduce 495) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 495) ((T_OBJECT_OPERATOR) reduce 495) ((T_POW) reduce 495) ((T_SL) reduce 495) ((T_SPACESHIP) reduce 495) ((T_SR) reduce 495) (("[") reduce 495) (("]") reduce 495) (("^") reduce 495) (("{") reduce 495) (("|") reduce 495)) 11705 ((("%") reduce 486) (("*") reduce 486) (("+") reduce 486) (("-") reduce 486) ((".") reduce 486) (("/") reduce 486) (("<") reduce 486) ((">") reduce 486) (("?") reduce 486) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_BOOLEAN_AND) reduce 486) ((T_BOOLEAN_OR) reduce 486) ((T_COALESCE) reduce 486) ((T_DOUBLE_ARROW) reduce 486) ((T_INSTANCEOF) reduce 486) ((T_IS_EQUAL) reduce 486) ((T_IS_GREATER_OR_EQUAL) reduce 486) ((T_IS_IDENTICAL) reduce 486) ((T_IS_NOT_EQUAL) reduce 486) ((T_IS_NOT_IDENTICAL) reduce 486) ((T_IS_SMALLER_OR_EQUAL) reduce 486) ((T_LOGICAL_AND) reduce 486) ((T_LOGICAL_OR) reduce 486) ((T_LOGICAL_XOR) reduce 486) ((T_POW) reduce 486) ((T_SL) reduce 486) ((T_SPACESHIP) reduce 486) ((T_SR) reduce 486) (("]") reduce 486) (("^") reduce 486) (("|") reduce 486)) 11707 ((("%") reduce 499) (("*") reduce 499) (("+") reduce 499) (("-") reduce 499) ((".") reduce 499) (("/") reduce 499) (("<") reduce 499) ((">") reduce 499) (("?") reduce 499) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_BOOLEAN_AND) reduce 499) ((T_BOOLEAN_OR) reduce 499) ((T_COALESCE) reduce 499) ((T_DOUBLE_ARROW) reduce 499) ((T_INSTANCEOF) reduce 499) ((T_IS_EQUAL) reduce 499) ((T_IS_GREATER_OR_EQUAL) reduce 499) ((T_IS_IDENTICAL) reduce 499) ((T_IS_NOT_EQUAL) reduce 499) ((T_IS_NOT_IDENTICAL) reduce 499) ((T_IS_SMALLER_OR_EQUAL) reduce 499) ((T_LOGICAL_AND) reduce 499) ((T_LOGICAL_OR) reduce 499) ((T_LOGICAL_XOR) reduce 499) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 499) ((T_OBJECT_OPERATOR) reduce 499) ((T_POW) reduce 499) ((T_SL) reduce 499) ((T_SPACESHIP) reduce 499) ((T_SR) reduce 499) (("[") reduce 499) (("]") reduce 499) (("^") reduce 499) (("{") reduce 499) (("|") reduce 499)) 11708 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 93) ((T_OBJECT_OPERATOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("[") reduce 93) (("]") reduce 93) (("^") reduce 93) (("{") reduce 93) (("|") reduce 93)) 11709 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 92) ((T_OBJECT_OPERATOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("[") reduce 92) (("]") reduce 92) (("^") reduce 92) (("{") reduce 92) (("|") reduce 92)) 11710 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 94) ((T_OBJECT_OPERATOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("[") reduce 94) (("]") reduce 94) (("^") reduce 94) (("{") reduce 94) (("|") reduce 94)) 11712 ((("%") reduce 501) (("*") reduce 501) (("+") reduce 501) (("-") reduce 501) ((".") reduce 501) (("/") reduce 501) (("<") reduce 501) ((">") reduce 501) (("?") reduce 501) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_BOOLEAN_AND) reduce 501) ((T_BOOLEAN_OR) reduce 501) ((T_COALESCE) reduce 501) ((T_DOUBLE_ARROW) reduce 501) ((T_INSTANCEOF) reduce 501) ((T_IS_EQUAL) reduce 501) ((T_IS_GREATER_OR_EQUAL) reduce 501) ((T_IS_IDENTICAL) reduce 501) ((T_IS_NOT_EQUAL) reduce 501) ((T_IS_NOT_IDENTICAL) reduce 501) ((T_IS_SMALLER_OR_EQUAL) reduce 501) ((T_LOGICAL_AND) reduce 501) ((T_LOGICAL_OR) reduce 501) ((T_LOGICAL_XOR) reduce 501) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 501) ((T_OBJECT_OPERATOR) reduce 501) ((T_POW) reduce 501) ((T_SL) reduce 501) ((T_SPACESHIP) reduce 501) ((T_SR) reduce 501) (("[") reduce 501) (("]") reduce 501) (("^") reduce 501) (("{") reduce 501) (("|") reduce 501)) 11720 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 91) ((T_OBJECT_OPERATOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("[") reduce 91) (("]") reduce 91) (("^") reduce 91) (("{") reduce 91) (("|") reduce 91)) 11723 ((("%") reduce 498) (("*") reduce 498) (("+") reduce 498) (("-") reduce 498) ((".") reduce 498) (("/") reduce 498) (("<") reduce 498) ((">") reduce 498) (("?") reduce 498) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_BOOLEAN_AND) reduce 498) ((T_BOOLEAN_OR) reduce 498) ((T_COALESCE) reduce 498) ((T_DOUBLE_ARROW) reduce 498) ((T_INSTANCEOF) reduce 498) ((T_IS_EQUAL) reduce 498) ((T_IS_GREATER_OR_EQUAL) reduce 498) ((T_IS_IDENTICAL) reduce 498) ((T_IS_NOT_EQUAL) reduce 498) ((T_IS_NOT_IDENTICAL) reduce 498) ((T_IS_SMALLER_OR_EQUAL) reduce 498) ((T_LOGICAL_AND) reduce 498) ((T_LOGICAL_OR) reduce 498) ((T_LOGICAL_XOR) reduce 498) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 498) ((T_OBJECT_OPERATOR) reduce 498) ((T_POW) reduce 498) ((T_SL) reduce 498) ((T_SPACESHIP) reduce 498) ((T_SR) reduce 498) (("[") reduce 498) (("]") reduce 498) (("^") reduce 498) (("{") reduce 498) (("|") reduce 498)) 11725 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) (("=") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AND_EQUAL) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_COALESCE_EQUAL) reduce 529) ((T_CONCAT_EQUAL) reduce 529) ((T_DEC) reduce 529) ((T_DIV_EQUAL) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INC) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_MINUS_EQUAL) reduce 529) ((T_MOD_EQUAL) reduce 529) ((T_MUL_EQUAL) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_OR_EQUAL) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_PLUS_EQUAL) reduce 529) ((T_POW) reduce 529) ((T_POW_EQUAL) reduce 529) ((T_SL) reduce 529) ((T_SL_EQUAL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) ((T_SR_EQUAL) reduce 529) ((T_XOR_EQUAL) reduce 529) (("[") reduce 529) (("]") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 11726 ((("!") shift) (("\"") shift) (("$") shift) (("%") reduce 440) (("(") shift) (("*") reduce 440) (("+") shift) (("-") shift) ((".") reduce 440) (("/") reduce 440) (("<") reduce 440) ((">") reduce 440) (("?") reduce 440) (("@") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOLEAN_AND) reduce 440) ((T_BOOLEAN_OR) reduce 440) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_COALESCE) reduce 440) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_ARROW) reduce 440) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INSTANCEOF) reduce 440) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_IS_EQUAL) reduce 440) ((T_IS_GREATER_OR_EQUAL) reduce 440) ((T_IS_IDENTICAL) reduce 440) ((T_IS_NOT_EQUAL) reduce 440) ((T_IS_NOT_IDENTICAL) reduce 440) ((T_IS_SMALLER_OR_EQUAL) reduce 440) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_LOGICAL_AND) reduce 440) ((T_LOGICAL_OR) reduce 440) ((T_LOGICAL_XOR) reduce 440) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_POW) reduce 440) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_SL) reduce 440) ((T_SPACESHIP) reduce 440) ((T_SR) reduce 440) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("]") reduce 440) (("^") reduce 440) (("`") shift) (("|") reduce 440) (("~") shift)) 11733 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) (("<") reduce 525) (("=") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AND_EQUAL) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_COALESCE_EQUAL) reduce 525) ((T_CONCAT_EQUAL) reduce 525) ((T_DEC) reduce 525) ((T_DIV_EQUAL) reduce 525) ((T_DOUBLE_ARROW) reduce 525) ((T_INC) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_MINUS_EQUAL) reduce 525) ((T_MOD_EQUAL) reduce 525) ((T_MUL_EQUAL) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_OR_EQUAL) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_PLUS_EQUAL) reduce 525) ((T_POW) reduce 525) ((T_POW_EQUAL) reduce 525) ((T_SL) reduce 525) ((T_SL_EQUAL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) ((T_SR_EQUAL) reduce 525) ((T_XOR_EQUAL) reduce 525) (("[") reduce 525) (("]") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 11734 ((("%") reduce 493) (("*") reduce 493) (("+") reduce 493) (("-") reduce 493) ((".") reduce 493) (("/") reduce 493) (("<") reduce 493) ((">") reduce 493) (("?") reduce 493) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_BOOLEAN_AND) reduce 493) ((T_BOOLEAN_OR) reduce 493) ((T_COALESCE) reduce 493) ((T_DOUBLE_ARROW) reduce 493) ((T_INSTANCEOF) reduce 493) ((T_IS_EQUAL) reduce 493) ((T_IS_GREATER_OR_EQUAL) reduce 493) ((T_IS_IDENTICAL) reduce 493) ((T_IS_NOT_EQUAL) reduce 493) ((T_IS_NOT_IDENTICAL) reduce 493) ((T_IS_SMALLER_OR_EQUAL) reduce 493) ((T_LOGICAL_AND) reduce 493) ((T_LOGICAL_OR) reduce 493) ((T_LOGICAL_XOR) reduce 493) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 513) ((T_OBJECT_OPERATOR) reduce 513) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 513) ((T_POW) reduce 493) ((T_SL) reduce 493) ((T_SPACESHIP) reduce 493) ((T_SR) reduce 493) (("[") reduce 513) (("]") reduce 493) (("^") reduce 493) (("{") reduce 513) (("|") reduce 493)) 11736 ((("%") reduce 492) (("*") reduce 492) (("+") reduce 492) (("-") reduce 492) ((".") reduce 492) (("/") reduce 492) (("<") reduce 492) ((">") reduce 492) (("?") reduce 492) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_BOOLEAN_AND) reduce 492) ((T_BOOLEAN_OR) reduce 492) ((T_COALESCE) reduce 492) ((T_DOUBLE_ARROW) reduce 492) ((T_INSTANCEOF) reduce 492) ((T_IS_EQUAL) reduce 492) ((T_IS_GREATER_OR_EQUAL) reduce 492) ((T_IS_IDENTICAL) reduce 492) ((T_IS_NOT_EQUAL) reduce 492) ((T_IS_NOT_IDENTICAL) reduce 492) ((T_IS_SMALLER_OR_EQUAL) reduce 492) ((T_LOGICAL_AND) reduce 492) ((T_LOGICAL_OR) reduce 492) ((T_LOGICAL_XOR) reduce 492) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 515) ((T_OBJECT_OPERATOR) reduce 515) ((T_POW) reduce 492) ((T_SL) reduce 492) ((T_SPACESHIP) reduce 492) ((T_SR) reduce 492) (("[") reduce 515) (("]") reduce 492) (("^") reduce 492) (("{") reduce 515) (("|") reduce 492)) 11737 ((("%") reduce 491) (("(") reduce 518) (("*") reduce 491) (("+") reduce 491) (("-") reduce 491) ((".") reduce 491) (("/") reduce 491) (("<") reduce 491) ((">") reduce 491) (("?") reduce 491) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_BOOLEAN_AND) reduce 491) ((T_BOOLEAN_OR) reduce 491) ((T_COALESCE) reduce 491) ((T_DOUBLE_ARROW) reduce 491) ((T_INSTANCEOF) reduce 491) ((T_IS_EQUAL) reduce 491) ((T_IS_GREATER_OR_EQUAL) reduce 491) ((T_IS_IDENTICAL) reduce 491) ((T_IS_NOT_EQUAL) reduce 491) ((T_IS_NOT_IDENTICAL) reduce 491) ((T_IS_SMALLER_OR_EQUAL) reduce 491) ((T_LOGICAL_AND) reduce 491) ((T_LOGICAL_OR) reduce 491) ((T_LOGICAL_XOR) reduce 491) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 512) ((T_OBJECT_OPERATOR) reduce 512) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 512) ((T_POW) reduce 491) ((T_SL) reduce 491) ((T_SPACESHIP) reduce 491) ((T_SR) reduce 491) (("[") reduce 512) (("]") reduce 491) (("^") reduce 491) (("{") reduce 512) (("|") reduce 491)) 11738 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 441) ((T_LOGICAL_OR) reduce 441) ((T_LOGICAL_XOR) reduce 441) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 441) (("^") shift) (("|") shift)) 11741 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) (("<") reduce 524) (("=") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AND_EQUAL) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_COALESCE_EQUAL) reduce 524) ((T_CONCAT_EQUAL) reduce 524) ((T_DEC) reduce 524) ((T_DIV_EQUAL) reduce 524) ((T_DOUBLE_ARROW) reduce 524) ((T_INC) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_MINUS_EQUAL) reduce 524) ((T_MOD_EQUAL) reduce 524) ((T_MUL_EQUAL) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_OR_EQUAL) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_PLUS_EQUAL) reduce 524) ((T_POW) reduce 524) ((T_POW_EQUAL) reduce 524) ((T_SL) reduce 524) ((T_SL_EQUAL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) ((T_SR_EQUAL) reduce 524) ((T_XOR_EQUAL) reduce 524) (("[") reduce 524) (("]") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 11742 ((("%") reduce 445) (("*") reduce 445) (("+") reduce 445) (("-") reduce 445) ((".") reduce 445) (("/") reduce 445) (("<") reduce 445) ((">") reduce 445) (("?") reduce 445) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_BOOLEAN_AND) reduce 445) ((T_BOOLEAN_OR) reduce 445) ((T_COALESCE) reduce 445) ((T_DOUBLE_ARROW) reduce 445) ((T_INSTANCEOF) reduce 445) ((T_IS_EQUAL) reduce 445) ((T_IS_GREATER_OR_EQUAL) reduce 445) ((T_IS_IDENTICAL) reduce 445) ((T_IS_NOT_EQUAL) reduce 445) ((T_IS_NOT_IDENTICAL) reduce 445) ((T_IS_SMALLER_OR_EQUAL) reduce 445) ((T_LOGICAL_AND) reduce 445) ((T_LOGICAL_OR) reduce 445) ((T_LOGICAL_XOR) reduce 445) ((T_POW) reduce 445) ((T_SL) reduce 445) ((T_SPACESHIP) reduce 445) ((T_SR) reduce 445) (("]") reduce 445) (("^") reduce 445) (("|") reduce 445)) 11743 ((("%") reduce 427) (("*") reduce 427) (("+") reduce 427) (("-") reduce 427) ((".") reduce 427) (("/") reduce 427) (("<") reduce 427) ((">") reduce 427) (("?") reduce 427) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_BOOLEAN_AND) reduce 427) ((T_BOOLEAN_OR) reduce 427) ((T_COALESCE) reduce 427) ((T_DOUBLE_ARROW) reduce 427) ((T_INSTANCEOF) reduce 427) ((T_IS_EQUAL) reduce 427) ((T_IS_GREATER_OR_EQUAL) reduce 427) ((T_IS_IDENTICAL) reduce 427) ((T_IS_NOT_EQUAL) reduce 427) ((T_IS_NOT_IDENTICAL) reduce 427) ((T_IS_SMALLER_OR_EQUAL) reduce 427) ((T_LOGICAL_AND) reduce 427) ((T_LOGICAL_OR) reduce 427) ((T_LOGICAL_XOR) reduce 427) ((T_POW) reduce 427) ((T_SL) reduce 427) ((T_SPACESHIP) reduce 427) ((T_SR) reduce 427) (("]") reduce 427) (("^") reduce 427) (("|") reduce 427)) 11744 ((("%") reduce 449) (("*") reduce 449) (("+") reduce 449) (("-") reduce 449) ((".") reduce 449) (("/") reduce 449) (("<") reduce 449) ((">") reduce 449) (("?") reduce 449) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_BOOLEAN_AND) reduce 449) ((T_BOOLEAN_OR) reduce 449) ((T_COALESCE) reduce 449) ((T_DOUBLE_ARROW) reduce 449) ((T_INSTANCEOF) reduce 449) ((T_IS_EQUAL) reduce 449) ((T_IS_GREATER_OR_EQUAL) reduce 449) ((T_IS_IDENTICAL) reduce 449) ((T_IS_NOT_EQUAL) reduce 449) ((T_IS_NOT_IDENTICAL) reduce 449) ((T_IS_SMALLER_OR_EQUAL) reduce 449) ((T_LOGICAL_AND) reduce 449) ((T_LOGICAL_OR) reduce 449) ((T_LOGICAL_XOR) reduce 449) ((T_POW) reduce 449) ((T_SL) reduce 449) ((T_SPACESHIP) reduce 449) ((T_SR) reduce 449) (("]") reduce 449) (("^") reduce 449) (("|") reduce 449)) 11745 ((("%") reduce 494) (("(") shift) (("*") reduce 494) (("+") reduce 494) (("-") reduce 494) ((".") reduce 494) (("/") reduce 494) (("<") reduce 494) ((">") reduce 494) (("?") reduce 494) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_BOOLEAN_AND) reduce 494) ((T_BOOLEAN_OR) reduce 494) ((T_COALESCE) reduce 494) ((T_DOUBLE_ARROW) reduce 494) ((T_INSTANCEOF) reduce 494) ((T_IS_EQUAL) reduce 494) ((T_IS_GREATER_OR_EQUAL) reduce 494) ((T_IS_IDENTICAL) reduce 494) ((T_IS_NOT_EQUAL) reduce 494) ((T_IS_NOT_IDENTICAL) reduce 494) ((T_IS_SMALLER_OR_EQUAL) reduce 494) ((T_LOGICAL_AND) reduce 494) ((T_LOGICAL_OR) reduce 494) ((T_LOGICAL_XOR) reduce 494) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 494) ((T_OBJECT_OPERATOR) reduce 494) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 494) ((T_SL) reduce 494) ((T_SPACESHIP) reduce 494) ((T_SR) reduce 494) (("[") reduce 494) (("]") reduce 494) (("^") reduce 494) (("{") reduce 494) (("|") reduce 494)) 11746 ((("%") reduce 423) (("*") reduce 423) (("+") reduce 423) (("-") reduce 423) ((".") reduce 423) (("/") reduce 423) (("<") reduce 423) ((">") reduce 423) (("?") reduce 423) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_BOOLEAN_AND) reduce 423) ((T_BOOLEAN_OR) reduce 423) ((T_COALESCE) reduce 423) ((T_DOUBLE_ARROW) reduce 423) ((T_INSTANCEOF) reduce 423) ((T_IS_EQUAL) reduce 423) ((T_IS_GREATER_OR_EQUAL) reduce 423) ((T_IS_IDENTICAL) reduce 423) ((T_IS_NOT_EQUAL) reduce 423) ((T_IS_NOT_IDENTICAL) reduce 423) ((T_IS_SMALLER_OR_EQUAL) reduce 423) ((T_LOGICAL_AND) reduce 423) ((T_LOGICAL_OR) reduce 423) ((T_LOGICAL_XOR) reduce 423) ((T_POW) reduce 423) ((T_SL) reduce 423) ((T_SPACESHIP) reduce 423) ((T_SR) reduce 423) (("]") reduce 423) (("^") reduce 423) (("|") reduce 423)) 11747 ((("%") reduce 437) (("*") reduce 437) (("+") reduce 437) (("-") reduce 437) ((".") reduce 437) (("/") reduce 437) (("<") reduce 437) ((">") reduce 437) (("?") reduce 437) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_BOOLEAN_AND) reduce 437) ((T_BOOLEAN_OR) reduce 437) ((T_COALESCE) reduce 437) ((T_DOUBLE_ARROW) reduce 437) ((T_INSTANCEOF) reduce 437) ((T_IS_EQUAL) reduce 437) ((T_IS_GREATER_OR_EQUAL) reduce 437) ((T_IS_IDENTICAL) reduce 437) ((T_IS_NOT_EQUAL) reduce 437) ((T_IS_NOT_IDENTICAL) reduce 437) ((T_IS_SMALLER_OR_EQUAL) reduce 437) ((T_LOGICAL_AND) reduce 437) ((T_LOGICAL_OR) reduce 437) ((T_LOGICAL_XOR) reduce 437) ((T_POW) reduce 437) ((T_SL) reduce 437) ((T_SPACESHIP) reduce 437) ((T_SR) reduce 437) (("]") reduce 437) (("^") reduce 437) (("|") reduce 437)) 11748 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) (("<") reduce 519) (("=") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AND_EQUAL) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_COALESCE_EQUAL) reduce 519) ((T_CONCAT_EQUAL) reduce 519) ((T_DEC) reduce 519) ((T_DIV_EQUAL) reduce 519) ((T_DOUBLE_ARROW) reduce 519) ((T_INC) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_MINUS_EQUAL) reduce 519) ((T_MOD_EQUAL) reduce 519) ((T_MUL_EQUAL) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_OR_EQUAL) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_PLUS_EQUAL) reduce 519) ((T_POW) reduce 519) ((T_POW_EQUAL) reduce 519) ((T_SL) reduce 519) ((T_SL_EQUAL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) ((T_SR_EQUAL) reduce 519) ((T_XOR_EQUAL) reduce 519) (("[") reduce 519) (("]") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 11749 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) (("<") reduce 526) (("=") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AND_EQUAL) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_COALESCE_EQUAL) reduce 526) ((T_CONCAT_EQUAL) reduce 526) ((T_DEC) reduce 526) ((T_DIV_EQUAL) reduce 526) ((T_DOUBLE_ARROW) reduce 526) ((T_INC) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_MINUS_EQUAL) reduce 526) ((T_MOD_EQUAL) reduce 526) ((T_MUL_EQUAL) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_OR_EQUAL) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_PLUS_EQUAL) reduce 526) ((T_POW) reduce 526) ((T_POW_EQUAL) reduce 526) ((T_SL) reduce 526) ((T_SL_EQUAL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) ((T_SR_EQUAL) reduce 526) ((T_XOR_EQUAL) reduce 526) (("[") reduce 526) (("]") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 11750 ((("%") reduce 367) (("*") reduce 367) (("+") reduce 367) (("-") reduce 367) ((".") reduce 367) (("/") reduce 367) (("<") reduce 367) (("=") shift) ((">") reduce 367) (("?") reduce 367) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AND_EQUAL) shift) ((T_BOOLEAN_AND) reduce 367) ((T_BOOLEAN_OR) reduce 367) ((T_COALESCE) reduce 367) ((T_COALESCE_EQUAL) shift) ((T_CONCAT_EQUAL) shift) ((T_DEC) shift) ((T_DIV_EQUAL) shift) ((T_DOUBLE_ARROW) reduce 367) ((T_INC) shift) ((T_INSTANCEOF) reduce 367) ((T_IS_EQUAL) reduce 367) ((T_IS_GREATER_OR_EQUAL) reduce 367) ((T_IS_IDENTICAL) reduce 367) ((T_IS_NOT_EQUAL) reduce 367) ((T_IS_NOT_IDENTICAL) reduce 367) ((T_IS_SMALLER_OR_EQUAL) reduce 367) ((T_LOGICAL_AND) reduce 367) ((T_LOGICAL_OR) reduce 367) ((T_LOGICAL_XOR) reduce 367) ((T_MINUS_EQUAL) shift) ((T_MOD_EQUAL) shift) ((T_MUL_EQUAL) shift) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_OR_EQUAL) shift) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_PLUS_EQUAL) shift) ((T_POW) reduce 367) ((T_POW_EQUAL) shift) ((T_SL) reduce 367) ((T_SL_EQUAL) shift) ((T_SPACESHIP) reduce 367) ((T_SR) reduce 367) ((T_SR_EQUAL) shift) ((T_XOR_EQUAL) shift) (("[") reduce 510) (("]") reduce 367) (("^") reduce 367) (("{") reduce 510) (("|") reduce 367)) 11753 ((("%") reduce 411) (("*") reduce 411) (("+") reduce 411) (("-") reduce 411) ((".") reduce 411) (("/") reduce 411) (("<") reduce 411) ((">") reduce 411) (("?") reduce 411) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_BOOLEAN_AND) reduce 411) ((T_BOOLEAN_OR) reduce 411) ((T_COALESCE) reduce 411) ((T_DOUBLE_ARROW) reduce 411) ((T_INSTANCEOF) reduce 411) ((T_IS_EQUAL) reduce 411) ((T_IS_GREATER_OR_EQUAL) reduce 411) ((T_IS_IDENTICAL) reduce 411) ((T_IS_NOT_EQUAL) reduce 411) ((T_IS_NOT_IDENTICAL) reduce 411) ((T_IS_SMALLER_OR_EQUAL) reduce 411) ((T_LOGICAL_AND) reduce 411) ((T_LOGICAL_OR) reduce 411) ((T_LOGICAL_XOR) reduce 411) ((T_POW) shift) ((T_SL) reduce 411) ((T_SPACESHIP) reduce 411) ((T_SR) reduce 411) (("]") reduce 411) (("^") reduce 411) (("|") reduce 411)) 11784 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 395) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 395) ((T_BOOLEAN_OR) reduce 395) ((T_COALESCE) reduce 395) ((T_DOUBLE_ARROW) reduce 395) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 395) ((T_LOGICAL_OR) reduce 395) ((T_LOGICAL_XOR) reduce 395) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 395) (("^") shift) (("|") reduce 395)) 11785 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 398) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 398) ((T_BOOLEAN_OR) reduce 398) ((T_COALESCE) reduce 398) ((T_DOUBLE_ARROW) reduce 398) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 398) ((T_LOGICAL_OR) reduce 398) ((T_LOGICAL_XOR) reduce 398) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 398) (("^") reduce 398) (("|") reduce 398)) 11786 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 407) (("/") shift) (("<") reduce 407) ((">") reduce 407) (("?") reduce 407) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_BOOLEAN_AND) reduce 407) ((T_BOOLEAN_OR) reduce 407) ((T_COALESCE) reduce 407) ((T_DOUBLE_ARROW) reduce 407) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 407) ((T_IS_GREATER_OR_EQUAL) reduce 407) ((T_IS_IDENTICAL) reduce 407) ((T_IS_NOT_EQUAL) reduce 407) ((T_IS_NOT_IDENTICAL) reduce 407) ((T_IS_SMALLER_OR_EQUAL) reduce 407) ((T_LOGICAL_AND) reduce 407) ((T_LOGICAL_OR) reduce 407) ((T_LOGICAL_XOR) reduce 407) ((T_POW) shift) ((T_SL) reduce 407) ((T_SPACESHIP) reduce 407) ((T_SR) reduce 407) (("]") reduce 407) (("^") reduce 407) (("|") reduce 407)) 11787 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 420) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_BOOLEAN_AND) reduce 420) ((T_BOOLEAN_OR) reduce 420) ((T_COALESCE) reduce 420) ((T_DOUBLE_ARROW) reduce 420) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 420) ((T_LOGICAL_OR) reduce 420) ((T_LOGICAL_XOR) reduce 420) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 420) (("^") reduce 420) (("|") reduce 420)) 11788 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 406) (("/") shift) (("<") reduce 406) ((">") reduce 406) (("?") reduce 406) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_BOOLEAN_AND) reduce 406) ((T_BOOLEAN_OR) reduce 406) ((T_COALESCE) reduce 406) ((T_DOUBLE_ARROW) reduce 406) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 406) ((T_IS_GREATER_OR_EQUAL) reduce 406) ((T_IS_IDENTICAL) reduce 406) ((T_IS_NOT_EQUAL) reduce 406) ((T_IS_NOT_IDENTICAL) reduce 406) ((T_IS_SMALLER_OR_EQUAL) reduce 406) ((T_LOGICAL_AND) reduce 406) ((T_LOGICAL_OR) reduce 406) ((T_LOGICAL_XOR) reduce 406) ((T_POW) shift) ((T_SL) reduce 406) ((T_SPACESHIP) reduce 406) ((T_SR) reduce 406) (("]") reduce 406) (("^") reduce 406) (("|") reduce 406)) 11789 ((("%") reduce 403) (("*") reduce 403) (("+") reduce 403) (("-") reduce 403) ((".") reduce 403) (("/") reduce 403) (("<") reduce 403) ((">") reduce 403) (("?") reduce 403) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_BOOLEAN_AND) reduce 403) ((T_BOOLEAN_OR) reduce 403) ((T_COALESCE) reduce 403) ((T_DOUBLE_ARROW) reduce 403) ((T_INSTANCEOF) reduce 403) ((T_IS_EQUAL) reduce 403) ((T_IS_GREATER_OR_EQUAL) reduce 403) ((T_IS_IDENTICAL) reduce 403) ((T_IS_NOT_EQUAL) reduce 403) ((T_IS_NOT_IDENTICAL) reduce 403) ((T_IS_SMALLER_OR_EQUAL) reduce 403) ((T_LOGICAL_AND) reduce 403) ((T_LOGICAL_OR) reduce 403) ((T_LOGICAL_XOR) reduce 403) ((T_POW) shift) ((T_SL) reduce 403) ((T_SPACESHIP) reduce 403) ((T_SR) reduce 403) (("]") reduce 403) (("^") reduce 403) (("|") reduce 403)) 11790 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 394) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 394) ((T_LOGICAL_XOR) reduce 394) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 394) (("^") shift) (("|") shift)) 11791 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 392) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 392) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 392) (("^") shift) (("|") shift)) 11792 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 393) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 393) ((T_LOGICAL_OR) reduce 393) ((T_LOGICAL_XOR) reduce 393) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 393) (("^") shift) (("|") shift)) 11793 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 417) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_BOOLEAN_AND) reduce 417) ((T_BOOLEAN_OR) reduce 417) ((T_COALESCE) reduce 417) ((T_DOUBLE_ARROW) reduce 417) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 417) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 417) ((T_IS_NOT_EQUAL) reduce 417) ((T_IS_NOT_IDENTICAL) reduce 417) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 417) ((T_LOGICAL_OR) reduce 417) ((T_LOGICAL_XOR) reduce 417) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 417) ((T_SR) shift) (("]") reduce 417) (("^") reduce 417) (("|") reduce 417)) 11794 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 413) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_BOOLEAN_AND) reduce 413) ((T_BOOLEAN_OR) reduce 413) ((T_COALESCE) reduce 413) ((T_DOUBLE_ARROW) reduce 413) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 413) ((T_LOGICAL_OR) reduce 413) ((T_LOGICAL_XOR) reduce 413) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 413) (("^") reduce 413) (("|") reduce 413)) 11795 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 415) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_BOOLEAN_AND) reduce 415) ((T_BOOLEAN_OR) reduce 415) ((T_COALESCE) reduce 415) ((T_DOUBLE_ARROW) reduce 415) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 415) ((T_LOGICAL_OR) reduce 415) ((T_LOGICAL_XOR) reduce 415) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 415) (("^") reduce 415) (("|") reduce 415)) 11796 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 412) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_BOOLEAN_AND) reduce 412) ((T_BOOLEAN_OR) reduce 412) ((T_COALESCE) reduce 412) ((T_DOUBLE_ARROW) reduce 412) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 412) ((T_LOGICAL_OR) reduce 412) ((T_LOGICAL_XOR) reduce 412) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 412) (("^") reduce 412) (("|") reduce 412)) 11797 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 419) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_BOOLEAN_AND) reduce 419) ((T_BOOLEAN_OR) reduce 419) ((T_COALESCE) reduce 419) ((T_DOUBLE_ARROW) reduce 419) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 419) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 419) ((T_IS_NOT_EQUAL) reduce 419) ((T_IS_NOT_IDENTICAL) reduce 419) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 419) ((T_LOGICAL_OR) reduce 419) ((T_LOGICAL_XOR) reduce 419) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 419) ((T_SR) shift) (("]") reduce 419) (("^") reduce 419) (("|") reduce 419)) 11798 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 414) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_BOOLEAN_AND) reduce 414) ((T_BOOLEAN_OR) reduce 414) ((T_COALESCE) reduce 414) ((T_DOUBLE_ARROW) reduce 414) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 414) ((T_LOGICAL_OR) reduce 414) ((T_LOGICAL_XOR) reduce 414) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 414) (("^") reduce 414) (("|") reduce 414)) 11801 ((("%") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("]") reduce 93) (("^") reduce 93) (("|") reduce 93)) 11802 ((("%") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("]") reduce 92) (("^") reduce 92) (("|") reduce 92)) 11803 ((("%") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("]") reduce 94) (("^") reduce 94) (("|") reduce 94)) 11804 ((("%") reduce 470) (("*") reduce 470) (("+") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_DOUBLE_ARROW) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("]") reduce 470) (("^") reduce 470) (("|") reduce 470)) 11805 ((("%") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("]") reduce 91) (("^") reduce 91) (("|") reduce 91)) 11806 ((("%") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("]") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 11807 ((("%") reduce 472) (("*") reduce 472) (("+") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_DOUBLE_ARROW) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("]") reduce 472) (("^") reduce 472) (("|") reduce 472)) 11808 ((("%") reduce 421) (("*") reduce 421) (("+") reduce 421) (("-") reduce 421) ((".") reduce 421) (("/") reduce 421) (("<") reduce 421) ((">") reduce 421) (("?") reduce 421) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_BOOLEAN_AND) reduce 421) ((T_BOOLEAN_OR) reduce 421) ((T_COALESCE) reduce 421) ((T_DOUBLE_ARROW) reduce 421) ((T_INSTANCEOF) reduce 421) ((T_IS_EQUAL) reduce 421) ((T_IS_GREATER_OR_EQUAL) reduce 421) ((T_IS_IDENTICAL) reduce 421) ((T_IS_NOT_EQUAL) reduce 421) ((T_IS_NOT_IDENTICAL) reduce 421) ((T_IS_SMALLER_OR_EQUAL) reduce 421) ((T_LOGICAL_AND) reduce 421) ((T_LOGICAL_OR) reduce 421) ((T_LOGICAL_XOR) reduce 421) ((T_POW) reduce 421) ((T_SL) reduce 421) ((T_SPACESHIP) reduce 421) ((T_SR) reduce 421) (("]") reduce 421) (("^") reduce 421) (("|") reduce 421)) 11809 ((("%") reduce 471) (("*") reduce 471) (("+") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_DOUBLE_ARROW) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("]") reduce 471) (("^") reduce 471) (("|") reduce 471)) 11810 ((("%") reduce 473) (("*") reduce 473) (("+") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_DOUBLE_ARROW) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("]") reduce 473) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 11811 ((("%") reduce 534) (("*") reduce 534) (("+") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_DOUBLE_ARROW) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("]") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 11818 ((("%") reduce 536) (("*") reduce 536) (("+") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_DOUBLE_ARROW) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("]") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 11820 ((("%") reduce 535) (("*") reduce 535) (("+") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_DOUBLE_ARROW) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("]") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 11821 ((("%") reduce 540) (("*") reduce 540) (("+") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_DOUBLE_ARROW) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("]") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 11822 ((("%") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("]") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 11823 ((("%") reduce 537) (("*") reduce 537) (("+") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_DOUBLE_ARROW) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("]") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 11824 ((("%") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("]") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 11827 ((("%") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("]") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 11828 ((("%") reduce 538) (("*") reduce 538) (("+") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_DOUBLE_ARROW) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("]") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 11830 ((("%") reduce 539) (("*") reduce 539) (("+") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_DOUBLE_ARROW) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("]") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 11832 ((("%") reduce 474) (("*") reduce 474) (("+") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_DOUBLE_ARROW) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("]") reduce 474) (("^") reduce 474) (("|") reduce 474)) 11833 ((("%") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("]") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 11836 ((("%") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("]") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 11837 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 426) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 426) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 426) ((T_LOGICAL_OR) reduce 426) ((T_LOGICAL_XOR) reduce 426) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 426) (("^") shift) (("|") shift)) 11838 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 390) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) reduce 390) ((T_COALESCE) reduce 390) ((T_DOUBLE_ARROW) reduce 390) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 390) ((T_LOGICAL_OR) reduce 390) ((T_LOGICAL_XOR) reduce 390) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 390) (("^") shift) (("|") shift)) 11839 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 391) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 391) ((T_BOOLEAN_OR) reduce 391) ((T_COALESCE) reduce 391) ((T_DOUBLE_ARROW) reduce 391) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 391) ((T_LOGICAL_OR) reduce 391) ((T_LOGICAL_XOR) reduce 391) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 391) (("^") shift) (("|") shift)) 11840 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 396) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_BOOLEAN_AND) reduce 396) ((T_BOOLEAN_OR) reduce 396) ((T_COALESCE) reduce 396) ((T_DOUBLE_ARROW) reduce 396) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 396) ((T_LOGICAL_OR) reduce 396) ((T_LOGICAL_XOR) reduce 396) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 396) (("^") reduce 396) (("|") reduce 396)) 11841 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 397) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_BOOLEAN_AND) reduce 397) ((T_BOOLEAN_OR) reduce 397) ((T_COALESCE) reduce 397) ((T_DOUBLE_ARROW) reduce 397) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 397) ((T_LOGICAL_OR) reduce 397) ((T_LOGICAL_XOR) reduce 397) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 397) (("^") reduce 397) (("|") reduce 397)) 11845 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 424) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 424) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 424) ((T_LOGICAL_OR) reduce 424) ((T_LOGICAL_XOR) reduce 424) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 424) (("^") shift) (("|") shift)) 11846 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 425) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 425) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 425) ((T_LOGICAL_OR) reduce 425) ((T_LOGICAL_XOR) reduce 425) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 425) (("^") shift) (("|") shift)) 11847 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 418) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_BOOLEAN_AND) reduce 418) ((T_BOOLEAN_OR) reduce 418) ((T_COALESCE) reduce 418) ((T_DOUBLE_ARROW) reduce 418) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 418) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 418) ((T_IS_NOT_EQUAL) reduce 418) ((T_IS_NOT_IDENTICAL) reduce 418) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 418) ((T_LOGICAL_OR) reduce 418) ((T_LOGICAL_XOR) reduce 418) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 418) ((T_SR) shift) (("]") reduce 418) (("^") reduce 418) (("|") reduce 418)) 11848 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 416) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_BOOLEAN_AND) reduce 416) ((T_BOOLEAN_OR) reduce 416) ((T_COALESCE) reduce 416) ((T_DOUBLE_ARROW) reduce 416) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 416) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 416) ((T_IS_NOT_EQUAL) reduce 416) ((T_IS_NOT_IDENTICAL) reduce 416) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 416) ((T_LOGICAL_OR) reduce 416) ((T_LOGICAL_XOR) reduce 416) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 416) ((T_SR) shift) (("]") reduce 416) (("^") reduce 416) (("|") reduce 416)) 11849 ((("%") reduce 404) (("*") reduce 404) (("+") reduce 404) (("-") reduce 404) ((".") reduce 404) (("/") reduce 404) (("<") reduce 404) ((">") reduce 404) (("?") reduce 404) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_BOOLEAN_AND) reduce 404) ((T_BOOLEAN_OR) reduce 404) ((T_COALESCE) reduce 404) ((T_DOUBLE_ARROW) reduce 404) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 404) ((T_IS_GREATER_OR_EQUAL) reduce 404) ((T_IS_IDENTICAL) reduce 404) ((T_IS_NOT_EQUAL) reduce 404) ((T_IS_NOT_IDENTICAL) reduce 404) ((T_IS_SMALLER_OR_EQUAL) reduce 404) ((T_LOGICAL_AND) reduce 404) ((T_LOGICAL_OR) reduce 404) ((T_LOGICAL_XOR) reduce 404) ((T_POW) shift) ((T_SL) reduce 404) ((T_SPACESHIP) reduce 404) ((T_SR) reduce 404) (("]") reduce 404) (("^") reduce 404) (("|") reduce 404)) 11850 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 399) (("/") shift) (("<") reduce 399) ((">") reduce 399) (("?") reduce 399) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_BOOLEAN_AND) reduce 399) ((T_BOOLEAN_OR) reduce 399) ((T_COALESCE) reduce 399) ((T_DOUBLE_ARROW) reduce 399) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 399) ((T_IS_GREATER_OR_EQUAL) reduce 399) ((T_IS_IDENTICAL) reduce 399) ((T_IS_NOT_EQUAL) reduce 399) ((T_IS_NOT_IDENTICAL) reduce 399) ((T_IS_SMALLER_OR_EQUAL) reduce 399) ((T_LOGICAL_AND) reduce 399) ((T_LOGICAL_OR) reduce 399) ((T_LOGICAL_XOR) reduce 399) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 399) ((T_SR) shift) (("]") reduce 399) (("^") reduce 399) (("|") reduce 399)) 11851 ((("%") shift) (("*") shift) (("+") reduce 401) (("-") reduce 401) ((".") reduce 401) (("/") shift) (("<") reduce 401) ((">") reduce 401) (("?") reduce 401) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_BOOLEAN_AND) reduce 401) ((T_BOOLEAN_OR) reduce 401) ((T_COALESCE) reduce 401) ((T_DOUBLE_ARROW) reduce 401) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 401) ((T_IS_GREATER_OR_EQUAL) reduce 401) ((T_IS_IDENTICAL) reduce 401) ((T_IS_NOT_EQUAL) reduce 401) ((T_IS_NOT_IDENTICAL) reduce 401) ((T_IS_SMALLER_OR_EQUAL) reduce 401) ((T_LOGICAL_AND) reduce 401) ((T_LOGICAL_OR) reduce 401) ((T_LOGICAL_XOR) reduce 401) ((T_POW) shift) ((T_SL) reduce 401) ((T_SPACESHIP) reduce 401) ((T_SR) reduce 401) (("]") reduce 401) (("^") reduce 401) (("|") reduce 401)) 11852 ((("%") shift) (("*") shift) (("+") reduce 400) (("-") reduce 400) ((".") reduce 400) (("/") shift) (("<") reduce 400) ((">") reduce 400) (("?") reduce 400) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_BOOLEAN_AND) reduce 400) ((T_BOOLEAN_OR) reduce 400) ((T_COALESCE) reduce 400) ((T_DOUBLE_ARROW) reduce 400) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 400) ((T_IS_GREATER_OR_EQUAL) reduce 400) ((T_IS_IDENTICAL) reduce 400) ((T_IS_NOT_EQUAL) reduce 400) ((T_IS_NOT_IDENTICAL) reduce 400) ((T_IS_SMALLER_OR_EQUAL) reduce 400) ((T_LOGICAL_AND) reduce 400) ((T_LOGICAL_OR) reduce 400) ((T_LOGICAL_XOR) reduce 400) ((T_POW) shift) ((T_SL) reduce 400) ((T_SPACESHIP) reduce 400) ((T_SR) reduce 400) (("]") reduce 400) (("^") reduce 400) (("|") reduce 400)) 11853 ((("%") reduce 402) (("*") reduce 402) (("+") reduce 402) (("-") reduce 402) ((".") reduce 402) (("/") reduce 402) (("<") reduce 402) ((">") reduce 402) (("?") reduce 402) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_BOOLEAN_AND) reduce 402) ((T_BOOLEAN_OR) reduce 402) ((T_COALESCE) reduce 402) ((T_DOUBLE_ARROW) reduce 402) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 402) ((T_IS_GREATER_OR_EQUAL) reduce 402) ((T_IS_IDENTICAL) reduce 402) ((T_IS_NOT_EQUAL) reduce 402) ((T_IS_NOT_IDENTICAL) reduce 402) ((T_IS_SMALLER_OR_EQUAL) reduce 402) ((T_LOGICAL_AND) reduce 402) ((T_LOGICAL_OR) reduce 402) ((T_LOGICAL_XOR) reduce 402) ((T_POW) shift) ((T_SL) reduce 402) ((T_SPACESHIP) reduce 402) ((T_SR) reduce 402) (("]") reduce 402) (("^") reduce 402) (("|") reduce 402)) 11854 ((("%") reduce 405) (("*") reduce 405) (("+") reduce 405) (("-") reduce 405) ((".") reduce 405) (("/") reduce 405) (("<") reduce 405) ((">") reduce 405) (("?") reduce 405) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_BOOLEAN_AND) reduce 405) ((T_BOOLEAN_OR) reduce 405) ((T_COALESCE) reduce 405) ((T_DOUBLE_ARROW) reduce 405) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 405) ((T_IS_GREATER_OR_EQUAL) reduce 405) ((T_IS_IDENTICAL) reduce 405) ((T_IS_NOT_EQUAL) reduce 405) ((T_IS_NOT_IDENTICAL) reduce 405) ((T_IS_SMALLER_OR_EQUAL) reduce 405) ((T_LOGICAL_AND) reduce 405) ((T_LOGICAL_OR) reduce 405) ((T_LOGICAL_XOR) reduce 405) ((T_POW) shift) ((T_SL) reduce 405) ((T_SPACESHIP) reduce 405) ((T_SR) reduce 405) (("]") reduce 405) (("^") reduce 405) (("|") reduce 405)) 11856 ((("%") reduce 73) (("(") reduce 73) (("*") reduce 73) (("+") reduce 73) (("-") reduce 73) ((".") reduce 73) (("/") reduce 73) (("<") reduce 73) ((">") reduce 73) (("?") reduce 73) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_BOOLEAN_AND) reduce 73) ((T_BOOLEAN_OR) reduce 73) ((T_COALESCE) reduce 73) ((T_DOUBLE_ARROW) reduce 73) ((T_INSTANCEOF) reduce 73) ((T_IS_EQUAL) reduce 73) ((T_IS_GREATER_OR_EQUAL) reduce 73) ((T_IS_IDENTICAL) reduce 73) ((T_IS_NOT_EQUAL) reduce 73) ((T_IS_NOT_IDENTICAL) reduce 73) ((T_IS_SMALLER_OR_EQUAL) reduce 73) ((T_LOGICAL_AND) reduce 73) ((T_LOGICAL_OR) reduce 73) ((T_LOGICAL_XOR) reduce 73) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 73) ((T_OBJECT_OPERATOR) reduce 73) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 73) ((T_POW) reduce 73) ((T_SL) reduce 73) ((T_SPACESHIP) reduce 73) ((T_SR) reduce 73) (("[") reduce 73) (("]") reduce 73) (("^") reduce 73) (("{") reduce 73) (("|") reduce 73)) 11857 ((("%") reduce 52) (("(") reduce 52) (("*") reduce 52) (("+") reduce 52) (("-") reduce 52) ((".") reduce 52) (("/") reduce 52) (("<") reduce 52) ((">") reduce 52) (("?") reduce 52) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_BOOLEAN_AND) reduce 52) ((T_BOOLEAN_OR) reduce 52) ((T_COALESCE) reduce 52) ((T_DOUBLE_ARROW) reduce 52) ((T_INSTANCEOF) reduce 52) ((T_IS_EQUAL) reduce 52) ((T_IS_GREATER_OR_EQUAL) reduce 52) ((T_IS_IDENTICAL) reduce 52) ((T_IS_NOT_EQUAL) reduce 52) ((T_IS_NOT_IDENTICAL) reduce 52) ((T_IS_SMALLER_OR_EQUAL) reduce 52) ((T_LOGICAL_AND) reduce 52) ((T_LOGICAL_OR) reduce 52) ((T_LOGICAL_XOR) reduce 52) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 52) ((T_OBJECT_OPERATOR) reduce 52) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 52) ((T_POW) reduce 52) ((T_SL) reduce 52) ((T_SPACESHIP) reduce 52) ((T_SR) reduce 52) (("[") reduce 52) (("]") reduce 52) (("^") reduce 52) (("{") reduce 52) (("|") reduce 52)) 11858 ((("%") reduce 27) (("(") reduce 27) (("*") reduce 27) (("+") reduce 27) (("-") reduce 27) ((".") reduce 27) (("/") reduce 27) (("<") reduce 27) ((">") reduce 27) (("?") reduce 27) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_BOOLEAN_AND) reduce 27) ((T_BOOLEAN_OR) reduce 27) ((T_COALESCE) reduce 27) ((T_DOUBLE_ARROW) reduce 27) ((T_INSTANCEOF) reduce 27) ((T_IS_EQUAL) reduce 27) ((T_IS_GREATER_OR_EQUAL) reduce 27) ((T_IS_IDENTICAL) reduce 27) ((T_IS_NOT_EQUAL) reduce 27) ((T_IS_NOT_IDENTICAL) reduce 27) ((T_IS_SMALLER_OR_EQUAL) reduce 27) ((T_LOGICAL_AND) reduce 27) ((T_LOGICAL_OR) reduce 27) ((T_LOGICAL_XOR) reduce 27) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 27) ((T_OBJECT_OPERATOR) reduce 27) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 27) ((T_POW) reduce 27) ((T_SL) reduce 27) ((T_SPACESHIP) reduce 27) ((T_SR) reduce 27) (("[") reduce 27) (("]") reduce 27) (("^") reduce 27) (("{") reduce 27) (("|") reduce 27)) 11859 ((("%") reduce 51) (("(") reduce 51) (("*") reduce 51) (("+") reduce 51) (("-") reduce 51) ((".") reduce 51) (("/") reduce 51) (("<") reduce 51) ((">") reduce 51) (("?") reduce 51) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_BOOLEAN_AND) reduce 51) ((T_BOOLEAN_OR) reduce 51) ((T_COALESCE) reduce 51) ((T_DOUBLE_ARROW) reduce 51) ((T_INSTANCEOF) reduce 51) ((T_IS_EQUAL) reduce 51) ((T_IS_GREATER_OR_EQUAL) reduce 51) ((T_IS_IDENTICAL) reduce 51) ((T_IS_NOT_EQUAL) reduce 51) ((T_IS_NOT_IDENTICAL) reduce 51) ((T_IS_SMALLER_OR_EQUAL) reduce 51) ((T_LOGICAL_AND) reduce 51) ((T_LOGICAL_OR) reduce 51) ((T_LOGICAL_XOR) reduce 51) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 51) ((T_OBJECT_OPERATOR) reduce 51) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 51) ((T_POW) reduce 51) ((T_SL) reduce 51) ((T_SPACESHIP) reduce 51) ((T_SR) reduce 51) (("[") reduce 51) (("]") reduce 51) (("^") reduce 51) (("{") reduce 51) (("|") reduce 51)) 11860 ((("%") reduce 53) (("(") reduce 53) (("*") reduce 53) (("+") reduce 53) (("-") reduce 53) ((".") reduce 53) (("/") reduce 53) (("<") reduce 53) ((">") reduce 53) (("?") reduce 53) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_BOOLEAN_AND) reduce 53) ((T_BOOLEAN_OR) reduce 53) ((T_COALESCE) reduce 53) ((T_DOUBLE_ARROW) reduce 53) ((T_INSTANCEOF) reduce 53) ((T_IS_EQUAL) reduce 53) ((T_IS_GREATER_OR_EQUAL) reduce 53) ((T_IS_IDENTICAL) reduce 53) ((T_IS_NOT_EQUAL) reduce 53) ((T_IS_NOT_IDENTICAL) reduce 53) ((T_IS_SMALLER_OR_EQUAL) reduce 53) ((T_LOGICAL_AND) reduce 53) ((T_LOGICAL_OR) reduce 53) ((T_LOGICAL_XOR) reduce 53) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 53) ((T_OBJECT_OPERATOR) reduce 53) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 53) ((T_POW) reduce 53) ((T_SL) reduce 53) ((T_SPACESHIP) reduce 53) ((T_SR) reduce 53) (("[") reduce 53) (("]") reduce 53) (("^") reduce 53) (("{") reduce 53) (("|") reduce 53)) 11861 ((("%") reduce 49) (("(") reduce 49) (("*") reduce 49) (("+") reduce 49) (("-") reduce 49) ((".") reduce 49) (("/") reduce 49) (("<") reduce 49) ((">") reduce 49) (("?") reduce 49) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_BOOLEAN_AND) reduce 49) ((T_BOOLEAN_OR) reduce 49) ((T_COALESCE) reduce 49) ((T_DOUBLE_ARROW) reduce 49) ((T_INSTANCEOF) reduce 49) ((T_IS_EQUAL) reduce 49) ((T_IS_GREATER_OR_EQUAL) reduce 49) ((T_IS_IDENTICAL) reduce 49) ((T_IS_NOT_EQUAL) reduce 49) ((T_IS_NOT_IDENTICAL) reduce 49) ((T_IS_SMALLER_OR_EQUAL) reduce 49) ((T_LOGICAL_AND) reduce 49) ((T_LOGICAL_OR) reduce 49) ((T_LOGICAL_XOR) reduce 49) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 49) ((T_OBJECT_OPERATOR) reduce 49) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 49) ((T_POW) reduce 49) ((T_SL) reduce 49) ((T_SPACESHIP) reduce 49) ((T_SR) reduce 49) (("[") reduce 49) (("]") reduce 49) (("^") reduce 49) (("{") reduce 49) (("|") reduce 49)) 11862 ((("%") reduce 29) (("(") reduce 29) (("*") reduce 29) (("+") reduce 29) (("-") reduce 29) ((".") reduce 29) (("/") reduce 29) (("<") reduce 29) ((">") reduce 29) (("?") reduce 29) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_BOOLEAN_AND) reduce 29) ((T_BOOLEAN_OR) reduce 29) ((T_COALESCE) reduce 29) ((T_DOUBLE_ARROW) reduce 29) ((T_INSTANCEOF) reduce 29) ((T_IS_EQUAL) reduce 29) ((T_IS_GREATER_OR_EQUAL) reduce 29) ((T_IS_IDENTICAL) reduce 29) ((T_IS_NOT_EQUAL) reduce 29) ((T_IS_NOT_IDENTICAL) reduce 29) ((T_IS_SMALLER_OR_EQUAL) reduce 29) ((T_LOGICAL_AND) reduce 29) ((T_LOGICAL_OR) reduce 29) ((T_LOGICAL_XOR) reduce 29) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 29) ((T_OBJECT_OPERATOR) reduce 29) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 29) ((T_POW) reduce 29) ((T_SL) reduce 29) ((T_SPACESHIP) reduce 29) ((T_SR) reduce 29) (("[") reduce 29) (("]") reduce 29) (("^") reduce 29) (("{") reduce 29) (("|") reduce 29)) 11863 ((("%") reduce 59) (("(") reduce 59) (("*") reduce 59) (("+") reduce 59) (("-") reduce 59) ((".") reduce 59) (("/") reduce 59) (("<") reduce 59) ((">") reduce 59) (("?") reduce 59) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_BOOLEAN_AND) reduce 59) ((T_BOOLEAN_OR) reduce 59) ((T_COALESCE) reduce 59) ((T_DOUBLE_ARROW) reduce 59) ((T_INSTANCEOF) reduce 59) ((T_IS_EQUAL) reduce 59) ((T_IS_GREATER_OR_EQUAL) reduce 59) ((T_IS_IDENTICAL) reduce 59) ((T_IS_NOT_EQUAL) reduce 59) ((T_IS_NOT_IDENTICAL) reduce 59) ((T_IS_SMALLER_OR_EQUAL) reduce 59) ((T_LOGICAL_AND) reduce 59) ((T_LOGICAL_OR) reduce 59) ((T_LOGICAL_XOR) reduce 59) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 59) ((T_OBJECT_OPERATOR) reduce 59) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 59) ((T_POW) reduce 59) ((T_SL) reduce 59) ((T_SPACESHIP) reduce 59) ((T_SR) reduce 59) (("[") reduce 59) (("]") reduce 59) (("^") reduce 59) (("{") reduce 59) (("|") reduce 59)) 11864 ((("%") reduce 60) (("(") reduce 60) (("*") reduce 60) (("+") reduce 60) (("-") reduce 60) ((".") reduce 60) (("/") reduce 60) (("<") reduce 60) ((">") reduce 60) (("?") reduce 60) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_BOOLEAN_AND) reduce 60) ((T_BOOLEAN_OR) reduce 60) ((T_COALESCE) reduce 60) ((T_DOUBLE_ARROW) reduce 60) ((T_INSTANCEOF) reduce 60) ((T_IS_EQUAL) reduce 60) ((T_IS_GREATER_OR_EQUAL) reduce 60) ((T_IS_IDENTICAL) reduce 60) ((T_IS_NOT_EQUAL) reduce 60) ((T_IS_NOT_IDENTICAL) reduce 60) ((T_IS_SMALLER_OR_EQUAL) reduce 60) ((T_LOGICAL_AND) reduce 60) ((T_LOGICAL_OR) reduce 60) ((T_LOGICAL_XOR) reduce 60) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 60) ((T_OBJECT_OPERATOR) reduce 60) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 60) ((T_POW) reduce 60) ((T_SL) reduce 60) ((T_SPACESHIP) reduce 60) ((T_SR) reduce 60) (("[") reduce 60) (("]") reduce 60) (("^") reduce 60) (("{") reduce 60) (("|") reduce 60)) 11865 ((("%") reduce 11) (("(") reduce 11) (("*") reduce 11) (("+") reduce 11) (("-") reduce 11) ((".") reduce 11) (("/") reduce 11) (("<") reduce 11) ((">") reduce 11) (("?") reduce 11) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_BOOLEAN_AND) reduce 11) ((T_BOOLEAN_OR) reduce 11) ((T_COALESCE) reduce 11) ((T_DOUBLE_ARROW) reduce 11) ((T_INSTANCEOF) reduce 11) ((T_IS_EQUAL) reduce 11) ((T_IS_GREATER_OR_EQUAL) reduce 11) ((T_IS_IDENTICAL) reduce 11) ((T_IS_NOT_EQUAL) reduce 11) ((T_IS_NOT_IDENTICAL) reduce 11) ((T_IS_SMALLER_OR_EQUAL) reduce 11) ((T_LOGICAL_AND) reduce 11) ((T_LOGICAL_OR) reduce 11) ((T_LOGICAL_XOR) reduce 11) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 11) ((T_OBJECT_OPERATOR) reduce 11) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 11) ((T_POW) reduce 11) ((T_SL) reduce 11) ((T_SPACESHIP) reduce 11) ((T_SR) reduce 11) (("[") reduce 11) (("]") reduce 11) (("^") reduce 11) (("{") reduce 11) (("|") reduce 11)) 11866 ((("%") reduce 42) (("(") reduce 42) (("*") reduce 42) (("+") reduce 42) (("-") reduce 42) ((".") reduce 42) (("/") reduce 42) (("<") reduce 42) ((">") reduce 42) (("?") reduce 42) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_BOOLEAN_AND) reduce 42) ((T_BOOLEAN_OR) reduce 42) ((T_COALESCE) reduce 42) ((T_DOUBLE_ARROW) reduce 42) ((T_INSTANCEOF) reduce 42) ((T_IS_EQUAL) reduce 42) ((T_IS_GREATER_OR_EQUAL) reduce 42) ((T_IS_IDENTICAL) reduce 42) ((T_IS_NOT_EQUAL) reduce 42) ((T_IS_NOT_IDENTICAL) reduce 42) ((T_IS_SMALLER_OR_EQUAL) reduce 42) ((T_LOGICAL_AND) reduce 42) ((T_LOGICAL_OR) reduce 42) ((T_LOGICAL_XOR) reduce 42) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 42) ((T_OBJECT_OPERATOR) reduce 42) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 42) ((T_POW) reduce 42) ((T_SL) reduce 42) ((T_SPACESHIP) reduce 42) ((T_SR) reduce 42) (("[") reduce 42) (("]") reduce 42) (("^") reduce 42) (("{") reduce 42) (("|") reduce 42)) 11867 ((("%") reduce 39) (("(") reduce 39) (("*") reduce 39) (("+") reduce 39) (("-") reduce 39) ((".") reduce 39) (("/") reduce 39) (("<") reduce 39) ((">") reduce 39) (("?") reduce 39) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_BOOLEAN_AND) reduce 39) ((T_BOOLEAN_OR) reduce 39) ((T_COALESCE) reduce 39) ((T_DOUBLE_ARROW) reduce 39) ((T_INSTANCEOF) reduce 39) ((T_IS_EQUAL) reduce 39) ((T_IS_GREATER_OR_EQUAL) reduce 39) ((T_IS_IDENTICAL) reduce 39) ((T_IS_NOT_EQUAL) reduce 39) ((T_IS_NOT_IDENTICAL) reduce 39) ((T_IS_SMALLER_OR_EQUAL) reduce 39) ((T_LOGICAL_AND) reduce 39) ((T_LOGICAL_OR) reduce 39) ((T_LOGICAL_XOR) reduce 39) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 39) ((T_OBJECT_OPERATOR) reduce 39) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 39) ((T_POW) reduce 39) ((T_SL) reduce 39) ((T_SPACESHIP) reduce 39) ((T_SR) reduce 39) (("[") reduce 39) (("]") reduce 39) (("^") reduce 39) (("{") reduce 39) (("|") reduce 39)) 11868 ((("%") reduce 25) (("(") reduce 25) (("*") reduce 25) (("+") reduce 25) (("-") reduce 25) ((".") reduce 25) (("/") reduce 25) (("<") reduce 25) ((">") reduce 25) (("?") reduce 25) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_BOOLEAN_AND) reduce 25) ((T_BOOLEAN_OR) reduce 25) ((T_COALESCE) reduce 25) ((T_DOUBLE_ARROW) reduce 25) ((T_INSTANCEOF) reduce 25) ((T_IS_EQUAL) reduce 25) ((T_IS_GREATER_OR_EQUAL) reduce 25) ((T_IS_IDENTICAL) reduce 25) ((T_IS_NOT_EQUAL) reduce 25) ((T_IS_NOT_IDENTICAL) reduce 25) ((T_IS_SMALLER_OR_EQUAL) reduce 25) ((T_LOGICAL_AND) reduce 25) ((T_LOGICAL_OR) reduce 25) ((T_LOGICAL_XOR) reduce 25) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 25) ((T_OBJECT_OPERATOR) reduce 25) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 25) ((T_POW) reduce 25) ((T_SL) reduce 25) ((T_SPACESHIP) reduce 25) ((T_SR) reduce 25) (("[") reduce 25) (("]") reduce 25) (("^") reduce 25) (("{") reduce 25) (("|") reduce 25)) 11869 ((("%") reduce 50) (("(") reduce 50) (("*") reduce 50) (("+") reduce 50) (("-") reduce 50) ((".") reduce 50) (("/") reduce 50) (("<") reduce 50) ((">") reduce 50) (("?") reduce 50) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_BOOLEAN_AND) reduce 50) ((T_BOOLEAN_OR) reduce 50) ((T_COALESCE) reduce 50) ((T_DOUBLE_ARROW) reduce 50) ((T_INSTANCEOF) reduce 50) ((T_IS_EQUAL) reduce 50) ((T_IS_GREATER_OR_EQUAL) reduce 50) ((T_IS_IDENTICAL) reduce 50) ((T_IS_NOT_EQUAL) reduce 50) ((T_IS_NOT_IDENTICAL) reduce 50) ((T_IS_SMALLER_OR_EQUAL) reduce 50) ((T_LOGICAL_AND) reduce 50) ((T_LOGICAL_OR) reduce 50) ((T_LOGICAL_XOR) reduce 50) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 50) ((T_OBJECT_OPERATOR) reduce 50) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 50) ((T_POW) reduce 50) ((T_SL) reduce 50) ((T_SPACESHIP) reduce 50) ((T_SR) reduce 50) (("[") reduce 50) (("]") reduce 50) (("^") reduce 50) (("{") reduce 50) (("|") reduce 50)) 11870 ((("%") reduce 66) (("(") reduce 66) (("*") reduce 66) (("+") reduce 66) (("-") reduce 66) ((".") reduce 66) (("/") reduce 66) (("<") reduce 66) ((">") reduce 66) (("?") reduce 66) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_BOOLEAN_AND) reduce 66) ((T_BOOLEAN_OR) reduce 66) ((T_COALESCE) reduce 66) ((T_DOUBLE_ARROW) reduce 66) ((T_INSTANCEOF) reduce 66) ((T_IS_EQUAL) reduce 66) ((T_IS_GREATER_OR_EQUAL) reduce 66) ((T_IS_IDENTICAL) reduce 66) ((T_IS_NOT_EQUAL) reduce 66) ((T_IS_NOT_IDENTICAL) reduce 66) ((T_IS_SMALLER_OR_EQUAL) reduce 66) ((T_LOGICAL_AND) reduce 66) ((T_LOGICAL_OR) reduce 66) ((T_LOGICAL_XOR) reduce 66) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 66) ((T_OBJECT_OPERATOR) reduce 66) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 66) ((T_POW) reduce 66) ((T_SL) reduce 66) ((T_SPACESHIP) reduce 66) ((T_SR) reduce 66) (("[") reduce 66) (("]") reduce 66) (("^") reduce 66) (("{") reduce 66) (("|") reduce 66)) 11871 ((("%") reduce 18) (("(") reduce 18) (("*") reduce 18) (("+") reduce 18) (("-") reduce 18) ((".") reduce 18) (("/") reduce 18) (("<") reduce 18) ((">") reduce 18) (("?") reduce 18) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_BOOLEAN_AND) reduce 18) ((T_BOOLEAN_OR) reduce 18) ((T_COALESCE) reduce 18) ((T_DOUBLE_ARROW) reduce 18) ((T_INSTANCEOF) reduce 18) ((T_IS_EQUAL) reduce 18) ((T_IS_GREATER_OR_EQUAL) reduce 18) ((T_IS_IDENTICAL) reduce 18) ((T_IS_NOT_EQUAL) reduce 18) ((T_IS_NOT_IDENTICAL) reduce 18) ((T_IS_SMALLER_OR_EQUAL) reduce 18) ((T_LOGICAL_AND) reduce 18) ((T_LOGICAL_OR) reduce 18) ((T_LOGICAL_XOR) reduce 18) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 18) ((T_OBJECT_OPERATOR) reduce 18) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 18) ((T_POW) reduce 18) ((T_SL) reduce 18) ((T_SPACESHIP) reduce 18) ((T_SR) reduce 18) (("[") reduce 18) (("]") reduce 18) (("^") reduce 18) (("{") reduce 18) (("|") reduce 18)) 11872 ((("%") reduce 17) (("(") reduce 17) (("*") reduce 17) (("+") reduce 17) (("-") reduce 17) ((".") reduce 17) (("/") reduce 17) (("<") reduce 17) ((">") reduce 17) (("?") reduce 17) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_BOOLEAN_AND) reduce 17) ((T_BOOLEAN_OR) reduce 17) ((T_COALESCE) reduce 17) ((T_DOUBLE_ARROW) reduce 17) ((T_INSTANCEOF) reduce 17) ((T_IS_EQUAL) reduce 17) ((T_IS_GREATER_OR_EQUAL) reduce 17) ((T_IS_IDENTICAL) reduce 17) ((T_IS_NOT_EQUAL) reduce 17) ((T_IS_NOT_IDENTICAL) reduce 17) ((T_IS_SMALLER_OR_EQUAL) reduce 17) ((T_LOGICAL_AND) reduce 17) ((T_LOGICAL_OR) reduce 17) ((T_LOGICAL_XOR) reduce 17) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 17) ((T_OBJECT_OPERATOR) reduce 17) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 17) ((T_POW) reduce 17) ((T_SL) reduce 17) ((T_SPACESHIP) reduce 17) ((T_SR) reduce 17) (("[") reduce 17) (("]") reduce 17) (("^") reduce 17) (("{") reduce 17) (("|") reduce 17)) 11873 ((("%") reduce 15) (("(") reduce 15) (("*") reduce 15) (("+") reduce 15) (("-") reduce 15) ((".") reduce 15) (("/") reduce 15) (("<") reduce 15) ((">") reduce 15) (("?") reduce 15) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_BOOLEAN_AND) reduce 15) ((T_BOOLEAN_OR) reduce 15) ((T_COALESCE) reduce 15) ((T_DOUBLE_ARROW) reduce 15) ((T_INSTANCEOF) reduce 15) ((T_IS_EQUAL) reduce 15) ((T_IS_GREATER_OR_EQUAL) reduce 15) ((T_IS_IDENTICAL) reduce 15) ((T_IS_NOT_EQUAL) reduce 15) ((T_IS_NOT_IDENTICAL) reduce 15) ((T_IS_SMALLER_OR_EQUAL) reduce 15) ((T_LOGICAL_AND) reduce 15) ((T_LOGICAL_OR) reduce 15) ((T_LOGICAL_XOR) reduce 15) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 15) ((T_OBJECT_OPERATOR) reduce 15) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 15) ((T_POW) reduce 15) ((T_SL) reduce 15) ((T_SPACESHIP) reduce 15) ((T_SR) reduce 15) (("[") reduce 15) (("]") reduce 15) (("^") reduce 15) (("{") reduce 15) (("|") reduce 15)) 11874 ((("%") reduce 14) (("(") reduce 14) (("*") reduce 14) (("+") reduce 14) (("-") reduce 14) ((".") reduce 14) (("/") reduce 14) (("<") reduce 14) ((">") reduce 14) (("?") reduce 14) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_BOOLEAN_AND) reduce 14) ((T_BOOLEAN_OR) reduce 14) ((T_COALESCE) reduce 14) ((T_DOUBLE_ARROW) reduce 14) ((T_INSTANCEOF) reduce 14) ((T_IS_EQUAL) reduce 14) ((T_IS_GREATER_OR_EQUAL) reduce 14) ((T_IS_IDENTICAL) reduce 14) ((T_IS_NOT_EQUAL) reduce 14) ((T_IS_NOT_IDENTICAL) reduce 14) ((T_IS_SMALLER_OR_EQUAL) reduce 14) ((T_LOGICAL_AND) reduce 14) ((T_LOGICAL_OR) reduce 14) ((T_LOGICAL_XOR) reduce 14) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 14) ((T_OBJECT_OPERATOR) reduce 14) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 14) ((T_POW) reduce 14) ((T_SL) reduce 14) ((T_SPACESHIP) reduce 14) ((T_SR) reduce 14) (("[") reduce 14) (("]") reduce 14) (("^") reduce 14) (("{") reduce 14) (("|") reduce 14)) 11875 ((("%") reduce 38) (("(") reduce 38) (("*") reduce 38) (("+") reduce 38) (("-") reduce 38) ((".") reduce 38) (("/") reduce 38) (("<") reduce 38) ((">") reduce 38) (("?") reduce 38) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_BOOLEAN_AND) reduce 38) ((T_BOOLEAN_OR) reduce 38) ((T_COALESCE) reduce 38) ((T_DOUBLE_ARROW) reduce 38) ((T_INSTANCEOF) reduce 38) ((T_IS_EQUAL) reduce 38) ((T_IS_GREATER_OR_EQUAL) reduce 38) ((T_IS_IDENTICAL) reduce 38) ((T_IS_NOT_EQUAL) reduce 38) ((T_IS_NOT_IDENTICAL) reduce 38) ((T_IS_SMALLER_OR_EQUAL) reduce 38) ((T_LOGICAL_AND) reduce 38) ((T_LOGICAL_OR) reduce 38) ((T_LOGICAL_XOR) reduce 38) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 38) ((T_OBJECT_OPERATOR) reduce 38) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 38) ((T_POW) reduce 38) ((T_SL) reduce 38) ((T_SPACESHIP) reduce 38) ((T_SR) reduce 38) (("[") reduce 38) (("]") reduce 38) (("^") reduce 38) (("{") reduce 38) (("|") reduce 38)) 11876 ((("%") reduce 26) (("(") reduce 26) (("*") reduce 26) (("+") reduce 26) (("-") reduce 26) ((".") reduce 26) (("/") reduce 26) (("<") reduce 26) ((">") reduce 26) (("?") reduce 26) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_BOOLEAN_AND) reduce 26) ((T_BOOLEAN_OR) reduce 26) ((T_COALESCE) reduce 26) ((T_DOUBLE_ARROW) reduce 26) ((T_INSTANCEOF) reduce 26) ((T_IS_EQUAL) reduce 26) ((T_IS_GREATER_OR_EQUAL) reduce 26) ((T_IS_IDENTICAL) reduce 26) ((T_IS_NOT_EQUAL) reduce 26) ((T_IS_NOT_IDENTICAL) reduce 26) ((T_IS_SMALLER_OR_EQUAL) reduce 26) ((T_LOGICAL_AND) reduce 26) ((T_LOGICAL_OR) reduce 26) ((T_LOGICAL_XOR) reduce 26) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 26) ((T_OBJECT_OPERATOR) reduce 26) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 26) ((T_POW) reduce 26) ((T_SL) reduce 26) ((T_SPACESHIP) reduce 26) ((T_SR) reduce 26) (("[") reduce 26) (("]") reduce 26) (("^") reduce 26) (("{") reduce 26) (("|") reduce 26)) 11877 ((("%") reduce 22) (("(") reduce 22) (("*") reduce 22) (("+") reduce 22) (("-") reduce 22) ((".") reduce 22) (("/") reduce 22) (("<") reduce 22) ((">") reduce 22) (("?") reduce 22) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_BOOLEAN_AND) reduce 22) ((T_BOOLEAN_OR) reduce 22) ((T_COALESCE) reduce 22) ((T_DOUBLE_ARROW) reduce 22) ((T_INSTANCEOF) reduce 22) ((T_IS_EQUAL) reduce 22) ((T_IS_GREATER_OR_EQUAL) reduce 22) ((T_IS_IDENTICAL) reduce 22) ((T_IS_NOT_EQUAL) reduce 22) ((T_IS_NOT_IDENTICAL) reduce 22) ((T_IS_SMALLER_OR_EQUAL) reduce 22) ((T_LOGICAL_AND) reduce 22) ((T_LOGICAL_OR) reduce 22) ((T_LOGICAL_XOR) reduce 22) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 22) ((T_OBJECT_OPERATOR) reduce 22) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 22) ((T_POW) reduce 22) ((T_SL) reduce 22) ((T_SPACESHIP) reduce 22) ((T_SR) reduce 22) (("[") reduce 22) (("]") reduce 22) (("^") reduce 22) (("{") reduce 22) (("|") reduce 22)) 11878 ((("%") reduce 24) (("(") reduce 24) (("*") reduce 24) (("+") reduce 24) (("-") reduce 24) ((".") reduce 24) (("/") reduce 24) (("<") reduce 24) ((">") reduce 24) (("?") reduce 24) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_BOOLEAN_AND) reduce 24) ((T_BOOLEAN_OR) reduce 24) ((T_COALESCE) reduce 24) ((T_DOUBLE_ARROW) reduce 24) ((T_INSTANCEOF) reduce 24) ((T_IS_EQUAL) reduce 24) ((T_IS_GREATER_OR_EQUAL) reduce 24) ((T_IS_IDENTICAL) reduce 24) ((T_IS_NOT_EQUAL) reduce 24) ((T_IS_NOT_IDENTICAL) reduce 24) ((T_IS_SMALLER_OR_EQUAL) reduce 24) ((T_LOGICAL_AND) reduce 24) ((T_LOGICAL_OR) reduce 24) ((T_LOGICAL_XOR) reduce 24) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 24) ((T_OBJECT_OPERATOR) reduce 24) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 24) ((T_POW) reduce 24) ((T_SL) reduce 24) ((T_SPACESHIP) reduce 24) ((T_SR) reduce 24) (("[") reduce 24) (("]") reduce 24) (("^") reduce 24) (("{") reduce 24) (("|") reduce 24)) 11879 ((("%") reduce 16) (("(") reduce 16) (("*") reduce 16) (("+") reduce 16) (("-") reduce 16) ((".") reduce 16) (("/") reduce 16) (("<") reduce 16) ((">") reduce 16) (("?") reduce 16) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_BOOLEAN_AND) reduce 16) ((T_BOOLEAN_OR) reduce 16) ((T_COALESCE) reduce 16) ((T_DOUBLE_ARROW) reduce 16) ((T_INSTANCEOF) reduce 16) ((T_IS_EQUAL) reduce 16) ((T_IS_GREATER_OR_EQUAL) reduce 16) ((T_IS_IDENTICAL) reduce 16) ((T_IS_NOT_EQUAL) reduce 16) ((T_IS_NOT_IDENTICAL) reduce 16) ((T_IS_SMALLER_OR_EQUAL) reduce 16) ((T_LOGICAL_AND) reduce 16) ((T_LOGICAL_OR) reduce 16) ((T_LOGICAL_XOR) reduce 16) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 16) ((T_OBJECT_OPERATOR) reduce 16) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 16) ((T_POW) reduce 16) ((T_SL) reduce 16) ((T_SPACESHIP) reduce 16) ((T_SR) reduce 16) (("[") reduce 16) (("]") reduce 16) (("^") reduce 16) (("{") reduce 16) (("|") reduce 16)) 11880 ((("%") reduce 48) (("(") reduce 48) (("*") reduce 48) (("+") reduce 48) (("-") reduce 48) ((".") reduce 48) (("/") reduce 48) (("<") reduce 48) ((">") reduce 48) (("?") reduce 48) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_BOOLEAN_AND) reduce 48) ((T_BOOLEAN_OR) reduce 48) ((T_COALESCE) reduce 48) ((T_DOUBLE_ARROW) reduce 48) ((T_INSTANCEOF) reduce 48) ((T_IS_EQUAL) reduce 48) ((T_IS_GREATER_OR_EQUAL) reduce 48) ((T_IS_IDENTICAL) reduce 48) ((T_IS_NOT_EQUAL) reduce 48) ((T_IS_NOT_IDENTICAL) reduce 48) ((T_IS_SMALLER_OR_EQUAL) reduce 48) ((T_LOGICAL_AND) reduce 48) ((T_LOGICAL_OR) reduce 48) ((T_LOGICAL_XOR) reduce 48) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 48) ((T_OBJECT_OPERATOR) reduce 48) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 48) ((T_POW) reduce 48) ((T_SL) reduce 48) ((T_SPACESHIP) reduce 48) ((T_SR) reduce 48) (("[") reduce 48) (("]") reduce 48) (("^") reduce 48) (("{") reduce 48) (("|") reduce 48)) 11881 ((("%") reduce 20) (("(") reduce 20) (("*") reduce 20) (("+") reduce 20) (("-") reduce 20) ((".") reduce 20) (("/") reduce 20) (("<") reduce 20) ((">") reduce 20) (("?") reduce 20) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_BOOLEAN_AND) reduce 20) ((T_BOOLEAN_OR) reduce 20) ((T_COALESCE) reduce 20) ((T_DOUBLE_ARROW) reduce 20) ((T_INSTANCEOF) reduce 20) ((T_IS_EQUAL) reduce 20) ((T_IS_GREATER_OR_EQUAL) reduce 20) ((T_IS_IDENTICAL) reduce 20) ((T_IS_NOT_EQUAL) reduce 20) ((T_IS_NOT_IDENTICAL) reduce 20) ((T_IS_SMALLER_OR_EQUAL) reduce 20) ((T_LOGICAL_AND) reduce 20) ((T_LOGICAL_OR) reduce 20) ((T_LOGICAL_XOR) reduce 20) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 20) ((T_OBJECT_OPERATOR) reduce 20) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 20) ((T_POW) reduce 20) ((T_SL) reduce 20) ((T_SPACESHIP) reduce 20) ((T_SR) reduce 20) (("[") reduce 20) (("]") reduce 20) (("^") reduce 20) (("{") reduce 20) (("|") reduce 20)) 11882 ((("%") reduce 70) (("(") reduce 70) (("*") reduce 70) (("+") reduce 70) (("-") reduce 70) ((".") reduce 70) (("/") reduce 70) (("<") reduce 70) ((">") reduce 70) (("?") reduce 70) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_BOOLEAN_AND) reduce 70) ((T_BOOLEAN_OR) reduce 70) ((T_COALESCE) reduce 70) ((T_DOUBLE_ARROW) reduce 70) ((T_INSTANCEOF) reduce 70) ((T_IS_EQUAL) reduce 70) ((T_IS_GREATER_OR_EQUAL) reduce 70) ((T_IS_IDENTICAL) reduce 70) ((T_IS_NOT_EQUAL) reduce 70) ((T_IS_NOT_IDENTICAL) reduce 70) ((T_IS_SMALLER_OR_EQUAL) reduce 70) ((T_LOGICAL_AND) reduce 70) ((T_LOGICAL_OR) reduce 70) ((T_LOGICAL_XOR) reduce 70) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 70) ((T_OBJECT_OPERATOR) reduce 70) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 70) ((T_POW) reduce 70) ((T_SL) reduce 70) ((T_SPACESHIP) reduce 70) ((T_SR) reduce 70) (("[") reduce 70) (("]") reduce 70) (("^") reduce 70) (("{") reduce 70) (("|") reduce 70)) 11883 ((("%") reduce 3) (("(") reduce 3) (("*") reduce 3) (("+") reduce 3) (("-") reduce 3) ((".") reduce 3) (("/") reduce 3) (("<") reduce 3) ((">") reduce 3) (("?") reduce 3) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_BOOLEAN_AND) reduce 3) ((T_BOOLEAN_OR) reduce 3) ((T_COALESCE) reduce 3) ((T_DOUBLE_ARROW) reduce 3) ((T_INSTANCEOF) reduce 3) ((T_IS_EQUAL) reduce 3) ((T_IS_GREATER_OR_EQUAL) reduce 3) ((T_IS_IDENTICAL) reduce 3) ((T_IS_NOT_EQUAL) reduce 3) ((T_IS_NOT_IDENTICAL) reduce 3) ((T_IS_SMALLER_OR_EQUAL) reduce 3) ((T_LOGICAL_AND) reduce 3) ((T_LOGICAL_OR) reduce 3) ((T_LOGICAL_XOR) reduce 3) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 3) ((T_OBJECT_OPERATOR) reduce 3) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 3) ((T_POW) reduce 3) ((T_SL) reduce 3) ((T_SPACESHIP) reduce 3) ((T_SR) reduce 3) (("[") reduce 3) (("]") reduce 3) (("^") reduce 3) (("{") reduce 3) (("|") reduce 3)) 11884 ((("%") reduce 12) (("(") reduce 12) (("*") reduce 12) (("+") reduce 12) (("-") reduce 12) ((".") reduce 12) (("/") reduce 12) (("<") reduce 12) ((">") reduce 12) (("?") reduce 12) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_BOOLEAN_AND) reduce 12) ((T_BOOLEAN_OR) reduce 12) ((T_COALESCE) reduce 12) ((T_DOUBLE_ARROW) reduce 12) ((T_INSTANCEOF) reduce 12) ((T_IS_EQUAL) reduce 12) ((T_IS_GREATER_OR_EQUAL) reduce 12) ((T_IS_IDENTICAL) reduce 12) ((T_IS_NOT_EQUAL) reduce 12) ((T_IS_NOT_IDENTICAL) reduce 12) ((T_IS_SMALLER_OR_EQUAL) reduce 12) ((T_LOGICAL_AND) reduce 12) ((T_LOGICAL_OR) reduce 12) ((T_LOGICAL_XOR) reduce 12) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 12) ((T_OBJECT_OPERATOR) reduce 12) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 12) ((T_POW) reduce 12) ((T_SL) reduce 12) ((T_SPACESHIP) reduce 12) ((T_SR) reduce 12) (("[") reduce 12) (("]") reduce 12) (("^") reduce 12) (("{") reduce 12) (("|") reduce 12)) 11885 ((("%") reduce 54) (("(") reduce 54) (("*") reduce 54) (("+") reduce 54) (("-") reduce 54) ((".") reduce 54) (("/") reduce 54) (("<") reduce 54) ((">") reduce 54) (("?") reduce 54) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_BOOLEAN_AND) reduce 54) ((T_BOOLEAN_OR) reduce 54) ((T_COALESCE) reduce 54) ((T_DOUBLE_ARROW) reduce 54) ((T_INSTANCEOF) reduce 54) ((T_IS_EQUAL) reduce 54) ((T_IS_GREATER_OR_EQUAL) reduce 54) ((T_IS_IDENTICAL) reduce 54) ((T_IS_NOT_EQUAL) reduce 54) ((T_IS_NOT_IDENTICAL) reduce 54) ((T_IS_SMALLER_OR_EQUAL) reduce 54) ((T_LOGICAL_AND) reduce 54) ((T_LOGICAL_OR) reduce 54) ((T_LOGICAL_XOR) reduce 54) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 54) ((T_OBJECT_OPERATOR) reduce 54) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 54) ((T_POW) reduce 54) ((T_SL) reduce 54) ((T_SPACESHIP) reduce 54) ((T_SR) reduce 54) (("[") reduce 54) (("]") reduce 54) (("^") reduce 54) (("{") reduce 54) (("|") reduce 54)) 11886 ((("%") reduce 65) (("(") reduce 65) (("*") reduce 65) (("+") reduce 65) (("-") reduce 65) ((".") reduce 65) (("/") reduce 65) (("<") reduce 65) ((">") reduce 65) (("?") reduce 65) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_BOOLEAN_AND) reduce 65) ((T_BOOLEAN_OR) reduce 65) ((T_COALESCE) reduce 65) ((T_DOUBLE_ARROW) reduce 65) ((T_INSTANCEOF) reduce 65) ((T_IS_EQUAL) reduce 65) ((T_IS_GREATER_OR_EQUAL) reduce 65) ((T_IS_IDENTICAL) reduce 65) ((T_IS_NOT_EQUAL) reduce 65) ((T_IS_NOT_IDENTICAL) reduce 65) ((T_IS_SMALLER_OR_EQUAL) reduce 65) ((T_LOGICAL_AND) reduce 65) ((T_LOGICAL_OR) reduce 65) ((T_LOGICAL_XOR) reduce 65) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 65) ((T_OBJECT_OPERATOR) reduce 65) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 65) ((T_POW) reduce 65) ((T_SL) reduce 65) ((T_SPACESHIP) reduce 65) ((T_SR) reduce 65) (("[") reduce 65) (("]") reduce 65) (("^") reduce 65) (("{") reduce 65) (("|") reduce 65)) 11887 ((("%") reduce 74) (("(") reduce 74) (("*") reduce 74) (("+") reduce 74) (("-") reduce 74) ((".") reduce 74) (("/") reduce 74) (("<") reduce 74) ((">") reduce 74) (("?") reduce 74) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_BOOLEAN_AND) reduce 74) ((T_BOOLEAN_OR) reduce 74) ((T_COALESCE) reduce 74) ((T_DOUBLE_ARROW) reduce 74) ((T_INSTANCEOF) reduce 74) ((T_IS_EQUAL) reduce 74) ((T_IS_GREATER_OR_EQUAL) reduce 74) ((T_IS_IDENTICAL) reduce 74) ((T_IS_NOT_EQUAL) reduce 74) ((T_IS_NOT_IDENTICAL) reduce 74) ((T_IS_SMALLER_OR_EQUAL) reduce 74) ((T_LOGICAL_AND) reduce 74) ((T_LOGICAL_OR) reduce 74) ((T_LOGICAL_XOR) reduce 74) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 74) ((T_OBJECT_OPERATOR) reduce 74) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 74) ((T_POW) reduce 74) ((T_SL) reduce 74) ((T_SPACESHIP) reduce 74) ((T_SR) reduce 74) (("[") reduce 74) (("]") reduce 74) (("^") reduce 74) (("{") reduce 74) (("|") reduce 74)) 11888 ((("%") reduce 30) (("(") reduce 30) (("*") reduce 30) (("+") reduce 30) (("-") reduce 30) ((".") reduce 30) (("/") reduce 30) (("<") reduce 30) ((">") reduce 30) (("?") reduce 30) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_BOOLEAN_AND) reduce 30) ((T_BOOLEAN_OR) reduce 30) ((T_COALESCE) reduce 30) ((T_DOUBLE_ARROW) reduce 30) ((T_INSTANCEOF) reduce 30) ((T_IS_EQUAL) reduce 30) ((T_IS_GREATER_OR_EQUAL) reduce 30) ((T_IS_IDENTICAL) reduce 30) ((T_IS_NOT_EQUAL) reduce 30) ((T_IS_NOT_IDENTICAL) reduce 30) ((T_IS_SMALLER_OR_EQUAL) reduce 30) ((T_LOGICAL_AND) reduce 30) ((T_LOGICAL_OR) reduce 30) ((T_LOGICAL_XOR) reduce 30) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 30) ((T_OBJECT_OPERATOR) reduce 30) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 30) ((T_POW) reduce 30) ((T_SL) reduce 30) ((T_SPACESHIP) reduce 30) ((T_SR) reduce 30) (("[") reduce 30) (("]") reduce 30) (("^") reduce 30) (("{") reduce 30) (("|") reduce 30)) 11889 ((("%") reduce 68) (("(") reduce 68) (("*") reduce 68) (("+") reduce 68) (("-") reduce 68) ((".") reduce 68) (("/") reduce 68) (("<") reduce 68) ((">") reduce 68) (("?") reduce 68) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_BOOLEAN_AND) reduce 68) ((T_BOOLEAN_OR) reduce 68) ((T_COALESCE) reduce 68) ((T_DOUBLE_ARROW) reduce 68) ((T_INSTANCEOF) reduce 68) ((T_IS_EQUAL) reduce 68) ((T_IS_GREATER_OR_EQUAL) reduce 68) ((T_IS_IDENTICAL) reduce 68) ((T_IS_NOT_EQUAL) reduce 68) ((T_IS_NOT_IDENTICAL) reduce 68) ((T_IS_SMALLER_OR_EQUAL) reduce 68) ((T_LOGICAL_AND) reduce 68) ((T_LOGICAL_OR) reduce 68) ((T_LOGICAL_XOR) reduce 68) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 68) ((T_OBJECT_OPERATOR) reduce 68) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 68) ((T_POW) reduce 68) ((T_SL) reduce 68) ((T_SPACESHIP) reduce 68) ((T_SR) reduce 68) (("[") reduce 68) (("]") reduce 68) (("^") reduce 68) (("{") reduce 68) (("|") reduce 68)) 11890 ((("%") reduce 21) (("(") reduce 21) (("*") reduce 21) (("+") reduce 21) (("-") reduce 21) ((".") reduce 21) (("/") reduce 21) (("<") reduce 21) ((">") reduce 21) (("?") reduce 21) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_BOOLEAN_AND) reduce 21) ((T_BOOLEAN_OR) reduce 21) ((T_COALESCE) reduce 21) ((T_DOUBLE_ARROW) reduce 21) ((T_INSTANCEOF) reduce 21) ((T_IS_EQUAL) reduce 21) ((T_IS_GREATER_OR_EQUAL) reduce 21) ((T_IS_IDENTICAL) reduce 21) ((T_IS_NOT_EQUAL) reduce 21) ((T_IS_NOT_IDENTICAL) reduce 21) ((T_IS_SMALLER_OR_EQUAL) reduce 21) ((T_LOGICAL_AND) reduce 21) ((T_LOGICAL_OR) reduce 21) ((T_LOGICAL_XOR) reduce 21) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 21) ((T_OBJECT_OPERATOR) reduce 21) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 21) ((T_POW) reduce 21) ((T_SL) reduce 21) ((T_SPACESHIP) reduce 21) ((T_SR) reduce 21) (("[") reduce 21) (("]") reduce 21) (("^") reduce 21) (("{") reduce 21) (("|") reduce 21)) 11891 ((("%") reduce 23) (("(") reduce 23) (("*") reduce 23) (("+") reduce 23) (("-") reduce 23) ((".") reduce 23) (("/") reduce 23) (("<") reduce 23) ((">") reduce 23) (("?") reduce 23) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_BOOLEAN_AND) reduce 23) ((T_BOOLEAN_OR) reduce 23) ((T_COALESCE) reduce 23) ((T_DOUBLE_ARROW) reduce 23) ((T_INSTANCEOF) reduce 23) ((T_IS_EQUAL) reduce 23) ((T_IS_GREATER_OR_EQUAL) reduce 23) ((T_IS_IDENTICAL) reduce 23) ((T_IS_NOT_EQUAL) reduce 23) ((T_IS_NOT_IDENTICAL) reduce 23) ((T_IS_SMALLER_OR_EQUAL) reduce 23) ((T_LOGICAL_AND) reduce 23) ((T_LOGICAL_OR) reduce 23) ((T_LOGICAL_XOR) reduce 23) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 23) ((T_OBJECT_OPERATOR) reduce 23) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 23) ((T_POW) reduce 23) ((T_SL) reduce 23) ((T_SPACESHIP) reduce 23) ((T_SR) reduce 23) (("[") reduce 23) (("]") reduce 23) (("^") reduce 23) (("{") reduce 23) (("|") reduce 23)) 11892 ((("%") reduce 41) (("(") reduce 41) (("*") reduce 41) (("+") reduce 41) (("-") reduce 41) ((".") reduce 41) (("/") reduce 41) (("<") reduce 41) ((">") reduce 41) (("?") reduce 41) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_BOOLEAN_AND) reduce 41) ((T_BOOLEAN_OR) reduce 41) ((T_COALESCE) reduce 41) ((T_DOUBLE_ARROW) reduce 41) ((T_INSTANCEOF) reduce 41) ((T_IS_EQUAL) reduce 41) ((T_IS_GREATER_OR_EQUAL) reduce 41) ((T_IS_IDENTICAL) reduce 41) ((T_IS_NOT_EQUAL) reduce 41) ((T_IS_NOT_IDENTICAL) reduce 41) ((T_IS_SMALLER_OR_EQUAL) reduce 41) ((T_LOGICAL_AND) reduce 41) ((T_LOGICAL_OR) reduce 41) ((T_LOGICAL_XOR) reduce 41) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 41) ((T_OBJECT_OPERATOR) reduce 41) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 41) ((T_POW) reduce 41) ((T_SL) reduce 41) ((T_SPACESHIP) reduce 41) ((T_SR) reduce 41) (("[") reduce 41) (("]") reduce 41) (("^") reduce 41) (("{") reduce 41) (("|") reduce 41)) 11893 ((("%") reduce 62) (("(") reduce 62) (("*") reduce 62) (("+") reduce 62) (("-") reduce 62) ((".") reduce 62) (("/") reduce 62) (("<") reduce 62) ((">") reduce 62) (("?") reduce 62) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_BOOLEAN_AND) reduce 62) ((T_BOOLEAN_OR) reduce 62) ((T_COALESCE) reduce 62) ((T_DOUBLE_ARROW) reduce 62) ((T_INSTANCEOF) reduce 62) ((T_IS_EQUAL) reduce 62) ((T_IS_GREATER_OR_EQUAL) reduce 62) ((T_IS_IDENTICAL) reduce 62) ((T_IS_NOT_EQUAL) reduce 62) ((T_IS_NOT_IDENTICAL) reduce 62) ((T_IS_SMALLER_OR_EQUAL) reduce 62) ((T_LOGICAL_AND) reduce 62) ((T_LOGICAL_OR) reduce 62) ((T_LOGICAL_XOR) reduce 62) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 62) ((T_OBJECT_OPERATOR) reduce 62) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 62) ((T_POW) reduce 62) ((T_SL) reduce 62) ((T_SPACESHIP) reduce 62) ((T_SR) reduce 62) (("[") reduce 62) (("]") reduce 62) (("^") reduce 62) (("{") reduce 62) (("|") reduce 62)) 11894 ((("%") reduce 34) (("(") reduce 34) (("*") reduce 34) (("+") reduce 34) (("-") reduce 34) ((".") reduce 34) (("/") reduce 34) (("<") reduce 34) ((">") reduce 34) (("?") reduce 34) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_BOOLEAN_AND) reduce 34) ((T_BOOLEAN_OR) reduce 34) ((T_COALESCE) reduce 34) ((T_DOUBLE_ARROW) reduce 34) ((T_INSTANCEOF) reduce 34) ((T_IS_EQUAL) reduce 34) ((T_IS_GREATER_OR_EQUAL) reduce 34) ((T_IS_IDENTICAL) reduce 34) ((T_IS_NOT_EQUAL) reduce 34) ((T_IS_NOT_IDENTICAL) reduce 34) ((T_IS_SMALLER_OR_EQUAL) reduce 34) ((T_LOGICAL_AND) reduce 34) ((T_LOGICAL_OR) reduce 34) ((T_LOGICAL_XOR) reduce 34) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 34) ((T_OBJECT_OPERATOR) reduce 34) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 34) ((T_POW) reduce 34) ((T_SL) reduce 34) ((T_SPACESHIP) reduce 34) ((T_SR) reduce 34) (("[") reduce 34) (("]") reduce 34) (("^") reduce 34) (("{") reduce 34) (("|") reduce 34)) 11895 ((("%") reduce 40) (("(") reduce 40) (("*") reduce 40) (("+") reduce 40) (("-") reduce 40) ((".") reduce 40) (("/") reduce 40) (("<") reduce 40) ((">") reduce 40) (("?") reduce 40) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_BOOLEAN_AND) reduce 40) ((T_BOOLEAN_OR) reduce 40) ((T_COALESCE) reduce 40) ((T_DOUBLE_ARROW) reduce 40) ((T_INSTANCEOF) reduce 40) ((T_IS_EQUAL) reduce 40) ((T_IS_GREATER_OR_EQUAL) reduce 40) ((T_IS_IDENTICAL) reduce 40) ((T_IS_NOT_EQUAL) reduce 40) ((T_IS_NOT_IDENTICAL) reduce 40) ((T_IS_SMALLER_OR_EQUAL) reduce 40) ((T_LOGICAL_AND) reduce 40) ((T_LOGICAL_OR) reduce 40) ((T_LOGICAL_XOR) reduce 40) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 40) ((T_OBJECT_OPERATOR) reduce 40) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 40) ((T_POW) reduce 40) ((T_SL) reduce 40) ((T_SPACESHIP) reduce 40) ((T_SR) reduce 40) (("[") reduce 40) (("]") reduce 40) (("^") reduce 40) (("{") reduce 40) (("|") reduce 40)) 11896 ((("%") reduce 13) (("(") reduce 13) (("*") reduce 13) (("+") reduce 13) (("-") reduce 13) ((".") reduce 13) (("/") reduce 13) (("<") reduce 13) ((">") reduce 13) (("?") reduce 13) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_BOOLEAN_AND) reduce 13) ((T_BOOLEAN_OR) reduce 13) ((T_COALESCE) reduce 13) ((T_DOUBLE_ARROW) reduce 13) ((T_INSTANCEOF) reduce 13) ((T_IS_EQUAL) reduce 13) ((T_IS_GREATER_OR_EQUAL) reduce 13) ((T_IS_IDENTICAL) reduce 13) ((T_IS_NOT_EQUAL) reduce 13) ((T_IS_NOT_IDENTICAL) reduce 13) ((T_IS_SMALLER_OR_EQUAL) reduce 13) ((T_LOGICAL_AND) reduce 13) ((T_LOGICAL_OR) reduce 13) ((T_LOGICAL_XOR) reduce 13) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 13) ((T_OBJECT_OPERATOR) reduce 13) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 13) ((T_POW) reduce 13) ((T_SL) reduce 13) ((T_SPACESHIP) reduce 13) ((T_SR) reduce 13) (("[") reduce 13) (("]") reduce 13) (("^") reduce 13) (("{") reduce 13) (("|") reduce 13)) 11897 ((("%") reduce 55) (("(") reduce 55) (("*") reduce 55) (("+") reduce 55) (("-") reduce 55) ((".") reduce 55) (("/") reduce 55) (("<") reduce 55) ((">") reduce 55) (("?") reduce 55) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_BOOLEAN_AND) reduce 55) ((T_BOOLEAN_OR) reduce 55) ((T_COALESCE) reduce 55) ((T_DOUBLE_ARROW) reduce 55) ((T_INSTANCEOF) reduce 55) ((T_IS_EQUAL) reduce 55) ((T_IS_GREATER_OR_EQUAL) reduce 55) ((T_IS_IDENTICAL) reduce 55) ((T_IS_NOT_EQUAL) reduce 55) ((T_IS_NOT_IDENTICAL) reduce 55) ((T_IS_SMALLER_OR_EQUAL) reduce 55) ((T_LOGICAL_AND) reduce 55) ((T_LOGICAL_OR) reduce 55) ((T_LOGICAL_XOR) reduce 55) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 55) ((T_OBJECT_OPERATOR) reduce 55) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 55) ((T_POW) reduce 55) ((T_SL) reduce 55) ((T_SPACESHIP) reduce 55) ((T_SR) reduce 55) (("[") reduce 55) (("]") reduce 55) (("^") reduce 55) (("{") reduce 55) (("|") reduce 55)) 11898 ((("%") reduce 1) (("(") reduce 1) (("*") reduce 1) (("+") reduce 1) (("-") reduce 1) ((".") reduce 1) (("/") reduce 1) (("<") reduce 1) ((">") reduce 1) (("?") reduce 1) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_BOOLEAN_AND) reduce 1) ((T_BOOLEAN_OR) reduce 1) ((T_COALESCE) reduce 1) ((T_DOUBLE_ARROW) reduce 1) ((T_INSTANCEOF) reduce 1) ((T_IS_EQUAL) reduce 1) ((T_IS_GREATER_OR_EQUAL) reduce 1) ((T_IS_IDENTICAL) reduce 1) ((T_IS_NOT_EQUAL) reduce 1) ((T_IS_NOT_IDENTICAL) reduce 1) ((T_IS_SMALLER_OR_EQUAL) reduce 1) ((T_LOGICAL_AND) reduce 1) ((T_LOGICAL_OR) reduce 1) ((T_LOGICAL_XOR) reduce 1) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 1) ((T_OBJECT_OPERATOR) reduce 1) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 1) ((T_POW) reduce 1) ((T_SL) reduce 1) ((T_SPACESHIP) reduce 1) ((T_SR) reduce 1) (("[") reduce 1) (("]") reduce 1) (("^") reduce 1) (("{") reduce 1) (("|") reduce 1)) 11899 ((("%") reduce 2) (("(") reduce 2) (("*") reduce 2) (("+") reduce 2) (("-") reduce 2) ((".") reduce 2) (("/") reduce 2) (("<") reduce 2) ((">") reduce 2) (("?") reduce 2) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_BOOLEAN_AND) reduce 2) ((T_BOOLEAN_OR) reduce 2) ((T_COALESCE) reduce 2) ((T_DOUBLE_ARROW) reduce 2) ((T_INSTANCEOF) reduce 2) ((T_IS_EQUAL) reduce 2) ((T_IS_GREATER_OR_EQUAL) reduce 2) ((T_IS_IDENTICAL) reduce 2) ((T_IS_NOT_EQUAL) reduce 2) ((T_IS_NOT_IDENTICAL) reduce 2) ((T_IS_SMALLER_OR_EQUAL) reduce 2) ((T_LOGICAL_AND) reduce 2) ((T_LOGICAL_OR) reduce 2) ((T_LOGICAL_XOR) reduce 2) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 2) ((T_OBJECT_OPERATOR) reduce 2) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 2) ((T_POW) reduce 2) ((T_SL) reduce 2) ((T_SPACESHIP) reduce 2) ((T_SR) reduce 2) (("[") reduce 2) (("]") reduce 2) (("^") reduce 2) (("{") reduce 2) (("|") reduce 2)) 11900 ((("%") reduce 9) (("(") reduce 9) (("*") reduce 9) (("+") reduce 9) (("-") reduce 9) ((".") reduce 9) (("/") reduce 9) (("<") reduce 9) ((">") reduce 9) (("?") reduce 9) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_BOOLEAN_AND) reduce 9) ((T_BOOLEAN_OR) reduce 9) ((T_COALESCE) reduce 9) ((T_DOUBLE_ARROW) reduce 9) ((T_INSTANCEOF) reduce 9) ((T_IS_EQUAL) reduce 9) ((T_IS_GREATER_OR_EQUAL) reduce 9) ((T_IS_IDENTICAL) reduce 9) ((T_IS_NOT_EQUAL) reduce 9) ((T_IS_NOT_IDENTICAL) reduce 9) ((T_IS_SMALLER_OR_EQUAL) reduce 9) ((T_LOGICAL_AND) reduce 9) ((T_LOGICAL_OR) reduce 9) ((T_LOGICAL_XOR) reduce 9) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 9) ((T_OBJECT_OPERATOR) reduce 9) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 9) ((T_POW) reduce 9) ((T_SL) reduce 9) ((T_SPACESHIP) reduce 9) ((T_SR) reduce 9) (("[") reduce 9) (("]") reduce 9) (("^") reduce 9) (("{") reduce 9) (("|") reduce 9)) 11901 ((("%") reduce 33) (("(") reduce 33) (("*") reduce 33) (("+") reduce 33) (("-") reduce 33) ((".") reduce 33) (("/") reduce 33) (("<") reduce 33) ((">") reduce 33) (("?") reduce 33) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_BOOLEAN_AND) reduce 33) ((T_BOOLEAN_OR) reduce 33) ((T_COALESCE) reduce 33) ((T_DOUBLE_ARROW) reduce 33) ((T_INSTANCEOF) reduce 33) ((T_IS_EQUAL) reduce 33) ((T_IS_GREATER_OR_EQUAL) reduce 33) ((T_IS_IDENTICAL) reduce 33) ((T_IS_NOT_EQUAL) reduce 33) ((T_IS_NOT_IDENTICAL) reduce 33) ((T_IS_SMALLER_OR_EQUAL) reduce 33) ((T_LOGICAL_AND) reduce 33) ((T_LOGICAL_OR) reduce 33) ((T_LOGICAL_XOR) reduce 33) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 33) ((T_OBJECT_OPERATOR) reduce 33) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 33) ((T_POW) reduce 33) ((T_SL) reduce 33) ((T_SPACESHIP) reduce 33) ((T_SR) reduce 33) (("[") reduce 33) (("]") reduce 33) (("^") reduce 33) (("{") reduce 33) (("|") reduce 33)) 11902 ((("%") reduce 58) (("(") reduce 58) (("*") reduce 58) (("+") reduce 58) (("-") reduce 58) ((".") reduce 58) (("/") reduce 58) (("<") reduce 58) ((">") reduce 58) (("?") reduce 58) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_BOOLEAN_AND) reduce 58) ((T_BOOLEAN_OR) reduce 58) ((T_COALESCE) reduce 58) ((T_DOUBLE_ARROW) reduce 58) ((T_INSTANCEOF) reduce 58) ((T_IS_EQUAL) reduce 58) ((T_IS_GREATER_OR_EQUAL) reduce 58) ((T_IS_IDENTICAL) reduce 58) ((T_IS_NOT_EQUAL) reduce 58) ((T_IS_NOT_IDENTICAL) reduce 58) ((T_IS_SMALLER_OR_EQUAL) reduce 58) ((T_LOGICAL_AND) reduce 58) ((T_LOGICAL_OR) reduce 58) ((T_LOGICAL_XOR) reduce 58) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 58) ((T_OBJECT_OPERATOR) reduce 58) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 58) ((T_POW) reduce 58) ((T_SL) reduce 58) ((T_SPACESHIP) reduce 58) ((T_SR) reduce 58) (("[") reduce 58) (("]") reduce 58) (("^") reduce 58) (("{") reduce 58) (("|") reduce 58)) 11903 ((("%") reduce 37) (("(") reduce 37) (("*") reduce 37) (("+") reduce 37) (("-") reduce 37) ((".") reduce 37) (("/") reduce 37) (("<") reduce 37) ((">") reduce 37) (("?") reduce 37) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_BOOLEAN_AND) reduce 37) ((T_BOOLEAN_OR) reduce 37) ((T_COALESCE) reduce 37) ((T_DOUBLE_ARROW) reduce 37) ((T_INSTANCEOF) reduce 37) ((T_IS_EQUAL) reduce 37) ((T_IS_GREATER_OR_EQUAL) reduce 37) ((T_IS_IDENTICAL) reduce 37) ((T_IS_NOT_EQUAL) reduce 37) ((T_IS_NOT_IDENTICAL) reduce 37) ((T_IS_SMALLER_OR_EQUAL) reduce 37) ((T_LOGICAL_AND) reduce 37) ((T_LOGICAL_OR) reduce 37) ((T_LOGICAL_XOR) reduce 37) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 37) ((T_OBJECT_OPERATOR) reduce 37) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 37) ((T_POW) reduce 37) ((T_SL) reduce 37) ((T_SPACESHIP) reduce 37) ((T_SR) reduce 37) (("[") reduce 37) (("]") reduce 37) (("^") reduce 37) (("{") reduce 37) (("|") reduce 37)) 11904 ((("%") reduce 64) (("(") reduce 64) (("*") reduce 64) (("+") reduce 64) (("-") reduce 64) ((".") reduce 64) (("/") reduce 64) (("<") reduce 64) ((">") reduce 64) (("?") reduce 64) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_BOOLEAN_AND) reduce 64) ((T_BOOLEAN_OR) reduce 64) ((T_COALESCE) reduce 64) ((T_DOUBLE_ARROW) reduce 64) ((T_INSTANCEOF) reduce 64) ((T_IS_EQUAL) reduce 64) ((T_IS_GREATER_OR_EQUAL) reduce 64) ((T_IS_IDENTICAL) reduce 64) ((T_IS_NOT_EQUAL) reduce 64) ((T_IS_NOT_IDENTICAL) reduce 64) ((T_IS_SMALLER_OR_EQUAL) reduce 64) ((T_LOGICAL_AND) reduce 64) ((T_LOGICAL_OR) reduce 64) ((T_LOGICAL_XOR) reduce 64) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 64) ((T_OBJECT_OPERATOR) reduce 64) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 64) ((T_POW) reduce 64) ((T_SL) reduce 64) ((T_SPACESHIP) reduce 64) ((T_SR) reduce 64) (("[") reduce 64) (("]") reduce 64) (("^") reduce 64) (("{") reduce 64) (("|") reduce 64)) 11905 ((("%") reduce 46) (("(") reduce 46) (("*") reduce 46) (("+") reduce 46) (("-") reduce 46) ((".") reduce 46) (("/") reduce 46) (("<") reduce 46) ((">") reduce 46) (("?") reduce 46) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_BOOLEAN_AND) reduce 46) ((T_BOOLEAN_OR) reduce 46) ((T_COALESCE) reduce 46) ((T_DOUBLE_ARROW) reduce 46) ((T_INSTANCEOF) reduce 46) ((T_IS_EQUAL) reduce 46) ((T_IS_GREATER_OR_EQUAL) reduce 46) ((T_IS_IDENTICAL) reduce 46) ((T_IS_NOT_EQUAL) reduce 46) ((T_IS_NOT_IDENTICAL) reduce 46) ((T_IS_SMALLER_OR_EQUAL) reduce 46) ((T_LOGICAL_AND) reduce 46) ((T_LOGICAL_OR) reduce 46) ((T_LOGICAL_XOR) reduce 46) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 46) ((T_OBJECT_OPERATOR) reduce 46) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 46) ((T_POW) reduce 46) ((T_SL) reduce 46) ((T_SPACESHIP) reduce 46) ((T_SR) reduce 46) (("[") reduce 46) (("]") reduce 46) (("^") reduce 46) (("{") reduce 46) (("|") reduce 46)) 11906 ((("%") reduce 8) (("(") reduce 8) (("*") reduce 8) (("+") reduce 8) (("-") reduce 8) ((".") reduce 8) (("/") reduce 8) (("<") reduce 8) ((">") reduce 8) (("?") reduce 8) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_BOOLEAN_AND) reduce 8) ((T_BOOLEAN_OR) reduce 8) ((T_COALESCE) reduce 8) ((T_DOUBLE_ARROW) reduce 8) ((T_INSTANCEOF) reduce 8) ((T_IS_EQUAL) reduce 8) ((T_IS_GREATER_OR_EQUAL) reduce 8) ((T_IS_IDENTICAL) reduce 8) ((T_IS_NOT_EQUAL) reduce 8) ((T_IS_NOT_IDENTICAL) reduce 8) ((T_IS_SMALLER_OR_EQUAL) reduce 8) ((T_LOGICAL_AND) reduce 8) ((T_LOGICAL_OR) reduce 8) ((T_LOGICAL_XOR) reduce 8) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 8) ((T_OBJECT_OPERATOR) reduce 8) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 8) ((T_POW) reduce 8) ((T_SL) reduce 8) ((T_SPACESHIP) reduce 8) ((T_SR) reduce 8) (("[") reduce 8) (("]") reduce 8) (("^") reduce 8) (("{") reduce 8) (("|") reduce 8)) 11907 ((("%") reduce 6) (("(") reduce 6) (("*") reduce 6) (("+") reduce 6) (("-") reduce 6) ((".") reduce 6) (("/") reduce 6) (("<") reduce 6) ((">") reduce 6) (("?") reduce 6) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_BOOLEAN_AND) reduce 6) ((T_BOOLEAN_OR) reduce 6) ((T_COALESCE) reduce 6) ((T_DOUBLE_ARROW) reduce 6) ((T_INSTANCEOF) reduce 6) ((T_IS_EQUAL) reduce 6) ((T_IS_GREATER_OR_EQUAL) reduce 6) ((T_IS_IDENTICAL) reduce 6) ((T_IS_NOT_EQUAL) reduce 6) ((T_IS_NOT_IDENTICAL) reduce 6) ((T_IS_SMALLER_OR_EQUAL) reduce 6) ((T_LOGICAL_AND) reduce 6) ((T_LOGICAL_OR) reduce 6) ((T_LOGICAL_XOR) reduce 6) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 6) ((T_OBJECT_OPERATOR) reduce 6) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 6) ((T_POW) reduce 6) ((T_SL) reduce 6) ((T_SPACESHIP) reduce 6) ((T_SR) reduce 6) (("[") reduce 6) (("]") reduce 6) (("^") reduce 6) (("{") reduce 6) (("|") reduce 6)) 11908 ((("%") reduce 7) (("(") reduce 7) (("*") reduce 7) (("+") reduce 7) (("-") reduce 7) ((".") reduce 7) (("/") reduce 7) (("<") reduce 7) ((">") reduce 7) (("?") reduce 7) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_BOOLEAN_AND) reduce 7) ((T_BOOLEAN_OR) reduce 7) ((T_COALESCE) reduce 7) ((T_DOUBLE_ARROW) reduce 7) ((T_INSTANCEOF) reduce 7) ((T_IS_EQUAL) reduce 7) ((T_IS_GREATER_OR_EQUAL) reduce 7) ((T_IS_IDENTICAL) reduce 7) ((T_IS_NOT_EQUAL) reduce 7) ((T_IS_NOT_IDENTICAL) reduce 7) ((T_IS_SMALLER_OR_EQUAL) reduce 7) ((T_LOGICAL_AND) reduce 7) ((T_LOGICAL_OR) reduce 7) ((T_LOGICAL_XOR) reduce 7) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 7) ((T_OBJECT_OPERATOR) reduce 7) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 7) ((T_POW) reduce 7) ((T_SL) reduce 7) ((T_SPACESHIP) reduce 7) ((T_SR) reduce 7) (("[") reduce 7) (("]") reduce 7) (("^") reduce 7) (("{") reduce 7) (("|") reduce 7)) 11909 ((("%") reduce 69) (("(") reduce 69) (("*") reduce 69) (("+") reduce 69) (("-") reduce 69) ((".") reduce 69) (("/") reduce 69) (("<") reduce 69) ((">") reduce 69) (("?") reduce 69) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_BOOLEAN_AND) reduce 69) ((T_BOOLEAN_OR) reduce 69) ((T_COALESCE) reduce 69) ((T_DOUBLE_ARROW) reduce 69) ((T_INSTANCEOF) reduce 69) ((T_IS_EQUAL) reduce 69) ((T_IS_GREATER_OR_EQUAL) reduce 69) ((T_IS_IDENTICAL) reduce 69) ((T_IS_NOT_EQUAL) reduce 69) ((T_IS_NOT_IDENTICAL) reduce 69) ((T_IS_SMALLER_OR_EQUAL) reduce 69) ((T_LOGICAL_AND) reduce 69) ((T_LOGICAL_OR) reduce 69) ((T_LOGICAL_XOR) reduce 69) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 69) ((T_OBJECT_OPERATOR) reduce 69) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 69) ((T_POW) reduce 69) ((T_SL) reduce 69) ((T_SPACESHIP) reduce 69) ((T_SR) reduce 69) (("[") reduce 69) (("]") reduce 69) (("^") reduce 69) (("{") reduce 69) (("|") reduce 69)) 11910 ((("%") reduce 63) (("(") reduce 63) (("*") reduce 63) (("+") reduce 63) (("-") reduce 63) ((".") reduce 63) (("/") reduce 63) (("<") reduce 63) ((">") reduce 63) (("?") reduce 63) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_BOOLEAN_AND) reduce 63) ((T_BOOLEAN_OR) reduce 63) ((T_COALESCE) reduce 63) ((T_DOUBLE_ARROW) reduce 63) ((T_INSTANCEOF) reduce 63) ((T_IS_EQUAL) reduce 63) ((T_IS_GREATER_OR_EQUAL) reduce 63) ((T_IS_IDENTICAL) reduce 63) ((T_IS_NOT_EQUAL) reduce 63) ((T_IS_NOT_IDENTICAL) reduce 63) ((T_IS_SMALLER_OR_EQUAL) reduce 63) ((T_LOGICAL_AND) reduce 63) ((T_LOGICAL_OR) reduce 63) ((T_LOGICAL_XOR) reduce 63) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 63) ((T_OBJECT_OPERATOR) reduce 63) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 63) ((T_POW) reduce 63) ((T_SL) reduce 63) ((T_SPACESHIP) reduce 63) ((T_SR) reduce 63) (("[") reduce 63) (("]") reduce 63) (("^") reduce 63) (("{") reduce 63) (("|") reduce 63)) 11911 ((("%") reduce 56) (("(") reduce 56) (("*") reduce 56) (("+") reduce 56) (("-") reduce 56) ((".") reduce 56) (("/") reduce 56) (("<") reduce 56) ((">") reduce 56) (("?") reduce 56) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_BOOLEAN_AND) reduce 56) ((T_BOOLEAN_OR) reduce 56) ((T_COALESCE) reduce 56) ((T_DOUBLE_ARROW) reduce 56) ((T_INSTANCEOF) reduce 56) ((T_IS_EQUAL) reduce 56) ((T_IS_GREATER_OR_EQUAL) reduce 56) ((T_IS_IDENTICAL) reduce 56) ((T_IS_NOT_EQUAL) reduce 56) ((T_IS_NOT_IDENTICAL) reduce 56) ((T_IS_SMALLER_OR_EQUAL) reduce 56) ((T_LOGICAL_AND) reduce 56) ((T_LOGICAL_OR) reduce 56) ((T_LOGICAL_XOR) reduce 56) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 56) ((T_OBJECT_OPERATOR) reduce 56) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 56) ((T_POW) reduce 56) ((T_SL) reduce 56) ((T_SPACESHIP) reduce 56) ((T_SR) reduce 56) (("[") reduce 56) (("]") reduce 56) (("^") reduce 56) (("{") reduce 56) (("|") reduce 56)) 11912 ((("%") reduce 10) (("(") reduce 10) (("*") reduce 10) (("+") reduce 10) (("-") reduce 10) ((".") reduce 10) (("/") reduce 10) (("<") reduce 10) ((">") reduce 10) (("?") reduce 10) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_BOOLEAN_AND) reduce 10) ((T_BOOLEAN_OR) reduce 10) ((T_COALESCE) reduce 10) ((T_DOUBLE_ARROW) reduce 10) ((T_INSTANCEOF) reduce 10) ((T_IS_EQUAL) reduce 10) ((T_IS_GREATER_OR_EQUAL) reduce 10) ((T_IS_IDENTICAL) reduce 10) ((T_IS_NOT_EQUAL) reduce 10) ((T_IS_NOT_IDENTICAL) reduce 10) ((T_IS_SMALLER_OR_EQUAL) reduce 10) ((T_LOGICAL_AND) reduce 10) ((T_LOGICAL_OR) reduce 10) ((T_LOGICAL_XOR) reduce 10) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 10) ((T_OBJECT_OPERATOR) reduce 10) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 10) ((T_POW) reduce 10) ((T_SL) reduce 10) ((T_SPACESHIP) reduce 10) ((T_SR) reduce 10) (("[") reduce 10) (("]") reduce 10) (("^") reduce 10) (("{") reduce 10) (("|") reduce 10)) 11913 ((("%") reduce 67) (("(") reduce 67) (("*") reduce 67) (("+") reduce 67) (("-") reduce 67) ((".") reduce 67) (("/") reduce 67) (("<") reduce 67) ((">") reduce 67) (("?") reduce 67) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_BOOLEAN_AND) reduce 67) ((T_BOOLEAN_OR) reduce 67) ((T_COALESCE) reduce 67) ((T_DOUBLE_ARROW) reduce 67) ((T_INSTANCEOF) reduce 67) ((T_IS_EQUAL) reduce 67) ((T_IS_GREATER_OR_EQUAL) reduce 67) ((T_IS_IDENTICAL) reduce 67) ((T_IS_NOT_EQUAL) reduce 67) ((T_IS_NOT_IDENTICAL) reduce 67) ((T_IS_SMALLER_OR_EQUAL) reduce 67) ((T_LOGICAL_AND) reduce 67) ((T_LOGICAL_OR) reduce 67) ((T_LOGICAL_XOR) reduce 67) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 67) ((T_OBJECT_OPERATOR) reduce 67) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 67) ((T_POW) reduce 67) ((T_SL) reduce 67) ((T_SPACESHIP) reduce 67) ((T_SR) reduce 67) (("[") reduce 67) (("]") reduce 67) (("^") reduce 67) (("{") reduce 67) (("|") reduce 67)) 11914 ((("%") reduce 44) (("(") reduce 44) (("*") reduce 44) (("+") reduce 44) (("-") reduce 44) ((".") reduce 44) (("/") reduce 44) (("<") reduce 44) ((">") reduce 44) (("?") reduce 44) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_BOOLEAN_AND) reduce 44) ((T_BOOLEAN_OR) reduce 44) ((T_COALESCE) reduce 44) ((T_DOUBLE_ARROW) reduce 44) ((T_INSTANCEOF) reduce 44) ((T_IS_EQUAL) reduce 44) ((T_IS_GREATER_OR_EQUAL) reduce 44) ((T_IS_IDENTICAL) reduce 44) ((T_IS_NOT_EQUAL) reduce 44) ((T_IS_NOT_IDENTICAL) reduce 44) ((T_IS_SMALLER_OR_EQUAL) reduce 44) ((T_LOGICAL_AND) reduce 44) ((T_LOGICAL_OR) reduce 44) ((T_LOGICAL_XOR) reduce 44) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 44) ((T_OBJECT_OPERATOR) reduce 44) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 44) ((T_POW) reduce 44) ((T_SL) reduce 44) ((T_SPACESHIP) reduce 44) ((T_SR) reduce 44) (("[") reduce 44) (("]") reduce 44) (("^") reduce 44) (("{") reduce 44) (("|") reduce 44)) 11915 ((("%") reduce 75) (("(") reduce 75) (("*") reduce 75) (("+") reduce 75) (("-") reduce 75) ((".") reduce 75) (("/") reduce 75) (("<") reduce 75) ((">") reduce 75) (("?") reduce 75) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_BOOLEAN_AND) reduce 75) ((T_BOOLEAN_OR) reduce 75) ((T_COALESCE) reduce 75) ((T_DOUBLE_ARROW) reduce 75) ((T_INSTANCEOF) reduce 75) ((T_IS_EQUAL) reduce 75) ((T_IS_GREATER_OR_EQUAL) reduce 75) ((T_IS_IDENTICAL) reduce 75) ((T_IS_NOT_EQUAL) reduce 75) ((T_IS_NOT_IDENTICAL) reduce 75) ((T_IS_SMALLER_OR_EQUAL) reduce 75) ((T_LOGICAL_AND) reduce 75) ((T_LOGICAL_OR) reduce 75) ((T_LOGICAL_XOR) reduce 75) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 75) ((T_OBJECT_OPERATOR) reduce 75) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 75) ((T_POW) reduce 75) ((T_SL) reduce 75) ((T_SPACESHIP) reduce 75) ((T_SR) reduce 75) (("[") reduce 75) (("]") reduce 75) (("^") reduce 75) (("{") reduce 75) (("|") reduce 75)) 11916 ((("%") reduce 76) (("(") reduce 76) (("*") reduce 76) (("+") reduce 76) (("-") reduce 76) ((".") reduce 76) (("/") reduce 76) (("<") reduce 76) ((">") reduce 76) (("?") reduce 76) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_BOOLEAN_AND) reduce 76) ((T_BOOLEAN_OR) reduce 76) ((T_COALESCE) reduce 76) ((T_DOUBLE_ARROW) reduce 76) ((T_INSTANCEOF) reduce 76) ((T_IS_EQUAL) reduce 76) ((T_IS_GREATER_OR_EQUAL) reduce 76) ((T_IS_IDENTICAL) reduce 76) ((T_IS_NOT_EQUAL) reduce 76) ((T_IS_NOT_IDENTICAL) reduce 76) ((T_IS_SMALLER_OR_EQUAL) reduce 76) ((T_LOGICAL_AND) reduce 76) ((T_LOGICAL_OR) reduce 76) ((T_LOGICAL_XOR) reduce 76) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 76) ((T_OBJECT_OPERATOR) reduce 76) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 76) ((T_POW) reduce 76) ((T_SL) reduce 76) ((T_SPACESHIP) reduce 76) ((T_SR) reduce 76) (("[") reduce 76) (("]") reduce 76) (("^") reduce 76) (("{") reduce 76) (("|") reduce 76)) 11917 ((("%") reduce 77) (("(") reduce 77) (("*") reduce 77) (("+") reduce 77) (("-") reduce 77) ((".") reduce 77) (("/") reduce 77) (("<") reduce 77) ((">") reduce 77) (("?") reduce 77) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_BOOLEAN_AND) reduce 77) ((T_BOOLEAN_OR) reduce 77) ((T_COALESCE) reduce 77) ((T_DOUBLE_ARROW) reduce 77) ((T_INSTANCEOF) reduce 77) ((T_IS_EQUAL) reduce 77) ((T_IS_GREATER_OR_EQUAL) reduce 77) ((T_IS_IDENTICAL) reduce 77) ((T_IS_NOT_EQUAL) reduce 77) ((T_IS_NOT_IDENTICAL) reduce 77) ((T_IS_SMALLER_OR_EQUAL) reduce 77) ((T_LOGICAL_AND) reduce 77) ((T_LOGICAL_OR) reduce 77) ((T_LOGICAL_XOR) reduce 77) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 77) ((T_OBJECT_OPERATOR) reduce 77) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 77) ((T_POW) reduce 77) ((T_SL) reduce 77) ((T_SPACESHIP) reduce 77) ((T_SR) reduce 77) (("[") reduce 77) (("]") reduce 77) (("^") reduce 77) (("{") reduce 77) (("|") reduce 77)) 11918 ((("%") reduce 78) (("(") reduce 78) (("*") reduce 78) (("+") reduce 78) (("-") reduce 78) ((".") reduce 78) (("/") reduce 78) (("<") reduce 78) ((">") reduce 78) (("?") reduce 78) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_BOOLEAN_AND) reduce 78) ((T_BOOLEAN_OR) reduce 78) ((T_COALESCE) reduce 78) ((T_DOUBLE_ARROW) reduce 78) ((T_INSTANCEOF) reduce 78) ((T_IS_EQUAL) reduce 78) ((T_IS_GREATER_OR_EQUAL) reduce 78) ((T_IS_IDENTICAL) reduce 78) ((T_IS_NOT_EQUAL) reduce 78) ((T_IS_NOT_IDENTICAL) reduce 78) ((T_IS_SMALLER_OR_EQUAL) reduce 78) ((T_LOGICAL_AND) reduce 78) ((T_LOGICAL_OR) reduce 78) ((T_LOGICAL_XOR) reduce 78) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 78) ((T_OBJECT_OPERATOR) reduce 78) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 78) ((T_POW) reduce 78) ((T_SL) reduce 78) ((T_SPACESHIP) reduce 78) ((T_SR) reduce 78) (("[") reduce 78) (("]") reduce 78) (("^") reduce 78) (("{") reduce 78) (("|") reduce 78)) 11919 ((("%") reduce 4) (("(") reduce 4) (("*") reduce 4) (("+") reduce 4) (("-") reduce 4) ((".") reduce 4) (("/") reduce 4) (("<") reduce 4) ((">") reduce 4) (("?") reduce 4) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_BOOLEAN_AND) reduce 4) ((T_BOOLEAN_OR) reduce 4) ((T_COALESCE) reduce 4) ((T_DOUBLE_ARROW) reduce 4) ((T_INSTANCEOF) reduce 4) ((T_IS_EQUAL) reduce 4) ((T_IS_GREATER_OR_EQUAL) reduce 4) ((T_IS_IDENTICAL) reduce 4) ((T_IS_NOT_EQUAL) reduce 4) ((T_IS_NOT_IDENTICAL) reduce 4) ((T_IS_SMALLER_OR_EQUAL) reduce 4) ((T_LOGICAL_AND) reduce 4) ((T_LOGICAL_OR) reduce 4) ((T_LOGICAL_XOR) reduce 4) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 4) ((T_OBJECT_OPERATOR) reduce 4) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 4) ((T_POW) reduce 4) ((T_SL) reduce 4) ((T_SPACESHIP) reduce 4) ((T_SR) reduce 4) (("[") reduce 4) (("]") reduce 4) (("^") reduce 4) (("{") reduce 4) (("|") reduce 4)) 11920 ((("%") reduce 5) (("(") reduce 5) (("*") reduce 5) (("+") reduce 5) (("-") reduce 5) ((".") reduce 5) (("/") reduce 5) (("<") reduce 5) ((">") reduce 5) (("?") reduce 5) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_BOOLEAN_AND) reduce 5) ((T_BOOLEAN_OR) reduce 5) ((T_COALESCE) reduce 5) ((T_DOUBLE_ARROW) reduce 5) ((T_INSTANCEOF) reduce 5) ((T_IS_EQUAL) reduce 5) ((T_IS_GREATER_OR_EQUAL) reduce 5) ((T_IS_IDENTICAL) reduce 5) ((T_IS_NOT_EQUAL) reduce 5) ((T_IS_NOT_IDENTICAL) reduce 5) ((T_IS_SMALLER_OR_EQUAL) reduce 5) ((T_LOGICAL_AND) reduce 5) ((T_LOGICAL_OR) reduce 5) ((T_LOGICAL_XOR) reduce 5) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 5) ((T_OBJECT_OPERATOR) reduce 5) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 5) ((T_POW) reduce 5) ((T_SL) reduce 5) ((T_SPACESHIP) reduce 5) ((T_SR) reduce 5) (("[") reduce 5) (("]") reduce 5) (("^") reduce 5) (("{") reduce 5) (("|") reduce 5)) 11921 ((("%") reduce 43) (("(") reduce 43) (("*") reduce 43) (("+") reduce 43) (("-") reduce 43) ((".") reduce 43) (("/") reduce 43) (("<") reduce 43) ((">") reduce 43) (("?") reduce 43) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_BOOLEAN_AND) reduce 43) ((T_BOOLEAN_OR) reduce 43) ((T_COALESCE) reduce 43) ((T_DOUBLE_ARROW) reduce 43) ((T_INSTANCEOF) reduce 43) ((T_IS_EQUAL) reduce 43) ((T_IS_GREATER_OR_EQUAL) reduce 43) ((T_IS_IDENTICAL) reduce 43) ((T_IS_NOT_EQUAL) reduce 43) ((T_IS_NOT_IDENTICAL) reduce 43) ((T_IS_SMALLER_OR_EQUAL) reduce 43) ((T_LOGICAL_AND) reduce 43) ((T_LOGICAL_OR) reduce 43) ((T_LOGICAL_XOR) reduce 43) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 43) ((T_OBJECT_OPERATOR) reduce 43) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 43) ((T_POW) reduce 43) ((T_SL) reduce 43) ((T_SPACESHIP) reduce 43) ((T_SR) reduce 43) (("[") reduce 43) (("]") reduce 43) (("^") reduce 43) (("{") reduce 43) (("|") reduce 43)) 11922 ((("%") reduce 72) (("(") reduce 72) (("*") reduce 72) (("+") reduce 72) (("-") reduce 72) ((".") reduce 72) (("/") reduce 72) (("<") reduce 72) ((">") reduce 72) (("?") reduce 72) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_BOOLEAN_AND) reduce 72) ((T_BOOLEAN_OR) reduce 72) ((T_COALESCE) reduce 72) ((T_DOUBLE_ARROW) reduce 72) ((T_INSTANCEOF) reduce 72) ((T_IS_EQUAL) reduce 72) ((T_IS_GREATER_OR_EQUAL) reduce 72) ((T_IS_IDENTICAL) reduce 72) ((T_IS_NOT_EQUAL) reduce 72) ((T_IS_NOT_IDENTICAL) reduce 72) ((T_IS_SMALLER_OR_EQUAL) reduce 72) ((T_LOGICAL_AND) reduce 72) ((T_LOGICAL_OR) reduce 72) ((T_LOGICAL_XOR) reduce 72) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 72) ((T_OBJECT_OPERATOR) reduce 72) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 72) ((T_POW) reduce 72) ((T_SL) reduce 72) ((T_SPACESHIP) reduce 72) ((T_SR) reduce 72) (("[") reduce 72) (("]") reduce 72) (("^") reduce 72) (("{") reduce 72) (("|") reduce 72)) 11923 ((("%") reduce 81) (("(") reduce 81) (("*") reduce 81) (("+") reduce 81) (("-") reduce 81) ((".") reduce 81) (("/") reduce 81) (("<") reduce 81) ((">") reduce 81) (("?") reduce 81) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_BOOLEAN_AND) reduce 81) ((T_BOOLEAN_OR) reduce 81) ((T_COALESCE) reduce 81) ((T_DOUBLE_ARROW) reduce 81) ((T_INSTANCEOF) reduce 81) ((T_IS_EQUAL) reduce 81) ((T_IS_GREATER_OR_EQUAL) reduce 81) ((T_IS_IDENTICAL) reduce 81) ((T_IS_NOT_EQUAL) reduce 81) ((T_IS_NOT_IDENTICAL) reduce 81) ((T_IS_SMALLER_OR_EQUAL) reduce 81) ((T_LOGICAL_AND) reduce 81) ((T_LOGICAL_OR) reduce 81) ((T_LOGICAL_XOR) reduce 81) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 81) ((T_OBJECT_OPERATOR) reduce 81) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 81) ((T_POW) reduce 81) ((T_SL) reduce 81) ((T_SPACESHIP) reduce 81) ((T_SR) reduce 81) (("[") reduce 81) (("]") reduce 81) (("^") reduce 81) (("{") reduce 81) (("|") reduce 81)) 11924 ((("%") reduce 47) (("(") reduce 47) (("*") reduce 47) (("+") reduce 47) (("-") reduce 47) ((".") reduce 47) (("/") reduce 47) (("<") reduce 47) ((">") reduce 47) (("?") reduce 47) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_BOOLEAN_AND) reduce 47) ((T_BOOLEAN_OR) reduce 47) ((T_COALESCE) reduce 47) ((T_DOUBLE_ARROW) reduce 47) ((T_INSTANCEOF) reduce 47) ((T_IS_EQUAL) reduce 47) ((T_IS_GREATER_OR_EQUAL) reduce 47) ((T_IS_IDENTICAL) reduce 47) ((T_IS_NOT_EQUAL) reduce 47) ((T_IS_NOT_IDENTICAL) reduce 47) ((T_IS_SMALLER_OR_EQUAL) reduce 47) ((T_LOGICAL_AND) reduce 47) ((T_LOGICAL_OR) reduce 47) ((T_LOGICAL_XOR) reduce 47) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 47) ((T_OBJECT_OPERATOR) reduce 47) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 47) ((T_POW) reduce 47) ((T_SL) reduce 47) ((T_SPACESHIP) reduce 47) ((T_SR) reduce 47) (("[") reduce 47) (("]") reduce 47) (("^") reduce 47) (("{") reduce 47) (("|") reduce 47)) 11925 ((("%") reduce 31) (("(") reduce 31) (("*") reduce 31) (("+") reduce 31) (("-") reduce 31) ((".") reduce 31) (("/") reduce 31) (("<") reduce 31) ((">") reduce 31) (("?") reduce 31) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_BOOLEAN_AND) reduce 31) ((T_BOOLEAN_OR) reduce 31) ((T_COALESCE) reduce 31) ((T_DOUBLE_ARROW) reduce 31) ((T_INSTANCEOF) reduce 31) ((T_IS_EQUAL) reduce 31) ((T_IS_GREATER_OR_EQUAL) reduce 31) ((T_IS_IDENTICAL) reduce 31) ((T_IS_NOT_EQUAL) reduce 31) ((T_IS_NOT_IDENTICAL) reduce 31) ((T_IS_SMALLER_OR_EQUAL) reduce 31) ((T_LOGICAL_AND) reduce 31) ((T_LOGICAL_OR) reduce 31) ((T_LOGICAL_XOR) reduce 31) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 31) ((T_OBJECT_OPERATOR) reduce 31) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 31) ((T_POW) reduce 31) ((T_SL) reduce 31) ((T_SPACESHIP) reduce 31) ((T_SR) reduce 31) (("[") reduce 31) (("]") reduce 31) (("^") reduce 31) (("{") reduce 31) (("|") reduce 31)) 11926 ((("%") reduce 57) (("(") reduce 57) (("*") reduce 57) (("+") reduce 57) (("-") reduce 57) ((".") reduce 57) (("/") reduce 57) (("<") reduce 57) ((">") reduce 57) (("?") reduce 57) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_BOOLEAN_AND) reduce 57) ((T_BOOLEAN_OR) reduce 57) ((T_COALESCE) reduce 57) ((T_DOUBLE_ARROW) reduce 57) ((T_INSTANCEOF) reduce 57) ((T_IS_EQUAL) reduce 57) ((T_IS_GREATER_OR_EQUAL) reduce 57) ((T_IS_IDENTICAL) reduce 57) ((T_IS_NOT_EQUAL) reduce 57) ((T_IS_NOT_IDENTICAL) reduce 57) ((T_IS_SMALLER_OR_EQUAL) reduce 57) ((T_LOGICAL_AND) reduce 57) ((T_LOGICAL_OR) reduce 57) ((T_LOGICAL_XOR) reduce 57) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 57) ((T_OBJECT_OPERATOR) reduce 57) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 57) ((T_POW) reduce 57) ((T_SL) reduce 57) ((T_SPACESHIP) reduce 57) ((T_SR) reduce 57) (("[") reduce 57) (("]") reduce 57) (("^") reduce 57) (("{") reduce 57) (("|") reduce 57)) 11927 ((("%") reduce 61) (("(") reduce 61) (("*") reduce 61) (("+") reduce 61) (("-") reduce 61) ((".") reduce 61) (("/") reduce 61) (("<") reduce 61) ((">") reduce 61) (("?") reduce 61) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_BOOLEAN_AND) reduce 61) ((T_BOOLEAN_OR) reduce 61) ((T_COALESCE) reduce 61) ((T_DOUBLE_ARROW) reduce 61) ((T_INSTANCEOF) reduce 61) ((T_IS_EQUAL) reduce 61) ((T_IS_GREATER_OR_EQUAL) reduce 61) ((T_IS_IDENTICAL) reduce 61) ((T_IS_NOT_EQUAL) reduce 61) ((T_IS_NOT_IDENTICAL) reduce 61) ((T_IS_SMALLER_OR_EQUAL) reduce 61) ((T_LOGICAL_AND) reduce 61) ((T_LOGICAL_OR) reduce 61) ((T_LOGICAL_XOR) reduce 61) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 61) ((T_OBJECT_OPERATOR) reduce 61) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 61) ((T_POW) reduce 61) ((T_SL) reduce 61) ((T_SPACESHIP) reduce 61) ((T_SR) reduce 61) (("[") reduce 61) (("]") reduce 61) (("^") reduce 61) (("{") reduce 61) (("|") reduce 61)) 11928 ((("%") reduce 28) (("(") reduce 28) (("*") reduce 28) (("+") reduce 28) (("-") reduce 28) ((".") reduce 28) (("/") reduce 28) (("<") reduce 28) ((">") reduce 28) (("?") reduce 28) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_BOOLEAN_AND) reduce 28) ((T_BOOLEAN_OR) reduce 28) ((T_COALESCE) reduce 28) ((T_DOUBLE_ARROW) reduce 28) ((T_INSTANCEOF) reduce 28) ((T_IS_EQUAL) reduce 28) ((T_IS_GREATER_OR_EQUAL) reduce 28) ((T_IS_IDENTICAL) reduce 28) ((T_IS_NOT_EQUAL) reduce 28) ((T_IS_NOT_IDENTICAL) reduce 28) ((T_IS_SMALLER_OR_EQUAL) reduce 28) ((T_LOGICAL_AND) reduce 28) ((T_LOGICAL_OR) reduce 28) ((T_LOGICAL_XOR) reduce 28) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 28) ((T_OBJECT_OPERATOR) reduce 28) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 28) ((T_POW) reduce 28) ((T_SL) reduce 28) ((T_SPACESHIP) reduce 28) ((T_SR) reduce 28) (("[") reduce 28) (("]") reduce 28) (("^") reduce 28) (("{") reduce 28) (("|") reduce 28)) 11929 ((("%") reduce 36) (("(") reduce 36) (("*") reduce 36) (("+") reduce 36) (("-") reduce 36) ((".") reduce 36) (("/") reduce 36) (("<") reduce 36) ((">") reduce 36) (("?") reduce 36) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_BOOLEAN_AND) reduce 36) ((T_BOOLEAN_OR) reduce 36) ((T_COALESCE) reduce 36) ((T_DOUBLE_ARROW) reduce 36) ((T_INSTANCEOF) reduce 36) ((T_IS_EQUAL) reduce 36) ((T_IS_GREATER_OR_EQUAL) reduce 36) ((T_IS_IDENTICAL) reduce 36) ((T_IS_NOT_EQUAL) reduce 36) ((T_IS_NOT_IDENTICAL) reduce 36) ((T_IS_SMALLER_OR_EQUAL) reduce 36) ((T_LOGICAL_AND) reduce 36) ((T_LOGICAL_OR) reduce 36) ((T_LOGICAL_XOR) reduce 36) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 36) ((T_OBJECT_OPERATOR) reduce 36) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 36) ((T_POW) reduce 36) ((T_SL) reduce 36) ((T_SPACESHIP) reduce 36) ((T_SR) reduce 36) (("[") reduce 36) (("]") reduce 36) (("^") reduce 36) (("{") reduce 36) (("|") reduce 36)) 11930 ((("%") reduce 32) (("(") reduce 32) (("*") reduce 32) (("+") reduce 32) (("-") reduce 32) ((".") reduce 32) (("/") reduce 32) (("<") reduce 32) ((">") reduce 32) (("?") reduce 32) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_BOOLEAN_AND) reduce 32) ((T_BOOLEAN_OR) reduce 32) ((T_COALESCE) reduce 32) ((T_DOUBLE_ARROW) reduce 32) ((T_INSTANCEOF) reduce 32) ((T_IS_EQUAL) reduce 32) ((T_IS_GREATER_OR_EQUAL) reduce 32) ((T_IS_IDENTICAL) reduce 32) ((T_IS_NOT_EQUAL) reduce 32) ((T_IS_NOT_IDENTICAL) reduce 32) ((T_IS_SMALLER_OR_EQUAL) reduce 32) ((T_LOGICAL_AND) reduce 32) ((T_LOGICAL_OR) reduce 32) ((T_LOGICAL_XOR) reduce 32) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 32) ((T_OBJECT_OPERATOR) reduce 32) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 32) ((T_POW) reduce 32) ((T_SL) reduce 32) ((T_SPACESHIP) reduce 32) ((T_SR) reduce 32) (("[") reduce 32) (("]") reduce 32) (("^") reduce 32) (("{") reduce 32) (("|") reduce 32)) 11931 ((("%") reduce 35) (("(") reduce 35) (("*") reduce 35) (("+") reduce 35) (("-") reduce 35) ((".") reduce 35) (("/") reduce 35) (("<") reduce 35) ((">") reduce 35) (("?") reduce 35) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_BOOLEAN_AND) reduce 35) ((T_BOOLEAN_OR) reduce 35) ((T_COALESCE) reduce 35) ((T_DOUBLE_ARROW) reduce 35) ((T_INSTANCEOF) reduce 35) ((T_IS_EQUAL) reduce 35) ((T_IS_GREATER_OR_EQUAL) reduce 35) ((T_IS_IDENTICAL) reduce 35) ((T_IS_NOT_EQUAL) reduce 35) ((T_IS_NOT_IDENTICAL) reduce 35) ((T_IS_SMALLER_OR_EQUAL) reduce 35) ((T_LOGICAL_AND) reduce 35) ((T_LOGICAL_OR) reduce 35) ((T_LOGICAL_XOR) reduce 35) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 35) ((T_OBJECT_OPERATOR) reduce 35) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 35) ((T_POW) reduce 35) ((T_SL) reduce 35) ((T_SPACESHIP) reduce 35) ((T_SR) reduce 35) (("[") reduce 35) (("]") reduce 35) (("^") reduce 35) (("{") reduce 35) (("|") reduce 35)) 11932 ((("%") reduce 19) (("(") reduce 19) (("*") reduce 19) (("+") reduce 19) (("-") reduce 19) ((".") reduce 19) (("/") reduce 19) (("<") reduce 19) ((">") reduce 19) (("?") reduce 19) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_BOOLEAN_AND) reduce 19) ((T_BOOLEAN_OR) reduce 19) ((T_COALESCE) reduce 19) ((T_DOUBLE_ARROW) reduce 19) ((T_INSTANCEOF) reduce 19) ((T_IS_EQUAL) reduce 19) ((T_IS_GREATER_OR_EQUAL) reduce 19) ((T_IS_IDENTICAL) reduce 19) ((T_IS_NOT_EQUAL) reduce 19) ((T_IS_NOT_IDENTICAL) reduce 19) ((T_IS_SMALLER_OR_EQUAL) reduce 19) ((T_LOGICAL_AND) reduce 19) ((T_LOGICAL_OR) reduce 19) ((T_LOGICAL_XOR) reduce 19) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 19) ((T_OBJECT_OPERATOR) reduce 19) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 19) ((T_POW) reduce 19) ((T_SL) reduce 19) ((T_SPACESHIP) reduce 19) ((T_SR) reduce 19) (("[") reduce 19) (("]") reduce 19) (("^") reduce 19) (("{") reduce 19) (("|") reduce 19)) 11933 ((("%") reduce 45) (("(") reduce 45) (("*") reduce 45) (("+") reduce 45) (("-") reduce 45) ((".") reduce 45) (("/") reduce 45) (("<") reduce 45) ((">") reduce 45) (("?") reduce 45) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_BOOLEAN_AND) reduce 45) ((T_BOOLEAN_OR) reduce 45) ((T_COALESCE) reduce 45) ((T_DOUBLE_ARROW) reduce 45) ((T_INSTANCEOF) reduce 45) ((T_IS_EQUAL) reduce 45) ((T_IS_GREATER_OR_EQUAL) reduce 45) ((T_IS_IDENTICAL) reduce 45) ((T_IS_NOT_EQUAL) reduce 45) ((T_IS_NOT_IDENTICAL) reduce 45) ((T_IS_SMALLER_OR_EQUAL) reduce 45) ((T_LOGICAL_AND) reduce 45) ((T_LOGICAL_OR) reduce 45) ((T_LOGICAL_XOR) reduce 45) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 45) ((T_OBJECT_OPERATOR) reduce 45) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 45) ((T_POW) reduce 45) ((T_SL) reduce 45) ((T_SPACESHIP) reduce 45) ((T_SR) reduce 45) (("[") reduce 45) (("]") reduce 45) (("^") reduce 45) (("{") reduce 45) (("|") reduce 45)) 11934 ((("%") reduce 504) (("(") reduce 541) (("*") reduce 504) (("+") reduce 504) (("-") reduce 504) ((".") reduce 504) (("/") reduce 504) (("<") reduce 504) ((">") reduce 504) (("?") reduce 504) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_BOOLEAN_AND) reduce 504) ((T_BOOLEAN_OR) reduce 504) ((T_COALESCE) reduce 504) ((T_DOUBLE_ARROW) reduce 504) ((T_INSTANCEOF) reduce 504) ((T_IS_EQUAL) reduce 504) ((T_IS_GREATER_OR_EQUAL) reduce 504) ((T_IS_IDENTICAL) reduce 504) ((T_IS_NOT_EQUAL) reduce 504) ((T_IS_NOT_IDENTICAL) reduce 504) ((T_IS_SMALLER_OR_EQUAL) reduce 504) ((T_LOGICAL_AND) reduce 504) ((T_LOGICAL_OR) reduce 504) ((T_LOGICAL_XOR) reduce 504) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 504) ((T_OBJECT_OPERATOR) reduce 504) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 504) ((T_POW) reduce 504) ((T_SL) reduce 504) ((T_SPACESHIP) reduce 504) ((T_SR) reduce 504) (("[") reduce 504) (("]") reduce 504) (("^") reduce 504) (("{") reduce 504) (("|") reduce 504)) 11936 ((("%") reduce 71) (("(") reduce 71) (("*") reduce 71) (("+") reduce 71) (("-") reduce 71) ((".") reduce 71) (("/") reduce 71) (("<") reduce 71) ((">") reduce 71) (("?") reduce 71) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_BOOLEAN_AND) reduce 71) ((T_BOOLEAN_OR) reduce 71) ((T_COALESCE) reduce 71) ((T_DOUBLE_ARROW) reduce 71) ((T_INSTANCEOF) reduce 71) ((T_IS_EQUAL) reduce 71) ((T_IS_GREATER_OR_EQUAL) reduce 71) ((T_IS_IDENTICAL) reduce 71) ((T_IS_NOT_EQUAL) reduce 71) ((T_IS_NOT_IDENTICAL) reduce 71) ((T_IS_SMALLER_OR_EQUAL) reduce 71) ((T_LOGICAL_AND) reduce 71) ((T_LOGICAL_OR) reduce 71) ((T_LOGICAL_XOR) reduce 71) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 71) ((T_OBJECT_OPERATOR) reduce 71) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 71) ((T_POW) reduce 71) ((T_SL) reduce 71) ((T_SPACESHIP) reduce 71) ((T_SR) reduce 71) (("[") reduce 71) (("]") reduce 71) (("^") reduce 71) (("{") reduce 71) (("|") reduce 71)) 11937 ((("%") reduce 82) (("(") reduce 82) (("*") reduce 82) (("+") reduce 82) (("-") reduce 82) ((".") reduce 82) (("/") reduce 82) (("<") reduce 82) ((">") reduce 82) (("?") reduce 82) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_BOOLEAN_AND) reduce 82) ((T_BOOLEAN_OR) reduce 82) ((T_COALESCE) reduce 82) ((T_DOUBLE_ARROW) reduce 82) ((T_INSTANCEOF) reduce 82) ((T_IS_EQUAL) reduce 82) ((T_IS_GREATER_OR_EQUAL) reduce 82) ((T_IS_IDENTICAL) reduce 82) ((T_IS_NOT_EQUAL) reduce 82) ((T_IS_NOT_IDENTICAL) reduce 82) ((T_IS_SMALLER_OR_EQUAL) reduce 82) ((T_LOGICAL_AND) reduce 82) ((T_LOGICAL_OR) reduce 82) ((T_LOGICAL_XOR) reduce 82) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 82) ((T_OBJECT_OPERATOR) reduce 82) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 82) ((T_POW) reduce 82) ((T_SL) reduce 82) ((T_SPACESHIP) reduce 82) ((T_SR) reduce 82) (("[") reduce 82) (("]") reduce 82) (("^") reduce 82) (("{") reduce 82) (("|") reduce 82)) 11938 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) (("<") reduce 533) (("=") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AND_EQUAL) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_COALESCE_EQUAL) reduce 533) ((T_CONCAT_EQUAL) reduce 533) ((T_DEC) reduce 533) ((T_DIV_EQUAL) reduce 533) ((T_DOUBLE_ARROW) reduce 533) ((T_INC) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_MINUS_EQUAL) reduce 533) ((T_MOD_EQUAL) reduce 533) ((T_MUL_EQUAL) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_OR_EQUAL) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_PLUS_EQUAL) reduce 533) ((T_POW) reduce 533) ((T_POW_EQUAL) reduce 533) ((T_SL) reduce 533) ((T_SL_EQUAL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) ((T_SR_EQUAL) reduce 533) ((T_XOR_EQUAL) reduce 533) (("[") reduce 533) (("]") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 11941 ((("%") reduce 506) (("(") reduce 542) (("*") reduce 506) (("+") reduce 506) (("-") reduce 506) ((".") reduce 506) (("/") reduce 506) (("<") reduce 506) ((">") reduce 506) (("?") reduce 506) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_BOOLEAN_AND) reduce 506) ((T_BOOLEAN_OR) reduce 506) ((T_COALESCE) reduce 506) ((T_DOUBLE_ARROW) reduce 506) ((T_INSTANCEOF) reduce 506) ((T_IS_EQUAL) reduce 506) ((T_IS_GREATER_OR_EQUAL) reduce 506) ((T_IS_IDENTICAL) reduce 506) ((T_IS_NOT_EQUAL) reduce 506) ((T_IS_NOT_IDENTICAL) reduce 506) ((T_IS_SMALLER_OR_EQUAL) reduce 506) ((T_LOGICAL_AND) reduce 506) ((T_LOGICAL_OR) reduce 506) ((T_LOGICAL_XOR) reduce 506) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 506) ((T_OBJECT_OPERATOR) reduce 506) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 506) ((T_POW) reduce 506) ((T_SL) reduce 506) ((T_SPACESHIP) reduce 506) ((T_SR) reduce 506) (("[") reduce 506) (("]") reduce 506) (("^") reduce 506) (("{") reduce 506) (("|") reduce 506)) 11943 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) (("<") reduce 468) (("=") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AND_EQUAL) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_COALESCE_EQUAL) reduce 468) ((T_CONCAT_EQUAL) reduce 468) ((T_DEC) reduce 468) ((T_DIV_EQUAL) reduce 468) ((T_DOUBLE_ARROW) reduce 468) ((T_INC) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_MINUS_EQUAL) reduce 468) ((T_MOD_EQUAL) reduce 468) ((T_MUL_EQUAL) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_OR_EQUAL) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_PLUS_EQUAL) reduce 468) ((T_POW) reduce 468) ((T_POW_EQUAL) reduce 468) ((T_SL) reduce 468) ((T_SL_EQUAL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) ((T_SR_EQUAL) reduce 468) ((T_XOR_EQUAL) reduce 468) (("[") reduce 468) (("]") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 11944 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) (("=") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AND_EQUAL) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_COALESCE_EQUAL) reduce 288) ((T_CONCAT_EQUAL) reduce 288) ((T_DEC) reduce 288) ((T_DIV_EQUAL) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INC) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_MINUS_EQUAL) reduce 288) ((T_MOD_EQUAL) reduce 288) ((T_MUL_EQUAL) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_OR_EQUAL) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_PLUS_EQUAL) reduce 288) ((T_POW) reduce 288) ((T_POW_EQUAL) reduce 288) ((T_SL) reduce 288) ((T_SL_EQUAL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) ((T_SR_EQUAL) reduce 288) ((T_XOR_EQUAL) reduce 288) (("[") reduce 288) (("]") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 11948 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) (("=") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AND_EQUAL) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_COALESCE_EQUAL) reduce 289) ((T_CONCAT_EQUAL) reduce 289) ((T_DEC) reduce 289) ((T_DIV_EQUAL) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INC) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_MINUS_EQUAL) reduce 289) ((T_MOD_EQUAL) reduce 289) ((T_MUL_EQUAL) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_OR_EQUAL) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_PLUS_EQUAL) reduce 289) ((T_POW) reduce 289) ((T_POW_EQUAL) reduce 289) ((T_SL) reduce 289) ((T_SL_EQUAL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) ((T_SR_EQUAL) reduce 289) ((T_XOR_EQUAL) reduce 289) (("[") reduce 289) (("]") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 11949 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) (("=") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AND_EQUAL) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_COALESCE_EQUAL) reduce 290) ((T_CONCAT_EQUAL) reduce 290) ((T_DEC) reduce 290) ((T_DIV_EQUAL) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INC) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_MINUS_EQUAL) reduce 290) ((T_MOD_EQUAL) reduce 290) ((T_MUL_EQUAL) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_OR_EQUAL) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_PLUS_EQUAL) reduce 290) ((T_POW) reduce 290) ((T_POW_EQUAL) reduce 290) ((T_SL) reduce 290) ((T_SL_EQUAL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) ((T_SR_EQUAL) reduce 290) ((T_XOR_EQUAL) reduce 290) (("[") reduce 290) (("]") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 11954 ((("%") reduce 388) (("*") reduce 388) (("+") reduce 388) (("-") reduce 388) ((".") reduce 388) (("/") reduce 388) (("<") reduce 388) ((">") reduce 388) (("?") reduce 388) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_BOOLEAN_AND) reduce 388) ((T_BOOLEAN_OR) reduce 388) ((T_COALESCE) reduce 388) ((T_DOUBLE_ARROW) reduce 388) ((T_INSTANCEOF) reduce 388) ((T_IS_EQUAL) reduce 388) ((T_IS_GREATER_OR_EQUAL) reduce 388) ((T_IS_IDENTICAL) reduce 388) ((T_IS_NOT_EQUAL) reduce 388) ((T_IS_NOT_IDENTICAL) reduce 388) ((T_IS_SMALLER_OR_EQUAL) reduce 388) ((T_LOGICAL_AND) reduce 388) ((T_LOGICAL_OR) reduce 388) ((T_LOGICAL_XOR) reduce 388) ((T_POW) reduce 388) ((T_SL) reduce 388) ((T_SPACESHIP) reduce 388) ((T_SR) reduce 388) (("]") reduce 388) (("^") reduce 388) (("|") reduce 388)) 11956 ((("%") reduce 386) (("*") reduce 386) (("+") reduce 386) (("-") reduce 386) ((".") reduce 386) (("/") reduce 386) (("<") reduce 386) ((">") reduce 386) (("?") reduce 386) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_BOOLEAN_AND) reduce 386) ((T_BOOLEAN_OR) reduce 386) ((T_COALESCE) reduce 386) ((T_DOUBLE_ARROW) reduce 386) ((T_INSTANCEOF) reduce 386) ((T_IS_EQUAL) reduce 386) ((T_IS_GREATER_OR_EQUAL) reduce 386) ((T_IS_IDENTICAL) reduce 386) ((T_IS_NOT_EQUAL) reduce 386) ((T_IS_NOT_IDENTICAL) reduce 386) ((T_IS_SMALLER_OR_EQUAL) reduce 386) ((T_LOGICAL_AND) reduce 386) ((T_LOGICAL_OR) reduce 386) ((T_LOGICAL_XOR) reduce 386) ((T_POW) reduce 386) ((T_SL) reduce 386) ((T_SPACESHIP) reduce 386) ((T_SR) reduce 386) (("]") reduce 386) (("^") reduce 386) (("|") reduce 386)) 11966 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 382) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 382) ((T_LOGICAL_OR) reduce 382) ((T_LOGICAL_XOR) reduce 382) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 382) (("^") shift) (("|") shift)) 11967 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 384) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 384) ((T_LOGICAL_OR) reduce 384) ((T_LOGICAL_XOR) reduce 384) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 384) (("^") shift) (("|") shift)) 11968 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 383) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 383) ((T_LOGICAL_OR) reduce 383) ((T_LOGICAL_XOR) reduce 383) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 383) (("^") shift) (("|") shift)) 11969 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 376) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 376) ((T_LOGICAL_OR) reduce 376) ((T_LOGICAL_XOR) reduce 376) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 376) (("^") shift) (("|") shift)) 11970 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 373) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 373) ((T_LOGICAL_OR) reduce 373) ((T_LOGICAL_XOR) reduce 373) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 373) (("^") shift) (("|") shift)) 11971 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 381) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 381) ((T_LOGICAL_OR) reduce 381) ((T_LOGICAL_XOR) reduce 381) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 381) (("^") shift) (("|") shift)) 11972 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 375) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 375) ((T_LOGICAL_OR) reduce 375) ((T_LOGICAL_XOR) reduce 375) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 375) (("^") shift) (("|") shift)) 11973 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 379) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 379) ((T_LOGICAL_OR) reduce 379) ((T_LOGICAL_XOR) reduce 379) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 379) (("^") shift) (("|") shift)) 11974 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 374) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 374) ((T_LOGICAL_OR) reduce 374) ((T_LOGICAL_XOR) reduce 374) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 374) (("^") shift) (("|") shift)) 11975 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 377) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 377) ((T_LOGICAL_OR) reduce 377) ((T_LOGICAL_XOR) reduce 377) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 377) (("^") shift) (("|") shift)) 11976 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 378) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 378) ((T_LOGICAL_OR) reduce 378) ((T_LOGICAL_XOR) reduce 378) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 378) (("^") shift) (("|") shift)) 11977 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 385) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 385) ((T_LOGICAL_OR) reduce 385) ((T_LOGICAL_XOR) reduce 385) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 385) (("^") shift) (("|") shift)) 11978 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 380) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 380) ((T_LOGICAL_OR) reduce 380) ((T_LOGICAL_XOR) reduce 380) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 380) (("^") shift) (("|") shift)) 11980 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 370) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 370) ((T_LOGICAL_OR) reduce 370) ((T_LOGICAL_XOR) reduce 370) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 370) (("^") shift) (("|") shift)) 11983 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("]") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 11986 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) (("<") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_DOUBLE_ARROW) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_POW) reduce 525) ((T_SL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) (("[") reduce 525) (("]") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 11988 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) (("<") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_DOUBLE_ARROW) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_POW) reduce 524) ((T_SL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) (("[") reduce 524) (("]") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 11990 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) (("<") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_DOUBLE_ARROW) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_POW) reduce 519) ((T_SL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) (("[") reduce 519) (("]") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 11991 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) (("<") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_DOUBLE_ARROW) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_POW) reduce 526) ((T_SL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) (("[") reduce 526) (("]") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 11992 ((("%") reduce 371) (("*") reduce 371) (("+") reduce 371) (("-") reduce 371) ((".") reduce 371) (("/") reduce 371) (("<") reduce 371) ((">") reduce 371) (("?") reduce 371) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_BOOLEAN_AND) reduce 371) ((T_BOOLEAN_OR) reduce 371) ((T_COALESCE) reduce 371) ((T_DOUBLE_ARROW) reduce 371) ((T_INSTANCEOF) reduce 371) ((T_IS_EQUAL) reduce 371) ((T_IS_GREATER_OR_EQUAL) reduce 371) ((T_IS_IDENTICAL) reduce 371) ((T_IS_NOT_EQUAL) reduce 371) ((T_IS_NOT_IDENTICAL) reduce 371) ((T_IS_SMALLER_OR_EQUAL) reduce 371) ((T_LOGICAL_AND) reduce 371) ((T_LOGICAL_OR) reduce 371) ((T_LOGICAL_XOR) reduce 371) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 371) ((T_SL) reduce 371) ((T_SPACESHIP) reduce 371) ((T_SR) reduce 371) (("[") reduce 510) (("]") reduce 371) (("^") reduce 371) (("{") reduce 510) (("|") reduce 371)) 11996 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) (("<") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_DOUBLE_ARROW) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_POW) reduce 533) ((T_SL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) (("[") reduce 533) (("]") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 11998 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) (("<") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_DOUBLE_ARROW) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_POW) reduce 468) ((T_SL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) (("[") reduce 468) (("]") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 11999 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("[") reduce 288) (("]") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 12003 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("[") reduce 289) (("]") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 12004 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("[") reduce 290) (("]") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 12005 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) (("<") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_DOUBLE_ARROW) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_POW) reduce 465) ((T_SL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) (("[") reduce 465) (("]") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 12008 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) (("<") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_DOUBLE_ARROW) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_POW) reduce 532) ((T_SL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) (("[") reduce 532) (("]") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 12009 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) (("<") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_DOUBLE_ARROW) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_POW) reduce 467) ((T_SL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) (("[") reduce 467) (("]") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 12010 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) (("<") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_DOUBLE_ARROW) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_POW) reduce 469) ((T_SL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) (("[") reduce 469) (("]") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 12016 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) (("<") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_DOUBLE_ARROW) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_POW) reduce 521) ((T_SL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) (("[") reduce 521) (("]") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 12018 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) (("<") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_DOUBLE_ARROW) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_POW) reduce 520) ((T_SL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) (("[") reduce 520) (("]") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 12019 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("]") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 12020 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) (("<") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_DOUBLE_ARROW) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_POW) reduce 527) ((T_SL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) (("[") reduce 527) (("]") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 12021 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("]") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 12024 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("]") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 12025 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) (("<") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_DOUBLE_ARROW) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_POW) reduce 522) ((T_SL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) (("[") reduce 522) (("]") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 12026 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) (("<") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_DOUBLE_ARROW) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_POW) reduce 528) ((T_SL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) (("[") reduce 528) (("]") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 12027 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) (("<") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_DOUBLE_ARROW) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_POW) reduce 523) ((T_SL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) (("[") reduce 523) (("]") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 12028 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) (("<") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_DOUBLE_ARROW) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_POW) reduce 466) ((T_SL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) (("[") reduce 466) (("]") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 12029 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("]") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 12032 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("]") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 12033 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) (("<") reduce 465) (("=") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AND_EQUAL) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_COALESCE_EQUAL) reduce 465) ((T_CONCAT_EQUAL) reduce 465) ((T_DEC) reduce 465) ((T_DIV_EQUAL) reduce 465) ((T_DOUBLE_ARROW) reduce 465) ((T_INC) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_MINUS_EQUAL) reduce 465) ((T_MOD_EQUAL) reduce 465) ((T_MUL_EQUAL) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_OR_EQUAL) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_PLUS_EQUAL) reduce 465) ((T_POW) reduce 465) ((T_POW_EQUAL) reduce 465) ((T_SL) reduce 465) ((T_SL_EQUAL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) ((T_SR_EQUAL) reduce 465) ((T_XOR_EQUAL) reduce 465) (("[") reduce 465) (("]") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 12044 ((("%") reduce 455) (("*") reduce 455) (("+") reduce 455) (("-") reduce 455) ((".") reduce 455) (("/") reduce 455) (("<") reduce 455) ((">") reduce 455) (("?") reduce 455) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_BOOLEAN_AND) reduce 455) ((T_BOOLEAN_OR) reduce 455) ((T_COALESCE) reduce 455) ((T_DOUBLE_ARROW) reduce 455) ((T_INSTANCEOF) reduce 455) ((T_IS_EQUAL) reduce 455) ((T_IS_GREATER_OR_EQUAL) reduce 455) ((T_IS_IDENTICAL) reduce 455) ((T_IS_NOT_EQUAL) reduce 455) ((T_IS_NOT_IDENTICAL) reduce 455) ((T_IS_SMALLER_OR_EQUAL) reduce 455) ((T_LOGICAL_AND) reduce 455) ((T_LOGICAL_OR) reduce 455) ((T_LOGICAL_XOR) reduce 455) ((T_POW) reduce 455) ((T_SL) reduce 455) ((T_SPACESHIP) reduce 455) ((T_SR) reduce 455) (("]") reduce 455) (("^") reduce 455) (("|") reduce 455)) 12045 ((("%") reduce 450) (("*") reduce 450) (("+") reduce 450) (("-") reduce 450) ((".") reduce 450) (("/") reduce 450) (("<") reduce 450) ((">") reduce 450) (("?") reduce 450) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_BOOLEAN_AND) reduce 450) ((T_BOOLEAN_OR) reduce 450) ((T_COALESCE) reduce 450) ((T_DOUBLE_ARROW) reduce 450) ((T_INSTANCEOF) reduce 450) ((T_IS_EQUAL) reduce 450) ((T_IS_GREATER_OR_EQUAL) reduce 450) ((T_IS_IDENTICAL) reduce 450) ((T_IS_NOT_EQUAL) reduce 450) ((T_IS_NOT_IDENTICAL) reduce 450) ((T_IS_SMALLER_OR_EQUAL) reduce 450) ((T_LOGICAL_AND) reduce 450) ((T_LOGICAL_OR) reduce 450) ((T_LOGICAL_XOR) reduce 450) ((T_POW) reduce 450) ((T_SL) reduce 450) ((T_SPACESHIP) reduce 450) ((T_SR) reduce 450) (("]") reduce 450) (("^") reduce 450) (("|") reduce 450)) 12055 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 455) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 455) (("^") shift) (("|") shift)) 12056 ((("%") reduce 451) (("*") reduce 451) (("+") reduce 451) (("-") reduce 451) ((".") reduce 451) (("/") reduce 451) (("<") reduce 451) ((">") reduce 451) (("?") reduce 451) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_BOOLEAN_AND) reduce 451) ((T_BOOLEAN_OR) reduce 451) ((T_COALESCE) reduce 451) ((T_DOUBLE_ARROW) reduce 451) ((T_INSTANCEOF) reduce 451) ((T_IS_EQUAL) reduce 451) ((T_IS_GREATER_OR_EQUAL) reduce 451) ((T_IS_IDENTICAL) reduce 451) ((T_IS_NOT_EQUAL) reduce 451) ((T_IS_NOT_IDENTICAL) reduce 451) ((T_IS_SMALLER_OR_EQUAL) reduce 451) ((T_LOGICAL_AND) reduce 451) ((T_LOGICAL_OR) reduce 451) ((T_LOGICAL_XOR) reduce 451) ((T_POW) reduce 451) ((T_SL) reduce 451) ((T_SPACESHIP) reduce 451) ((T_SR) reduce 451) (("]") reduce 451) (("^") reduce 451) (("|") reduce 451)) 12058 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 442) ((T_LOGICAL_OR) reduce 442) ((T_LOGICAL_XOR) reduce 442) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 442) (("^") shift) (("|") shift)) 12060 ((("%") reduce 503) (("(") reduce 541) (("*") reduce 503) (("+") reduce 503) (("-") reduce 503) ((".") reduce 503) (("/") reduce 503) (("<") reduce 503) ((">") reduce 503) (("?") reduce 503) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_BOOLEAN_AND) reduce 503) ((T_BOOLEAN_OR) reduce 503) ((T_COALESCE) reduce 503) ((T_DOUBLE_ARROW) reduce 503) ((T_INSTANCEOF) reduce 503) ((T_IS_EQUAL) reduce 503) ((T_IS_GREATER_OR_EQUAL) reduce 503) ((T_IS_IDENTICAL) reduce 503) ((T_IS_NOT_EQUAL) reduce 503) ((T_IS_NOT_IDENTICAL) reduce 503) ((T_IS_SMALLER_OR_EQUAL) reduce 503) ((T_LOGICAL_AND) reduce 503) ((T_LOGICAL_OR) reduce 503) ((T_LOGICAL_XOR) reduce 503) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 503) ((T_OBJECT_OPERATOR) reduce 503) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 503) ((T_POW) reduce 503) ((T_SL) reduce 503) ((T_SPACESHIP) reduce 503) ((T_SR) reduce 503) (("[") reduce 503) (("]") reduce 503) (("^") reduce 503) (("{") reduce 503) (("|") reduce 503)) 12062 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) (("<") reduce 532) (("=") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AND_EQUAL) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_COALESCE_EQUAL) reduce 532) ((T_CONCAT_EQUAL) reduce 532) ((T_DEC) reduce 532) ((T_DIV_EQUAL) reduce 532) ((T_DOUBLE_ARROW) reduce 532) ((T_INC) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_MINUS_EQUAL) reduce 532) ((T_MOD_EQUAL) reduce 532) ((T_MUL_EQUAL) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_OR_EQUAL) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_PLUS_EQUAL) reduce 532) ((T_POW) reduce 532) ((T_POW_EQUAL) reduce 532) ((T_SL) reduce 532) ((T_SL_EQUAL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) ((T_SR_EQUAL) reduce 532) ((T_XOR_EQUAL) reduce 532) (("[") reduce 532) (("]") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 12065 ((("%") reduce 505) (("(") reduce 542) (("*") reduce 505) (("+") reduce 505) (("-") reduce 505) ((".") reduce 505) (("/") reduce 505) (("<") reduce 505) ((">") reduce 505) (("?") reduce 505) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_BOOLEAN_AND) reduce 505) ((T_BOOLEAN_OR) reduce 505) ((T_COALESCE) reduce 505) ((T_DOUBLE_ARROW) reduce 505) ((T_INSTANCEOF) reduce 505) ((T_IS_EQUAL) reduce 505) ((T_IS_GREATER_OR_EQUAL) reduce 505) ((T_IS_IDENTICAL) reduce 505) ((T_IS_NOT_EQUAL) reduce 505) ((T_IS_NOT_IDENTICAL) reduce 505) ((T_IS_SMALLER_OR_EQUAL) reduce 505) ((T_LOGICAL_AND) reduce 505) ((T_LOGICAL_OR) reduce 505) ((T_LOGICAL_XOR) reduce 505) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 505) ((T_OBJECT_OPERATOR) reduce 505) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 505) ((T_POW) reduce 505) ((T_SL) reduce 505) ((T_SPACESHIP) reduce 505) ((T_SR) reduce 505) (("[") reduce 505) (("]") reduce 505) (("^") reduce 505) (("{") reduce 505) (("|") reduce 505)) 12066 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) (("<") reduce 467) (("=") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AND_EQUAL) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_COALESCE_EQUAL) reduce 467) ((T_CONCAT_EQUAL) reduce 467) ((T_DEC) reduce 467) ((T_DIV_EQUAL) reduce 467) ((T_DOUBLE_ARROW) reduce 467) ((T_INC) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_MINUS_EQUAL) reduce 467) ((T_MOD_EQUAL) reduce 467) ((T_MUL_EQUAL) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_OR_EQUAL) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_PLUS_EQUAL) reduce 467) ((T_POW) reduce 467) ((T_POW_EQUAL) reduce 467) ((T_SL) reduce 467) ((T_SL_EQUAL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) ((T_SR_EQUAL) reduce 467) ((T_XOR_EQUAL) reduce 467) (("[") reduce 467) (("]") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 12067 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) (("<") reduce 469) (("=") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AND_EQUAL) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_COALESCE_EQUAL) reduce 469) ((T_CONCAT_EQUAL) reduce 469) ((T_DEC) reduce 469) ((T_DIV_EQUAL) reduce 469) ((T_DOUBLE_ARROW) reduce 469) ((T_INC) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_MINUS_EQUAL) reduce 469) ((T_MOD_EQUAL) reduce 469) ((T_MUL_EQUAL) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_OR_EQUAL) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_PLUS_EQUAL) reduce 469) ((T_POW) reduce 469) ((T_POW_EQUAL) reduce 469) ((T_SL) reduce 469) ((T_SL_EQUAL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) ((T_SR_EQUAL) reduce 469) ((T_XOR_EQUAL) reduce 469) (("[") reduce 469) (("]") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 12069 ((("%") reduce 446) (("*") reduce 446) (("+") reduce 446) (("-") reduce 446) ((".") reduce 446) (("/") reduce 446) (("<") reduce 446) ((">") reduce 446) (("?") reduce 446) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_BOOLEAN_AND) reduce 446) ((T_BOOLEAN_OR) reduce 446) ((T_COALESCE) reduce 446) ((T_DOUBLE_ARROW) reduce 446) ((T_INSTANCEOF) reduce 446) ((T_IS_EQUAL) reduce 446) ((T_IS_GREATER_OR_EQUAL) reduce 446) ((T_IS_IDENTICAL) reduce 446) ((T_IS_NOT_EQUAL) reduce 446) ((T_IS_NOT_IDENTICAL) reduce 446) ((T_IS_SMALLER_OR_EQUAL) reduce 446) ((T_LOGICAL_AND) reduce 446) ((T_LOGICAL_OR) reduce 446) ((T_LOGICAL_XOR) reduce 446) ((T_POW) reduce 446) ((T_SL) reduce 446) ((T_SPACESHIP) reduce 446) ((T_SR) reduce 446) (("]") reduce 446) (("^") reduce 446) (("|") reduce 446)) 12070 ((("%") reduce 448) (("*") reduce 448) (("+") reduce 448) (("-") reduce 448) ((".") reduce 448) (("/") reduce 448) (("<") reduce 448) ((">") reduce 448) (("?") reduce 448) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_BOOLEAN_AND) reduce 448) ((T_BOOLEAN_OR) reduce 448) ((T_COALESCE) reduce 448) ((T_DOUBLE_ARROW) reduce 448) ((T_INSTANCEOF) reduce 448) ((T_IS_EQUAL) reduce 448) ((T_IS_GREATER_OR_EQUAL) reduce 448) ((T_IS_IDENTICAL) reduce 448) ((T_IS_NOT_EQUAL) reduce 448) ((T_IS_NOT_IDENTICAL) reduce 448) ((T_IS_SMALLER_OR_EQUAL) reduce 448) ((T_LOGICAL_AND) reduce 448) ((T_LOGICAL_OR) reduce 448) ((T_LOGICAL_XOR) reduce 448) ((T_POW) reduce 448) ((T_SL) reduce 448) ((T_SPACESHIP) reduce 448) ((T_SR) reduce 448) (("]") reduce 448) (("^") reduce 448) (("|") reduce 448)) 12076 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) (("<") reduce 521) (("=") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AND_EQUAL) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_COALESCE_EQUAL) reduce 521) ((T_CONCAT_EQUAL) reduce 521) ((T_DEC) reduce 521) ((T_DIV_EQUAL) reduce 521) ((T_DOUBLE_ARROW) reduce 521) ((T_INC) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_MINUS_EQUAL) reduce 521) ((T_MOD_EQUAL) reduce 521) ((T_MUL_EQUAL) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_OR_EQUAL) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_PLUS_EQUAL) reduce 521) ((T_POW) reduce 521) ((T_POW_EQUAL) reduce 521) ((T_SL) reduce 521) ((T_SL_EQUAL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) ((T_SR_EQUAL) reduce 521) ((T_XOR_EQUAL) reduce 521) (("[") reduce 521) (("]") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 12078 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) (("<") reduce 520) (("=") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AND_EQUAL) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_COALESCE_EQUAL) reduce 520) ((T_CONCAT_EQUAL) reduce 520) ((T_DEC) reduce 520) ((T_DIV_EQUAL) reduce 520) ((T_DOUBLE_ARROW) reduce 520) ((T_INC) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_MINUS_EQUAL) reduce 520) ((T_MOD_EQUAL) reduce 520) ((T_MUL_EQUAL) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_OR_EQUAL) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_PLUS_EQUAL) reduce 520) ((T_POW) reduce 520) ((T_POW_EQUAL) reduce 520) ((T_SL) reduce 520) ((T_SL_EQUAL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) ((T_SR_EQUAL) reduce 520) ((T_XOR_EQUAL) reduce 520) (("[") reduce 520) (("]") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 12079 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) (("=") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AND_EQUAL) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_COALESCE_EQUAL) reduce 544) ((T_CONCAT_EQUAL) reduce 544) ((T_DEC) reduce 544) ((T_DIV_EQUAL) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INC) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_MINUS_EQUAL) reduce 544) ((T_MOD_EQUAL) reduce 544) ((T_MUL_EQUAL) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_OR_EQUAL) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_PLUS_EQUAL) reduce 544) ((T_POW) reduce 544) ((T_POW_EQUAL) reduce 544) ((T_SL) reduce 544) ((T_SL_EQUAL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) ((T_SR_EQUAL) reduce 544) ((T_XOR_EQUAL) reduce 544) (("[") reduce 544) (("]") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 12080 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) (("<") reduce 527) (("=") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AND_EQUAL) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_COALESCE_EQUAL) reduce 527) ((T_CONCAT_EQUAL) reduce 527) ((T_DEC) reduce 527) ((T_DIV_EQUAL) reduce 527) ((T_DOUBLE_ARROW) reduce 527) ((T_INC) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_MINUS_EQUAL) reduce 527) ((T_MOD_EQUAL) reduce 527) ((T_MUL_EQUAL) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_OR_EQUAL) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_PLUS_EQUAL) reduce 527) ((T_POW) reduce 527) ((T_POW_EQUAL) reduce 527) ((T_SL) reduce 527) ((T_SL_EQUAL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) ((T_SR_EQUAL) reduce 527) ((T_XOR_EQUAL) reduce 527) (("[") reduce 527) (("]") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 12081 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) (("=") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AND_EQUAL) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_COALESCE_EQUAL) reduce 546) ((T_CONCAT_EQUAL) reduce 546) ((T_DEC) reduce 546) ((T_DIV_EQUAL) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INC) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_MINUS_EQUAL) reduce 546) ((T_MOD_EQUAL) reduce 546) ((T_MUL_EQUAL) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_OR_EQUAL) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_PLUS_EQUAL) reduce 546) ((T_POW) reduce 546) ((T_POW_EQUAL) reduce 546) ((T_SL) reduce 546) ((T_SL_EQUAL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) ((T_SR_EQUAL) reduce 546) ((T_XOR_EQUAL) reduce 546) (("[") reduce 546) (("]") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 12084 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) (("=") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AND_EQUAL) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_COALESCE_EQUAL) reduce 545) ((T_CONCAT_EQUAL) reduce 545) ((T_DEC) reduce 545) ((T_DIV_EQUAL) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INC) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_MINUS_EQUAL) reduce 545) ((T_MOD_EQUAL) reduce 545) ((T_MUL_EQUAL) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_OR_EQUAL) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_PLUS_EQUAL) reduce 545) ((T_POW) reduce 545) ((T_POW_EQUAL) reduce 545) ((T_SL) reduce 545) ((T_SL_EQUAL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) ((T_SR_EQUAL) reduce 545) ((T_XOR_EQUAL) reduce 545) (("[") reduce 545) (("]") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 12085 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) (("<") reduce 522) (("=") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AND_EQUAL) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_COALESCE_EQUAL) reduce 522) ((T_CONCAT_EQUAL) reduce 522) ((T_DEC) reduce 522) ((T_DIV_EQUAL) reduce 522) ((T_DOUBLE_ARROW) reduce 522) ((T_INC) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_MINUS_EQUAL) reduce 522) ((T_MOD_EQUAL) reduce 522) ((T_MUL_EQUAL) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_OR_EQUAL) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_PLUS_EQUAL) reduce 522) ((T_POW) reduce 522) ((T_POW_EQUAL) reduce 522) ((T_SL) reduce 522) ((T_SL_EQUAL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) ((T_SR_EQUAL) reduce 522) ((T_XOR_EQUAL) reduce 522) (("[") reduce 522) (("]") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 12086 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) (("<") reduce 528) (("=") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AND_EQUAL) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_COALESCE_EQUAL) reduce 528) ((T_CONCAT_EQUAL) reduce 528) ((T_DEC) reduce 528) ((T_DIV_EQUAL) reduce 528) ((T_DOUBLE_ARROW) reduce 528) ((T_INC) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_MINUS_EQUAL) reduce 528) ((T_MOD_EQUAL) reduce 528) ((T_MUL_EQUAL) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_OR_EQUAL) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_PLUS_EQUAL) reduce 528) ((T_POW) reduce 528) ((T_POW_EQUAL) reduce 528) ((T_SL) reduce 528) ((T_SL_EQUAL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) ((T_SR_EQUAL) reduce 528) ((T_XOR_EQUAL) reduce 528) (("[") reduce 528) (("]") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 12087 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) (("<") reduce 523) (("=") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AND_EQUAL) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_COALESCE_EQUAL) reduce 523) ((T_CONCAT_EQUAL) reduce 523) ((T_DEC) reduce 523) ((T_DIV_EQUAL) reduce 523) ((T_DOUBLE_ARROW) reduce 523) ((T_INC) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_MINUS_EQUAL) reduce 523) ((T_MOD_EQUAL) reduce 523) ((T_MUL_EQUAL) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_OR_EQUAL) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_PLUS_EQUAL) reduce 523) ((T_POW) reduce 523) ((T_POW_EQUAL) reduce 523) ((T_SL) reduce 523) ((T_SL_EQUAL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) ((T_SR_EQUAL) reduce 523) ((T_XOR_EQUAL) reduce 523) (("[") reduce 523) (("]") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 12089 ((("%") reduce 438) (("*") reduce 438) (("+") reduce 438) (("-") reduce 438) ((".") reduce 438) (("/") reduce 438) (("<") reduce 438) ((">") reduce 438) (("?") reduce 438) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_BOOLEAN_AND) reduce 438) ((T_BOOLEAN_OR) reduce 438) ((T_COALESCE) reduce 438) ((T_DOUBLE_ARROW) reduce 438) ((T_INSTANCEOF) reduce 438) ((T_IS_EQUAL) reduce 438) ((T_IS_GREATER_OR_EQUAL) reduce 438) ((T_IS_IDENTICAL) reduce 438) ((T_IS_NOT_EQUAL) reduce 438) ((T_IS_NOT_IDENTICAL) reduce 438) ((T_IS_SMALLER_OR_EQUAL) reduce 438) ((T_LOGICAL_AND) reduce 438) ((T_LOGICAL_OR) reduce 438) ((T_LOGICAL_XOR) reduce 438) ((T_POW) reduce 438) ((T_SL) reduce 438) ((T_SPACESHIP) reduce 438) ((T_SR) reduce 438) (("]") reduce 438) (("^") reduce 438) (("|") reduce 438)) 12091 ((("%") reduce 483) (("(") reduce 483) (("*") reduce 483) (("+") reduce 483) (("-") reduce 483) ((".") reduce 483) (("/") reduce 483) (("<") reduce 483) (("=") shift) ((">") reduce 483) (("?") reduce 483) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_BOOLEAN_AND) reduce 483) ((T_BOOLEAN_OR) reduce 483) ((T_COALESCE) reduce 483) ((T_DOUBLE_ARROW) reduce 483) ((T_INSTANCEOF) reduce 483) ((T_IS_EQUAL) reduce 483) ((T_IS_GREATER_OR_EQUAL) reduce 483) ((T_IS_IDENTICAL) reduce 483) ((T_IS_NOT_EQUAL) reduce 483) ((T_IS_NOT_IDENTICAL) reduce 483) ((T_IS_SMALLER_OR_EQUAL) reduce 483) ((T_LOGICAL_AND) reduce 483) ((T_LOGICAL_OR) reduce 483) ((T_LOGICAL_XOR) reduce 483) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 483) ((T_OBJECT_OPERATOR) reduce 483) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 483) ((T_POW) reduce 483) ((T_SL) reduce 483) ((T_SPACESHIP) reduce 483) ((T_SR) reduce 483) (("[") reduce 483) (("]") reduce 483) (("^") reduce 483) (("{") reduce 483) (("|") reduce 483)) 12093 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 369) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 369) ((T_LOGICAL_OR) reduce 369) ((T_LOGICAL_XOR) reduce 369) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 369) (("^") shift) (("|") shift)) 12094 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 443) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 443) ((T_LOGICAL_OR) reduce 443) ((T_LOGICAL_XOR) reduce 443) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 443) (("^") shift) (("|") shift)) 12097 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 442) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 442) ((T_LOGICAL_OR) reduce 442) ((T_LOGICAL_XOR) reduce 442) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 442) (("^") shift) (("|") shift)) 12098 ((("%") reduce 434) (("*") reduce 434) (("+") reduce 434) (("-") reduce 434) ((".") reduce 434) (("/") reduce 434) (("<") reduce 434) ((">") reduce 434) (("?") reduce 434) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_BOOLEAN_AND) reduce 434) ((T_BOOLEAN_OR) reduce 434) ((T_COALESCE) reduce 434) ((T_DOUBLE_ARROW) reduce 434) ((T_INSTANCEOF) reduce 434) ((T_IS_EQUAL) reduce 434) ((T_IS_GREATER_OR_EQUAL) reduce 434) ((T_IS_IDENTICAL) reduce 434) ((T_IS_NOT_EQUAL) reduce 434) ((T_IS_NOT_IDENTICAL) reduce 434) ((T_IS_SMALLER_OR_EQUAL) reduce 434) ((T_LOGICAL_AND) reduce 434) ((T_LOGICAL_OR) reduce 434) ((T_LOGICAL_XOR) reduce 434) ((T_POW) shift) ((T_SL) reduce 434) ((T_SPACESHIP) reduce 434) ((T_SR) reduce 434) (("]") reduce 434) (("^") reduce 434) (("|") reduce 434)) 12099 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 444) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 444) (("^") shift) (("|") shift)) 12100 ((("%") reduce 430) (("*") reduce 430) (("+") reduce 430) (("-") reduce 430) ((".") reduce 430) (("/") reduce 430) (("<") reduce 430) ((">") reduce 430) (("?") reduce 430) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_BOOLEAN_AND) reduce 430) ((T_BOOLEAN_OR) reduce 430) ((T_COALESCE) reduce 430) ((T_DOUBLE_ARROW) reduce 430) ((T_INSTANCEOF) reduce 430) ((T_IS_EQUAL) reduce 430) ((T_IS_GREATER_OR_EQUAL) reduce 430) ((T_IS_IDENTICAL) reduce 430) ((T_IS_NOT_EQUAL) reduce 430) ((T_IS_NOT_IDENTICAL) reduce 430) ((T_IS_SMALLER_OR_EQUAL) reduce 430) ((T_LOGICAL_AND) reduce 430) ((T_LOGICAL_OR) reduce 430) ((T_LOGICAL_XOR) reduce 430) ((T_POW) shift) ((T_SL) reduce 430) ((T_SPACESHIP) reduce 430) ((T_SR) reduce 430) (("]") reduce 430) (("^") reduce 430) (("|") reduce 430)) 12101 ((("%") reduce 447) (("*") reduce 447) (("+") reduce 447) (("-") reduce 447) ((".") reduce 447) (("/") reduce 447) (("<") reduce 447) ((">") reduce 447) (("?") reduce 447) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_BOOLEAN_AND) reduce 447) ((T_BOOLEAN_OR) reduce 447) ((T_COALESCE) reduce 447) ((T_DOUBLE_ARROW) reduce 447) ((T_INSTANCEOF) reduce 447) ((T_IS_EQUAL) reduce 447) ((T_IS_GREATER_OR_EQUAL) reduce 447) ((T_IS_IDENTICAL) reduce 447) ((T_IS_NOT_EQUAL) reduce 447) ((T_IS_NOT_IDENTICAL) reduce 447) ((T_IS_SMALLER_OR_EQUAL) reduce 447) ((T_LOGICAL_AND) reduce 447) ((T_LOGICAL_OR) reduce 447) ((T_LOGICAL_XOR) reduce 447) ((T_POW) reduce 447) ((T_SL) reduce 447) ((T_SPACESHIP) reduce 447) ((T_SR) reduce 447) (("]") reduce 447) (("^") reduce 447) (("|") reduce 447)) 12103 ((("%") reduce 489) (("*") reduce 489) (("+") reduce 489) (("-") reduce 489) ((".") reduce 489) (("/") reduce 489) (("<") reduce 489) ((">") reduce 489) (("?") reduce 489) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_BOOLEAN_AND) reduce 489) ((T_BOOLEAN_OR) reduce 489) ((T_COALESCE) reduce 489) ((T_DOUBLE_ARROW) reduce 489) ((T_INSTANCEOF) reduce 489) ((T_IS_EQUAL) reduce 489) ((T_IS_GREATER_OR_EQUAL) reduce 489) ((T_IS_IDENTICAL) reduce 489) ((T_IS_NOT_EQUAL) reduce 489) ((T_IS_NOT_IDENTICAL) reduce 489) ((T_IS_SMALLER_OR_EQUAL) reduce 489) ((T_LOGICAL_AND) reduce 489) ((T_LOGICAL_OR) reduce 489) ((T_LOGICAL_XOR) reduce 489) ((T_POW) reduce 489) ((T_SL) reduce 489) ((T_SPACESHIP) reduce 489) ((T_SR) reduce 489) (("]") reduce 489) (("^") reduce 489) (("|") reduce 489)) 12105 ((("%") reduce 490) (("*") reduce 490) (("+") reduce 490) (("-") reduce 490) ((".") reduce 490) (("/") reduce 490) (("<") reduce 490) ((">") reduce 490) (("?") reduce 490) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_BOOLEAN_AND) reduce 490) ((T_BOOLEAN_OR) reduce 490) ((T_COALESCE) reduce 490) ((T_DOUBLE_ARROW) reduce 490) ((T_INSTANCEOF) reduce 490) ((T_IS_EQUAL) reduce 490) ((T_IS_GREATER_OR_EQUAL) reduce 490) ((T_IS_IDENTICAL) reduce 490) ((T_IS_NOT_EQUAL) reduce 490) ((T_IS_NOT_IDENTICAL) reduce 490) ((T_IS_SMALLER_OR_EQUAL) reduce 490) ((T_LOGICAL_AND) reduce 490) ((T_LOGICAL_OR) reduce 490) ((T_LOGICAL_XOR) reduce 490) ((T_POW) reduce 490) ((T_SL) reduce 490) ((T_SPACESHIP) reduce 490) ((T_SR) reduce 490) (("]") reduce 490) (("^") reduce 490) (("|") reduce 490)) 12106 ((("%") reduce 488) (("*") reduce 488) (("+") reduce 488) (("-") reduce 488) ((".") reduce 488) (("/") reduce 488) (("<") reduce 488) ((">") reduce 488) (("?") reduce 488) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_BOOLEAN_AND) reduce 488) ((T_BOOLEAN_OR) reduce 488) ((T_COALESCE) reduce 488) ((T_DOUBLE_ARROW) reduce 488) ((T_INSTANCEOF) reduce 488) ((T_IS_EQUAL) reduce 488) ((T_IS_GREATER_OR_EQUAL) reduce 488) ((T_IS_IDENTICAL) reduce 488) ((T_IS_NOT_EQUAL) reduce 488) ((T_IS_NOT_IDENTICAL) reduce 488) ((T_IS_SMALLER_OR_EQUAL) reduce 488) ((T_LOGICAL_AND) reduce 488) ((T_LOGICAL_OR) reduce 488) ((T_LOGICAL_XOR) reduce 488) ((T_POW) reduce 488) ((T_SL) reduce 488) ((T_SPACESHIP) reduce 488) ((T_SR) reduce 488) (("]") reduce 488) (("^") reduce 488) (("|") reduce 488)) 12107 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 581) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 581) (("^") shift) (("|") shift)) 12108 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 580) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 580) (("^") shift) (("|") shift)) 12109 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) (("<") reduce 466) (("=") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AND_EQUAL) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_COALESCE_EQUAL) reduce 466) ((T_CONCAT_EQUAL) reduce 466) ((T_DEC) reduce 466) ((T_DIV_EQUAL) reduce 466) ((T_DOUBLE_ARROW) reduce 466) ((T_INC) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_MINUS_EQUAL) reduce 466) ((T_MOD_EQUAL) reduce 466) ((T_MUL_EQUAL) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_OR_EQUAL) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_PLUS_EQUAL) reduce 466) ((T_POW) reduce 466) ((T_POW_EQUAL) reduce 466) ((T_SL) reduce 466) ((T_SL_EQUAL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) ((T_SR_EQUAL) reduce 466) ((T_XOR_EQUAL) reduce 466) (("[") reduce 466) (("]") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 12110 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 439) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 439) ((T_LOGICAL_OR) reduce 439) ((T_LOGICAL_XOR) reduce 439) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 439) (("^") shift) (("|") shift)) 12111 ((("%") reduce 432) (("*") reduce 432) (("+") reduce 432) (("-") reduce 432) ((".") reduce 432) (("/") reduce 432) (("<") reduce 432) ((">") reduce 432) (("?") reduce 432) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_BOOLEAN_AND) reduce 432) ((T_BOOLEAN_OR) reduce 432) ((T_COALESCE) reduce 432) ((T_DOUBLE_ARROW) reduce 432) ((T_INSTANCEOF) reduce 432) ((T_IS_EQUAL) reduce 432) ((T_IS_GREATER_OR_EQUAL) reduce 432) ((T_IS_IDENTICAL) reduce 432) ((T_IS_NOT_EQUAL) reduce 432) ((T_IS_NOT_IDENTICAL) reduce 432) ((T_IS_SMALLER_OR_EQUAL) reduce 432) ((T_LOGICAL_AND) reduce 432) ((T_LOGICAL_OR) reduce 432) ((T_LOGICAL_XOR) reduce 432) ((T_POW) shift) ((T_SL) reduce 432) ((T_SPACESHIP) reduce 432) ((T_SR) reduce 432) (("]") reduce 432) (("^") reduce 432) (("|") reduce 432)) 12113 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("]") reduce 93) (("^") reduce 93) (("|") reduce 93)) 12114 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("]") reduce 92) (("^") reduce 92) (("|") reduce 92)) 12115 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("]") reduce 94) (("^") reduce 94) (("|") reduce 94)) 12116 ((("%") reduce 470) (("(") reduce 470) (("*") reduce 470) (("+") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_DOUBLE_ARROW) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("]") reduce 470) (("^") reduce 470) (("|") reduce 470)) 12117 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("]") reduce 91) (("^") reduce 91) (("|") reduce 91)) 12118 ((("%") reduce 365) (("*") reduce 365) (("+") reduce 365) (("-") reduce 365) ((".") reduce 365) (("/") reduce 365) (("<") reduce 365) ((">") reduce 365) (("?") reduce 365) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_BOOLEAN_AND) reduce 365) ((T_BOOLEAN_OR) reduce 365) ((T_COALESCE) reduce 365) ((T_DOUBLE_ARROW) reduce 365) ((T_INSTANCEOF) reduce 365) ((T_IS_EQUAL) reduce 365) ((T_IS_GREATER_OR_EQUAL) reduce 365) ((T_IS_IDENTICAL) reduce 365) ((T_IS_NOT_EQUAL) reduce 365) ((T_IS_NOT_IDENTICAL) reduce 365) ((T_IS_SMALLER_OR_EQUAL) reduce 365) ((T_LOGICAL_AND) reduce 365) ((T_LOGICAL_OR) reduce 365) ((T_LOGICAL_XOR) reduce 365) ((T_POW) reduce 365) ((T_SL) reduce 365) ((T_SPACESHIP) reduce 365) ((T_SR) reduce 365) (("]") reduce 365) (("^") reduce 365) (("|") reduce 365)) 12121 ((("%") reduce 472) (("(") reduce 472) (("*") reduce 472) (("+") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_DOUBLE_ARROW) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("]") reduce 472) (("^") reduce 472) (("|") reduce 472)) 12122 ((("%") reduce 480) (("(") shift) (("*") reduce 480) (("+") reduce 480) (("-") reduce 480) ((".") reduce 480) (("/") reduce 480) (("<") reduce 480) ((">") reduce 480) (("?") reduce 480) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_BOOLEAN_AND) reduce 480) ((T_BOOLEAN_OR) reduce 480) ((T_COALESCE) reduce 480) ((T_DOUBLE_ARROW) reduce 480) ((T_INSTANCEOF) reduce 480) ((T_IS_EQUAL) reduce 480) ((T_IS_GREATER_OR_EQUAL) reduce 480) ((T_IS_IDENTICAL) reduce 480) ((T_IS_NOT_EQUAL) reduce 480) ((T_IS_NOT_IDENTICAL) reduce 480) ((T_IS_SMALLER_OR_EQUAL) reduce 480) ((T_LOGICAL_AND) reduce 480) ((T_LOGICAL_OR) reduce 480) ((T_LOGICAL_XOR) reduce 480) ((T_POW) reduce 480) ((T_SL) reduce 480) ((T_SPACESHIP) reduce 480) ((T_SR) reduce 480) (("]") reduce 480) (("^") reduce 480) (("|") reduce 480)) 12123 ((("%") reduce 471) (("(") reduce 471) (("*") reduce 471) (("+") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_DOUBLE_ARROW) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("]") reduce 471) (("^") reduce 471) (("|") reduce 471)) 12124 ((("%") reduce 473) (("(") reduce 473) (("*") reduce 473) (("+") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_DOUBLE_ARROW) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("]") reduce 473) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 12125 ((("%") reduce 534) (("(") reduce 534) (("*") reduce 534) (("+") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_DOUBLE_ARROW) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("]") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 12132 ((("%") reduce 536) (("(") reduce 536) (("*") reduce 536) (("+") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_DOUBLE_ARROW) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("]") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 12134 ((("%") reduce 535) (("(") reduce 535) (("*") reduce 535) (("+") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_DOUBLE_ARROW) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("]") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 12135 ((("%") reduce 540) (("(") reduce 540) (("*") reduce 540) (("+") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_DOUBLE_ARROW) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("]") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 12136 ((("%") reduce 537) (("(") reduce 537) (("*") reduce 537) (("+") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_DOUBLE_ARROW) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("]") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 12137 ((("%") reduce 538) (("(") reduce 538) (("*") reduce 538) (("+") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_DOUBLE_ARROW) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("]") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 12139 ((("%") reduce 481) (("*") reduce 481) (("+") reduce 481) (("-") reduce 481) ((".") reduce 481) (("/") reduce 481) (("<") reduce 481) ((">") reduce 481) (("?") reduce 481) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_BOOLEAN_AND) reduce 481) ((T_BOOLEAN_OR) reduce 481) ((T_COALESCE) reduce 481) ((T_DOUBLE_ARROW) reduce 481) ((T_INSTANCEOF) reduce 481) ((T_IS_EQUAL) reduce 481) ((T_IS_GREATER_OR_EQUAL) reduce 481) ((T_IS_IDENTICAL) reduce 481) ((T_IS_NOT_EQUAL) reduce 481) ((T_IS_NOT_IDENTICAL) reduce 481) ((T_IS_SMALLER_OR_EQUAL) reduce 481) ((T_LOGICAL_AND) reduce 481) ((T_LOGICAL_OR) reduce 481) ((T_LOGICAL_XOR) reduce 481) ((T_POW) reduce 481) ((T_SL) reduce 481) ((T_SPACESHIP) reduce 481) ((T_SR) reduce 481) (("]") reduce 481) (("^") reduce 481) (("|") reduce 481)) 12140 ((("%") reduce 364) (("*") reduce 364) (("+") reduce 364) (("-") reduce 364) ((".") reduce 364) (("/") reduce 364) (("<") reduce 364) ((">") reduce 364) (("?") reduce 364) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_BOOLEAN_AND) reduce 364) ((T_BOOLEAN_OR) reduce 364) ((T_COALESCE) reduce 364) ((T_DOUBLE_ARROW) reduce 364) ((T_INSTANCEOF) reduce 364) ((T_IS_EQUAL) reduce 364) ((T_IS_GREATER_OR_EQUAL) reduce 364) ((T_IS_IDENTICAL) reduce 364) ((T_IS_NOT_EQUAL) reduce 364) ((T_IS_NOT_IDENTICAL) reduce 364) ((T_IS_SMALLER_OR_EQUAL) reduce 364) ((T_LOGICAL_AND) reduce 364) ((T_LOGICAL_OR) reduce 364) ((T_LOGICAL_XOR) reduce 364) ((T_POW) reduce 364) ((T_SL) reduce 364) ((T_SPACESHIP) reduce 364) ((T_SR) reduce 364) (("]") reduce 364) (("^") reduce 364) (("|") reduce 364)) 12141 ((("%") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("]") reduce 288) (("^") reduce 288) (("|") reduce 288)) 12145 ((("%") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("]") reduce 289) (("^") reduce 289) (("|") reduce 289)) 12146 ((("%") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("]") reduce 290) (("^") reduce 290) (("|") reduce 290)) 12148 ((("%") reduce 539) (("(") reduce 539) (("*") reduce 539) (("+") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_DOUBLE_ARROW) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("]") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 12149 ((("%") reduce 366) (("*") reduce 366) (("+") reduce 366) (("-") reduce 366) ((".") reduce 366) (("/") reduce 366) (("<") reduce 366) ((">") reduce 366) (("?") reduce 366) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_BOOLEAN_AND) reduce 366) ((T_BOOLEAN_OR) reduce 366) ((T_COALESCE) reduce 366) ((T_DOUBLE_ARROW) reduce 366) ((T_INSTANCEOF) reduce 366) ((T_IS_EQUAL) reduce 366) ((T_IS_GREATER_OR_EQUAL) reduce 366) ((T_IS_IDENTICAL) reduce 366) ((T_IS_NOT_EQUAL) reduce 366) ((T_IS_NOT_IDENTICAL) reduce 366) ((T_IS_SMALLER_OR_EQUAL) reduce 366) ((T_LOGICAL_AND) reduce 366) ((T_LOGICAL_OR) reduce 366) ((T_LOGICAL_XOR) reduce 366) ((T_POW) reduce 366) ((T_SL) reduce 366) ((T_SPACESHIP) reduce 366) ((T_SR) reduce 366) (("]") reduce 366) (("^") reduce 366) (("|") reduce 366)) 12157 ((("%") reduce 363) (("*") reduce 363) (("+") reduce 363) (("-") reduce 363) ((".") reduce 363) (("/") reduce 363) (("<") reduce 363) ((">") reduce 363) (("?") reduce 363) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_BOOLEAN_AND) reduce 363) ((T_BOOLEAN_OR) reduce 363) ((T_COALESCE) reduce 363) ((T_DOUBLE_ARROW) reduce 363) ((T_INSTANCEOF) reduce 363) ((T_IS_EQUAL) reduce 363) ((T_IS_GREATER_OR_EQUAL) reduce 363) ((T_IS_IDENTICAL) reduce 363) ((T_IS_NOT_EQUAL) reduce 363) ((T_IS_NOT_IDENTICAL) reduce 363) ((T_IS_SMALLER_OR_EQUAL) reduce 363) ((T_LOGICAL_AND) reduce 363) ((T_LOGICAL_OR) reduce 363) ((T_LOGICAL_XOR) reduce 363) ((T_POW) reduce 363) ((T_SL) reduce 363) ((T_SPACESHIP) reduce 363) ((T_SR) reduce 363) (("]") reduce 363) (("^") reduce 363) (("|") reduce 363)) 12159 ((("%") reduce 474) (("(") reduce 474) (("*") reduce 474) (("+") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_DOUBLE_ARROW) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("]") reduce 474) (("^") reduce 474) (("|") reduce 474)) 12165 ((("%") reduce 230) (("*") reduce 230) (("+") reduce 230) (("-") reduce 230) ((".") reduce 230) (("/") reduce 230) (("<") reduce 230) ((">") reduce 230) (("?") reduce 230) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_BOOLEAN_AND) reduce 230) ((T_BOOLEAN_OR) reduce 230) ((T_COALESCE) reduce 230) ((T_DOUBLE_ARROW) reduce 230) ((T_INSTANCEOF) reduce 230) ((T_IS_EQUAL) reduce 230) ((T_IS_GREATER_OR_EQUAL) reduce 230) ((T_IS_IDENTICAL) reduce 230) ((T_IS_NOT_EQUAL) reduce 230) ((T_IS_NOT_IDENTICAL) reduce 230) ((T_IS_SMALLER_OR_EQUAL) reduce 230) ((T_LOGICAL_AND) reduce 230) ((T_LOGICAL_OR) reduce 230) ((T_LOGICAL_XOR) reduce 230) ((T_POW) reduce 230) ((T_SL) reduce 230) ((T_SPACESHIP) reduce 230) ((T_SR) reduce 230) (("]") reduce 230) (("^") reduce 230) (("|") reduce 230)) 12170 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 368) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 368) ((T_LOGICAL_OR) reduce 368) ((T_LOGICAL_XOR) reduce 368) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 368) (("^") shift) (("|") shift)) 12174 ((("%") reduce 575) (("*") reduce 575) (("+") reduce 575) (("-") reduce 575) ((".") reduce 575) (("/") reduce 575) (("<") reduce 575) ((">") reduce 575) (("?") reduce 575) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_BOOLEAN_AND) reduce 575) ((T_BOOLEAN_OR) reduce 575) ((T_COALESCE) reduce 575) ((T_DOUBLE_ARROW) reduce 575) ((T_INSTANCEOF) reduce 575) ((T_IS_EQUAL) reduce 575) ((T_IS_GREATER_OR_EQUAL) reduce 575) ((T_IS_IDENTICAL) reduce 575) ((T_IS_NOT_EQUAL) reduce 575) ((T_IS_NOT_IDENTICAL) reduce 575) ((T_IS_SMALLER_OR_EQUAL) reduce 575) ((T_LOGICAL_AND) reduce 575) ((T_LOGICAL_OR) reduce 575) ((T_LOGICAL_XOR) reduce 575) ((T_POW) reduce 575) ((T_SL) reduce 575) ((T_SPACESHIP) reduce 575) ((T_SR) reduce 575) (("]") reduce 575) (("^") reduce 575) (("|") reduce 575)) 12175 ((("%") reduce 428) (("*") reduce 428) (("+") reduce 428) (("-") reduce 428) ((".") reduce 428) (("/") reduce 428) (("<") reduce 428) ((">") reduce 428) (("?") reduce 428) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_BOOLEAN_AND) reduce 428) ((T_BOOLEAN_OR) reduce 428) ((T_COALESCE) reduce 428) ((T_DOUBLE_ARROW) reduce 428) ((T_INSTANCEOF) reduce 428) ((T_IS_EQUAL) reduce 428) ((T_IS_GREATER_OR_EQUAL) reduce 428) ((T_IS_IDENTICAL) reduce 428) ((T_IS_NOT_EQUAL) reduce 428) ((T_IS_NOT_IDENTICAL) reduce 428) ((T_IS_SMALLER_OR_EQUAL) reduce 428) ((T_LOGICAL_AND) reduce 428) ((T_LOGICAL_OR) reduce 428) ((T_LOGICAL_XOR) reduce 428) ((T_POW) shift) ((T_SL) reduce 428) ((T_SPACESHIP) reduce 428) ((T_SR) reduce 428) (("]") reduce 428) (("^") reduce 428) (("|") reduce 428)) 12176 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 578) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 578) (("^") shift) (("|") shift)) 12177 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 577) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 577) (("^") shift) (("|") shift)) 12178 ((("%") reduce 387) (("*") reduce 387) (("+") reduce 387) (("-") reduce 387) ((".") reduce 387) (("/") reduce 387) (("<") reduce 387) ((">") reduce 387) (("?") reduce 387) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_BOOLEAN_AND) reduce 387) ((T_BOOLEAN_OR) reduce 387) ((T_COALESCE) reduce 387) ((T_DOUBLE_ARROW) reduce 387) ((T_INSTANCEOF) reduce 387) ((T_IS_EQUAL) reduce 387) ((T_IS_GREATER_OR_EQUAL) reduce 387) ((T_IS_IDENTICAL) reduce 387) ((T_IS_NOT_EQUAL) reduce 387) ((T_IS_NOT_IDENTICAL) reduce 387) ((T_IS_SMALLER_OR_EQUAL) reduce 387) ((T_LOGICAL_AND) reduce 387) ((T_LOGICAL_OR) reduce 387) ((T_LOGICAL_XOR) reduce 387) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 387) ((T_SL) reduce 387) ((T_SPACESHIP) reduce 387) ((T_SR) reduce 387) (("[") reduce 510) (("]") reduce 387) (("^") reduce 387) (("{") reduce 510) (("|") reduce 387)) 12180 ((("%") reduce 435) (("*") reduce 435) (("+") reduce 435) (("-") reduce 435) ((".") reduce 435) (("/") reduce 435) (("<") reduce 435) ((">") reduce 435) (("?") reduce 435) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_BOOLEAN_AND) reduce 435) ((T_BOOLEAN_OR) reduce 435) ((T_COALESCE) reduce 435) ((T_DOUBLE_ARROW) reduce 435) ((T_INSTANCEOF) reduce 435) ((T_IS_EQUAL) reduce 435) ((T_IS_GREATER_OR_EQUAL) reduce 435) ((T_IS_IDENTICAL) reduce 435) ((T_IS_NOT_EQUAL) reduce 435) ((T_IS_NOT_IDENTICAL) reduce 435) ((T_IS_SMALLER_OR_EQUAL) reduce 435) ((T_LOGICAL_AND) reduce 435) ((T_LOGICAL_OR) reduce 435) ((T_LOGICAL_XOR) reduce 435) ((T_POW) reduce 435) ((T_SL) reduce 435) ((T_SPACESHIP) reduce 435) ((T_SR) reduce 435) (("]") reduce 435) (("^") reduce 435) (("|") reduce 435)) 12182 ((("%") reduce 476) (("*") reduce 476) (("+") reduce 476) (("-") reduce 476) ((".") reduce 476) (("/") reduce 476) (("<") reduce 476) ((">") reduce 476) (("?") reduce 476) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_BOOLEAN_AND) reduce 476) ((T_BOOLEAN_OR) reduce 476) ((T_COALESCE) reduce 476) ((T_DOUBLE_ARROW) reduce 476) ((T_INSTANCEOF) reduce 476) ((T_IS_EQUAL) reduce 476) ((T_IS_GREATER_OR_EQUAL) reduce 476) ((T_IS_IDENTICAL) reduce 476) ((T_IS_NOT_EQUAL) reduce 476) ((T_IS_NOT_IDENTICAL) reduce 476) ((T_IS_SMALLER_OR_EQUAL) reduce 476) ((T_LOGICAL_AND) reduce 476) ((T_LOGICAL_OR) reduce 476) ((T_LOGICAL_XOR) reduce 476) ((T_POW) reduce 476) ((T_SL) reduce 476) ((T_SPACESHIP) reduce 476) ((T_SR) reduce 476) (("]") reduce 476) (("^") reduce 476) (("|") reduce 476)) 12185 ((("%") reduce 579) (("*") reduce 579) (("+") reduce 579) (("-") reduce 579) ((".") reduce 579) (("/") reduce 579) (("<") reduce 579) ((">") reduce 579) (("?") reduce 579) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_BOOLEAN_AND) reduce 579) ((T_BOOLEAN_OR) reduce 579) ((T_COALESCE) reduce 579) ((T_DOUBLE_ARROW) reduce 579) ((T_INSTANCEOF) reduce 579) ((T_IS_EQUAL) reduce 579) ((T_IS_GREATER_OR_EQUAL) reduce 579) ((T_IS_IDENTICAL) reduce 579) ((T_IS_NOT_EQUAL) reduce 579) ((T_IS_NOT_IDENTICAL) reduce 579) ((T_IS_SMALLER_OR_EQUAL) reduce 579) ((T_LOGICAL_AND) reduce 579) ((T_LOGICAL_OR) reduce 579) ((T_LOGICAL_XOR) reduce 579) ((T_POW) reduce 579) ((T_SL) reduce 579) ((T_SPACESHIP) reduce 579) ((T_SR) reduce 579) (("]") reduce 579) (("^") reduce 579) (("|") reduce 579)) 12188 ((("%") reduce 576) (("*") reduce 576) (("+") reduce 576) (("-") reduce 576) ((".") reduce 576) (("/") reduce 576) (("<") reduce 576) ((">") reduce 576) (("?") reduce 576) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_BOOLEAN_AND) reduce 576) ((T_BOOLEAN_OR) reduce 576) ((T_COALESCE) reduce 576) ((T_DOUBLE_ARROW) reduce 576) ((T_INSTANCEOF) reduce 576) ((T_IS_EQUAL) reduce 576) ((T_IS_GREATER_OR_EQUAL) reduce 576) ((T_IS_IDENTICAL) reduce 576) ((T_IS_NOT_EQUAL) reduce 576) ((T_IS_NOT_IDENTICAL) reduce 576) ((T_IS_SMALLER_OR_EQUAL) reduce 576) ((T_LOGICAL_AND) reduce 576) ((T_LOGICAL_OR) reduce 576) ((T_LOGICAL_XOR) reduce 576) ((T_POW) reduce 576) ((T_SL) reduce 576) ((T_SPACESHIP) reduce 576) ((T_SR) reduce 576) (("]") reduce 576) (("^") reduce 576) (("|") reduce 576)) 12189 ((("%") reduce 429) (("*") reduce 429) (("+") reduce 429) (("-") reduce 429) ((".") reduce 429) (("/") reduce 429) (("<") reduce 429) ((">") reduce 429) (("?") reduce 429) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_BOOLEAN_AND) reduce 429) ((T_BOOLEAN_OR) reduce 429) ((T_COALESCE) reduce 429) ((T_DOUBLE_ARROW) reduce 429) ((T_INSTANCEOF) reduce 429) ((T_IS_EQUAL) reduce 429) ((T_IS_GREATER_OR_EQUAL) reduce 429) ((T_IS_IDENTICAL) reduce 429) ((T_IS_NOT_EQUAL) reduce 429) ((T_IS_NOT_IDENTICAL) reduce 429) ((T_IS_SMALLER_OR_EQUAL) reduce 429) ((T_LOGICAL_AND) reduce 429) ((T_LOGICAL_OR) reduce 429) ((T_LOGICAL_XOR) reduce 429) ((T_POW) shift) ((T_SL) reduce 429) ((T_SPACESHIP) reduce 429) ((T_SR) reduce 429) (("]") reduce 429) (("^") reduce 429) (("|") reduce 429)) 12190 ((("%") reduce 389) (("*") reduce 389) (("+") reduce 389) (("-") reduce 389) ((".") reduce 389) (("/") reduce 389) (("<") reduce 389) ((">") reduce 389) (("?") reduce 389) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_BOOLEAN_AND) reduce 389) ((T_BOOLEAN_OR) reduce 389) ((T_COALESCE) reduce 389) ((T_DOUBLE_ARROW) reduce 389) ((T_INSTANCEOF) reduce 389) ((T_IS_EQUAL) reduce 389) ((T_IS_GREATER_OR_EQUAL) reduce 389) ((T_IS_IDENTICAL) reduce 389) ((T_IS_NOT_EQUAL) reduce 389) ((T_IS_NOT_IDENTICAL) reduce 389) ((T_IS_SMALLER_OR_EQUAL) reduce 389) ((T_LOGICAL_AND) reduce 389) ((T_LOGICAL_OR) reduce 389) ((T_LOGICAL_XOR) reduce 389) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 389) ((T_SL) reduce 389) ((T_SPACESHIP) reduce 389) ((T_SR) reduce 389) (("[") reduce 510) (("]") reduce 389) (("^") reduce 389) (("{") reduce 510) (("|") reduce 389)) 12191 ((("%") reduce 372) (("*") reduce 372) (("+") reduce 372) (("-") reduce 372) ((".") reduce 372) (("/") reduce 372) (("<") reduce 372) ((">") reduce 372) (("?") reduce 372) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_BOOLEAN_AND) reduce 372) ((T_BOOLEAN_OR) reduce 372) ((T_COALESCE) reduce 372) ((T_DOUBLE_ARROW) reduce 372) ((T_INSTANCEOF) reduce 372) ((T_IS_EQUAL) reduce 372) ((T_IS_GREATER_OR_EQUAL) reduce 372) ((T_IS_IDENTICAL) reduce 372) ((T_IS_NOT_EQUAL) reduce 372) ((T_IS_NOT_IDENTICAL) reduce 372) ((T_IS_SMALLER_OR_EQUAL) reduce 372) ((T_LOGICAL_AND) reduce 372) ((T_LOGICAL_OR) reduce 372) ((T_LOGICAL_XOR) reduce 372) ((T_POW) reduce 372) ((T_SL) reduce 372) ((T_SPACESHIP) reduce 372) ((T_SR) reduce 372) (("]") reduce 372) (("^") reduce 372) (("|") reduce 372)) 12192 ((("%") reduce 433) (("*") reduce 433) (("+") reduce 433) (("-") reduce 433) ((".") reduce 433) (("/") reduce 433) (("<") reduce 433) ((">") reduce 433) (("?") reduce 433) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_BOOLEAN_AND) reduce 433) ((T_BOOLEAN_OR) reduce 433) ((T_COALESCE) reduce 433) ((T_DOUBLE_ARROW) reduce 433) ((T_INSTANCEOF) reduce 433) ((T_IS_EQUAL) reduce 433) ((T_IS_GREATER_OR_EQUAL) reduce 433) ((T_IS_IDENTICAL) reduce 433) ((T_IS_NOT_EQUAL) reduce 433) ((T_IS_NOT_IDENTICAL) reduce 433) ((T_IS_SMALLER_OR_EQUAL) reduce 433) ((T_LOGICAL_AND) reduce 433) ((T_LOGICAL_OR) reduce 433) ((T_LOGICAL_XOR) reduce 433) ((T_POW) shift) ((T_SL) reduce 433) ((T_SPACESHIP) reduce 433) ((T_SR) reduce 433) (("]") reduce 433) (("^") reduce 433) (("|") reduce 433)) 12193 ((("%") reduce 431) (("*") reduce 431) (("+") reduce 431) (("-") reduce 431) ((".") reduce 431) (("/") reduce 431) (("<") reduce 431) ((">") reduce 431) (("?") reduce 431) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_BOOLEAN_AND) reduce 431) ((T_BOOLEAN_OR) reduce 431) ((T_COALESCE) reduce 431) ((T_DOUBLE_ARROW) reduce 431) ((T_INSTANCEOF) reduce 431) ((T_IS_EQUAL) reduce 431) ((T_IS_GREATER_OR_EQUAL) reduce 431) ((T_IS_IDENTICAL) reduce 431) ((T_IS_NOT_EQUAL) reduce 431) ((T_IS_NOT_IDENTICAL) reduce 431) ((T_IS_SMALLER_OR_EQUAL) reduce 431) ((T_LOGICAL_AND) reduce 431) ((T_LOGICAL_OR) reduce 431) ((T_LOGICAL_XOR) reduce 431) ((T_POW) shift) ((T_SL) reduce 431) ((T_SPACESHIP) reduce 431) ((T_SR) reduce 431) (("]") reduce 431) (("^") reduce 431) (("|") reduce 431)) 12196 ((("%") reduce 482) (("(") reduce 482) (("*") reduce 482) (("+") reduce 482) (("-") reduce 482) ((".") reduce 482) (("/") reduce 482) (("<") reduce 482) ((">") reduce 482) (("?") reduce 482) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_BOOLEAN_AND) reduce 482) ((T_BOOLEAN_OR) reduce 482) ((T_COALESCE) reduce 482) ((T_DOUBLE_ARROW) reduce 482) ((T_INSTANCEOF) reduce 482) ((T_IS_EQUAL) reduce 482) ((T_IS_GREATER_OR_EQUAL) reduce 482) ((T_IS_IDENTICAL) reduce 482) ((T_IS_NOT_EQUAL) reduce 482) ((T_IS_NOT_IDENTICAL) reduce 482) ((T_IS_SMALLER_OR_EQUAL) reduce 482) ((T_LOGICAL_AND) reduce 482) ((T_LOGICAL_OR) reduce 482) ((T_LOGICAL_XOR) reduce 482) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 482) ((T_OBJECT_OPERATOR) reduce 482) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 482) ((T_POW) reduce 482) ((T_SL) reduce 482) ((T_SPACESHIP) reduce 482) ((T_SR) reduce 482) (("[") reduce 482) (("]") reduce 482) (("^") reduce 482) (("{") reduce 482) (("|") reduce 482)) 12197 ((("%") reduce 436) (("*") reduce 436) (("+") reduce 436) (("-") reduce 436) ((".") reduce 436) (("/") reduce 436) (("<") reduce 436) ((">") reduce 436) (("?") reduce 436) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_BOOLEAN_AND) reduce 436) ((T_BOOLEAN_OR) reduce 436) ((T_COALESCE) reduce 436) ((T_DOUBLE_ARROW) reduce 436) ((T_INSTANCEOF) reduce 436) ((T_IS_EQUAL) reduce 436) ((T_IS_GREATER_OR_EQUAL) reduce 436) ((T_IS_IDENTICAL) reduce 436) ((T_IS_NOT_EQUAL) reduce 436) ((T_IS_NOT_IDENTICAL) reduce 436) ((T_IS_SMALLER_OR_EQUAL) reduce 436) ((T_LOGICAL_AND) reduce 436) ((T_LOGICAL_OR) reduce 436) ((T_LOGICAL_XOR) reduce 436) ((T_POW) shift) ((T_SL) reduce 436) ((T_SPACESHIP) reduce 436) ((T_SR) reduce 436) (("]") reduce 436) (("^") reduce 436) (("|") reduce 436)) 12198 ((("%") reduce 409) (("*") reduce 409) (("+") reduce 409) (("-") reduce 409) ((".") reduce 409) (("/") reduce 409) (("<") reduce 409) ((">") reduce 409) (("?") reduce 409) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_BOOLEAN_AND) reduce 409) ((T_BOOLEAN_OR) reduce 409) ((T_COALESCE) reduce 409) ((T_DOUBLE_ARROW) reduce 409) ((T_INSTANCEOF) reduce 409) ((T_IS_EQUAL) reduce 409) ((T_IS_GREATER_OR_EQUAL) reduce 409) ((T_IS_IDENTICAL) reduce 409) ((T_IS_NOT_EQUAL) reduce 409) ((T_IS_NOT_IDENTICAL) reduce 409) ((T_IS_SMALLER_OR_EQUAL) reduce 409) ((T_LOGICAL_AND) reduce 409) ((T_LOGICAL_OR) reduce 409) ((T_LOGICAL_XOR) reduce 409) ((T_POW) shift) ((T_SL) reduce 409) ((T_SPACESHIP) reduce 409) ((T_SR) reduce 409) (("]") reduce 409) (("^") reduce 409) (("|") reduce 409)) 12199 ((("%") reduce 408) (("*") reduce 408) (("+") reduce 408) (("-") reduce 408) ((".") reduce 408) (("/") reduce 408) (("<") reduce 408) ((">") reduce 408) (("?") reduce 408) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_BOOLEAN_AND) reduce 408) ((T_BOOLEAN_OR) reduce 408) ((T_COALESCE) reduce 408) ((T_DOUBLE_ARROW) reduce 408) ((T_INSTANCEOF) reduce 408) ((T_IS_EQUAL) reduce 408) ((T_IS_GREATER_OR_EQUAL) reduce 408) ((T_IS_IDENTICAL) reduce 408) ((T_IS_NOT_EQUAL) reduce 408) ((T_IS_NOT_IDENTICAL) reduce 408) ((T_IS_SMALLER_OR_EQUAL) reduce 408) ((T_LOGICAL_AND) reduce 408) ((T_LOGICAL_OR) reduce 408) ((T_LOGICAL_XOR) reduce 408) ((T_POW) shift) ((T_SL) reduce 408) ((T_SPACESHIP) reduce 408) ((T_SR) reduce 408) (("]") reduce 408) (("^") reduce 408) (("|") reduce 408)) 12201 ((("%") reduce 422) (("(") reduce 517) (("*") reduce 422) (("+") reduce 422) (("-") reduce 422) ((".") reduce 422) (("/") reduce 422) (("<") reduce 422) ((">") reduce 422) (("?") reduce 422) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_BOOLEAN_AND) reduce 422) ((T_BOOLEAN_OR) reduce 422) ((T_COALESCE) reduce 422) ((T_DOUBLE_ARROW) reduce 422) ((T_INSTANCEOF) reduce 422) ((T_IS_EQUAL) reduce 422) ((T_IS_GREATER_OR_EQUAL) reduce 422) ((T_IS_IDENTICAL) reduce 422) ((T_IS_NOT_EQUAL) reduce 422) ((T_IS_NOT_IDENTICAL) reduce 422) ((T_IS_SMALLER_OR_EQUAL) reduce 422) ((T_LOGICAL_AND) reduce 422) ((T_LOGICAL_OR) reduce 422) ((T_LOGICAL_XOR) reduce 422) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 511) ((T_OBJECT_OPERATOR) reduce 511) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 511) ((T_POW) reduce 422) ((T_SL) reduce 422) ((T_SPACESHIP) reduce 422) ((T_SR) reduce 422) (("[") reduce 511) (("]") reduce 422) (("^") reduce 422) (("{") reduce 511) (("|") reduce 422)) 12202 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) (("=") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AND_EQUAL) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_COALESCE_EQUAL) reduce 531) ((T_CONCAT_EQUAL) reduce 531) ((T_DEC) reduce 531) ((T_DIV_EQUAL) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INC) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_MINUS_EQUAL) reduce 531) ((T_MOD_EQUAL) reduce 531) ((T_MUL_EQUAL) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_OR_EQUAL) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_PLUS_EQUAL) reduce 531) ((T_POW) reduce 531) ((T_POW_EQUAL) reduce 531) ((T_SL) reduce 531) ((T_SL_EQUAL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) ((T_SR_EQUAL) reduce 531) ((T_XOR_EQUAL) reduce 531) (("[") reduce 531) (("]") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 12205 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) (("=") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AND_EQUAL) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_COALESCE_EQUAL) reduce 530) ((T_CONCAT_EQUAL) reduce 530) ((T_DEC) reduce 530) ((T_DIV_EQUAL) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INC) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_MINUS_EQUAL) reduce 530) ((T_MOD_EQUAL) reduce 530) ((T_MUL_EQUAL) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_OR_EQUAL) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_PLUS_EQUAL) reduce 530) ((T_POW) reduce 530) ((T_POW_EQUAL) reduce 530) ((T_SL) reduce 530) ((T_SL_EQUAL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) ((T_SR_EQUAL) reduce 530) ((T_XOR_EQUAL) reduce 530) (("[") reduce 530) (("]") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 12207 ((("%") reduce 485) (("(") reduce 485) (("*") reduce 485) (("+") reduce 485) (("-") reduce 485) ((".") reduce 485) (("/") reduce 485) (("<") reduce 485) ((">") reduce 485) (("?") reduce 485) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_BOOLEAN_AND) reduce 485) ((T_BOOLEAN_OR) reduce 485) ((T_COALESCE) reduce 485) ((T_DOUBLE_ARROW) reduce 485) ((T_INSTANCEOF) reduce 485) ((T_IS_EQUAL) reduce 485) ((T_IS_GREATER_OR_EQUAL) reduce 485) ((T_IS_IDENTICAL) reduce 485) ((T_IS_NOT_EQUAL) reduce 485) ((T_IS_NOT_IDENTICAL) reduce 485) ((T_IS_SMALLER_OR_EQUAL) reduce 485) ((T_LOGICAL_AND) reduce 485) ((T_LOGICAL_OR) reduce 485) ((T_LOGICAL_XOR) reduce 485) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 485) ((T_OBJECT_OPERATOR) reduce 485) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 485) ((T_POW) reduce 485) ((T_SL) reduce 485) ((T_SPACESHIP) reduce 485) ((T_SR) reduce 485) (("[") reduce 485) (("]") reduce 485) (("^") reduce 485) (("{") reduce 485) (("|") reduce 485)) 12208 ((("%") reduce 410) (("*") reduce 410) (("+") reduce 410) (("-") reduce 410) ((".") reduce 410) (("/") reduce 410) (("<") reduce 410) ((">") reduce 410) (("?") reduce 410) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_BOOLEAN_AND) reduce 410) ((T_BOOLEAN_OR) reduce 410) ((T_COALESCE) reduce 410) ((T_DOUBLE_ARROW) reduce 410) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 410) ((T_IS_GREATER_OR_EQUAL) reduce 410) ((T_IS_IDENTICAL) reduce 410) ((T_IS_NOT_EQUAL) reduce 410) ((T_IS_NOT_IDENTICAL) reduce 410) ((T_IS_SMALLER_OR_EQUAL) reduce 410) ((T_LOGICAL_AND) reduce 410) ((T_LOGICAL_OR) reduce 410) ((T_LOGICAL_XOR) reduce 410) ((T_POW) shift) ((T_SL) reduce 410) ((T_SPACESHIP) reduce 410) ((T_SR) reduce 410) (("]") reduce 410) (("^") reduce 410) (("|") reduce 410)) 12209 ((("%") reduce 434) (("*") reduce 434) (("+") reduce 434) (("-") reduce 434) ((".") reduce 434) (("/") reduce 434) (("<") reduce 434) ((">") reduce 434) (("?") reduce 434) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_BOOLEAN_AND) reduce 434) ((T_BOOLEAN_OR) reduce 434) ((T_COALESCE) reduce 434) ((T_INSTANCEOF) reduce 434) ((T_IS_EQUAL) reduce 434) ((T_IS_GREATER_OR_EQUAL) reduce 434) ((T_IS_IDENTICAL) reduce 434) ((T_IS_NOT_EQUAL) reduce 434) ((T_IS_NOT_IDENTICAL) reduce 434) ((T_IS_SMALLER_OR_EQUAL) reduce 434) ((T_LOGICAL_AND) reduce 434) ((T_LOGICAL_OR) reduce 434) ((T_LOGICAL_XOR) reduce 434) ((T_POW) shift) ((T_SL) reduce 434) ((T_SPACESHIP) reduce 434) ((T_SR) reduce 434) (("]") reduce 434) (("^") reduce 434) (("|") reduce 434)) 12210 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 444) (("^") shift) (("|") shift)) 12211 ((("%") reduce 430) (("*") reduce 430) (("+") reduce 430) (("-") reduce 430) ((".") reduce 430) (("/") reduce 430) (("<") reduce 430) ((">") reduce 430) (("?") reduce 430) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_BOOLEAN_AND) reduce 430) ((T_BOOLEAN_OR) reduce 430) ((T_COALESCE) reduce 430) ((T_INSTANCEOF) reduce 430) ((T_IS_EQUAL) reduce 430) ((T_IS_GREATER_OR_EQUAL) reduce 430) ((T_IS_IDENTICAL) reduce 430) ((T_IS_NOT_EQUAL) reduce 430) ((T_IS_NOT_IDENTICAL) reduce 430) ((T_IS_SMALLER_OR_EQUAL) reduce 430) ((T_LOGICAL_AND) reduce 430) ((T_LOGICAL_OR) reduce 430) ((T_LOGICAL_XOR) reduce 430) ((T_POW) shift) ((T_SL) reduce 430) ((T_SPACESHIP) reduce 430) ((T_SR) reduce 430) (("]") reduce 430) (("^") reduce 430) (("|") reduce 430)) 12212 ((("%") reduce 447) (("*") reduce 447) (("+") reduce 447) (("-") reduce 447) ((".") reduce 447) (("/") reduce 447) (("<") reduce 447) ((">") reduce 447) (("?") reduce 447) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_BOOLEAN_AND) reduce 447) ((T_BOOLEAN_OR) reduce 447) ((T_COALESCE) reduce 447) ((T_INSTANCEOF) reduce 447) ((T_IS_EQUAL) reduce 447) ((T_IS_GREATER_OR_EQUAL) reduce 447) ((T_IS_IDENTICAL) reduce 447) ((T_IS_NOT_EQUAL) reduce 447) ((T_IS_NOT_IDENTICAL) reduce 447) ((T_IS_SMALLER_OR_EQUAL) reduce 447) ((T_LOGICAL_AND) reduce 447) ((T_LOGICAL_OR) reduce 447) ((T_LOGICAL_XOR) reduce 447) ((T_POW) reduce 447) ((T_SL) reduce 447) ((T_SPACESHIP) reduce 447) ((T_SR) reduce 447) (("]") reduce 447) (("^") reduce 447) (("|") reduce 447)) 12214 ((("%") reduce 489) (("*") reduce 489) (("+") reduce 489) (("-") reduce 489) ((".") reduce 489) (("/") reduce 489) (("<") reduce 489) ((">") reduce 489) (("?") reduce 489) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_BOOLEAN_AND) reduce 489) ((T_BOOLEAN_OR) reduce 489) ((T_COALESCE) reduce 489) ((T_INSTANCEOF) reduce 489) ((T_IS_EQUAL) reduce 489) ((T_IS_GREATER_OR_EQUAL) reduce 489) ((T_IS_IDENTICAL) reduce 489) ((T_IS_NOT_EQUAL) reduce 489) ((T_IS_NOT_IDENTICAL) reduce 489) ((T_IS_SMALLER_OR_EQUAL) reduce 489) ((T_LOGICAL_AND) reduce 489) ((T_LOGICAL_OR) reduce 489) ((T_LOGICAL_XOR) reduce 489) ((T_POW) reduce 489) ((T_SL) reduce 489) ((T_SPACESHIP) reduce 489) ((T_SR) reduce 489) (("]") reduce 489) (("^") reduce 489) (("|") reduce 489)) 12216 ((("%") reduce 490) (("*") reduce 490) (("+") reduce 490) (("-") reduce 490) ((".") reduce 490) (("/") reduce 490) (("<") reduce 490) ((">") reduce 490) (("?") reduce 490) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_BOOLEAN_AND) reduce 490) ((T_BOOLEAN_OR) reduce 490) ((T_COALESCE) reduce 490) ((T_INSTANCEOF) reduce 490) ((T_IS_EQUAL) reduce 490) ((T_IS_GREATER_OR_EQUAL) reduce 490) ((T_IS_IDENTICAL) reduce 490) ((T_IS_NOT_EQUAL) reduce 490) ((T_IS_NOT_IDENTICAL) reduce 490) ((T_IS_SMALLER_OR_EQUAL) reduce 490) ((T_LOGICAL_AND) reduce 490) ((T_LOGICAL_OR) reduce 490) ((T_LOGICAL_XOR) reduce 490) ((T_POW) reduce 490) ((T_SL) reduce 490) ((T_SPACESHIP) reduce 490) ((T_SR) reduce 490) (("]") reduce 490) (("^") reduce 490) (("|") reduce 490)) 12217 ((("%") reduce 488) (("*") reduce 488) (("+") reduce 488) (("-") reduce 488) ((".") reduce 488) (("/") reduce 488) (("<") reduce 488) ((">") reduce 488) (("?") reduce 488) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_BOOLEAN_AND) reduce 488) ((T_BOOLEAN_OR) reduce 488) ((T_COALESCE) reduce 488) ((T_INSTANCEOF) reduce 488) ((T_IS_EQUAL) reduce 488) ((T_IS_GREATER_OR_EQUAL) reduce 488) ((T_IS_IDENTICAL) reduce 488) ((T_IS_NOT_EQUAL) reduce 488) ((T_IS_NOT_IDENTICAL) reduce 488) ((T_IS_SMALLER_OR_EQUAL) reduce 488) ((T_LOGICAL_AND) reduce 488) ((T_LOGICAL_OR) reduce 488) ((T_LOGICAL_XOR) reduce 488) ((T_POW) reduce 488) ((T_SL) reduce 488) ((T_SPACESHIP) reduce 488) ((T_SR) reduce 488) (("]") reduce 488) (("^") reduce 488) (("|") reduce 488)) 12218 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 581) (("^") shift) (("|") shift)) 12219 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 580) (("^") shift) (("|") shift)) 12220 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) (("<") reduce 466) (("=") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AND_EQUAL) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_COALESCE_EQUAL) reduce 466) ((T_CONCAT_EQUAL) reduce 466) ((T_DEC) reduce 466) ((T_DIV_EQUAL) reduce 466) ((T_INC) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_MINUS_EQUAL) reduce 466) ((T_MOD_EQUAL) reduce 466) ((T_MUL_EQUAL) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_OR_EQUAL) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_PLUS_EQUAL) reduce 466) ((T_POW) reduce 466) ((T_POW_EQUAL) reduce 466) ((T_SL) reduce 466) ((T_SL_EQUAL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) ((T_SR_EQUAL) reduce 466) ((T_XOR_EQUAL) reduce 466) (("[") reduce 466) (("]") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 12221 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 439) ((T_LOGICAL_OR) reduce 439) ((T_LOGICAL_XOR) reduce 439) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 439) (("^") shift) (("|") shift)) 12222 ((("%") reduce 432) (("*") reduce 432) (("+") reduce 432) (("-") reduce 432) ((".") reduce 432) (("/") reduce 432) (("<") reduce 432) ((">") reduce 432) (("?") reduce 432) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_BOOLEAN_AND) reduce 432) ((T_BOOLEAN_OR) reduce 432) ((T_COALESCE) reduce 432) ((T_INSTANCEOF) reduce 432) ((T_IS_EQUAL) reduce 432) ((T_IS_GREATER_OR_EQUAL) reduce 432) ((T_IS_IDENTICAL) reduce 432) ((T_IS_NOT_EQUAL) reduce 432) ((T_IS_NOT_IDENTICAL) reduce 432) ((T_IS_SMALLER_OR_EQUAL) reduce 432) ((T_LOGICAL_AND) reduce 432) ((T_LOGICAL_OR) reduce 432) ((T_LOGICAL_XOR) reduce 432) ((T_POW) shift) ((T_SL) reduce 432) ((T_SPACESHIP) reduce 432) ((T_SR) reduce 432) (("]") reduce 432) (("^") reduce 432) (("|") reduce 432)) 12224 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("]") reduce 93) (("^") reduce 93) (("|") reduce 93)) 12225 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("]") reduce 92) (("^") reduce 92) (("|") reduce 92)) 12226 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("]") reduce 94) (("^") reduce 94) (("|") reduce 94)) 12227 ((("%") reduce 470) (("(") reduce 470) (("*") reduce 470) (("+") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("]") reduce 470) (("^") reduce 470) (("|") reduce 470)) 12228 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("]") reduce 91) (("^") reduce 91) (("|") reduce 91)) 12229 ((("%") reduce 365) (("*") reduce 365) (("+") reduce 365) (("-") reduce 365) ((".") reduce 365) (("/") reduce 365) (("<") reduce 365) ((">") reduce 365) (("?") reduce 365) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_BOOLEAN_AND) reduce 365) ((T_BOOLEAN_OR) reduce 365) ((T_COALESCE) reduce 365) ((T_INSTANCEOF) reduce 365) ((T_IS_EQUAL) reduce 365) ((T_IS_GREATER_OR_EQUAL) reduce 365) ((T_IS_IDENTICAL) reduce 365) ((T_IS_NOT_EQUAL) reduce 365) ((T_IS_NOT_IDENTICAL) reduce 365) ((T_IS_SMALLER_OR_EQUAL) reduce 365) ((T_LOGICAL_AND) reduce 365) ((T_LOGICAL_OR) reduce 365) ((T_LOGICAL_XOR) reduce 365) ((T_POW) reduce 365) ((T_SL) reduce 365) ((T_SPACESHIP) reduce 365) ((T_SR) reduce 365) (("]") reduce 365) (("^") reduce 365) (("|") reduce 365)) 12232 ((("%") reduce 472) (("(") reduce 472) (("*") reduce 472) (("+") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("]") reduce 472) (("^") reduce 472) (("|") reduce 472)) 12233 ((("%") reduce 480) (("(") shift) (("*") reduce 480) (("+") reduce 480) (("-") reduce 480) ((".") reduce 480) (("/") reduce 480) (("<") reduce 480) ((">") reduce 480) (("?") reduce 480) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_BOOLEAN_AND) reduce 480) ((T_BOOLEAN_OR) reduce 480) ((T_COALESCE) reduce 480) ((T_INSTANCEOF) reduce 480) ((T_IS_EQUAL) reduce 480) ((T_IS_GREATER_OR_EQUAL) reduce 480) ((T_IS_IDENTICAL) reduce 480) ((T_IS_NOT_EQUAL) reduce 480) ((T_IS_NOT_IDENTICAL) reduce 480) ((T_IS_SMALLER_OR_EQUAL) reduce 480) ((T_LOGICAL_AND) reduce 480) ((T_LOGICAL_OR) reduce 480) ((T_LOGICAL_XOR) reduce 480) ((T_POW) reduce 480) ((T_SL) reduce 480) ((T_SPACESHIP) reduce 480) ((T_SR) reduce 480) (("]") reduce 480) (("^") reduce 480) (("|") reduce 480)) 12234 ((("%") reduce 471) (("(") reduce 471) (("*") reduce 471) (("+") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("]") reduce 471) (("^") reduce 471) (("|") reduce 471)) 12235 ((("%") reduce 473) (("(") reduce 473) (("*") reduce 473) (("+") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("]") reduce 473) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 12236 ((("%") reduce 534) (("(") reduce 534) (("*") reduce 534) (("+") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("]") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 12243 ((("%") reduce 536) (("(") reduce 536) (("*") reduce 536) (("+") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("]") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 12245 ((("%") reduce 535) (("(") reduce 535) (("*") reduce 535) (("+") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("]") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 12246 ((("%") reduce 540) (("(") reduce 540) (("*") reduce 540) (("+") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("]") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 12247 ((("%") reduce 537) (("(") reduce 537) (("*") reduce 537) (("+") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("]") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 12248 ((("%") reduce 538) (("(") reduce 538) (("*") reduce 538) (("+") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("]") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 12250 ((("%") reduce 481) (("*") reduce 481) (("+") reduce 481) (("-") reduce 481) ((".") reduce 481) (("/") reduce 481) (("<") reduce 481) ((">") reduce 481) (("?") reduce 481) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_BOOLEAN_AND) reduce 481) ((T_BOOLEAN_OR) reduce 481) ((T_COALESCE) reduce 481) ((T_INSTANCEOF) reduce 481) ((T_IS_EQUAL) reduce 481) ((T_IS_GREATER_OR_EQUAL) reduce 481) ((T_IS_IDENTICAL) reduce 481) ((T_IS_NOT_EQUAL) reduce 481) ((T_IS_NOT_IDENTICAL) reduce 481) ((T_IS_SMALLER_OR_EQUAL) reduce 481) ((T_LOGICAL_AND) reduce 481) ((T_LOGICAL_OR) reduce 481) ((T_LOGICAL_XOR) reduce 481) ((T_POW) reduce 481) ((T_SL) reduce 481) ((T_SPACESHIP) reduce 481) ((T_SR) reduce 481) (("]") reduce 481) (("^") reduce 481) (("|") reduce 481)) 12251 ((("%") reduce 364) (("*") reduce 364) (("+") reduce 364) (("-") reduce 364) ((".") reduce 364) (("/") reduce 364) (("<") reduce 364) ((">") reduce 364) (("?") reduce 364) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_BOOLEAN_AND) reduce 364) ((T_BOOLEAN_OR) reduce 364) ((T_COALESCE) reduce 364) ((T_INSTANCEOF) reduce 364) ((T_IS_EQUAL) reduce 364) ((T_IS_GREATER_OR_EQUAL) reduce 364) ((T_IS_IDENTICAL) reduce 364) ((T_IS_NOT_EQUAL) reduce 364) ((T_IS_NOT_IDENTICAL) reduce 364) ((T_IS_SMALLER_OR_EQUAL) reduce 364) ((T_LOGICAL_AND) reduce 364) ((T_LOGICAL_OR) reduce 364) ((T_LOGICAL_XOR) reduce 364) ((T_POW) reduce 364) ((T_SL) reduce 364) ((T_SPACESHIP) reduce 364) ((T_SR) reduce 364) (("]") reduce 364) (("^") reduce 364) (("|") reduce 364)) 12252 ((("%") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("]") reduce 288) (("^") reduce 288) (("|") reduce 288)) 12256 ((("%") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("]") reduce 289) (("^") reduce 289) (("|") reduce 289)) 12257 ((("%") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("]") reduce 290) (("^") reduce 290) (("|") reduce 290)) 12259 ((("%") reduce 539) (("(") reduce 539) (("*") reduce 539) (("+") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("]") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 12260 ((("%") reduce 366) (("*") reduce 366) (("+") reduce 366) (("-") reduce 366) ((".") reduce 366) (("/") reduce 366) (("<") reduce 366) ((">") reduce 366) (("?") reduce 366) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_BOOLEAN_AND) reduce 366) ((T_BOOLEAN_OR) reduce 366) ((T_COALESCE) reduce 366) ((T_INSTANCEOF) reduce 366) ((T_IS_EQUAL) reduce 366) ((T_IS_GREATER_OR_EQUAL) reduce 366) ((T_IS_IDENTICAL) reduce 366) ((T_IS_NOT_EQUAL) reduce 366) ((T_IS_NOT_IDENTICAL) reduce 366) ((T_IS_SMALLER_OR_EQUAL) reduce 366) ((T_LOGICAL_AND) reduce 366) ((T_LOGICAL_OR) reduce 366) ((T_LOGICAL_XOR) reduce 366) ((T_POW) reduce 366) ((T_SL) reduce 366) ((T_SPACESHIP) reduce 366) ((T_SR) reduce 366) (("]") reduce 366) (("^") reduce 366) (("|") reduce 366)) 12268 ((("%") reduce 363) (("*") reduce 363) (("+") reduce 363) (("-") reduce 363) ((".") reduce 363) (("/") reduce 363) (("<") reduce 363) ((">") reduce 363) (("?") reduce 363) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_BOOLEAN_AND) reduce 363) ((T_BOOLEAN_OR) reduce 363) ((T_COALESCE) reduce 363) ((T_INSTANCEOF) reduce 363) ((T_IS_EQUAL) reduce 363) ((T_IS_GREATER_OR_EQUAL) reduce 363) ((T_IS_IDENTICAL) reduce 363) ((T_IS_NOT_EQUAL) reduce 363) ((T_IS_NOT_IDENTICAL) reduce 363) ((T_IS_SMALLER_OR_EQUAL) reduce 363) ((T_LOGICAL_AND) reduce 363) ((T_LOGICAL_OR) reduce 363) ((T_LOGICAL_XOR) reduce 363) ((T_POW) reduce 363) ((T_SL) reduce 363) ((T_SPACESHIP) reduce 363) ((T_SR) reduce 363) (("]") reduce 363) (("^") reduce 363) (("|") reduce 363)) 12270 ((("%") reduce 474) (("(") reduce 474) (("*") reduce 474) (("+") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("]") reduce 474) (("^") reduce 474) (("|") reduce 474)) 12276 ((("%") reduce 230) (("*") reduce 230) (("+") reduce 230) (("-") reduce 230) ((".") reduce 230) (("/") reduce 230) (("<") reduce 230) ((">") reduce 230) (("?") reduce 230) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_BOOLEAN_AND) reduce 230) ((T_BOOLEAN_OR) reduce 230) ((T_COALESCE) reduce 230) ((T_INSTANCEOF) reduce 230) ((T_IS_EQUAL) reduce 230) ((T_IS_GREATER_OR_EQUAL) reduce 230) ((T_IS_IDENTICAL) reduce 230) ((T_IS_NOT_EQUAL) reduce 230) ((T_IS_NOT_IDENTICAL) reduce 230) ((T_IS_SMALLER_OR_EQUAL) reduce 230) ((T_LOGICAL_AND) reduce 230) ((T_LOGICAL_OR) reduce 230) ((T_LOGICAL_XOR) reduce 230) ((T_POW) reduce 230) ((T_SL) reduce 230) ((T_SPACESHIP) reduce 230) ((T_SR) reduce 230) (("]") reduce 230) (("^") reduce 230) (("|") reduce 230)) 12281 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 368) ((T_LOGICAL_OR) reduce 368) ((T_LOGICAL_XOR) reduce 368) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 368) (("^") shift) (("|") shift)) 12285 ((("%") reduce 575) (("*") reduce 575) (("+") reduce 575) (("-") reduce 575) ((".") reduce 575) (("/") reduce 575) (("<") reduce 575) ((">") reduce 575) (("?") reduce 575) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_BOOLEAN_AND) reduce 575) ((T_BOOLEAN_OR) reduce 575) ((T_COALESCE) reduce 575) ((T_INSTANCEOF) reduce 575) ((T_IS_EQUAL) reduce 575) ((T_IS_GREATER_OR_EQUAL) reduce 575) ((T_IS_IDENTICAL) reduce 575) ((T_IS_NOT_EQUAL) reduce 575) ((T_IS_NOT_IDENTICAL) reduce 575) ((T_IS_SMALLER_OR_EQUAL) reduce 575) ((T_LOGICAL_AND) reduce 575) ((T_LOGICAL_OR) reduce 575) ((T_LOGICAL_XOR) reduce 575) ((T_POW) reduce 575) ((T_SL) reduce 575) ((T_SPACESHIP) reduce 575) ((T_SR) reduce 575) (("]") reduce 575) (("^") reduce 575) (("|") reduce 575)) 12286 ((("%") reduce 428) (("*") reduce 428) (("+") reduce 428) (("-") reduce 428) ((".") reduce 428) (("/") reduce 428) (("<") reduce 428) ((">") reduce 428) (("?") reduce 428) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_BOOLEAN_AND) reduce 428) ((T_BOOLEAN_OR) reduce 428) ((T_COALESCE) reduce 428) ((T_INSTANCEOF) reduce 428) ((T_IS_EQUAL) reduce 428) ((T_IS_GREATER_OR_EQUAL) reduce 428) ((T_IS_IDENTICAL) reduce 428) ((T_IS_NOT_EQUAL) reduce 428) ((T_IS_NOT_IDENTICAL) reduce 428) ((T_IS_SMALLER_OR_EQUAL) reduce 428) ((T_LOGICAL_AND) reduce 428) ((T_LOGICAL_OR) reduce 428) ((T_LOGICAL_XOR) reduce 428) ((T_POW) shift) ((T_SL) reduce 428) ((T_SPACESHIP) reduce 428) ((T_SR) reduce 428) (("]") reduce 428) (("^") reduce 428) (("|") reduce 428)) 12287 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 578) (("^") shift) (("|") shift)) 12288 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("]") reduce 577) (("^") shift) (("|") shift)) 12289 ((("%") reduce 387) (("*") reduce 387) (("+") reduce 387) (("-") reduce 387) ((".") reduce 387) (("/") reduce 387) (("<") reduce 387) ((">") reduce 387) (("?") reduce 387) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_BOOLEAN_AND) reduce 387) ((T_BOOLEAN_OR) reduce 387) ((T_COALESCE) reduce 387) ((T_INSTANCEOF) reduce 387) ((T_IS_EQUAL) reduce 387) ((T_IS_GREATER_OR_EQUAL) reduce 387) ((T_IS_IDENTICAL) reduce 387) ((T_IS_NOT_EQUAL) reduce 387) ((T_IS_NOT_IDENTICAL) reduce 387) ((T_IS_SMALLER_OR_EQUAL) reduce 387) ((T_LOGICAL_AND) reduce 387) ((T_LOGICAL_OR) reduce 387) ((T_LOGICAL_XOR) reduce 387) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 387) ((T_SL) reduce 387) ((T_SPACESHIP) reduce 387) ((T_SR) reduce 387) (("[") reduce 510) (("]") reduce 387) (("^") reduce 387) (("{") reduce 510) (("|") reduce 387)) 12291 ((("%") reduce 435) (("*") reduce 435) (("+") reduce 435) (("-") reduce 435) ((".") reduce 435) (("/") reduce 435) (("<") reduce 435) ((">") reduce 435) (("?") reduce 435) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_BOOLEAN_AND) reduce 435) ((T_BOOLEAN_OR) reduce 435) ((T_COALESCE) reduce 435) ((T_INSTANCEOF) reduce 435) ((T_IS_EQUAL) reduce 435) ((T_IS_GREATER_OR_EQUAL) reduce 435) ((T_IS_IDENTICAL) reduce 435) ((T_IS_NOT_EQUAL) reduce 435) ((T_IS_NOT_IDENTICAL) reduce 435) ((T_IS_SMALLER_OR_EQUAL) reduce 435) ((T_LOGICAL_AND) reduce 435) ((T_LOGICAL_OR) reduce 435) ((T_LOGICAL_XOR) reduce 435) ((T_POW) reduce 435) ((T_SL) reduce 435) ((T_SPACESHIP) reduce 435) ((T_SR) reduce 435) (("]") reduce 435) (("^") reduce 435) (("|") reduce 435)) 12293 ((("%") reduce 476) (("*") reduce 476) (("+") reduce 476) (("-") reduce 476) ((".") reduce 476) (("/") reduce 476) (("<") reduce 476) ((">") reduce 476) (("?") reduce 476) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_BOOLEAN_AND) reduce 476) ((T_BOOLEAN_OR) reduce 476) ((T_COALESCE) reduce 476) ((T_INSTANCEOF) reduce 476) ((T_IS_EQUAL) reduce 476) ((T_IS_GREATER_OR_EQUAL) reduce 476) ((T_IS_IDENTICAL) reduce 476) ((T_IS_NOT_EQUAL) reduce 476) ((T_IS_NOT_IDENTICAL) reduce 476) ((T_IS_SMALLER_OR_EQUAL) reduce 476) ((T_LOGICAL_AND) reduce 476) ((T_LOGICAL_OR) reduce 476) ((T_LOGICAL_XOR) reduce 476) ((T_POW) reduce 476) ((T_SL) reduce 476) ((T_SPACESHIP) reduce 476) ((T_SR) reduce 476) (("]") reduce 476) (("^") reduce 476) (("|") reduce 476)) 12296 ((("%") reduce 579) (("*") reduce 579) (("+") reduce 579) (("-") reduce 579) ((".") reduce 579) (("/") reduce 579) (("<") reduce 579) ((">") reduce 579) (("?") reduce 579) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_BOOLEAN_AND) reduce 579) ((T_BOOLEAN_OR) reduce 579) ((T_COALESCE) reduce 579) ((T_INSTANCEOF) reduce 579) ((T_IS_EQUAL) reduce 579) ((T_IS_GREATER_OR_EQUAL) reduce 579) ((T_IS_IDENTICAL) reduce 579) ((T_IS_NOT_EQUAL) reduce 579) ((T_IS_NOT_IDENTICAL) reduce 579) ((T_IS_SMALLER_OR_EQUAL) reduce 579) ((T_LOGICAL_AND) reduce 579) ((T_LOGICAL_OR) reduce 579) ((T_LOGICAL_XOR) reduce 579) ((T_POW) reduce 579) ((T_SL) reduce 579) ((T_SPACESHIP) reduce 579) ((T_SR) reduce 579) (("]") reduce 579) (("^") reduce 579) (("|") reduce 579)) 12299 ((("%") reduce 576) (("*") reduce 576) (("+") reduce 576) (("-") reduce 576) ((".") reduce 576) (("/") reduce 576) (("<") reduce 576) ((">") reduce 576) (("?") reduce 576) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_BOOLEAN_AND) reduce 576) ((T_BOOLEAN_OR) reduce 576) ((T_COALESCE) reduce 576) ((T_INSTANCEOF) reduce 576) ((T_IS_EQUAL) reduce 576) ((T_IS_GREATER_OR_EQUAL) reduce 576) ((T_IS_IDENTICAL) reduce 576) ((T_IS_NOT_EQUAL) reduce 576) ((T_IS_NOT_IDENTICAL) reduce 576) ((T_IS_SMALLER_OR_EQUAL) reduce 576) ((T_LOGICAL_AND) reduce 576) ((T_LOGICAL_OR) reduce 576) ((T_LOGICAL_XOR) reduce 576) ((T_POW) reduce 576) ((T_SL) reduce 576) ((T_SPACESHIP) reduce 576) ((T_SR) reduce 576) (("]") reduce 576) (("^") reduce 576) (("|") reduce 576)) 12300 ((("%") reduce 429) (("*") reduce 429) (("+") reduce 429) (("-") reduce 429) ((".") reduce 429) (("/") reduce 429) (("<") reduce 429) ((">") reduce 429) (("?") reduce 429) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_BOOLEAN_AND) reduce 429) ((T_BOOLEAN_OR) reduce 429) ((T_COALESCE) reduce 429) ((T_INSTANCEOF) reduce 429) ((T_IS_EQUAL) reduce 429) ((T_IS_GREATER_OR_EQUAL) reduce 429) ((T_IS_IDENTICAL) reduce 429) ((T_IS_NOT_EQUAL) reduce 429) ((T_IS_NOT_IDENTICAL) reduce 429) ((T_IS_SMALLER_OR_EQUAL) reduce 429) ((T_LOGICAL_AND) reduce 429) ((T_LOGICAL_OR) reduce 429) ((T_LOGICAL_XOR) reduce 429) ((T_POW) shift) ((T_SL) reduce 429) ((T_SPACESHIP) reduce 429) ((T_SR) reduce 429) (("]") reduce 429) (("^") reduce 429) (("|") reduce 429)) 12301 ((("%") reduce 389) (("*") reduce 389) (("+") reduce 389) (("-") reduce 389) ((".") reduce 389) (("/") reduce 389) (("<") reduce 389) ((">") reduce 389) (("?") reduce 389) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_BOOLEAN_AND) reduce 389) ((T_BOOLEAN_OR) reduce 389) ((T_COALESCE) reduce 389) ((T_INSTANCEOF) reduce 389) ((T_IS_EQUAL) reduce 389) ((T_IS_GREATER_OR_EQUAL) reduce 389) ((T_IS_IDENTICAL) reduce 389) ((T_IS_NOT_EQUAL) reduce 389) ((T_IS_NOT_IDENTICAL) reduce 389) ((T_IS_SMALLER_OR_EQUAL) reduce 389) ((T_LOGICAL_AND) reduce 389) ((T_LOGICAL_OR) reduce 389) ((T_LOGICAL_XOR) reduce 389) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 389) ((T_SL) reduce 389) ((T_SPACESHIP) reduce 389) ((T_SR) reduce 389) (("[") reduce 510) (("]") reduce 389) (("^") reduce 389) (("{") reduce 510) (("|") reduce 389)) 12302 ((("%") reduce 372) (("*") reduce 372) (("+") reduce 372) (("-") reduce 372) ((".") reduce 372) (("/") reduce 372) (("<") reduce 372) ((">") reduce 372) (("?") reduce 372) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_BOOLEAN_AND) reduce 372) ((T_BOOLEAN_OR) reduce 372) ((T_COALESCE) reduce 372) ((T_INSTANCEOF) reduce 372) ((T_IS_EQUAL) reduce 372) ((T_IS_GREATER_OR_EQUAL) reduce 372) ((T_IS_IDENTICAL) reduce 372) ((T_IS_NOT_EQUAL) reduce 372) ((T_IS_NOT_IDENTICAL) reduce 372) ((T_IS_SMALLER_OR_EQUAL) reduce 372) ((T_LOGICAL_AND) reduce 372) ((T_LOGICAL_OR) reduce 372) ((T_LOGICAL_XOR) reduce 372) ((T_POW) reduce 372) ((T_SL) reduce 372) ((T_SPACESHIP) reduce 372) ((T_SR) reduce 372) (("]") reduce 372) (("^") reduce 372) (("|") reduce 372)) 12303 ((("%") reduce 433) (("*") reduce 433) (("+") reduce 433) (("-") reduce 433) ((".") reduce 433) (("/") reduce 433) (("<") reduce 433) ((">") reduce 433) (("?") reduce 433) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_BOOLEAN_AND) reduce 433) ((T_BOOLEAN_OR) reduce 433) ((T_COALESCE) reduce 433) ((T_INSTANCEOF) reduce 433) ((T_IS_EQUAL) reduce 433) ((T_IS_GREATER_OR_EQUAL) reduce 433) ((T_IS_IDENTICAL) reduce 433) ((T_IS_NOT_EQUAL) reduce 433) ((T_IS_NOT_IDENTICAL) reduce 433) ((T_IS_SMALLER_OR_EQUAL) reduce 433) ((T_LOGICAL_AND) reduce 433) ((T_LOGICAL_OR) reduce 433) ((T_LOGICAL_XOR) reduce 433) ((T_POW) shift) ((T_SL) reduce 433) ((T_SPACESHIP) reduce 433) ((T_SR) reduce 433) (("]") reduce 433) (("^") reduce 433) (("|") reduce 433)) 12304 ((("%") reduce 431) (("*") reduce 431) (("+") reduce 431) (("-") reduce 431) ((".") reduce 431) (("/") reduce 431) (("<") reduce 431) ((">") reduce 431) (("?") reduce 431) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_BOOLEAN_AND) reduce 431) ((T_BOOLEAN_OR) reduce 431) ((T_COALESCE) reduce 431) ((T_INSTANCEOF) reduce 431) ((T_IS_EQUAL) reduce 431) ((T_IS_GREATER_OR_EQUAL) reduce 431) ((T_IS_IDENTICAL) reduce 431) ((T_IS_NOT_EQUAL) reduce 431) ((T_IS_NOT_IDENTICAL) reduce 431) ((T_IS_SMALLER_OR_EQUAL) reduce 431) ((T_LOGICAL_AND) reduce 431) ((T_LOGICAL_OR) reduce 431) ((T_LOGICAL_XOR) reduce 431) ((T_POW) shift) ((T_SL) reduce 431) ((T_SPACESHIP) reduce 431) ((T_SR) reduce 431) (("]") reduce 431) (("^") reduce 431) (("|") reduce 431)) 12307 ((("%") reduce 482) (("(") reduce 482) (("*") reduce 482) (("+") reduce 482) (("-") reduce 482) ((".") reduce 482) (("/") reduce 482) (("<") reduce 482) ((">") reduce 482) (("?") reduce 482) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_BOOLEAN_AND) reduce 482) ((T_BOOLEAN_OR) reduce 482) ((T_COALESCE) reduce 482) ((T_INSTANCEOF) reduce 482) ((T_IS_EQUAL) reduce 482) ((T_IS_GREATER_OR_EQUAL) reduce 482) ((T_IS_IDENTICAL) reduce 482) ((T_IS_NOT_EQUAL) reduce 482) ((T_IS_NOT_IDENTICAL) reduce 482) ((T_IS_SMALLER_OR_EQUAL) reduce 482) ((T_LOGICAL_AND) reduce 482) ((T_LOGICAL_OR) reduce 482) ((T_LOGICAL_XOR) reduce 482) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 482) ((T_OBJECT_OPERATOR) reduce 482) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 482) ((T_POW) reduce 482) ((T_SL) reduce 482) ((T_SPACESHIP) reduce 482) ((T_SR) reduce 482) (("[") reduce 482) (("]") reduce 482) (("^") reduce 482) (("{") reduce 482) (("|") reduce 482)) 12308 ((("%") reduce 436) (("*") reduce 436) (("+") reduce 436) (("-") reduce 436) ((".") reduce 436) (("/") reduce 436) (("<") reduce 436) ((">") reduce 436) (("?") reduce 436) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_BOOLEAN_AND) reduce 436) ((T_BOOLEAN_OR) reduce 436) ((T_COALESCE) reduce 436) ((T_INSTANCEOF) reduce 436) ((T_IS_EQUAL) reduce 436) ((T_IS_GREATER_OR_EQUAL) reduce 436) ((T_IS_IDENTICAL) reduce 436) ((T_IS_NOT_EQUAL) reduce 436) ((T_IS_NOT_IDENTICAL) reduce 436) ((T_IS_SMALLER_OR_EQUAL) reduce 436) ((T_LOGICAL_AND) reduce 436) ((T_LOGICAL_OR) reduce 436) ((T_LOGICAL_XOR) reduce 436) ((T_POW) shift) ((T_SL) reduce 436) ((T_SPACESHIP) reduce 436) ((T_SR) reduce 436) (("]") reduce 436) (("^") reduce 436) (("|") reduce 436)) 12309 ((("%") reduce 409) (("*") reduce 409) (("+") reduce 409) (("-") reduce 409) ((".") reduce 409) (("/") reduce 409) (("<") reduce 409) ((">") reduce 409) (("?") reduce 409) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_BOOLEAN_AND) reduce 409) ((T_BOOLEAN_OR) reduce 409) ((T_COALESCE) reduce 409) ((T_INSTANCEOF) reduce 409) ((T_IS_EQUAL) reduce 409) ((T_IS_GREATER_OR_EQUAL) reduce 409) ((T_IS_IDENTICAL) reduce 409) ((T_IS_NOT_EQUAL) reduce 409) ((T_IS_NOT_IDENTICAL) reduce 409) ((T_IS_SMALLER_OR_EQUAL) reduce 409) ((T_LOGICAL_AND) reduce 409) ((T_LOGICAL_OR) reduce 409) ((T_LOGICAL_XOR) reduce 409) ((T_POW) shift) ((T_SL) reduce 409) ((T_SPACESHIP) reduce 409) ((T_SR) reduce 409) (("]") reduce 409) (("^") reduce 409) (("|") reduce 409)) 12310 ((("%") reduce 408) (("*") reduce 408) (("+") reduce 408) (("-") reduce 408) ((".") reduce 408) (("/") reduce 408) (("<") reduce 408) ((">") reduce 408) (("?") reduce 408) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_BOOLEAN_AND) reduce 408) ((T_BOOLEAN_OR) reduce 408) ((T_COALESCE) reduce 408) ((T_INSTANCEOF) reduce 408) ((T_IS_EQUAL) reduce 408) ((T_IS_GREATER_OR_EQUAL) reduce 408) ((T_IS_IDENTICAL) reduce 408) ((T_IS_NOT_EQUAL) reduce 408) ((T_IS_NOT_IDENTICAL) reduce 408) ((T_IS_SMALLER_OR_EQUAL) reduce 408) ((T_LOGICAL_AND) reduce 408) ((T_LOGICAL_OR) reduce 408) ((T_LOGICAL_XOR) reduce 408) ((T_POW) shift) ((T_SL) reduce 408) ((T_SPACESHIP) reduce 408) ((T_SR) reduce 408) (("]") reduce 408) (("^") reduce 408) (("|") reduce 408)) 12312 ((("%") reduce 422) (("(") reduce 517) (("*") reduce 422) (("+") reduce 422) (("-") reduce 422) ((".") reduce 422) (("/") reduce 422) (("<") reduce 422) ((">") reduce 422) (("?") reduce 422) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_BOOLEAN_AND) reduce 422) ((T_BOOLEAN_OR) reduce 422) ((T_COALESCE) reduce 422) ((T_INSTANCEOF) reduce 422) ((T_IS_EQUAL) reduce 422) ((T_IS_GREATER_OR_EQUAL) reduce 422) ((T_IS_IDENTICAL) reduce 422) ((T_IS_NOT_EQUAL) reduce 422) ((T_IS_NOT_IDENTICAL) reduce 422) ((T_IS_SMALLER_OR_EQUAL) reduce 422) ((T_LOGICAL_AND) reduce 422) ((T_LOGICAL_OR) reduce 422) ((T_LOGICAL_XOR) reduce 422) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 511) ((T_OBJECT_OPERATOR) reduce 511) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 511) ((T_POW) reduce 422) ((T_SL) reduce 422) ((T_SPACESHIP) reduce 422) ((T_SR) reduce 422) (("[") reduce 511) (("]") reduce 422) (("^") reduce 422) (("{") reduce 511) (("|") reduce 422)) 12313 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) (("=") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AND_EQUAL) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_COALESCE_EQUAL) reduce 531) ((T_CONCAT_EQUAL) reduce 531) ((T_DEC) reduce 531) ((T_DIV_EQUAL) reduce 531) ((T_INC) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_MINUS_EQUAL) reduce 531) ((T_MOD_EQUAL) reduce 531) ((T_MUL_EQUAL) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_OR_EQUAL) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_PLUS_EQUAL) reduce 531) ((T_POW) reduce 531) ((T_POW_EQUAL) reduce 531) ((T_SL) reduce 531) ((T_SL_EQUAL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) ((T_SR_EQUAL) reduce 531) ((T_XOR_EQUAL) reduce 531) (("[") reduce 531) (("]") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 12316 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) (("=") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AND_EQUAL) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_COALESCE_EQUAL) reduce 530) ((T_CONCAT_EQUAL) reduce 530) ((T_DEC) reduce 530) ((T_DIV_EQUAL) reduce 530) ((T_INC) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_MINUS_EQUAL) reduce 530) ((T_MOD_EQUAL) reduce 530) ((T_MUL_EQUAL) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_OR_EQUAL) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_PLUS_EQUAL) reduce 530) ((T_POW) reduce 530) ((T_POW_EQUAL) reduce 530) ((T_SL) reduce 530) ((T_SL_EQUAL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) ((T_SR_EQUAL) reduce 530) ((T_XOR_EQUAL) reduce 530) (("[") reduce 530) (("]") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 12318 ((("%") reduce 485) (("(") reduce 485) (("*") reduce 485) (("+") reduce 485) (("-") reduce 485) ((".") reduce 485) (("/") reduce 485) (("<") reduce 485) ((">") reduce 485) (("?") reduce 485) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_BOOLEAN_AND) reduce 485) ((T_BOOLEAN_OR) reduce 485) ((T_COALESCE) reduce 485) ((T_INSTANCEOF) reduce 485) ((T_IS_EQUAL) reduce 485) ((T_IS_GREATER_OR_EQUAL) reduce 485) ((T_IS_IDENTICAL) reduce 485) ((T_IS_NOT_EQUAL) reduce 485) ((T_IS_NOT_IDENTICAL) reduce 485) ((T_IS_SMALLER_OR_EQUAL) reduce 485) ((T_LOGICAL_AND) reduce 485) ((T_LOGICAL_OR) reduce 485) ((T_LOGICAL_XOR) reduce 485) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 485) ((T_OBJECT_OPERATOR) reduce 485) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 485) ((T_POW) reduce 485) ((T_SL) reduce 485) ((T_SPACESHIP) reduce 485) ((T_SR) reduce 485) (("[") reduce 485) (("]") reduce 485) (("^") reduce 485) (("{") reduce 485) (("|") reduce 485)) 12319 ((("%") reduce 410) (("*") reduce 410) (("+") reduce 410) (("-") reduce 410) ((".") reduce 410) (("/") reduce 410) (("<") reduce 410) ((">") reduce 410) (("?") reduce 410) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_BOOLEAN_AND) reduce 410) ((T_BOOLEAN_OR) reduce 410) ((T_COALESCE) reduce 410) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 410) ((T_IS_GREATER_OR_EQUAL) reduce 410) ((T_IS_IDENTICAL) reduce 410) ((T_IS_NOT_EQUAL) reduce 410) ((T_IS_NOT_IDENTICAL) reduce 410) ((T_IS_SMALLER_OR_EQUAL) reduce 410) ((T_LOGICAL_AND) reduce 410) ((T_LOGICAL_OR) reduce 410) ((T_LOGICAL_XOR) reduce 410) ((T_POW) shift) ((T_SL) reduce 410) ((T_SPACESHIP) reduce 410) ((T_SR) reduce 410) (("]") reduce 410) (("^") reduce 410) (("|") reduce 410)) 12948 ((("%") reduce 540) (("*") reduce 540) (("+") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540) (("}") reduce 540)) 12949 ((("%") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544) (("}") reduce 544)) 12950 ((("%") reduce 537) (("*") reduce 537) (("+") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537) (("}") reduce 537)) 12951 ((("%") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546) (("}") reduce 546)) 12954 ((("%") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545) (("}") reduce 545)) 12955 ((("%") reduce 538) (("*") reduce 538) (("+") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538) (("}") reduce 538)) 12957 ((("%") reduce 539) (("*") reduce 539) (("+") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539) (("}") reduce 539)) 12959 ((("%") reduce 474) (("*") reduce 474) (("+") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474) (("}") reduce 474)) 12960 ((("%") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531) (("}") reduce 531)) 12963 ((("%") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530) (("}") reduce 530)) 12964 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 426) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 426) ((T_LOGICAL_OR) reduce 426) ((T_LOGICAL_XOR) reduce 426) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 426)) 12965 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 390) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) reduce 390) ((T_COALESCE) reduce 390) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 390) ((T_LOGICAL_OR) reduce 390) ((T_LOGICAL_XOR) reduce 390) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 390)) 12966 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 391) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 391) ((T_BOOLEAN_OR) reduce 391) ((T_COALESCE) reduce 391) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 391) ((T_LOGICAL_OR) reduce 391) ((T_LOGICAL_XOR) reduce 391) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 391)) 12967 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 396) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_BOOLEAN_AND) reduce 396) ((T_BOOLEAN_OR) reduce 396) ((T_COALESCE) reduce 396) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 396) ((T_LOGICAL_OR) reduce 396) ((T_LOGICAL_XOR) reduce 396) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 396) (("|") reduce 396) (("}") reduce 396)) 12968 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 397) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_BOOLEAN_AND) reduce 397) ((T_BOOLEAN_OR) reduce 397) ((T_COALESCE) reduce 397) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 397) ((T_LOGICAL_OR) reduce 397) ((T_LOGICAL_XOR) reduce 397) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 397) (("|") reduce 397) (("}") reduce 397)) 12972 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 424) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 424) ((T_LOGICAL_OR) reduce 424) ((T_LOGICAL_XOR) reduce 424) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 424)) 12973 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 425) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 425) ((T_LOGICAL_OR) reduce 425) ((T_LOGICAL_XOR) reduce 425) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 425)) 12974 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 418) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_BOOLEAN_AND) reduce 418) ((T_BOOLEAN_OR) reduce 418) ((T_COALESCE) reduce 418) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 418) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 418) ((T_IS_NOT_EQUAL) reduce 418) ((T_IS_NOT_IDENTICAL) reduce 418) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 418) ((T_LOGICAL_OR) reduce 418) ((T_LOGICAL_XOR) reduce 418) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 418) ((T_SR) shift) (("^") reduce 418) (("|") reduce 418) (("}") reduce 418)) 12975 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 416) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_BOOLEAN_AND) reduce 416) ((T_BOOLEAN_OR) reduce 416) ((T_COALESCE) reduce 416) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 416) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 416) ((T_IS_NOT_EQUAL) reduce 416) ((T_IS_NOT_IDENTICAL) reduce 416) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 416) ((T_LOGICAL_OR) reduce 416) ((T_LOGICAL_XOR) reduce 416) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 416) ((T_SR) shift) (("^") reduce 416) (("|") reduce 416) (("}") reduce 416)) 12976 ((("%") reduce 404) (("*") reduce 404) (("+") reduce 404) (("-") reduce 404) ((".") reduce 404) (("/") reduce 404) (("<") reduce 404) ((">") reduce 404) (("?") reduce 404) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_BOOLEAN_AND) reduce 404) ((T_BOOLEAN_OR) reduce 404) ((T_COALESCE) reduce 404) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 404) ((T_IS_GREATER_OR_EQUAL) reduce 404) ((T_IS_IDENTICAL) reduce 404) ((T_IS_NOT_EQUAL) reduce 404) ((T_IS_NOT_IDENTICAL) reduce 404) ((T_IS_SMALLER_OR_EQUAL) reduce 404) ((T_LOGICAL_AND) reduce 404) ((T_LOGICAL_OR) reduce 404) ((T_LOGICAL_XOR) reduce 404) ((T_POW) shift) ((T_SL) reduce 404) ((T_SPACESHIP) reduce 404) ((T_SR) reduce 404) (("^") reduce 404) (("|") reduce 404) (("}") reduce 404)) 12977 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 399) (("/") shift) (("<") reduce 399) ((">") reduce 399) (("?") reduce 399) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_BOOLEAN_AND) reduce 399) ((T_BOOLEAN_OR) reduce 399) ((T_COALESCE) reduce 399) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 399) ((T_IS_GREATER_OR_EQUAL) reduce 399) ((T_IS_IDENTICAL) reduce 399) ((T_IS_NOT_EQUAL) reduce 399) ((T_IS_NOT_IDENTICAL) reduce 399) ((T_IS_SMALLER_OR_EQUAL) reduce 399) ((T_LOGICAL_AND) reduce 399) ((T_LOGICAL_OR) reduce 399) ((T_LOGICAL_XOR) reduce 399) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 399) ((T_SR) shift) (("^") reduce 399) (("|") reduce 399) (("}") reduce 399)) 12978 ((("%") shift) (("*") shift) (("+") reduce 401) (("-") reduce 401) ((".") reduce 401) (("/") shift) (("<") reduce 401) ((">") reduce 401) (("?") reduce 401) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_BOOLEAN_AND) reduce 401) ((T_BOOLEAN_OR) reduce 401) ((T_COALESCE) reduce 401) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 401) ((T_IS_GREATER_OR_EQUAL) reduce 401) ((T_IS_IDENTICAL) reduce 401) ((T_IS_NOT_EQUAL) reduce 401) ((T_IS_NOT_IDENTICAL) reduce 401) ((T_IS_SMALLER_OR_EQUAL) reduce 401) ((T_LOGICAL_AND) reduce 401) ((T_LOGICAL_OR) reduce 401) ((T_LOGICAL_XOR) reduce 401) ((T_POW) shift) ((T_SL) reduce 401) ((T_SPACESHIP) reduce 401) ((T_SR) reduce 401) (("^") reduce 401) (("|") reduce 401) (("}") reduce 401)) 12979 ((("%") shift) (("*") shift) (("+") reduce 400) (("-") reduce 400) ((".") reduce 400) (("/") shift) (("<") reduce 400) ((">") reduce 400) (("?") reduce 400) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_BOOLEAN_AND) reduce 400) ((T_BOOLEAN_OR) reduce 400) ((T_COALESCE) reduce 400) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 400) ((T_IS_GREATER_OR_EQUAL) reduce 400) ((T_IS_IDENTICAL) reduce 400) ((T_IS_NOT_EQUAL) reduce 400) ((T_IS_NOT_IDENTICAL) reduce 400) ((T_IS_SMALLER_OR_EQUAL) reduce 400) ((T_LOGICAL_AND) reduce 400) ((T_LOGICAL_OR) reduce 400) ((T_LOGICAL_XOR) reduce 400) ((T_POW) shift) ((T_SL) reduce 400) ((T_SPACESHIP) reduce 400) ((T_SR) reduce 400) (("^") reduce 400) (("|") reduce 400) (("}") reduce 400)) 12980 ((("%") reduce 402) (("*") reduce 402) (("+") reduce 402) (("-") reduce 402) ((".") reduce 402) (("/") reduce 402) (("<") reduce 402) ((">") reduce 402) (("?") reduce 402) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_BOOLEAN_AND) reduce 402) ((T_BOOLEAN_OR) reduce 402) ((T_COALESCE) reduce 402) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 402) ((T_IS_GREATER_OR_EQUAL) reduce 402) ((T_IS_IDENTICAL) reduce 402) ((T_IS_NOT_EQUAL) reduce 402) ((T_IS_NOT_IDENTICAL) reduce 402) ((T_IS_SMALLER_OR_EQUAL) reduce 402) ((T_LOGICAL_AND) reduce 402) ((T_LOGICAL_OR) reduce 402) ((T_LOGICAL_XOR) reduce 402) ((T_POW) shift) ((T_SL) reduce 402) ((T_SPACESHIP) reduce 402) ((T_SR) reduce 402) (("^") reduce 402) (("|") reduce 402) (("}") reduce 402)) 12981 ((("%") reduce 405) (("*") reduce 405) (("+") reduce 405) (("-") reduce 405) ((".") reduce 405) (("/") reduce 405) (("<") reduce 405) ((">") reduce 405) (("?") reduce 405) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_BOOLEAN_AND) reduce 405) ((T_BOOLEAN_OR) reduce 405) ((T_COALESCE) reduce 405) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 405) ((T_IS_GREATER_OR_EQUAL) reduce 405) ((T_IS_IDENTICAL) reduce 405) ((T_IS_NOT_EQUAL) reduce 405) ((T_IS_NOT_IDENTICAL) reduce 405) ((T_IS_SMALLER_OR_EQUAL) reduce 405) ((T_LOGICAL_AND) reduce 405) ((T_LOGICAL_OR) reduce 405) ((T_LOGICAL_XOR) reduce 405) ((T_POW) shift) ((T_SL) reduce 405) ((T_SPACESHIP) reduce 405) ((T_SR) reduce 405) (("^") reduce 405) (("|") reduce 405) (("}") reduce 405)) 12983 ((("%") reduce 73) (("(") reduce 73) (("*") reduce 73) (("+") reduce 73) (("-") reduce 73) ((".") reduce 73) (("/") reduce 73) (("<") reduce 73) ((">") reduce 73) (("?") reduce 73) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_BOOLEAN_AND) reduce 73) ((T_BOOLEAN_OR) reduce 73) ((T_COALESCE) reduce 73) ((T_INSTANCEOF) reduce 73) ((T_IS_EQUAL) reduce 73) ((T_IS_GREATER_OR_EQUAL) reduce 73) ((T_IS_IDENTICAL) reduce 73) ((T_IS_NOT_EQUAL) reduce 73) ((T_IS_NOT_IDENTICAL) reduce 73) ((T_IS_SMALLER_OR_EQUAL) reduce 73) ((T_LOGICAL_AND) reduce 73) ((T_LOGICAL_OR) reduce 73) ((T_LOGICAL_XOR) reduce 73) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 73) ((T_OBJECT_OPERATOR) reduce 73) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 73) ((T_POW) reduce 73) ((T_SL) reduce 73) ((T_SPACESHIP) reduce 73) ((T_SR) reduce 73) (("[") reduce 73) (("^") reduce 73) (("{") reduce 73) (("|") reduce 73) (("}") reduce 73)) 12984 ((("%") reduce 52) (("(") reduce 52) (("*") reduce 52) (("+") reduce 52) (("-") reduce 52) ((".") reduce 52) (("/") reduce 52) (("<") reduce 52) ((">") reduce 52) (("?") reduce 52) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_BOOLEAN_AND) reduce 52) ((T_BOOLEAN_OR) reduce 52) ((T_COALESCE) reduce 52) ((T_INSTANCEOF) reduce 52) ((T_IS_EQUAL) reduce 52) ((T_IS_GREATER_OR_EQUAL) reduce 52) ((T_IS_IDENTICAL) reduce 52) ((T_IS_NOT_EQUAL) reduce 52) ((T_IS_NOT_IDENTICAL) reduce 52) ((T_IS_SMALLER_OR_EQUAL) reduce 52) ((T_LOGICAL_AND) reduce 52) ((T_LOGICAL_OR) reduce 52) ((T_LOGICAL_XOR) reduce 52) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 52) ((T_OBJECT_OPERATOR) reduce 52) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 52) ((T_POW) reduce 52) ((T_SL) reduce 52) ((T_SPACESHIP) reduce 52) ((T_SR) reduce 52) (("[") reduce 52) (("^") reduce 52) (("{") reduce 52) (("|") reduce 52) (("}") reduce 52)) 12985 ((("%") reduce 27) (("(") reduce 27) (("*") reduce 27) (("+") reduce 27) (("-") reduce 27) ((".") reduce 27) (("/") reduce 27) (("<") reduce 27) ((">") reduce 27) (("?") reduce 27) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_BOOLEAN_AND) reduce 27) ((T_BOOLEAN_OR) reduce 27) ((T_COALESCE) reduce 27) ((T_INSTANCEOF) reduce 27) ((T_IS_EQUAL) reduce 27) ((T_IS_GREATER_OR_EQUAL) reduce 27) ((T_IS_IDENTICAL) reduce 27) ((T_IS_NOT_EQUAL) reduce 27) ((T_IS_NOT_IDENTICAL) reduce 27) ((T_IS_SMALLER_OR_EQUAL) reduce 27) ((T_LOGICAL_AND) reduce 27) ((T_LOGICAL_OR) reduce 27) ((T_LOGICAL_XOR) reduce 27) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 27) ((T_OBJECT_OPERATOR) reduce 27) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 27) ((T_POW) reduce 27) ((T_SL) reduce 27) ((T_SPACESHIP) reduce 27) ((T_SR) reduce 27) (("[") reduce 27) (("^") reduce 27) (("{") reduce 27) (("|") reduce 27) (("}") reduce 27)) 12986 ((("%") reduce 51) (("(") reduce 51) (("*") reduce 51) (("+") reduce 51) (("-") reduce 51) ((".") reduce 51) (("/") reduce 51) (("<") reduce 51) ((">") reduce 51) (("?") reduce 51) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_BOOLEAN_AND) reduce 51) ((T_BOOLEAN_OR) reduce 51) ((T_COALESCE) reduce 51) ((T_INSTANCEOF) reduce 51) ((T_IS_EQUAL) reduce 51) ((T_IS_GREATER_OR_EQUAL) reduce 51) ((T_IS_IDENTICAL) reduce 51) ((T_IS_NOT_EQUAL) reduce 51) ((T_IS_NOT_IDENTICAL) reduce 51) ((T_IS_SMALLER_OR_EQUAL) reduce 51) ((T_LOGICAL_AND) reduce 51) ((T_LOGICAL_OR) reduce 51) ((T_LOGICAL_XOR) reduce 51) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 51) ((T_OBJECT_OPERATOR) reduce 51) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 51) ((T_POW) reduce 51) ((T_SL) reduce 51) ((T_SPACESHIP) reduce 51) ((T_SR) reduce 51) (("[") reduce 51) (("^") reduce 51) (("{") reduce 51) (("|") reduce 51) (("}") reduce 51)) 12987 ((("%") reduce 53) (("(") reduce 53) (("*") reduce 53) (("+") reduce 53) (("-") reduce 53) ((".") reduce 53) (("/") reduce 53) (("<") reduce 53) ((">") reduce 53) (("?") reduce 53) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_BOOLEAN_AND) reduce 53) ((T_BOOLEAN_OR) reduce 53) ((T_COALESCE) reduce 53) ((T_INSTANCEOF) reduce 53) ((T_IS_EQUAL) reduce 53) ((T_IS_GREATER_OR_EQUAL) reduce 53) ((T_IS_IDENTICAL) reduce 53) ((T_IS_NOT_EQUAL) reduce 53) ((T_IS_NOT_IDENTICAL) reduce 53) ((T_IS_SMALLER_OR_EQUAL) reduce 53) ((T_LOGICAL_AND) reduce 53) ((T_LOGICAL_OR) reduce 53) ((T_LOGICAL_XOR) reduce 53) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 53) ((T_OBJECT_OPERATOR) reduce 53) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 53) ((T_POW) reduce 53) ((T_SL) reduce 53) ((T_SPACESHIP) reduce 53) ((T_SR) reduce 53) (("[") reduce 53) (("^") reduce 53) (("{") reduce 53) (("|") reduce 53) (("}") reduce 53)) 12988 ((("%") reduce 49) (("(") reduce 49) (("*") reduce 49) (("+") reduce 49) (("-") reduce 49) ((".") reduce 49) (("/") reduce 49) (("<") reduce 49) ((">") reduce 49) (("?") reduce 49) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_BOOLEAN_AND) reduce 49) ((T_BOOLEAN_OR) reduce 49) ((T_COALESCE) reduce 49) ((T_INSTANCEOF) reduce 49) ((T_IS_EQUAL) reduce 49) ((T_IS_GREATER_OR_EQUAL) reduce 49) ((T_IS_IDENTICAL) reduce 49) ((T_IS_NOT_EQUAL) reduce 49) ((T_IS_NOT_IDENTICAL) reduce 49) ((T_IS_SMALLER_OR_EQUAL) reduce 49) ((T_LOGICAL_AND) reduce 49) ((T_LOGICAL_OR) reduce 49) ((T_LOGICAL_XOR) reduce 49) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 49) ((T_OBJECT_OPERATOR) reduce 49) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 49) ((T_POW) reduce 49) ((T_SL) reduce 49) ((T_SPACESHIP) reduce 49) ((T_SR) reduce 49) (("[") reduce 49) (("^") reduce 49) (("{") reduce 49) (("|") reduce 49) (("}") reduce 49)) 12989 ((("%") reduce 29) (("(") reduce 29) (("*") reduce 29) (("+") reduce 29) (("-") reduce 29) ((".") reduce 29) (("/") reduce 29) (("<") reduce 29) ((">") reduce 29) (("?") reduce 29) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_BOOLEAN_AND) reduce 29) ((T_BOOLEAN_OR) reduce 29) ((T_COALESCE) reduce 29) ((T_INSTANCEOF) reduce 29) ((T_IS_EQUAL) reduce 29) ((T_IS_GREATER_OR_EQUAL) reduce 29) ((T_IS_IDENTICAL) reduce 29) ((T_IS_NOT_EQUAL) reduce 29) ((T_IS_NOT_IDENTICAL) reduce 29) ((T_IS_SMALLER_OR_EQUAL) reduce 29) ((T_LOGICAL_AND) reduce 29) ((T_LOGICAL_OR) reduce 29) ((T_LOGICAL_XOR) reduce 29) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 29) ((T_OBJECT_OPERATOR) reduce 29) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 29) ((T_POW) reduce 29) ((T_SL) reduce 29) ((T_SPACESHIP) reduce 29) ((T_SR) reduce 29) (("[") reduce 29) (("^") reduce 29) (("{") reduce 29) (("|") reduce 29) (("}") reduce 29)) 12990 ((("%") reduce 59) (("(") reduce 59) (("*") reduce 59) (("+") reduce 59) (("-") reduce 59) ((".") reduce 59) (("/") reduce 59) (("<") reduce 59) ((">") reduce 59) (("?") reduce 59) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_BOOLEAN_AND) reduce 59) ((T_BOOLEAN_OR) reduce 59) ((T_COALESCE) reduce 59) ((T_INSTANCEOF) reduce 59) ((T_IS_EQUAL) reduce 59) ((T_IS_GREATER_OR_EQUAL) reduce 59) ((T_IS_IDENTICAL) reduce 59) ((T_IS_NOT_EQUAL) reduce 59) ((T_IS_NOT_IDENTICAL) reduce 59) ((T_IS_SMALLER_OR_EQUAL) reduce 59) ((T_LOGICAL_AND) reduce 59) ((T_LOGICAL_OR) reduce 59) ((T_LOGICAL_XOR) reduce 59) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 59) ((T_OBJECT_OPERATOR) reduce 59) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 59) ((T_POW) reduce 59) ((T_SL) reduce 59) ((T_SPACESHIP) reduce 59) ((T_SR) reduce 59) (("[") reduce 59) (("^") reduce 59) (("{") reduce 59) (("|") reduce 59) (("}") reduce 59)) 12991 ((("%") reduce 60) (("(") reduce 60) (("*") reduce 60) (("+") reduce 60) (("-") reduce 60) ((".") reduce 60) (("/") reduce 60) (("<") reduce 60) ((">") reduce 60) (("?") reduce 60) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_BOOLEAN_AND) reduce 60) ((T_BOOLEAN_OR) reduce 60) ((T_COALESCE) reduce 60) ((T_INSTANCEOF) reduce 60) ((T_IS_EQUAL) reduce 60) ((T_IS_GREATER_OR_EQUAL) reduce 60) ((T_IS_IDENTICAL) reduce 60) ((T_IS_NOT_EQUAL) reduce 60) ((T_IS_NOT_IDENTICAL) reduce 60) ((T_IS_SMALLER_OR_EQUAL) reduce 60) ((T_LOGICAL_AND) reduce 60) ((T_LOGICAL_OR) reduce 60) ((T_LOGICAL_XOR) reduce 60) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 60) ((T_OBJECT_OPERATOR) reduce 60) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 60) ((T_POW) reduce 60) ((T_SL) reduce 60) ((T_SPACESHIP) reduce 60) ((T_SR) reduce 60) (("[") reduce 60) (("^") reduce 60) (("{") reduce 60) (("|") reduce 60) (("}") reduce 60)) 12992 ((("%") reduce 11) (("(") reduce 11) (("*") reduce 11) (("+") reduce 11) (("-") reduce 11) ((".") reduce 11) (("/") reduce 11) (("<") reduce 11) ((">") reduce 11) (("?") reduce 11) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_BOOLEAN_AND) reduce 11) ((T_BOOLEAN_OR) reduce 11) ((T_COALESCE) reduce 11) ((T_INSTANCEOF) reduce 11) ((T_IS_EQUAL) reduce 11) ((T_IS_GREATER_OR_EQUAL) reduce 11) ((T_IS_IDENTICAL) reduce 11) ((T_IS_NOT_EQUAL) reduce 11) ((T_IS_NOT_IDENTICAL) reduce 11) ((T_IS_SMALLER_OR_EQUAL) reduce 11) ((T_LOGICAL_AND) reduce 11) ((T_LOGICAL_OR) reduce 11) ((T_LOGICAL_XOR) reduce 11) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 11) ((T_OBJECT_OPERATOR) reduce 11) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 11) ((T_POW) reduce 11) ((T_SL) reduce 11) ((T_SPACESHIP) reduce 11) ((T_SR) reduce 11) (("[") reduce 11) (("^") reduce 11) (("{") reduce 11) (("|") reduce 11) (("}") reduce 11)) 12993 ((("%") reduce 42) (("(") reduce 42) (("*") reduce 42) (("+") reduce 42) (("-") reduce 42) ((".") reduce 42) (("/") reduce 42) (("<") reduce 42) ((">") reduce 42) (("?") reduce 42) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_BOOLEAN_AND) reduce 42) ((T_BOOLEAN_OR) reduce 42) ((T_COALESCE) reduce 42) ((T_INSTANCEOF) reduce 42) ((T_IS_EQUAL) reduce 42) ((T_IS_GREATER_OR_EQUAL) reduce 42) ((T_IS_IDENTICAL) reduce 42) ((T_IS_NOT_EQUAL) reduce 42) ((T_IS_NOT_IDENTICAL) reduce 42) ((T_IS_SMALLER_OR_EQUAL) reduce 42) ((T_LOGICAL_AND) reduce 42) ((T_LOGICAL_OR) reduce 42) ((T_LOGICAL_XOR) reduce 42) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 42) ((T_OBJECT_OPERATOR) reduce 42) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 42) ((T_POW) reduce 42) ((T_SL) reduce 42) ((T_SPACESHIP) reduce 42) ((T_SR) reduce 42) (("[") reduce 42) (("^") reduce 42) (("{") reduce 42) (("|") reduce 42) (("}") reduce 42)) 12994 ((("%") reduce 39) (("(") reduce 39) (("*") reduce 39) (("+") reduce 39) (("-") reduce 39) ((".") reduce 39) (("/") reduce 39) (("<") reduce 39) ((">") reduce 39) (("?") reduce 39) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_BOOLEAN_AND) reduce 39) ((T_BOOLEAN_OR) reduce 39) ((T_COALESCE) reduce 39) ((T_INSTANCEOF) reduce 39) ((T_IS_EQUAL) reduce 39) ((T_IS_GREATER_OR_EQUAL) reduce 39) ((T_IS_IDENTICAL) reduce 39) ((T_IS_NOT_EQUAL) reduce 39) ((T_IS_NOT_IDENTICAL) reduce 39) ((T_IS_SMALLER_OR_EQUAL) reduce 39) ((T_LOGICAL_AND) reduce 39) ((T_LOGICAL_OR) reduce 39) ((T_LOGICAL_XOR) reduce 39) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 39) ((T_OBJECT_OPERATOR) reduce 39) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 39) ((T_POW) reduce 39) ((T_SL) reduce 39) ((T_SPACESHIP) reduce 39) ((T_SR) reduce 39) (("[") reduce 39) (("^") reduce 39) (("{") reduce 39) (("|") reduce 39) (("}") reduce 39)) 12995 ((("%") reduce 25) (("(") reduce 25) (("*") reduce 25) (("+") reduce 25) (("-") reduce 25) ((".") reduce 25) (("/") reduce 25) (("<") reduce 25) ((">") reduce 25) (("?") reduce 25) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_BOOLEAN_AND) reduce 25) ((T_BOOLEAN_OR) reduce 25) ((T_COALESCE) reduce 25) ((T_INSTANCEOF) reduce 25) ((T_IS_EQUAL) reduce 25) ((T_IS_GREATER_OR_EQUAL) reduce 25) ((T_IS_IDENTICAL) reduce 25) ((T_IS_NOT_EQUAL) reduce 25) ((T_IS_NOT_IDENTICAL) reduce 25) ((T_IS_SMALLER_OR_EQUAL) reduce 25) ((T_LOGICAL_AND) reduce 25) ((T_LOGICAL_OR) reduce 25) ((T_LOGICAL_XOR) reduce 25) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 25) ((T_OBJECT_OPERATOR) reduce 25) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 25) ((T_POW) reduce 25) ((T_SL) reduce 25) ((T_SPACESHIP) reduce 25) ((T_SR) reduce 25) (("[") reduce 25) (("^") reduce 25) (("{") reduce 25) (("|") reduce 25) (("}") reduce 25)) 12996 ((("%") reduce 50) (("(") reduce 50) (("*") reduce 50) (("+") reduce 50) (("-") reduce 50) ((".") reduce 50) (("/") reduce 50) (("<") reduce 50) ((">") reduce 50) (("?") reduce 50) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_BOOLEAN_AND) reduce 50) ((T_BOOLEAN_OR) reduce 50) ((T_COALESCE) reduce 50) ((T_INSTANCEOF) reduce 50) ((T_IS_EQUAL) reduce 50) ((T_IS_GREATER_OR_EQUAL) reduce 50) ((T_IS_IDENTICAL) reduce 50) ((T_IS_NOT_EQUAL) reduce 50) ((T_IS_NOT_IDENTICAL) reduce 50) ((T_IS_SMALLER_OR_EQUAL) reduce 50) ((T_LOGICAL_AND) reduce 50) ((T_LOGICAL_OR) reduce 50) ((T_LOGICAL_XOR) reduce 50) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 50) ((T_OBJECT_OPERATOR) reduce 50) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 50) ((T_POW) reduce 50) ((T_SL) reduce 50) ((T_SPACESHIP) reduce 50) ((T_SR) reduce 50) (("[") reduce 50) (("^") reduce 50) (("{") reduce 50) (("|") reduce 50) (("}") reduce 50)) 12997 ((("%") reduce 66) (("(") reduce 66) (("*") reduce 66) (("+") reduce 66) (("-") reduce 66) ((".") reduce 66) (("/") reduce 66) (("<") reduce 66) ((">") reduce 66) (("?") reduce 66) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_BOOLEAN_AND) reduce 66) ((T_BOOLEAN_OR) reduce 66) ((T_COALESCE) reduce 66) ((T_INSTANCEOF) reduce 66) ((T_IS_EQUAL) reduce 66) ((T_IS_GREATER_OR_EQUAL) reduce 66) ((T_IS_IDENTICAL) reduce 66) ((T_IS_NOT_EQUAL) reduce 66) ((T_IS_NOT_IDENTICAL) reduce 66) ((T_IS_SMALLER_OR_EQUAL) reduce 66) ((T_LOGICAL_AND) reduce 66) ((T_LOGICAL_OR) reduce 66) ((T_LOGICAL_XOR) reduce 66) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 66) ((T_OBJECT_OPERATOR) reduce 66) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 66) ((T_POW) reduce 66) ((T_SL) reduce 66) ((T_SPACESHIP) reduce 66) ((T_SR) reduce 66) (("[") reduce 66) (("^") reduce 66) (("{") reduce 66) (("|") reduce 66) (("}") reduce 66)) 12998 ((("%") reduce 18) (("(") reduce 18) (("*") reduce 18) (("+") reduce 18) (("-") reduce 18) ((".") reduce 18) (("/") reduce 18) (("<") reduce 18) ((">") reduce 18) (("?") reduce 18) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_BOOLEAN_AND) reduce 18) ((T_BOOLEAN_OR) reduce 18) ((T_COALESCE) reduce 18) ((T_INSTANCEOF) reduce 18) ((T_IS_EQUAL) reduce 18) ((T_IS_GREATER_OR_EQUAL) reduce 18) ((T_IS_IDENTICAL) reduce 18) ((T_IS_NOT_EQUAL) reduce 18) ((T_IS_NOT_IDENTICAL) reduce 18) ((T_IS_SMALLER_OR_EQUAL) reduce 18) ((T_LOGICAL_AND) reduce 18) ((T_LOGICAL_OR) reduce 18) ((T_LOGICAL_XOR) reduce 18) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 18) ((T_OBJECT_OPERATOR) reduce 18) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 18) ((T_POW) reduce 18) ((T_SL) reduce 18) ((T_SPACESHIP) reduce 18) ((T_SR) reduce 18) (("[") reduce 18) (("^") reduce 18) (("{") reduce 18) (("|") reduce 18) (("}") reduce 18)) 12999 ((("%") reduce 17) (("(") reduce 17) (("*") reduce 17) (("+") reduce 17) (("-") reduce 17) ((".") reduce 17) (("/") reduce 17) (("<") reduce 17) ((">") reduce 17) (("?") reduce 17) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_BOOLEAN_AND) reduce 17) ((T_BOOLEAN_OR) reduce 17) ((T_COALESCE) reduce 17) ((T_INSTANCEOF) reduce 17) ((T_IS_EQUAL) reduce 17) ((T_IS_GREATER_OR_EQUAL) reduce 17) ((T_IS_IDENTICAL) reduce 17) ((T_IS_NOT_EQUAL) reduce 17) ((T_IS_NOT_IDENTICAL) reduce 17) ((T_IS_SMALLER_OR_EQUAL) reduce 17) ((T_LOGICAL_AND) reduce 17) ((T_LOGICAL_OR) reduce 17) ((T_LOGICAL_XOR) reduce 17) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 17) ((T_OBJECT_OPERATOR) reduce 17) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 17) ((T_POW) reduce 17) ((T_SL) reduce 17) ((T_SPACESHIP) reduce 17) ((T_SR) reduce 17) (("[") reduce 17) (("^") reduce 17) (("{") reduce 17) (("|") reduce 17) (("}") reduce 17)) 13000 ((("%") reduce 15) (("(") reduce 15) (("*") reduce 15) (("+") reduce 15) (("-") reduce 15) ((".") reduce 15) (("/") reduce 15) (("<") reduce 15) ((">") reduce 15) (("?") reduce 15) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_BOOLEAN_AND) reduce 15) ((T_BOOLEAN_OR) reduce 15) ((T_COALESCE) reduce 15) ((T_INSTANCEOF) reduce 15) ((T_IS_EQUAL) reduce 15) ((T_IS_GREATER_OR_EQUAL) reduce 15) ((T_IS_IDENTICAL) reduce 15) ((T_IS_NOT_EQUAL) reduce 15) ((T_IS_NOT_IDENTICAL) reduce 15) ((T_IS_SMALLER_OR_EQUAL) reduce 15) ((T_LOGICAL_AND) reduce 15) ((T_LOGICAL_OR) reduce 15) ((T_LOGICAL_XOR) reduce 15) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 15) ((T_OBJECT_OPERATOR) reduce 15) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 15) ((T_POW) reduce 15) ((T_SL) reduce 15) ((T_SPACESHIP) reduce 15) ((T_SR) reduce 15) (("[") reduce 15) (("^") reduce 15) (("{") reduce 15) (("|") reduce 15) (("}") reduce 15)) 13001 ((("%") reduce 14) (("(") reduce 14) (("*") reduce 14) (("+") reduce 14) (("-") reduce 14) ((".") reduce 14) (("/") reduce 14) (("<") reduce 14) ((">") reduce 14) (("?") reduce 14) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_BOOLEAN_AND) reduce 14) ((T_BOOLEAN_OR) reduce 14) ((T_COALESCE) reduce 14) ((T_INSTANCEOF) reduce 14) ((T_IS_EQUAL) reduce 14) ((T_IS_GREATER_OR_EQUAL) reduce 14) ((T_IS_IDENTICAL) reduce 14) ((T_IS_NOT_EQUAL) reduce 14) ((T_IS_NOT_IDENTICAL) reduce 14) ((T_IS_SMALLER_OR_EQUAL) reduce 14) ((T_LOGICAL_AND) reduce 14) ((T_LOGICAL_OR) reduce 14) ((T_LOGICAL_XOR) reduce 14) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 14) ((T_OBJECT_OPERATOR) reduce 14) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 14) ((T_POW) reduce 14) ((T_SL) reduce 14) ((T_SPACESHIP) reduce 14) ((T_SR) reduce 14) (("[") reduce 14) (("^") reduce 14) (("{") reduce 14) (("|") reduce 14) (("}") reduce 14)) 13002 ((("%") reduce 38) (("(") reduce 38) (("*") reduce 38) (("+") reduce 38) (("-") reduce 38) ((".") reduce 38) (("/") reduce 38) (("<") reduce 38) ((">") reduce 38) (("?") reduce 38) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_BOOLEAN_AND) reduce 38) ((T_BOOLEAN_OR) reduce 38) ((T_COALESCE) reduce 38) ((T_INSTANCEOF) reduce 38) ((T_IS_EQUAL) reduce 38) ((T_IS_GREATER_OR_EQUAL) reduce 38) ((T_IS_IDENTICAL) reduce 38) ((T_IS_NOT_EQUAL) reduce 38) ((T_IS_NOT_IDENTICAL) reduce 38) ((T_IS_SMALLER_OR_EQUAL) reduce 38) ((T_LOGICAL_AND) reduce 38) ((T_LOGICAL_OR) reduce 38) ((T_LOGICAL_XOR) reduce 38) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 38) ((T_OBJECT_OPERATOR) reduce 38) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 38) ((T_POW) reduce 38) ((T_SL) reduce 38) ((T_SPACESHIP) reduce 38) ((T_SR) reduce 38) (("[") reduce 38) (("^") reduce 38) (("{") reduce 38) (("|") reduce 38) (("}") reduce 38)) 13003 ((("%") reduce 26) (("(") reduce 26) (("*") reduce 26) (("+") reduce 26) (("-") reduce 26) ((".") reduce 26) (("/") reduce 26) (("<") reduce 26) ((">") reduce 26) (("?") reduce 26) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_BOOLEAN_AND) reduce 26) ((T_BOOLEAN_OR) reduce 26) ((T_COALESCE) reduce 26) ((T_INSTANCEOF) reduce 26) ((T_IS_EQUAL) reduce 26) ((T_IS_GREATER_OR_EQUAL) reduce 26) ((T_IS_IDENTICAL) reduce 26) ((T_IS_NOT_EQUAL) reduce 26) ((T_IS_NOT_IDENTICAL) reduce 26) ((T_IS_SMALLER_OR_EQUAL) reduce 26) ((T_LOGICAL_AND) reduce 26) ((T_LOGICAL_OR) reduce 26) ((T_LOGICAL_XOR) reduce 26) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 26) ((T_OBJECT_OPERATOR) reduce 26) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 26) ((T_POW) reduce 26) ((T_SL) reduce 26) ((T_SPACESHIP) reduce 26) ((T_SR) reduce 26) (("[") reduce 26) (("^") reduce 26) (("{") reduce 26) (("|") reduce 26) (("}") reduce 26)) 13004 ((("%") reduce 22) (("(") reduce 22) (("*") reduce 22) (("+") reduce 22) (("-") reduce 22) ((".") reduce 22) (("/") reduce 22) (("<") reduce 22) ((">") reduce 22) (("?") reduce 22) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_BOOLEAN_AND) reduce 22) ((T_BOOLEAN_OR) reduce 22) ((T_COALESCE) reduce 22) ((T_INSTANCEOF) reduce 22) ((T_IS_EQUAL) reduce 22) ((T_IS_GREATER_OR_EQUAL) reduce 22) ((T_IS_IDENTICAL) reduce 22) ((T_IS_NOT_EQUAL) reduce 22) ((T_IS_NOT_IDENTICAL) reduce 22) ((T_IS_SMALLER_OR_EQUAL) reduce 22) ((T_LOGICAL_AND) reduce 22) ((T_LOGICAL_OR) reduce 22) ((T_LOGICAL_XOR) reduce 22) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 22) ((T_OBJECT_OPERATOR) reduce 22) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 22) ((T_POW) reduce 22) ((T_SL) reduce 22) ((T_SPACESHIP) reduce 22) ((T_SR) reduce 22) (("[") reduce 22) (("^") reduce 22) (("{") reduce 22) (("|") reduce 22) (("}") reduce 22)) 13005 ((("%") reduce 24) (("(") reduce 24) (("*") reduce 24) (("+") reduce 24) (("-") reduce 24) ((".") reduce 24) (("/") reduce 24) (("<") reduce 24) ((">") reduce 24) (("?") reduce 24) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_BOOLEAN_AND) reduce 24) ((T_BOOLEAN_OR) reduce 24) ((T_COALESCE) reduce 24) ((T_INSTANCEOF) reduce 24) ((T_IS_EQUAL) reduce 24) ((T_IS_GREATER_OR_EQUAL) reduce 24) ((T_IS_IDENTICAL) reduce 24) ((T_IS_NOT_EQUAL) reduce 24) ((T_IS_NOT_IDENTICAL) reduce 24) ((T_IS_SMALLER_OR_EQUAL) reduce 24) ((T_LOGICAL_AND) reduce 24) ((T_LOGICAL_OR) reduce 24) ((T_LOGICAL_XOR) reduce 24) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 24) ((T_OBJECT_OPERATOR) reduce 24) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 24) ((T_POW) reduce 24) ((T_SL) reduce 24) ((T_SPACESHIP) reduce 24) ((T_SR) reduce 24) (("[") reduce 24) (("^") reduce 24) (("{") reduce 24) (("|") reduce 24) (("}") reduce 24)) 13006 ((("%") reduce 16) (("(") reduce 16) (("*") reduce 16) (("+") reduce 16) (("-") reduce 16) ((".") reduce 16) (("/") reduce 16) (("<") reduce 16) ((">") reduce 16) (("?") reduce 16) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_BOOLEAN_AND) reduce 16) ((T_BOOLEAN_OR) reduce 16) ((T_COALESCE) reduce 16) ((T_INSTANCEOF) reduce 16) ((T_IS_EQUAL) reduce 16) ((T_IS_GREATER_OR_EQUAL) reduce 16) ((T_IS_IDENTICAL) reduce 16) ((T_IS_NOT_EQUAL) reduce 16) ((T_IS_NOT_IDENTICAL) reduce 16) ((T_IS_SMALLER_OR_EQUAL) reduce 16) ((T_LOGICAL_AND) reduce 16) ((T_LOGICAL_OR) reduce 16) ((T_LOGICAL_XOR) reduce 16) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 16) ((T_OBJECT_OPERATOR) reduce 16) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 16) ((T_POW) reduce 16) ((T_SL) reduce 16) ((T_SPACESHIP) reduce 16) ((T_SR) reduce 16) (("[") reduce 16) (("^") reduce 16) (("{") reduce 16) (("|") reduce 16) (("}") reduce 16)) 13007 ((("%") reduce 48) (("(") reduce 48) (("*") reduce 48) (("+") reduce 48) (("-") reduce 48) ((".") reduce 48) (("/") reduce 48) (("<") reduce 48) ((">") reduce 48) (("?") reduce 48) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_BOOLEAN_AND) reduce 48) ((T_BOOLEAN_OR) reduce 48) ((T_COALESCE) reduce 48) ((T_INSTANCEOF) reduce 48) ((T_IS_EQUAL) reduce 48) ((T_IS_GREATER_OR_EQUAL) reduce 48) ((T_IS_IDENTICAL) reduce 48) ((T_IS_NOT_EQUAL) reduce 48) ((T_IS_NOT_IDENTICAL) reduce 48) ((T_IS_SMALLER_OR_EQUAL) reduce 48) ((T_LOGICAL_AND) reduce 48) ((T_LOGICAL_OR) reduce 48) ((T_LOGICAL_XOR) reduce 48) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 48) ((T_OBJECT_OPERATOR) reduce 48) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 48) ((T_POW) reduce 48) ((T_SL) reduce 48) ((T_SPACESHIP) reduce 48) ((T_SR) reduce 48) (("[") reduce 48) (("^") reduce 48) (("{") reduce 48) (("|") reduce 48) (("}") reduce 48)) 13008 ((("%") reduce 20) (("(") reduce 20) (("*") reduce 20) (("+") reduce 20) (("-") reduce 20) ((".") reduce 20) (("/") reduce 20) (("<") reduce 20) ((">") reduce 20) (("?") reduce 20) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_BOOLEAN_AND) reduce 20) ((T_BOOLEAN_OR) reduce 20) ((T_COALESCE) reduce 20) ((T_INSTANCEOF) reduce 20) ((T_IS_EQUAL) reduce 20) ((T_IS_GREATER_OR_EQUAL) reduce 20) ((T_IS_IDENTICAL) reduce 20) ((T_IS_NOT_EQUAL) reduce 20) ((T_IS_NOT_IDENTICAL) reduce 20) ((T_IS_SMALLER_OR_EQUAL) reduce 20) ((T_LOGICAL_AND) reduce 20) ((T_LOGICAL_OR) reduce 20) ((T_LOGICAL_XOR) reduce 20) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 20) ((T_OBJECT_OPERATOR) reduce 20) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 20) ((T_POW) reduce 20) ((T_SL) reduce 20) ((T_SPACESHIP) reduce 20) ((T_SR) reduce 20) (("[") reduce 20) (("^") reduce 20) (("{") reduce 20) (("|") reduce 20) (("}") reduce 20)) 13009 ((("%") reduce 70) (("(") reduce 70) (("*") reduce 70) (("+") reduce 70) (("-") reduce 70) ((".") reduce 70) (("/") reduce 70) (("<") reduce 70) ((">") reduce 70) (("?") reduce 70) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_BOOLEAN_AND) reduce 70) ((T_BOOLEAN_OR) reduce 70) ((T_COALESCE) reduce 70) ((T_INSTANCEOF) reduce 70) ((T_IS_EQUAL) reduce 70) ((T_IS_GREATER_OR_EQUAL) reduce 70) ((T_IS_IDENTICAL) reduce 70) ((T_IS_NOT_EQUAL) reduce 70) ((T_IS_NOT_IDENTICAL) reduce 70) ((T_IS_SMALLER_OR_EQUAL) reduce 70) ((T_LOGICAL_AND) reduce 70) ((T_LOGICAL_OR) reduce 70) ((T_LOGICAL_XOR) reduce 70) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 70) ((T_OBJECT_OPERATOR) reduce 70) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 70) ((T_POW) reduce 70) ((T_SL) reduce 70) ((T_SPACESHIP) reduce 70) ((T_SR) reduce 70) (("[") reduce 70) (("^") reduce 70) (("{") reduce 70) (("|") reduce 70) (("}") reduce 70)) 13010 ((("%") reduce 3) (("(") reduce 3) (("*") reduce 3) (("+") reduce 3) (("-") reduce 3) ((".") reduce 3) (("/") reduce 3) (("<") reduce 3) ((">") reduce 3) (("?") reduce 3) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_BOOLEAN_AND) reduce 3) ((T_BOOLEAN_OR) reduce 3) ((T_COALESCE) reduce 3) ((T_INSTANCEOF) reduce 3) ((T_IS_EQUAL) reduce 3) ((T_IS_GREATER_OR_EQUAL) reduce 3) ((T_IS_IDENTICAL) reduce 3) ((T_IS_NOT_EQUAL) reduce 3) ((T_IS_NOT_IDENTICAL) reduce 3) ((T_IS_SMALLER_OR_EQUAL) reduce 3) ((T_LOGICAL_AND) reduce 3) ((T_LOGICAL_OR) reduce 3) ((T_LOGICAL_XOR) reduce 3) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 3) ((T_OBJECT_OPERATOR) reduce 3) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 3) ((T_POW) reduce 3) ((T_SL) reduce 3) ((T_SPACESHIP) reduce 3) ((T_SR) reduce 3) (("[") reduce 3) (("^") reduce 3) (("{") reduce 3) (("|") reduce 3) (("}") reduce 3)) 13011 ((("%") reduce 12) (("(") reduce 12) (("*") reduce 12) (("+") reduce 12) (("-") reduce 12) ((".") reduce 12) (("/") reduce 12) (("<") reduce 12) ((">") reduce 12) (("?") reduce 12) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_BOOLEAN_AND) reduce 12) ((T_BOOLEAN_OR) reduce 12) ((T_COALESCE) reduce 12) ((T_INSTANCEOF) reduce 12) ((T_IS_EQUAL) reduce 12) ((T_IS_GREATER_OR_EQUAL) reduce 12) ((T_IS_IDENTICAL) reduce 12) ((T_IS_NOT_EQUAL) reduce 12) ((T_IS_NOT_IDENTICAL) reduce 12) ((T_IS_SMALLER_OR_EQUAL) reduce 12) ((T_LOGICAL_AND) reduce 12) ((T_LOGICAL_OR) reduce 12) ((T_LOGICAL_XOR) reduce 12) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 12) ((T_OBJECT_OPERATOR) reduce 12) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 12) ((T_POW) reduce 12) ((T_SL) reduce 12) ((T_SPACESHIP) reduce 12) ((T_SR) reduce 12) (("[") reduce 12) (("^") reduce 12) (("{") reduce 12) (("|") reduce 12) (("}") reduce 12)) 13012 ((("%") reduce 54) (("(") reduce 54) (("*") reduce 54) (("+") reduce 54) (("-") reduce 54) ((".") reduce 54) (("/") reduce 54) (("<") reduce 54) ((">") reduce 54) (("?") reduce 54) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_BOOLEAN_AND) reduce 54) ((T_BOOLEAN_OR) reduce 54) ((T_COALESCE) reduce 54) ((T_INSTANCEOF) reduce 54) ((T_IS_EQUAL) reduce 54) ((T_IS_GREATER_OR_EQUAL) reduce 54) ((T_IS_IDENTICAL) reduce 54) ((T_IS_NOT_EQUAL) reduce 54) ((T_IS_NOT_IDENTICAL) reduce 54) ((T_IS_SMALLER_OR_EQUAL) reduce 54) ((T_LOGICAL_AND) reduce 54) ((T_LOGICAL_OR) reduce 54) ((T_LOGICAL_XOR) reduce 54) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 54) ((T_OBJECT_OPERATOR) reduce 54) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 54) ((T_POW) reduce 54) ((T_SL) reduce 54) ((T_SPACESHIP) reduce 54) ((T_SR) reduce 54) (("[") reduce 54) (("^") reduce 54) (("{") reduce 54) (("|") reduce 54) (("}") reduce 54)) 13013 ((("%") reduce 65) (("(") reduce 65) (("*") reduce 65) (("+") reduce 65) (("-") reduce 65) ((".") reduce 65) (("/") reduce 65) (("<") reduce 65) ((">") reduce 65) (("?") reduce 65) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_BOOLEAN_AND) reduce 65) ((T_BOOLEAN_OR) reduce 65) ((T_COALESCE) reduce 65) ((T_INSTANCEOF) reduce 65) ((T_IS_EQUAL) reduce 65) ((T_IS_GREATER_OR_EQUAL) reduce 65) ((T_IS_IDENTICAL) reduce 65) ((T_IS_NOT_EQUAL) reduce 65) ((T_IS_NOT_IDENTICAL) reduce 65) ((T_IS_SMALLER_OR_EQUAL) reduce 65) ((T_LOGICAL_AND) reduce 65) ((T_LOGICAL_OR) reduce 65) ((T_LOGICAL_XOR) reduce 65) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 65) ((T_OBJECT_OPERATOR) reduce 65) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 65) ((T_POW) reduce 65) ((T_SL) reduce 65) ((T_SPACESHIP) reduce 65) ((T_SR) reduce 65) (("[") reduce 65) (("^") reduce 65) (("{") reduce 65) (("|") reduce 65) (("}") reduce 65)) 13014 ((("%") reduce 74) (("(") reduce 74) (("*") reduce 74) (("+") reduce 74) (("-") reduce 74) ((".") reduce 74) (("/") reduce 74) (("<") reduce 74) ((">") reduce 74) (("?") reduce 74) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_BOOLEAN_AND) reduce 74) ((T_BOOLEAN_OR) reduce 74) ((T_COALESCE) reduce 74) ((T_INSTANCEOF) reduce 74) ((T_IS_EQUAL) reduce 74) ((T_IS_GREATER_OR_EQUAL) reduce 74) ((T_IS_IDENTICAL) reduce 74) ((T_IS_NOT_EQUAL) reduce 74) ((T_IS_NOT_IDENTICAL) reduce 74) ((T_IS_SMALLER_OR_EQUAL) reduce 74) ((T_LOGICAL_AND) reduce 74) ((T_LOGICAL_OR) reduce 74) ((T_LOGICAL_XOR) reduce 74) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 74) ((T_OBJECT_OPERATOR) reduce 74) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 74) ((T_POW) reduce 74) ((T_SL) reduce 74) ((T_SPACESHIP) reduce 74) ((T_SR) reduce 74) (("[") reduce 74) (("^") reduce 74) (("{") reduce 74) (("|") reduce 74) (("}") reduce 74)) 13015 ((("%") reduce 30) (("(") reduce 30) (("*") reduce 30) (("+") reduce 30) (("-") reduce 30) ((".") reduce 30) (("/") reduce 30) (("<") reduce 30) ((">") reduce 30) (("?") reduce 30) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_BOOLEAN_AND) reduce 30) ((T_BOOLEAN_OR) reduce 30) ((T_COALESCE) reduce 30) ((T_INSTANCEOF) reduce 30) ((T_IS_EQUAL) reduce 30) ((T_IS_GREATER_OR_EQUAL) reduce 30) ((T_IS_IDENTICAL) reduce 30) ((T_IS_NOT_EQUAL) reduce 30) ((T_IS_NOT_IDENTICAL) reduce 30) ((T_IS_SMALLER_OR_EQUAL) reduce 30) ((T_LOGICAL_AND) reduce 30) ((T_LOGICAL_OR) reduce 30) ((T_LOGICAL_XOR) reduce 30) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 30) ((T_OBJECT_OPERATOR) reduce 30) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 30) ((T_POW) reduce 30) ((T_SL) reduce 30) ((T_SPACESHIP) reduce 30) ((T_SR) reduce 30) (("[") reduce 30) (("^") reduce 30) (("{") reduce 30) (("|") reduce 30) (("}") reduce 30)) 13016 ((("%") reduce 68) (("(") reduce 68) (("*") reduce 68) (("+") reduce 68) (("-") reduce 68) ((".") reduce 68) (("/") reduce 68) (("<") reduce 68) ((">") reduce 68) (("?") reduce 68) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_BOOLEAN_AND) reduce 68) ((T_BOOLEAN_OR) reduce 68) ((T_COALESCE) reduce 68) ((T_INSTANCEOF) reduce 68) ((T_IS_EQUAL) reduce 68) ((T_IS_GREATER_OR_EQUAL) reduce 68) ((T_IS_IDENTICAL) reduce 68) ((T_IS_NOT_EQUAL) reduce 68) ((T_IS_NOT_IDENTICAL) reduce 68) ((T_IS_SMALLER_OR_EQUAL) reduce 68) ((T_LOGICAL_AND) reduce 68) ((T_LOGICAL_OR) reduce 68) ((T_LOGICAL_XOR) reduce 68) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 68) ((T_OBJECT_OPERATOR) reduce 68) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 68) ((T_POW) reduce 68) ((T_SL) reduce 68) ((T_SPACESHIP) reduce 68) ((T_SR) reduce 68) (("[") reduce 68) (("^") reduce 68) (("{") reduce 68) (("|") reduce 68) (("}") reduce 68)) 13017 ((("%") reduce 21) (("(") reduce 21) (("*") reduce 21) (("+") reduce 21) (("-") reduce 21) ((".") reduce 21) (("/") reduce 21) (("<") reduce 21) ((">") reduce 21) (("?") reduce 21) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_BOOLEAN_AND) reduce 21) ((T_BOOLEAN_OR) reduce 21) ((T_COALESCE) reduce 21) ((T_INSTANCEOF) reduce 21) ((T_IS_EQUAL) reduce 21) ((T_IS_GREATER_OR_EQUAL) reduce 21) ((T_IS_IDENTICAL) reduce 21) ((T_IS_NOT_EQUAL) reduce 21) ((T_IS_NOT_IDENTICAL) reduce 21) ((T_IS_SMALLER_OR_EQUAL) reduce 21) ((T_LOGICAL_AND) reduce 21) ((T_LOGICAL_OR) reduce 21) ((T_LOGICAL_XOR) reduce 21) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 21) ((T_OBJECT_OPERATOR) reduce 21) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 21) ((T_POW) reduce 21) ((T_SL) reduce 21) ((T_SPACESHIP) reduce 21) ((T_SR) reduce 21) (("[") reduce 21) (("^") reduce 21) (("{") reduce 21) (("|") reduce 21) (("}") reduce 21)) 13018 ((("%") reduce 23) (("(") reduce 23) (("*") reduce 23) (("+") reduce 23) (("-") reduce 23) ((".") reduce 23) (("/") reduce 23) (("<") reduce 23) ((">") reduce 23) (("?") reduce 23) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_BOOLEAN_AND) reduce 23) ((T_BOOLEAN_OR) reduce 23) ((T_COALESCE) reduce 23) ((T_INSTANCEOF) reduce 23) ((T_IS_EQUAL) reduce 23) ((T_IS_GREATER_OR_EQUAL) reduce 23) ((T_IS_IDENTICAL) reduce 23) ((T_IS_NOT_EQUAL) reduce 23) ((T_IS_NOT_IDENTICAL) reduce 23) ((T_IS_SMALLER_OR_EQUAL) reduce 23) ((T_LOGICAL_AND) reduce 23) ((T_LOGICAL_OR) reduce 23) ((T_LOGICAL_XOR) reduce 23) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 23) ((T_OBJECT_OPERATOR) reduce 23) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 23) ((T_POW) reduce 23) ((T_SL) reduce 23) ((T_SPACESHIP) reduce 23) ((T_SR) reduce 23) (("[") reduce 23) (("^") reduce 23) (("{") reduce 23) (("|") reduce 23) (("}") reduce 23)) 13019 ((("%") reduce 41) (("(") reduce 41) (("*") reduce 41) (("+") reduce 41) (("-") reduce 41) ((".") reduce 41) (("/") reduce 41) (("<") reduce 41) ((">") reduce 41) (("?") reduce 41) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_BOOLEAN_AND) reduce 41) ((T_BOOLEAN_OR) reduce 41) ((T_COALESCE) reduce 41) ((T_INSTANCEOF) reduce 41) ((T_IS_EQUAL) reduce 41) ((T_IS_GREATER_OR_EQUAL) reduce 41) ((T_IS_IDENTICAL) reduce 41) ((T_IS_NOT_EQUAL) reduce 41) ((T_IS_NOT_IDENTICAL) reduce 41) ((T_IS_SMALLER_OR_EQUAL) reduce 41) ((T_LOGICAL_AND) reduce 41) ((T_LOGICAL_OR) reduce 41) ((T_LOGICAL_XOR) reduce 41) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 41) ((T_OBJECT_OPERATOR) reduce 41) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 41) ((T_POW) reduce 41) ((T_SL) reduce 41) ((T_SPACESHIP) reduce 41) ((T_SR) reduce 41) (("[") reduce 41) (("^") reduce 41) (("{") reduce 41) (("|") reduce 41) (("}") reduce 41)) 13020 ((("%") reduce 62) (("(") reduce 62) (("*") reduce 62) (("+") reduce 62) (("-") reduce 62) ((".") reduce 62) (("/") reduce 62) (("<") reduce 62) ((">") reduce 62) (("?") reduce 62) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_BOOLEAN_AND) reduce 62) ((T_BOOLEAN_OR) reduce 62) ((T_COALESCE) reduce 62) ((T_INSTANCEOF) reduce 62) ((T_IS_EQUAL) reduce 62) ((T_IS_GREATER_OR_EQUAL) reduce 62) ((T_IS_IDENTICAL) reduce 62) ((T_IS_NOT_EQUAL) reduce 62) ((T_IS_NOT_IDENTICAL) reduce 62) ((T_IS_SMALLER_OR_EQUAL) reduce 62) ((T_LOGICAL_AND) reduce 62) ((T_LOGICAL_OR) reduce 62) ((T_LOGICAL_XOR) reduce 62) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 62) ((T_OBJECT_OPERATOR) reduce 62) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 62) ((T_POW) reduce 62) ((T_SL) reduce 62) ((T_SPACESHIP) reduce 62) ((T_SR) reduce 62) (("[") reduce 62) (("^") reduce 62) (("{") reduce 62) (("|") reduce 62) (("}") reduce 62)) 13021 ((("%") reduce 34) (("(") reduce 34) (("*") reduce 34) (("+") reduce 34) (("-") reduce 34) ((".") reduce 34) (("/") reduce 34) (("<") reduce 34) ((">") reduce 34) (("?") reduce 34) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_BOOLEAN_AND) reduce 34) ((T_BOOLEAN_OR) reduce 34) ((T_COALESCE) reduce 34) ((T_INSTANCEOF) reduce 34) ((T_IS_EQUAL) reduce 34) ((T_IS_GREATER_OR_EQUAL) reduce 34) ((T_IS_IDENTICAL) reduce 34) ((T_IS_NOT_EQUAL) reduce 34) ((T_IS_NOT_IDENTICAL) reduce 34) ((T_IS_SMALLER_OR_EQUAL) reduce 34) ((T_LOGICAL_AND) reduce 34) ((T_LOGICAL_OR) reduce 34) ((T_LOGICAL_XOR) reduce 34) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 34) ((T_OBJECT_OPERATOR) reduce 34) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 34) ((T_POW) reduce 34) ((T_SL) reduce 34) ((T_SPACESHIP) reduce 34) ((T_SR) reduce 34) (("[") reduce 34) (("^") reduce 34) (("{") reduce 34) (("|") reduce 34) (("}") reduce 34)) 13022 ((("%") reduce 40) (("(") reduce 40) (("*") reduce 40) (("+") reduce 40) (("-") reduce 40) ((".") reduce 40) (("/") reduce 40) (("<") reduce 40) ((">") reduce 40) (("?") reduce 40) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_BOOLEAN_AND) reduce 40) ((T_BOOLEAN_OR) reduce 40) ((T_COALESCE) reduce 40) ((T_INSTANCEOF) reduce 40) ((T_IS_EQUAL) reduce 40) ((T_IS_GREATER_OR_EQUAL) reduce 40) ((T_IS_IDENTICAL) reduce 40) ((T_IS_NOT_EQUAL) reduce 40) ((T_IS_NOT_IDENTICAL) reduce 40) ((T_IS_SMALLER_OR_EQUAL) reduce 40) ((T_LOGICAL_AND) reduce 40) ((T_LOGICAL_OR) reduce 40) ((T_LOGICAL_XOR) reduce 40) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 40) ((T_OBJECT_OPERATOR) reduce 40) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 40) ((T_POW) reduce 40) ((T_SL) reduce 40) ((T_SPACESHIP) reduce 40) ((T_SR) reduce 40) (("[") reduce 40) (("^") reduce 40) (("{") reduce 40) (("|") reduce 40) (("}") reduce 40)) 13023 ((("%") reduce 13) (("(") reduce 13) (("*") reduce 13) (("+") reduce 13) (("-") reduce 13) ((".") reduce 13) (("/") reduce 13) (("<") reduce 13) ((">") reduce 13) (("?") reduce 13) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_BOOLEAN_AND) reduce 13) ((T_BOOLEAN_OR) reduce 13) ((T_COALESCE) reduce 13) ((T_INSTANCEOF) reduce 13) ((T_IS_EQUAL) reduce 13) ((T_IS_GREATER_OR_EQUAL) reduce 13) ((T_IS_IDENTICAL) reduce 13) ((T_IS_NOT_EQUAL) reduce 13) ((T_IS_NOT_IDENTICAL) reduce 13) ((T_IS_SMALLER_OR_EQUAL) reduce 13) ((T_LOGICAL_AND) reduce 13) ((T_LOGICAL_OR) reduce 13) ((T_LOGICAL_XOR) reduce 13) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 13) ((T_OBJECT_OPERATOR) reduce 13) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 13) ((T_POW) reduce 13) ((T_SL) reduce 13) ((T_SPACESHIP) reduce 13) ((T_SR) reduce 13) (("[") reduce 13) (("^") reduce 13) (("{") reduce 13) (("|") reduce 13) (("}") reduce 13)) 13024 ((("%") reduce 55) (("(") reduce 55) (("*") reduce 55) (("+") reduce 55) (("-") reduce 55) ((".") reduce 55) (("/") reduce 55) (("<") reduce 55) ((">") reduce 55) (("?") reduce 55) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_BOOLEAN_AND) reduce 55) ((T_BOOLEAN_OR) reduce 55) ((T_COALESCE) reduce 55) ((T_INSTANCEOF) reduce 55) ((T_IS_EQUAL) reduce 55) ((T_IS_GREATER_OR_EQUAL) reduce 55) ((T_IS_IDENTICAL) reduce 55) ((T_IS_NOT_EQUAL) reduce 55) ((T_IS_NOT_IDENTICAL) reduce 55) ((T_IS_SMALLER_OR_EQUAL) reduce 55) ((T_LOGICAL_AND) reduce 55) ((T_LOGICAL_OR) reduce 55) ((T_LOGICAL_XOR) reduce 55) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 55) ((T_OBJECT_OPERATOR) reduce 55) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 55) ((T_POW) reduce 55) ((T_SL) reduce 55) ((T_SPACESHIP) reduce 55) ((T_SR) reduce 55) (("[") reduce 55) (("^") reduce 55) (("{") reduce 55) (("|") reduce 55) (("}") reduce 55)) 13025 ((("%") reduce 1) (("(") reduce 1) (("*") reduce 1) (("+") reduce 1) (("-") reduce 1) ((".") reduce 1) (("/") reduce 1) (("<") reduce 1) ((">") reduce 1) (("?") reduce 1) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_BOOLEAN_AND) reduce 1) ((T_BOOLEAN_OR) reduce 1) ((T_COALESCE) reduce 1) ((T_INSTANCEOF) reduce 1) ((T_IS_EQUAL) reduce 1) ((T_IS_GREATER_OR_EQUAL) reduce 1) ((T_IS_IDENTICAL) reduce 1) ((T_IS_NOT_EQUAL) reduce 1) ((T_IS_NOT_IDENTICAL) reduce 1) ((T_IS_SMALLER_OR_EQUAL) reduce 1) ((T_LOGICAL_AND) reduce 1) ((T_LOGICAL_OR) reduce 1) ((T_LOGICAL_XOR) reduce 1) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 1) ((T_OBJECT_OPERATOR) reduce 1) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 1) ((T_POW) reduce 1) ((T_SL) reduce 1) ((T_SPACESHIP) reduce 1) ((T_SR) reduce 1) (("[") reduce 1) (("^") reduce 1) (("{") reduce 1) (("|") reduce 1) (("}") reduce 1)) 13026 ((("%") reduce 2) (("(") reduce 2) (("*") reduce 2) (("+") reduce 2) (("-") reduce 2) ((".") reduce 2) (("/") reduce 2) (("<") reduce 2) ((">") reduce 2) (("?") reduce 2) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_BOOLEAN_AND) reduce 2) ((T_BOOLEAN_OR) reduce 2) ((T_COALESCE) reduce 2) ((T_INSTANCEOF) reduce 2) ((T_IS_EQUAL) reduce 2) ((T_IS_GREATER_OR_EQUAL) reduce 2) ((T_IS_IDENTICAL) reduce 2) ((T_IS_NOT_EQUAL) reduce 2) ((T_IS_NOT_IDENTICAL) reduce 2) ((T_IS_SMALLER_OR_EQUAL) reduce 2) ((T_LOGICAL_AND) reduce 2) ((T_LOGICAL_OR) reduce 2) ((T_LOGICAL_XOR) reduce 2) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 2) ((T_OBJECT_OPERATOR) reduce 2) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 2) ((T_POW) reduce 2) ((T_SL) reduce 2) ((T_SPACESHIP) reduce 2) ((T_SR) reduce 2) (("[") reduce 2) (("^") reduce 2) (("{") reduce 2) (("|") reduce 2) (("}") reduce 2)) 13027 ((("%") reduce 9) (("(") reduce 9) (("*") reduce 9) (("+") reduce 9) (("-") reduce 9) ((".") reduce 9) (("/") reduce 9) (("<") reduce 9) ((">") reduce 9) (("?") reduce 9) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_BOOLEAN_AND) reduce 9) ((T_BOOLEAN_OR) reduce 9) ((T_COALESCE) reduce 9) ((T_INSTANCEOF) reduce 9) ((T_IS_EQUAL) reduce 9) ((T_IS_GREATER_OR_EQUAL) reduce 9) ((T_IS_IDENTICAL) reduce 9) ((T_IS_NOT_EQUAL) reduce 9) ((T_IS_NOT_IDENTICAL) reduce 9) ((T_IS_SMALLER_OR_EQUAL) reduce 9) ((T_LOGICAL_AND) reduce 9) ((T_LOGICAL_OR) reduce 9) ((T_LOGICAL_XOR) reduce 9) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 9) ((T_OBJECT_OPERATOR) reduce 9) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 9) ((T_POW) reduce 9) ((T_SL) reduce 9) ((T_SPACESHIP) reduce 9) ((T_SR) reduce 9) (("[") reduce 9) (("^") reduce 9) (("{") reduce 9) (("|") reduce 9) (("}") reduce 9)) 13028 ((("%") reduce 33) (("(") reduce 33) (("*") reduce 33) (("+") reduce 33) (("-") reduce 33) ((".") reduce 33) (("/") reduce 33) (("<") reduce 33) ((">") reduce 33) (("?") reduce 33) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_BOOLEAN_AND) reduce 33) ((T_BOOLEAN_OR) reduce 33) ((T_COALESCE) reduce 33) ((T_INSTANCEOF) reduce 33) ((T_IS_EQUAL) reduce 33) ((T_IS_GREATER_OR_EQUAL) reduce 33) ((T_IS_IDENTICAL) reduce 33) ((T_IS_NOT_EQUAL) reduce 33) ((T_IS_NOT_IDENTICAL) reduce 33) ((T_IS_SMALLER_OR_EQUAL) reduce 33) ((T_LOGICAL_AND) reduce 33) ((T_LOGICAL_OR) reduce 33) ((T_LOGICAL_XOR) reduce 33) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 33) ((T_OBJECT_OPERATOR) reduce 33) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 33) ((T_POW) reduce 33) ((T_SL) reduce 33) ((T_SPACESHIP) reduce 33) ((T_SR) reduce 33) (("[") reduce 33) (("^") reduce 33) (("{") reduce 33) (("|") reduce 33) (("}") reduce 33)) 13029 ((("%") reduce 58) (("(") reduce 58) (("*") reduce 58) (("+") reduce 58) (("-") reduce 58) ((".") reduce 58) (("/") reduce 58) (("<") reduce 58) ((">") reduce 58) (("?") reduce 58) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_BOOLEAN_AND) reduce 58) ((T_BOOLEAN_OR) reduce 58) ((T_COALESCE) reduce 58) ((T_INSTANCEOF) reduce 58) ((T_IS_EQUAL) reduce 58) ((T_IS_GREATER_OR_EQUAL) reduce 58) ((T_IS_IDENTICAL) reduce 58) ((T_IS_NOT_EQUAL) reduce 58) ((T_IS_NOT_IDENTICAL) reduce 58) ((T_IS_SMALLER_OR_EQUAL) reduce 58) ((T_LOGICAL_AND) reduce 58) ((T_LOGICAL_OR) reduce 58) ((T_LOGICAL_XOR) reduce 58) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 58) ((T_OBJECT_OPERATOR) reduce 58) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 58) ((T_POW) reduce 58) ((T_SL) reduce 58) ((T_SPACESHIP) reduce 58) ((T_SR) reduce 58) (("[") reduce 58) (("^") reduce 58) (("{") reduce 58) (("|") reduce 58) (("}") reduce 58)) 13030 ((("%") reduce 37) (("(") reduce 37) (("*") reduce 37) (("+") reduce 37) (("-") reduce 37) ((".") reduce 37) (("/") reduce 37) (("<") reduce 37) ((">") reduce 37) (("?") reduce 37) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_BOOLEAN_AND) reduce 37) ((T_BOOLEAN_OR) reduce 37) ((T_COALESCE) reduce 37) ((T_INSTANCEOF) reduce 37) ((T_IS_EQUAL) reduce 37) ((T_IS_GREATER_OR_EQUAL) reduce 37) ((T_IS_IDENTICAL) reduce 37) ((T_IS_NOT_EQUAL) reduce 37) ((T_IS_NOT_IDENTICAL) reduce 37) ((T_IS_SMALLER_OR_EQUAL) reduce 37) ((T_LOGICAL_AND) reduce 37) ((T_LOGICAL_OR) reduce 37) ((T_LOGICAL_XOR) reduce 37) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 37) ((T_OBJECT_OPERATOR) reduce 37) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 37) ((T_POW) reduce 37) ((T_SL) reduce 37) ((T_SPACESHIP) reduce 37) ((T_SR) reduce 37) (("[") reduce 37) (("^") reduce 37) (("{") reduce 37) (("|") reduce 37) (("}") reduce 37)) 13031 ((("%") reduce 64) (("(") reduce 64) (("*") reduce 64) (("+") reduce 64) (("-") reduce 64) ((".") reduce 64) (("/") reduce 64) (("<") reduce 64) ((">") reduce 64) (("?") reduce 64) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_BOOLEAN_AND) reduce 64) ((T_BOOLEAN_OR) reduce 64) ((T_COALESCE) reduce 64) ((T_INSTANCEOF) reduce 64) ((T_IS_EQUAL) reduce 64) ((T_IS_GREATER_OR_EQUAL) reduce 64) ((T_IS_IDENTICAL) reduce 64) ((T_IS_NOT_EQUAL) reduce 64) ((T_IS_NOT_IDENTICAL) reduce 64) ((T_IS_SMALLER_OR_EQUAL) reduce 64) ((T_LOGICAL_AND) reduce 64) ((T_LOGICAL_OR) reduce 64) ((T_LOGICAL_XOR) reduce 64) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 64) ((T_OBJECT_OPERATOR) reduce 64) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 64) ((T_POW) reduce 64) ((T_SL) reduce 64) ((T_SPACESHIP) reduce 64) ((T_SR) reduce 64) (("[") reduce 64) (("^") reduce 64) (("{") reduce 64) (("|") reduce 64) (("}") reduce 64)) 13032 ((("%") reduce 46) (("(") reduce 46) (("*") reduce 46) (("+") reduce 46) (("-") reduce 46) ((".") reduce 46) (("/") reduce 46) (("<") reduce 46) ((">") reduce 46) (("?") reduce 46) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_BOOLEAN_AND) reduce 46) ((T_BOOLEAN_OR) reduce 46) ((T_COALESCE) reduce 46) ((T_INSTANCEOF) reduce 46) ((T_IS_EQUAL) reduce 46) ((T_IS_GREATER_OR_EQUAL) reduce 46) ((T_IS_IDENTICAL) reduce 46) ((T_IS_NOT_EQUAL) reduce 46) ((T_IS_NOT_IDENTICAL) reduce 46) ((T_IS_SMALLER_OR_EQUAL) reduce 46) ((T_LOGICAL_AND) reduce 46) ((T_LOGICAL_OR) reduce 46) ((T_LOGICAL_XOR) reduce 46) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 46) ((T_OBJECT_OPERATOR) reduce 46) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 46) ((T_POW) reduce 46) ((T_SL) reduce 46) ((T_SPACESHIP) reduce 46) ((T_SR) reduce 46) (("[") reduce 46) (("^") reduce 46) (("{") reduce 46) (("|") reduce 46) (("}") reduce 46)) 13033 ((("%") reduce 8) (("(") reduce 8) (("*") reduce 8) (("+") reduce 8) (("-") reduce 8) ((".") reduce 8) (("/") reduce 8) (("<") reduce 8) ((">") reduce 8) (("?") reduce 8) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_BOOLEAN_AND) reduce 8) ((T_BOOLEAN_OR) reduce 8) ((T_COALESCE) reduce 8) ((T_INSTANCEOF) reduce 8) ((T_IS_EQUAL) reduce 8) ((T_IS_GREATER_OR_EQUAL) reduce 8) ((T_IS_IDENTICAL) reduce 8) ((T_IS_NOT_EQUAL) reduce 8) ((T_IS_NOT_IDENTICAL) reduce 8) ((T_IS_SMALLER_OR_EQUAL) reduce 8) ((T_LOGICAL_AND) reduce 8) ((T_LOGICAL_OR) reduce 8) ((T_LOGICAL_XOR) reduce 8) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 8) ((T_OBJECT_OPERATOR) reduce 8) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 8) ((T_POW) reduce 8) ((T_SL) reduce 8) ((T_SPACESHIP) reduce 8) ((T_SR) reduce 8) (("[") reduce 8) (("^") reduce 8) (("{") reduce 8) (("|") reduce 8) (("}") reduce 8)) 13034 ((("%") reduce 6) (("(") reduce 6) (("*") reduce 6) (("+") reduce 6) (("-") reduce 6) ((".") reduce 6) (("/") reduce 6) (("<") reduce 6) ((">") reduce 6) (("?") reduce 6) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_BOOLEAN_AND) reduce 6) ((T_BOOLEAN_OR) reduce 6) ((T_COALESCE) reduce 6) ((T_INSTANCEOF) reduce 6) ((T_IS_EQUAL) reduce 6) ((T_IS_GREATER_OR_EQUAL) reduce 6) ((T_IS_IDENTICAL) reduce 6) ((T_IS_NOT_EQUAL) reduce 6) ((T_IS_NOT_IDENTICAL) reduce 6) ((T_IS_SMALLER_OR_EQUAL) reduce 6) ((T_LOGICAL_AND) reduce 6) ((T_LOGICAL_OR) reduce 6) ((T_LOGICAL_XOR) reduce 6) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 6) ((T_OBJECT_OPERATOR) reduce 6) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 6) ((T_POW) reduce 6) ((T_SL) reduce 6) ((T_SPACESHIP) reduce 6) ((T_SR) reduce 6) (("[") reduce 6) (("^") reduce 6) (("{") reduce 6) (("|") reduce 6) (("}") reduce 6)) 13035 ((("%") reduce 7) (("(") reduce 7) (("*") reduce 7) (("+") reduce 7) (("-") reduce 7) ((".") reduce 7) (("/") reduce 7) (("<") reduce 7) ((">") reduce 7) (("?") reduce 7) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_BOOLEAN_AND) reduce 7) ((T_BOOLEAN_OR) reduce 7) ((T_COALESCE) reduce 7) ((T_INSTANCEOF) reduce 7) ((T_IS_EQUAL) reduce 7) ((T_IS_GREATER_OR_EQUAL) reduce 7) ((T_IS_IDENTICAL) reduce 7) ((T_IS_NOT_EQUAL) reduce 7) ((T_IS_NOT_IDENTICAL) reduce 7) ((T_IS_SMALLER_OR_EQUAL) reduce 7) ((T_LOGICAL_AND) reduce 7) ((T_LOGICAL_OR) reduce 7) ((T_LOGICAL_XOR) reduce 7) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 7) ((T_OBJECT_OPERATOR) reduce 7) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 7) ((T_POW) reduce 7) ((T_SL) reduce 7) ((T_SPACESHIP) reduce 7) ((T_SR) reduce 7) (("[") reduce 7) (("^") reduce 7) (("{") reduce 7) (("|") reduce 7) (("}") reduce 7)) 13036 ((("%") reduce 69) (("(") reduce 69) (("*") reduce 69) (("+") reduce 69) (("-") reduce 69) ((".") reduce 69) (("/") reduce 69) (("<") reduce 69) ((">") reduce 69) (("?") reduce 69) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_BOOLEAN_AND) reduce 69) ((T_BOOLEAN_OR) reduce 69) ((T_COALESCE) reduce 69) ((T_INSTANCEOF) reduce 69) ((T_IS_EQUAL) reduce 69) ((T_IS_GREATER_OR_EQUAL) reduce 69) ((T_IS_IDENTICAL) reduce 69) ((T_IS_NOT_EQUAL) reduce 69) ((T_IS_NOT_IDENTICAL) reduce 69) ((T_IS_SMALLER_OR_EQUAL) reduce 69) ((T_LOGICAL_AND) reduce 69) ((T_LOGICAL_OR) reduce 69) ((T_LOGICAL_XOR) reduce 69) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 69) ((T_OBJECT_OPERATOR) reduce 69) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 69) ((T_POW) reduce 69) ((T_SL) reduce 69) ((T_SPACESHIP) reduce 69) ((T_SR) reduce 69) (("[") reduce 69) (("^") reduce 69) (("{") reduce 69) (("|") reduce 69) (("}") reduce 69)) 13037 ((("%") reduce 63) (("(") reduce 63) (("*") reduce 63) (("+") reduce 63) (("-") reduce 63) ((".") reduce 63) (("/") reduce 63) (("<") reduce 63) ((">") reduce 63) (("?") reduce 63) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_BOOLEAN_AND) reduce 63) ((T_BOOLEAN_OR) reduce 63) ((T_COALESCE) reduce 63) ((T_INSTANCEOF) reduce 63) ((T_IS_EQUAL) reduce 63) ((T_IS_GREATER_OR_EQUAL) reduce 63) ((T_IS_IDENTICAL) reduce 63) ((T_IS_NOT_EQUAL) reduce 63) ((T_IS_NOT_IDENTICAL) reduce 63) ((T_IS_SMALLER_OR_EQUAL) reduce 63) ((T_LOGICAL_AND) reduce 63) ((T_LOGICAL_OR) reduce 63) ((T_LOGICAL_XOR) reduce 63) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 63) ((T_OBJECT_OPERATOR) reduce 63) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 63) ((T_POW) reduce 63) ((T_SL) reduce 63) ((T_SPACESHIP) reduce 63) ((T_SR) reduce 63) (("[") reduce 63) (("^") reduce 63) (("{") reduce 63) (("|") reduce 63) (("}") reduce 63)) 13038 ((("%") reduce 56) (("(") reduce 56) (("*") reduce 56) (("+") reduce 56) (("-") reduce 56) ((".") reduce 56) (("/") reduce 56) (("<") reduce 56) ((">") reduce 56) (("?") reduce 56) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_BOOLEAN_AND) reduce 56) ((T_BOOLEAN_OR) reduce 56) ((T_COALESCE) reduce 56) ((T_INSTANCEOF) reduce 56) ((T_IS_EQUAL) reduce 56) ((T_IS_GREATER_OR_EQUAL) reduce 56) ((T_IS_IDENTICAL) reduce 56) ((T_IS_NOT_EQUAL) reduce 56) ((T_IS_NOT_IDENTICAL) reduce 56) ((T_IS_SMALLER_OR_EQUAL) reduce 56) ((T_LOGICAL_AND) reduce 56) ((T_LOGICAL_OR) reduce 56) ((T_LOGICAL_XOR) reduce 56) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 56) ((T_OBJECT_OPERATOR) reduce 56) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 56) ((T_POW) reduce 56) ((T_SL) reduce 56) ((T_SPACESHIP) reduce 56) ((T_SR) reduce 56) (("[") reduce 56) (("^") reduce 56) (("{") reduce 56) (("|") reduce 56) (("}") reduce 56)) 13039 ((("%") reduce 10) (("(") reduce 10) (("*") reduce 10) (("+") reduce 10) (("-") reduce 10) ((".") reduce 10) (("/") reduce 10) (("<") reduce 10) ((">") reduce 10) (("?") reduce 10) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_BOOLEAN_AND) reduce 10) ((T_BOOLEAN_OR) reduce 10) ((T_COALESCE) reduce 10) ((T_INSTANCEOF) reduce 10) ((T_IS_EQUAL) reduce 10) ((T_IS_GREATER_OR_EQUAL) reduce 10) ((T_IS_IDENTICAL) reduce 10) ((T_IS_NOT_EQUAL) reduce 10) ((T_IS_NOT_IDENTICAL) reduce 10) ((T_IS_SMALLER_OR_EQUAL) reduce 10) ((T_LOGICAL_AND) reduce 10) ((T_LOGICAL_OR) reduce 10) ((T_LOGICAL_XOR) reduce 10) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 10) ((T_OBJECT_OPERATOR) reduce 10) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 10) ((T_POW) reduce 10) ((T_SL) reduce 10) ((T_SPACESHIP) reduce 10) ((T_SR) reduce 10) (("[") reduce 10) (("^") reduce 10) (("{") reduce 10) (("|") reduce 10) (("}") reduce 10)) 13040 ((("%") reduce 67) (("(") reduce 67) (("*") reduce 67) (("+") reduce 67) (("-") reduce 67) ((".") reduce 67) (("/") reduce 67) (("<") reduce 67) ((">") reduce 67) (("?") reduce 67) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_BOOLEAN_AND) reduce 67) ((T_BOOLEAN_OR) reduce 67) ((T_COALESCE) reduce 67) ((T_INSTANCEOF) reduce 67) ((T_IS_EQUAL) reduce 67) ((T_IS_GREATER_OR_EQUAL) reduce 67) ((T_IS_IDENTICAL) reduce 67) ((T_IS_NOT_EQUAL) reduce 67) ((T_IS_NOT_IDENTICAL) reduce 67) ((T_IS_SMALLER_OR_EQUAL) reduce 67) ((T_LOGICAL_AND) reduce 67) ((T_LOGICAL_OR) reduce 67) ((T_LOGICAL_XOR) reduce 67) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 67) ((T_OBJECT_OPERATOR) reduce 67) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 67) ((T_POW) reduce 67) ((T_SL) reduce 67) ((T_SPACESHIP) reduce 67) ((T_SR) reduce 67) (("[") reduce 67) (("^") reduce 67) (("{") reduce 67) (("|") reduce 67) (("}") reduce 67)) 13041 ((("%") reduce 44) (("(") reduce 44) (("*") reduce 44) (("+") reduce 44) (("-") reduce 44) ((".") reduce 44) (("/") reduce 44) (("<") reduce 44) ((">") reduce 44) (("?") reduce 44) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_BOOLEAN_AND) reduce 44) ((T_BOOLEAN_OR) reduce 44) ((T_COALESCE) reduce 44) ((T_INSTANCEOF) reduce 44) ((T_IS_EQUAL) reduce 44) ((T_IS_GREATER_OR_EQUAL) reduce 44) ((T_IS_IDENTICAL) reduce 44) ((T_IS_NOT_EQUAL) reduce 44) ((T_IS_NOT_IDENTICAL) reduce 44) ((T_IS_SMALLER_OR_EQUAL) reduce 44) ((T_LOGICAL_AND) reduce 44) ((T_LOGICAL_OR) reduce 44) ((T_LOGICAL_XOR) reduce 44) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 44) ((T_OBJECT_OPERATOR) reduce 44) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 44) ((T_POW) reduce 44) ((T_SL) reduce 44) ((T_SPACESHIP) reduce 44) ((T_SR) reduce 44) (("[") reduce 44) (("^") reduce 44) (("{") reduce 44) (("|") reduce 44) (("}") reduce 44)) 13042 ((("%") reduce 75) (("(") reduce 75) (("*") reduce 75) (("+") reduce 75) (("-") reduce 75) ((".") reduce 75) (("/") reduce 75) (("<") reduce 75) ((">") reduce 75) (("?") reduce 75) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_BOOLEAN_AND) reduce 75) ((T_BOOLEAN_OR) reduce 75) ((T_COALESCE) reduce 75) ((T_INSTANCEOF) reduce 75) ((T_IS_EQUAL) reduce 75) ((T_IS_GREATER_OR_EQUAL) reduce 75) ((T_IS_IDENTICAL) reduce 75) ((T_IS_NOT_EQUAL) reduce 75) ((T_IS_NOT_IDENTICAL) reduce 75) ((T_IS_SMALLER_OR_EQUAL) reduce 75) ((T_LOGICAL_AND) reduce 75) ((T_LOGICAL_OR) reduce 75) ((T_LOGICAL_XOR) reduce 75) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 75) ((T_OBJECT_OPERATOR) reduce 75) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 75) ((T_POW) reduce 75) ((T_SL) reduce 75) ((T_SPACESHIP) reduce 75) ((T_SR) reduce 75) (("[") reduce 75) (("^") reduce 75) (("{") reduce 75) (("|") reduce 75) (("}") reduce 75)) 13043 ((("%") reduce 76) (("(") reduce 76) (("*") reduce 76) (("+") reduce 76) (("-") reduce 76) ((".") reduce 76) (("/") reduce 76) (("<") reduce 76) ((">") reduce 76) (("?") reduce 76) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_BOOLEAN_AND) reduce 76) ((T_BOOLEAN_OR) reduce 76) ((T_COALESCE) reduce 76) ((T_INSTANCEOF) reduce 76) ((T_IS_EQUAL) reduce 76) ((T_IS_GREATER_OR_EQUAL) reduce 76) ((T_IS_IDENTICAL) reduce 76) ((T_IS_NOT_EQUAL) reduce 76) ((T_IS_NOT_IDENTICAL) reduce 76) ((T_IS_SMALLER_OR_EQUAL) reduce 76) ((T_LOGICAL_AND) reduce 76) ((T_LOGICAL_OR) reduce 76) ((T_LOGICAL_XOR) reduce 76) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 76) ((T_OBJECT_OPERATOR) reduce 76) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 76) ((T_POW) reduce 76) ((T_SL) reduce 76) ((T_SPACESHIP) reduce 76) ((T_SR) reduce 76) (("[") reduce 76) (("^") reduce 76) (("{") reduce 76) (("|") reduce 76) (("}") reduce 76)) 13044 ((("%") reduce 77) (("(") reduce 77) (("*") reduce 77) (("+") reduce 77) (("-") reduce 77) ((".") reduce 77) (("/") reduce 77) (("<") reduce 77) ((">") reduce 77) (("?") reduce 77) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_BOOLEAN_AND) reduce 77) ((T_BOOLEAN_OR) reduce 77) ((T_COALESCE) reduce 77) ((T_INSTANCEOF) reduce 77) ((T_IS_EQUAL) reduce 77) ((T_IS_GREATER_OR_EQUAL) reduce 77) ((T_IS_IDENTICAL) reduce 77) ((T_IS_NOT_EQUAL) reduce 77) ((T_IS_NOT_IDENTICAL) reduce 77) ((T_IS_SMALLER_OR_EQUAL) reduce 77) ((T_LOGICAL_AND) reduce 77) ((T_LOGICAL_OR) reduce 77) ((T_LOGICAL_XOR) reduce 77) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 77) ((T_OBJECT_OPERATOR) reduce 77) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 77) ((T_POW) reduce 77) ((T_SL) reduce 77) ((T_SPACESHIP) reduce 77) ((T_SR) reduce 77) (("[") reduce 77) (("^") reduce 77) (("{") reduce 77) (("|") reduce 77) (("}") reduce 77)) 13045 ((("%") reduce 78) (("(") reduce 78) (("*") reduce 78) (("+") reduce 78) (("-") reduce 78) ((".") reduce 78) (("/") reduce 78) (("<") reduce 78) ((">") reduce 78) (("?") reduce 78) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_BOOLEAN_AND) reduce 78) ((T_BOOLEAN_OR) reduce 78) ((T_COALESCE) reduce 78) ((T_INSTANCEOF) reduce 78) ((T_IS_EQUAL) reduce 78) ((T_IS_GREATER_OR_EQUAL) reduce 78) ((T_IS_IDENTICAL) reduce 78) ((T_IS_NOT_EQUAL) reduce 78) ((T_IS_NOT_IDENTICAL) reduce 78) ((T_IS_SMALLER_OR_EQUAL) reduce 78) ((T_LOGICAL_AND) reduce 78) ((T_LOGICAL_OR) reduce 78) ((T_LOGICAL_XOR) reduce 78) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 78) ((T_OBJECT_OPERATOR) reduce 78) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 78) ((T_POW) reduce 78) ((T_SL) reduce 78) ((T_SPACESHIP) reduce 78) ((T_SR) reduce 78) (("[") reduce 78) (("^") reduce 78) (("{") reduce 78) (("|") reduce 78) (("}") reduce 78)) 13046 ((("%") reduce 4) (("(") reduce 4) (("*") reduce 4) (("+") reduce 4) (("-") reduce 4) ((".") reduce 4) (("/") reduce 4) (("<") reduce 4) ((">") reduce 4) (("?") reduce 4) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_BOOLEAN_AND) reduce 4) ((T_BOOLEAN_OR) reduce 4) ((T_COALESCE) reduce 4) ((T_INSTANCEOF) reduce 4) ((T_IS_EQUAL) reduce 4) ((T_IS_GREATER_OR_EQUAL) reduce 4) ((T_IS_IDENTICAL) reduce 4) ((T_IS_NOT_EQUAL) reduce 4) ((T_IS_NOT_IDENTICAL) reduce 4) ((T_IS_SMALLER_OR_EQUAL) reduce 4) ((T_LOGICAL_AND) reduce 4) ((T_LOGICAL_OR) reduce 4) ((T_LOGICAL_XOR) reduce 4) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 4) ((T_OBJECT_OPERATOR) reduce 4) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 4) ((T_POW) reduce 4) ((T_SL) reduce 4) ((T_SPACESHIP) reduce 4) ((T_SR) reduce 4) (("[") reduce 4) (("^") reduce 4) (("{") reduce 4) (("|") reduce 4) (("}") reduce 4)) 13047 ((("%") reduce 5) (("(") reduce 5) (("*") reduce 5) (("+") reduce 5) (("-") reduce 5) ((".") reduce 5) (("/") reduce 5) (("<") reduce 5) ((">") reduce 5) (("?") reduce 5) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_BOOLEAN_AND) reduce 5) ((T_BOOLEAN_OR) reduce 5) ((T_COALESCE) reduce 5) ((T_INSTANCEOF) reduce 5) ((T_IS_EQUAL) reduce 5) ((T_IS_GREATER_OR_EQUAL) reduce 5) ((T_IS_IDENTICAL) reduce 5) ((T_IS_NOT_EQUAL) reduce 5) ((T_IS_NOT_IDENTICAL) reduce 5) ((T_IS_SMALLER_OR_EQUAL) reduce 5) ((T_LOGICAL_AND) reduce 5) ((T_LOGICAL_OR) reduce 5) ((T_LOGICAL_XOR) reduce 5) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 5) ((T_OBJECT_OPERATOR) reduce 5) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 5) ((T_POW) reduce 5) ((T_SL) reduce 5) ((T_SPACESHIP) reduce 5) ((T_SR) reduce 5) (("[") reduce 5) (("^") reduce 5) (("{") reduce 5) (("|") reduce 5) (("}") reduce 5)) 13048 ((("%") reduce 43) (("(") reduce 43) (("*") reduce 43) (("+") reduce 43) (("-") reduce 43) ((".") reduce 43) (("/") reduce 43) (("<") reduce 43) ((">") reduce 43) (("?") reduce 43) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_BOOLEAN_AND) reduce 43) ((T_BOOLEAN_OR) reduce 43) ((T_COALESCE) reduce 43) ((T_INSTANCEOF) reduce 43) ((T_IS_EQUAL) reduce 43) ((T_IS_GREATER_OR_EQUAL) reduce 43) ((T_IS_IDENTICAL) reduce 43) ((T_IS_NOT_EQUAL) reduce 43) ((T_IS_NOT_IDENTICAL) reduce 43) ((T_IS_SMALLER_OR_EQUAL) reduce 43) ((T_LOGICAL_AND) reduce 43) ((T_LOGICAL_OR) reduce 43) ((T_LOGICAL_XOR) reduce 43) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 43) ((T_OBJECT_OPERATOR) reduce 43) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 43) ((T_POW) reduce 43) ((T_SL) reduce 43) ((T_SPACESHIP) reduce 43) ((T_SR) reduce 43) (("[") reduce 43) (("^") reduce 43) (("{") reduce 43) (("|") reduce 43) (("}") reduce 43)) 13049 ((("%") reduce 72) (("(") reduce 72) (("*") reduce 72) (("+") reduce 72) (("-") reduce 72) ((".") reduce 72) (("/") reduce 72) (("<") reduce 72) ((">") reduce 72) (("?") reduce 72) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_BOOLEAN_AND) reduce 72) ((T_BOOLEAN_OR) reduce 72) ((T_COALESCE) reduce 72) ((T_INSTANCEOF) reduce 72) ((T_IS_EQUAL) reduce 72) ((T_IS_GREATER_OR_EQUAL) reduce 72) ((T_IS_IDENTICAL) reduce 72) ((T_IS_NOT_EQUAL) reduce 72) ((T_IS_NOT_IDENTICAL) reduce 72) ((T_IS_SMALLER_OR_EQUAL) reduce 72) ((T_LOGICAL_AND) reduce 72) ((T_LOGICAL_OR) reduce 72) ((T_LOGICAL_XOR) reduce 72) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 72) ((T_OBJECT_OPERATOR) reduce 72) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 72) ((T_POW) reduce 72) ((T_SL) reduce 72) ((T_SPACESHIP) reduce 72) ((T_SR) reduce 72) (("[") reduce 72) (("^") reduce 72) (("{") reduce 72) (("|") reduce 72) (("}") reduce 72)) 13050 ((("%") reduce 81) (("(") reduce 81) (("*") reduce 81) (("+") reduce 81) (("-") reduce 81) ((".") reduce 81) (("/") reduce 81) (("<") reduce 81) ((">") reduce 81) (("?") reduce 81) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_BOOLEAN_AND) reduce 81) ((T_BOOLEAN_OR) reduce 81) ((T_COALESCE) reduce 81) ((T_INSTANCEOF) reduce 81) ((T_IS_EQUAL) reduce 81) ((T_IS_GREATER_OR_EQUAL) reduce 81) ((T_IS_IDENTICAL) reduce 81) ((T_IS_NOT_EQUAL) reduce 81) ((T_IS_NOT_IDENTICAL) reduce 81) ((T_IS_SMALLER_OR_EQUAL) reduce 81) ((T_LOGICAL_AND) reduce 81) ((T_LOGICAL_OR) reduce 81) ((T_LOGICAL_XOR) reduce 81) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 81) ((T_OBJECT_OPERATOR) reduce 81) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 81) ((T_POW) reduce 81) ((T_SL) reduce 81) ((T_SPACESHIP) reduce 81) ((T_SR) reduce 81) (("[") reduce 81) (("^") reduce 81) (("{") reduce 81) (("|") reduce 81) (("}") reduce 81)) 13051 ((("%") reduce 47) (("(") reduce 47) (("*") reduce 47) (("+") reduce 47) (("-") reduce 47) ((".") reduce 47) (("/") reduce 47) (("<") reduce 47) ((">") reduce 47) (("?") reduce 47) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_BOOLEAN_AND) reduce 47) ((T_BOOLEAN_OR) reduce 47) ((T_COALESCE) reduce 47) ((T_INSTANCEOF) reduce 47) ((T_IS_EQUAL) reduce 47) ((T_IS_GREATER_OR_EQUAL) reduce 47) ((T_IS_IDENTICAL) reduce 47) ((T_IS_NOT_EQUAL) reduce 47) ((T_IS_NOT_IDENTICAL) reduce 47) ((T_IS_SMALLER_OR_EQUAL) reduce 47) ((T_LOGICAL_AND) reduce 47) ((T_LOGICAL_OR) reduce 47) ((T_LOGICAL_XOR) reduce 47) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 47) ((T_OBJECT_OPERATOR) reduce 47) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 47) ((T_POW) reduce 47) ((T_SL) reduce 47) ((T_SPACESHIP) reduce 47) ((T_SR) reduce 47) (("[") reduce 47) (("^") reduce 47) (("{") reduce 47) (("|") reduce 47) (("}") reduce 47)) 13052 ((("%") reduce 31) (("(") reduce 31) (("*") reduce 31) (("+") reduce 31) (("-") reduce 31) ((".") reduce 31) (("/") reduce 31) (("<") reduce 31) ((">") reduce 31) (("?") reduce 31) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_BOOLEAN_AND) reduce 31) ((T_BOOLEAN_OR) reduce 31) ((T_COALESCE) reduce 31) ((T_INSTANCEOF) reduce 31) ((T_IS_EQUAL) reduce 31) ((T_IS_GREATER_OR_EQUAL) reduce 31) ((T_IS_IDENTICAL) reduce 31) ((T_IS_NOT_EQUAL) reduce 31) ((T_IS_NOT_IDENTICAL) reduce 31) ((T_IS_SMALLER_OR_EQUAL) reduce 31) ((T_LOGICAL_AND) reduce 31) ((T_LOGICAL_OR) reduce 31) ((T_LOGICAL_XOR) reduce 31) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 31) ((T_OBJECT_OPERATOR) reduce 31) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 31) ((T_POW) reduce 31) ((T_SL) reduce 31) ((T_SPACESHIP) reduce 31) ((T_SR) reduce 31) (("[") reduce 31) (("^") reduce 31) (("{") reduce 31) (("|") reduce 31) (("}") reduce 31)) 13053 ((("%") reduce 57) (("(") reduce 57) (("*") reduce 57) (("+") reduce 57) (("-") reduce 57) ((".") reduce 57) (("/") reduce 57) (("<") reduce 57) ((">") reduce 57) (("?") reduce 57) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_BOOLEAN_AND) reduce 57) ((T_BOOLEAN_OR) reduce 57) ((T_COALESCE) reduce 57) ((T_INSTANCEOF) reduce 57) ((T_IS_EQUAL) reduce 57) ((T_IS_GREATER_OR_EQUAL) reduce 57) ((T_IS_IDENTICAL) reduce 57) ((T_IS_NOT_EQUAL) reduce 57) ((T_IS_NOT_IDENTICAL) reduce 57) ((T_IS_SMALLER_OR_EQUAL) reduce 57) ((T_LOGICAL_AND) reduce 57) ((T_LOGICAL_OR) reduce 57) ((T_LOGICAL_XOR) reduce 57) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 57) ((T_OBJECT_OPERATOR) reduce 57) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 57) ((T_POW) reduce 57) ((T_SL) reduce 57) ((T_SPACESHIP) reduce 57) ((T_SR) reduce 57) (("[") reduce 57) (("^") reduce 57) (("{") reduce 57) (("|") reduce 57) (("}") reduce 57)) 13054 ((("%") reduce 61) (("(") reduce 61) (("*") reduce 61) (("+") reduce 61) (("-") reduce 61) ((".") reduce 61) (("/") reduce 61) (("<") reduce 61) ((">") reduce 61) (("?") reduce 61) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_BOOLEAN_AND) reduce 61) ((T_BOOLEAN_OR) reduce 61) ((T_COALESCE) reduce 61) ((T_INSTANCEOF) reduce 61) ((T_IS_EQUAL) reduce 61) ((T_IS_GREATER_OR_EQUAL) reduce 61) ((T_IS_IDENTICAL) reduce 61) ((T_IS_NOT_EQUAL) reduce 61) ((T_IS_NOT_IDENTICAL) reduce 61) ((T_IS_SMALLER_OR_EQUAL) reduce 61) ((T_LOGICAL_AND) reduce 61) ((T_LOGICAL_OR) reduce 61) ((T_LOGICAL_XOR) reduce 61) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 61) ((T_OBJECT_OPERATOR) reduce 61) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 61) ((T_POW) reduce 61) ((T_SL) reduce 61) ((T_SPACESHIP) reduce 61) ((T_SR) reduce 61) (("[") reduce 61) (("^") reduce 61) (("{") reduce 61) (("|") reduce 61) (("}") reduce 61)) 13055 ((("%") reduce 28) (("(") reduce 28) (("*") reduce 28) (("+") reduce 28) (("-") reduce 28) ((".") reduce 28) (("/") reduce 28) (("<") reduce 28) ((">") reduce 28) (("?") reduce 28) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_BOOLEAN_AND) reduce 28) ((T_BOOLEAN_OR) reduce 28) ((T_COALESCE) reduce 28) ((T_INSTANCEOF) reduce 28) ((T_IS_EQUAL) reduce 28) ((T_IS_GREATER_OR_EQUAL) reduce 28) ((T_IS_IDENTICAL) reduce 28) ((T_IS_NOT_EQUAL) reduce 28) ((T_IS_NOT_IDENTICAL) reduce 28) ((T_IS_SMALLER_OR_EQUAL) reduce 28) ((T_LOGICAL_AND) reduce 28) ((T_LOGICAL_OR) reduce 28) ((T_LOGICAL_XOR) reduce 28) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 28) ((T_OBJECT_OPERATOR) reduce 28) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 28) ((T_POW) reduce 28) ((T_SL) reduce 28) ((T_SPACESHIP) reduce 28) ((T_SR) reduce 28) (("[") reduce 28) (("^") reduce 28) (("{") reduce 28) (("|") reduce 28) (("}") reduce 28)) 13056 ((("%") reduce 36) (("(") reduce 36) (("*") reduce 36) (("+") reduce 36) (("-") reduce 36) ((".") reduce 36) (("/") reduce 36) (("<") reduce 36) ((">") reduce 36) (("?") reduce 36) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_BOOLEAN_AND) reduce 36) ((T_BOOLEAN_OR) reduce 36) ((T_COALESCE) reduce 36) ((T_INSTANCEOF) reduce 36) ((T_IS_EQUAL) reduce 36) ((T_IS_GREATER_OR_EQUAL) reduce 36) ((T_IS_IDENTICAL) reduce 36) ((T_IS_NOT_EQUAL) reduce 36) ((T_IS_NOT_IDENTICAL) reduce 36) ((T_IS_SMALLER_OR_EQUAL) reduce 36) ((T_LOGICAL_AND) reduce 36) ((T_LOGICAL_OR) reduce 36) ((T_LOGICAL_XOR) reduce 36) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 36) ((T_OBJECT_OPERATOR) reduce 36) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 36) ((T_POW) reduce 36) ((T_SL) reduce 36) ((T_SPACESHIP) reduce 36) ((T_SR) reduce 36) (("[") reduce 36) (("^") reduce 36) (("{") reduce 36) (("|") reduce 36) (("}") reduce 36)) 13057 ((("%") reduce 32) (("(") reduce 32) (("*") reduce 32) (("+") reduce 32) (("-") reduce 32) ((".") reduce 32) (("/") reduce 32) (("<") reduce 32) ((">") reduce 32) (("?") reduce 32) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_BOOLEAN_AND) reduce 32) ((T_BOOLEAN_OR) reduce 32) ((T_COALESCE) reduce 32) ((T_INSTANCEOF) reduce 32) ((T_IS_EQUAL) reduce 32) ((T_IS_GREATER_OR_EQUAL) reduce 32) ((T_IS_IDENTICAL) reduce 32) ((T_IS_NOT_EQUAL) reduce 32) ((T_IS_NOT_IDENTICAL) reduce 32) ((T_IS_SMALLER_OR_EQUAL) reduce 32) ((T_LOGICAL_AND) reduce 32) ((T_LOGICAL_OR) reduce 32) ((T_LOGICAL_XOR) reduce 32) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 32) ((T_OBJECT_OPERATOR) reduce 32) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 32) ((T_POW) reduce 32) ((T_SL) reduce 32) ((T_SPACESHIP) reduce 32) ((T_SR) reduce 32) (("[") reduce 32) (("^") reduce 32) (("{") reduce 32) (("|") reduce 32) (("}") reduce 32)) 13058 ((("%") reduce 35) (("(") reduce 35) (("*") reduce 35) (("+") reduce 35) (("-") reduce 35) ((".") reduce 35) (("/") reduce 35) (("<") reduce 35) ((">") reduce 35) (("?") reduce 35) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_BOOLEAN_AND) reduce 35) ((T_BOOLEAN_OR) reduce 35) ((T_COALESCE) reduce 35) ((T_INSTANCEOF) reduce 35) ((T_IS_EQUAL) reduce 35) ((T_IS_GREATER_OR_EQUAL) reduce 35) ((T_IS_IDENTICAL) reduce 35) ((T_IS_NOT_EQUAL) reduce 35) ((T_IS_NOT_IDENTICAL) reduce 35) ((T_IS_SMALLER_OR_EQUAL) reduce 35) ((T_LOGICAL_AND) reduce 35) ((T_LOGICAL_OR) reduce 35) ((T_LOGICAL_XOR) reduce 35) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 35) ((T_OBJECT_OPERATOR) reduce 35) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 35) ((T_POW) reduce 35) ((T_SL) reduce 35) ((T_SPACESHIP) reduce 35) ((T_SR) reduce 35) (("[") reduce 35) (("^") reduce 35) (("{") reduce 35) (("|") reduce 35) (("}") reduce 35)) 13059 ((("%") reduce 19) (("(") reduce 19) (("*") reduce 19) (("+") reduce 19) (("-") reduce 19) ((".") reduce 19) (("/") reduce 19) (("<") reduce 19) ((">") reduce 19) (("?") reduce 19) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_BOOLEAN_AND) reduce 19) ((T_BOOLEAN_OR) reduce 19) ((T_COALESCE) reduce 19) ((T_INSTANCEOF) reduce 19) ((T_IS_EQUAL) reduce 19) ((T_IS_GREATER_OR_EQUAL) reduce 19) ((T_IS_IDENTICAL) reduce 19) ((T_IS_NOT_EQUAL) reduce 19) ((T_IS_NOT_IDENTICAL) reduce 19) ((T_IS_SMALLER_OR_EQUAL) reduce 19) ((T_LOGICAL_AND) reduce 19) ((T_LOGICAL_OR) reduce 19) ((T_LOGICAL_XOR) reduce 19) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 19) ((T_OBJECT_OPERATOR) reduce 19) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 19) ((T_POW) reduce 19) ((T_SL) reduce 19) ((T_SPACESHIP) reduce 19) ((T_SR) reduce 19) (("[") reduce 19) (("^") reduce 19) (("{") reduce 19) (("|") reduce 19) (("}") reduce 19)) 13060 ((("%") reduce 45) (("(") reduce 45) (("*") reduce 45) (("+") reduce 45) (("-") reduce 45) ((".") reduce 45) (("/") reduce 45) (("<") reduce 45) ((">") reduce 45) (("?") reduce 45) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_BOOLEAN_AND) reduce 45) ((T_BOOLEAN_OR) reduce 45) ((T_COALESCE) reduce 45) ((T_INSTANCEOF) reduce 45) ((T_IS_EQUAL) reduce 45) ((T_IS_GREATER_OR_EQUAL) reduce 45) ((T_IS_IDENTICAL) reduce 45) ((T_IS_NOT_EQUAL) reduce 45) ((T_IS_NOT_IDENTICAL) reduce 45) ((T_IS_SMALLER_OR_EQUAL) reduce 45) ((T_LOGICAL_AND) reduce 45) ((T_LOGICAL_OR) reduce 45) ((T_LOGICAL_XOR) reduce 45) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 45) ((T_OBJECT_OPERATOR) reduce 45) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 45) ((T_POW) reduce 45) ((T_SL) reduce 45) ((T_SPACESHIP) reduce 45) ((T_SR) reduce 45) (("[") reduce 45) (("^") reduce 45) (("{") reduce 45) (("|") reduce 45) (("}") reduce 45)) 13061 ((("%") reduce 504) (("(") reduce 541) (("*") reduce 504) (("+") reduce 504) (("-") reduce 504) ((".") reduce 504) (("/") reduce 504) (("<") reduce 504) ((">") reduce 504) (("?") reduce 504) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_BOOLEAN_AND) reduce 504) ((T_BOOLEAN_OR) reduce 504) ((T_COALESCE) reduce 504) ((T_INSTANCEOF) reduce 504) ((T_IS_EQUAL) reduce 504) ((T_IS_GREATER_OR_EQUAL) reduce 504) ((T_IS_IDENTICAL) reduce 504) ((T_IS_NOT_EQUAL) reduce 504) ((T_IS_NOT_IDENTICAL) reduce 504) ((T_IS_SMALLER_OR_EQUAL) reduce 504) ((T_LOGICAL_AND) reduce 504) ((T_LOGICAL_OR) reduce 504) ((T_LOGICAL_XOR) reduce 504) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 504) ((T_OBJECT_OPERATOR) reduce 504) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 504) ((T_POW) reduce 504) ((T_SL) reduce 504) ((T_SPACESHIP) reduce 504) ((T_SR) reduce 504) (("[") reduce 504) (("^") reduce 504) (("{") reduce 504) (("|") reduce 504) (("}") reduce 504)) 13063 ((("%") reduce 71) (("(") reduce 71) (("*") reduce 71) (("+") reduce 71) (("-") reduce 71) ((".") reduce 71) (("/") reduce 71) (("<") reduce 71) ((">") reduce 71) (("?") reduce 71) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_BOOLEAN_AND) reduce 71) ((T_BOOLEAN_OR) reduce 71) ((T_COALESCE) reduce 71) ((T_INSTANCEOF) reduce 71) ((T_IS_EQUAL) reduce 71) ((T_IS_GREATER_OR_EQUAL) reduce 71) ((T_IS_IDENTICAL) reduce 71) ((T_IS_NOT_EQUAL) reduce 71) ((T_IS_NOT_IDENTICAL) reduce 71) ((T_IS_SMALLER_OR_EQUAL) reduce 71) ((T_LOGICAL_AND) reduce 71) ((T_LOGICAL_OR) reduce 71) ((T_LOGICAL_XOR) reduce 71) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 71) ((T_OBJECT_OPERATOR) reduce 71) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 71) ((T_POW) reduce 71) ((T_SL) reduce 71) ((T_SPACESHIP) reduce 71) ((T_SR) reduce 71) (("[") reduce 71) (("^") reduce 71) (("{") reduce 71) (("|") reduce 71) (("}") reduce 71)) 13064 ((("%") reduce 82) (("(") reduce 82) (("*") reduce 82) (("+") reduce 82) (("-") reduce 82) ((".") reduce 82) (("/") reduce 82) (("<") reduce 82) ((">") reduce 82) (("?") reduce 82) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_BOOLEAN_AND) reduce 82) ((T_BOOLEAN_OR) reduce 82) ((T_COALESCE) reduce 82) ((T_INSTANCEOF) reduce 82) ((T_IS_EQUAL) reduce 82) ((T_IS_GREATER_OR_EQUAL) reduce 82) ((T_IS_IDENTICAL) reduce 82) ((T_IS_NOT_EQUAL) reduce 82) ((T_IS_NOT_IDENTICAL) reduce 82) ((T_IS_SMALLER_OR_EQUAL) reduce 82) ((T_LOGICAL_AND) reduce 82) ((T_LOGICAL_OR) reduce 82) ((T_LOGICAL_XOR) reduce 82) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 82) ((T_OBJECT_OPERATOR) reduce 82) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 82) ((T_POW) reduce 82) ((T_SL) reduce 82) ((T_SPACESHIP) reduce 82) ((T_SR) reduce 82) (("[") reduce 82) (("^") reduce 82) (("{") reduce 82) (("|") reduce 82) (("}") reduce 82)) 13065 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) (("<") reduce 533) (("=") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AND_EQUAL) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_COALESCE_EQUAL) reduce 533) ((T_CONCAT_EQUAL) reduce 533) ((T_DEC) reduce 533) ((T_DIV_EQUAL) reduce 533) ((T_INC) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_MINUS_EQUAL) reduce 533) ((T_MOD_EQUAL) reduce 533) ((T_MUL_EQUAL) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_OR_EQUAL) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_PLUS_EQUAL) reduce 533) ((T_POW) reduce 533) ((T_POW_EQUAL) reduce 533) ((T_SL) reduce 533) ((T_SL_EQUAL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) ((T_SR_EQUAL) reduce 533) ((T_XOR_EQUAL) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533) (("}") reduce 533)) 13068 ((("%") reduce 506) (("(") reduce 542) (("*") reduce 506) (("+") reduce 506) (("-") reduce 506) ((".") reduce 506) (("/") reduce 506) (("<") reduce 506) ((">") reduce 506) (("?") reduce 506) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_BOOLEAN_AND) reduce 506) ((T_BOOLEAN_OR) reduce 506) ((T_COALESCE) reduce 506) ((T_INSTANCEOF) reduce 506) ((T_IS_EQUAL) reduce 506) ((T_IS_GREATER_OR_EQUAL) reduce 506) ((T_IS_IDENTICAL) reduce 506) ((T_IS_NOT_EQUAL) reduce 506) ((T_IS_NOT_IDENTICAL) reduce 506) ((T_IS_SMALLER_OR_EQUAL) reduce 506) ((T_LOGICAL_AND) reduce 506) ((T_LOGICAL_OR) reduce 506) ((T_LOGICAL_XOR) reduce 506) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 506) ((T_OBJECT_OPERATOR) reduce 506) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 506) ((T_POW) reduce 506) ((T_SL) reduce 506) ((T_SPACESHIP) reduce 506) ((T_SR) reduce 506) (("[") reduce 506) (("^") reduce 506) (("{") reduce 506) (("|") reduce 506) (("}") reduce 506)) 13070 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) (("<") reduce 468) (("=") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AND_EQUAL) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_COALESCE_EQUAL) reduce 468) ((T_CONCAT_EQUAL) reduce 468) ((T_DEC) reduce 468) ((T_DIV_EQUAL) reduce 468) ((T_INC) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_MINUS_EQUAL) reduce 468) ((T_MOD_EQUAL) reduce 468) ((T_MUL_EQUAL) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_OR_EQUAL) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_PLUS_EQUAL) reduce 468) ((T_POW) reduce 468) ((T_POW_EQUAL) reduce 468) ((T_SL) reduce 468) ((T_SL_EQUAL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) ((T_SR_EQUAL) reduce 468) ((T_XOR_EQUAL) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468) (("}") reduce 468)) 13071 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) (("=") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AND_EQUAL) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_COALESCE_EQUAL) reduce 288) ((T_CONCAT_EQUAL) reduce 288) ((T_DEC) reduce 288) ((T_DIV_EQUAL) reduce 288) ((T_INC) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_MINUS_EQUAL) reduce 288) ((T_MOD_EQUAL) reduce 288) ((T_MUL_EQUAL) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_OR_EQUAL) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_PLUS_EQUAL) reduce 288) ((T_POW) reduce 288) ((T_POW_EQUAL) reduce 288) ((T_SL) reduce 288) ((T_SL_EQUAL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) ((T_SR_EQUAL) reduce 288) ((T_XOR_EQUAL) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288) (("}") reduce 288)) 13075 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) (("=") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AND_EQUAL) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_COALESCE_EQUAL) reduce 289) ((T_CONCAT_EQUAL) reduce 289) ((T_DEC) reduce 289) ((T_DIV_EQUAL) reduce 289) ((T_INC) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_MINUS_EQUAL) reduce 289) ((T_MOD_EQUAL) reduce 289) ((T_MUL_EQUAL) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_OR_EQUAL) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_PLUS_EQUAL) reduce 289) ((T_POW) reduce 289) ((T_POW_EQUAL) reduce 289) ((T_SL) reduce 289) ((T_SL_EQUAL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) ((T_SR_EQUAL) reduce 289) ((T_XOR_EQUAL) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289) (("}") reduce 289)) 13076 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) (("=") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AND_EQUAL) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_COALESCE_EQUAL) reduce 290) ((T_CONCAT_EQUAL) reduce 290) ((T_DEC) reduce 290) ((T_DIV_EQUAL) reduce 290) ((T_INC) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_MINUS_EQUAL) reduce 290) ((T_MOD_EQUAL) reduce 290) ((T_MUL_EQUAL) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_OR_EQUAL) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_PLUS_EQUAL) reduce 290) ((T_POW) reduce 290) ((T_POW_EQUAL) reduce 290) ((T_SL) reduce 290) ((T_SL_EQUAL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) ((T_SR_EQUAL) reduce 290) ((T_XOR_EQUAL) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290) (("}") reduce 290)) 13081 ((("%") reduce 388) (("*") reduce 388) (("+") reduce 388) (("-") reduce 388) ((".") reduce 388) (("/") reduce 388) (("<") reduce 388) ((">") reduce 388) (("?") reduce 388) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_BOOLEAN_AND) reduce 388) ((T_BOOLEAN_OR) reduce 388) ((T_COALESCE) reduce 388) ((T_INSTANCEOF) reduce 388) ((T_IS_EQUAL) reduce 388) ((T_IS_GREATER_OR_EQUAL) reduce 388) ((T_IS_IDENTICAL) reduce 388) ((T_IS_NOT_EQUAL) reduce 388) ((T_IS_NOT_IDENTICAL) reduce 388) ((T_IS_SMALLER_OR_EQUAL) reduce 388) ((T_LOGICAL_AND) reduce 388) ((T_LOGICAL_OR) reduce 388) ((T_LOGICAL_XOR) reduce 388) ((T_POW) reduce 388) ((T_SL) reduce 388) ((T_SPACESHIP) reduce 388) ((T_SR) reduce 388) (("^") reduce 388) (("|") reduce 388) (("}") reduce 388)) 13083 ((("%") reduce 386) (("*") reduce 386) (("+") reduce 386) (("-") reduce 386) ((".") reduce 386) (("/") reduce 386) (("<") reduce 386) ((">") reduce 386) (("?") reduce 386) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_BOOLEAN_AND) reduce 386) ((T_BOOLEAN_OR) reduce 386) ((T_COALESCE) reduce 386) ((T_INSTANCEOF) reduce 386) ((T_IS_EQUAL) reduce 386) ((T_IS_GREATER_OR_EQUAL) reduce 386) ((T_IS_IDENTICAL) reduce 386) ((T_IS_NOT_EQUAL) reduce 386) ((T_IS_NOT_IDENTICAL) reduce 386) ((T_IS_SMALLER_OR_EQUAL) reduce 386) ((T_LOGICAL_AND) reduce 386) ((T_LOGICAL_OR) reduce 386) ((T_LOGICAL_XOR) reduce 386) ((T_POW) reduce 386) ((T_SL) reduce 386) ((T_SPACESHIP) reduce 386) ((T_SR) reduce 386) (("^") reduce 386) (("|") reduce 386) (("}") reduce 386)) 13093 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 382) ((T_LOGICAL_OR) reduce 382) ((T_LOGICAL_XOR) reduce 382) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 382)) 13094 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 384) ((T_LOGICAL_OR) reduce 384) ((T_LOGICAL_XOR) reduce 384) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 384)) 13095 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 383) ((T_LOGICAL_OR) reduce 383) ((T_LOGICAL_XOR) reduce 383) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 383)) 13096 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 376) ((T_LOGICAL_OR) reduce 376) ((T_LOGICAL_XOR) reduce 376) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 376)) 13097 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 373) ((T_LOGICAL_OR) reduce 373) ((T_LOGICAL_XOR) reduce 373) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 373)) 13098 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 381) ((T_LOGICAL_OR) reduce 381) ((T_LOGICAL_XOR) reduce 381) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 381)) 13099 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 375) ((T_LOGICAL_OR) reduce 375) ((T_LOGICAL_XOR) reduce 375) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 375)) 13100 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 379) ((T_LOGICAL_OR) reduce 379) ((T_LOGICAL_XOR) reduce 379) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 379)) 13101 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 374) ((T_LOGICAL_OR) reduce 374) ((T_LOGICAL_XOR) reduce 374) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 374)) 13102 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 377) ((T_LOGICAL_OR) reduce 377) ((T_LOGICAL_XOR) reduce 377) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 377)) 13103 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 378) ((T_LOGICAL_OR) reduce 378) ((T_LOGICAL_XOR) reduce 378) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 378)) 13104 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 385) ((T_LOGICAL_OR) reduce 385) ((T_LOGICAL_XOR) reduce 385) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 385)) 13105 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 380) ((T_LOGICAL_OR) reduce 380) ((T_LOGICAL_XOR) reduce 380) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 380)) 13107 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 370) ((T_LOGICAL_OR) reduce 370) ((T_LOGICAL_XOR) reduce 370) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 370)) 13110 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529) (("}") reduce 529)) 13113 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) (("<") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_POW) reduce 525) ((T_SL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525) (("}") reduce 525)) 13115 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) (("<") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_POW) reduce 524) ((T_SL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524) (("}") reduce 524)) 13117 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) (("<") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_POW) reduce 519) ((T_SL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519) (("}") reduce 519)) 13118 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) (("<") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_POW) reduce 526) ((T_SL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526) (("}") reduce 526)) 13119 ((("%") reduce 371) (("*") reduce 371) (("+") reduce 371) (("-") reduce 371) ((".") reduce 371) (("/") reduce 371) (("<") reduce 371) ((">") reduce 371) (("?") reduce 371) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_BOOLEAN_AND) reduce 371) ((T_BOOLEAN_OR) reduce 371) ((T_COALESCE) reduce 371) ((T_INSTANCEOF) reduce 371) ((T_IS_EQUAL) reduce 371) ((T_IS_GREATER_OR_EQUAL) reduce 371) ((T_IS_IDENTICAL) reduce 371) ((T_IS_NOT_EQUAL) reduce 371) ((T_IS_NOT_IDENTICAL) reduce 371) ((T_IS_SMALLER_OR_EQUAL) reduce 371) ((T_LOGICAL_AND) reduce 371) ((T_LOGICAL_OR) reduce 371) ((T_LOGICAL_XOR) reduce 371) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 371) ((T_SL) reduce 371) ((T_SPACESHIP) reduce 371) ((T_SR) reduce 371) (("[") reduce 510) (("^") reduce 371) (("{") reduce 510) (("|") reduce 371) (("}") reduce 371)) 13123 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) (("<") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_POW) reduce 533) ((T_SL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533) (("}") reduce 533)) 13125 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) (("<") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_POW) reduce 468) ((T_SL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468) (("}") reduce 468)) 13126 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288) (("}") reduce 288)) 13130 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289) (("}") reduce 289)) 13131 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290) (("}") reduce 290)) 13132 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) (("<") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_POW) reduce 465) ((T_SL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465) (("}") reduce 465)) 13135 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) (("<") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_POW) reduce 532) ((T_SL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532) (("}") reduce 532)) 13136 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) (("<") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_POW) reduce 467) ((T_SL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467) (("}") reduce 467)) 13137 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) (("<") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_POW) reduce 469) ((T_SL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469) (("}") reduce 469)) 13143 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) (("<") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_POW) reduce 521) ((T_SL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521) (("}") reduce 521)) 13145 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) (("<") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_POW) reduce 520) ((T_SL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520) (("}") reduce 520)) 13146 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544) (("}") reduce 544)) 13147 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) (("<") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_POW) reduce 527) ((T_SL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527) (("}") reduce 527)) 13148 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546) (("}") reduce 546)) 13151 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545) (("}") reduce 545)) 13152 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) (("<") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_POW) reduce 522) ((T_SL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522) (("}") reduce 522)) 13153 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) (("<") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_POW) reduce 528) ((T_SL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528) (("}") reduce 528)) 13154 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) (("<") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_POW) reduce 523) ((T_SL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523) (("}") reduce 523)) 13155 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) (("<") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_POW) reduce 466) ((T_SL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466) (("}") reduce 466)) 13156 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531) (("}") reduce 531)) 13159 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530) (("}") reduce 530)) 13160 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) (("<") reduce 465) (("=") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AND_EQUAL) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_COALESCE_EQUAL) reduce 465) ((T_CONCAT_EQUAL) reduce 465) ((T_DEC) reduce 465) ((T_DIV_EQUAL) reduce 465) ((T_INC) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_MINUS_EQUAL) reduce 465) ((T_MOD_EQUAL) reduce 465) ((T_MUL_EQUAL) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_OR_EQUAL) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_PLUS_EQUAL) reduce 465) ((T_POW) reduce 465) ((T_POW_EQUAL) reduce 465) ((T_SL) reduce 465) ((T_SL_EQUAL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) ((T_SR_EQUAL) reduce 465) ((T_XOR_EQUAL) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465) (("}") reduce 465)) 13171 ((("%") reduce 455) (("*") reduce 455) (("+") reduce 455) (("-") reduce 455) ((".") reduce 455) (("/") reduce 455) (("<") reduce 455) ((">") reduce 455) (("?") reduce 455) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_BOOLEAN_AND) reduce 455) ((T_BOOLEAN_OR) reduce 455) ((T_COALESCE) reduce 455) ((T_INSTANCEOF) reduce 455) ((T_IS_EQUAL) reduce 455) ((T_IS_GREATER_OR_EQUAL) reduce 455) ((T_IS_IDENTICAL) reduce 455) ((T_IS_NOT_EQUAL) reduce 455) ((T_IS_NOT_IDENTICAL) reduce 455) ((T_IS_SMALLER_OR_EQUAL) reduce 455) ((T_LOGICAL_AND) reduce 455) ((T_LOGICAL_OR) reduce 455) ((T_LOGICAL_XOR) reduce 455) ((T_POW) reduce 455) ((T_SL) reduce 455) ((T_SPACESHIP) reduce 455) ((T_SR) reduce 455) (("^") reduce 455) (("|") reduce 455) (("}") reduce 455)) 13172 ((("%") reduce 450) (("*") reduce 450) (("+") reduce 450) (("-") reduce 450) ((".") reduce 450) (("/") reduce 450) (("<") reduce 450) ((">") reduce 450) (("?") reduce 450) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_BOOLEAN_AND) reduce 450) ((T_BOOLEAN_OR) reduce 450) ((T_COALESCE) reduce 450) ((T_INSTANCEOF) reduce 450) ((T_IS_EQUAL) reduce 450) ((T_IS_GREATER_OR_EQUAL) reduce 450) ((T_IS_IDENTICAL) reduce 450) ((T_IS_NOT_EQUAL) reduce 450) ((T_IS_NOT_IDENTICAL) reduce 450) ((T_IS_SMALLER_OR_EQUAL) reduce 450) ((T_LOGICAL_AND) reduce 450) ((T_LOGICAL_OR) reduce 450) ((T_LOGICAL_XOR) reduce 450) ((T_POW) reduce 450) ((T_SL) reduce 450) ((T_SPACESHIP) reduce 450) ((T_SR) reduce 450) (("^") reduce 450) (("|") reduce 450) (("}") reduce 450)) 13244 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 455)) 13562 ((("%") reduce 451) (("*") reduce 451) (("+") reduce 451) (("-") reduce 451) ((".") reduce 451) (("/") reduce 451) (("<") reduce 451) ((">") reduce 451) (("?") reduce 451) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_BOOLEAN_AND) reduce 451) ((T_BOOLEAN_OR) reduce 451) ((T_COALESCE) reduce 451) ((T_INSTANCEOF) reduce 451) ((T_IS_EQUAL) reduce 451) ((T_IS_GREATER_OR_EQUAL) reduce 451) ((T_IS_IDENTICAL) reduce 451) ((T_IS_NOT_EQUAL) reduce 451) ((T_IS_NOT_IDENTICAL) reduce 451) ((T_IS_SMALLER_OR_EQUAL) reduce 451) ((T_LOGICAL_AND) reduce 451) ((T_LOGICAL_OR) reduce 451) ((T_LOGICAL_XOR) reduce 451) ((T_POW) reduce 451) ((T_SL) reduce 451) ((T_SPACESHIP) reduce 451) ((T_SR) reduce 451) (("^") reduce 451) (("|") reduce 451) (("}") reduce 451)) 13565 ((("%") reduce 503) (("(") reduce 541) (("*") reduce 503) (("+") reduce 503) (("-") reduce 503) ((".") reduce 503) (("/") reduce 503) (("<") reduce 503) ((">") reduce 503) (("?") reduce 503) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_BOOLEAN_AND) reduce 503) ((T_BOOLEAN_OR) reduce 503) ((T_COALESCE) reduce 503) ((T_INSTANCEOF) reduce 503) ((T_IS_EQUAL) reduce 503) ((T_IS_GREATER_OR_EQUAL) reduce 503) ((T_IS_IDENTICAL) reduce 503) ((T_IS_NOT_EQUAL) reduce 503) ((T_IS_NOT_IDENTICAL) reduce 503) ((T_IS_SMALLER_OR_EQUAL) reduce 503) ((T_LOGICAL_AND) reduce 503) ((T_LOGICAL_OR) reduce 503) ((T_LOGICAL_XOR) reduce 503) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 503) ((T_OBJECT_OPERATOR) reduce 503) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 503) ((T_POW) reduce 503) ((T_SL) reduce 503) ((T_SPACESHIP) reduce 503) ((T_SR) reduce 503) (("[") reduce 503) (("^") reduce 503) (("{") reduce 503) (("|") reduce 503) (("}") reduce 503)) 13567 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) (("<") reduce 532) (("=") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AND_EQUAL) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_COALESCE_EQUAL) reduce 532) ((T_CONCAT_EQUAL) reduce 532) ((T_DEC) reduce 532) ((T_DIV_EQUAL) reduce 532) ((T_INC) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_MINUS_EQUAL) reduce 532) ((T_MOD_EQUAL) reduce 532) ((T_MUL_EQUAL) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_OR_EQUAL) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_PLUS_EQUAL) reduce 532) ((T_POW) reduce 532) ((T_POW_EQUAL) reduce 532) ((T_SL) reduce 532) ((T_SL_EQUAL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) ((T_SR_EQUAL) reduce 532) ((T_XOR_EQUAL) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532) (("}") reduce 532)) 13570 ((("%") reduce 505) (("(") reduce 542) (("*") reduce 505) (("+") reduce 505) (("-") reduce 505) ((".") reduce 505) (("/") reduce 505) (("<") reduce 505) ((">") reduce 505) (("?") reduce 505) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_BOOLEAN_AND) reduce 505) ((T_BOOLEAN_OR) reduce 505) ((T_COALESCE) reduce 505) ((T_INSTANCEOF) reduce 505) ((T_IS_EQUAL) reduce 505) ((T_IS_GREATER_OR_EQUAL) reduce 505) ((T_IS_IDENTICAL) reduce 505) ((T_IS_NOT_EQUAL) reduce 505) ((T_IS_NOT_IDENTICAL) reduce 505) ((T_IS_SMALLER_OR_EQUAL) reduce 505) ((T_LOGICAL_AND) reduce 505) ((T_LOGICAL_OR) reduce 505) ((T_LOGICAL_XOR) reduce 505) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 505) ((T_OBJECT_OPERATOR) reduce 505) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 505) ((T_POW) reduce 505) ((T_SL) reduce 505) ((T_SPACESHIP) reduce 505) ((T_SR) reduce 505) (("[") reduce 505) (("^") reduce 505) (("{") reduce 505) (("|") reduce 505) (("}") reduce 505)) 13571 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) (("<") reduce 467) (("=") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AND_EQUAL) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_COALESCE_EQUAL) reduce 467) ((T_CONCAT_EQUAL) reduce 467) ((T_DEC) reduce 467) ((T_DIV_EQUAL) reduce 467) ((T_INC) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_MINUS_EQUAL) reduce 467) ((T_MOD_EQUAL) reduce 467) ((T_MUL_EQUAL) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_OR_EQUAL) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_PLUS_EQUAL) reduce 467) ((T_POW) reduce 467) ((T_POW_EQUAL) reduce 467) ((T_SL) reduce 467) ((T_SL_EQUAL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) ((T_SR_EQUAL) reduce 467) ((T_XOR_EQUAL) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467) (("}") reduce 467)) 13572 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) (("<") reduce 469) (("=") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AND_EQUAL) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_COALESCE_EQUAL) reduce 469) ((T_CONCAT_EQUAL) reduce 469) ((T_DEC) reduce 469) ((T_DIV_EQUAL) reduce 469) ((T_INC) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_MINUS_EQUAL) reduce 469) ((T_MOD_EQUAL) reduce 469) ((T_MUL_EQUAL) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_OR_EQUAL) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_PLUS_EQUAL) reduce 469) ((T_POW) reduce 469) ((T_POW_EQUAL) reduce 469) ((T_SL) reduce 469) ((T_SL_EQUAL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) ((T_SR_EQUAL) reduce 469) ((T_XOR_EQUAL) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469) (("}") reduce 469)) 13574 ((("%") reduce 446) (("*") reduce 446) (("+") reduce 446) (("-") reduce 446) ((".") reduce 446) (("/") reduce 446) (("<") reduce 446) ((">") reduce 446) (("?") reduce 446) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_BOOLEAN_AND) reduce 446) ((T_BOOLEAN_OR) reduce 446) ((T_COALESCE) reduce 446) ((T_INSTANCEOF) reduce 446) ((T_IS_EQUAL) reduce 446) ((T_IS_GREATER_OR_EQUAL) reduce 446) ((T_IS_IDENTICAL) reduce 446) ((T_IS_NOT_EQUAL) reduce 446) ((T_IS_NOT_IDENTICAL) reduce 446) ((T_IS_SMALLER_OR_EQUAL) reduce 446) ((T_LOGICAL_AND) reduce 446) ((T_LOGICAL_OR) reduce 446) ((T_LOGICAL_XOR) reduce 446) ((T_POW) reduce 446) ((T_SL) reduce 446) ((T_SPACESHIP) reduce 446) ((T_SR) reduce 446) (("^") reduce 446) (("|") reduce 446) (("}") reduce 446)) 13575 ((("%") reduce 448) (("*") reduce 448) (("+") reduce 448) (("-") reduce 448) ((".") reduce 448) (("/") reduce 448) (("<") reduce 448) ((">") reduce 448) (("?") reduce 448) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_BOOLEAN_AND) reduce 448) ((T_BOOLEAN_OR) reduce 448) ((T_COALESCE) reduce 448) ((T_INSTANCEOF) reduce 448) ((T_IS_EQUAL) reduce 448) ((T_IS_GREATER_OR_EQUAL) reduce 448) ((T_IS_IDENTICAL) reduce 448) ((T_IS_NOT_EQUAL) reduce 448) ((T_IS_NOT_IDENTICAL) reduce 448) ((T_IS_SMALLER_OR_EQUAL) reduce 448) ((T_LOGICAL_AND) reduce 448) ((T_LOGICAL_OR) reduce 448) ((T_LOGICAL_XOR) reduce 448) ((T_POW) reduce 448) ((T_SL) reduce 448) ((T_SPACESHIP) reduce 448) ((T_SR) reduce 448) (("^") reduce 448) (("|") reduce 448) (("}") reduce 448)) 13581 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) (("<") reduce 521) (("=") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AND_EQUAL) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_COALESCE_EQUAL) reduce 521) ((T_CONCAT_EQUAL) reduce 521) ((T_DEC) reduce 521) ((T_DIV_EQUAL) reduce 521) ((T_INC) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_MINUS_EQUAL) reduce 521) ((T_MOD_EQUAL) reduce 521) ((T_MUL_EQUAL) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_OR_EQUAL) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_PLUS_EQUAL) reduce 521) ((T_POW) reduce 521) ((T_POW_EQUAL) reduce 521) ((T_SL) reduce 521) ((T_SL_EQUAL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) ((T_SR_EQUAL) reduce 521) ((T_XOR_EQUAL) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521) (("}") reduce 521)) 13583 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) (("<") reduce 520) (("=") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AND_EQUAL) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_COALESCE_EQUAL) reduce 520) ((T_CONCAT_EQUAL) reduce 520) ((T_DEC) reduce 520) ((T_DIV_EQUAL) reduce 520) ((T_INC) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_MINUS_EQUAL) reduce 520) ((T_MOD_EQUAL) reduce 520) ((T_MUL_EQUAL) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_OR_EQUAL) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_PLUS_EQUAL) reduce 520) ((T_POW) reduce 520) ((T_POW_EQUAL) reduce 520) ((T_SL) reduce 520) ((T_SL_EQUAL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) ((T_SR_EQUAL) reduce 520) ((T_XOR_EQUAL) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520) (("}") reduce 520)) 13584 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) (("=") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AND_EQUAL) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_COALESCE_EQUAL) reduce 544) ((T_CONCAT_EQUAL) reduce 544) ((T_DEC) reduce 544) ((T_DIV_EQUAL) reduce 544) ((T_INC) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_MINUS_EQUAL) reduce 544) ((T_MOD_EQUAL) reduce 544) ((T_MUL_EQUAL) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_OR_EQUAL) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_PLUS_EQUAL) reduce 544) ((T_POW) reduce 544) ((T_POW_EQUAL) reduce 544) ((T_SL) reduce 544) ((T_SL_EQUAL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) ((T_SR_EQUAL) reduce 544) ((T_XOR_EQUAL) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544) (("}") reduce 544)) 13585 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) (("<") reduce 527) (("=") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AND_EQUAL) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_COALESCE_EQUAL) reduce 527) ((T_CONCAT_EQUAL) reduce 527) ((T_DEC) reduce 527) ((T_DIV_EQUAL) reduce 527) ((T_INC) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_MINUS_EQUAL) reduce 527) ((T_MOD_EQUAL) reduce 527) ((T_MUL_EQUAL) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_OR_EQUAL) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_PLUS_EQUAL) reduce 527) ((T_POW) reduce 527) ((T_POW_EQUAL) reduce 527) ((T_SL) reduce 527) ((T_SL_EQUAL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) ((T_SR_EQUAL) reduce 527) ((T_XOR_EQUAL) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527) (("}") reduce 527)) 13586 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) (("=") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AND_EQUAL) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_COALESCE_EQUAL) reduce 546) ((T_CONCAT_EQUAL) reduce 546) ((T_DEC) reduce 546) ((T_DIV_EQUAL) reduce 546) ((T_INC) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_MINUS_EQUAL) reduce 546) ((T_MOD_EQUAL) reduce 546) ((T_MUL_EQUAL) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_OR_EQUAL) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_PLUS_EQUAL) reduce 546) ((T_POW) reduce 546) ((T_POW_EQUAL) reduce 546) ((T_SL) reduce 546) ((T_SL_EQUAL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) ((T_SR_EQUAL) reduce 546) ((T_XOR_EQUAL) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546) (("}") reduce 546)) 13589 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) (("=") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AND_EQUAL) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_COALESCE_EQUAL) reduce 545) ((T_CONCAT_EQUAL) reduce 545) ((T_DEC) reduce 545) ((T_DIV_EQUAL) reduce 545) ((T_INC) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_MINUS_EQUAL) reduce 545) ((T_MOD_EQUAL) reduce 545) ((T_MUL_EQUAL) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_OR_EQUAL) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_PLUS_EQUAL) reduce 545) ((T_POW) reduce 545) ((T_POW_EQUAL) reduce 545) ((T_SL) reduce 545) ((T_SL_EQUAL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) ((T_SR_EQUAL) reduce 545) ((T_XOR_EQUAL) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545) (("}") reduce 545)) 13590 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) (("<") reduce 522) (("=") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AND_EQUAL) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_COALESCE_EQUAL) reduce 522) ((T_CONCAT_EQUAL) reduce 522) ((T_DEC) reduce 522) ((T_DIV_EQUAL) reduce 522) ((T_INC) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_MINUS_EQUAL) reduce 522) ((T_MOD_EQUAL) reduce 522) ((T_MUL_EQUAL) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_OR_EQUAL) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_PLUS_EQUAL) reduce 522) ((T_POW) reduce 522) ((T_POW_EQUAL) reduce 522) ((T_SL) reduce 522) ((T_SL_EQUAL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) ((T_SR_EQUAL) reduce 522) ((T_XOR_EQUAL) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522) (("}") reduce 522)) 13591 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) (("<") reduce 528) (("=") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AND_EQUAL) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_COALESCE_EQUAL) reduce 528) ((T_CONCAT_EQUAL) reduce 528) ((T_DEC) reduce 528) ((T_DIV_EQUAL) reduce 528) ((T_INC) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_MINUS_EQUAL) reduce 528) ((T_MOD_EQUAL) reduce 528) ((T_MUL_EQUAL) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_OR_EQUAL) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_PLUS_EQUAL) reduce 528) ((T_POW) reduce 528) ((T_POW_EQUAL) reduce 528) ((T_SL) reduce 528) ((T_SL_EQUAL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) ((T_SR_EQUAL) reduce 528) ((T_XOR_EQUAL) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528) (("}") reduce 528)) 13592 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) (("<") reduce 523) (("=") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AND_EQUAL) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_COALESCE_EQUAL) reduce 523) ((T_CONCAT_EQUAL) reduce 523) ((T_DEC) reduce 523) ((T_DIV_EQUAL) reduce 523) ((T_INC) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_MINUS_EQUAL) reduce 523) ((T_MOD_EQUAL) reduce 523) ((T_MUL_EQUAL) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_OR_EQUAL) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_PLUS_EQUAL) reduce 523) ((T_POW) reduce 523) ((T_POW_EQUAL) reduce 523) ((T_SL) reduce 523) ((T_SL_EQUAL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) ((T_SR_EQUAL) reduce 523) ((T_XOR_EQUAL) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523) (("}") reduce 523)) 13594 ((("%") reduce 438) (("*") reduce 438) (("+") reduce 438) (("-") reduce 438) ((".") reduce 438) (("/") reduce 438) (("<") reduce 438) ((">") reduce 438) (("?") reduce 438) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_BOOLEAN_AND) reduce 438) ((T_BOOLEAN_OR) reduce 438) ((T_COALESCE) reduce 438) ((T_INSTANCEOF) reduce 438) ((T_IS_EQUAL) reduce 438) ((T_IS_GREATER_OR_EQUAL) reduce 438) ((T_IS_IDENTICAL) reduce 438) ((T_IS_NOT_EQUAL) reduce 438) ((T_IS_NOT_IDENTICAL) reduce 438) ((T_IS_SMALLER_OR_EQUAL) reduce 438) ((T_LOGICAL_AND) reduce 438) ((T_LOGICAL_OR) reduce 438) ((T_LOGICAL_XOR) reduce 438) ((T_POW) reduce 438) ((T_SL) reduce 438) ((T_SPACESHIP) reduce 438) ((T_SR) reduce 438) (("^") reduce 438) (("|") reduce 438) (("}") reduce 438)) 13596 ((("%") reduce 483) (("(") reduce 483) (("*") reduce 483) (("+") reduce 483) (("-") reduce 483) ((".") reduce 483) (("/") reduce 483) (("<") reduce 483) (("=") shift) ((">") reduce 483) (("?") reduce 483) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_BOOLEAN_AND) reduce 483) ((T_BOOLEAN_OR) reduce 483) ((T_COALESCE) reduce 483) ((T_INSTANCEOF) reduce 483) ((T_IS_EQUAL) reduce 483) ((T_IS_GREATER_OR_EQUAL) reduce 483) ((T_IS_IDENTICAL) reduce 483) ((T_IS_NOT_EQUAL) reduce 483) ((T_IS_NOT_IDENTICAL) reduce 483) ((T_IS_SMALLER_OR_EQUAL) reduce 483) ((T_LOGICAL_AND) reduce 483) ((T_LOGICAL_OR) reduce 483) ((T_LOGICAL_XOR) reduce 483) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 483) ((T_OBJECT_OPERATOR) reduce 483) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 483) ((T_POW) reduce 483) ((T_SL) reduce 483) ((T_SPACESHIP) reduce 483) ((T_SR) reduce 483) (("[") reduce 483) (("^") reduce 483) (("{") reduce 483) (("|") reduce 483) (("}") reduce 483)) 13598 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 369) ((T_LOGICAL_OR) reduce 369) ((T_LOGICAL_XOR) reduce 369) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 369)) 13599 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 443) ((T_LOGICAL_OR) reduce 443) ((T_LOGICAL_XOR) reduce 443) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 443)) 13610 ((("%") reduce 502) (("*") reduce 502) (("+") reduce 502) (("-") reduce 502) ((".") reduce 502) (("/") reduce 502) (("<") reduce 502) ((">") reduce 502) (("?") reduce 502) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_BOOLEAN_AND) reduce 502) ((T_BOOLEAN_OR) reduce 502) ((T_COALESCE) reduce 502) ((T_DOUBLE_ARROW) reduce 502) ((T_INSTANCEOF) reduce 502) ((T_IS_EQUAL) reduce 502) ((T_IS_GREATER_OR_EQUAL) reduce 502) ((T_IS_IDENTICAL) reduce 502) ((T_IS_NOT_EQUAL) reduce 502) ((T_IS_NOT_IDENTICAL) reduce 502) ((T_IS_SMALLER_OR_EQUAL) reduce 502) ((T_LOGICAL_AND) reduce 502) ((T_LOGICAL_OR) reduce 502) ((T_LOGICAL_XOR) reduce 502) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 502) ((T_OBJECT_OPERATOR) reduce 502) ((T_POW) reduce 502) ((T_SL) reduce 502) ((T_SPACESHIP) reduce 502) ((T_SR) reduce 502) (("[") reduce 502) (("^") reduce 502) (("{") reduce 502) (("|") reduce 502) (("}") reduce 502)) 13612 ((("%") reduce 484) (("(") reduce 484) (("*") reduce 484) (("+") reduce 484) (("-") reduce 484) ((".") reduce 484) (("/") reduce 484) (("<") reduce 484) ((">") reduce 484) (("?") reduce 484) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_BOOLEAN_AND) reduce 484) ((T_BOOLEAN_OR) reduce 484) ((T_COALESCE) reduce 484) ((T_DOUBLE_ARROW) reduce 484) ((T_INSTANCEOF) reduce 484) ((T_IS_EQUAL) reduce 484) ((T_IS_GREATER_OR_EQUAL) reduce 484) ((T_IS_IDENTICAL) reduce 484) ((T_IS_NOT_EQUAL) reduce 484) ((T_IS_NOT_IDENTICAL) reduce 484) ((T_IS_SMALLER_OR_EQUAL) reduce 484) ((T_LOGICAL_AND) reduce 484) ((T_LOGICAL_OR) reduce 484) ((T_LOGICAL_XOR) reduce 484) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 484) ((T_OBJECT_OPERATOR) reduce 484) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 484) ((T_POW) reduce 484) ((T_SL) reduce 484) ((T_SPACESHIP) reduce 484) ((T_SR) reduce 484) (("[") reduce 484) (("^") reduce 484) (("{") reduce 484) (("|") reduce 484) (("}") reduce 484)) 13614 ((("%") reduce 497) (("*") reduce 497) (("+") reduce 497) (("-") reduce 497) ((".") reduce 497) (("/") reduce 497) (("<") reduce 497) ((">") reduce 497) (("?") reduce 497) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_BOOLEAN_AND) reduce 497) ((T_BOOLEAN_OR) reduce 497) ((T_COALESCE) reduce 497) ((T_DOUBLE_ARROW) reduce 497) ((T_INSTANCEOF) reduce 497) ((T_IS_EQUAL) reduce 497) ((T_IS_GREATER_OR_EQUAL) reduce 497) ((T_IS_IDENTICAL) reduce 497) ((T_IS_NOT_EQUAL) reduce 497) ((T_IS_NOT_IDENTICAL) reduce 497) ((T_IS_SMALLER_OR_EQUAL) reduce 497) ((T_LOGICAL_AND) reduce 497) ((T_LOGICAL_OR) reduce 497) ((T_LOGICAL_XOR) reduce 497) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 497) ((T_OBJECT_OPERATOR) reduce 497) ((T_POW) reduce 497) ((T_SL) reduce 497) ((T_SPACESHIP) reduce 497) ((T_SR) reduce 497) (("[") reduce 497) (("^") reduce 497) (("{") reduce 497) (("|") reduce 497) (("}") reduce 497)) 13615 ((("%") reduce 487) (("*") reduce 487) (("+") reduce 487) (("-") reduce 487) ((".") reduce 487) (("/") reduce 487) (("<") reduce 487) ((">") reduce 487) (("?") reduce 487) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_BOOLEAN_AND) reduce 487) ((T_BOOLEAN_OR) reduce 487) ((T_COALESCE) reduce 487) ((T_DOUBLE_ARROW) reduce 487) ((T_INSTANCEOF) reduce 487) ((T_IS_EQUAL) reduce 487) ((T_IS_GREATER_OR_EQUAL) reduce 487) ((T_IS_IDENTICAL) reduce 487) ((T_IS_NOT_EQUAL) reduce 487) ((T_IS_NOT_IDENTICAL) reduce 487) ((T_IS_SMALLER_OR_EQUAL) reduce 487) ((T_LOGICAL_AND) reduce 487) ((T_LOGICAL_OR) reduce 487) ((T_LOGICAL_XOR) reduce 487) ((T_POW) reduce 487) ((T_SL) reduce 487) ((T_SPACESHIP) reduce 487) ((T_SR) reduce 487) (("^") reduce 487) (("|") reduce 487) (("}") reduce 487)) 13619 ((("%") reduce 475) (("(") shift) (("*") reduce 475) (("+") reduce 475) (("-") reduce 475) ((".") reduce 475) (("/") reduce 475) (("<") reduce 475) ((">") reduce 475) (("?") reduce 475) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_BOOLEAN_AND) reduce 475) ((T_BOOLEAN_OR) reduce 475) ((T_COALESCE) reduce 475) ((T_DOUBLE_ARROW) reduce 475) ((T_INSTANCEOF) reduce 475) ((T_IS_EQUAL) reduce 475) ((T_IS_GREATER_OR_EQUAL) reduce 475) ((T_IS_IDENTICAL) reduce 475) ((T_IS_NOT_EQUAL) reduce 475) ((T_IS_NOT_IDENTICAL) reduce 475) ((T_IS_SMALLER_OR_EQUAL) reduce 475) ((T_LOGICAL_AND) reduce 475) ((T_LOGICAL_OR) reduce 475) ((T_LOGICAL_XOR) reduce 475) ((T_POW) reduce 475) ((T_SL) reduce 475) ((T_SPACESHIP) reduce 475) ((T_SR) reduce 475) (("^") reduce 475) (("|") reduce 475) (("}") reduce 475)) 13620 ((("%") reduce 496) (("*") reduce 496) (("+") reduce 496) (("-") reduce 496) ((".") reduce 496) (("/") reduce 496) (("<") reduce 496) ((">") reduce 496) (("?") reduce 496) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_BOOLEAN_AND) reduce 496) ((T_BOOLEAN_OR) reduce 496) ((T_COALESCE) reduce 496) ((T_DOUBLE_ARROW) reduce 496) ((T_INSTANCEOF) reduce 496) ((T_IS_EQUAL) reduce 496) ((T_IS_GREATER_OR_EQUAL) reduce 496) ((T_IS_IDENTICAL) reduce 496) ((T_IS_NOT_EQUAL) reduce 496) ((T_IS_NOT_IDENTICAL) reduce 496) ((T_IS_SMALLER_OR_EQUAL) reduce 496) ((T_LOGICAL_AND) reduce 496) ((T_LOGICAL_OR) reduce 496) ((T_LOGICAL_XOR) reduce 496) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 496) ((T_OBJECT_OPERATOR) reduce 496) ((T_POW) reduce 496) ((T_SL) reduce 496) ((T_SPACESHIP) reduce 496) ((T_SR) reduce 496) (("[") reduce 496) (("^") reduce 496) (("{") reduce 496) (("|") reduce 496) (("}") reduce 496)) 13621 ((("%") reduce 500) (("*") reduce 500) (("+") reduce 500) (("-") reduce 500) ((".") reduce 500) (("/") reduce 500) (("<") reduce 500) ((">") reduce 500) (("?") reduce 500) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_BOOLEAN_AND) reduce 500) ((T_BOOLEAN_OR) reduce 500) ((T_COALESCE) reduce 500) ((T_DOUBLE_ARROW) reduce 500) ((T_INSTANCEOF) reduce 500) ((T_IS_EQUAL) reduce 500) ((T_IS_GREATER_OR_EQUAL) reduce 500) ((T_IS_IDENTICAL) reduce 500) ((T_IS_NOT_EQUAL) reduce 500) ((T_IS_NOT_IDENTICAL) reduce 500) ((T_IS_SMALLER_OR_EQUAL) reduce 500) ((T_LOGICAL_AND) reduce 500) ((T_LOGICAL_OR) reduce 500) ((T_LOGICAL_XOR) reduce 500) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 500) ((T_OBJECT_OPERATOR) reduce 500) ((T_POW) reduce 500) ((T_SL) reduce 500) ((T_SPACESHIP) reduce 500) ((T_SR) reduce 500) (("[") reduce 500) (("^") reduce 500) (("{") reduce 500) (("|") reduce 500) (("}") reduce 500)) 13627 ((("%") reduce 495) (("*") reduce 495) (("+") reduce 495) (("-") reduce 495) ((".") reduce 495) (("/") reduce 495) (("<") reduce 495) ((">") reduce 495) (("?") reduce 495) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_BOOLEAN_AND) reduce 495) ((T_BOOLEAN_OR) reduce 495) ((T_COALESCE) reduce 495) ((T_DOUBLE_ARROW) reduce 495) ((T_INSTANCEOF) reduce 495) ((T_IS_EQUAL) reduce 495) ((T_IS_GREATER_OR_EQUAL) reduce 495) ((T_IS_IDENTICAL) reduce 495) ((T_IS_NOT_EQUAL) reduce 495) ((T_IS_NOT_IDENTICAL) reduce 495) ((T_IS_SMALLER_OR_EQUAL) reduce 495) ((T_LOGICAL_AND) reduce 495) ((T_LOGICAL_OR) reduce 495) ((T_LOGICAL_XOR) reduce 495) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 495) ((T_OBJECT_OPERATOR) reduce 495) ((T_POW) reduce 495) ((T_SL) reduce 495) ((T_SPACESHIP) reduce 495) ((T_SR) reduce 495) (("[") reduce 495) (("^") reduce 495) (("{") reduce 495) (("|") reduce 495) (("}") reduce 495)) 13629 ((("%") reduce 486) (("*") reduce 486) (("+") reduce 486) (("-") reduce 486) ((".") reduce 486) (("/") reduce 486) (("<") reduce 486) ((">") reduce 486) (("?") reduce 486) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_BOOLEAN_AND) reduce 486) ((T_BOOLEAN_OR) reduce 486) ((T_COALESCE) reduce 486) ((T_DOUBLE_ARROW) reduce 486) ((T_INSTANCEOF) reduce 486) ((T_IS_EQUAL) reduce 486) ((T_IS_GREATER_OR_EQUAL) reduce 486) ((T_IS_IDENTICAL) reduce 486) ((T_IS_NOT_EQUAL) reduce 486) ((T_IS_NOT_IDENTICAL) reduce 486) ((T_IS_SMALLER_OR_EQUAL) reduce 486) ((T_LOGICAL_AND) reduce 486) ((T_LOGICAL_OR) reduce 486) ((T_LOGICAL_XOR) reduce 486) ((T_POW) reduce 486) ((T_SL) reduce 486) ((T_SPACESHIP) reduce 486) ((T_SR) reduce 486) (("^") reduce 486) (("|") reduce 486) (("}") reduce 486)) 13631 ((("%") reduce 499) (("*") reduce 499) (("+") reduce 499) (("-") reduce 499) ((".") reduce 499) (("/") reduce 499) (("<") reduce 499) ((">") reduce 499) (("?") reduce 499) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_BOOLEAN_AND) reduce 499) ((T_BOOLEAN_OR) reduce 499) ((T_COALESCE) reduce 499) ((T_DOUBLE_ARROW) reduce 499) ((T_INSTANCEOF) reduce 499) ((T_IS_EQUAL) reduce 499) ((T_IS_GREATER_OR_EQUAL) reduce 499) ((T_IS_IDENTICAL) reduce 499) ((T_IS_NOT_EQUAL) reduce 499) ((T_IS_NOT_IDENTICAL) reduce 499) ((T_IS_SMALLER_OR_EQUAL) reduce 499) ((T_LOGICAL_AND) reduce 499) ((T_LOGICAL_OR) reduce 499) ((T_LOGICAL_XOR) reduce 499) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 499) ((T_OBJECT_OPERATOR) reduce 499) ((T_POW) reduce 499) ((T_SL) reduce 499) ((T_SPACESHIP) reduce 499) ((T_SR) reduce 499) (("[") reduce 499) (("^") reduce 499) (("{") reduce 499) (("|") reduce 499) (("}") reduce 499)) 13632 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 93) ((T_OBJECT_OPERATOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("[") reduce 93) (("^") reduce 93) (("{") reduce 93) (("|") reduce 93) (("}") reduce 93)) 13633 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 92) ((T_OBJECT_OPERATOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("[") reduce 92) (("^") reduce 92) (("{") reduce 92) (("|") reduce 92) (("}") reduce 92)) 13634 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 94) ((T_OBJECT_OPERATOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("[") reduce 94) (("^") reduce 94) (("{") reduce 94) (("|") reduce 94) (("}") reduce 94)) 13636 ((("%") reduce 501) (("*") reduce 501) (("+") reduce 501) (("-") reduce 501) ((".") reduce 501) (("/") reduce 501) (("<") reduce 501) ((">") reduce 501) (("?") reduce 501) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_BOOLEAN_AND) reduce 501) ((T_BOOLEAN_OR) reduce 501) ((T_COALESCE) reduce 501) ((T_DOUBLE_ARROW) reduce 501) ((T_INSTANCEOF) reduce 501) ((T_IS_EQUAL) reduce 501) ((T_IS_GREATER_OR_EQUAL) reduce 501) ((T_IS_IDENTICAL) reduce 501) ((T_IS_NOT_EQUAL) reduce 501) ((T_IS_NOT_IDENTICAL) reduce 501) ((T_IS_SMALLER_OR_EQUAL) reduce 501) ((T_LOGICAL_AND) reduce 501) ((T_LOGICAL_OR) reduce 501) ((T_LOGICAL_XOR) reduce 501) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 501) ((T_OBJECT_OPERATOR) reduce 501) ((T_POW) reduce 501) ((T_SL) reduce 501) ((T_SPACESHIP) reduce 501) ((T_SR) reduce 501) (("[") reduce 501) (("^") reduce 501) (("{") reduce 501) (("|") reduce 501) (("}") reduce 501)) 13644 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 91) ((T_OBJECT_OPERATOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("[") reduce 91) (("^") reduce 91) (("{") reduce 91) (("|") reduce 91) (("}") reduce 91)) 13647 ((("%") reduce 498) (("*") reduce 498) (("+") reduce 498) (("-") reduce 498) ((".") reduce 498) (("/") reduce 498) (("<") reduce 498) ((">") reduce 498) (("?") reduce 498) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_BOOLEAN_AND) reduce 498) ((T_BOOLEAN_OR) reduce 498) ((T_COALESCE) reduce 498) ((T_DOUBLE_ARROW) reduce 498) ((T_INSTANCEOF) reduce 498) ((T_IS_EQUAL) reduce 498) ((T_IS_GREATER_OR_EQUAL) reduce 498) ((T_IS_IDENTICAL) reduce 498) ((T_IS_NOT_EQUAL) reduce 498) ((T_IS_NOT_IDENTICAL) reduce 498) ((T_IS_SMALLER_OR_EQUAL) reduce 498) ((T_LOGICAL_AND) reduce 498) ((T_LOGICAL_OR) reduce 498) ((T_LOGICAL_XOR) reduce 498) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 498) ((T_OBJECT_OPERATOR) reduce 498) ((T_POW) reduce 498) ((T_SL) reduce 498) ((T_SPACESHIP) reduce 498) ((T_SR) reduce 498) (("[") reduce 498) (("^") reduce 498) (("{") reduce 498) (("|") reduce 498) (("}") reduce 498)) 13649 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) (("=") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AND_EQUAL) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_COALESCE_EQUAL) reduce 529) ((T_CONCAT_EQUAL) reduce 529) ((T_DEC) reduce 529) ((T_DIV_EQUAL) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INC) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_MINUS_EQUAL) reduce 529) ((T_MOD_EQUAL) reduce 529) ((T_MUL_EQUAL) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_OR_EQUAL) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_PLUS_EQUAL) reduce 529) ((T_POW) reduce 529) ((T_POW_EQUAL) reduce 529) ((T_SL) reduce 529) ((T_SL_EQUAL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) ((T_SR_EQUAL) reduce 529) ((T_XOR_EQUAL) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529) (("}") reduce 529)) 13650 ((("!") shift) (("\"") shift) (("$") shift) (("%") reduce 440) (("(") shift) (("*") reduce 440) (("+") shift) (("-") shift) ((".") reduce 440) (("/") reduce 440) (("<") reduce 440) ((">") reduce 440) (("?") reduce 440) (("@") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOLEAN_AND) reduce 440) ((T_BOOLEAN_OR) reduce 440) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_COALESCE) reduce 440) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_ARROW) reduce 440) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INSTANCEOF) reduce 440) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_IS_EQUAL) reduce 440) ((T_IS_GREATER_OR_EQUAL) reduce 440) ((T_IS_IDENTICAL) reduce 440) ((T_IS_NOT_EQUAL) reduce 440) ((T_IS_NOT_IDENTICAL) reduce 440) ((T_IS_SMALLER_OR_EQUAL) reduce 440) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_LOGICAL_AND) reduce 440) ((T_LOGICAL_OR) reduce 440) ((T_LOGICAL_XOR) reduce 440) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_POW) reduce 440) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_SL) reduce 440) ((T_SPACESHIP) reduce 440) ((T_SR) reduce 440) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("^") reduce 440) (("`") shift) (("|") reduce 440) (("}") reduce 440) (("~") shift)) 13657 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) (("<") reduce 525) (("=") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AND_EQUAL) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_COALESCE_EQUAL) reduce 525) ((T_CONCAT_EQUAL) reduce 525) ((T_DEC) reduce 525) ((T_DIV_EQUAL) reduce 525) ((T_DOUBLE_ARROW) reduce 525) ((T_INC) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_MINUS_EQUAL) reduce 525) ((T_MOD_EQUAL) reduce 525) ((T_MUL_EQUAL) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_OR_EQUAL) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_PLUS_EQUAL) reduce 525) ((T_POW) reduce 525) ((T_POW_EQUAL) reduce 525) ((T_SL) reduce 525) ((T_SL_EQUAL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) ((T_SR_EQUAL) reduce 525) ((T_XOR_EQUAL) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525) (("}") reduce 525)) 13658 ((("%") reduce 493) (("*") reduce 493) (("+") reduce 493) (("-") reduce 493) ((".") reduce 493) (("/") reduce 493) (("<") reduce 493) ((">") reduce 493) (("?") reduce 493) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_BOOLEAN_AND) reduce 493) ((T_BOOLEAN_OR) reduce 493) ((T_COALESCE) reduce 493) ((T_DOUBLE_ARROW) reduce 493) ((T_INSTANCEOF) reduce 493) ((T_IS_EQUAL) reduce 493) ((T_IS_GREATER_OR_EQUAL) reduce 493) ((T_IS_IDENTICAL) reduce 493) ((T_IS_NOT_EQUAL) reduce 493) ((T_IS_NOT_IDENTICAL) reduce 493) ((T_IS_SMALLER_OR_EQUAL) reduce 493) ((T_LOGICAL_AND) reduce 493) ((T_LOGICAL_OR) reduce 493) ((T_LOGICAL_XOR) reduce 493) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 513) ((T_OBJECT_OPERATOR) reduce 513) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 513) ((T_POW) reduce 493) ((T_SL) reduce 493) ((T_SPACESHIP) reduce 493) ((T_SR) reduce 493) (("[") reduce 513) (("^") reduce 493) (("{") reduce 513) (("|") reduce 493) (("}") reduce 493)) 13660 ((("%") reduce 492) (("*") reduce 492) (("+") reduce 492) (("-") reduce 492) ((".") reduce 492) (("/") reduce 492) (("<") reduce 492) ((">") reduce 492) (("?") reduce 492) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_BOOLEAN_AND) reduce 492) ((T_BOOLEAN_OR) reduce 492) ((T_COALESCE) reduce 492) ((T_DOUBLE_ARROW) reduce 492) ((T_INSTANCEOF) reduce 492) ((T_IS_EQUAL) reduce 492) ((T_IS_GREATER_OR_EQUAL) reduce 492) ((T_IS_IDENTICAL) reduce 492) ((T_IS_NOT_EQUAL) reduce 492) ((T_IS_NOT_IDENTICAL) reduce 492) ((T_IS_SMALLER_OR_EQUAL) reduce 492) ((T_LOGICAL_AND) reduce 492) ((T_LOGICAL_OR) reduce 492) ((T_LOGICAL_XOR) reduce 492) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 515) ((T_OBJECT_OPERATOR) reduce 515) ((T_POW) reduce 492) ((T_SL) reduce 492) ((T_SPACESHIP) reduce 492) ((T_SR) reduce 492) (("[") reduce 515) (("^") reduce 492) (("{") reduce 515) (("|") reduce 492) (("}") reduce 492)) 13661 ((("%") reduce 491) (("(") reduce 518) (("*") reduce 491) (("+") reduce 491) (("-") reduce 491) ((".") reduce 491) (("/") reduce 491) (("<") reduce 491) ((">") reduce 491) (("?") reduce 491) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_BOOLEAN_AND) reduce 491) ((T_BOOLEAN_OR) reduce 491) ((T_COALESCE) reduce 491) ((T_DOUBLE_ARROW) reduce 491) ((T_INSTANCEOF) reduce 491) ((T_IS_EQUAL) reduce 491) ((T_IS_GREATER_OR_EQUAL) reduce 491) ((T_IS_IDENTICAL) reduce 491) ((T_IS_NOT_EQUAL) reduce 491) ((T_IS_NOT_IDENTICAL) reduce 491) ((T_IS_SMALLER_OR_EQUAL) reduce 491) ((T_LOGICAL_AND) reduce 491) ((T_LOGICAL_OR) reduce 491) ((T_LOGICAL_XOR) reduce 491) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 512) ((T_OBJECT_OPERATOR) reduce 512) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 512) ((T_POW) reduce 491) ((T_SL) reduce 491) ((T_SPACESHIP) reduce 491) ((T_SR) reduce 491) (("[") reduce 512) (("^") reduce 491) (("{") reduce 512) (("|") reduce 491) (("}") reduce 491)) 13662 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 441) ((T_LOGICAL_OR) reduce 441) ((T_LOGICAL_XOR) reduce 441) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 441)) 13665 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) (("<") reduce 524) (("=") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AND_EQUAL) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_COALESCE_EQUAL) reduce 524) ((T_CONCAT_EQUAL) reduce 524) ((T_DEC) reduce 524) ((T_DIV_EQUAL) reduce 524) ((T_DOUBLE_ARROW) reduce 524) ((T_INC) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_MINUS_EQUAL) reduce 524) ((T_MOD_EQUAL) reduce 524) ((T_MUL_EQUAL) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_OR_EQUAL) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_PLUS_EQUAL) reduce 524) ((T_POW) reduce 524) ((T_POW_EQUAL) reduce 524) ((T_SL) reduce 524) ((T_SL_EQUAL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) ((T_SR_EQUAL) reduce 524) ((T_XOR_EQUAL) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524) (("}") reduce 524)) 13666 ((("%") reduce 445) (("*") reduce 445) (("+") reduce 445) (("-") reduce 445) ((".") reduce 445) (("/") reduce 445) (("<") reduce 445) ((">") reduce 445) (("?") reduce 445) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_BOOLEAN_AND) reduce 445) ((T_BOOLEAN_OR) reduce 445) ((T_COALESCE) reduce 445) ((T_DOUBLE_ARROW) reduce 445) ((T_INSTANCEOF) reduce 445) ((T_IS_EQUAL) reduce 445) ((T_IS_GREATER_OR_EQUAL) reduce 445) ((T_IS_IDENTICAL) reduce 445) ((T_IS_NOT_EQUAL) reduce 445) ((T_IS_NOT_IDENTICAL) reduce 445) ((T_IS_SMALLER_OR_EQUAL) reduce 445) ((T_LOGICAL_AND) reduce 445) ((T_LOGICAL_OR) reduce 445) ((T_LOGICAL_XOR) reduce 445) ((T_POW) reduce 445) ((T_SL) reduce 445) ((T_SPACESHIP) reduce 445) ((T_SR) reduce 445) (("^") reduce 445) (("|") reduce 445) (("}") reduce 445)) 13667 ((("%") reduce 427) (("*") reduce 427) (("+") reduce 427) (("-") reduce 427) ((".") reduce 427) (("/") reduce 427) (("<") reduce 427) ((">") reduce 427) (("?") reduce 427) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_BOOLEAN_AND) reduce 427) ((T_BOOLEAN_OR) reduce 427) ((T_COALESCE) reduce 427) ((T_DOUBLE_ARROW) reduce 427) ((T_INSTANCEOF) reduce 427) ((T_IS_EQUAL) reduce 427) ((T_IS_GREATER_OR_EQUAL) reduce 427) ((T_IS_IDENTICAL) reduce 427) ((T_IS_NOT_EQUAL) reduce 427) ((T_IS_NOT_IDENTICAL) reduce 427) ((T_IS_SMALLER_OR_EQUAL) reduce 427) ((T_LOGICAL_AND) reduce 427) ((T_LOGICAL_OR) reduce 427) ((T_LOGICAL_XOR) reduce 427) ((T_POW) reduce 427) ((T_SL) reduce 427) ((T_SPACESHIP) reduce 427) ((T_SR) reduce 427) (("^") reduce 427) (("|") reduce 427) (("}") reduce 427)) 13668 ((("%") reduce 449) (("*") reduce 449) (("+") reduce 449) (("-") reduce 449) ((".") reduce 449) (("/") reduce 449) (("<") reduce 449) ((">") reduce 449) (("?") reduce 449) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_BOOLEAN_AND) reduce 449) ((T_BOOLEAN_OR) reduce 449) ((T_COALESCE) reduce 449) ((T_DOUBLE_ARROW) reduce 449) ((T_INSTANCEOF) reduce 449) ((T_IS_EQUAL) reduce 449) ((T_IS_GREATER_OR_EQUAL) reduce 449) ((T_IS_IDENTICAL) reduce 449) ((T_IS_NOT_EQUAL) reduce 449) ((T_IS_NOT_IDENTICAL) reduce 449) ((T_IS_SMALLER_OR_EQUAL) reduce 449) ((T_LOGICAL_AND) reduce 449) ((T_LOGICAL_OR) reduce 449) ((T_LOGICAL_XOR) reduce 449) ((T_POW) reduce 449) ((T_SL) reduce 449) ((T_SPACESHIP) reduce 449) ((T_SR) reduce 449) (("^") reduce 449) (("|") reduce 449) (("}") reduce 449)) 13669 ((("%") reduce 494) (("(") shift) (("*") reduce 494) (("+") reduce 494) (("-") reduce 494) ((".") reduce 494) (("/") reduce 494) (("<") reduce 494) ((">") reduce 494) (("?") reduce 494) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_BOOLEAN_AND) reduce 494) ((T_BOOLEAN_OR) reduce 494) ((T_COALESCE) reduce 494) ((T_DOUBLE_ARROW) reduce 494) ((T_INSTANCEOF) reduce 494) ((T_IS_EQUAL) reduce 494) ((T_IS_GREATER_OR_EQUAL) reduce 494) ((T_IS_IDENTICAL) reduce 494) ((T_IS_NOT_EQUAL) reduce 494) ((T_IS_NOT_IDENTICAL) reduce 494) ((T_IS_SMALLER_OR_EQUAL) reduce 494) ((T_LOGICAL_AND) reduce 494) ((T_LOGICAL_OR) reduce 494) ((T_LOGICAL_XOR) reduce 494) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 494) ((T_OBJECT_OPERATOR) reduce 494) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 494) ((T_SL) reduce 494) ((T_SPACESHIP) reduce 494) ((T_SR) reduce 494) (("[") reduce 494) (("^") reduce 494) (("{") reduce 494) (("|") reduce 494) (("}") reduce 494)) 13670 ((("%") reduce 423) (("*") reduce 423) (("+") reduce 423) (("-") reduce 423) ((".") reduce 423) (("/") reduce 423) (("<") reduce 423) ((">") reduce 423) (("?") reduce 423) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_BOOLEAN_AND) reduce 423) ((T_BOOLEAN_OR) reduce 423) ((T_COALESCE) reduce 423) ((T_DOUBLE_ARROW) reduce 423) ((T_INSTANCEOF) reduce 423) ((T_IS_EQUAL) reduce 423) ((T_IS_GREATER_OR_EQUAL) reduce 423) ((T_IS_IDENTICAL) reduce 423) ((T_IS_NOT_EQUAL) reduce 423) ((T_IS_NOT_IDENTICAL) reduce 423) ((T_IS_SMALLER_OR_EQUAL) reduce 423) ((T_LOGICAL_AND) reduce 423) ((T_LOGICAL_OR) reduce 423) ((T_LOGICAL_XOR) reduce 423) ((T_POW) reduce 423) ((T_SL) reduce 423) ((T_SPACESHIP) reduce 423) ((T_SR) reduce 423) (("^") reduce 423) (("|") reduce 423) (("}") reduce 423)) 13671 ((("%") reduce 437) (("*") reduce 437) (("+") reduce 437) (("-") reduce 437) ((".") reduce 437) (("/") reduce 437) (("<") reduce 437) ((">") reduce 437) (("?") reduce 437) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_BOOLEAN_AND) reduce 437) ((T_BOOLEAN_OR) reduce 437) ((T_COALESCE) reduce 437) ((T_DOUBLE_ARROW) reduce 437) ((T_INSTANCEOF) reduce 437) ((T_IS_EQUAL) reduce 437) ((T_IS_GREATER_OR_EQUAL) reduce 437) ((T_IS_IDENTICAL) reduce 437) ((T_IS_NOT_EQUAL) reduce 437) ((T_IS_NOT_IDENTICAL) reduce 437) ((T_IS_SMALLER_OR_EQUAL) reduce 437) ((T_LOGICAL_AND) reduce 437) ((T_LOGICAL_OR) reduce 437) ((T_LOGICAL_XOR) reduce 437) ((T_POW) reduce 437) ((T_SL) reduce 437) ((T_SPACESHIP) reduce 437) ((T_SR) reduce 437) (("^") reduce 437) (("|") reduce 437) (("}") reduce 437)) 13672 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) (("<") reduce 519) (("=") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AND_EQUAL) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_COALESCE_EQUAL) reduce 519) ((T_CONCAT_EQUAL) reduce 519) ((T_DEC) reduce 519) ((T_DIV_EQUAL) reduce 519) ((T_DOUBLE_ARROW) reduce 519) ((T_INC) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_MINUS_EQUAL) reduce 519) ((T_MOD_EQUAL) reduce 519) ((T_MUL_EQUAL) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_OR_EQUAL) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_PLUS_EQUAL) reduce 519) ((T_POW) reduce 519) ((T_POW_EQUAL) reduce 519) ((T_SL) reduce 519) ((T_SL_EQUAL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) ((T_SR_EQUAL) reduce 519) ((T_XOR_EQUAL) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519) (("}") reduce 519)) 13673 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) (("<") reduce 526) (("=") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AND_EQUAL) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_COALESCE_EQUAL) reduce 526) ((T_CONCAT_EQUAL) reduce 526) ((T_DEC) reduce 526) ((T_DIV_EQUAL) reduce 526) ((T_DOUBLE_ARROW) reduce 526) ((T_INC) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_MINUS_EQUAL) reduce 526) ((T_MOD_EQUAL) reduce 526) ((T_MUL_EQUAL) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_OR_EQUAL) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_PLUS_EQUAL) reduce 526) ((T_POW) reduce 526) ((T_POW_EQUAL) reduce 526) ((T_SL) reduce 526) ((T_SL_EQUAL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) ((T_SR_EQUAL) reduce 526) ((T_XOR_EQUAL) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526) (("}") reduce 526)) 13674 ((("%") reduce 367) (("*") reduce 367) (("+") reduce 367) (("-") reduce 367) ((".") reduce 367) (("/") reduce 367) (("<") reduce 367) (("=") shift) ((">") reduce 367) (("?") reduce 367) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AND_EQUAL) shift) ((T_BOOLEAN_AND) reduce 367) ((T_BOOLEAN_OR) reduce 367) ((T_COALESCE) reduce 367) ((T_COALESCE_EQUAL) shift) ((T_CONCAT_EQUAL) shift) ((T_DEC) shift) ((T_DIV_EQUAL) shift) ((T_DOUBLE_ARROW) reduce 367) ((T_INC) shift) ((T_INSTANCEOF) reduce 367) ((T_IS_EQUAL) reduce 367) ((T_IS_GREATER_OR_EQUAL) reduce 367) ((T_IS_IDENTICAL) reduce 367) ((T_IS_NOT_EQUAL) reduce 367) ((T_IS_NOT_IDENTICAL) reduce 367) ((T_IS_SMALLER_OR_EQUAL) reduce 367) ((T_LOGICAL_AND) reduce 367) ((T_LOGICAL_OR) reduce 367) ((T_LOGICAL_XOR) reduce 367) ((T_MINUS_EQUAL) shift) ((T_MOD_EQUAL) shift) ((T_MUL_EQUAL) shift) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_OR_EQUAL) shift) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_PLUS_EQUAL) shift) ((T_POW) reduce 367) ((T_POW_EQUAL) shift) ((T_SL) reduce 367) ((T_SL_EQUAL) shift) ((T_SPACESHIP) reduce 367) ((T_SR) reduce 367) ((T_SR_EQUAL) shift) ((T_XOR_EQUAL) shift) (("[") reduce 510) (("^") reduce 367) (("{") reduce 510) (("|") reduce 367) (("}") reduce 367)) 13677 ((("%") reduce 411) (("*") reduce 411) (("+") reduce 411) (("-") reduce 411) ((".") reduce 411) (("/") reduce 411) (("<") reduce 411) ((">") reduce 411) (("?") reduce 411) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_BOOLEAN_AND) reduce 411) ((T_BOOLEAN_OR) reduce 411) ((T_COALESCE) reduce 411) ((T_DOUBLE_ARROW) reduce 411) ((T_INSTANCEOF) reduce 411) ((T_IS_EQUAL) reduce 411) ((T_IS_GREATER_OR_EQUAL) reduce 411) ((T_IS_IDENTICAL) reduce 411) ((T_IS_NOT_EQUAL) reduce 411) ((T_IS_NOT_IDENTICAL) reduce 411) ((T_IS_SMALLER_OR_EQUAL) reduce 411) ((T_LOGICAL_AND) reduce 411) ((T_LOGICAL_OR) reduce 411) ((T_LOGICAL_XOR) reduce 411) ((T_POW) shift) ((T_SL) reduce 411) ((T_SPACESHIP) reduce 411) ((T_SR) reduce 411) (("^") reduce 411) (("|") reduce 411) (("}") reduce 411)) 13708 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 395) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 395) ((T_BOOLEAN_OR) reduce 395) ((T_COALESCE) reduce 395) ((T_DOUBLE_ARROW) reduce 395) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 395) ((T_LOGICAL_OR) reduce 395) ((T_LOGICAL_XOR) reduce 395) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") reduce 395) (("}") reduce 395)) 13709 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 398) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 398) ((T_BOOLEAN_OR) reduce 398) ((T_COALESCE) reduce 398) ((T_DOUBLE_ARROW) reduce 398) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 398) ((T_LOGICAL_OR) reduce 398) ((T_LOGICAL_XOR) reduce 398) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 398) (("|") reduce 398) (("}") reduce 398)) 13710 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 407) (("/") shift) (("<") reduce 407) ((">") reduce 407) (("?") reduce 407) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_BOOLEAN_AND) reduce 407) ((T_BOOLEAN_OR) reduce 407) ((T_COALESCE) reduce 407) ((T_DOUBLE_ARROW) reduce 407) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 407) ((T_IS_GREATER_OR_EQUAL) reduce 407) ((T_IS_IDENTICAL) reduce 407) ((T_IS_NOT_EQUAL) reduce 407) ((T_IS_NOT_IDENTICAL) reduce 407) ((T_IS_SMALLER_OR_EQUAL) reduce 407) ((T_LOGICAL_AND) reduce 407) ((T_LOGICAL_OR) reduce 407) ((T_LOGICAL_XOR) reduce 407) ((T_POW) shift) ((T_SL) reduce 407) ((T_SPACESHIP) reduce 407) ((T_SR) reduce 407) (("^") reduce 407) (("|") reduce 407) (("}") reduce 407)) 13711 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 420) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_BOOLEAN_AND) reduce 420) ((T_BOOLEAN_OR) reduce 420) ((T_COALESCE) reduce 420) ((T_DOUBLE_ARROW) reduce 420) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 420) ((T_LOGICAL_OR) reduce 420) ((T_LOGICAL_XOR) reduce 420) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 420) (("|") reduce 420) (("}") reduce 420)) 13712 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 406) (("/") shift) (("<") reduce 406) ((">") reduce 406) (("?") reduce 406) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_BOOLEAN_AND) reduce 406) ((T_BOOLEAN_OR) reduce 406) ((T_COALESCE) reduce 406) ((T_DOUBLE_ARROW) reduce 406) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 406) ((T_IS_GREATER_OR_EQUAL) reduce 406) ((T_IS_IDENTICAL) reduce 406) ((T_IS_NOT_EQUAL) reduce 406) ((T_IS_NOT_IDENTICAL) reduce 406) ((T_IS_SMALLER_OR_EQUAL) reduce 406) ((T_LOGICAL_AND) reduce 406) ((T_LOGICAL_OR) reduce 406) ((T_LOGICAL_XOR) reduce 406) ((T_POW) shift) ((T_SL) reduce 406) ((T_SPACESHIP) reduce 406) ((T_SR) reduce 406) (("^") reduce 406) (("|") reduce 406) (("}") reduce 406)) 13713 ((("%") reduce 403) (("*") reduce 403) (("+") reduce 403) (("-") reduce 403) ((".") reduce 403) (("/") reduce 403) (("<") reduce 403) ((">") reduce 403) (("?") reduce 403) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_BOOLEAN_AND) reduce 403) ((T_BOOLEAN_OR) reduce 403) ((T_COALESCE) reduce 403) ((T_DOUBLE_ARROW) reduce 403) ((T_INSTANCEOF) reduce 403) ((T_IS_EQUAL) reduce 403) ((T_IS_GREATER_OR_EQUAL) reduce 403) ((T_IS_IDENTICAL) reduce 403) ((T_IS_NOT_EQUAL) reduce 403) ((T_IS_NOT_IDENTICAL) reduce 403) ((T_IS_SMALLER_OR_EQUAL) reduce 403) ((T_LOGICAL_AND) reduce 403) ((T_LOGICAL_OR) reduce 403) ((T_LOGICAL_XOR) reduce 403) ((T_POW) shift) ((T_SL) reduce 403) ((T_SPACESHIP) reduce 403) ((T_SR) reduce 403) (("^") reduce 403) (("|") reduce 403) (("}") reduce 403)) 13714 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 394) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 394) ((T_LOGICAL_XOR) reduce 394) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 394)) 13715 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 392) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 392) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 392)) 13716 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 393) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 393) ((T_LOGICAL_OR) reduce 393) ((T_LOGICAL_XOR) reduce 393) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 393)) 13717 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 417) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_BOOLEAN_AND) reduce 417) ((T_BOOLEAN_OR) reduce 417) ((T_COALESCE) reduce 417) ((T_DOUBLE_ARROW) reduce 417) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 417) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 417) ((T_IS_NOT_EQUAL) reduce 417) ((T_IS_NOT_IDENTICAL) reduce 417) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 417) ((T_LOGICAL_OR) reduce 417) ((T_LOGICAL_XOR) reduce 417) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 417) ((T_SR) shift) (("^") reduce 417) (("|") reduce 417) (("}") reduce 417)) 13718 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 413) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_BOOLEAN_AND) reduce 413) ((T_BOOLEAN_OR) reduce 413) ((T_COALESCE) reduce 413) ((T_DOUBLE_ARROW) reduce 413) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 413) ((T_LOGICAL_OR) reduce 413) ((T_LOGICAL_XOR) reduce 413) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 413) (("|") reduce 413) (("}") reduce 413)) 13719 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 415) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_BOOLEAN_AND) reduce 415) ((T_BOOLEAN_OR) reduce 415) ((T_COALESCE) reduce 415) ((T_DOUBLE_ARROW) reduce 415) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 415) ((T_LOGICAL_OR) reduce 415) ((T_LOGICAL_XOR) reduce 415) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 415) (("|") reduce 415) (("}") reduce 415)) 13720 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 412) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_BOOLEAN_AND) reduce 412) ((T_BOOLEAN_OR) reduce 412) ((T_COALESCE) reduce 412) ((T_DOUBLE_ARROW) reduce 412) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 412) ((T_LOGICAL_OR) reduce 412) ((T_LOGICAL_XOR) reduce 412) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 412) (("|") reduce 412) (("}") reduce 412)) 13721 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 419) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_BOOLEAN_AND) reduce 419) ((T_BOOLEAN_OR) reduce 419) ((T_COALESCE) reduce 419) ((T_DOUBLE_ARROW) reduce 419) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 419) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 419) ((T_IS_NOT_EQUAL) reduce 419) ((T_IS_NOT_IDENTICAL) reduce 419) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 419) ((T_LOGICAL_OR) reduce 419) ((T_LOGICAL_XOR) reduce 419) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 419) ((T_SR) shift) (("^") reduce 419) (("|") reduce 419) (("}") reduce 419)) 13722 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 414) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_BOOLEAN_AND) reduce 414) ((T_BOOLEAN_OR) reduce 414) ((T_COALESCE) reduce 414) ((T_DOUBLE_ARROW) reduce 414) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 414) ((T_LOGICAL_OR) reduce 414) ((T_LOGICAL_XOR) reduce 414) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 414) (("|") reduce 414) (("}") reduce 414)) 13725 ((("%") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93) (("}") reduce 93)) 13726 ((("%") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92) (("}") reduce 92)) 13727 ((("%") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94) (("}") reduce 94)) 13728 ((("%") reduce 470) (("*") reduce 470) (("+") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_DOUBLE_ARROW) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470) (("}") reduce 470)) 13729 ((("%") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91) (("}") reduce 91)) 13730 ((("%") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529) (("}") reduce 529)) 13731 ((("%") reduce 472) (("*") reduce 472) (("+") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_DOUBLE_ARROW) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472) (("}") reduce 472)) 13732 ((("%") reduce 421) (("*") reduce 421) (("+") reduce 421) (("-") reduce 421) ((".") reduce 421) (("/") reduce 421) (("<") reduce 421) ((">") reduce 421) (("?") reduce 421) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_BOOLEAN_AND) reduce 421) ((T_BOOLEAN_OR) reduce 421) ((T_COALESCE) reduce 421) ((T_DOUBLE_ARROW) reduce 421) ((T_INSTANCEOF) reduce 421) ((T_IS_EQUAL) reduce 421) ((T_IS_GREATER_OR_EQUAL) reduce 421) ((T_IS_IDENTICAL) reduce 421) ((T_IS_NOT_EQUAL) reduce 421) ((T_IS_NOT_IDENTICAL) reduce 421) ((T_IS_SMALLER_OR_EQUAL) reduce 421) ((T_LOGICAL_AND) reduce 421) ((T_LOGICAL_OR) reduce 421) ((T_LOGICAL_XOR) reduce 421) ((T_POW) reduce 421) ((T_SL) reduce 421) ((T_SPACESHIP) reduce 421) ((T_SR) reduce 421) (("^") reduce 421) (("|") reduce 421) (("}") reduce 421)) 13733 ((("%") reduce 471) (("*") reduce 471) (("+") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_DOUBLE_ARROW) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471) (("}") reduce 471)) 13734 ((("%") reduce 473) (("*") reduce 473) (("+") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_DOUBLE_ARROW) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473) (("}") reduce 473)) 13735 ((("%") reduce 534) (("*") reduce 534) (("+") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_DOUBLE_ARROW) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534) (("}") reduce 534)) 13742 ((("%") reduce 536) (("*") reduce 536) (("+") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_DOUBLE_ARROW) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536) (("}") reduce 536)) 13744 ((("%") reduce 535) (("*") reduce 535) (("+") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_DOUBLE_ARROW) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535) (("}") reduce 535)) 13745 ((("%") reduce 540) (("*") reduce 540) (("+") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_DOUBLE_ARROW) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540) (("}") reduce 540)) 13746 ((("%") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544) (("}") reduce 544)) 13747 ((("%") reduce 537) (("*") reduce 537) (("+") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_DOUBLE_ARROW) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537) (("}") reduce 537)) 13748 ((("%") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546) (("}") reduce 546)) 13751 ((("%") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545) (("}") reduce 545)) 13752 ((("%") reduce 538) (("*") reduce 538) (("+") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_DOUBLE_ARROW) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538) (("}") reduce 538)) 13754 ((("%") reduce 539) (("*") reduce 539) (("+") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_DOUBLE_ARROW) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539) (("}") reduce 539)) 13756 ((("%") reduce 474) (("*") reduce 474) (("+") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_DOUBLE_ARROW) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474) (("}") reduce 474)) 13757 ((("%") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531) (("}") reduce 531)) 13760 ((("%") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530) (("}") reduce 530)) 13761 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 426) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 426) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 426) ((T_LOGICAL_OR) reduce 426) ((T_LOGICAL_XOR) reduce 426) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 426)) 13762 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 390) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) reduce 390) ((T_COALESCE) reduce 390) ((T_DOUBLE_ARROW) reduce 390) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 390) ((T_LOGICAL_OR) reduce 390) ((T_LOGICAL_XOR) reduce 390) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 390)) 13763 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 391) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 391) ((T_BOOLEAN_OR) reduce 391) ((T_COALESCE) reduce 391) ((T_DOUBLE_ARROW) reduce 391) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 391) ((T_LOGICAL_OR) reduce 391) ((T_LOGICAL_XOR) reduce 391) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 391)) 13764 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 396) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_BOOLEAN_AND) reduce 396) ((T_BOOLEAN_OR) reduce 396) ((T_COALESCE) reduce 396) ((T_DOUBLE_ARROW) reduce 396) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 396) ((T_LOGICAL_OR) reduce 396) ((T_LOGICAL_XOR) reduce 396) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 396) (("|") reduce 396) (("}") reduce 396)) 13765 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 397) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_BOOLEAN_AND) reduce 397) ((T_BOOLEAN_OR) reduce 397) ((T_COALESCE) reduce 397) ((T_DOUBLE_ARROW) reduce 397) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 397) ((T_LOGICAL_OR) reduce 397) ((T_LOGICAL_XOR) reduce 397) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 397) (("|") reduce 397) (("}") reduce 397)) 13769 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 424) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 424) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 424) ((T_LOGICAL_OR) reduce 424) ((T_LOGICAL_XOR) reduce 424) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 424)) 13770 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 425) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 425) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 425) ((T_LOGICAL_OR) reduce 425) ((T_LOGICAL_XOR) reduce 425) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 425)) 13771 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 418) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_BOOLEAN_AND) reduce 418) ((T_BOOLEAN_OR) reduce 418) ((T_COALESCE) reduce 418) ((T_DOUBLE_ARROW) reduce 418) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 418) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 418) ((T_IS_NOT_EQUAL) reduce 418) ((T_IS_NOT_IDENTICAL) reduce 418) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 418) ((T_LOGICAL_OR) reduce 418) ((T_LOGICAL_XOR) reduce 418) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 418) ((T_SR) shift) (("^") reduce 418) (("|") reduce 418) (("}") reduce 418)) 13772 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 416) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_BOOLEAN_AND) reduce 416) ((T_BOOLEAN_OR) reduce 416) ((T_COALESCE) reduce 416) ((T_DOUBLE_ARROW) reduce 416) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 416) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 416) ((T_IS_NOT_EQUAL) reduce 416) ((T_IS_NOT_IDENTICAL) reduce 416) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 416) ((T_LOGICAL_OR) reduce 416) ((T_LOGICAL_XOR) reduce 416) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 416) ((T_SR) shift) (("^") reduce 416) (("|") reduce 416) (("}") reduce 416)) 13773 ((("%") reduce 404) (("*") reduce 404) (("+") reduce 404) (("-") reduce 404) ((".") reduce 404) (("/") reduce 404) (("<") reduce 404) ((">") reduce 404) (("?") reduce 404) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_BOOLEAN_AND) reduce 404) ((T_BOOLEAN_OR) reduce 404) ((T_COALESCE) reduce 404) ((T_DOUBLE_ARROW) reduce 404) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 404) ((T_IS_GREATER_OR_EQUAL) reduce 404) ((T_IS_IDENTICAL) reduce 404) ((T_IS_NOT_EQUAL) reduce 404) ((T_IS_NOT_IDENTICAL) reduce 404) ((T_IS_SMALLER_OR_EQUAL) reduce 404) ((T_LOGICAL_AND) reduce 404) ((T_LOGICAL_OR) reduce 404) ((T_LOGICAL_XOR) reduce 404) ((T_POW) shift) ((T_SL) reduce 404) ((T_SPACESHIP) reduce 404) ((T_SR) reduce 404) (("^") reduce 404) (("|") reduce 404) (("}") reduce 404)) 13774 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 399) (("/") shift) (("<") reduce 399) ((">") reduce 399) (("?") reduce 399) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_BOOLEAN_AND) reduce 399) ((T_BOOLEAN_OR) reduce 399) ((T_COALESCE) reduce 399) ((T_DOUBLE_ARROW) reduce 399) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 399) ((T_IS_GREATER_OR_EQUAL) reduce 399) ((T_IS_IDENTICAL) reduce 399) ((T_IS_NOT_EQUAL) reduce 399) ((T_IS_NOT_IDENTICAL) reduce 399) ((T_IS_SMALLER_OR_EQUAL) reduce 399) ((T_LOGICAL_AND) reduce 399) ((T_LOGICAL_OR) reduce 399) ((T_LOGICAL_XOR) reduce 399) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 399) ((T_SR) shift) (("^") reduce 399) (("|") reduce 399) (("}") reduce 399)) 13775 ((("%") shift) (("*") shift) (("+") reduce 401) (("-") reduce 401) ((".") reduce 401) (("/") shift) (("<") reduce 401) ((">") reduce 401) (("?") reduce 401) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_BOOLEAN_AND) reduce 401) ((T_BOOLEAN_OR) reduce 401) ((T_COALESCE) reduce 401) ((T_DOUBLE_ARROW) reduce 401) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 401) ((T_IS_GREATER_OR_EQUAL) reduce 401) ((T_IS_IDENTICAL) reduce 401) ((T_IS_NOT_EQUAL) reduce 401) ((T_IS_NOT_IDENTICAL) reduce 401) ((T_IS_SMALLER_OR_EQUAL) reduce 401) ((T_LOGICAL_AND) reduce 401) ((T_LOGICAL_OR) reduce 401) ((T_LOGICAL_XOR) reduce 401) ((T_POW) shift) ((T_SL) reduce 401) ((T_SPACESHIP) reduce 401) ((T_SR) reduce 401) (("^") reduce 401) (("|") reduce 401) (("}") reduce 401)) 13776 ((("%") shift) (("*") shift) (("+") reduce 400) (("-") reduce 400) ((".") reduce 400) (("/") shift) (("<") reduce 400) ((">") reduce 400) (("?") reduce 400) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_BOOLEAN_AND) reduce 400) ((T_BOOLEAN_OR) reduce 400) ((T_COALESCE) reduce 400) ((T_DOUBLE_ARROW) reduce 400) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 400) ((T_IS_GREATER_OR_EQUAL) reduce 400) ((T_IS_IDENTICAL) reduce 400) ((T_IS_NOT_EQUAL) reduce 400) ((T_IS_NOT_IDENTICAL) reduce 400) ((T_IS_SMALLER_OR_EQUAL) reduce 400) ((T_LOGICAL_AND) reduce 400) ((T_LOGICAL_OR) reduce 400) ((T_LOGICAL_XOR) reduce 400) ((T_POW) shift) ((T_SL) reduce 400) ((T_SPACESHIP) reduce 400) ((T_SR) reduce 400) (("^") reduce 400) (("|") reduce 400) (("}") reduce 400)) 13777 ((("%") reduce 402) (("*") reduce 402) (("+") reduce 402) (("-") reduce 402) ((".") reduce 402) (("/") reduce 402) (("<") reduce 402) ((">") reduce 402) (("?") reduce 402) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_BOOLEAN_AND) reduce 402) ((T_BOOLEAN_OR) reduce 402) ((T_COALESCE) reduce 402) ((T_DOUBLE_ARROW) reduce 402) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 402) ((T_IS_GREATER_OR_EQUAL) reduce 402) ((T_IS_IDENTICAL) reduce 402) ((T_IS_NOT_EQUAL) reduce 402) ((T_IS_NOT_IDENTICAL) reduce 402) ((T_IS_SMALLER_OR_EQUAL) reduce 402) ((T_LOGICAL_AND) reduce 402) ((T_LOGICAL_OR) reduce 402) ((T_LOGICAL_XOR) reduce 402) ((T_POW) shift) ((T_SL) reduce 402) ((T_SPACESHIP) reduce 402) ((T_SR) reduce 402) (("^") reduce 402) (("|") reduce 402) (("}") reduce 402)) 13778 ((("%") reduce 405) (("*") reduce 405) (("+") reduce 405) (("-") reduce 405) ((".") reduce 405) (("/") reduce 405) (("<") reduce 405) ((">") reduce 405) (("?") reduce 405) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_BOOLEAN_AND) reduce 405) ((T_BOOLEAN_OR) reduce 405) ((T_COALESCE) reduce 405) ((T_DOUBLE_ARROW) reduce 405) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 405) ((T_IS_GREATER_OR_EQUAL) reduce 405) ((T_IS_IDENTICAL) reduce 405) ((T_IS_NOT_EQUAL) reduce 405) ((T_IS_NOT_IDENTICAL) reduce 405) ((T_IS_SMALLER_OR_EQUAL) reduce 405) ((T_LOGICAL_AND) reduce 405) ((T_LOGICAL_OR) reduce 405) ((T_LOGICAL_XOR) reduce 405) ((T_POW) shift) ((T_SL) reduce 405) ((T_SPACESHIP) reduce 405) ((T_SR) reduce 405) (("^") reduce 405) (("|") reduce 405) (("}") reduce 405)) 13780 ((("%") reduce 73) (("(") reduce 73) (("*") reduce 73) (("+") reduce 73) (("-") reduce 73) ((".") reduce 73) (("/") reduce 73) (("<") reduce 73) ((">") reduce 73) (("?") reduce 73) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_BOOLEAN_AND) reduce 73) ((T_BOOLEAN_OR) reduce 73) ((T_COALESCE) reduce 73) ((T_DOUBLE_ARROW) reduce 73) ((T_INSTANCEOF) reduce 73) ((T_IS_EQUAL) reduce 73) ((T_IS_GREATER_OR_EQUAL) reduce 73) ((T_IS_IDENTICAL) reduce 73) ((T_IS_NOT_EQUAL) reduce 73) ((T_IS_NOT_IDENTICAL) reduce 73) ((T_IS_SMALLER_OR_EQUAL) reduce 73) ((T_LOGICAL_AND) reduce 73) ((T_LOGICAL_OR) reduce 73) ((T_LOGICAL_XOR) reduce 73) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 73) ((T_OBJECT_OPERATOR) reduce 73) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 73) ((T_POW) reduce 73) ((T_SL) reduce 73) ((T_SPACESHIP) reduce 73) ((T_SR) reduce 73) (("[") reduce 73) (("^") reduce 73) (("{") reduce 73) (("|") reduce 73) (("}") reduce 73)) 13781 ((("%") reduce 52) (("(") reduce 52) (("*") reduce 52) (("+") reduce 52) (("-") reduce 52) ((".") reduce 52) (("/") reduce 52) (("<") reduce 52) ((">") reduce 52) (("?") reduce 52) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_BOOLEAN_AND) reduce 52) ((T_BOOLEAN_OR) reduce 52) ((T_COALESCE) reduce 52) ((T_DOUBLE_ARROW) reduce 52) ((T_INSTANCEOF) reduce 52) ((T_IS_EQUAL) reduce 52) ((T_IS_GREATER_OR_EQUAL) reduce 52) ((T_IS_IDENTICAL) reduce 52) ((T_IS_NOT_EQUAL) reduce 52) ((T_IS_NOT_IDENTICAL) reduce 52) ((T_IS_SMALLER_OR_EQUAL) reduce 52) ((T_LOGICAL_AND) reduce 52) ((T_LOGICAL_OR) reduce 52) ((T_LOGICAL_XOR) reduce 52) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 52) ((T_OBJECT_OPERATOR) reduce 52) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 52) ((T_POW) reduce 52) ((T_SL) reduce 52) ((T_SPACESHIP) reduce 52) ((T_SR) reduce 52) (("[") reduce 52) (("^") reduce 52) (("{") reduce 52) (("|") reduce 52) (("}") reduce 52)) 13782 ((("%") reduce 27) (("(") reduce 27) (("*") reduce 27) (("+") reduce 27) (("-") reduce 27) ((".") reduce 27) (("/") reduce 27) (("<") reduce 27) ((">") reduce 27) (("?") reduce 27) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_BOOLEAN_AND) reduce 27) ((T_BOOLEAN_OR) reduce 27) ((T_COALESCE) reduce 27) ((T_DOUBLE_ARROW) reduce 27) ((T_INSTANCEOF) reduce 27) ((T_IS_EQUAL) reduce 27) ((T_IS_GREATER_OR_EQUAL) reduce 27) ((T_IS_IDENTICAL) reduce 27) ((T_IS_NOT_EQUAL) reduce 27) ((T_IS_NOT_IDENTICAL) reduce 27) ((T_IS_SMALLER_OR_EQUAL) reduce 27) ((T_LOGICAL_AND) reduce 27) ((T_LOGICAL_OR) reduce 27) ((T_LOGICAL_XOR) reduce 27) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 27) ((T_OBJECT_OPERATOR) reduce 27) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 27) ((T_POW) reduce 27) ((T_SL) reduce 27) ((T_SPACESHIP) reduce 27) ((T_SR) reduce 27) (("[") reduce 27) (("^") reduce 27) (("{") reduce 27) (("|") reduce 27) (("}") reduce 27)) 13783 ((("%") reduce 51) (("(") reduce 51) (("*") reduce 51) (("+") reduce 51) (("-") reduce 51) ((".") reduce 51) (("/") reduce 51) (("<") reduce 51) ((">") reduce 51) (("?") reduce 51) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_BOOLEAN_AND) reduce 51) ((T_BOOLEAN_OR) reduce 51) ((T_COALESCE) reduce 51) ((T_DOUBLE_ARROW) reduce 51) ((T_INSTANCEOF) reduce 51) ((T_IS_EQUAL) reduce 51) ((T_IS_GREATER_OR_EQUAL) reduce 51) ((T_IS_IDENTICAL) reduce 51) ((T_IS_NOT_EQUAL) reduce 51) ((T_IS_NOT_IDENTICAL) reduce 51) ((T_IS_SMALLER_OR_EQUAL) reduce 51) ((T_LOGICAL_AND) reduce 51) ((T_LOGICAL_OR) reduce 51) ((T_LOGICAL_XOR) reduce 51) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 51) ((T_OBJECT_OPERATOR) reduce 51) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 51) ((T_POW) reduce 51) ((T_SL) reduce 51) ((T_SPACESHIP) reduce 51) ((T_SR) reduce 51) (("[") reduce 51) (("^") reduce 51) (("{") reduce 51) (("|") reduce 51) (("}") reduce 51)) 13784 ((("%") reduce 53) (("(") reduce 53) (("*") reduce 53) (("+") reduce 53) (("-") reduce 53) ((".") reduce 53) (("/") reduce 53) (("<") reduce 53) ((">") reduce 53) (("?") reduce 53) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_BOOLEAN_AND) reduce 53) ((T_BOOLEAN_OR) reduce 53) ((T_COALESCE) reduce 53) ((T_DOUBLE_ARROW) reduce 53) ((T_INSTANCEOF) reduce 53) ((T_IS_EQUAL) reduce 53) ((T_IS_GREATER_OR_EQUAL) reduce 53) ((T_IS_IDENTICAL) reduce 53) ((T_IS_NOT_EQUAL) reduce 53) ((T_IS_NOT_IDENTICAL) reduce 53) ((T_IS_SMALLER_OR_EQUAL) reduce 53) ((T_LOGICAL_AND) reduce 53) ((T_LOGICAL_OR) reduce 53) ((T_LOGICAL_XOR) reduce 53) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 53) ((T_OBJECT_OPERATOR) reduce 53) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 53) ((T_POW) reduce 53) ((T_SL) reduce 53) ((T_SPACESHIP) reduce 53) ((T_SR) reduce 53) (("[") reduce 53) (("^") reduce 53) (("{") reduce 53) (("|") reduce 53) (("}") reduce 53)) 13785 ((("%") reduce 49) (("(") reduce 49) (("*") reduce 49) (("+") reduce 49) (("-") reduce 49) ((".") reduce 49) (("/") reduce 49) (("<") reduce 49) ((">") reduce 49) (("?") reduce 49) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_BOOLEAN_AND) reduce 49) ((T_BOOLEAN_OR) reduce 49) ((T_COALESCE) reduce 49) ((T_DOUBLE_ARROW) reduce 49) ((T_INSTANCEOF) reduce 49) ((T_IS_EQUAL) reduce 49) ((T_IS_GREATER_OR_EQUAL) reduce 49) ((T_IS_IDENTICAL) reduce 49) ((T_IS_NOT_EQUAL) reduce 49) ((T_IS_NOT_IDENTICAL) reduce 49) ((T_IS_SMALLER_OR_EQUAL) reduce 49) ((T_LOGICAL_AND) reduce 49) ((T_LOGICAL_OR) reduce 49) ((T_LOGICAL_XOR) reduce 49) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 49) ((T_OBJECT_OPERATOR) reduce 49) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 49) ((T_POW) reduce 49) ((T_SL) reduce 49) ((T_SPACESHIP) reduce 49) ((T_SR) reduce 49) (("[") reduce 49) (("^") reduce 49) (("{") reduce 49) (("|") reduce 49) (("}") reduce 49)) 13786 ((("%") reduce 29) (("(") reduce 29) (("*") reduce 29) (("+") reduce 29) (("-") reduce 29) ((".") reduce 29) (("/") reduce 29) (("<") reduce 29) ((">") reduce 29) (("?") reduce 29) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_BOOLEAN_AND) reduce 29) ((T_BOOLEAN_OR) reduce 29) ((T_COALESCE) reduce 29) ((T_DOUBLE_ARROW) reduce 29) ((T_INSTANCEOF) reduce 29) ((T_IS_EQUAL) reduce 29) ((T_IS_GREATER_OR_EQUAL) reduce 29) ((T_IS_IDENTICAL) reduce 29) ((T_IS_NOT_EQUAL) reduce 29) ((T_IS_NOT_IDENTICAL) reduce 29) ((T_IS_SMALLER_OR_EQUAL) reduce 29) ((T_LOGICAL_AND) reduce 29) ((T_LOGICAL_OR) reduce 29) ((T_LOGICAL_XOR) reduce 29) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 29) ((T_OBJECT_OPERATOR) reduce 29) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 29) ((T_POW) reduce 29) ((T_SL) reduce 29) ((T_SPACESHIP) reduce 29) ((T_SR) reduce 29) (("[") reduce 29) (("^") reduce 29) (("{") reduce 29) (("|") reduce 29) (("}") reduce 29)) 13787 ((("%") reduce 59) (("(") reduce 59) (("*") reduce 59) (("+") reduce 59) (("-") reduce 59) ((".") reduce 59) (("/") reduce 59) (("<") reduce 59) ((">") reduce 59) (("?") reduce 59) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_BOOLEAN_AND) reduce 59) ((T_BOOLEAN_OR) reduce 59) ((T_COALESCE) reduce 59) ((T_DOUBLE_ARROW) reduce 59) ((T_INSTANCEOF) reduce 59) ((T_IS_EQUAL) reduce 59) ((T_IS_GREATER_OR_EQUAL) reduce 59) ((T_IS_IDENTICAL) reduce 59) ((T_IS_NOT_EQUAL) reduce 59) ((T_IS_NOT_IDENTICAL) reduce 59) ((T_IS_SMALLER_OR_EQUAL) reduce 59) ((T_LOGICAL_AND) reduce 59) ((T_LOGICAL_OR) reduce 59) ((T_LOGICAL_XOR) reduce 59) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 59) ((T_OBJECT_OPERATOR) reduce 59) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 59) ((T_POW) reduce 59) ((T_SL) reduce 59) ((T_SPACESHIP) reduce 59) ((T_SR) reduce 59) (("[") reduce 59) (("^") reduce 59) (("{") reduce 59) (("|") reduce 59) (("}") reduce 59)) 13788 ((("%") reduce 60) (("(") reduce 60) (("*") reduce 60) (("+") reduce 60) (("-") reduce 60) ((".") reduce 60) (("/") reduce 60) (("<") reduce 60) ((">") reduce 60) (("?") reduce 60) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_BOOLEAN_AND) reduce 60) ((T_BOOLEAN_OR) reduce 60) ((T_COALESCE) reduce 60) ((T_DOUBLE_ARROW) reduce 60) ((T_INSTANCEOF) reduce 60) ((T_IS_EQUAL) reduce 60) ((T_IS_GREATER_OR_EQUAL) reduce 60) ((T_IS_IDENTICAL) reduce 60) ((T_IS_NOT_EQUAL) reduce 60) ((T_IS_NOT_IDENTICAL) reduce 60) ((T_IS_SMALLER_OR_EQUAL) reduce 60) ((T_LOGICAL_AND) reduce 60) ((T_LOGICAL_OR) reduce 60) ((T_LOGICAL_XOR) reduce 60) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 60) ((T_OBJECT_OPERATOR) reduce 60) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 60) ((T_POW) reduce 60) ((T_SL) reduce 60) ((T_SPACESHIP) reduce 60) ((T_SR) reduce 60) (("[") reduce 60) (("^") reduce 60) (("{") reduce 60) (("|") reduce 60) (("}") reduce 60)) 13789 ((("%") reduce 11) (("(") reduce 11) (("*") reduce 11) (("+") reduce 11) (("-") reduce 11) ((".") reduce 11) (("/") reduce 11) (("<") reduce 11) ((">") reduce 11) (("?") reduce 11) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_BOOLEAN_AND) reduce 11) ((T_BOOLEAN_OR) reduce 11) ((T_COALESCE) reduce 11) ((T_DOUBLE_ARROW) reduce 11) ((T_INSTANCEOF) reduce 11) ((T_IS_EQUAL) reduce 11) ((T_IS_GREATER_OR_EQUAL) reduce 11) ((T_IS_IDENTICAL) reduce 11) ((T_IS_NOT_EQUAL) reduce 11) ((T_IS_NOT_IDENTICAL) reduce 11) ((T_IS_SMALLER_OR_EQUAL) reduce 11) ((T_LOGICAL_AND) reduce 11) ((T_LOGICAL_OR) reduce 11) ((T_LOGICAL_XOR) reduce 11) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 11) ((T_OBJECT_OPERATOR) reduce 11) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 11) ((T_POW) reduce 11) ((T_SL) reduce 11) ((T_SPACESHIP) reduce 11) ((T_SR) reduce 11) (("[") reduce 11) (("^") reduce 11) (("{") reduce 11) (("|") reduce 11) (("}") reduce 11)) 13790 ((("%") reduce 42) (("(") reduce 42) (("*") reduce 42) (("+") reduce 42) (("-") reduce 42) ((".") reduce 42) (("/") reduce 42) (("<") reduce 42) ((">") reduce 42) (("?") reduce 42) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_BOOLEAN_AND) reduce 42) ((T_BOOLEAN_OR) reduce 42) ((T_COALESCE) reduce 42) ((T_DOUBLE_ARROW) reduce 42) ((T_INSTANCEOF) reduce 42) ((T_IS_EQUAL) reduce 42) ((T_IS_GREATER_OR_EQUAL) reduce 42) ((T_IS_IDENTICAL) reduce 42) ((T_IS_NOT_EQUAL) reduce 42) ((T_IS_NOT_IDENTICAL) reduce 42) ((T_IS_SMALLER_OR_EQUAL) reduce 42) ((T_LOGICAL_AND) reduce 42) ((T_LOGICAL_OR) reduce 42) ((T_LOGICAL_XOR) reduce 42) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 42) ((T_OBJECT_OPERATOR) reduce 42) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 42) ((T_POW) reduce 42) ((T_SL) reduce 42) ((T_SPACESHIP) reduce 42) ((T_SR) reduce 42) (("[") reduce 42) (("^") reduce 42) (("{") reduce 42) (("|") reduce 42) (("}") reduce 42)) 13791 ((("%") reduce 39) (("(") reduce 39) (("*") reduce 39) (("+") reduce 39) (("-") reduce 39) ((".") reduce 39) (("/") reduce 39) (("<") reduce 39) ((">") reduce 39) (("?") reduce 39) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_BOOLEAN_AND) reduce 39) ((T_BOOLEAN_OR) reduce 39) ((T_COALESCE) reduce 39) ((T_DOUBLE_ARROW) reduce 39) ((T_INSTANCEOF) reduce 39) ((T_IS_EQUAL) reduce 39) ((T_IS_GREATER_OR_EQUAL) reduce 39) ((T_IS_IDENTICAL) reduce 39) ((T_IS_NOT_EQUAL) reduce 39) ((T_IS_NOT_IDENTICAL) reduce 39) ((T_IS_SMALLER_OR_EQUAL) reduce 39) ((T_LOGICAL_AND) reduce 39) ((T_LOGICAL_OR) reduce 39) ((T_LOGICAL_XOR) reduce 39) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 39) ((T_OBJECT_OPERATOR) reduce 39) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 39) ((T_POW) reduce 39) ((T_SL) reduce 39) ((T_SPACESHIP) reduce 39) ((T_SR) reduce 39) (("[") reduce 39) (("^") reduce 39) (("{") reduce 39) (("|") reduce 39) (("}") reduce 39)) 13792 ((("%") reduce 25) (("(") reduce 25) (("*") reduce 25) (("+") reduce 25) (("-") reduce 25) ((".") reduce 25) (("/") reduce 25) (("<") reduce 25) ((">") reduce 25) (("?") reduce 25) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_BOOLEAN_AND) reduce 25) ((T_BOOLEAN_OR) reduce 25) ((T_COALESCE) reduce 25) ((T_DOUBLE_ARROW) reduce 25) ((T_INSTANCEOF) reduce 25) ((T_IS_EQUAL) reduce 25) ((T_IS_GREATER_OR_EQUAL) reduce 25) ((T_IS_IDENTICAL) reduce 25) ((T_IS_NOT_EQUAL) reduce 25) ((T_IS_NOT_IDENTICAL) reduce 25) ((T_IS_SMALLER_OR_EQUAL) reduce 25) ((T_LOGICAL_AND) reduce 25) ((T_LOGICAL_OR) reduce 25) ((T_LOGICAL_XOR) reduce 25) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 25) ((T_OBJECT_OPERATOR) reduce 25) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 25) ((T_POW) reduce 25) ((T_SL) reduce 25) ((T_SPACESHIP) reduce 25) ((T_SR) reduce 25) (("[") reduce 25) (("^") reduce 25) (("{") reduce 25) (("|") reduce 25) (("}") reduce 25)) 13793 ((("%") reduce 50) (("(") reduce 50) (("*") reduce 50) (("+") reduce 50) (("-") reduce 50) ((".") reduce 50) (("/") reduce 50) (("<") reduce 50) ((">") reduce 50) (("?") reduce 50) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_BOOLEAN_AND) reduce 50) ((T_BOOLEAN_OR) reduce 50) ((T_COALESCE) reduce 50) ((T_DOUBLE_ARROW) reduce 50) ((T_INSTANCEOF) reduce 50) ((T_IS_EQUAL) reduce 50) ((T_IS_GREATER_OR_EQUAL) reduce 50) ((T_IS_IDENTICAL) reduce 50) ((T_IS_NOT_EQUAL) reduce 50) ((T_IS_NOT_IDENTICAL) reduce 50) ((T_IS_SMALLER_OR_EQUAL) reduce 50) ((T_LOGICAL_AND) reduce 50) ((T_LOGICAL_OR) reduce 50) ((T_LOGICAL_XOR) reduce 50) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 50) ((T_OBJECT_OPERATOR) reduce 50) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 50) ((T_POW) reduce 50) ((T_SL) reduce 50) ((T_SPACESHIP) reduce 50) ((T_SR) reduce 50) (("[") reduce 50) (("^") reduce 50) (("{") reduce 50) (("|") reduce 50) (("}") reduce 50)) 13794 ((("%") reduce 66) (("(") reduce 66) (("*") reduce 66) (("+") reduce 66) (("-") reduce 66) ((".") reduce 66) (("/") reduce 66) (("<") reduce 66) ((">") reduce 66) (("?") reduce 66) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_BOOLEAN_AND) reduce 66) ((T_BOOLEAN_OR) reduce 66) ((T_COALESCE) reduce 66) ((T_DOUBLE_ARROW) reduce 66) ((T_INSTANCEOF) reduce 66) ((T_IS_EQUAL) reduce 66) ((T_IS_GREATER_OR_EQUAL) reduce 66) ((T_IS_IDENTICAL) reduce 66) ((T_IS_NOT_EQUAL) reduce 66) ((T_IS_NOT_IDENTICAL) reduce 66) ((T_IS_SMALLER_OR_EQUAL) reduce 66) ((T_LOGICAL_AND) reduce 66) ((T_LOGICAL_OR) reduce 66) ((T_LOGICAL_XOR) reduce 66) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 66) ((T_OBJECT_OPERATOR) reduce 66) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 66) ((T_POW) reduce 66) ((T_SL) reduce 66) ((T_SPACESHIP) reduce 66) ((T_SR) reduce 66) (("[") reduce 66) (("^") reduce 66) (("{") reduce 66) (("|") reduce 66) (("}") reduce 66)) 13795 ((("%") reduce 18) (("(") reduce 18) (("*") reduce 18) (("+") reduce 18) (("-") reduce 18) ((".") reduce 18) (("/") reduce 18) (("<") reduce 18) ((">") reduce 18) (("?") reduce 18) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_BOOLEAN_AND) reduce 18) ((T_BOOLEAN_OR) reduce 18) ((T_COALESCE) reduce 18) ((T_DOUBLE_ARROW) reduce 18) ((T_INSTANCEOF) reduce 18) ((T_IS_EQUAL) reduce 18) ((T_IS_GREATER_OR_EQUAL) reduce 18) ((T_IS_IDENTICAL) reduce 18) ((T_IS_NOT_EQUAL) reduce 18) ((T_IS_NOT_IDENTICAL) reduce 18) ((T_IS_SMALLER_OR_EQUAL) reduce 18) ((T_LOGICAL_AND) reduce 18) ((T_LOGICAL_OR) reduce 18) ((T_LOGICAL_XOR) reduce 18) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 18) ((T_OBJECT_OPERATOR) reduce 18) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 18) ((T_POW) reduce 18) ((T_SL) reduce 18) ((T_SPACESHIP) reduce 18) ((T_SR) reduce 18) (("[") reduce 18) (("^") reduce 18) (("{") reduce 18) (("|") reduce 18) (("}") reduce 18)) 13796 ((("%") reduce 17) (("(") reduce 17) (("*") reduce 17) (("+") reduce 17) (("-") reduce 17) ((".") reduce 17) (("/") reduce 17) (("<") reduce 17) ((">") reduce 17) (("?") reduce 17) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_BOOLEAN_AND) reduce 17) ((T_BOOLEAN_OR) reduce 17) ((T_COALESCE) reduce 17) ((T_DOUBLE_ARROW) reduce 17) ((T_INSTANCEOF) reduce 17) ((T_IS_EQUAL) reduce 17) ((T_IS_GREATER_OR_EQUAL) reduce 17) ((T_IS_IDENTICAL) reduce 17) ((T_IS_NOT_EQUAL) reduce 17) ((T_IS_NOT_IDENTICAL) reduce 17) ((T_IS_SMALLER_OR_EQUAL) reduce 17) ((T_LOGICAL_AND) reduce 17) ((T_LOGICAL_OR) reduce 17) ((T_LOGICAL_XOR) reduce 17) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 17) ((T_OBJECT_OPERATOR) reduce 17) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 17) ((T_POW) reduce 17) ((T_SL) reduce 17) ((T_SPACESHIP) reduce 17) ((T_SR) reduce 17) (("[") reduce 17) (("^") reduce 17) (("{") reduce 17) (("|") reduce 17) (("}") reduce 17)) 13797 ((("%") reduce 15) (("(") reduce 15) (("*") reduce 15) (("+") reduce 15) (("-") reduce 15) ((".") reduce 15) (("/") reduce 15) (("<") reduce 15) ((">") reduce 15) (("?") reduce 15) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_BOOLEAN_AND) reduce 15) ((T_BOOLEAN_OR) reduce 15) ((T_COALESCE) reduce 15) ((T_DOUBLE_ARROW) reduce 15) ((T_INSTANCEOF) reduce 15) ((T_IS_EQUAL) reduce 15) ((T_IS_GREATER_OR_EQUAL) reduce 15) ((T_IS_IDENTICAL) reduce 15) ((T_IS_NOT_EQUAL) reduce 15) ((T_IS_NOT_IDENTICAL) reduce 15) ((T_IS_SMALLER_OR_EQUAL) reduce 15) ((T_LOGICAL_AND) reduce 15) ((T_LOGICAL_OR) reduce 15) ((T_LOGICAL_XOR) reduce 15) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 15) ((T_OBJECT_OPERATOR) reduce 15) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 15) ((T_POW) reduce 15) ((T_SL) reduce 15) ((T_SPACESHIP) reduce 15) ((T_SR) reduce 15) (("[") reduce 15) (("^") reduce 15) (("{") reduce 15) (("|") reduce 15) (("}") reduce 15)) 13798 ((("%") reduce 14) (("(") reduce 14) (("*") reduce 14) (("+") reduce 14) (("-") reduce 14) ((".") reduce 14) (("/") reduce 14) (("<") reduce 14) ((">") reduce 14) (("?") reduce 14) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_BOOLEAN_AND) reduce 14) ((T_BOOLEAN_OR) reduce 14) ((T_COALESCE) reduce 14) ((T_DOUBLE_ARROW) reduce 14) ((T_INSTANCEOF) reduce 14) ((T_IS_EQUAL) reduce 14) ((T_IS_GREATER_OR_EQUAL) reduce 14) ((T_IS_IDENTICAL) reduce 14) ((T_IS_NOT_EQUAL) reduce 14) ((T_IS_NOT_IDENTICAL) reduce 14) ((T_IS_SMALLER_OR_EQUAL) reduce 14) ((T_LOGICAL_AND) reduce 14) ((T_LOGICAL_OR) reduce 14) ((T_LOGICAL_XOR) reduce 14) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 14) ((T_OBJECT_OPERATOR) reduce 14) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 14) ((T_POW) reduce 14) ((T_SL) reduce 14) ((T_SPACESHIP) reduce 14) ((T_SR) reduce 14) (("[") reduce 14) (("^") reduce 14) (("{") reduce 14) (("|") reduce 14) (("}") reduce 14)) 13799 ((("%") reduce 38) (("(") reduce 38) (("*") reduce 38) (("+") reduce 38) (("-") reduce 38) ((".") reduce 38) (("/") reduce 38) (("<") reduce 38) ((">") reduce 38) (("?") reduce 38) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_BOOLEAN_AND) reduce 38) ((T_BOOLEAN_OR) reduce 38) ((T_COALESCE) reduce 38) ((T_DOUBLE_ARROW) reduce 38) ((T_INSTANCEOF) reduce 38) ((T_IS_EQUAL) reduce 38) ((T_IS_GREATER_OR_EQUAL) reduce 38) ((T_IS_IDENTICAL) reduce 38) ((T_IS_NOT_EQUAL) reduce 38) ((T_IS_NOT_IDENTICAL) reduce 38) ((T_IS_SMALLER_OR_EQUAL) reduce 38) ((T_LOGICAL_AND) reduce 38) ((T_LOGICAL_OR) reduce 38) ((T_LOGICAL_XOR) reduce 38) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 38) ((T_OBJECT_OPERATOR) reduce 38) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 38) ((T_POW) reduce 38) ((T_SL) reduce 38) ((T_SPACESHIP) reduce 38) ((T_SR) reduce 38) (("[") reduce 38) (("^") reduce 38) (("{") reduce 38) (("|") reduce 38) (("}") reduce 38)) 13800 ((("%") reduce 26) (("(") reduce 26) (("*") reduce 26) (("+") reduce 26) (("-") reduce 26) ((".") reduce 26) (("/") reduce 26) (("<") reduce 26) ((">") reduce 26) (("?") reduce 26) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_BOOLEAN_AND) reduce 26) ((T_BOOLEAN_OR) reduce 26) ((T_COALESCE) reduce 26) ((T_DOUBLE_ARROW) reduce 26) ((T_INSTANCEOF) reduce 26) ((T_IS_EQUAL) reduce 26) ((T_IS_GREATER_OR_EQUAL) reduce 26) ((T_IS_IDENTICAL) reduce 26) ((T_IS_NOT_EQUAL) reduce 26) ((T_IS_NOT_IDENTICAL) reduce 26) ((T_IS_SMALLER_OR_EQUAL) reduce 26) ((T_LOGICAL_AND) reduce 26) ((T_LOGICAL_OR) reduce 26) ((T_LOGICAL_XOR) reduce 26) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 26) ((T_OBJECT_OPERATOR) reduce 26) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 26) ((T_POW) reduce 26) ((T_SL) reduce 26) ((T_SPACESHIP) reduce 26) ((T_SR) reduce 26) (("[") reduce 26) (("^") reduce 26) (("{") reduce 26) (("|") reduce 26) (("}") reduce 26)) 13801 ((("%") reduce 22) (("(") reduce 22) (("*") reduce 22) (("+") reduce 22) (("-") reduce 22) ((".") reduce 22) (("/") reduce 22) (("<") reduce 22) ((">") reduce 22) (("?") reduce 22) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_BOOLEAN_AND) reduce 22) ((T_BOOLEAN_OR) reduce 22) ((T_COALESCE) reduce 22) ((T_DOUBLE_ARROW) reduce 22) ((T_INSTANCEOF) reduce 22) ((T_IS_EQUAL) reduce 22) ((T_IS_GREATER_OR_EQUAL) reduce 22) ((T_IS_IDENTICAL) reduce 22) ((T_IS_NOT_EQUAL) reduce 22) ((T_IS_NOT_IDENTICAL) reduce 22) ((T_IS_SMALLER_OR_EQUAL) reduce 22) ((T_LOGICAL_AND) reduce 22) ((T_LOGICAL_OR) reduce 22) ((T_LOGICAL_XOR) reduce 22) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 22) ((T_OBJECT_OPERATOR) reduce 22) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 22) ((T_POW) reduce 22) ((T_SL) reduce 22) ((T_SPACESHIP) reduce 22) ((T_SR) reduce 22) (("[") reduce 22) (("^") reduce 22) (("{") reduce 22) (("|") reduce 22) (("}") reduce 22)) 13802 ((("%") reduce 24) (("(") reduce 24) (("*") reduce 24) (("+") reduce 24) (("-") reduce 24) ((".") reduce 24) (("/") reduce 24) (("<") reduce 24) ((">") reduce 24) (("?") reduce 24) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_BOOLEAN_AND) reduce 24) ((T_BOOLEAN_OR) reduce 24) ((T_COALESCE) reduce 24) ((T_DOUBLE_ARROW) reduce 24) ((T_INSTANCEOF) reduce 24) ((T_IS_EQUAL) reduce 24) ((T_IS_GREATER_OR_EQUAL) reduce 24) ((T_IS_IDENTICAL) reduce 24) ((T_IS_NOT_EQUAL) reduce 24) ((T_IS_NOT_IDENTICAL) reduce 24) ((T_IS_SMALLER_OR_EQUAL) reduce 24) ((T_LOGICAL_AND) reduce 24) ((T_LOGICAL_OR) reduce 24) ((T_LOGICAL_XOR) reduce 24) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 24) ((T_OBJECT_OPERATOR) reduce 24) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 24) ((T_POW) reduce 24) ((T_SL) reduce 24) ((T_SPACESHIP) reduce 24) ((T_SR) reduce 24) (("[") reduce 24) (("^") reduce 24) (("{") reduce 24) (("|") reduce 24) (("}") reduce 24)) 13803 ((("%") reduce 16) (("(") reduce 16) (("*") reduce 16) (("+") reduce 16) (("-") reduce 16) ((".") reduce 16) (("/") reduce 16) (("<") reduce 16) ((">") reduce 16) (("?") reduce 16) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_BOOLEAN_AND) reduce 16) ((T_BOOLEAN_OR) reduce 16) ((T_COALESCE) reduce 16) ((T_DOUBLE_ARROW) reduce 16) ((T_INSTANCEOF) reduce 16) ((T_IS_EQUAL) reduce 16) ((T_IS_GREATER_OR_EQUAL) reduce 16) ((T_IS_IDENTICAL) reduce 16) ((T_IS_NOT_EQUAL) reduce 16) ((T_IS_NOT_IDENTICAL) reduce 16) ((T_IS_SMALLER_OR_EQUAL) reduce 16) ((T_LOGICAL_AND) reduce 16) ((T_LOGICAL_OR) reduce 16) ((T_LOGICAL_XOR) reduce 16) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 16) ((T_OBJECT_OPERATOR) reduce 16) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 16) ((T_POW) reduce 16) ((T_SL) reduce 16) ((T_SPACESHIP) reduce 16) ((T_SR) reduce 16) (("[") reduce 16) (("^") reduce 16) (("{") reduce 16) (("|") reduce 16) (("}") reduce 16)) 13804 ((("%") reduce 48) (("(") reduce 48) (("*") reduce 48) (("+") reduce 48) (("-") reduce 48) ((".") reduce 48) (("/") reduce 48) (("<") reduce 48) ((">") reduce 48) (("?") reduce 48) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_BOOLEAN_AND) reduce 48) ((T_BOOLEAN_OR) reduce 48) ((T_COALESCE) reduce 48) ((T_DOUBLE_ARROW) reduce 48) ((T_INSTANCEOF) reduce 48) ((T_IS_EQUAL) reduce 48) ((T_IS_GREATER_OR_EQUAL) reduce 48) ((T_IS_IDENTICAL) reduce 48) ((T_IS_NOT_EQUAL) reduce 48) ((T_IS_NOT_IDENTICAL) reduce 48) ((T_IS_SMALLER_OR_EQUAL) reduce 48) ((T_LOGICAL_AND) reduce 48) ((T_LOGICAL_OR) reduce 48) ((T_LOGICAL_XOR) reduce 48) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 48) ((T_OBJECT_OPERATOR) reduce 48) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 48) ((T_POW) reduce 48) ((T_SL) reduce 48) ((T_SPACESHIP) reduce 48) ((T_SR) reduce 48) (("[") reduce 48) (("^") reduce 48) (("{") reduce 48) (("|") reduce 48) (("}") reduce 48)) 13805 ((("%") reduce 20) (("(") reduce 20) (("*") reduce 20) (("+") reduce 20) (("-") reduce 20) ((".") reduce 20) (("/") reduce 20) (("<") reduce 20) ((">") reduce 20) (("?") reduce 20) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_BOOLEAN_AND) reduce 20) ((T_BOOLEAN_OR) reduce 20) ((T_COALESCE) reduce 20) ((T_DOUBLE_ARROW) reduce 20) ((T_INSTANCEOF) reduce 20) ((T_IS_EQUAL) reduce 20) ((T_IS_GREATER_OR_EQUAL) reduce 20) ((T_IS_IDENTICAL) reduce 20) ((T_IS_NOT_EQUAL) reduce 20) ((T_IS_NOT_IDENTICAL) reduce 20) ((T_IS_SMALLER_OR_EQUAL) reduce 20) ((T_LOGICAL_AND) reduce 20) ((T_LOGICAL_OR) reduce 20) ((T_LOGICAL_XOR) reduce 20) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 20) ((T_OBJECT_OPERATOR) reduce 20) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 20) ((T_POW) reduce 20) ((T_SL) reduce 20) ((T_SPACESHIP) reduce 20) ((T_SR) reduce 20) (("[") reduce 20) (("^") reduce 20) (("{") reduce 20) (("|") reduce 20) (("}") reduce 20)) 13806 ((("%") reduce 70) (("(") reduce 70) (("*") reduce 70) (("+") reduce 70) (("-") reduce 70) ((".") reduce 70) (("/") reduce 70) (("<") reduce 70) ((">") reduce 70) (("?") reduce 70) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_BOOLEAN_AND) reduce 70) ((T_BOOLEAN_OR) reduce 70) ((T_COALESCE) reduce 70) ((T_DOUBLE_ARROW) reduce 70) ((T_INSTANCEOF) reduce 70) ((T_IS_EQUAL) reduce 70) ((T_IS_GREATER_OR_EQUAL) reduce 70) ((T_IS_IDENTICAL) reduce 70) ((T_IS_NOT_EQUAL) reduce 70) ((T_IS_NOT_IDENTICAL) reduce 70) ((T_IS_SMALLER_OR_EQUAL) reduce 70) ((T_LOGICAL_AND) reduce 70) ((T_LOGICAL_OR) reduce 70) ((T_LOGICAL_XOR) reduce 70) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 70) ((T_OBJECT_OPERATOR) reduce 70) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 70) ((T_POW) reduce 70) ((T_SL) reduce 70) ((T_SPACESHIP) reduce 70) ((T_SR) reduce 70) (("[") reduce 70) (("^") reduce 70) (("{") reduce 70) (("|") reduce 70) (("}") reduce 70)) 13807 ((("%") reduce 3) (("(") reduce 3) (("*") reduce 3) (("+") reduce 3) (("-") reduce 3) ((".") reduce 3) (("/") reduce 3) (("<") reduce 3) ((">") reduce 3) (("?") reduce 3) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_BOOLEAN_AND) reduce 3) ((T_BOOLEAN_OR) reduce 3) ((T_COALESCE) reduce 3) ((T_DOUBLE_ARROW) reduce 3) ((T_INSTANCEOF) reduce 3) ((T_IS_EQUAL) reduce 3) ((T_IS_GREATER_OR_EQUAL) reduce 3) ((T_IS_IDENTICAL) reduce 3) ((T_IS_NOT_EQUAL) reduce 3) ((T_IS_NOT_IDENTICAL) reduce 3) ((T_IS_SMALLER_OR_EQUAL) reduce 3) ((T_LOGICAL_AND) reduce 3) ((T_LOGICAL_OR) reduce 3) ((T_LOGICAL_XOR) reduce 3) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 3) ((T_OBJECT_OPERATOR) reduce 3) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 3) ((T_POW) reduce 3) ((T_SL) reduce 3) ((T_SPACESHIP) reduce 3) ((T_SR) reduce 3) (("[") reduce 3) (("^") reduce 3) (("{") reduce 3) (("|") reduce 3) (("}") reduce 3)) 13808 ((("%") reduce 12) (("(") reduce 12) (("*") reduce 12) (("+") reduce 12) (("-") reduce 12) ((".") reduce 12) (("/") reduce 12) (("<") reduce 12) ((">") reduce 12) (("?") reduce 12) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_BOOLEAN_AND) reduce 12) ((T_BOOLEAN_OR) reduce 12) ((T_COALESCE) reduce 12) ((T_DOUBLE_ARROW) reduce 12) ((T_INSTANCEOF) reduce 12) ((T_IS_EQUAL) reduce 12) ((T_IS_GREATER_OR_EQUAL) reduce 12) ((T_IS_IDENTICAL) reduce 12) ((T_IS_NOT_EQUAL) reduce 12) ((T_IS_NOT_IDENTICAL) reduce 12) ((T_IS_SMALLER_OR_EQUAL) reduce 12) ((T_LOGICAL_AND) reduce 12) ((T_LOGICAL_OR) reduce 12) ((T_LOGICAL_XOR) reduce 12) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 12) ((T_OBJECT_OPERATOR) reduce 12) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 12) ((T_POW) reduce 12) ((T_SL) reduce 12) ((T_SPACESHIP) reduce 12) ((T_SR) reduce 12) (("[") reduce 12) (("^") reduce 12) (("{") reduce 12) (("|") reduce 12) (("}") reduce 12)) 13809 ((("%") reduce 54) (("(") reduce 54) (("*") reduce 54) (("+") reduce 54) (("-") reduce 54) ((".") reduce 54) (("/") reduce 54) (("<") reduce 54) ((">") reduce 54) (("?") reduce 54) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_BOOLEAN_AND) reduce 54) ((T_BOOLEAN_OR) reduce 54) ((T_COALESCE) reduce 54) ((T_DOUBLE_ARROW) reduce 54) ((T_INSTANCEOF) reduce 54) ((T_IS_EQUAL) reduce 54) ((T_IS_GREATER_OR_EQUAL) reduce 54) ((T_IS_IDENTICAL) reduce 54) ((T_IS_NOT_EQUAL) reduce 54) ((T_IS_NOT_IDENTICAL) reduce 54) ((T_IS_SMALLER_OR_EQUAL) reduce 54) ((T_LOGICAL_AND) reduce 54) ((T_LOGICAL_OR) reduce 54) ((T_LOGICAL_XOR) reduce 54) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 54) ((T_OBJECT_OPERATOR) reduce 54) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 54) ((T_POW) reduce 54) ((T_SL) reduce 54) ((T_SPACESHIP) reduce 54) ((T_SR) reduce 54) (("[") reduce 54) (("^") reduce 54) (("{") reduce 54) (("|") reduce 54) (("}") reduce 54)) 13810 ((("%") reduce 65) (("(") reduce 65) (("*") reduce 65) (("+") reduce 65) (("-") reduce 65) ((".") reduce 65) (("/") reduce 65) (("<") reduce 65) ((">") reduce 65) (("?") reduce 65) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_BOOLEAN_AND) reduce 65) ((T_BOOLEAN_OR) reduce 65) ((T_COALESCE) reduce 65) ((T_DOUBLE_ARROW) reduce 65) ((T_INSTANCEOF) reduce 65) ((T_IS_EQUAL) reduce 65) ((T_IS_GREATER_OR_EQUAL) reduce 65) ((T_IS_IDENTICAL) reduce 65) ((T_IS_NOT_EQUAL) reduce 65) ((T_IS_NOT_IDENTICAL) reduce 65) ((T_IS_SMALLER_OR_EQUAL) reduce 65) ((T_LOGICAL_AND) reduce 65) ((T_LOGICAL_OR) reduce 65) ((T_LOGICAL_XOR) reduce 65) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 65) ((T_OBJECT_OPERATOR) reduce 65) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 65) ((T_POW) reduce 65) ((T_SL) reduce 65) ((T_SPACESHIP) reduce 65) ((T_SR) reduce 65) (("[") reduce 65) (("^") reduce 65) (("{") reduce 65) (("|") reduce 65) (("}") reduce 65)) 13811 ((("%") reduce 74) (("(") reduce 74) (("*") reduce 74) (("+") reduce 74) (("-") reduce 74) ((".") reduce 74) (("/") reduce 74) (("<") reduce 74) ((">") reduce 74) (("?") reduce 74) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_BOOLEAN_AND) reduce 74) ((T_BOOLEAN_OR) reduce 74) ((T_COALESCE) reduce 74) ((T_DOUBLE_ARROW) reduce 74) ((T_INSTANCEOF) reduce 74) ((T_IS_EQUAL) reduce 74) ((T_IS_GREATER_OR_EQUAL) reduce 74) ((T_IS_IDENTICAL) reduce 74) ((T_IS_NOT_EQUAL) reduce 74) ((T_IS_NOT_IDENTICAL) reduce 74) ((T_IS_SMALLER_OR_EQUAL) reduce 74) ((T_LOGICAL_AND) reduce 74) ((T_LOGICAL_OR) reduce 74) ((T_LOGICAL_XOR) reduce 74) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 74) ((T_OBJECT_OPERATOR) reduce 74) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 74) ((T_POW) reduce 74) ((T_SL) reduce 74) ((T_SPACESHIP) reduce 74) ((T_SR) reduce 74) (("[") reduce 74) (("^") reduce 74) (("{") reduce 74) (("|") reduce 74) (("}") reduce 74)) 13812 ((("%") reduce 30) (("(") reduce 30) (("*") reduce 30) (("+") reduce 30) (("-") reduce 30) ((".") reduce 30) (("/") reduce 30) (("<") reduce 30) ((">") reduce 30) (("?") reduce 30) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_BOOLEAN_AND) reduce 30) ((T_BOOLEAN_OR) reduce 30) ((T_COALESCE) reduce 30) ((T_DOUBLE_ARROW) reduce 30) ((T_INSTANCEOF) reduce 30) ((T_IS_EQUAL) reduce 30) ((T_IS_GREATER_OR_EQUAL) reduce 30) ((T_IS_IDENTICAL) reduce 30) ((T_IS_NOT_EQUAL) reduce 30) ((T_IS_NOT_IDENTICAL) reduce 30) ((T_IS_SMALLER_OR_EQUAL) reduce 30) ((T_LOGICAL_AND) reduce 30) ((T_LOGICAL_OR) reduce 30) ((T_LOGICAL_XOR) reduce 30) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 30) ((T_OBJECT_OPERATOR) reduce 30) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 30) ((T_POW) reduce 30) ((T_SL) reduce 30) ((T_SPACESHIP) reduce 30) ((T_SR) reduce 30) (("[") reduce 30) (("^") reduce 30) (("{") reduce 30) (("|") reduce 30) (("}") reduce 30)) 13813 ((("%") reduce 68) (("(") reduce 68) (("*") reduce 68) (("+") reduce 68) (("-") reduce 68) ((".") reduce 68) (("/") reduce 68) (("<") reduce 68) ((">") reduce 68) (("?") reduce 68) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_BOOLEAN_AND) reduce 68) ((T_BOOLEAN_OR) reduce 68) ((T_COALESCE) reduce 68) ((T_DOUBLE_ARROW) reduce 68) ((T_INSTANCEOF) reduce 68) ((T_IS_EQUAL) reduce 68) ((T_IS_GREATER_OR_EQUAL) reduce 68) ((T_IS_IDENTICAL) reduce 68) ((T_IS_NOT_EQUAL) reduce 68) ((T_IS_NOT_IDENTICAL) reduce 68) ((T_IS_SMALLER_OR_EQUAL) reduce 68) ((T_LOGICAL_AND) reduce 68) ((T_LOGICAL_OR) reduce 68) ((T_LOGICAL_XOR) reduce 68) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 68) ((T_OBJECT_OPERATOR) reduce 68) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 68) ((T_POW) reduce 68) ((T_SL) reduce 68) ((T_SPACESHIP) reduce 68) ((T_SR) reduce 68) (("[") reduce 68) (("^") reduce 68) (("{") reduce 68) (("|") reduce 68) (("}") reduce 68)) 13814 ((("%") reduce 21) (("(") reduce 21) (("*") reduce 21) (("+") reduce 21) (("-") reduce 21) ((".") reduce 21) (("/") reduce 21) (("<") reduce 21) ((">") reduce 21) (("?") reduce 21) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_BOOLEAN_AND) reduce 21) ((T_BOOLEAN_OR) reduce 21) ((T_COALESCE) reduce 21) ((T_DOUBLE_ARROW) reduce 21) ((T_INSTANCEOF) reduce 21) ((T_IS_EQUAL) reduce 21) ((T_IS_GREATER_OR_EQUAL) reduce 21) ((T_IS_IDENTICAL) reduce 21) ((T_IS_NOT_EQUAL) reduce 21) ((T_IS_NOT_IDENTICAL) reduce 21) ((T_IS_SMALLER_OR_EQUAL) reduce 21) ((T_LOGICAL_AND) reduce 21) ((T_LOGICAL_OR) reduce 21) ((T_LOGICAL_XOR) reduce 21) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 21) ((T_OBJECT_OPERATOR) reduce 21) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 21) ((T_POW) reduce 21) ((T_SL) reduce 21) ((T_SPACESHIP) reduce 21) ((T_SR) reduce 21) (("[") reduce 21) (("^") reduce 21) (("{") reduce 21) (("|") reduce 21) (("}") reduce 21)) 13815 ((("%") reduce 23) (("(") reduce 23) (("*") reduce 23) (("+") reduce 23) (("-") reduce 23) ((".") reduce 23) (("/") reduce 23) (("<") reduce 23) ((">") reduce 23) (("?") reduce 23) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_BOOLEAN_AND) reduce 23) ((T_BOOLEAN_OR) reduce 23) ((T_COALESCE) reduce 23) ((T_DOUBLE_ARROW) reduce 23) ((T_INSTANCEOF) reduce 23) ((T_IS_EQUAL) reduce 23) ((T_IS_GREATER_OR_EQUAL) reduce 23) ((T_IS_IDENTICAL) reduce 23) ((T_IS_NOT_EQUAL) reduce 23) ((T_IS_NOT_IDENTICAL) reduce 23) ((T_IS_SMALLER_OR_EQUAL) reduce 23) ((T_LOGICAL_AND) reduce 23) ((T_LOGICAL_OR) reduce 23) ((T_LOGICAL_XOR) reduce 23) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 23) ((T_OBJECT_OPERATOR) reduce 23) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 23) ((T_POW) reduce 23) ((T_SL) reduce 23) ((T_SPACESHIP) reduce 23) ((T_SR) reduce 23) (("[") reduce 23) (("^") reduce 23) (("{") reduce 23) (("|") reduce 23) (("}") reduce 23)) 13816 ((("%") reduce 41) (("(") reduce 41) (("*") reduce 41) (("+") reduce 41) (("-") reduce 41) ((".") reduce 41) (("/") reduce 41) (("<") reduce 41) ((">") reduce 41) (("?") reduce 41) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_BOOLEAN_AND) reduce 41) ((T_BOOLEAN_OR) reduce 41) ((T_COALESCE) reduce 41) ((T_DOUBLE_ARROW) reduce 41) ((T_INSTANCEOF) reduce 41) ((T_IS_EQUAL) reduce 41) ((T_IS_GREATER_OR_EQUAL) reduce 41) ((T_IS_IDENTICAL) reduce 41) ((T_IS_NOT_EQUAL) reduce 41) ((T_IS_NOT_IDENTICAL) reduce 41) ((T_IS_SMALLER_OR_EQUAL) reduce 41) ((T_LOGICAL_AND) reduce 41) ((T_LOGICAL_OR) reduce 41) ((T_LOGICAL_XOR) reduce 41) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 41) ((T_OBJECT_OPERATOR) reduce 41) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 41) ((T_POW) reduce 41) ((T_SL) reduce 41) ((T_SPACESHIP) reduce 41) ((T_SR) reduce 41) (("[") reduce 41) (("^") reduce 41) (("{") reduce 41) (("|") reduce 41) (("}") reduce 41)) 13817 ((("%") reduce 62) (("(") reduce 62) (("*") reduce 62) (("+") reduce 62) (("-") reduce 62) ((".") reduce 62) (("/") reduce 62) (("<") reduce 62) ((">") reduce 62) (("?") reduce 62) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_BOOLEAN_AND) reduce 62) ((T_BOOLEAN_OR) reduce 62) ((T_COALESCE) reduce 62) ((T_DOUBLE_ARROW) reduce 62) ((T_INSTANCEOF) reduce 62) ((T_IS_EQUAL) reduce 62) ((T_IS_GREATER_OR_EQUAL) reduce 62) ((T_IS_IDENTICAL) reduce 62) ((T_IS_NOT_EQUAL) reduce 62) ((T_IS_NOT_IDENTICAL) reduce 62) ((T_IS_SMALLER_OR_EQUAL) reduce 62) ((T_LOGICAL_AND) reduce 62) ((T_LOGICAL_OR) reduce 62) ((T_LOGICAL_XOR) reduce 62) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 62) ((T_OBJECT_OPERATOR) reduce 62) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 62) ((T_POW) reduce 62) ((T_SL) reduce 62) ((T_SPACESHIP) reduce 62) ((T_SR) reduce 62) (("[") reduce 62) (("^") reduce 62) (("{") reduce 62) (("|") reduce 62) (("}") reduce 62)) 13818 ((("%") reduce 34) (("(") reduce 34) (("*") reduce 34) (("+") reduce 34) (("-") reduce 34) ((".") reduce 34) (("/") reduce 34) (("<") reduce 34) ((">") reduce 34) (("?") reduce 34) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_BOOLEAN_AND) reduce 34) ((T_BOOLEAN_OR) reduce 34) ((T_COALESCE) reduce 34) ((T_DOUBLE_ARROW) reduce 34) ((T_INSTANCEOF) reduce 34) ((T_IS_EQUAL) reduce 34) ((T_IS_GREATER_OR_EQUAL) reduce 34) ((T_IS_IDENTICAL) reduce 34) ((T_IS_NOT_EQUAL) reduce 34) ((T_IS_NOT_IDENTICAL) reduce 34) ((T_IS_SMALLER_OR_EQUAL) reduce 34) ((T_LOGICAL_AND) reduce 34) ((T_LOGICAL_OR) reduce 34) ((T_LOGICAL_XOR) reduce 34) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 34) ((T_OBJECT_OPERATOR) reduce 34) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 34) ((T_POW) reduce 34) ((T_SL) reduce 34) ((T_SPACESHIP) reduce 34) ((T_SR) reduce 34) (("[") reduce 34) (("^") reduce 34) (("{") reduce 34) (("|") reduce 34) (("}") reduce 34)) 13819 ((("%") reduce 40) (("(") reduce 40) (("*") reduce 40) (("+") reduce 40) (("-") reduce 40) ((".") reduce 40) (("/") reduce 40) (("<") reduce 40) ((">") reduce 40) (("?") reduce 40) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_BOOLEAN_AND) reduce 40) ((T_BOOLEAN_OR) reduce 40) ((T_COALESCE) reduce 40) ((T_DOUBLE_ARROW) reduce 40) ((T_INSTANCEOF) reduce 40) ((T_IS_EQUAL) reduce 40) ((T_IS_GREATER_OR_EQUAL) reduce 40) ((T_IS_IDENTICAL) reduce 40) ((T_IS_NOT_EQUAL) reduce 40) ((T_IS_NOT_IDENTICAL) reduce 40) ((T_IS_SMALLER_OR_EQUAL) reduce 40) ((T_LOGICAL_AND) reduce 40) ((T_LOGICAL_OR) reduce 40) ((T_LOGICAL_XOR) reduce 40) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 40) ((T_OBJECT_OPERATOR) reduce 40) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 40) ((T_POW) reduce 40) ((T_SL) reduce 40) ((T_SPACESHIP) reduce 40) ((T_SR) reduce 40) (("[") reduce 40) (("^") reduce 40) (("{") reduce 40) (("|") reduce 40) (("}") reduce 40)) 13820 ((("%") reduce 13) (("(") reduce 13) (("*") reduce 13) (("+") reduce 13) (("-") reduce 13) ((".") reduce 13) (("/") reduce 13) (("<") reduce 13) ((">") reduce 13) (("?") reduce 13) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_BOOLEAN_AND) reduce 13) ((T_BOOLEAN_OR) reduce 13) ((T_COALESCE) reduce 13) ((T_DOUBLE_ARROW) reduce 13) ((T_INSTANCEOF) reduce 13) ((T_IS_EQUAL) reduce 13) ((T_IS_GREATER_OR_EQUAL) reduce 13) ((T_IS_IDENTICAL) reduce 13) ((T_IS_NOT_EQUAL) reduce 13) ((T_IS_NOT_IDENTICAL) reduce 13) ((T_IS_SMALLER_OR_EQUAL) reduce 13) ((T_LOGICAL_AND) reduce 13) ((T_LOGICAL_OR) reduce 13) ((T_LOGICAL_XOR) reduce 13) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 13) ((T_OBJECT_OPERATOR) reduce 13) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 13) ((T_POW) reduce 13) ((T_SL) reduce 13) ((T_SPACESHIP) reduce 13) ((T_SR) reduce 13) (("[") reduce 13) (("^") reduce 13) (("{") reduce 13) (("|") reduce 13) (("}") reduce 13)) 13821 ((("%") reduce 55) (("(") reduce 55) (("*") reduce 55) (("+") reduce 55) (("-") reduce 55) ((".") reduce 55) (("/") reduce 55) (("<") reduce 55) ((">") reduce 55) (("?") reduce 55) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_BOOLEAN_AND) reduce 55) ((T_BOOLEAN_OR) reduce 55) ((T_COALESCE) reduce 55) ((T_DOUBLE_ARROW) reduce 55) ((T_INSTANCEOF) reduce 55) ((T_IS_EQUAL) reduce 55) ((T_IS_GREATER_OR_EQUAL) reduce 55) ((T_IS_IDENTICAL) reduce 55) ((T_IS_NOT_EQUAL) reduce 55) ((T_IS_NOT_IDENTICAL) reduce 55) ((T_IS_SMALLER_OR_EQUAL) reduce 55) ((T_LOGICAL_AND) reduce 55) ((T_LOGICAL_OR) reduce 55) ((T_LOGICAL_XOR) reduce 55) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 55) ((T_OBJECT_OPERATOR) reduce 55) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 55) ((T_POW) reduce 55) ((T_SL) reduce 55) ((T_SPACESHIP) reduce 55) ((T_SR) reduce 55) (("[") reduce 55) (("^") reduce 55) (("{") reduce 55) (("|") reduce 55) (("}") reduce 55)) 13822 ((("%") reduce 1) (("(") reduce 1) (("*") reduce 1) (("+") reduce 1) (("-") reduce 1) ((".") reduce 1) (("/") reduce 1) (("<") reduce 1) ((">") reduce 1) (("?") reduce 1) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_BOOLEAN_AND) reduce 1) ((T_BOOLEAN_OR) reduce 1) ((T_COALESCE) reduce 1) ((T_DOUBLE_ARROW) reduce 1) ((T_INSTANCEOF) reduce 1) ((T_IS_EQUAL) reduce 1) ((T_IS_GREATER_OR_EQUAL) reduce 1) ((T_IS_IDENTICAL) reduce 1) ((T_IS_NOT_EQUAL) reduce 1) ((T_IS_NOT_IDENTICAL) reduce 1) ((T_IS_SMALLER_OR_EQUAL) reduce 1) ((T_LOGICAL_AND) reduce 1) ((T_LOGICAL_OR) reduce 1) ((T_LOGICAL_XOR) reduce 1) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 1) ((T_OBJECT_OPERATOR) reduce 1) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 1) ((T_POW) reduce 1) ((T_SL) reduce 1) ((T_SPACESHIP) reduce 1) ((T_SR) reduce 1) (("[") reduce 1) (("^") reduce 1) (("{") reduce 1) (("|") reduce 1) (("}") reduce 1)) 13823 ((("%") reduce 2) (("(") reduce 2) (("*") reduce 2) (("+") reduce 2) (("-") reduce 2) ((".") reduce 2) (("/") reduce 2) (("<") reduce 2) ((">") reduce 2) (("?") reduce 2) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_BOOLEAN_AND) reduce 2) ((T_BOOLEAN_OR) reduce 2) ((T_COALESCE) reduce 2) ((T_DOUBLE_ARROW) reduce 2) ((T_INSTANCEOF) reduce 2) ((T_IS_EQUAL) reduce 2) ((T_IS_GREATER_OR_EQUAL) reduce 2) ((T_IS_IDENTICAL) reduce 2) ((T_IS_NOT_EQUAL) reduce 2) ((T_IS_NOT_IDENTICAL) reduce 2) ((T_IS_SMALLER_OR_EQUAL) reduce 2) ((T_LOGICAL_AND) reduce 2) ((T_LOGICAL_OR) reduce 2) ((T_LOGICAL_XOR) reduce 2) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 2) ((T_OBJECT_OPERATOR) reduce 2) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 2) ((T_POW) reduce 2) ((T_SL) reduce 2) ((T_SPACESHIP) reduce 2) ((T_SR) reduce 2) (("[") reduce 2) (("^") reduce 2) (("{") reduce 2) (("|") reduce 2) (("}") reduce 2)) 13824 ((("%") reduce 9) (("(") reduce 9) (("*") reduce 9) (("+") reduce 9) (("-") reduce 9) ((".") reduce 9) (("/") reduce 9) (("<") reduce 9) ((">") reduce 9) (("?") reduce 9) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_BOOLEAN_AND) reduce 9) ((T_BOOLEAN_OR) reduce 9) ((T_COALESCE) reduce 9) ((T_DOUBLE_ARROW) reduce 9) ((T_INSTANCEOF) reduce 9) ((T_IS_EQUAL) reduce 9) ((T_IS_GREATER_OR_EQUAL) reduce 9) ((T_IS_IDENTICAL) reduce 9) ((T_IS_NOT_EQUAL) reduce 9) ((T_IS_NOT_IDENTICAL) reduce 9) ((T_IS_SMALLER_OR_EQUAL) reduce 9) ((T_LOGICAL_AND) reduce 9) ((T_LOGICAL_OR) reduce 9) ((T_LOGICAL_XOR) reduce 9) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 9) ((T_OBJECT_OPERATOR) reduce 9) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 9) ((T_POW) reduce 9) ((T_SL) reduce 9) ((T_SPACESHIP) reduce 9) ((T_SR) reduce 9) (("[") reduce 9) (("^") reduce 9) (("{") reduce 9) (("|") reduce 9) (("}") reduce 9)) 13825 ((("%") reduce 33) (("(") reduce 33) (("*") reduce 33) (("+") reduce 33) (("-") reduce 33) ((".") reduce 33) (("/") reduce 33) (("<") reduce 33) ((">") reduce 33) (("?") reduce 33) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_BOOLEAN_AND) reduce 33) ((T_BOOLEAN_OR) reduce 33) ((T_COALESCE) reduce 33) ((T_DOUBLE_ARROW) reduce 33) ((T_INSTANCEOF) reduce 33) ((T_IS_EQUAL) reduce 33) ((T_IS_GREATER_OR_EQUAL) reduce 33) ((T_IS_IDENTICAL) reduce 33) ((T_IS_NOT_EQUAL) reduce 33) ((T_IS_NOT_IDENTICAL) reduce 33) ((T_IS_SMALLER_OR_EQUAL) reduce 33) ((T_LOGICAL_AND) reduce 33) ((T_LOGICAL_OR) reduce 33) ((T_LOGICAL_XOR) reduce 33) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 33) ((T_OBJECT_OPERATOR) reduce 33) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 33) ((T_POW) reduce 33) ((T_SL) reduce 33) ((T_SPACESHIP) reduce 33) ((T_SR) reduce 33) (("[") reduce 33) (("^") reduce 33) (("{") reduce 33) (("|") reduce 33) (("}") reduce 33)) 13826 ((("%") reduce 58) (("(") reduce 58) (("*") reduce 58) (("+") reduce 58) (("-") reduce 58) ((".") reduce 58) (("/") reduce 58) (("<") reduce 58) ((">") reduce 58) (("?") reduce 58) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_BOOLEAN_AND) reduce 58) ((T_BOOLEAN_OR) reduce 58) ((T_COALESCE) reduce 58) ((T_DOUBLE_ARROW) reduce 58) ((T_INSTANCEOF) reduce 58) ((T_IS_EQUAL) reduce 58) ((T_IS_GREATER_OR_EQUAL) reduce 58) ((T_IS_IDENTICAL) reduce 58) ((T_IS_NOT_EQUAL) reduce 58) ((T_IS_NOT_IDENTICAL) reduce 58) ((T_IS_SMALLER_OR_EQUAL) reduce 58) ((T_LOGICAL_AND) reduce 58) ((T_LOGICAL_OR) reduce 58) ((T_LOGICAL_XOR) reduce 58) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 58) ((T_OBJECT_OPERATOR) reduce 58) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 58) ((T_POW) reduce 58) ((T_SL) reduce 58) ((T_SPACESHIP) reduce 58) ((T_SR) reduce 58) (("[") reduce 58) (("^") reduce 58) (("{") reduce 58) (("|") reduce 58) (("}") reduce 58)) 13827 ((("%") reduce 37) (("(") reduce 37) (("*") reduce 37) (("+") reduce 37) (("-") reduce 37) ((".") reduce 37) (("/") reduce 37) (("<") reduce 37) ((">") reduce 37) (("?") reduce 37) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_BOOLEAN_AND) reduce 37) ((T_BOOLEAN_OR) reduce 37) ((T_COALESCE) reduce 37) ((T_DOUBLE_ARROW) reduce 37) ((T_INSTANCEOF) reduce 37) ((T_IS_EQUAL) reduce 37) ((T_IS_GREATER_OR_EQUAL) reduce 37) ((T_IS_IDENTICAL) reduce 37) ((T_IS_NOT_EQUAL) reduce 37) ((T_IS_NOT_IDENTICAL) reduce 37) ((T_IS_SMALLER_OR_EQUAL) reduce 37) ((T_LOGICAL_AND) reduce 37) ((T_LOGICAL_OR) reduce 37) ((T_LOGICAL_XOR) reduce 37) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 37) ((T_OBJECT_OPERATOR) reduce 37) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 37) ((T_POW) reduce 37) ((T_SL) reduce 37) ((T_SPACESHIP) reduce 37) ((T_SR) reduce 37) (("[") reduce 37) (("^") reduce 37) (("{") reduce 37) (("|") reduce 37) (("}") reduce 37)) 13828 ((("%") reduce 64) (("(") reduce 64) (("*") reduce 64) (("+") reduce 64) (("-") reduce 64) ((".") reduce 64) (("/") reduce 64) (("<") reduce 64) ((">") reduce 64) (("?") reduce 64) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_BOOLEAN_AND) reduce 64) ((T_BOOLEAN_OR) reduce 64) ((T_COALESCE) reduce 64) ((T_DOUBLE_ARROW) reduce 64) ((T_INSTANCEOF) reduce 64) ((T_IS_EQUAL) reduce 64) ((T_IS_GREATER_OR_EQUAL) reduce 64) ((T_IS_IDENTICAL) reduce 64) ((T_IS_NOT_EQUAL) reduce 64) ((T_IS_NOT_IDENTICAL) reduce 64) ((T_IS_SMALLER_OR_EQUAL) reduce 64) ((T_LOGICAL_AND) reduce 64) ((T_LOGICAL_OR) reduce 64) ((T_LOGICAL_XOR) reduce 64) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 64) ((T_OBJECT_OPERATOR) reduce 64) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 64) ((T_POW) reduce 64) ((T_SL) reduce 64) ((T_SPACESHIP) reduce 64) ((T_SR) reduce 64) (("[") reduce 64) (("^") reduce 64) (("{") reduce 64) (("|") reduce 64) (("}") reduce 64)) 13829 ((("%") reduce 46) (("(") reduce 46) (("*") reduce 46) (("+") reduce 46) (("-") reduce 46) ((".") reduce 46) (("/") reduce 46) (("<") reduce 46) ((">") reduce 46) (("?") reduce 46) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_BOOLEAN_AND) reduce 46) ((T_BOOLEAN_OR) reduce 46) ((T_COALESCE) reduce 46) ((T_DOUBLE_ARROW) reduce 46) ((T_INSTANCEOF) reduce 46) ((T_IS_EQUAL) reduce 46) ((T_IS_GREATER_OR_EQUAL) reduce 46) ((T_IS_IDENTICAL) reduce 46) ((T_IS_NOT_EQUAL) reduce 46) ((T_IS_NOT_IDENTICAL) reduce 46) ((T_IS_SMALLER_OR_EQUAL) reduce 46) ((T_LOGICAL_AND) reduce 46) ((T_LOGICAL_OR) reduce 46) ((T_LOGICAL_XOR) reduce 46) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 46) ((T_OBJECT_OPERATOR) reduce 46) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 46) ((T_POW) reduce 46) ((T_SL) reduce 46) ((T_SPACESHIP) reduce 46) ((T_SR) reduce 46) (("[") reduce 46) (("^") reduce 46) (("{") reduce 46) (("|") reduce 46) (("}") reduce 46)) 13830 ((("%") reduce 8) (("(") reduce 8) (("*") reduce 8) (("+") reduce 8) (("-") reduce 8) ((".") reduce 8) (("/") reduce 8) (("<") reduce 8) ((">") reduce 8) (("?") reduce 8) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_BOOLEAN_AND) reduce 8) ((T_BOOLEAN_OR) reduce 8) ((T_COALESCE) reduce 8) ((T_DOUBLE_ARROW) reduce 8) ((T_INSTANCEOF) reduce 8) ((T_IS_EQUAL) reduce 8) ((T_IS_GREATER_OR_EQUAL) reduce 8) ((T_IS_IDENTICAL) reduce 8) ((T_IS_NOT_EQUAL) reduce 8) ((T_IS_NOT_IDENTICAL) reduce 8) ((T_IS_SMALLER_OR_EQUAL) reduce 8) ((T_LOGICAL_AND) reduce 8) ((T_LOGICAL_OR) reduce 8) ((T_LOGICAL_XOR) reduce 8) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 8) ((T_OBJECT_OPERATOR) reduce 8) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 8) ((T_POW) reduce 8) ((T_SL) reduce 8) ((T_SPACESHIP) reduce 8) ((T_SR) reduce 8) (("[") reduce 8) (("^") reduce 8) (("{") reduce 8) (("|") reduce 8) (("}") reduce 8)) 13831 ((("%") reduce 6) (("(") reduce 6) (("*") reduce 6) (("+") reduce 6) (("-") reduce 6) ((".") reduce 6) (("/") reduce 6) (("<") reduce 6) ((">") reduce 6) (("?") reduce 6) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_BOOLEAN_AND) reduce 6) ((T_BOOLEAN_OR) reduce 6) ((T_COALESCE) reduce 6) ((T_DOUBLE_ARROW) reduce 6) ((T_INSTANCEOF) reduce 6) ((T_IS_EQUAL) reduce 6) ((T_IS_GREATER_OR_EQUAL) reduce 6) ((T_IS_IDENTICAL) reduce 6) ((T_IS_NOT_EQUAL) reduce 6) ((T_IS_NOT_IDENTICAL) reduce 6) ((T_IS_SMALLER_OR_EQUAL) reduce 6) ((T_LOGICAL_AND) reduce 6) ((T_LOGICAL_OR) reduce 6) ((T_LOGICAL_XOR) reduce 6) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 6) ((T_OBJECT_OPERATOR) reduce 6) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 6) ((T_POW) reduce 6) ((T_SL) reduce 6) ((T_SPACESHIP) reduce 6) ((T_SR) reduce 6) (("[") reduce 6) (("^") reduce 6) (("{") reduce 6) (("|") reduce 6) (("}") reduce 6)) 13832 ((("%") reduce 7) (("(") reduce 7) (("*") reduce 7) (("+") reduce 7) (("-") reduce 7) ((".") reduce 7) (("/") reduce 7) (("<") reduce 7) ((">") reduce 7) (("?") reduce 7) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_BOOLEAN_AND) reduce 7) ((T_BOOLEAN_OR) reduce 7) ((T_COALESCE) reduce 7) ((T_DOUBLE_ARROW) reduce 7) ((T_INSTANCEOF) reduce 7) ((T_IS_EQUAL) reduce 7) ((T_IS_GREATER_OR_EQUAL) reduce 7) ((T_IS_IDENTICAL) reduce 7) ((T_IS_NOT_EQUAL) reduce 7) ((T_IS_NOT_IDENTICAL) reduce 7) ((T_IS_SMALLER_OR_EQUAL) reduce 7) ((T_LOGICAL_AND) reduce 7) ((T_LOGICAL_OR) reduce 7) ((T_LOGICAL_XOR) reduce 7) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 7) ((T_OBJECT_OPERATOR) reduce 7) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 7) ((T_POW) reduce 7) ((T_SL) reduce 7) ((T_SPACESHIP) reduce 7) ((T_SR) reduce 7) (("[") reduce 7) (("^") reduce 7) (("{") reduce 7) (("|") reduce 7) (("}") reduce 7)) 13833 ((("%") reduce 69) (("(") reduce 69) (("*") reduce 69) (("+") reduce 69) (("-") reduce 69) ((".") reduce 69) (("/") reduce 69) (("<") reduce 69) ((">") reduce 69) (("?") reduce 69) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_BOOLEAN_AND) reduce 69) ((T_BOOLEAN_OR) reduce 69) ((T_COALESCE) reduce 69) ((T_DOUBLE_ARROW) reduce 69) ((T_INSTANCEOF) reduce 69) ((T_IS_EQUAL) reduce 69) ((T_IS_GREATER_OR_EQUAL) reduce 69) ((T_IS_IDENTICAL) reduce 69) ((T_IS_NOT_EQUAL) reduce 69) ((T_IS_NOT_IDENTICAL) reduce 69) ((T_IS_SMALLER_OR_EQUAL) reduce 69) ((T_LOGICAL_AND) reduce 69) ((T_LOGICAL_OR) reduce 69) ((T_LOGICAL_XOR) reduce 69) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 69) ((T_OBJECT_OPERATOR) reduce 69) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 69) ((T_POW) reduce 69) ((T_SL) reduce 69) ((T_SPACESHIP) reduce 69) ((T_SR) reduce 69) (("[") reduce 69) (("^") reduce 69) (("{") reduce 69) (("|") reduce 69) (("}") reduce 69)) 13834 ((("%") reduce 63) (("(") reduce 63) (("*") reduce 63) (("+") reduce 63) (("-") reduce 63) ((".") reduce 63) (("/") reduce 63) (("<") reduce 63) ((">") reduce 63) (("?") reduce 63) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_BOOLEAN_AND) reduce 63) ((T_BOOLEAN_OR) reduce 63) ((T_COALESCE) reduce 63) ((T_DOUBLE_ARROW) reduce 63) ((T_INSTANCEOF) reduce 63) ((T_IS_EQUAL) reduce 63) ((T_IS_GREATER_OR_EQUAL) reduce 63) ((T_IS_IDENTICAL) reduce 63) ((T_IS_NOT_EQUAL) reduce 63) ((T_IS_NOT_IDENTICAL) reduce 63) ((T_IS_SMALLER_OR_EQUAL) reduce 63) ((T_LOGICAL_AND) reduce 63) ((T_LOGICAL_OR) reduce 63) ((T_LOGICAL_XOR) reduce 63) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 63) ((T_OBJECT_OPERATOR) reduce 63) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 63) ((T_POW) reduce 63) ((T_SL) reduce 63) ((T_SPACESHIP) reduce 63) ((T_SR) reduce 63) (("[") reduce 63) (("^") reduce 63) (("{") reduce 63) (("|") reduce 63) (("}") reduce 63)) 13835 ((("%") reduce 56) (("(") reduce 56) (("*") reduce 56) (("+") reduce 56) (("-") reduce 56) ((".") reduce 56) (("/") reduce 56) (("<") reduce 56) ((">") reduce 56) (("?") reduce 56) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_BOOLEAN_AND) reduce 56) ((T_BOOLEAN_OR) reduce 56) ((T_COALESCE) reduce 56) ((T_DOUBLE_ARROW) reduce 56) ((T_INSTANCEOF) reduce 56) ((T_IS_EQUAL) reduce 56) ((T_IS_GREATER_OR_EQUAL) reduce 56) ((T_IS_IDENTICAL) reduce 56) ((T_IS_NOT_EQUAL) reduce 56) ((T_IS_NOT_IDENTICAL) reduce 56) ((T_IS_SMALLER_OR_EQUAL) reduce 56) ((T_LOGICAL_AND) reduce 56) ((T_LOGICAL_OR) reduce 56) ((T_LOGICAL_XOR) reduce 56) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 56) ((T_OBJECT_OPERATOR) reduce 56) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 56) ((T_POW) reduce 56) ((T_SL) reduce 56) ((T_SPACESHIP) reduce 56) ((T_SR) reduce 56) (("[") reduce 56) (("^") reduce 56) (("{") reduce 56) (("|") reduce 56) (("}") reduce 56)) 13836 ((("%") reduce 10) (("(") reduce 10) (("*") reduce 10) (("+") reduce 10) (("-") reduce 10) ((".") reduce 10) (("/") reduce 10) (("<") reduce 10) ((">") reduce 10) (("?") reduce 10) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_BOOLEAN_AND) reduce 10) ((T_BOOLEAN_OR) reduce 10) ((T_COALESCE) reduce 10) ((T_DOUBLE_ARROW) reduce 10) ((T_INSTANCEOF) reduce 10) ((T_IS_EQUAL) reduce 10) ((T_IS_GREATER_OR_EQUAL) reduce 10) ((T_IS_IDENTICAL) reduce 10) ((T_IS_NOT_EQUAL) reduce 10) ((T_IS_NOT_IDENTICAL) reduce 10) ((T_IS_SMALLER_OR_EQUAL) reduce 10) ((T_LOGICAL_AND) reduce 10) ((T_LOGICAL_OR) reduce 10) ((T_LOGICAL_XOR) reduce 10) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 10) ((T_OBJECT_OPERATOR) reduce 10) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 10) ((T_POW) reduce 10) ((T_SL) reduce 10) ((T_SPACESHIP) reduce 10) ((T_SR) reduce 10) (("[") reduce 10) (("^") reduce 10) (("{") reduce 10) (("|") reduce 10) (("}") reduce 10)) 13837 ((("%") reduce 67) (("(") reduce 67) (("*") reduce 67) (("+") reduce 67) (("-") reduce 67) ((".") reduce 67) (("/") reduce 67) (("<") reduce 67) ((">") reduce 67) (("?") reduce 67) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_BOOLEAN_AND) reduce 67) ((T_BOOLEAN_OR) reduce 67) ((T_COALESCE) reduce 67) ((T_DOUBLE_ARROW) reduce 67) ((T_INSTANCEOF) reduce 67) ((T_IS_EQUAL) reduce 67) ((T_IS_GREATER_OR_EQUAL) reduce 67) ((T_IS_IDENTICAL) reduce 67) ((T_IS_NOT_EQUAL) reduce 67) ((T_IS_NOT_IDENTICAL) reduce 67) ((T_IS_SMALLER_OR_EQUAL) reduce 67) ((T_LOGICAL_AND) reduce 67) ((T_LOGICAL_OR) reduce 67) ((T_LOGICAL_XOR) reduce 67) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 67) ((T_OBJECT_OPERATOR) reduce 67) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 67) ((T_POW) reduce 67) ((T_SL) reduce 67) ((T_SPACESHIP) reduce 67) ((T_SR) reduce 67) (("[") reduce 67) (("^") reduce 67) (("{") reduce 67) (("|") reduce 67) (("}") reduce 67)) 13838 ((("%") reduce 44) (("(") reduce 44) (("*") reduce 44) (("+") reduce 44) (("-") reduce 44) ((".") reduce 44) (("/") reduce 44) (("<") reduce 44) ((">") reduce 44) (("?") reduce 44) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_BOOLEAN_AND) reduce 44) ((T_BOOLEAN_OR) reduce 44) ((T_COALESCE) reduce 44) ((T_DOUBLE_ARROW) reduce 44) ((T_INSTANCEOF) reduce 44) ((T_IS_EQUAL) reduce 44) ((T_IS_GREATER_OR_EQUAL) reduce 44) ((T_IS_IDENTICAL) reduce 44) ((T_IS_NOT_EQUAL) reduce 44) ((T_IS_NOT_IDENTICAL) reduce 44) ((T_IS_SMALLER_OR_EQUAL) reduce 44) ((T_LOGICAL_AND) reduce 44) ((T_LOGICAL_OR) reduce 44) ((T_LOGICAL_XOR) reduce 44) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 44) ((T_OBJECT_OPERATOR) reduce 44) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 44) ((T_POW) reduce 44) ((T_SL) reduce 44) ((T_SPACESHIP) reduce 44) ((T_SR) reduce 44) (("[") reduce 44) (("^") reduce 44) (("{") reduce 44) (("|") reduce 44) (("}") reduce 44)) 13839 ((("%") reduce 75) (("(") reduce 75) (("*") reduce 75) (("+") reduce 75) (("-") reduce 75) ((".") reduce 75) (("/") reduce 75) (("<") reduce 75) ((">") reduce 75) (("?") reduce 75) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_BOOLEAN_AND) reduce 75) ((T_BOOLEAN_OR) reduce 75) ((T_COALESCE) reduce 75) ((T_DOUBLE_ARROW) reduce 75) ((T_INSTANCEOF) reduce 75) ((T_IS_EQUAL) reduce 75) ((T_IS_GREATER_OR_EQUAL) reduce 75) ((T_IS_IDENTICAL) reduce 75) ((T_IS_NOT_EQUAL) reduce 75) ((T_IS_NOT_IDENTICAL) reduce 75) ((T_IS_SMALLER_OR_EQUAL) reduce 75) ((T_LOGICAL_AND) reduce 75) ((T_LOGICAL_OR) reduce 75) ((T_LOGICAL_XOR) reduce 75) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 75) ((T_OBJECT_OPERATOR) reduce 75) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 75) ((T_POW) reduce 75) ((T_SL) reduce 75) ((T_SPACESHIP) reduce 75) ((T_SR) reduce 75) (("[") reduce 75) (("^") reduce 75) (("{") reduce 75) (("|") reduce 75) (("}") reduce 75)) 13840 ((("%") reduce 76) (("(") reduce 76) (("*") reduce 76) (("+") reduce 76) (("-") reduce 76) ((".") reduce 76) (("/") reduce 76) (("<") reduce 76) ((">") reduce 76) (("?") reduce 76) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_BOOLEAN_AND) reduce 76) ((T_BOOLEAN_OR) reduce 76) ((T_COALESCE) reduce 76) ((T_DOUBLE_ARROW) reduce 76) ((T_INSTANCEOF) reduce 76) ((T_IS_EQUAL) reduce 76) ((T_IS_GREATER_OR_EQUAL) reduce 76) ((T_IS_IDENTICAL) reduce 76) ((T_IS_NOT_EQUAL) reduce 76) ((T_IS_NOT_IDENTICAL) reduce 76) ((T_IS_SMALLER_OR_EQUAL) reduce 76) ((T_LOGICAL_AND) reduce 76) ((T_LOGICAL_OR) reduce 76) ((T_LOGICAL_XOR) reduce 76) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 76) ((T_OBJECT_OPERATOR) reduce 76) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 76) ((T_POW) reduce 76) ((T_SL) reduce 76) ((T_SPACESHIP) reduce 76) ((T_SR) reduce 76) (("[") reduce 76) (("^") reduce 76) (("{") reduce 76) (("|") reduce 76) (("}") reduce 76)) 13841 ((("%") reduce 77) (("(") reduce 77) (("*") reduce 77) (("+") reduce 77) (("-") reduce 77) ((".") reduce 77) (("/") reduce 77) (("<") reduce 77) ((">") reduce 77) (("?") reduce 77) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_BOOLEAN_AND) reduce 77) ((T_BOOLEAN_OR) reduce 77) ((T_COALESCE) reduce 77) ((T_DOUBLE_ARROW) reduce 77) ((T_INSTANCEOF) reduce 77) ((T_IS_EQUAL) reduce 77) ((T_IS_GREATER_OR_EQUAL) reduce 77) ((T_IS_IDENTICAL) reduce 77) ((T_IS_NOT_EQUAL) reduce 77) ((T_IS_NOT_IDENTICAL) reduce 77) ((T_IS_SMALLER_OR_EQUAL) reduce 77) ((T_LOGICAL_AND) reduce 77) ((T_LOGICAL_OR) reduce 77) ((T_LOGICAL_XOR) reduce 77) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 77) ((T_OBJECT_OPERATOR) reduce 77) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 77) ((T_POW) reduce 77) ((T_SL) reduce 77) ((T_SPACESHIP) reduce 77) ((T_SR) reduce 77) (("[") reduce 77) (("^") reduce 77) (("{") reduce 77) (("|") reduce 77) (("}") reduce 77)) 13842 ((("%") reduce 78) (("(") reduce 78) (("*") reduce 78) (("+") reduce 78) (("-") reduce 78) ((".") reduce 78) (("/") reduce 78) (("<") reduce 78) ((">") reduce 78) (("?") reduce 78) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_BOOLEAN_AND) reduce 78) ((T_BOOLEAN_OR) reduce 78) ((T_COALESCE) reduce 78) ((T_DOUBLE_ARROW) reduce 78) ((T_INSTANCEOF) reduce 78) ((T_IS_EQUAL) reduce 78) ((T_IS_GREATER_OR_EQUAL) reduce 78) ((T_IS_IDENTICAL) reduce 78) ((T_IS_NOT_EQUAL) reduce 78) ((T_IS_NOT_IDENTICAL) reduce 78) ((T_IS_SMALLER_OR_EQUAL) reduce 78) ((T_LOGICAL_AND) reduce 78) ((T_LOGICAL_OR) reduce 78) ((T_LOGICAL_XOR) reduce 78) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 78) ((T_OBJECT_OPERATOR) reduce 78) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 78) ((T_POW) reduce 78) ((T_SL) reduce 78) ((T_SPACESHIP) reduce 78) ((T_SR) reduce 78) (("[") reduce 78) (("^") reduce 78) (("{") reduce 78) (("|") reduce 78) (("}") reduce 78)) 13843 ((("%") reduce 4) (("(") reduce 4) (("*") reduce 4) (("+") reduce 4) (("-") reduce 4) ((".") reduce 4) (("/") reduce 4) (("<") reduce 4) ((">") reduce 4) (("?") reduce 4) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_BOOLEAN_AND) reduce 4) ((T_BOOLEAN_OR) reduce 4) ((T_COALESCE) reduce 4) ((T_DOUBLE_ARROW) reduce 4) ((T_INSTANCEOF) reduce 4) ((T_IS_EQUAL) reduce 4) ((T_IS_GREATER_OR_EQUAL) reduce 4) ((T_IS_IDENTICAL) reduce 4) ((T_IS_NOT_EQUAL) reduce 4) ((T_IS_NOT_IDENTICAL) reduce 4) ((T_IS_SMALLER_OR_EQUAL) reduce 4) ((T_LOGICAL_AND) reduce 4) ((T_LOGICAL_OR) reduce 4) ((T_LOGICAL_XOR) reduce 4) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 4) ((T_OBJECT_OPERATOR) reduce 4) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 4) ((T_POW) reduce 4) ((T_SL) reduce 4) ((T_SPACESHIP) reduce 4) ((T_SR) reduce 4) (("[") reduce 4) (("^") reduce 4) (("{") reduce 4) (("|") reduce 4) (("}") reduce 4)) 13844 ((("%") reduce 5) (("(") reduce 5) (("*") reduce 5) (("+") reduce 5) (("-") reduce 5) ((".") reduce 5) (("/") reduce 5) (("<") reduce 5) ((">") reduce 5) (("?") reduce 5) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_BOOLEAN_AND) reduce 5) ((T_BOOLEAN_OR) reduce 5) ((T_COALESCE) reduce 5) ((T_DOUBLE_ARROW) reduce 5) ((T_INSTANCEOF) reduce 5) ((T_IS_EQUAL) reduce 5) ((T_IS_GREATER_OR_EQUAL) reduce 5) ((T_IS_IDENTICAL) reduce 5) ((T_IS_NOT_EQUAL) reduce 5) ((T_IS_NOT_IDENTICAL) reduce 5) ((T_IS_SMALLER_OR_EQUAL) reduce 5) ((T_LOGICAL_AND) reduce 5) ((T_LOGICAL_OR) reduce 5) ((T_LOGICAL_XOR) reduce 5) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 5) ((T_OBJECT_OPERATOR) reduce 5) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 5) ((T_POW) reduce 5) ((T_SL) reduce 5) ((T_SPACESHIP) reduce 5) ((T_SR) reduce 5) (("[") reduce 5) (("^") reduce 5) (("{") reduce 5) (("|") reduce 5) (("}") reduce 5)) 13845 ((("%") reduce 43) (("(") reduce 43) (("*") reduce 43) (("+") reduce 43) (("-") reduce 43) ((".") reduce 43) (("/") reduce 43) (("<") reduce 43) ((">") reduce 43) (("?") reduce 43) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_BOOLEAN_AND) reduce 43) ((T_BOOLEAN_OR) reduce 43) ((T_COALESCE) reduce 43) ((T_DOUBLE_ARROW) reduce 43) ((T_INSTANCEOF) reduce 43) ((T_IS_EQUAL) reduce 43) ((T_IS_GREATER_OR_EQUAL) reduce 43) ((T_IS_IDENTICAL) reduce 43) ((T_IS_NOT_EQUAL) reduce 43) ((T_IS_NOT_IDENTICAL) reduce 43) ((T_IS_SMALLER_OR_EQUAL) reduce 43) ((T_LOGICAL_AND) reduce 43) ((T_LOGICAL_OR) reduce 43) ((T_LOGICAL_XOR) reduce 43) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 43) ((T_OBJECT_OPERATOR) reduce 43) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 43) ((T_POW) reduce 43) ((T_SL) reduce 43) ((T_SPACESHIP) reduce 43) ((T_SR) reduce 43) (("[") reduce 43) (("^") reduce 43) (("{") reduce 43) (("|") reduce 43) (("}") reduce 43)) 13846 ((("%") reduce 72) (("(") reduce 72) (("*") reduce 72) (("+") reduce 72) (("-") reduce 72) ((".") reduce 72) (("/") reduce 72) (("<") reduce 72) ((">") reduce 72) (("?") reduce 72) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_BOOLEAN_AND) reduce 72) ((T_BOOLEAN_OR) reduce 72) ((T_COALESCE) reduce 72) ((T_DOUBLE_ARROW) reduce 72) ((T_INSTANCEOF) reduce 72) ((T_IS_EQUAL) reduce 72) ((T_IS_GREATER_OR_EQUAL) reduce 72) ((T_IS_IDENTICAL) reduce 72) ((T_IS_NOT_EQUAL) reduce 72) ((T_IS_NOT_IDENTICAL) reduce 72) ((T_IS_SMALLER_OR_EQUAL) reduce 72) ((T_LOGICAL_AND) reduce 72) ((T_LOGICAL_OR) reduce 72) ((T_LOGICAL_XOR) reduce 72) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 72) ((T_OBJECT_OPERATOR) reduce 72) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 72) ((T_POW) reduce 72) ((T_SL) reduce 72) ((T_SPACESHIP) reduce 72) ((T_SR) reduce 72) (("[") reduce 72) (("^") reduce 72) (("{") reduce 72) (("|") reduce 72) (("}") reduce 72)) 13847 ((("%") reduce 81) (("(") reduce 81) (("*") reduce 81) (("+") reduce 81) (("-") reduce 81) ((".") reduce 81) (("/") reduce 81) (("<") reduce 81) ((">") reduce 81) (("?") reduce 81) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_BOOLEAN_AND) reduce 81) ((T_BOOLEAN_OR) reduce 81) ((T_COALESCE) reduce 81) ((T_DOUBLE_ARROW) reduce 81) ((T_INSTANCEOF) reduce 81) ((T_IS_EQUAL) reduce 81) ((T_IS_GREATER_OR_EQUAL) reduce 81) ((T_IS_IDENTICAL) reduce 81) ((T_IS_NOT_EQUAL) reduce 81) ((T_IS_NOT_IDENTICAL) reduce 81) ((T_IS_SMALLER_OR_EQUAL) reduce 81) ((T_LOGICAL_AND) reduce 81) ((T_LOGICAL_OR) reduce 81) ((T_LOGICAL_XOR) reduce 81) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 81) ((T_OBJECT_OPERATOR) reduce 81) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 81) ((T_POW) reduce 81) ((T_SL) reduce 81) ((T_SPACESHIP) reduce 81) ((T_SR) reduce 81) (("[") reduce 81) (("^") reduce 81) (("{") reduce 81) (("|") reduce 81) (("}") reduce 81)) 13848 ((("%") reduce 47) (("(") reduce 47) (("*") reduce 47) (("+") reduce 47) (("-") reduce 47) ((".") reduce 47) (("/") reduce 47) (("<") reduce 47) ((">") reduce 47) (("?") reduce 47) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_BOOLEAN_AND) reduce 47) ((T_BOOLEAN_OR) reduce 47) ((T_COALESCE) reduce 47) ((T_DOUBLE_ARROW) reduce 47) ((T_INSTANCEOF) reduce 47) ((T_IS_EQUAL) reduce 47) ((T_IS_GREATER_OR_EQUAL) reduce 47) ((T_IS_IDENTICAL) reduce 47) ((T_IS_NOT_EQUAL) reduce 47) ((T_IS_NOT_IDENTICAL) reduce 47) ((T_IS_SMALLER_OR_EQUAL) reduce 47) ((T_LOGICAL_AND) reduce 47) ((T_LOGICAL_OR) reduce 47) ((T_LOGICAL_XOR) reduce 47) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 47) ((T_OBJECT_OPERATOR) reduce 47) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 47) ((T_POW) reduce 47) ((T_SL) reduce 47) ((T_SPACESHIP) reduce 47) ((T_SR) reduce 47) (("[") reduce 47) (("^") reduce 47) (("{") reduce 47) (("|") reduce 47) (("}") reduce 47)) 13849 ((("%") reduce 31) (("(") reduce 31) (("*") reduce 31) (("+") reduce 31) (("-") reduce 31) ((".") reduce 31) (("/") reduce 31) (("<") reduce 31) ((">") reduce 31) (("?") reduce 31) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_BOOLEAN_AND) reduce 31) ((T_BOOLEAN_OR) reduce 31) ((T_COALESCE) reduce 31) ((T_DOUBLE_ARROW) reduce 31) ((T_INSTANCEOF) reduce 31) ((T_IS_EQUAL) reduce 31) ((T_IS_GREATER_OR_EQUAL) reduce 31) ((T_IS_IDENTICAL) reduce 31) ((T_IS_NOT_EQUAL) reduce 31) ((T_IS_NOT_IDENTICAL) reduce 31) ((T_IS_SMALLER_OR_EQUAL) reduce 31) ((T_LOGICAL_AND) reduce 31) ((T_LOGICAL_OR) reduce 31) ((T_LOGICAL_XOR) reduce 31) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 31) ((T_OBJECT_OPERATOR) reduce 31) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 31) ((T_POW) reduce 31) ((T_SL) reduce 31) ((T_SPACESHIP) reduce 31) ((T_SR) reduce 31) (("[") reduce 31) (("^") reduce 31) (("{") reduce 31) (("|") reduce 31) (("}") reduce 31)) 13850 ((("%") reduce 57) (("(") reduce 57) (("*") reduce 57) (("+") reduce 57) (("-") reduce 57) ((".") reduce 57) (("/") reduce 57) (("<") reduce 57) ((">") reduce 57) (("?") reduce 57) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_BOOLEAN_AND) reduce 57) ((T_BOOLEAN_OR) reduce 57) ((T_COALESCE) reduce 57) ((T_DOUBLE_ARROW) reduce 57) ((T_INSTANCEOF) reduce 57) ((T_IS_EQUAL) reduce 57) ((T_IS_GREATER_OR_EQUAL) reduce 57) ((T_IS_IDENTICAL) reduce 57) ((T_IS_NOT_EQUAL) reduce 57) ((T_IS_NOT_IDENTICAL) reduce 57) ((T_IS_SMALLER_OR_EQUAL) reduce 57) ((T_LOGICAL_AND) reduce 57) ((T_LOGICAL_OR) reduce 57) ((T_LOGICAL_XOR) reduce 57) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 57) ((T_OBJECT_OPERATOR) reduce 57) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 57) ((T_POW) reduce 57) ((T_SL) reduce 57) ((T_SPACESHIP) reduce 57) ((T_SR) reduce 57) (("[") reduce 57) (("^") reduce 57) (("{") reduce 57) (("|") reduce 57) (("}") reduce 57)) 13851 ((("%") reduce 61) (("(") reduce 61) (("*") reduce 61) (("+") reduce 61) (("-") reduce 61) ((".") reduce 61) (("/") reduce 61) (("<") reduce 61) ((">") reduce 61) (("?") reduce 61) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_BOOLEAN_AND) reduce 61) ((T_BOOLEAN_OR) reduce 61) ((T_COALESCE) reduce 61) ((T_DOUBLE_ARROW) reduce 61) ((T_INSTANCEOF) reduce 61) ((T_IS_EQUAL) reduce 61) ((T_IS_GREATER_OR_EQUAL) reduce 61) ((T_IS_IDENTICAL) reduce 61) ((T_IS_NOT_EQUAL) reduce 61) ((T_IS_NOT_IDENTICAL) reduce 61) ((T_IS_SMALLER_OR_EQUAL) reduce 61) ((T_LOGICAL_AND) reduce 61) ((T_LOGICAL_OR) reduce 61) ((T_LOGICAL_XOR) reduce 61) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 61) ((T_OBJECT_OPERATOR) reduce 61) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 61) ((T_POW) reduce 61) ((T_SL) reduce 61) ((T_SPACESHIP) reduce 61) ((T_SR) reduce 61) (("[") reduce 61) (("^") reduce 61) (("{") reduce 61) (("|") reduce 61) (("}") reduce 61)) 13852 ((("%") reduce 28) (("(") reduce 28) (("*") reduce 28) (("+") reduce 28) (("-") reduce 28) ((".") reduce 28) (("/") reduce 28) (("<") reduce 28) ((">") reduce 28) (("?") reduce 28) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_BOOLEAN_AND) reduce 28) ((T_BOOLEAN_OR) reduce 28) ((T_COALESCE) reduce 28) ((T_DOUBLE_ARROW) reduce 28) ((T_INSTANCEOF) reduce 28) ((T_IS_EQUAL) reduce 28) ((T_IS_GREATER_OR_EQUAL) reduce 28) ((T_IS_IDENTICAL) reduce 28) ((T_IS_NOT_EQUAL) reduce 28) ((T_IS_NOT_IDENTICAL) reduce 28) ((T_IS_SMALLER_OR_EQUAL) reduce 28) ((T_LOGICAL_AND) reduce 28) ((T_LOGICAL_OR) reduce 28) ((T_LOGICAL_XOR) reduce 28) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 28) ((T_OBJECT_OPERATOR) reduce 28) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 28) ((T_POW) reduce 28) ((T_SL) reduce 28) ((T_SPACESHIP) reduce 28) ((T_SR) reduce 28) (("[") reduce 28) (("^") reduce 28) (("{") reduce 28) (("|") reduce 28) (("}") reduce 28)) 13853 ((("%") reduce 36) (("(") reduce 36) (("*") reduce 36) (("+") reduce 36) (("-") reduce 36) ((".") reduce 36) (("/") reduce 36) (("<") reduce 36) ((">") reduce 36) (("?") reduce 36) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_BOOLEAN_AND) reduce 36) ((T_BOOLEAN_OR) reduce 36) ((T_COALESCE) reduce 36) ((T_DOUBLE_ARROW) reduce 36) ((T_INSTANCEOF) reduce 36) ((T_IS_EQUAL) reduce 36) ((T_IS_GREATER_OR_EQUAL) reduce 36) ((T_IS_IDENTICAL) reduce 36) ((T_IS_NOT_EQUAL) reduce 36) ((T_IS_NOT_IDENTICAL) reduce 36) ((T_IS_SMALLER_OR_EQUAL) reduce 36) ((T_LOGICAL_AND) reduce 36) ((T_LOGICAL_OR) reduce 36) ((T_LOGICAL_XOR) reduce 36) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 36) ((T_OBJECT_OPERATOR) reduce 36) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 36) ((T_POW) reduce 36) ((T_SL) reduce 36) ((T_SPACESHIP) reduce 36) ((T_SR) reduce 36) (("[") reduce 36) (("^") reduce 36) (("{") reduce 36) (("|") reduce 36) (("}") reduce 36)) 13854 ((("%") reduce 32) (("(") reduce 32) (("*") reduce 32) (("+") reduce 32) (("-") reduce 32) ((".") reduce 32) (("/") reduce 32) (("<") reduce 32) ((">") reduce 32) (("?") reduce 32) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_BOOLEAN_AND) reduce 32) ((T_BOOLEAN_OR) reduce 32) ((T_COALESCE) reduce 32) ((T_DOUBLE_ARROW) reduce 32) ((T_INSTANCEOF) reduce 32) ((T_IS_EQUAL) reduce 32) ((T_IS_GREATER_OR_EQUAL) reduce 32) ((T_IS_IDENTICAL) reduce 32) ((T_IS_NOT_EQUAL) reduce 32) ((T_IS_NOT_IDENTICAL) reduce 32) ((T_IS_SMALLER_OR_EQUAL) reduce 32) ((T_LOGICAL_AND) reduce 32) ((T_LOGICAL_OR) reduce 32) ((T_LOGICAL_XOR) reduce 32) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 32) ((T_OBJECT_OPERATOR) reduce 32) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 32) ((T_POW) reduce 32) ((T_SL) reduce 32) ((T_SPACESHIP) reduce 32) ((T_SR) reduce 32) (("[") reduce 32) (("^") reduce 32) (("{") reduce 32) (("|") reduce 32) (("}") reduce 32)) 13855 ((("%") reduce 35) (("(") reduce 35) (("*") reduce 35) (("+") reduce 35) (("-") reduce 35) ((".") reduce 35) (("/") reduce 35) (("<") reduce 35) ((">") reduce 35) (("?") reduce 35) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_BOOLEAN_AND) reduce 35) ((T_BOOLEAN_OR) reduce 35) ((T_COALESCE) reduce 35) ((T_DOUBLE_ARROW) reduce 35) ((T_INSTANCEOF) reduce 35) ((T_IS_EQUAL) reduce 35) ((T_IS_GREATER_OR_EQUAL) reduce 35) ((T_IS_IDENTICAL) reduce 35) ((T_IS_NOT_EQUAL) reduce 35) ((T_IS_NOT_IDENTICAL) reduce 35) ((T_IS_SMALLER_OR_EQUAL) reduce 35) ((T_LOGICAL_AND) reduce 35) ((T_LOGICAL_OR) reduce 35) ((T_LOGICAL_XOR) reduce 35) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 35) ((T_OBJECT_OPERATOR) reduce 35) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 35) ((T_POW) reduce 35) ((T_SL) reduce 35) ((T_SPACESHIP) reduce 35) ((T_SR) reduce 35) (("[") reduce 35) (("^") reduce 35) (("{") reduce 35) (("|") reduce 35) (("}") reduce 35)) 13856 ((("%") reduce 19) (("(") reduce 19) (("*") reduce 19) (("+") reduce 19) (("-") reduce 19) ((".") reduce 19) (("/") reduce 19) (("<") reduce 19) ((">") reduce 19) (("?") reduce 19) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_BOOLEAN_AND) reduce 19) ((T_BOOLEAN_OR) reduce 19) ((T_COALESCE) reduce 19) ((T_DOUBLE_ARROW) reduce 19) ((T_INSTANCEOF) reduce 19) ((T_IS_EQUAL) reduce 19) ((T_IS_GREATER_OR_EQUAL) reduce 19) ((T_IS_IDENTICAL) reduce 19) ((T_IS_NOT_EQUAL) reduce 19) ((T_IS_NOT_IDENTICAL) reduce 19) ((T_IS_SMALLER_OR_EQUAL) reduce 19) ((T_LOGICAL_AND) reduce 19) ((T_LOGICAL_OR) reduce 19) ((T_LOGICAL_XOR) reduce 19) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 19) ((T_OBJECT_OPERATOR) reduce 19) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 19) ((T_POW) reduce 19) ((T_SL) reduce 19) ((T_SPACESHIP) reduce 19) ((T_SR) reduce 19) (("[") reduce 19) (("^") reduce 19) (("{") reduce 19) (("|") reduce 19) (("}") reduce 19)) 13857 ((("%") reduce 45) (("(") reduce 45) (("*") reduce 45) (("+") reduce 45) (("-") reduce 45) ((".") reduce 45) (("/") reduce 45) (("<") reduce 45) ((">") reduce 45) (("?") reduce 45) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_BOOLEAN_AND) reduce 45) ((T_BOOLEAN_OR) reduce 45) ((T_COALESCE) reduce 45) ((T_DOUBLE_ARROW) reduce 45) ((T_INSTANCEOF) reduce 45) ((T_IS_EQUAL) reduce 45) ((T_IS_GREATER_OR_EQUAL) reduce 45) ((T_IS_IDENTICAL) reduce 45) ((T_IS_NOT_EQUAL) reduce 45) ((T_IS_NOT_IDENTICAL) reduce 45) ((T_IS_SMALLER_OR_EQUAL) reduce 45) ((T_LOGICAL_AND) reduce 45) ((T_LOGICAL_OR) reduce 45) ((T_LOGICAL_XOR) reduce 45) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 45) ((T_OBJECT_OPERATOR) reduce 45) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 45) ((T_POW) reduce 45) ((T_SL) reduce 45) ((T_SPACESHIP) reduce 45) ((T_SR) reduce 45) (("[") reduce 45) (("^") reduce 45) (("{") reduce 45) (("|") reduce 45) (("}") reduce 45)) 13858 ((("%") reduce 504) (("(") reduce 541) (("*") reduce 504) (("+") reduce 504) (("-") reduce 504) ((".") reduce 504) (("/") reduce 504) (("<") reduce 504) ((">") reduce 504) (("?") reduce 504) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_BOOLEAN_AND) reduce 504) ((T_BOOLEAN_OR) reduce 504) ((T_COALESCE) reduce 504) ((T_DOUBLE_ARROW) reduce 504) ((T_INSTANCEOF) reduce 504) ((T_IS_EQUAL) reduce 504) ((T_IS_GREATER_OR_EQUAL) reduce 504) ((T_IS_IDENTICAL) reduce 504) ((T_IS_NOT_EQUAL) reduce 504) ((T_IS_NOT_IDENTICAL) reduce 504) ((T_IS_SMALLER_OR_EQUAL) reduce 504) ((T_LOGICAL_AND) reduce 504) ((T_LOGICAL_OR) reduce 504) ((T_LOGICAL_XOR) reduce 504) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 504) ((T_OBJECT_OPERATOR) reduce 504) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 504) ((T_POW) reduce 504) ((T_SL) reduce 504) ((T_SPACESHIP) reduce 504) ((T_SR) reduce 504) (("[") reduce 504) (("^") reduce 504) (("{") reduce 504) (("|") reduce 504) (("}") reduce 504)) 13860 ((("%") reduce 71) (("(") reduce 71) (("*") reduce 71) (("+") reduce 71) (("-") reduce 71) ((".") reduce 71) (("/") reduce 71) (("<") reduce 71) ((">") reduce 71) (("?") reduce 71) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_BOOLEAN_AND) reduce 71) ((T_BOOLEAN_OR) reduce 71) ((T_COALESCE) reduce 71) ((T_DOUBLE_ARROW) reduce 71) ((T_INSTANCEOF) reduce 71) ((T_IS_EQUAL) reduce 71) ((T_IS_GREATER_OR_EQUAL) reduce 71) ((T_IS_IDENTICAL) reduce 71) ((T_IS_NOT_EQUAL) reduce 71) ((T_IS_NOT_IDENTICAL) reduce 71) ((T_IS_SMALLER_OR_EQUAL) reduce 71) ((T_LOGICAL_AND) reduce 71) ((T_LOGICAL_OR) reduce 71) ((T_LOGICAL_XOR) reduce 71) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 71) ((T_OBJECT_OPERATOR) reduce 71) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 71) ((T_POW) reduce 71) ((T_SL) reduce 71) ((T_SPACESHIP) reduce 71) ((T_SR) reduce 71) (("[") reduce 71) (("^") reduce 71) (("{") reduce 71) (("|") reduce 71) (("}") reduce 71)) 13861 ((("%") reduce 82) (("(") reduce 82) (("*") reduce 82) (("+") reduce 82) (("-") reduce 82) ((".") reduce 82) (("/") reduce 82) (("<") reduce 82) ((">") reduce 82) (("?") reduce 82) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_BOOLEAN_AND) reduce 82) ((T_BOOLEAN_OR) reduce 82) ((T_COALESCE) reduce 82) ((T_DOUBLE_ARROW) reduce 82) ((T_INSTANCEOF) reduce 82) ((T_IS_EQUAL) reduce 82) ((T_IS_GREATER_OR_EQUAL) reduce 82) ((T_IS_IDENTICAL) reduce 82) ((T_IS_NOT_EQUAL) reduce 82) ((T_IS_NOT_IDENTICAL) reduce 82) ((T_IS_SMALLER_OR_EQUAL) reduce 82) ((T_LOGICAL_AND) reduce 82) ((T_LOGICAL_OR) reduce 82) ((T_LOGICAL_XOR) reduce 82) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 82) ((T_OBJECT_OPERATOR) reduce 82) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 82) ((T_POW) reduce 82) ((T_SL) reduce 82) ((T_SPACESHIP) reduce 82) ((T_SR) reduce 82) (("[") reduce 82) (("^") reduce 82) (("{") reduce 82) (("|") reduce 82) (("}") reduce 82)) 13862 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) (("<") reduce 533) (("=") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AND_EQUAL) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_COALESCE_EQUAL) reduce 533) ((T_CONCAT_EQUAL) reduce 533) ((T_DEC) reduce 533) ((T_DIV_EQUAL) reduce 533) ((T_DOUBLE_ARROW) reduce 533) ((T_INC) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_MINUS_EQUAL) reduce 533) ((T_MOD_EQUAL) reduce 533) ((T_MUL_EQUAL) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_OR_EQUAL) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_PLUS_EQUAL) reduce 533) ((T_POW) reduce 533) ((T_POW_EQUAL) reduce 533) ((T_SL) reduce 533) ((T_SL_EQUAL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) ((T_SR_EQUAL) reduce 533) ((T_XOR_EQUAL) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533) (("}") reduce 533)) 13865 ((("%") reduce 506) (("(") reduce 542) (("*") reduce 506) (("+") reduce 506) (("-") reduce 506) ((".") reduce 506) (("/") reduce 506) (("<") reduce 506) ((">") reduce 506) (("?") reduce 506) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_BOOLEAN_AND) reduce 506) ((T_BOOLEAN_OR) reduce 506) ((T_COALESCE) reduce 506) ((T_DOUBLE_ARROW) reduce 506) ((T_INSTANCEOF) reduce 506) ((T_IS_EQUAL) reduce 506) ((T_IS_GREATER_OR_EQUAL) reduce 506) ((T_IS_IDENTICAL) reduce 506) ((T_IS_NOT_EQUAL) reduce 506) ((T_IS_NOT_IDENTICAL) reduce 506) ((T_IS_SMALLER_OR_EQUAL) reduce 506) ((T_LOGICAL_AND) reduce 506) ((T_LOGICAL_OR) reduce 506) ((T_LOGICAL_XOR) reduce 506) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 506) ((T_OBJECT_OPERATOR) reduce 506) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 506) ((T_POW) reduce 506) ((T_SL) reduce 506) ((T_SPACESHIP) reduce 506) ((T_SR) reduce 506) (("[") reduce 506) (("^") reduce 506) (("{") reduce 506) (("|") reduce 506) (("}") reduce 506)) 13867 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) (("<") reduce 468) (("=") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AND_EQUAL) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_COALESCE_EQUAL) reduce 468) ((T_CONCAT_EQUAL) reduce 468) ((T_DEC) reduce 468) ((T_DIV_EQUAL) reduce 468) ((T_DOUBLE_ARROW) reduce 468) ((T_INC) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_MINUS_EQUAL) reduce 468) ((T_MOD_EQUAL) reduce 468) ((T_MUL_EQUAL) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_OR_EQUAL) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_PLUS_EQUAL) reduce 468) ((T_POW) reduce 468) ((T_POW_EQUAL) reduce 468) ((T_SL) reduce 468) ((T_SL_EQUAL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) ((T_SR_EQUAL) reduce 468) ((T_XOR_EQUAL) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468) (("}") reduce 468)) 13868 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) (("=") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AND_EQUAL) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_COALESCE_EQUAL) reduce 288) ((T_CONCAT_EQUAL) reduce 288) ((T_DEC) reduce 288) ((T_DIV_EQUAL) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INC) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_MINUS_EQUAL) reduce 288) ((T_MOD_EQUAL) reduce 288) ((T_MUL_EQUAL) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_OR_EQUAL) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_PLUS_EQUAL) reduce 288) ((T_POW) reduce 288) ((T_POW_EQUAL) reduce 288) ((T_SL) reduce 288) ((T_SL_EQUAL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) ((T_SR_EQUAL) reduce 288) ((T_XOR_EQUAL) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288) (("}") reduce 288)) 13872 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) (("=") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AND_EQUAL) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_COALESCE_EQUAL) reduce 289) ((T_CONCAT_EQUAL) reduce 289) ((T_DEC) reduce 289) ((T_DIV_EQUAL) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INC) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_MINUS_EQUAL) reduce 289) ((T_MOD_EQUAL) reduce 289) ((T_MUL_EQUAL) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_OR_EQUAL) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_PLUS_EQUAL) reduce 289) ((T_POW) reduce 289) ((T_POW_EQUAL) reduce 289) ((T_SL) reduce 289) ((T_SL_EQUAL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) ((T_SR_EQUAL) reduce 289) ((T_XOR_EQUAL) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289) (("}") reduce 289)) 13873 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) (("=") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AND_EQUAL) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_COALESCE_EQUAL) reduce 290) ((T_CONCAT_EQUAL) reduce 290) ((T_DEC) reduce 290) ((T_DIV_EQUAL) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INC) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_MINUS_EQUAL) reduce 290) ((T_MOD_EQUAL) reduce 290) ((T_MUL_EQUAL) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_OR_EQUAL) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_PLUS_EQUAL) reduce 290) ((T_POW) reduce 290) ((T_POW_EQUAL) reduce 290) ((T_SL) reduce 290) ((T_SL_EQUAL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) ((T_SR_EQUAL) reduce 290) ((T_XOR_EQUAL) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290) (("}") reduce 290)) 13878 ((("%") reduce 388) (("*") reduce 388) (("+") reduce 388) (("-") reduce 388) ((".") reduce 388) (("/") reduce 388) (("<") reduce 388) ((">") reduce 388) (("?") reduce 388) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_BOOLEAN_AND) reduce 388) ((T_BOOLEAN_OR) reduce 388) ((T_COALESCE) reduce 388) ((T_DOUBLE_ARROW) reduce 388) ((T_INSTANCEOF) reduce 388) ((T_IS_EQUAL) reduce 388) ((T_IS_GREATER_OR_EQUAL) reduce 388) ((T_IS_IDENTICAL) reduce 388) ((T_IS_NOT_EQUAL) reduce 388) ((T_IS_NOT_IDENTICAL) reduce 388) ((T_IS_SMALLER_OR_EQUAL) reduce 388) ((T_LOGICAL_AND) reduce 388) ((T_LOGICAL_OR) reduce 388) ((T_LOGICAL_XOR) reduce 388) ((T_POW) reduce 388) ((T_SL) reduce 388) ((T_SPACESHIP) reduce 388) ((T_SR) reduce 388) (("^") reduce 388) (("|") reduce 388) (("}") reduce 388)) 13880 ((("%") reduce 386) (("*") reduce 386) (("+") reduce 386) (("-") reduce 386) ((".") reduce 386) (("/") reduce 386) (("<") reduce 386) ((">") reduce 386) (("?") reduce 386) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_BOOLEAN_AND) reduce 386) ((T_BOOLEAN_OR) reduce 386) ((T_COALESCE) reduce 386) ((T_DOUBLE_ARROW) reduce 386) ((T_INSTANCEOF) reduce 386) ((T_IS_EQUAL) reduce 386) ((T_IS_GREATER_OR_EQUAL) reduce 386) ((T_IS_IDENTICAL) reduce 386) ((T_IS_NOT_EQUAL) reduce 386) ((T_IS_NOT_IDENTICAL) reduce 386) ((T_IS_SMALLER_OR_EQUAL) reduce 386) ((T_LOGICAL_AND) reduce 386) ((T_LOGICAL_OR) reduce 386) ((T_LOGICAL_XOR) reduce 386) ((T_POW) reduce 386) ((T_SL) reduce 386) ((T_SPACESHIP) reduce 386) ((T_SR) reduce 386) (("^") reduce 386) (("|") reduce 386) (("}") reduce 386)) 13890 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 382) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 382) ((T_LOGICAL_OR) reduce 382) ((T_LOGICAL_XOR) reduce 382) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 382)) 13891 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 384) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 384) ((T_LOGICAL_OR) reduce 384) ((T_LOGICAL_XOR) reduce 384) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 384)) 13892 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 383) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 383) ((T_LOGICAL_OR) reduce 383) ((T_LOGICAL_XOR) reduce 383) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 383)) 13893 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 376) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 376) ((T_LOGICAL_OR) reduce 376) ((T_LOGICAL_XOR) reduce 376) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 376)) 13894 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 373) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 373) ((T_LOGICAL_OR) reduce 373) ((T_LOGICAL_XOR) reduce 373) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 373)) 13895 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 381) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 381) ((T_LOGICAL_OR) reduce 381) ((T_LOGICAL_XOR) reduce 381) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 381)) 13896 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 375) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 375) ((T_LOGICAL_OR) reduce 375) ((T_LOGICAL_XOR) reduce 375) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 375)) 13897 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 379) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 379) ((T_LOGICAL_OR) reduce 379) ((T_LOGICAL_XOR) reduce 379) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 379)) 13898 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 374) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 374) ((T_LOGICAL_OR) reduce 374) ((T_LOGICAL_XOR) reduce 374) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 374)) 13899 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 377) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 377) ((T_LOGICAL_OR) reduce 377) ((T_LOGICAL_XOR) reduce 377) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 377)) 13900 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 378) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 378) ((T_LOGICAL_OR) reduce 378) ((T_LOGICAL_XOR) reduce 378) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 378)) 13901 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 385) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 385) ((T_LOGICAL_OR) reduce 385) ((T_LOGICAL_XOR) reduce 385) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 385)) 13902 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 380) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 380) ((T_LOGICAL_OR) reduce 380) ((T_LOGICAL_XOR) reduce 380) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 380)) 13904 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 370) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 370) ((T_LOGICAL_OR) reduce 370) ((T_LOGICAL_XOR) reduce 370) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 370)) 13907 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529) (("}") reduce 529)) 13910 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) (("<") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_DOUBLE_ARROW) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_POW) reduce 525) ((T_SL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525) (("}") reduce 525)) 13912 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) (("<") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_DOUBLE_ARROW) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_POW) reduce 524) ((T_SL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524) (("}") reduce 524)) 13914 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) (("<") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_DOUBLE_ARROW) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_POW) reduce 519) ((T_SL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519) (("}") reduce 519)) 13915 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) (("<") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_DOUBLE_ARROW) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_POW) reduce 526) ((T_SL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526) (("}") reduce 526)) 13916 ((("%") reduce 371) (("*") reduce 371) (("+") reduce 371) (("-") reduce 371) ((".") reduce 371) (("/") reduce 371) (("<") reduce 371) ((">") reduce 371) (("?") reduce 371) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_BOOLEAN_AND) reduce 371) ((T_BOOLEAN_OR) reduce 371) ((T_COALESCE) reduce 371) ((T_DOUBLE_ARROW) reduce 371) ((T_INSTANCEOF) reduce 371) ((T_IS_EQUAL) reduce 371) ((T_IS_GREATER_OR_EQUAL) reduce 371) ((T_IS_IDENTICAL) reduce 371) ((T_IS_NOT_EQUAL) reduce 371) ((T_IS_NOT_IDENTICAL) reduce 371) ((T_IS_SMALLER_OR_EQUAL) reduce 371) ((T_LOGICAL_AND) reduce 371) ((T_LOGICAL_OR) reduce 371) ((T_LOGICAL_XOR) reduce 371) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 371) ((T_SL) reduce 371) ((T_SPACESHIP) reduce 371) ((T_SR) reduce 371) (("[") reduce 510) (("^") reduce 371) (("{") reduce 510) (("|") reduce 371) (("}") reduce 371)) 13920 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) (("<") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_DOUBLE_ARROW) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_POW) reduce 533) ((T_SL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533) (("}") reduce 533)) 13922 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) (("<") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_DOUBLE_ARROW) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_POW) reduce 468) ((T_SL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468) (("}") reduce 468)) 13923 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288) (("}") reduce 288)) 13927 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289) (("}") reduce 289)) 13928 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290) (("}") reduce 290)) 13929 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) (("<") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_DOUBLE_ARROW) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_POW) reduce 465) ((T_SL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465) (("}") reduce 465)) 13932 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) (("<") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_DOUBLE_ARROW) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_POW) reduce 532) ((T_SL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532) (("}") reduce 532)) 13933 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) (("<") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_DOUBLE_ARROW) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_POW) reduce 467) ((T_SL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467) (("}") reduce 467)) 13934 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) (("<") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_DOUBLE_ARROW) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_POW) reduce 469) ((T_SL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469) (("}") reduce 469)) 13940 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) (("<") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_DOUBLE_ARROW) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_POW) reduce 521) ((T_SL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521) (("}") reduce 521)) 13942 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) (("<") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_DOUBLE_ARROW) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_POW) reduce 520) ((T_SL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520) (("}") reduce 520)) 13943 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544) (("}") reduce 544)) 13944 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) (("<") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_DOUBLE_ARROW) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_POW) reduce 527) ((T_SL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527) (("}") reduce 527)) 13945 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546) (("}") reduce 546)) 13948 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545) (("}") reduce 545)) 13949 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) (("<") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_DOUBLE_ARROW) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_POW) reduce 522) ((T_SL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522) (("}") reduce 522)) 13950 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) (("<") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_DOUBLE_ARROW) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_POW) reduce 528) ((T_SL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528) (("}") reduce 528)) 13951 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) (("<") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_DOUBLE_ARROW) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_POW) reduce 523) ((T_SL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523) (("}") reduce 523)) 13952 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) (("<") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_DOUBLE_ARROW) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_POW) reduce 466) ((T_SL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466) (("}") reduce 466)) 13953 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531) (("}") reduce 531)) 13956 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530) (("}") reduce 530)) 13957 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) (("<") reduce 465) (("=") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AND_EQUAL) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_COALESCE_EQUAL) reduce 465) ((T_CONCAT_EQUAL) reduce 465) ((T_DEC) reduce 465) ((T_DIV_EQUAL) reduce 465) ((T_DOUBLE_ARROW) reduce 465) ((T_INC) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_MINUS_EQUAL) reduce 465) ((T_MOD_EQUAL) reduce 465) ((T_MUL_EQUAL) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_OR_EQUAL) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_PLUS_EQUAL) reduce 465) ((T_POW) reduce 465) ((T_POW_EQUAL) reduce 465) ((T_SL) reduce 465) ((T_SL_EQUAL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) ((T_SR_EQUAL) reduce 465) ((T_XOR_EQUAL) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465) (("}") reduce 465)) 13968 ((("%") reduce 455) (("*") reduce 455) (("+") reduce 455) (("-") reduce 455) ((".") reduce 455) (("/") reduce 455) (("<") reduce 455) ((">") reduce 455) (("?") reduce 455) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_BOOLEAN_AND) reduce 455) ((T_BOOLEAN_OR) reduce 455) ((T_COALESCE) reduce 455) ((T_DOUBLE_ARROW) reduce 455) ((T_INSTANCEOF) reduce 455) ((T_IS_EQUAL) reduce 455) ((T_IS_GREATER_OR_EQUAL) reduce 455) ((T_IS_IDENTICAL) reduce 455) ((T_IS_NOT_EQUAL) reduce 455) ((T_IS_NOT_IDENTICAL) reduce 455) ((T_IS_SMALLER_OR_EQUAL) reduce 455) ((T_LOGICAL_AND) reduce 455) ((T_LOGICAL_OR) reduce 455) ((T_LOGICAL_XOR) reduce 455) ((T_POW) reduce 455) ((T_SL) reduce 455) ((T_SPACESHIP) reduce 455) ((T_SR) reduce 455) (("^") reduce 455) (("|") reduce 455) (("}") reduce 455)) 13969 ((("%") reduce 450) (("*") reduce 450) (("+") reduce 450) (("-") reduce 450) ((".") reduce 450) (("/") reduce 450) (("<") reduce 450) ((">") reduce 450) (("?") reduce 450) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_BOOLEAN_AND) reduce 450) ((T_BOOLEAN_OR) reduce 450) ((T_COALESCE) reduce 450) ((T_DOUBLE_ARROW) reduce 450) ((T_INSTANCEOF) reduce 450) ((T_IS_EQUAL) reduce 450) ((T_IS_GREATER_OR_EQUAL) reduce 450) ((T_IS_IDENTICAL) reduce 450) ((T_IS_NOT_EQUAL) reduce 450) ((T_IS_NOT_IDENTICAL) reduce 450) ((T_IS_SMALLER_OR_EQUAL) reduce 450) ((T_LOGICAL_AND) reduce 450) ((T_LOGICAL_OR) reduce 450) ((T_LOGICAL_XOR) reduce 450) ((T_POW) reduce 450) ((T_SL) reduce 450) ((T_SPACESHIP) reduce 450) ((T_SR) reduce 450) (("^") reduce 450) (("|") reduce 450) (("}") reduce 450)) 13979 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 455) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 455)) 13980 ((("%") reduce 451) (("*") reduce 451) (("+") reduce 451) (("-") reduce 451) ((".") reduce 451) (("/") reduce 451) (("<") reduce 451) ((">") reduce 451) (("?") reduce 451) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_BOOLEAN_AND) reduce 451) ((T_BOOLEAN_OR) reduce 451) ((T_COALESCE) reduce 451) ((T_DOUBLE_ARROW) reduce 451) ((T_INSTANCEOF) reduce 451) ((T_IS_EQUAL) reduce 451) ((T_IS_GREATER_OR_EQUAL) reduce 451) ((T_IS_IDENTICAL) reduce 451) ((T_IS_NOT_EQUAL) reduce 451) ((T_IS_NOT_IDENTICAL) reduce 451) ((T_IS_SMALLER_OR_EQUAL) reduce 451) ((T_LOGICAL_AND) reduce 451) ((T_LOGICAL_OR) reduce 451) ((T_LOGICAL_XOR) reduce 451) ((T_POW) reduce 451) ((T_SL) reduce 451) ((T_SPACESHIP) reduce 451) ((T_SR) reduce 451) (("^") reduce 451) (("|") reduce 451) (("}") reduce 451)) 13982 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 442) ((T_LOGICAL_OR) reduce 442) ((T_LOGICAL_XOR) reduce 442) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 442)) 13984 ((("%") reduce 503) (("(") reduce 541) (("*") reduce 503) (("+") reduce 503) (("-") reduce 503) ((".") reduce 503) (("/") reduce 503) (("<") reduce 503) ((">") reduce 503) (("?") reduce 503) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_BOOLEAN_AND) reduce 503) ((T_BOOLEAN_OR) reduce 503) ((T_COALESCE) reduce 503) ((T_DOUBLE_ARROW) reduce 503) ((T_INSTANCEOF) reduce 503) ((T_IS_EQUAL) reduce 503) ((T_IS_GREATER_OR_EQUAL) reduce 503) ((T_IS_IDENTICAL) reduce 503) ((T_IS_NOT_EQUAL) reduce 503) ((T_IS_NOT_IDENTICAL) reduce 503) ((T_IS_SMALLER_OR_EQUAL) reduce 503) ((T_LOGICAL_AND) reduce 503) ((T_LOGICAL_OR) reduce 503) ((T_LOGICAL_XOR) reduce 503) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 503) ((T_OBJECT_OPERATOR) reduce 503) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 503) ((T_POW) reduce 503) ((T_SL) reduce 503) ((T_SPACESHIP) reduce 503) ((T_SR) reduce 503) (("[") reduce 503) (("^") reduce 503) (("{") reduce 503) (("|") reduce 503) (("}") reduce 503)) 13986 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) (("<") reduce 532) (("=") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AND_EQUAL) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_COALESCE_EQUAL) reduce 532) ((T_CONCAT_EQUAL) reduce 532) ((T_DEC) reduce 532) ((T_DIV_EQUAL) reduce 532) ((T_DOUBLE_ARROW) reduce 532) ((T_INC) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_MINUS_EQUAL) reduce 532) ((T_MOD_EQUAL) reduce 532) ((T_MUL_EQUAL) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_OR_EQUAL) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_PLUS_EQUAL) reduce 532) ((T_POW) reduce 532) ((T_POW_EQUAL) reduce 532) ((T_SL) reduce 532) ((T_SL_EQUAL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) ((T_SR_EQUAL) reduce 532) ((T_XOR_EQUAL) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532) (("}") reduce 532)) 13989 ((("%") reduce 505) (("(") reduce 542) (("*") reduce 505) (("+") reduce 505) (("-") reduce 505) ((".") reduce 505) (("/") reduce 505) (("<") reduce 505) ((">") reduce 505) (("?") reduce 505) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_BOOLEAN_AND) reduce 505) ((T_BOOLEAN_OR) reduce 505) ((T_COALESCE) reduce 505) ((T_DOUBLE_ARROW) reduce 505) ((T_INSTANCEOF) reduce 505) ((T_IS_EQUAL) reduce 505) ((T_IS_GREATER_OR_EQUAL) reduce 505) ((T_IS_IDENTICAL) reduce 505) ((T_IS_NOT_EQUAL) reduce 505) ((T_IS_NOT_IDENTICAL) reduce 505) ((T_IS_SMALLER_OR_EQUAL) reduce 505) ((T_LOGICAL_AND) reduce 505) ((T_LOGICAL_OR) reduce 505) ((T_LOGICAL_XOR) reduce 505) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 505) ((T_OBJECT_OPERATOR) reduce 505) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 505) ((T_POW) reduce 505) ((T_SL) reduce 505) ((T_SPACESHIP) reduce 505) ((T_SR) reduce 505) (("[") reduce 505) (("^") reduce 505) (("{") reduce 505) (("|") reduce 505) (("}") reduce 505)) 13990 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) (("<") reduce 467) (("=") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AND_EQUAL) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_COALESCE_EQUAL) reduce 467) ((T_CONCAT_EQUAL) reduce 467) ((T_DEC) reduce 467) ((T_DIV_EQUAL) reduce 467) ((T_DOUBLE_ARROW) reduce 467) ((T_INC) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_MINUS_EQUAL) reduce 467) ((T_MOD_EQUAL) reduce 467) ((T_MUL_EQUAL) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_OR_EQUAL) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_PLUS_EQUAL) reduce 467) ((T_POW) reduce 467) ((T_POW_EQUAL) reduce 467) ((T_SL) reduce 467) ((T_SL_EQUAL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) ((T_SR_EQUAL) reduce 467) ((T_XOR_EQUAL) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467) (("}") reduce 467)) 13991 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) (("<") reduce 469) (("=") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AND_EQUAL) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_COALESCE_EQUAL) reduce 469) ((T_CONCAT_EQUAL) reduce 469) ((T_DEC) reduce 469) ((T_DIV_EQUAL) reduce 469) ((T_DOUBLE_ARROW) reduce 469) ((T_INC) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_MINUS_EQUAL) reduce 469) ((T_MOD_EQUAL) reduce 469) ((T_MUL_EQUAL) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_OR_EQUAL) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_PLUS_EQUAL) reduce 469) ((T_POW) reduce 469) ((T_POW_EQUAL) reduce 469) ((T_SL) reduce 469) ((T_SL_EQUAL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) ((T_SR_EQUAL) reduce 469) ((T_XOR_EQUAL) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469) (("}") reduce 469)) 13993 ((("%") reduce 446) (("*") reduce 446) (("+") reduce 446) (("-") reduce 446) ((".") reduce 446) (("/") reduce 446) (("<") reduce 446) ((">") reduce 446) (("?") reduce 446) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_BOOLEAN_AND) reduce 446) ((T_BOOLEAN_OR) reduce 446) ((T_COALESCE) reduce 446) ((T_DOUBLE_ARROW) reduce 446) ((T_INSTANCEOF) reduce 446) ((T_IS_EQUAL) reduce 446) ((T_IS_GREATER_OR_EQUAL) reduce 446) ((T_IS_IDENTICAL) reduce 446) ((T_IS_NOT_EQUAL) reduce 446) ((T_IS_NOT_IDENTICAL) reduce 446) ((T_IS_SMALLER_OR_EQUAL) reduce 446) ((T_LOGICAL_AND) reduce 446) ((T_LOGICAL_OR) reduce 446) ((T_LOGICAL_XOR) reduce 446) ((T_POW) reduce 446) ((T_SL) reduce 446) ((T_SPACESHIP) reduce 446) ((T_SR) reduce 446) (("^") reduce 446) (("|") reduce 446) (("}") reduce 446)) 13994 ((("%") reduce 448) (("*") reduce 448) (("+") reduce 448) (("-") reduce 448) ((".") reduce 448) (("/") reduce 448) (("<") reduce 448) ((">") reduce 448) (("?") reduce 448) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_BOOLEAN_AND) reduce 448) ((T_BOOLEAN_OR) reduce 448) ((T_COALESCE) reduce 448) ((T_DOUBLE_ARROW) reduce 448) ((T_INSTANCEOF) reduce 448) ((T_IS_EQUAL) reduce 448) ((T_IS_GREATER_OR_EQUAL) reduce 448) ((T_IS_IDENTICAL) reduce 448) ((T_IS_NOT_EQUAL) reduce 448) ((T_IS_NOT_IDENTICAL) reduce 448) ((T_IS_SMALLER_OR_EQUAL) reduce 448) ((T_LOGICAL_AND) reduce 448) ((T_LOGICAL_OR) reduce 448) ((T_LOGICAL_XOR) reduce 448) ((T_POW) reduce 448) ((T_SL) reduce 448) ((T_SPACESHIP) reduce 448) ((T_SR) reduce 448) (("^") reduce 448) (("|") reduce 448) (("}") reduce 448)) 14000 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) (("<") reduce 521) (("=") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AND_EQUAL) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_COALESCE_EQUAL) reduce 521) ((T_CONCAT_EQUAL) reduce 521) ((T_DEC) reduce 521) ((T_DIV_EQUAL) reduce 521) ((T_DOUBLE_ARROW) reduce 521) ((T_INC) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_MINUS_EQUAL) reduce 521) ((T_MOD_EQUAL) reduce 521) ((T_MUL_EQUAL) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_OR_EQUAL) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_PLUS_EQUAL) reduce 521) ((T_POW) reduce 521) ((T_POW_EQUAL) reduce 521) ((T_SL) reduce 521) ((T_SL_EQUAL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) ((T_SR_EQUAL) reduce 521) ((T_XOR_EQUAL) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521) (("}") reduce 521)) 14002 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) (("<") reduce 520) (("=") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AND_EQUAL) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_COALESCE_EQUAL) reduce 520) ((T_CONCAT_EQUAL) reduce 520) ((T_DEC) reduce 520) ((T_DIV_EQUAL) reduce 520) ((T_DOUBLE_ARROW) reduce 520) ((T_INC) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_MINUS_EQUAL) reduce 520) ((T_MOD_EQUAL) reduce 520) ((T_MUL_EQUAL) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_OR_EQUAL) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_PLUS_EQUAL) reduce 520) ((T_POW) reduce 520) ((T_POW_EQUAL) reduce 520) ((T_SL) reduce 520) ((T_SL_EQUAL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) ((T_SR_EQUAL) reduce 520) ((T_XOR_EQUAL) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520) (("}") reduce 520)) 14003 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) (("=") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AND_EQUAL) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_COALESCE_EQUAL) reduce 544) ((T_CONCAT_EQUAL) reduce 544) ((T_DEC) reduce 544) ((T_DIV_EQUAL) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INC) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_MINUS_EQUAL) reduce 544) ((T_MOD_EQUAL) reduce 544) ((T_MUL_EQUAL) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_OR_EQUAL) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_PLUS_EQUAL) reduce 544) ((T_POW) reduce 544) ((T_POW_EQUAL) reduce 544) ((T_SL) reduce 544) ((T_SL_EQUAL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) ((T_SR_EQUAL) reduce 544) ((T_XOR_EQUAL) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544) (("}") reduce 544)) 14004 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) (("<") reduce 527) (("=") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AND_EQUAL) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_COALESCE_EQUAL) reduce 527) ((T_CONCAT_EQUAL) reduce 527) ((T_DEC) reduce 527) ((T_DIV_EQUAL) reduce 527) ((T_DOUBLE_ARROW) reduce 527) ((T_INC) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_MINUS_EQUAL) reduce 527) ((T_MOD_EQUAL) reduce 527) ((T_MUL_EQUAL) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_OR_EQUAL) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_PLUS_EQUAL) reduce 527) ((T_POW) reduce 527) ((T_POW_EQUAL) reduce 527) ((T_SL) reduce 527) ((T_SL_EQUAL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) ((T_SR_EQUAL) reduce 527) ((T_XOR_EQUAL) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527) (("}") reduce 527)) 14005 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) (("=") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AND_EQUAL) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_COALESCE_EQUAL) reduce 546) ((T_CONCAT_EQUAL) reduce 546) ((T_DEC) reduce 546) ((T_DIV_EQUAL) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INC) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_MINUS_EQUAL) reduce 546) ((T_MOD_EQUAL) reduce 546) ((T_MUL_EQUAL) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_OR_EQUAL) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_PLUS_EQUAL) reduce 546) ((T_POW) reduce 546) ((T_POW_EQUAL) reduce 546) ((T_SL) reduce 546) ((T_SL_EQUAL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) ((T_SR_EQUAL) reduce 546) ((T_XOR_EQUAL) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546) (("}") reduce 546)) 14008 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) (("=") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AND_EQUAL) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_COALESCE_EQUAL) reduce 545) ((T_CONCAT_EQUAL) reduce 545) ((T_DEC) reduce 545) ((T_DIV_EQUAL) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INC) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_MINUS_EQUAL) reduce 545) ((T_MOD_EQUAL) reduce 545) ((T_MUL_EQUAL) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_OR_EQUAL) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_PLUS_EQUAL) reduce 545) ((T_POW) reduce 545) ((T_POW_EQUAL) reduce 545) ((T_SL) reduce 545) ((T_SL_EQUAL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) ((T_SR_EQUAL) reduce 545) ((T_XOR_EQUAL) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545) (("}") reduce 545)) 14009 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) (("<") reduce 522) (("=") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AND_EQUAL) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_COALESCE_EQUAL) reduce 522) ((T_CONCAT_EQUAL) reduce 522) ((T_DEC) reduce 522) ((T_DIV_EQUAL) reduce 522) ((T_DOUBLE_ARROW) reduce 522) ((T_INC) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_MINUS_EQUAL) reduce 522) ((T_MOD_EQUAL) reduce 522) ((T_MUL_EQUAL) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_OR_EQUAL) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_PLUS_EQUAL) reduce 522) ((T_POW) reduce 522) ((T_POW_EQUAL) reduce 522) ((T_SL) reduce 522) ((T_SL_EQUAL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) ((T_SR_EQUAL) reduce 522) ((T_XOR_EQUAL) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522) (("}") reduce 522)) 14010 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) (("<") reduce 528) (("=") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AND_EQUAL) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_COALESCE_EQUAL) reduce 528) ((T_CONCAT_EQUAL) reduce 528) ((T_DEC) reduce 528) ((T_DIV_EQUAL) reduce 528) ((T_DOUBLE_ARROW) reduce 528) ((T_INC) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_MINUS_EQUAL) reduce 528) ((T_MOD_EQUAL) reduce 528) ((T_MUL_EQUAL) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_OR_EQUAL) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_PLUS_EQUAL) reduce 528) ((T_POW) reduce 528) ((T_POW_EQUAL) reduce 528) ((T_SL) reduce 528) ((T_SL_EQUAL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) ((T_SR_EQUAL) reduce 528) ((T_XOR_EQUAL) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528) (("}") reduce 528)) 14011 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) (("<") reduce 523) (("=") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AND_EQUAL) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_COALESCE_EQUAL) reduce 523) ((T_CONCAT_EQUAL) reduce 523) ((T_DEC) reduce 523) ((T_DIV_EQUAL) reduce 523) ((T_DOUBLE_ARROW) reduce 523) ((T_INC) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_MINUS_EQUAL) reduce 523) ((T_MOD_EQUAL) reduce 523) ((T_MUL_EQUAL) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_OR_EQUAL) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_PLUS_EQUAL) reduce 523) ((T_POW) reduce 523) ((T_POW_EQUAL) reduce 523) ((T_SL) reduce 523) ((T_SL_EQUAL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) ((T_SR_EQUAL) reduce 523) ((T_XOR_EQUAL) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523) (("}") reduce 523)) 14013 ((("%") reduce 438) (("*") reduce 438) (("+") reduce 438) (("-") reduce 438) ((".") reduce 438) (("/") reduce 438) (("<") reduce 438) ((">") reduce 438) (("?") reduce 438) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_BOOLEAN_AND) reduce 438) ((T_BOOLEAN_OR) reduce 438) ((T_COALESCE) reduce 438) ((T_DOUBLE_ARROW) reduce 438) ((T_INSTANCEOF) reduce 438) ((T_IS_EQUAL) reduce 438) ((T_IS_GREATER_OR_EQUAL) reduce 438) ((T_IS_IDENTICAL) reduce 438) ((T_IS_NOT_EQUAL) reduce 438) ((T_IS_NOT_IDENTICAL) reduce 438) ((T_IS_SMALLER_OR_EQUAL) reduce 438) ((T_LOGICAL_AND) reduce 438) ((T_LOGICAL_OR) reduce 438) ((T_LOGICAL_XOR) reduce 438) ((T_POW) reduce 438) ((T_SL) reduce 438) ((T_SPACESHIP) reduce 438) ((T_SR) reduce 438) (("^") reduce 438) (("|") reduce 438) (("}") reduce 438)) 14015 ((("%") reduce 483) (("(") reduce 483) (("*") reduce 483) (("+") reduce 483) (("-") reduce 483) ((".") reduce 483) (("/") reduce 483) (("<") reduce 483) (("=") shift) ((">") reduce 483) (("?") reduce 483) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_BOOLEAN_AND) reduce 483) ((T_BOOLEAN_OR) reduce 483) ((T_COALESCE) reduce 483) ((T_DOUBLE_ARROW) reduce 483) ((T_INSTANCEOF) reduce 483) ((T_IS_EQUAL) reduce 483) ((T_IS_GREATER_OR_EQUAL) reduce 483) ((T_IS_IDENTICAL) reduce 483) ((T_IS_NOT_EQUAL) reduce 483) ((T_IS_NOT_IDENTICAL) reduce 483) ((T_IS_SMALLER_OR_EQUAL) reduce 483) ((T_LOGICAL_AND) reduce 483) ((T_LOGICAL_OR) reduce 483) ((T_LOGICAL_XOR) reduce 483) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 483) ((T_OBJECT_OPERATOR) reduce 483) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 483) ((T_POW) reduce 483) ((T_SL) reduce 483) ((T_SPACESHIP) reduce 483) ((T_SR) reduce 483) (("[") reduce 483) (("^") reduce 483) (("{") reduce 483) (("|") reduce 483) (("}") reduce 483)) 14017 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 369) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 369) ((T_LOGICAL_OR) reduce 369) ((T_LOGICAL_XOR) reduce 369) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 369)) 14018 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 443) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 443) ((T_LOGICAL_OR) reduce 443) ((T_LOGICAL_XOR) reduce 443) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 443)) 14021 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 442) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 442) ((T_LOGICAL_OR) reduce 442) ((T_LOGICAL_XOR) reduce 442) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 442)) 14022 ((("%") reduce 434) (("*") reduce 434) (("+") reduce 434) (("-") reduce 434) ((".") reduce 434) (("/") reduce 434) (("<") reduce 434) ((">") reduce 434) (("?") reduce 434) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_BOOLEAN_AND) reduce 434) ((T_BOOLEAN_OR) reduce 434) ((T_COALESCE) reduce 434) ((T_DOUBLE_ARROW) reduce 434) ((T_INSTANCEOF) reduce 434) ((T_IS_EQUAL) reduce 434) ((T_IS_GREATER_OR_EQUAL) reduce 434) ((T_IS_IDENTICAL) reduce 434) ((T_IS_NOT_EQUAL) reduce 434) ((T_IS_NOT_IDENTICAL) reduce 434) ((T_IS_SMALLER_OR_EQUAL) reduce 434) ((T_LOGICAL_AND) reduce 434) ((T_LOGICAL_OR) reduce 434) ((T_LOGICAL_XOR) reduce 434) ((T_POW) shift) ((T_SL) reduce 434) ((T_SPACESHIP) reduce 434) ((T_SR) reduce 434) (("^") reduce 434) (("|") reduce 434) (("}") reduce 434)) 14023 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 444) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 444)) 14024 ((("%") reduce 430) (("*") reduce 430) (("+") reduce 430) (("-") reduce 430) ((".") reduce 430) (("/") reduce 430) (("<") reduce 430) ((">") reduce 430) (("?") reduce 430) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_BOOLEAN_AND) reduce 430) ((T_BOOLEAN_OR) reduce 430) ((T_COALESCE) reduce 430) ((T_DOUBLE_ARROW) reduce 430) ((T_INSTANCEOF) reduce 430) ((T_IS_EQUAL) reduce 430) ((T_IS_GREATER_OR_EQUAL) reduce 430) ((T_IS_IDENTICAL) reduce 430) ((T_IS_NOT_EQUAL) reduce 430) ((T_IS_NOT_IDENTICAL) reduce 430) ((T_IS_SMALLER_OR_EQUAL) reduce 430) ((T_LOGICAL_AND) reduce 430) ((T_LOGICAL_OR) reduce 430) ((T_LOGICAL_XOR) reduce 430) ((T_POW) shift) ((T_SL) reduce 430) ((T_SPACESHIP) reduce 430) ((T_SR) reduce 430) (("^") reduce 430) (("|") reduce 430) (("}") reduce 430)) 14025 ((("%") reduce 447) (("*") reduce 447) (("+") reduce 447) (("-") reduce 447) ((".") reduce 447) (("/") reduce 447) (("<") reduce 447) ((">") reduce 447) (("?") reduce 447) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_BOOLEAN_AND) reduce 447) ((T_BOOLEAN_OR) reduce 447) ((T_COALESCE) reduce 447) ((T_DOUBLE_ARROW) reduce 447) ((T_INSTANCEOF) reduce 447) ((T_IS_EQUAL) reduce 447) ((T_IS_GREATER_OR_EQUAL) reduce 447) ((T_IS_IDENTICAL) reduce 447) ((T_IS_NOT_EQUAL) reduce 447) ((T_IS_NOT_IDENTICAL) reduce 447) ((T_IS_SMALLER_OR_EQUAL) reduce 447) ((T_LOGICAL_AND) reduce 447) ((T_LOGICAL_OR) reduce 447) ((T_LOGICAL_XOR) reduce 447) ((T_POW) reduce 447) ((T_SL) reduce 447) ((T_SPACESHIP) reduce 447) ((T_SR) reduce 447) (("^") reduce 447) (("|") reduce 447) (("}") reduce 447)) 14027 ((("%") reduce 489) (("*") reduce 489) (("+") reduce 489) (("-") reduce 489) ((".") reduce 489) (("/") reduce 489) (("<") reduce 489) ((">") reduce 489) (("?") reduce 489) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_BOOLEAN_AND) reduce 489) ((T_BOOLEAN_OR) reduce 489) ((T_COALESCE) reduce 489) ((T_DOUBLE_ARROW) reduce 489) ((T_INSTANCEOF) reduce 489) ((T_IS_EQUAL) reduce 489) ((T_IS_GREATER_OR_EQUAL) reduce 489) ((T_IS_IDENTICAL) reduce 489) ((T_IS_NOT_EQUAL) reduce 489) ((T_IS_NOT_IDENTICAL) reduce 489) ((T_IS_SMALLER_OR_EQUAL) reduce 489) ((T_LOGICAL_AND) reduce 489) ((T_LOGICAL_OR) reduce 489) ((T_LOGICAL_XOR) reduce 489) ((T_POW) reduce 489) ((T_SL) reduce 489) ((T_SPACESHIP) reduce 489) ((T_SR) reduce 489) (("^") reduce 489) (("|") reduce 489) (("}") reduce 489)) 14029 ((("%") reduce 490) (("*") reduce 490) (("+") reduce 490) (("-") reduce 490) ((".") reduce 490) (("/") reduce 490) (("<") reduce 490) ((">") reduce 490) (("?") reduce 490) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_BOOLEAN_AND) reduce 490) ((T_BOOLEAN_OR) reduce 490) ((T_COALESCE) reduce 490) ((T_DOUBLE_ARROW) reduce 490) ((T_INSTANCEOF) reduce 490) ((T_IS_EQUAL) reduce 490) ((T_IS_GREATER_OR_EQUAL) reduce 490) ((T_IS_IDENTICAL) reduce 490) ((T_IS_NOT_EQUAL) reduce 490) ((T_IS_NOT_IDENTICAL) reduce 490) ((T_IS_SMALLER_OR_EQUAL) reduce 490) ((T_LOGICAL_AND) reduce 490) ((T_LOGICAL_OR) reduce 490) ((T_LOGICAL_XOR) reduce 490) ((T_POW) reduce 490) ((T_SL) reduce 490) ((T_SPACESHIP) reduce 490) ((T_SR) reduce 490) (("^") reduce 490) (("|") reduce 490) (("}") reduce 490)) 14030 ((("%") reduce 488) (("*") reduce 488) (("+") reduce 488) (("-") reduce 488) ((".") reduce 488) (("/") reduce 488) (("<") reduce 488) ((">") reduce 488) (("?") reduce 488) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_BOOLEAN_AND) reduce 488) ((T_BOOLEAN_OR) reduce 488) ((T_COALESCE) reduce 488) ((T_DOUBLE_ARROW) reduce 488) ((T_INSTANCEOF) reduce 488) ((T_IS_EQUAL) reduce 488) ((T_IS_GREATER_OR_EQUAL) reduce 488) ((T_IS_IDENTICAL) reduce 488) ((T_IS_NOT_EQUAL) reduce 488) ((T_IS_NOT_IDENTICAL) reduce 488) ((T_IS_SMALLER_OR_EQUAL) reduce 488) ((T_LOGICAL_AND) reduce 488) ((T_LOGICAL_OR) reduce 488) ((T_LOGICAL_XOR) reduce 488) ((T_POW) reduce 488) ((T_SL) reduce 488) ((T_SPACESHIP) reduce 488) ((T_SR) reduce 488) (("^") reduce 488) (("|") reduce 488) (("}") reduce 488)) 14031 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 581) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 581)) 14032 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 580) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 580)) 14033 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) (("<") reduce 466) (("=") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AND_EQUAL) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_COALESCE_EQUAL) reduce 466) ((T_CONCAT_EQUAL) reduce 466) ((T_DEC) reduce 466) ((T_DIV_EQUAL) reduce 466) ((T_DOUBLE_ARROW) reduce 466) ((T_INC) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_MINUS_EQUAL) reduce 466) ((T_MOD_EQUAL) reduce 466) ((T_MUL_EQUAL) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_OR_EQUAL) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_PLUS_EQUAL) reduce 466) ((T_POW) reduce 466) ((T_POW_EQUAL) reduce 466) ((T_SL) reduce 466) ((T_SL_EQUAL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) ((T_SR_EQUAL) reduce 466) ((T_XOR_EQUAL) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466) (("}") reduce 466)) 14034 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 439) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 439) ((T_LOGICAL_OR) reduce 439) ((T_LOGICAL_XOR) reduce 439) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 439)) 14035 ((("%") reduce 432) (("*") reduce 432) (("+") reduce 432) (("-") reduce 432) ((".") reduce 432) (("/") reduce 432) (("<") reduce 432) ((">") reduce 432) (("?") reduce 432) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_BOOLEAN_AND) reduce 432) ((T_BOOLEAN_OR) reduce 432) ((T_COALESCE) reduce 432) ((T_DOUBLE_ARROW) reduce 432) ((T_INSTANCEOF) reduce 432) ((T_IS_EQUAL) reduce 432) ((T_IS_GREATER_OR_EQUAL) reduce 432) ((T_IS_IDENTICAL) reduce 432) ((T_IS_NOT_EQUAL) reduce 432) ((T_IS_NOT_IDENTICAL) reduce 432) ((T_IS_SMALLER_OR_EQUAL) reduce 432) ((T_LOGICAL_AND) reduce 432) ((T_LOGICAL_OR) reduce 432) ((T_LOGICAL_XOR) reduce 432) ((T_POW) shift) ((T_SL) reduce 432) ((T_SPACESHIP) reduce 432) ((T_SR) reduce 432) (("^") reduce 432) (("|") reduce 432) (("}") reduce 432)) 14037 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93) (("}") reduce 93)) 14038 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92) (("}") reduce 92)) 14039 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94) (("}") reduce 94)) 14040 ((("%") reduce 470) (("(") reduce 470) (("*") reduce 470) (("+") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_DOUBLE_ARROW) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470) (("}") reduce 470)) 14041 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91) (("}") reduce 91)) 14042 ((("%") reduce 365) (("*") reduce 365) (("+") reduce 365) (("-") reduce 365) ((".") reduce 365) (("/") reduce 365) (("<") reduce 365) ((">") reduce 365) (("?") reduce 365) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_BOOLEAN_AND) reduce 365) ((T_BOOLEAN_OR) reduce 365) ((T_COALESCE) reduce 365) ((T_DOUBLE_ARROW) reduce 365) ((T_INSTANCEOF) reduce 365) ((T_IS_EQUAL) reduce 365) ((T_IS_GREATER_OR_EQUAL) reduce 365) ((T_IS_IDENTICAL) reduce 365) ((T_IS_NOT_EQUAL) reduce 365) ((T_IS_NOT_IDENTICAL) reduce 365) ((T_IS_SMALLER_OR_EQUAL) reduce 365) ((T_LOGICAL_AND) reduce 365) ((T_LOGICAL_OR) reduce 365) ((T_LOGICAL_XOR) reduce 365) ((T_POW) reduce 365) ((T_SL) reduce 365) ((T_SPACESHIP) reduce 365) ((T_SR) reduce 365) (("^") reduce 365) (("|") reduce 365) (("}") reduce 365)) 14045 ((("%") reduce 472) (("(") reduce 472) (("*") reduce 472) (("+") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_DOUBLE_ARROW) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472) (("}") reduce 472)) 14046 ((("%") reduce 480) (("(") shift) (("*") reduce 480) (("+") reduce 480) (("-") reduce 480) ((".") reduce 480) (("/") reduce 480) (("<") reduce 480) ((">") reduce 480) (("?") reduce 480) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_BOOLEAN_AND) reduce 480) ((T_BOOLEAN_OR) reduce 480) ((T_COALESCE) reduce 480) ((T_DOUBLE_ARROW) reduce 480) ((T_INSTANCEOF) reduce 480) ((T_IS_EQUAL) reduce 480) ((T_IS_GREATER_OR_EQUAL) reduce 480) ((T_IS_IDENTICAL) reduce 480) ((T_IS_NOT_EQUAL) reduce 480) ((T_IS_NOT_IDENTICAL) reduce 480) ((T_IS_SMALLER_OR_EQUAL) reduce 480) ((T_LOGICAL_AND) reduce 480) ((T_LOGICAL_OR) reduce 480) ((T_LOGICAL_XOR) reduce 480) ((T_POW) reduce 480) ((T_SL) reduce 480) ((T_SPACESHIP) reduce 480) ((T_SR) reduce 480) (("^") reduce 480) (("|") reduce 480) (("}") reduce 480)) 14047 ((("%") reduce 471) (("(") reduce 471) (("*") reduce 471) (("+") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_DOUBLE_ARROW) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471) (("}") reduce 471)) 14048 ((("%") reduce 473) (("(") reduce 473) (("*") reduce 473) (("+") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_DOUBLE_ARROW) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473) (("}") reduce 473)) 14049 ((("%") reduce 534) (("(") reduce 534) (("*") reduce 534) (("+") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_DOUBLE_ARROW) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534) (("}") reduce 534)) 14056 ((("%") reduce 536) (("(") reduce 536) (("*") reduce 536) (("+") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_DOUBLE_ARROW) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536) (("}") reduce 536)) 14058 ((("%") reduce 535) (("(") reduce 535) (("*") reduce 535) (("+") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_DOUBLE_ARROW) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535) (("}") reduce 535)) 14059 ((("%") reduce 540) (("(") reduce 540) (("*") reduce 540) (("+") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_DOUBLE_ARROW) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540) (("}") reduce 540)) 14060 ((("%") reduce 537) (("(") reduce 537) (("*") reduce 537) (("+") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_DOUBLE_ARROW) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537) (("}") reduce 537)) 14061 ((("%") reduce 538) (("(") reduce 538) (("*") reduce 538) (("+") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_DOUBLE_ARROW) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538) (("}") reduce 538)) 14063 ((("%") reduce 481) (("*") reduce 481) (("+") reduce 481) (("-") reduce 481) ((".") reduce 481) (("/") reduce 481) (("<") reduce 481) ((">") reduce 481) (("?") reduce 481) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_BOOLEAN_AND) reduce 481) ((T_BOOLEAN_OR) reduce 481) ((T_COALESCE) reduce 481) ((T_DOUBLE_ARROW) reduce 481) ((T_INSTANCEOF) reduce 481) ((T_IS_EQUAL) reduce 481) ((T_IS_GREATER_OR_EQUAL) reduce 481) ((T_IS_IDENTICAL) reduce 481) ((T_IS_NOT_EQUAL) reduce 481) ((T_IS_NOT_IDENTICAL) reduce 481) ((T_IS_SMALLER_OR_EQUAL) reduce 481) ((T_LOGICAL_AND) reduce 481) ((T_LOGICAL_OR) reduce 481) ((T_LOGICAL_XOR) reduce 481) ((T_POW) reduce 481) ((T_SL) reduce 481) ((T_SPACESHIP) reduce 481) ((T_SR) reduce 481) (("^") reduce 481) (("|") reduce 481) (("}") reduce 481)) 14064 ((("%") reduce 364) (("*") reduce 364) (("+") reduce 364) (("-") reduce 364) ((".") reduce 364) (("/") reduce 364) (("<") reduce 364) ((">") reduce 364) (("?") reduce 364) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_BOOLEAN_AND) reduce 364) ((T_BOOLEAN_OR) reduce 364) ((T_COALESCE) reduce 364) ((T_DOUBLE_ARROW) reduce 364) ((T_INSTANCEOF) reduce 364) ((T_IS_EQUAL) reduce 364) ((T_IS_GREATER_OR_EQUAL) reduce 364) ((T_IS_IDENTICAL) reduce 364) ((T_IS_NOT_EQUAL) reduce 364) ((T_IS_NOT_IDENTICAL) reduce 364) ((T_IS_SMALLER_OR_EQUAL) reduce 364) ((T_LOGICAL_AND) reduce 364) ((T_LOGICAL_OR) reduce 364) ((T_LOGICAL_XOR) reduce 364) ((T_POW) reduce 364) ((T_SL) reduce 364) ((T_SPACESHIP) reduce 364) ((T_SR) reduce 364) (("^") reduce 364) (("|") reduce 364) (("}") reduce 364)) 14065 ((("%") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("^") reduce 288) (("|") reduce 288) (("}") reduce 288)) 14069 ((("%") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("^") reduce 289) (("|") reduce 289) (("}") reduce 289)) 14070 ((("%") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("^") reduce 290) (("|") reduce 290) (("}") reduce 290)) 14072 ((("%") reduce 539) (("(") reduce 539) (("*") reduce 539) (("+") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_DOUBLE_ARROW) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539) (("}") reduce 539)) 14073 ((("%") reduce 366) (("*") reduce 366) (("+") reduce 366) (("-") reduce 366) ((".") reduce 366) (("/") reduce 366) (("<") reduce 366) ((">") reduce 366) (("?") reduce 366) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_BOOLEAN_AND) reduce 366) ((T_BOOLEAN_OR) reduce 366) ((T_COALESCE) reduce 366) ((T_DOUBLE_ARROW) reduce 366) ((T_INSTANCEOF) reduce 366) ((T_IS_EQUAL) reduce 366) ((T_IS_GREATER_OR_EQUAL) reduce 366) ((T_IS_IDENTICAL) reduce 366) ((T_IS_NOT_EQUAL) reduce 366) ((T_IS_NOT_IDENTICAL) reduce 366) ((T_IS_SMALLER_OR_EQUAL) reduce 366) ((T_LOGICAL_AND) reduce 366) ((T_LOGICAL_OR) reduce 366) ((T_LOGICAL_XOR) reduce 366) ((T_POW) reduce 366) ((T_SL) reduce 366) ((T_SPACESHIP) reduce 366) ((T_SR) reduce 366) (("^") reduce 366) (("|") reduce 366) (("}") reduce 366)) 14081 ((("%") reduce 363) (("*") reduce 363) (("+") reduce 363) (("-") reduce 363) ((".") reduce 363) (("/") reduce 363) (("<") reduce 363) ((">") reduce 363) (("?") reduce 363) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_BOOLEAN_AND) reduce 363) ((T_BOOLEAN_OR) reduce 363) ((T_COALESCE) reduce 363) ((T_DOUBLE_ARROW) reduce 363) ((T_INSTANCEOF) reduce 363) ((T_IS_EQUAL) reduce 363) ((T_IS_GREATER_OR_EQUAL) reduce 363) ((T_IS_IDENTICAL) reduce 363) ((T_IS_NOT_EQUAL) reduce 363) ((T_IS_NOT_IDENTICAL) reduce 363) ((T_IS_SMALLER_OR_EQUAL) reduce 363) ((T_LOGICAL_AND) reduce 363) ((T_LOGICAL_OR) reduce 363) ((T_LOGICAL_XOR) reduce 363) ((T_POW) reduce 363) ((T_SL) reduce 363) ((T_SPACESHIP) reduce 363) ((T_SR) reduce 363) (("^") reduce 363) (("|") reduce 363) (("}") reduce 363)) 14083 ((("%") reduce 474) (("(") reduce 474) (("*") reduce 474) (("+") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_DOUBLE_ARROW) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474) (("}") reduce 474)) 14089 ((("%") reduce 230) (("*") reduce 230) (("+") reduce 230) (("-") reduce 230) ((".") reduce 230) (("/") reduce 230) (("<") reduce 230) ((">") reduce 230) (("?") reduce 230) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_BOOLEAN_AND) reduce 230) ((T_BOOLEAN_OR) reduce 230) ((T_COALESCE) reduce 230) ((T_DOUBLE_ARROW) reduce 230) ((T_INSTANCEOF) reduce 230) ((T_IS_EQUAL) reduce 230) ((T_IS_GREATER_OR_EQUAL) reduce 230) ((T_IS_IDENTICAL) reduce 230) ((T_IS_NOT_EQUAL) reduce 230) ((T_IS_NOT_IDENTICAL) reduce 230) ((T_IS_SMALLER_OR_EQUAL) reduce 230) ((T_LOGICAL_AND) reduce 230) ((T_LOGICAL_OR) reduce 230) ((T_LOGICAL_XOR) reduce 230) ((T_POW) reduce 230) ((T_SL) reduce 230) ((T_SPACESHIP) reduce 230) ((T_SR) reduce 230) (("^") reduce 230) (("|") reduce 230) (("}") reduce 230)) 14094 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 368) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 368) ((T_LOGICAL_OR) reduce 368) ((T_LOGICAL_XOR) reduce 368) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 368)) 14098 ((("%") reduce 575) (("*") reduce 575) (("+") reduce 575) (("-") reduce 575) ((".") reduce 575) (("/") reduce 575) (("<") reduce 575) ((">") reduce 575) (("?") reduce 575) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_BOOLEAN_AND) reduce 575) ((T_BOOLEAN_OR) reduce 575) ((T_COALESCE) reduce 575) ((T_DOUBLE_ARROW) reduce 575) ((T_INSTANCEOF) reduce 575) ((T_IS_EQUAL) reduce 575) ((T_IS_GREATER_OR_EQUAL) reduce 575) ((T_IS_IDENTICAL) reduce 575) ((T_IS_NOT_EQUAL) reduce 575) ((T_IS_NOT_IDENTICAL) reduce 575) ((T_IS_SMALLER_OR_EQUAL) reduce 575) ((T_LOGICAL_AND) reduce 575) ((T_LOGICAL_OR) reduce 575) ((T_LOGICAL_XOR) reduce 575) ((T_POW) reduce 575) ((T_SL) reduce 575) ((T_SPACESHIP) reduce 575) ((T_SR) reduce 575) (("^") reduce 575) (("|") reduce 575) (("}") reduce 575)) 14099 ((("%") reduce 428) (("*") reduce 428) (("+") reduce 428) (("-") reduce 428) ((".") reduce 428) (("/") reduce 428) (("<") reduce 428) ((">") reduce 428) (("?") reduce 428) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_BOOLEAN_AND) reduce 428) ((T_BOOLEAN_OR) reduce 428) ((T_COALESCE) reduce 428) ((T_DOUBLE_ARROW) reduce 428) ((T_INSTANCEOF) reduce 428) ((T_IS_EQUAL) reduce 428) ((T_IS_GREATER_OR_EQUAL) reduce 428) ((T_IS_IDENTICAL) reduce 428) ((T_IS_NOT_EQUAL) reduce 428) ((T_IS_NOT_IDENTICAL) reduce 428) ((T_IS_SMALLER_OR_EQUAL) reduce 428) ((T_LOGICAL_AND) reduce 428) ((T_LOGICAL_OR) reduce 428) ((T_LOGICAL_XOR) reduce 428) ((T_POW) shift) ((T_SL) reduce 428) ((T_SPACESHIP) reduce 428) ((T_SR) reduce 428) (("^") reduce 428) (("|") reduce 428) (("}") reduce 428)) 14100 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 578) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 578)) 14101 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 577) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 577)) 14102 ((("%") reduce 387) (("*") reduce 387) (("+") reduce 387) (("-") reduce 387) ((".") reduce 387) (("/") reduce 387) (("<") reduce 387) ((">") reduce 387) (("?") reduce 387) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_BOOLEAN_AND) reduce 387) ((T_BOOLEAN_OR) reduce 387) ((T_COALESCE) reduce 387) ((T_DOUBLE_ARROW) reduce 387) ((T_INSTANCEOF) reduce 387) ((T_IS_EQUAL) reduce 387) ((T_IS_GREATER_OR_EQUAL) reduce 387) ((T_IS_IDENTICAL) reduce 387) ((T_IS_NOT_EQUAL) reduce 387) ((T_IS_NOT_IDENTICAL) reduce 387) ((T_IS_SMALLER_OR_EQUAL) reduce 387) ((T_LOGICAL_AND) reduce 387) ((T_LOGICAL_OR) reduce 387) ((T_LOGICAL_XOR) reduce 387) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 387) ((T_SL) reduce 387) ((T_SPACESHIP) reduce 387) ((T_SR) reduce 387) (("[") reduce 510) (("^") reduce 387) (("{") reduce 510) (("|") reduce 387) (("}") reduce 387)) 14104 ((("%") reduce 435) (("*") reduce 435) (("+") reduce 435) (("-") reduce 435) ((".") reduce 435) (("/") reduce 435) (("<") reduce 435) ((">") reduce 435) (("?") reduce 435) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_BOOLEAN_AND) reduce 435) ((T_BOOLEAN_OR) reduce 435) ((T_COALESCE) reduce 435) ((T_DOUBLE_ARROW) reduce 435) ((T_INSTANCEOF) reduce 435) ((T_IS_EQUAL) reduce 435) ((T_IS_GREATER_OR_EQUAL) reduce 435) ((T_IS_IDENTICAL) reduce 435) ((T_IS_NOT_EQUAL) reduce 435) ((T_IS_NOT_IDENTICAL) reduce 435) ((T_IS_SMALLER_OR_EQUAL) reduce 435) ((T_LOGICAL_AND) reduce 435) ((T_LOGICAL_OR) reduce 435) ((T_LOGICAL_XOR) reduce 435) ((T_POW) reduce 435) ((T_SL) reduce 435) ((T_SPACESHIP) reduce 435) ((T_SR) reduce 435) (("^") reduce 435) (("|") reduce 435) (("}") reduce 435)) 14106 ((("%") reduce 476) (("*") reduce 476) (("+") reduce 476) (("-") reduce 476) ((".") reduce 476) (("/") reduce 476) (("<") reduce 476) ((">") reduce 476) (("?") reduce 476) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_BOOLEAN_AND) reduce 476) ((T_BOOLEAN_OR) reduce 476) ((T_COALESCE) reduce 476) ((T_DOUBLE_ARROW) reduce 476) ((T_INSTANCEOF) reduce 476) ((T_IS_EQUAL) reduce 476) ((T_IS_GREATER_OR_EQUAL) reduce 476) ((T_IS_IDENTICAL) reduce 476) ((T_IS_NOT_EQUAL) reduce 476) ((T_IS_NOT_IDENTICAL) reduce 476) ((T_IS_SMALLER_OR_EQUAL) reduce 476) ((T_LOGICAL_AND) reduce 476) ((T_LOGICAL_OR) reduce 476) ((T_LOGICAL_XOR) reduce 476) ((T_POW) reduce 476) ((T_SL) reduce 476) ((T_SPACESHIP) reduce 476) ((T_SR) reduce 476) (("^") reduce 476) (("|") reduce 476) (("}") reduce 476)) 14109 ((("%") reduce 579) (("*") reduce 579) (("+") reduce 579) (("-") reduce 579) ((".") reduce 579) (("/") reduce 579) (("<") reduce 579) ((">") reduce 579) (("?") reduce 579) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_BOOLEAN_AND) reduce 579) ((T_BOOLEAN_OR) reduce 579) ((T_COALESCE) reduce 579) ((T_DOUBLE_ARROW) reduce 579) ((T_INSTANCEOF) reduce 579) ((T_IS_EQUAL) reduce 579) ((T_IS_GREATER_OR_EQUAL) reduce 579) ((T_IS_IDENTICAL) reduce 579) ((T_IS_NOT_EQUAL) reduce 579) ((T_IS_NOT_IDENTICAL) reduce 579) ((T_IS_SMALLER_OR_EQUAL) reduce 579) ((T_LOGICAL_AND) reduce 579) ((T_LOGICAL_OR) reduce 579) ((T_LOGICAL_XOR) reduce 579) ((T_POW) reduce 579) ((T_SL) reduce 579) ((T_SPACESHIP) reduce 579) ((T_SR) reduce 579) (("^") reduce 579) (("|") reduce 579) (("}") reduce 579)) 14112 ((("%") reduce 576) (("*") reduce 576) (("+") reduce 576) (("-") reduce 576) ((".") reduce 576) (("/") reduce 576) (("<") reduce 576) ((">") reduce 576) (("?") reduce 576) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_BOOLEAN_AND) reduce 576) ((T_BOOLEAN_OR) reduce 576) ((T_COALESCE) reduce 576) ((T_DOUBLE_ARROW) reduce 576) ((T_INSTANCEOF) reduce 576) ((T_IS_EQUAL) reduce 576) ((T_IS_GREATER_OR_EQUAL) reduce 576) ((T_IS_IDENTICAL) reduce 576) ((T_IS_NOT_EQUAL) reduce 576) ((T_IS_NOT_IDENTICAL) reduce 576) ((T_IS_SMALLER_OR_EQUAL) reduce 576) ((T_LOGICAL_AND) reduce 576) ((T_LOGICAL_OR) reduce 576) ((T_LOGICAL_XOR) reduce 576) ((T_POW) reduce 576) ((T_SL) reduce 576) ((T_SPACESHIP) reduce 576) ((T_SR) reduce 576) (("^") reduce 576) (("|") reduce 576) (("}") reduce 576)) 14113 ((("%") reduce 429) (("*") reduce 429) (("+") reduce 429) (("-") reduce 429) ((".") reduce 429) (("/") reduce 429) (("<") reduce 429) ((">") reduce 429) (("?") reduce 429) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_BOOLEAN_AND) reduce 429) ((T_BOOLEAN_OR) reduce 429) ((T_COALESCE) reduce 429) ((T_DOUBLE_ARROW) reduce 429) ((T_INSTANCEOF) reduce 429) ((T_IS_EQUAL) reduce 429) ((T_IS_GREATER_OR_EQUAL) reduce 429) ((T_IS_IDENTICAL) reduce 429) ((T_IS_NOT_EQUAL) reduce 429) ((T_IS_NOT_IDENTICAL) reduce 429) ((T_IS_SMALLER_OR_EQUAL) reduce 429) ((T_LOGICAL_AND) reduce 429) ((T_LOGICAL_OR) reduce 429) ((T_LOGICAL_XOR) reduce 429) ((T_POW) shift) ((T_SL) reduce 429) ((T_SPACESHIP) reduce 429) ((T_SR) reduce 429) (("^") reduce 429) (("|") reduce 429) (("}") reduce 429)) 14114 ((("%") reduce 389) (("*") reduce 389) (("+") reduce 389) (("-") reduce 389) ((".") reduce 389) (("/") reduce 389) (("<") reduce 389) ((">") reduce 389) (("?") reduce 389) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_BOOLEAN_AND) reduce 389) ((T_BOOLEAN_OR) reduce 389) ((T_COALESCE) reduce 389) ((T_DOUBLE_ARROW) reduce 389) ((T_INSTANCEOF) reduce 389) ((T_IS_EQUAL) reduce 389) ((T_IS_GREATER_OR_EQUAL) reduce 389) ((T_IS_IDENTICAL) reduce 389) ((T_IS_NOT_EQUAL) reduce 389) ((T_IS_NOT_IDENTICAL) reduce 389) ((T_IS_SMALLER_OR_EQUAL) reduce 389) ((T_LOGICAL_AND) reduce 389) ((T_LOGICAL_OR) reduce 389) ((T_LOGICAL_XOR) reduce 389) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 389) ((T_SL) reduce 389) ((T_SPACESHIP) reduce 389) ((T_SR) reduce 389) (("[") reduce 510) (("^") reduce 389) (("{") reduce 510) (("|") reduce 389) (("}") reduce 389)) 14115 ((("%") reduce 372) (("*") reduce 372) (("+") reduce 372) (("-") reduce 372) ((".") reduce 372) (("/") reduce 372) (("<") reduce 372) ((">") reduce 372) (("?") reduce 372) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_BOOLEAN_AND) reduce 372) ((T_BOOLEAN_OR) reduce 372) ((T_COALESCE) reduce 372) ((T_DOUBLE_ARROW) reduce 372) ((T_INSTANCEOF) reduce 372) ((T_IS_EQUAL) reduce 372) ((T_IS_GREATER_OR_EQUAL) reduce 372) ((T_IS_IDENTICAL) reduce 372) ((T_IS_NOT_EQUAL) reduce 372) ((T_IS_NOT_IDENTICAL) reduce 372) ((T_IS_SMALLER_OR_EQUAL) reduce 372) ((T_LOGICAL_AND) reduce 372) ((T_LOGICAL_OR) reduce 372) ((T_LOGICAL_XOR) reduce 372) ((T_POW) reduce 372) ((T_SL) reduce 372) ((T_SPACESHIP) reduce 372) ((T_SR) reduce 372) (("^") reduce 372) (("|") reduce 372) (("}") reduce 372)) 14116 ((("%") reduce 433) (("*") reduce 433) (("+") reduce 433) (("-") reduce 433) ((".") reduce 433) (("/") reduce 433) (("<") reduce 433) ((">") reduce 433) (("?") reduce 433) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_BOOLEAN_AND) reduce 433) ((T_BOOLEAN_OR) reduce 433) ((T_COALESCE) reduce 433) ((T_DOUBLE_ARROW) reduce 433) ((T_INSTANCEOF) reduce 433) ((T_IS_EQUAL) reduce 433) ((T_IS_GREATER_OR_EQUAL) reduce 433) ((T_IS_IDENTICAL) reduce 433) ((T_IS_NOT_EQUAL) reduce 433) ((T_IS_NOT_IDENTICAL) reduce 433) ((T_IS_SMALLER_OR_EQUAL) reduce 433) ((T_LOGICAL_AND) reduce 433) ((T_LOGICAL_OR) reduce 433) ((T_LOGICAL_XOR) reduce 433) ((T_POW) shift) ((T_SL) reduce 433) ((T_SPACESHIP) reduce 433) ((T_SR) reduce 433) (("^") reduce 433) (("|") reduce 433) (("}") reduce 433)) 14117 ((("%") reduce 431) (("*") reduce 431) (("+") reduce 431) (("-") reduce 431) ((".") reduce 431) (("/") reduce 431) (("<") reduce 431) ((">") reduce 431) (("?") reduce 431) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_BOOLEAN_AND) reduce 431) ((T_BOOLEAN_OR) reduce 431) ((T_COALESCE) reduce 431) ((T_DOUBLE_ARROW) reduce 431) ((T_INSTANCEOF) reduce 431) ((T_IS_EQUAL) reduce 431) ((T_IS_GREATER_OR_EQUAL) reduce 431) ((T_IS_IDENTICAL) reduce 431) ((T_IS_NOT_EQUAL) reduce 431) ((T_IS_NOT_IDENTICAL) reduce 431) ((T_IS_SMALLER_OR_EQUAL) reduce 431) ((T_LOGICAL_AND) reduce 431) ((T_LOGICAL_OR) reduce 431) ((T_LOGICAL_XOR) reduce 431) ((T_POW) shift) ((T_SL) reduce 431) ((T_SPACESHIP) reduce 431) ((T_SR) reduce 431) (("^") reduce 431) (("|") reduce 431) (("}") reduce 431)) 14120 ((("%") reduce 482) (("(") reduce 482) (("*") reduce 482) (("+") reduce 482) (("-") reduce 482) ((".") reduce 482) (("/") reduce 482) (("<") reduce 482) ((">") reduce 482) (("?") reduce 482) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_BOOLEAN_AND) reduce 482) ((T_BOOLEAN_OR) reduce 482) ((T_COALESCE) reduce 482) ((T_DOUBLE_ARROW) reduce 482) ((T_INSTANCEOF) reduce 482) ((T_IS_EQUAL) reduce 482) ((T_IS_GREATER_OR_EQUAL) reduce 482) ((T_IS_IDENTICAL) reduce 482) ((T_IS_NOT_EQUAL) reduce 482) ((T_IS_NOT_IDENTICAL) reduce 482) ((T_IS_SMALLER_OR_EQUAL) reduce 482) ((T_LOGICAL_AND) reduce 482) ((T_LOGICAL_OR) reduce 482) ((T_LOGICAL_XOR) reduce 482) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 482) ((T_OBJECT_OPERATOR) reduce 482) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 482) ((T_POW) reduce 482) ((T_SL) reduce 482) ((T_SPACESHIP) reduce 482) ((T_SR) reduce 482) (("[") reduce 482) (("^") reduce 482) (("{") reduce 482) (("|") reduce 482) (("}") reduce 482)) 14121 ((("%") reduce 436) (("*") reduce 436) (("+") reduce 436) (("-") reduce 436) ((".") reduce 436) (("/") reduce 436) (("<") reduce 436) ((">") reduce 436) (("?") reduce 436) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_BOOLEAN_AND) reduce 436) ((T_BOOLEAN_OR) reduce 436) ((T_COALESCE) reduce 436) ((T_DOUBLE_ARROW) reduce 436) ((T_INSTANCEOF) reduce 436) ((T_IS_EQUAL) reduce 436) ((T_IS_GREATER_OR_EQUAL) reduce 436) ((T_IS_IDENTICAL) reduce 436) ((T_IS_NOT_EQUAL) reduce 436) ((T_IS_NOT_IDENTICAL) reduce 436) ((T_IS_SMALLER_OR_EQUAL) reduce 436) ((T_LOGICAL_AND) reduce 436) ((T_LOGICAL_OR) reduce 436) ((T_LOGICAL_XOR) reduce 436) ((T_POW) shift) ((T_SL) reduce 436) ((T_SPACESHIP) reduce 436) ((T_SR) reduce 436) (("^") reduce 436) (("|") reduce 436) (("}") reduce 436)) 14122 ((("%") reduce 409) (("*") reduce 409) (("+") reduce 409) (("-") reduce 409) ((".") reduce 409) (("/") reduce 409) (("<") reduce 409) ((">") reduce 409) (("?") reduce 409) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_BOOLEAN_AND) reduce 409) ((T_BOOLEAN_OR) reduce 409) ((T_COALESCE) reduce 409) ((T_DOUBLE_ARROW) reduce 409) ((T_INSTANCEOF) reduce 409) ((T_IS_EQUAL) reduce 409) ((T_IS_GREATER_OR_EQUAL) reduce 409) ((T_IS_IDENTICAL) reduce 409) ((T_IS_NOT_EQUAL) reduce 409) ((T_IS_NOT_IDENTICAL) reduce 409) ((T_IS_SMALLER_OR_EQUAL) reduce 409) ((T_LOGICAL_AND) reduce 409) ((T_LOGICAL_OR) reduce 409) ((T_LOGICAL_XOR) reduce 409) ((T_POW) shift) ((T_SL) reduce 409) ((T_SPACESHIP) reduce 409) ((T_SR) reduce 409) (("^") reduce 409) (("|") reduce 409) (("}") reduce 409)) 14123 ((("%") reduce 408) (("*") reduce 408) (("+") reduce 408) (("-") reduce 408) ((".") reduce 408) (("/") reduce 408) (("<") reduce 408) ((">") reduce 408) (("?") reduce 408) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_BOOLEAN_AND) reduce 408) ((T_BOOLEAN_OR) reduce 408) ((T_COALESCE) reduce 408) ((T_DOUBLE_ARROW) reduce 408) ((T_INSTANCEOF) reduce 408) ((T_IS_EQUAL) reduce 408) ((T_IS_GREATER_OR_EQUAL) reduce 408) ((T_IS_IDENTICAL) reduce 408) ((T_IS_NOT_EQUAL) reduce 408) ((T_IS_NOT_IDENTICAL) reduce 408) ((T_IS_SMALLER_OR_EQUAL) reduce 408) ((T_LOGICAL_AND) reduce 408) ((T_LOGICAL_OR) reduce 408) ((T_LOGICAL_XOR) reduce 408) ((T_POW) shift) ((T_SL) reduce 408) ((T_SPACESHIP) reduce 408) ((T_SR) reduce 408) (("^") reduce 408) (("|") reduce 408) (("}") reduce 408)) 14125 ((("%") reduce 422) (("(") reduce 517) (("*") reduce 422) (("+") reduce 422) (("-") reduce 422) ((".") reduce 422) (("/") reduce 422) (("<") reduce 422) ((">") reduce 422) (("?") reduce 422) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_BOOLEAN_AND) reduce 422) ((T_BOOLEAN_OR) reduce 422) ((T_COALESCE) reduce 422) ((T_DOUBLE_ARROW) reduce 422) ((T_INSTANCEOF) reduce 422) ((T_IS_EQUAL) reduce 422) ((T_IS_GREATER_OR_EQUAL) reduce 422) ((T_IS_IDENTICAL) reduce 422) ((T_IS_NOT_EQUAL) reduce 422) ((T_IS_NOT_IDENTICAL) reduce 422) ((T_IS_SMALLER_OR_EQUAL) reduce 422) ((T_LOGICAL_AND) reduce 422) ((T_LOGICAL_OR) reduce 422) ((T_LOGICAL_XOR) reduce 422) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 511) ((T_OBJECT_OPERATOR) reduce 511) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 511) ((T_POW) reduce 422) ((T_SL) reduce 422) ((T_SPACESHIP) reduce 422) ((T_SR) reduce 422) (("[") reduce 511) (("^") reduce 422) (("{") reduce 511) (("|") reduce 422) (("}") reduce 422)) 14126 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) (("=") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AND_EQUAL) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_COALESCE_EQUAL) reduce 531) ((T_CONCAT_EQUAL) reduce 531) ((T_DEC) reduce 531) ((T_DIV_EQUAL) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INC) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_MINUS_EQUAL) reduce 531) ((T_MOD_EQUAL) reduce 531) ((T_MUL_EQUAL) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_OR_EQUAL) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_PLUS_EQUAL) reduce 531) ((T_POW) reduce 531) ((T_POW_EQUAL) reduce 531) ((T_SL) reduce 531) ((T_SL_EQUAL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) ((T_SR_EQUAL) reduce 531) ((T_XOR_EQUAL) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531) (("}") reduce 531)) 14129 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) (("=") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AND_EQUAL) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_COALESCE_EQUAL) reduce 530) ((T_CONCAT_EQUAL) reduce 530) ((T_DEC) reduce 530) ((T_DIV_EQUAL) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INC) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_MINUS_EQUAL) reduce 530) ((T_MOD_EQUAL) reduce 530) ((T_MUL_EQUAL) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_OR_EQUAL) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_PLUS_EQUAL) reduce 530) ((T_POW) reduce 530) ((T_POW_EQUAL) reduce 530) ((T_SL) reduce 530) ((T_SL_EQUAL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) ((T_SR_EQUAL) reduce 530) ((T_XOR_EQUAL) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530) (("}") reduce 530)) 14131 ((("%") reduce 485) (("(") reduce 485) (("*") reduce 485) (("+") reduce 485) (("-") reduce 485) ((".") reduce 485) (("/") reduce 485) (("<") reduce 485) ((">") reduce 485) (("?") reduce 485) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_BOOLEAN_AND) reduce 485) ((T_BOOLEAN_OR) reduce 485) ((T_COALESCE) reduce 485) ((T_DOUBLE_ARROW) reduce 485) ((T_INSTANCEOF) reduce 485) ((T_IS_EQUAL) reduce 485) ((T_IS_GREATER_OR_EQUAL) reduce 485) ((T_IS_IDENTICAL) reduce 485) ((T_IS_NOT_EQUAL) reduce 485) ((T_IS_NOT_IDENTICAL) reduce 485) ((T_IS_SMALLER_OR_EQUAL) reduce 485) ((T_LOGICAL_AND) reduce 485) ((T_LOGICAL_OR) reduce 485) ((T_LOGICAL_XOR) reduce 485) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 485) ((T_OBJECT_OPERATOR) reduce 485) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 485) ((T_POW) reduce 485) ((T_SL) reduce 485) ((T_SPACESHIP) reduce 485) ((T_SR) reduce 485) (("[") reduce 485) (("^") reduce 485) (("{") reduce 485) (("|") reduce 485) (("}") reduce 485)) 14132 ((("%") reduce 410) (("*") reduce 410) (("+") reduce 410) (("-") reduce 410) ((".") reduce 410) (("/") reduce 410) (("<") reduce 410) ((">") reduce 410) (("?") reduce 410) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_BOOLEAN_AND) reduce 410) ((T_BOOLEAN_OR) reduce 410) ((T_COALESCE) reduce 410) ((T_DOUBLE_ARROW) reduce 410) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 410) ((T_IS_GREATER_OR_EQUAL) reduce 410) ((T_IS_IDENTICAL) reduce 410) ((T_IS_NOT_EQUAL) reduce 410) ((T_IS_NOT_IDENTICAL) reduce 410) ((T_IS_SMALLER_OR_EQUAL) reduce 410) ((T_LOGICAL_AND) reduce 410) ((T_LOGICAL_OR) reduce 410) ((T_LOGICAL_XOR) reduce 410) ((T_POW) shift) ((T_SL) reduce 410) ((T_SPACESHIP) reduce 410) ((T_SR) reduce 410) (("^") reduce 410) (("|") reduce 410) (("}") reduce 410)) 14133 ((("%") reduce 434) (("*") reduce 434) (("+") reduce 434) (("-") reduce 434) ((".") reduce 434) (("/") reduce 434) (("<") reduce 434) ((">") reduce 434) (("?") reduce 434) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_BOOLEAN_AND) reduce 434) ((T_BOOLEAN_OR) reduce 434) ((T_COALESCE) reduce 434) ((T_INSTANCEOF) reduce 434) ((T_IS_EQUAL) reduce 434) ((T_IS_GREATER_OR_EQUAL) reduce 434) ((T_IS_IDENTICAL) reduce 434) ((T_IS_NOT_EQUAL) reduce 434) ((T_IS_NOT_IDENTICAL) reduce 434) ((T_IS_SMALLER_OR_EQUAL) reduce 434) ((T_LOGICAL_AND) reduce 434) ((T_LOGICAL_OR) reduce 434) ((T_LOGICAL_XOR) reduce 434) ((T_POW) shift) ((T_SL) reduce 434) ((T_SPACESHIP) reduce 434) ((T_SR) reduce 434) (("^") reduce 434) (("|") reduce 434) (("}") reduce 434)) 14134 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 444)) 14135 ((("%") reduce 430) (("*") reduce 430) (("+") reduce 430) (("-") reduce 430) ((".") reduce 430) (("/") reduce 430) (("<") reduce 430) ((">") reduce 430) (("?") reduce 430) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_BOOLEAN_AND) reduce 430) ((T_BOOLEAN_OR) reduce 430) ((T_COALESCE) reduce 430) ((T_INSTANCEOF) reduce 430) ((T_IS_EQUAL) reduce 430) ((T_IS_GREATER_OR_EQUAL) reduce 430) ((T_IS_IDENTICAL) reduce 430) ((T_IS_NOT_EQUAL) reduce 430) ((T_IS_NOT_IDENTICAL) reduce 430) ((T_IS_SMALLER_OR_EQUAL) reduce 430) ((T_LOGICAL_AND) reduce 430) ((T_LOGICAL_OR) reduce 430) ((T_LOGICAL_XOR) reduce 430) ((T_POW) shift) ((T_SL) reduce 430) ((T_SPACESHIP) reduce 430) ((T_SR) reduce 430) (("^") reduce 430) (("|") reduce 430) (("}") reduce 430)) 14136 ((("%") reduce 447) (("*") reduce 447) (("+") reduce 447) (("-") reduce 447) ((".") reduce 447) (("/") reduce 447) (("<") reduce 447) ((">") reduce 447) (("?") reduce 447) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_BOOLEAN_AND) reduce 447) ((T_BOOLEAN_OR) reduce 447) ((T_COALESCE) reduce 447) ((T_INSTANCEOF) reduce 447) ((T_IS_EQUAL) reduce 447) ((T_IS_GREATER_OR_EQUAL) reduce 447) ((T_IS_IDENTICAL) reduce 447) ((T_IS_NOT_EQUAL) reduce 447) ((T_IS_NOT_IDENTICAL) reduce 447) ((T_IS_SMALLER_OR_EQUAL) reduce 447) ((T_LOGICAL_AND) reduce 447) ((T_LOGICAL_OR) reduce 447) ((T_LOGICAL_XOR) reduce 447) ((T_POW) reduce 447) ((T_SL) reduce 447) ((T_SPACESHIP) reduce 447) ((T_SR) reduce 447) (("^") reduce 447) (("|") reduce 447) (("}") reduce 447)) 14138 ((("%") reduce 489) (("*") reduce 489) (("+") reduce 489) (("-") reduce 489) ((".") reduce 489) (("/") reduce 489) (("<") reduce 489) ((">") reduce 489) (("?") reduce 489) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_BOOLEAN_AND) reduce 489) ((T_BOOLEAN_OR) reduce 489) ((T_COALESCE) reduce 489) ((T_INSTANCEOF) reduce 489) ((T_IS_EQUAL) reduce 489) ((T_IS_GREATER_OR_EQUAL) reduce 489) ((T_IS_IDENTICAL) reduce 489) ((T_IS_NOT_EQUAL) reduce 489) ((T_IS_NOT_IDENTICAL) reduce 489) ((T_IS_SMALLER_OR_EQUAL) reduce 489) ((T_LOGICAL_AND) reduce 489) ((T_LOGICAL_OR) reduce 489) ((T_LOGICAL_XOR) reduce 489) ((T_POW) reduce 489) ((T_SL) reduce 489) ((T_SPACESHIP) reduce 489) ((T_SR) reduce 489) (("^") reduce 489) (("|") reduce 489) (("}") reduce 489)) 14140 ((("%") reduce 490) (("*") reduce 490) (("+") reduce 490) (("-") reduce 490) ((".") reduce 490) (("/") reduce 490) (("<") reduce 490) ((">") reduce 490) (("?") reduce 490) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_BOOLEAN_AND) reduce 490) ((T_BOOLEAN_OR) reduce 490) ((T_COALESCE) reduce 490) ((T_INSTANCEOF) reduce 490) ((T_IS_EQUAL) reduce 490) ((T_IS_GREATER_OR_EQUAL) reduce 490) ((T_IS_IDENTICAL) reduce 490) ((T_IS_NOT_EQUAL) reduce 490) ((T_IS_NOT_IDENTICAL) reduce 490) ((T_IS_SMALLER_OR_EQUAL) reduce 490) ((T_LOGICAL_AND) reduce 490) ((T_LOGICAL_OR) reduce 490) ((T_LOGICAL_XOR) reduce 490) ((T_POW) reduce 490) ((T_SL) reduce 490) ((T_SPACESHIP) reduce 490) ((T_SR) reduce 490) (("^") reduce 490) (("|") reduce 490) (("}") reduce 490)) 14141 ((("%") reduce 488) (("*") reduce 488) (("+") reduce 488) (("-") reduce 488) ((".") reduce 488) (("/") reduce 488) (("<") reduce 488) ((">") reduce 488) (("?") reduce 488) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_BOOLEAN_AND) reduce 488) ((T_BOOLEAN_OR) reduce 488) ((T_COALESCE) reduce 488) ((T_INSTANCEOF) reduce 488) ((T_IS_EQUAL) reduce 488) ((T_IS_GREATER_OR_EQUAL) reduce 488) ((T_IS_IDENTICAL) reduce 488) ((T_IS_NOT_EQUAL) reduce 488) ((T_IS_NOT_IDENTICAL) reduce 488) ((T_IS_SMALLER_OR_EQUAL) reduce 488) ((T_LOGICAL_AND) reduce 488) ((T_LOGICAL_OR) reduce 488) ((T_LOGICAL_XOR) reduce 488) ((T_POW) reduce 488) ((T_SL) reduce 488) ((T_SPACESHIP) reduce 488) ((T_SR) reduce 488) (("^") reduce 488) (("|") reduce 488) (("}") reduce 488)) 14142 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 581)) 14143 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 580)) 14144 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) (("<") reduce 466) (("=") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AND_EQUAL) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_COALESCE_EQUAL) reduce 466) ((T_CONCAT_EQUAL) reduce 466) ((T_DEC) reduce 466) ((T_DIV_EQUAL) reduce 466) ((T_INC) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_MINUS_EQUAL) reduce 466) ((T_MOD_EQUAL) reduce 466) ((T_MUL_EQUAL) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_OR_EQUAL) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_PLUS_EQUAL) reduce 466) ((T_POW) reduce 466) ((T_POW_EQUAL) reduce 466) ((T_SL) reduce 466) ((T_SL_EQUAL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) ((T_SR_EQUAL) reduce 466) ((T_XOR_EQUAL) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466) (("}") reduce 466)) 14145 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 439) ((T_LOGICAL_OR) reduce 439) ((T_LOGICAL_XOR) reduce 439) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 439)) 14146 ((("%") reduce 432) (("*") reduce 432) (("+") reduce 432) (("-") reduce 432) ((".") reduce 432) (("/") reduce 432) (("<") reduce 432) ((">") reduce 432) (("?") reduce 432) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_BOOLEAN_AND) reduce 432) ((T_BOOLEAN_OR) reduce 432) ((T_COALESCE) reduce 432) ((T_INSTANCEOF) reduce 432) ((T_IS_EQUAL) reduce 432) ((T_IS_GREATER_OR_EQUAL) reduce 432) ((T_IS_IDENTICAL) reduce 432) ((T_IS_NOT_EQUAL) reduce 432) ((T_IS_NOT_IDENTICAL) reduce 432) ((T_IS_SMALLER_OR_EQUAL) reduce 432) ((T_LOGICAL_AND) reduce 432) ((T_LOGICAL_OR) reduce 432) ((T_LOGICAL_XOR) reduce 432) ((T_POW) shift) ((T_SL) reduce 432) ((T_SPACESHIP) reduce 432) ((T_SR) reduce 432) (("^") reduce 432) (("|") reduce 432) (("}") reduce 432)) 14148 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93) (("}") reduce 93)) 14149 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92) (("}") reduce 92)) 14150 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94) (("}") reduce 94)) 14151 ((("%") reduce 470) (("(") reduce 470) (("*") reduce 470) (("+") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470) (("}") reduce 470)) 14152 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91) (("}") reduce 91)) 14153 ((("%") reduce 365) (("*") reduce 365) (("+") reduce 365) (("-") reduce 365) ((".") reduce 365) (("/") reduce 365) (("<") reduce 365) ((">") reduce 365) (("?") reduce 365) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_BOOLEAN_AND) reduce 365) ((T_BOOLEAN_OR) reduce 365) ((T_COALESCE) reduce 365) ((T_INSTANCEOF) reduce 365) ((T_IS_EQUAL) reduce 365) ((T_IS_GREATER_OR_EQUAL) reduce 365) ((T_IS_IDENTICAL) reduce 365) ((T_IS_NOT_EQUAL) reduce 365) ((T_IS_NOT_IDENTICAL) reduce 365) ((T_IS_SMALLER_OR_EQUAL) reduce 365) ((T_LOGICAL_AND) reduce 365) ((T_LOGICAL_OR) reduce 365) ((T_LOGICAL_XOR) reduce 365) ((T_POW) reduce 365) ((T_SL) reduce 365) ((T_SPACESHIP) reduce 365) ((T_SR) reduce 365) (("^") reduce 365) (("|") reduce 365) (("}") reduce 365)) 14156 ((("%") reduce 472) (("(") reduce 472) (("*") reduce 472) (("+") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472) (("}") reduce 472)) 14157 ((("%") reduce 480) (("(") shift) (("*") reduce 480) (("+") reduce 480) (("-") reduce 480) ((".") reduce 480) (("/") reduce 480) (("<") reduce 480) ((">") reduce 480) (("?") reduce 480) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_BOOLEAN_AND) reduce 480) ((T_BOOLEAN_OR) reduce 480) ((T_COALESCE) reduce 480) ((T_INSTANCEOF) reduce 480) ((T_IS_EQUAL) reduce 480) ((T_IS_GREATER_OR_EQUAL) reduce 480) ((T_IS_IDENTICAL) reduce 480) ((T_IS_NOT_EQUAL) reduce 480) ((T_IS_NOT_IDENTICAL) reduce 480) ((T_IS_SMALLER_OR_EQUAL) reduce 480) ((T_LOGICAL_AND) reduce 480) ((T_LOGICAL_OR) reduce 480) ((T_LOGICAL_XOR) reduce 480) ((T_POW) reduce 480) ((T_SL) reduce 480) ((T_SPACESHIP) reduce 480) ((T_SR) reduce 480) (("^") reduce 480) (("|") reduce 480) (("}") reduce 480)) 14158 ((("%") reduce 471) (("(") reduce 471) (("*") reduce 471) (("+") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471) (("}") reduce 471)) 14159 ((("%") reduce 473) (("(") reduce 473) (("*") reduce 473) (("+") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473) (("}") reduce 473)) 14160 ((("%") reduce 534) (("(") reduce 534) (("*") reduce 534) (("+") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534) (("}") reduce 534)) 14167 ((("%") reduce 536) (("(") reduce 536) (("*") reduce 536) (("+") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536) (("}") reduce 536)) 14169 ((("%") reduce 535) (("(") reduce 535) (("*") reduce 535) (("+") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535) (("}") reduce 535)) 14170 ((("%") reduce 540) (("(") reduce 540) (("*") reduce 540) (("+") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540) (("}") reduce 540)) 14171 ((("%") reduce 537) (("(") reduce 537) (("*") reduce 537) (("+") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537) (("}") reduce 537)) 14172 ((("%") reduce 538) (("(") reduce 538) (("*") reduce 538) (("+") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538) (("}") reduce 538)) 14174 ((("%") reduce 481) (("*") reduce 481) (("+") reduce 481) (("-") reduce 481) ((".") reduce 481) (("/") reduce 481) (("<") reduce 481) ((">") reduce 481) (("?") reduce 481) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_BOOLEAN_AND) reduce 481) ((T_BOOLEAN_OR) reduce 481) ((T_COALESCE) reduce 481) ((T_INSTANCEOF) reduce 481) ((T_IS_EQUAL) reduce 481) ((T_IS_GREATER_OR_EQUAL) reduce 481) ((T_IS_IDENTICAL) reduce 481) ((T_IS_NOT_EQUAL) reduce 481) ((T_IS_NOT_IDENTICAL) reduce 481) ((T_IS_SMALLER_OR_EQUAL) reduce 481) ((T_LOGICAL_AND) reduce 481) ((T_LOGICAL_OR) reduce 481) ((T_LOGICAL_XOR) reduce 481) ((T_POW) reduce 481) ((T_SL) reduce 481) ((T_SPACESHIP) reduce 481) ((T_SR) reduce 481) (("^") reduce 481) (("|") reduce 481) (("}") reduce 481)) 14175 ((("%") reduce 364) (("*") reduce 364) (("+") reduce 364) (("-") reduce 364) ((".") reduce 364) (("/") reduce 364) (("<") reduce 364) ((">") reduce 364) (("?") reduce 364) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_BOOLEAN_AND) reduce 364) ((T_BOOLEAN_OR) reduce 364) ((T_COALESCE) reduce 364) ((T_INSTANCEOF) reduce 364) ((T_IS_EQUAL) reduce 364) ((T_IS_GREATER_OR_EQUAL) reduce 364) ((T_IS_IDENTICAL) reduce 364) ((T_IS_NOT_EQUAL) reduce 364) ((T_IS_NOT_IDENTICAL) reduce 364) ((T_IS_SMALLER_OR_EQUAL) reduce 364) ((T_LOGICAL_AND) reduce 364) ((T_LOGICAL_OR) reduce 364) ((T_LOGICAL_XOR) reduce 364) ((T_POW) reduce 364) ((T_SL) reduce 364) ((T_SPACESHIP) reduce 364) ((T_SR) reduce 364) (("^") reduce 364) (("|") reduce 364) (("}") reduce 364)) 14176 ((("%") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("^") reduce 288) (("|") reduce 288) (("}") reduce 288)) 14180 ((("%") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("^") reduce 289) (("|") reduce 289) (("}") reduce 289)) 14181 ((("%") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("^") reduce 290) (("|") reduce 290) (("}") reduce 290)) 14183 ((("%") reduce 539) (("(") reduce 539) (("*") reduce 539) (("+") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539) (("}") reduce 539)) 14184 ((("%") reduce 366) (("*") reduce 366) (("+") reduce 366) (("-") reduce 366) ((".") reduce 366) (("/") reduce 366) (("<") reduce 366) ((">") reduce 366) (("?") reduce 366) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_BOOLEAN_AND) reduce 366) ((T_BOOLEAN_OR) reduce 366) ((T_COALESCE) reduce 366) ((T_INSTANCEOF) reduce 366) ((T_IS_EQUAL) reduce 366) ((T_IS_GREATER_OR_EQUAL) reduce 366) ((T_IS_IDENTICAL) reduce 366) ((T_IS_NOT_EQUAL) reduce 366) ((T_IS_NOT_IDENTICAL) reduce 366) ((T_IS_SMALLER_OR_EQUAL) reduce 366) ((T_LOGICAL_AND) reduce 366) ((T_LOGICAL_OR) reduce 366) ((T_LOGICAL_XOR) reduce 366) ((T_POW) reduce 366) ((T_SL) reduce 366) ((T_SPACESHIP) reduce 366) ((T_SR) reduce 366) (("^") reduce 366) (("|") reduce 366) (("}") reduce 366)) 14192 ((("%") reduce 363) (("*") reduce 363) (("+") reduce 363) (("-") reduce 363) ((".") reduce 363) (("/") reduce 363) (("<") reduce 363) ((">") reduce 363) (("?") reduce 363) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_BOOLEAN_AND) reduce 363) ((T_BOOLEAN_OR) reduce 363) ((T_COALESCE) reduce 363) ((T_INSTANCEOF) reduce 363) ((T_IS_EQUAL) reduce 363) ((T_IS_GREATER_OR_EQUAL) reduce 363) ((T_IS_IDENTICAL) reduce 363) ((T_IS_NOT_EQUAL) reduce 363) ((T_IS_NOT_IDENTICAL) reduce 363) ((T_IS_SMALLER_OR_EQUAL) reduce 363) ((T_LOGICAL_AND) reduce 363) ((T_LOGICAL_OR) reduce 363) ((T_LOGICAL_XOR) reduce 363) ((T_POW) reduce 363) ((T_SL) reduce 363) ((T_SPACESHIP) reduce 363) ((T_SR) reduce 363) (("^") reduce 363) (("|") reduce 363) (("}") reduce 363)) 14194 ((("%") reduce 474) (("(") reduce 474) (("*") reduce 474) (("+") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474) (("}") reduce 474)) 14200 ((("%") reduce 230) (("*") reduce 230) (("+") reduce 230) (("-") reduce 230) ((".") reduce 230) (("/") reduce 230) (("<") reduce 230) ((">") reduce 230) (("?") reduce 230) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_BOOLEAN_AND) reduce 230) ((T_BOOLEAN_OR) reduce 230) ((T_COALESCE) reduce 230) ((T_INSTANCEOF) reduce 230) ((T_IS_EQUAL) reduce 230) ((T_IS_GREATER_OR_EQUAL) reduce 230) ((T_IS_IDENTICAL) reduce 230) ((T_IS_NOT_EQUAL) reduce 230) ((T_IS_NOT_IDENTICAL) reduce 230) ((T_IS_SMALLER_OR_EQUAL) reduce 230) ((T_LOGICAL_AND) reduce 230) ((T_LOGICAL_OR) reduce 230) ((T_LOGICAL_XOR) reduce 230) ((T_POW) reduce 230) ((T_SL) reduce 230) ((T_SPACESHIP) reduce 230) ((T_SR) reduce 230) (("^") reduce 230) (("|") reduce 230) (("}") reduce 230)) 14205 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 368) ((T_LOGICAL_OR) reduce 368) ((T_LOGICAL_XOR) reduce 368) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 368)) 14209 ((("%") reduce 575) (("*") reduce 575) (("+") reduce 575) (("-") reduce 575) ((".") reduce 575) (("/") reduce 575) (("<") reduce 575) ((">") reduce 575) (("?") reduce 575) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_BOOLEAN_AND) reduce 575) ((T_BOOLEAN_OR) reduce 575) ((T_COALESCE) reduce 575) ((T_INSTANCEOF) reduce 575) ((T_IS_EQUAL) reduce 575) ((T_IS_GREATER_OR_EQUAL) reduce 575) ((T_IS_IDENTICAL) reduce 575) ((T_IS_NOT_EQUAL) reduce 575) ((T_IS_NOT_IDENTICAL) reduce 575) ((T_IS_SMALLER_OR_EQUAL) reduce 575) ((T_LOGICAL_AND) reduce 575) ((T_LOGICAL_OR) reduce 575) ((T_LOGICAL_XOR) reduce 575) ((T_POW) reduce 575) ((T_SL) reduce 575) ((T_SPACESHIP) reduce 575) ((T_SR) reduce 575) (("^") reduce 575) (("|") reduce 575) (("}") reduce 575)) 14210 ((("%") reduce 428) (("*") reduce 428) (("+") reduce 428) (("-") reduce 428) ((".") reduce 428) (("/") reduce 428) (("<") reduce 428) ((">") reduce 428) (("?") reduce 428) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_BOOLEAN_AND) reduce 428) ((T_BOOLEAN_OR) reduce 428) ((T_COALESCE) reduce 428) ((T_INSTANCEOF) reduce 428) ((T_IS_EQUAL) reduce 428) ((T_IS_GREATER_OR_EQUAL) reduce 428) ((T_IS_IDENTICAL) reduce 428) ((T_IS_NOT_EQUAL) reduce 428) ((T_IS_NOT_IDENTICAL) reduce 428) ((T_IS_SMALLER_OR_EQUAL) reduce 428) ((T_LOGICAL_AND) reduce 428) ((T_LOGICAL_OR) reduce 428) ((T_LOGICAL_XOR) reduce 428) ((T_POW) shift) ((T_SL) reduce 428) ((T_SPACESHIP) reduce 428) ((T_SR) reduce 428) (("^") reduce 428) (("|") reduce 428) (("}") reduce 428)) 14211 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 578)) 14212 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift) (("}") reduce 577)) 14213 ((("%") reduce 387) (("*") reduce 387) (("+") reduce 387) (("-") reduce 387) ((".") reduce 387) (("/") reduce 387) (("<") reduce 387) ((">") reduce 387) (("?") reduce 387) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_BOOLEAN_AND) reduce 387) ((T_BOOLEAN_OR) reduce 387) ((T_COALESCE) reduce 387) ((T_INSTANCEOF) reduce 387) ((T_IS_EQUAL) reduce 387) ((T_IS_GREATER_OR_EQUAL) reduce 387) ((T_IS_IDENTICAL) reduce 387) ((T_IS_NOT_EQUAL) reduce 387) ((T_IS_NOT_IDENTICAL) reduce 387) ((T_IS_SMALLER_OR_EQUAL) reduce 387) ((T_LOGICAL_AND) reduce 387) ((T_LOGICAL_OR) reduce 387) ((T_LOGICAL_XOR) reduce 387) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 387) ((T_SL) reduce 387) ((T_SPACESHIP) reduce 387) ((T_SR) reduce 387) (("[") reduce 510) (("^") reduce 387) (("{") reduce 510) (("|") reduce 387) (("}") reduce 387)) 14215 ((("%") reduce 435) (("*") reduce 435) (("+") reduce 435) (("-") reduce 435) ((".") reduce 435) (("/") reduce 435) (("<") reduce 435) ((">") reduce 435) (("?") reduce 435) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_BOOLEAN_AND) reduce 435) ((T_BOOLEAN_OR) reduce 435) ((T_COALESCE) reduce 435) ((T_INSTANCEOF) reduce 435) ((T_IS_EQUAL) reduce 435) ((T_IS_GREATER_OR_EQUAL) reduce 435) ((T_IS_IDENTICAL) reduce 435) ((T_IS_NOT_EQUAL) reduce 435) ((T_IS_NOT_IDENTICAL) reduce 435) ((T_IS_SMALLER_OR_EQUAL) reduce 435) ((T_LOGICAL_AND) reduce 435) ((T_LOGICAL_OR) reduce 435) ((T_LOGICAL_XOR) reduce 435) ((T_POW) reduce 435) ((T_SL) reduce 435) ((T_SPACESHIP) reduce 435) ((T_SR) reduce 435) (("^") reduce 435) (("|") reduce 435) (("}") reduce 435)) 14217 ((("%") reduce 476) (("*") reduce 476) (("+") reduce 476) (("-") reduce 476) ((".") reduce 476) (("/") reduce 476) (("<") reduce 476) ((">") reduce 476) (("?") reduce 476) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_BOOLEAN_AND) reduce 476) ((T_BOOLEAN_OR) reduce 476) ((T_COALESCE) reduce 476) ((T_INSTANCEOF) reduce 476) ((T_IS_EQUAL) reduce 476) ((T_IS_GREATER_OR_EQUAL) reduce 476) ((T_IS_IDENTICAL) reduce 476) ((T_IS_NOT_EQUAL) reduce 476) ((T_IS_NOT_IDENTICAL) reduce 476) ((T_IS_SMALLER_OR_EQUAL) reduce 476) ((T_LOGICAL_AND) reduce 476) ((T_LOGICAL_OR) reduce 476) ((T_LOGICAL_XOR) reduce 476) ((T_POW) reduce 476) ((T_SL) reduce 476) ((T_SPACESHIP) reduce 476) ((T_SR) reduce 476) (("^") reduce 476) (("|") reduce 476) (("}") reduce 476)) 14220 ((("%") reduce 579) (("*") reduce 579) (("+") reduce 579) (("-") reduce 579) ((".") reduce 579) (("/") reduce 579) (("<") reduce 579) ((">") reduce 579) (("?") reduce 579) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_BOOLEAN_AND) reduce 579) ((T_BOOLEAN_OR) reduce 579) ((T_COALESCE) reduce 579) ((T_INSTANCEOF) reduce 579) ((T_IS_EQUAL) reduce 579) ((T_IS_GREATER_OR_EQUAL) reduce 579) ((T_IS_IDENTICAL) reduce 579) ((T_IS_NOT_EQUAL) reduce 579) ((T_IS_NOT_IDENTICAL) reduce 579) ((T_IS_SMALLER_OR_EQUAL) reduce 579) ((T_LOGICAL_AND) reduce 579) ((T_LOGICAL_OR) reduce 579) ((T_LOGICAL_XOR) reduce 579) ((T_POW) reduce 579) ((T_SL) reduce 579) ((T_SPACESHIP) reduce 579) ((T_SR) reduce 579) (("^") reduce 579) (("|") reduce 579) (("}") reduce 579)) 14223 ((("%") reduce 576) (("*") reduce 576) (("+") reduce 576) (("-") reduce 576) ((".") reduce 576) (("/") reduce 576) (("<") reduce 576) ((">") reduce 576) (("?") reduce 576) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_BOOLEAN_AND) reduce 576) ((T_BOOLEAN_OR) reduce 576) ((T_COALESCE) reduce 576) ((T_INSTANCEOF) reduce 576) ((T_IS_EQUAL) reduce 576) ((T_IS_GREATER_OR_EQUAL) reduce 576) ((T_IS_IDENTICAL) reduce 576) ((T_IS_NOT_EQUAL) reduce 576) ((T_IS_NOT_IDENTICAL) reduce 576) ((T_IS_SMALLER_OR_EQUAL) reduce 576) ((T_LOGICAL_AND) reduce 576) ((T_LOGICAL_OR) reduce 576) ((T_LOGICAL_XOR) reduce 576) ((T_POW) reduce 576) ((T_SL) reduce 576) ((T_SPACESHIP) reduce 576) ((T_SR) reduce 576) (("^") reduce 576) (("|") reduce 576) (("}") reduce 576)) 14224 ((("%") reduce 429) (("*") reduce 429) (("+") reduce 429) (("-") reduce 429) ((".") reduce 429) (("/") reduce 429) (("<") reduce 429) ((">") reduce 429) (("?") reduce 429) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_BOOLEAN_AND) reduce 429) ((T_BOOLEAN_OR) reduce 429) ((T_COALESCE) reduce 429) ((T_INSTANCEOF) reduce 429) ((T_IS_EQUAL) reduce 429) ((T_IS_GREATER_OR_EQUAL) reduce 429) ((T_IS_IDENTICAL) reduce 429) ((T_IS_NOT_EQUAL) reduce 429) ((T_IS_NOT_IDENTICAL) reduce 429) ((T_IS_SMALLER_OR_EQUAL) reduce 429) ((T_LOGICAL_AND) reduce 429) ((T_LOGICAL_OR) reduce 429) ((T_LOGICAL_XOR) reduce 429) ((T_POW) shift) ((T_SL) reduce 429) ((T_SPACESHIP) reduce 429) ((T_SR) reduce 429) (("^") reduce 429) (("|") reduce 429) (("}") reduce 429)) 14225 ((("%") reduce 389) (("*") reduce 389) (("+") reduce 389) (("-") reduce 389) ((".") reduce 389) (("/") reduce 389) (("<") reduce 389) ((">") reduce 389) (("?") reduce 389) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_BOOLEAN_AND) reduce 389) ((T_BOOLEAN_OR) reduce 389) ((T_COALESCE) reduce 389) ((T_INSTANCEOF) reduce 389) ((T_IS_EQUAL) reduce 389) ((T_IS_GREATER_OR_EQUAL) reduce 389) ((T_IS_IDENTICAL) reduce 389) ((T_IS_NOT_EQUAL) reduce 389) ((T_IS_NOT_IDENTICAL) reduce 389) ((T_IS_SMALLER_OR_EQUAL) reduce 389) ((T_LOGICAL_AND) reduce 389) ((T_LOGICAL_OR) reduce 389) ((T_LOGICAL_XOR) reduce 389) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 389) ((T_SL) reduce 389) ((T_SPACESHIP) reduce 389) ((T_SR) reduce 389) (("[") reduce 510) (("^") reduce 389) (("{") reduce 510) (("|") reduce 389) (("}") reduce 389)) 14226 ((("%") reduce 372) (("*") reduce 372) (("+") reduce 372) (("-") reduce 372) ((".") reduce 372) (("/") reduce 372) (("<") reduce 372) ((">") reduce 372) (("?") reduce 372) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_BOOLEAN_AND) reduce 372) ((T_BOOLEAN_OR) reduce 372) ((T_COALESCE) reduce 372) ((T_INSTANCEOF) reduce 372) ((T_IS_EQUAL) reduce 372) ((T_IS_GREATER_OR_EQUAL) reduce 372) ((T_IS_IDENTICAL) reduce 372) ((T_IS_NOT_EQUAL) reduce 372) ((T_IS_NOT_IDENTICAL) reduce 372) ((T_IS_SMALLER_OR_EQUAL) reduce 372) ((T_LOGICAL_AND) reduce 372) ((T_LOGICAL_OR) reduce 372) ((T_LOGICAL_XOR) reduce 372) ((T_POW) reduce 372) ((T_SL) reduce 372) ((T_SPACESHIP) reduce 372) ((T_SR) reduce 372) (("^") reduce 372) (("|") reduce 372) (("}") reduce 372)) 14227 ((("%") reduce 433) (("*") reduce 433) (("+") reduce 433) (("-") reduce 433) ((".") reduce 433) (("/") reduce 433) (("<") reduce 433) ((">") reduce 433) (("?") reduce 433) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_BOOLEAN_AND) reduce 433) ((T_BOOLEAN_OR) reduce 433) ((T_COALESCE) reduce 433) ((T_INSTANCEOF) reduce 433) ((T_IS_EQUAL) reduce 433) ((T_IS_GREATER_OR_EQUAL) reduce 433) ((T_IS_IDENTICAL) reduce 433) ((T_IS_NOT_EQUAL) reduce 433) ((T_IS_NOT_IDENTICAL) reduce 433) ((T_IS_SMALLER_OR_EQUAL) reduce 433) ((T_LOGICAL_AND) reduce 433) ((T_LOGICAL_OR) reduce 433) ((T_LOGICAL_XOR) reduce 433) ((T_POW) shift) ((T_SL) reduce 433) ((T_SPACESHIP) reduce 433) ((T_SR) reduce 433) (("^") reduce 433) (("|") reduce 433) (("}") reduce 433)) 14228 ((("%") reduce 431) (("*") reduce 431) (("+") reduce 431) (("-") reduce 431) ((".") reduce 431) (("/") reduce 431) (("<") reduce 431) ((">") reduce 431) (("?") reduce 431) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_BOOLEAN_AND) reduce 431) ((T_BOOLEAN_OR) reduce 431) ((T_COALESCE) reduce 431) ((T_INSTANCEOF) reduce 431) ((T_IS_EQUAL) reduce 431) ((T_IS_GREATER_OR_EQUAL) reduce 431) ((T_IS_IDENTICAL) reduce 431) ((T_IS_NOT_EQUAL) reduce 431) ((T_IS_NOT_IDENTICAL) reduce 431) ((T_IS_SMALLER_OR_EQUAL) reduce 431) ((T_LOGICAL_AND) reduce 431) ((T_LOGICAL_OR) reduce 431) ((T_LOGICAL_XOR) reduce 431) ((T_POW) shift) ((T_SL) reduce 431) ((T_SPACESHIP) reduce 431) ((T_SR) reduce 431) (("^") reduce 431) (("|") reduce 431) (("}") reduce 431)) 14231 ((("%") reduce 482) (("(") reduce 482) (("*") reduce 482) (("+") reduce 482) (("-") reduce 482) ((".") reduce 482) (("/") reduce 482) (("<") reduce 482) ((">") reduce 482) (("?") reduce 482) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_BOOLEAN_AND) reduce 482) ((T_BOOLEAN_OR) reduce 482) ((T_COALESCE) reduce 482) ((T_INSTANCEOF) reduce 482) ((T_IS_EQUAL) reduce 482) ((T_IS_GREATER_OR_EQUAL) reduce 482) ((T_IS_IDENTICAL) reduce 482) ((T_IS_NOT_EQUAL) reduce 482) ((T_IS_NOT_IDENTICAL) reduce 482) ((T_IS_SMALLER_OR_EQUAL) reduce 482) ((T_LOGICAL_AND) reduce 482) ((T_LOGICAL_OR) reduce 482) ((T_LOGICAL_XOR) reduce 482) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 482) ((T_OBJECT_OPERATOR) reduce 482) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 482) ((T_POW) reduce 482) ((T_SL) reduce 482) ((T_SPACESHIP) reduce 482) ((T_SR) reduce 482) (("[") reduce 482) (("^") reduce 482) (("{") reduce 482) (("|") reduce 482) (("}") reduce 482)) 14232 ((("%") reduce 436) (("*") reduce 436) (("+") reduce 436) (("-") reduce 436) ((".") reduce 436) (("/") reduce 436) (("<") reduce 436) ((">") reduce 436) (("?") reduce 436) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_BOOLEAN_AND) reduce 436) ((T_BOOLEAN_OR) reduce 436) ((T_COALESCE) reduce 436) ((T_INSTANCEOF) reduce 436) ((T_IS_EQUAL) reduce 436) ((T_IS_GREATER_OR_EQUAL) reduce 436) ((T_IS_IDENTICAL) reduce 436) ((T_IS_NOT_EQUAL) reduce 436) ((T_IS_NOT_IDENTICAL) reduce 436) ((T_IS_SMALLER_OR_EQUAL) reduce 436) ((T_LOGICAL_AND) reduce 436) ((T_LOGICAL_OR) reduce 436) ((T_LOGICAL_XOR) reduce 436) ((T_POW) shift) ((T_SL) reduce 436) ((T_SPACESHIP) reduce 436) ((T_SR) reduce 436) (("^") reduce 436) (("|") reduce 436) (("}") reduce 436)) 14233 ((("%") reduce 409) (("*") reduce 409) (("+") reduce 409) (("-") reduce 409) ((".") reduce 409) (("/") reduce 409) (("<") reduce 409) ((">") reduce 409) (("?") reduce 409) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_BOOLEAN_AND) reduce 409) ((T_BOOLEAN_OR) reduce 409) ((T_COALESCE) reduce 409) ((T_INSTANCEOF) reduce 409) ((T_IS_EQUAL) reduce 409) ((T_IS_GREATER_OR_EQUAL) reduce 409) ((T_IS_IDENTICAL) reduce 409) ((T_IS_NOT_EQUAL) reduce 409) ((T_IS_NOT_IDENTICAL) reduce 409) ((T_IS_SMALLER_OR_EQUAL) reduce 409) ((T_LOGICAL_AND) reduce 409) ((T_LOGICAL_OR) reduce 409) ((T_LOGICAL_XOR) reduce 409) ((T_POW) shift) ((T_SL) reduce 409) ((T_SPACESHIP) reduce 409) ((T_SR) reduce 409) (("^") reduce 409) (("|") reduce 409) (("}") reduce 409)) 14234 ((("%") reduce 408) (("*") reduce 408) (("+") reduce 408) (("-") reduce 408) ((".") reduce 408) (("/") reduce 408) (("<") reduce 408) ((">") reduce 408) (("?") reduce 408) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_BOOLEAN_AND) reduce 408) ((T_BOOLEAN_OR) reduce 408) ((T_COALESCE) reduce 408) ((T_INSTANCEOF) reduce 408) ((T_IS_EQUAL) reduce 408) ((T_IS_GREATER_OR_EQUAL) reduce 408) ((T_IS_IDENTICAL) reduce 408) ((T_IS_NOT_EQUAL) reduce 408) ((T_IS_NOT_IDENTICAL) reduce 408) ((T_IS_SMALLER_OR_EQUAL) reduce 408) ((T_LOGICAL_AND) reduce 408) ((T_LOGICAL_OR) reduce 408) ((T_LOGICAL_XOR) reduce 408) ((T_POW) shift) ((T_SL) reduce 408) ((T_SPACESHIP) reduce 408) ((T_SR) reduce 408) (("^") reduce 408) (("|") reduce 408) (("}") reduce 408)) 14236 ((("%") reduce 422) (("(") reduce 517) (("*") reduce 422) (("+") reduce 422) (("-") reduce 422) ((".") reduce 422) (("/") reduce 422) (("<") reduce 422) ((">") reduce 422) (("?") reduce 422) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_BOOLEAN_AND) reduce 422) ((T_BOOLEAN_OR) reduce 422) ((T_COALESCE) reduce 422) ((T_INSTANCEOF) reduce 422) ((T_IS_EQUAL) reduce 422) ((T_IS_GREATER_OR_EQUAL) reduce 422) ((T_IS_IDENTICAL) reduce 422) ((T_IS_NOT_EQUAL) reduce 422) ((T_IS_NOT_IDENTICAL) reduce 422) ((T_IS_SMALLER_OR_EQUAL) reduce 422) ((T_LOGICAL_AND) reduce 422) ((T_LOGICAL_OR) reduce 422) ((T_LOGICAL_XOR) reduce 422) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 511) ((T_OBJECT_OPERATOR) reduce 511) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 511) ((T_POW) reduce 422) ((T_SL) reduce 422) ((T_SPACESHIP) reduce 422) ((T_SR) reduce 422) (("[") reduce 511) (("^") reduce 422) (("{") reduce 511) (("|") reduce 422) (("}") reduce 422)) 14237 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) (("=") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AND_EQUAL) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_COALESCE_EQUAL) reduce 531) ((T_CONCAT_EQUAL) reduce 531) ((T_DEC) reduce 531) ((T_DIV_EQUAL) reduce 531) ((T_INC) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_MINUS_EQUAL) reduce 531) ((T_MOD_EQUAL) reduce 531) ((T_MUL_EQUAL) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_OR_EQUAL) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_PLUS_EQUAL) reduce 531) ((T_POW) reduce 531) ((T_POW_EQUAL) reduce 531) ((T_SL) reduce 531) ((T_SL_EQUAL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) ((T_SR_EQUAL) reduce 531) ((T_XOR_EQUAL) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531) (("}") reduce 531)) 14240 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) (("=") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AND_EQUAL) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_COALESCE_EQUAL) reduce 530) ((T_CONCAT_EQUAL) reduce 530) ((T_DEC) reduce 530) ((T_DIV_EQUAL) reduce 530) ((T_INC) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_MINUS_EQUAL) reduce 530) ((T_MOD_EQUAL) reduce 530) ((T_MUL_EQUAL) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_OR_EQUAL) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_PLUS_EQUAL) reduce 530) ((T_POW) reduce 530) ((T_POW_EQUAL) reduce 530) ((T_SL) reduce 530) ((T_SL_EQUAL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) ((T_SR_EQUAL) reduce 530) ((T_XOR_EQUAL) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530) (("}") reduce 530)) 14242 ((("%") reduce 485) (("(") reduce 485) (("*") reduce 485) (("+") reduce 485) (("-") reduce 485) ((".") reduce 485) (("/") reduce 485) (("<") reduce 485) ((">") reduce 485) (("?") reduce 485) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_BOOLEAN_AND) reduce 485) ((T_BOOLEAN_OR) reduce 485) ((T_COALESCE) reduce 485) ((T_INSTANCEOF) reduce 485) ((T_IS_EQUAL) reduce 485) ((T_IS_GREATER_OR_EQUAL) reduce 485) ((T_IS_IDENTICAL) reduce 485) ((T_IS_NOT_EQUAL) reduce 485) ((T_IS_NOT_IDENTICAL) reduce 485) ((T_IS_SMALLER_OR_EQUAL) reduce 485) ((T_LOGICAL_AND) reduce 485) ((T_LOGICAL_OR) reduce 485) ((T_LOGICAL_XOR) reduce 485) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 485) ((T_OBJECT_OPERATOR) reduce 485) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 485) ((T_POW) reduce 485) ((T_SL) reduce 485) ((T_SPACESHIP) reduce 485) ((T_SR) reduce 485) (("[") reduce 485) (("^") reduce 485) (("{") reduce 485) (("|") reduce 485) (("}") reduce 485)) 14243 ((("%") reduce 410) (("*") reduce 410) (("+") reduce 410) (("-") reduce 410) ((".") reduce 410) (("/") reduce 410) (("<") reduce 410) ((">") reduce 410) (("?") reduce 410) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_BOOLEAN_AND) reduce 410) ((T_BOOLEAN_OR) reduce 410) ((T_COALESCE) reduce 410) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 410) ((T_IS_GREATER_OR_EQUAL) reduce 410) ((T_IS_IDENTICAL) reduce 410) ((T_IS_NOT_EQUAL) reduce 410) ((T_IS_NOT_IDENTICAL) reduce 410) ((T_IS_SMALLER_OR_EQUAL) reduce 410) ((T_LOGICAL_AND) reduce 410) ((T_LOGICAL_OR) reduce 410) ((T_LOGICAL_XOR) reduce 410) ((T_POW) shift) ((T_SL) reduce 410) ((T_SPACESHIP) reduce 410) ((T_SR) reduce 410) (("^") reduce 410) (("|") reduce 410) (("}") reduce 410)) 14244 ((("%") reduce 536) ((")") reduce 536) (("*") reduce 536) (("+") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 14874 ((("%") reduce 535) ((")") reduce 535) (("*") reduce 535) (("+") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 14875 ((("%") reduce 540) ((")") reduce 540) (("*") reduce 540) (("+") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 14876 ((("%") reduce 544) ((")") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 14877 ((("%") reduce 537) ((")") reduce 537) (("*") reduce 537) (("+") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 14878 ((("%") reduce 546) ((")") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 14881 ((("%") reduce 545) ((")") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 14882 ((("%") reduce 538) ((")") reduce 538) (("*") reduce 538) (("+") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 14884 ((("%") reduce 539) ((")") reduce 539) (("*") reduce 539) (("+") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 14886 ((("%") reduce 474) ((")") reduce 474) (("*") reduce 474) (("+") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474)) 14887 ((("%") reduce 531) ((")") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 14890 ((("%") reduce 530) ((")") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 14891 ((("%") shift) ((")") reduce 426) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 426) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 426) ((T_LOGICAL_OR) reduce 426) ((T_LOGICAL_XOR) reduce 426) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 14892 ((("%") shift) ((")") reduce 390) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 390) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) reduce 390) ((T_COALESCE) reduce 390) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 390) ((T_LOGICAL_OR) reduce 390) ((T_LOGICAL_XOR) reduce 390) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 14893 ((("%") shift) ((")") reduce 391) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 391) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 391) ((T_BOOLEAN_OR) reduce 391) ((T_COALESCE) reduce 391) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 391) ((T_LOGICAL_OR) reduce 391) ((T_LOGICAL_XOR) reduce 391) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 14894 ((("%") shift) ((")") reduce 396) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 396) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_BOOLEAN_AND) reduce 396) ((T_BOOLEAN_OR) reduce 396) ((T_COALESCE) reduce 396) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 396) ((T_LOGICAL_OR) reduce 396) ((T_LOGICAL_XOR) reduce 396) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 396) (("|") reduce 396)) 14895 ((("%") shift) ((")") reduce 397) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 397) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_BOOLEAN_AND) reduce 397) ((T_BOOLEAN_OR) reduce 397) ((T_COALESCE) reduce 397) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 397) ((T_LOGICAL_OR) reduce 397) ((T_LOGICAL_XOR) reduce 397) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 397) (("|") reduce 397)) 14899 ((("%") shift) ((")") reduce 424) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 424) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 424) ((T_LOGICAL_OR) reduce 424) ((T_LOGICAL_XOR) reduce 424) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 14900 ((("%") shift) ((")") reduce 425) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 425) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 425) ((T_LOGICAL_OR) reduce 425) ((T_LOGICAL_XOR) reduce 425) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 14901 ((("%") shift) ((")") reduce 418) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 418) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_BOOLEAN_AND) reduce 418) ((T_BOOLEAN_OR) reduce 418) ((T_COALESCE) reduce 418) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 418) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 418) ((T_IS_NOT_EQUAL) reduce 418) ((T_IS_NOT_IDENTICAL) reduce 418) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 418) ((T_LOGICAL_OR) reduce 418) ((T_LOGICAL_XOR) reduce 418) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 418) ((T_SR) shift) (("^") reduce 418) (("|") reduce 418)) 14902 ((("%") shift) ((")") reduce 416) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 416) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_BOOLEAN_AND) reduce 416) ((T_BOOLEAN_OR) reduce 416) ((T_COALESCE) reduce 416) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 416) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 416) ((T_IS_NOT_EQUAL) reduce 416) ((T_IS_NOT_IDENTICAL) reduce 416) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 416) ((T_LOGICAL_OR) reduce 416) ((T_LOGICAL_XOR) reduce 416) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 416) ((T_SR) shift) (("^") reduce 416) (("|") reduce 416)) 14903 ((("%") reduce 404) ((")") reduce 404) (("*") reduce 404) (("+") reduce 404) (("-") reduce 404) ((".") reduce 404) (("/") reduce 404) (("<") reduce 404) ((">") reduce 404) (("?") reduce 404) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_BOOLEAN_AND) reduce 404) ((T_BOOLEAN_OR) reduce 404) ((T_COALESCE) reduce 404) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 404) ((T_IS_GREATER_OR_EQUAL) reduce 404) ((T_IS_IDENTICAL) reduce 404) ((T_IS_NOT_EQUAL) reduce 404) ((T_IS_NOT_IDENTICAL) reduce 404) ((T_IS_SMALLER_OR_EQUAL) reduce 404) ((T_LOGICAL_AND) reduce 404) ((T_LOGICAL_OR) reduce 404) ((T_LOGICAL_XOR) reduce 404) ((T_POW) shift) ((T_SL) reduce 404) ((T_SPACESHIP) reduce 404) ((T_SR) reduce 404) (("^") reduce 404) (("|") reduce 404)) 14904 ((("%") shift) ((")") reduce 399) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 399) (("/") shift) (("<") reduce 399) ((">") reduce 399) (("?") reduce 399) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_BOOLEAN_AND) reduce 399) ((T_BOOLEAN_OR) reduce 399) ((T_COALESCE) reduce 399) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 399) ((T_IS_GREATER_OR_EQUAL) reduce 399) ((T_IS_IDENTICAL) reduce 399) ((T_IS_NOT_EQUAL) reduce 399) ((T_IS_NOT_IDENTICAL) reduce 399) ((T_IS_SMALLER_OR_EQUAL) reduce 399) ((T_LOGICAL_AND) reduce 399) ((T_LOGICAL_OR) reduce 399) ((T_LOGICAL_XOR) reduce 399) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 399) ((T_SR) shift) (("^") reduce 399) (("|") reduce 399)) 14905 ((("%") shift) ((")") reduce 401) (("*") shift) (("+") reduce 401) (("-") reduce 401) ((".") reduce 401) (("/") shift) (("<") reduce 401) ((">") reduce 401) (("?") reduce 401) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_BOOLEAN_AND) reduce 401) ((T_BOOLEAN_OR) reduce 401) ((T_COALESCE) reduce 401) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 401) ((T_IS_GREATER_OR_EQUAL) reduce 401) ((T_IS_IDENTICAL) reduce 401) ((T_IS_NOT_EQUAL) reduce 401) ((T_IS_NOT_IDENTICAL) reduce 401) ((T_IS_SMALLER_OR_EQUAL) reduce 401) ((T_LOGICAL_AND) reduce 401) ((T_LOGICAL_OR) reduce 401) ((T_LOGICAL_XOR) reduce 401) ((T_POW) shift) ((T_SL) reduce 401) ((T_SPACESHIP) reduce 401) ((T_SR) reduce 401) (("^") reduce 401) (("|") reduce 401)) 14906 ((("%") shift) ((")") reduce 400) (("*") shift) (("+") reduce 400) (("-") reduce 400) ((".") reduce 400) (("/") shift) (("<") reduce 400) ((">") reduce 400) (("?") reduce 400) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_BOOLEAN_AND) reduce 400) ((T_BOOLEAN_OR) reduce 400) ((T_COALESCE) reduce 400) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 400) ((T_IS_GREATER_OR_EQUAL) reduce 400) ((T_IS_IDENTICAL) reduce 400) ((T_IS_NOT_EQUAL) reduce 400) ((T_IS_NOT_IDENTICAL) reduce 400) ((T_IS_SMALLER_OR_EQUAL) reduce 400) ((T_LOGICAL_AND) reduce 400) ((T_LOGICAL_OR) reduce 400) ((T_LOGICAL_XOR) reduce 400) ((T_POW) shift) ((T_SL) reduce 400) ((T_SPACESHIP) reduce 400) ((T_SR) reduce 400) (("^") reduce 400) (("|") reduce 400)) 14907 ((("%") reduce 402) ((")") reduce 402) (("*") reduce 402) (("+") reduce 402) (("-") reduce 402) ((".") reduce 402) (("/") reduce 402) (("<") reduce 402) ((">") reduce 402) (("?") reduce 402) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_BOOLEAN_AND) reduce 402) ((T_BOOLEAN_OR) reduce 402) ((T_COALESCE) reduce 402) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 402) ((T_IS_GREATER_OR_EQUAL) reduce 402) ((T_IS_IDENTICAL) reduce 402) ((T_IS_NOT_EQUAL) reduce 402) ((T_IS_NOT_IDENTICAL) reduce 402) ((T_IS_SMALLER_OR_EQUAL) reduce 402) ((T_LOGICAL_AND) reduce 402) ((T_LOGICAL_OR) reduce 402) ((T_LOGICAL_XOR) reduce 402) ((T_POW) shift) ((T_SL) reduce 402) ((T_SPACESHIP) reduce 402) ((T_SR) reduce 402) (("^") reduce 402) (("|") reduce 402)) 14908 ((("%") reduce 405) ((")") reduce 405) (("*") reduce 405) (("+") reduce 405) (("-") reduce 405) ((".") reduce 405) (("/") reduce 405) (("<") reduce 405) ((">") reduce 405) (("?") reduce 405) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_BOOLEAN_AND) reduce 405) ((T_BOOLEAN_OR) reduce 405) ((T_COALESCE) reduce 405) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 405) ((T_IS_GREATER_OR_EQUAL) reduce 405) ((T_IS_IDENTICAL) reduce 405) ((T_IS_NOT_EQUAL) reduce 405) ((T_IS_NOT_IDENTICAL) reduce 405) ((T_IS_SMALLER_OR_EQUAL) reduce 405) ((T_LOGICAL_AND) reduce 405) ((T_LOGICAL_OR) reduce 405) ((T_LOGICAL_XOR) reduce 405) ((T_POW) shift) ((T_SL) reduce 405) ((T_SPACESHIP) reduce 405) ((T_SR) reduce 405) (("^") reduce 405) (("|") reduce 405)) 14910 ((("%") reduce 73) (("(") reduce 73) ((")") reduce 73) (("*") reduce 73) (("+") reduce 73) (("-") reduce 73) ((".") reduce 73) (("/") reduce 73) (("<") reduce 73) ((">") reduce 73) (("?") reduce 73) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_BOOLEAN_AND) reduce 73) ((T_BOOLEAN_OR) reduce 73) ((T_COALESCE) reduce 73) ((T_INSTANCEOF) reduce 73) ((T_IS_EQUAL) reduce 73) ((T_IS_GREATER_OR_EQUAL) reduce 73) ((T_IS_IDENTICAL) reduce 73) ((T_IS_NOT_EQUAL) reduce 73) ((T_IS_NOT_IDENTICAL) reduce 73) ((T_IS_SMALLER_OR_EQUAL) reduce 73) ((T_LOGICAL_AND) reduce 73) ((T_LOGICAL_OR) reduce 73) ((T_LOGICAL_XOR) reduce 73) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 73) ((T_OBJECT_OPERATOR) reduce 73) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 73) ((T_POW) reduce 73) ((T_SL) reduce 73) ((T_SPACESHIP) reduce 73) ((T_SR) reduce 73) (("[") reduce 73) (("^") reduce 73) (("{") reduce 73) (("|") reduce 73)) 14911 ((("%") reduce 52) (("(") reduce 52) ((")") reduce 52) (("*") reduce 52) (("+") reduce 52) (("-") reduce 52) ((".") reduce 52) (("/") reduce 52) (("<") reduce 52) ((">") reduce 52) (("?") reduce 52) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_BOOLEAN_AND) reduce 52) ((T_BOOLEAN_OR) reduce 52) ((T_COALESCE) reduce 52) ((T_INSTANCEOF) reduce 52) ((T_IS_EQUAL) reduce 52) ((T_IS_GREATER_OR_EQUAL) reduce 52) ((T_IS_IDENTICAL) reduce 52) ((T_IS_NOT_EQUAL) reduce 52) ((T_IS_NOT_IDENTICAL) reduce 52) ((T_IS_SMALLER_OR_EQUAL) reduce 52) ((T_LOGICAL_AND) reduce 52) ((T_LOGICAL_OR) reduce 52) ((T_LOGICAL_XOR) reduce 52) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 52) ((T_OBJECT_OPERATOR) reduce 52) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 52) ((T_POW) reduce 52) ((T_SL) reduce 52) ((T_SPACESHIP) reduce 52) ((T_SR) reduce 52) (("[") reduce 52) (("^") reduce 52) (("{") reduce 52) (("|") reduce 52)) 14912 ((("%") reduce 27) (("(") reduce 27) ((")") reduce 27) (("*") reduce 27) (("+") reduce 27) (("-") reduce 27) ((".") reduce 27) (("/") reduce 27) (("<") reduce 27) ((">") reduce 27) (("?") reduce 27) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_BOOLEAN_AND) reduce 27) ((T_BOOLEAN_OR) reduce 27) ((T_COALESCE) reduce 27) ((T_INSTANCEOF) reduce 27) ((T_IS_EQUAL) reduce 27) ((T_IS_GREATER_OR_EQUAL) reduce 27) ((T_IS_IDENTICAL) reduce 27) ((T_IS_NOT_EQUAL) reduce 27) ((T_IS_NOT_IDENTICAL) reduce 27) ((T_IS_SMALLER_OR_EQUAL) reduce 27) ((T_LOGICAL_AND) reduce 27) ((T_LOGICAL_OR) reduce 27) ((T_LOGICAL_XOR) reduce 27) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 27) ((T_OBJECT_OPERATOR) reduce 27) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 27) ((T_POW) reduce 27) ((T_SL) reduce 27) ((T_SPACESHIP) reduce 27) ((T_SR) reduce 27) (("[") reduce 27) (("^") reduce 27) (("{") reduce 27) (("|") reduce 27)) 14913 ((("%") reduce 51) (("(") reduce 51) ((")") reduce 51) (("*") reduce 51) (("+") reduce 51) (("-") reduce 51) ((".") reduce 51) (("/") reduce 51) (("<") reduce 51) ((">") reduce 51) (("?") reduce 51) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_BOOLEAN_AND) reduce 51) ((T_BOOLEAN_OR) reduce 51) ((T_COALESCE) reduce 51) ((T_INSTANCEOF) reduce 51) ((T_IS_EQUAL) reduce 51) ((T_IS_GREATER_OR_EQUAL) reduce 51) ((T_IS_IDENTICAL) reduce 51) ((T_IS_NOT_EQUAL) reduce 51) ((T_IS_NOT_IDENTICAL) reduce 51) ((T_IS_SMALLER_OR_EQUAL) reduce 51) ((T_LOGICAL_AND) reduce 51) ((T_LOGICAL_OR) reduce 51) ((T_LOGICAL_XOR) reduce 51) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 51) ((T_OBJECT_OPERATOR) reduce 51) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 51) ((T_POW) reduce 51) ((T_SL) reduce 51) ((T_SPACESHIP) reduce 51) ((T_SR) reduce 51) (("[") reduce 51) (("^") reduce 51) (("{") reduce 51) (("|") reduce 51)) 14914 ((("%") reduce 53) (("(") reduce 53) ((")") reduce 53) (("*") reduce 53) (("+") reduce 53) (("-") reduce 53) ((".") reduce 53) (("/") reduce 53) (("<") reduce 53) ((">") reduce 53) (("?") reduce 53) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_BOOLEAN_AND) reduce 53) ((T_BOOLEAN_OR) reduce 53) ((T_COALESCE) reduce 53) ((T_INSTANCEOF) reduce 53) ((T_IS_EQUAL) reduce 53) ((T_IS_GREATER_OR_EQUAL) reduce 53) ((T_IS_IDENTICAL) reduce 53) ((T_IS_NOT_EQUAL) reduce 53) ((T_IS_NOT_IDENTICAL) reduce 53) ((T_IS_SMALLER_OR_EQUAL) reduce 53) ((T_LOGICAL_AND) reduce 53) ((T_LOGICAL_OR) reduce 53) ((T_LOGICAL_XOR) reduce 53) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 53) ((T_OBJECT_OPERATOR) reduce 53) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 53) ((T_POW) reduce 53) ((T_SL) reduce 53) ((T_SPACESHIP) reduce 53) ((T_SR) reduce 53) (("[") reduce 53) (("^") reduce 53) (("{") reduce 53) (("|") reduce 53)) 14915 ((("%") reduce 49) (("(") reduce 49) ((")") reduce 49) (("*") reduce 49) (("+") reduce 49) (("-") reduce 49) ((".") reduce 49) (("/") reduce 49) (("<") reduce 49) ((">") reduce 49) (("?") reduce 49) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_BOOLEAN_AND) reduce 49) ((T_BOOLEAN_OR) reduce 49) ((T_COALESCE) reduce 49) ((T_INSTANCEOF) reduce 49) ((T_IS_EQUAL) reduce 49) ((T_IS_GREATER_OR_EQUAL) reduce 49) ((T_IS_IDENTICAL) reduce 49) ((T_IS_NOT_EQUAL) reduce 49) ((T_IS_NOT_IDENTICAL) reduce 49) ((T_IS_SMALLER_OR_EQUAL) reduce 49) ((T_LOGICAL_AND) reduce 49) ((T_LOGICAL_OR) reduce 49) ((T_LOGICAL_XOR) reduce 49) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 49) ((T_OBJECT_OPERATOR) reduce 49) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 49) ((T_POW) reduce 49) ((T_SL) reduce 49) ((T_SPACESHIP) reduce 49) ((T_SR) reduce 49) (("[") reduce 49) (("^") reduce 49) (("{") reduce 49) (("|") reduce 49)) 14916 ((("%") reduce 29) (("(") reduce 29) ((")") reduce 29) (("*") reduce 29) (("+") reduce 29) (("-") reduce 29) ((".") reduce 29) (("/") reduce 29) (("<") reduce 29) ((">") reduce 29) (("?") reduce 29) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_BOOLEAN_AND) reduce 29) ((T_BOOLEAN_OR) reduce 29) ((T_COALESCE) reduce 29) ((T_INSTANCEOF) reduce 29) ((T_IS_EQUAL) reduce 29) ((T_IS_GREATER_OR_EQUAL) reduce 29) ((T_IS_IDENTICAL) reduce 29) ((T_IS_NOT_EQUAL) reduce 29) ((T_IS_NOT_IDENTICAL) reduce 29) ((T_IS_SMALLER_OR_EQUAL) reduce 29) ((T_LOGICAL_AND) reduce 29) ((T_LOGICAL_OR) reduce 29) ((T_LOGICAL_XOR) reduce 29) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 29) ((T_OBJECT_OPERATOR) reduce 29) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 29) ((T_POW) reduce 29) ((T_SL) reduce 29) ((T_SPACESHIP) reduce 29) ((T_SR) reduce 29) (("[") reduce 29) (("^") reduce 29) (("{") reduce 29) (("|") reduce 29)) 14917 ((("%") reduce 59) (("(") reduce 59) ((")") reduce 59) (("*") reduce 59) (("+") reduce 59) (("-") reduce 59) ((".") reduce 59) (("/") reduce 59) (("<") reduce 59) ((">") reduce 59) (("?") reduce 59) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_BOOLEAN_AND) reduce 59) ((T_BOOLEAN_OR) reduce 59) ((T_COALESCE) reduce 59) ((T_INSTANCEOF) reduce 59) ((T_IS_EQUAL) reduce 59) ((T_IS_GREATER_OR_EQUAL) reduce 59) ((T_IS_IDENTICAL) reduce 59) ((T_IS_NOT_EQUAL) reduce 59) ((T_IS_NOT_IDENTICAL) reduce 59) ((T_IS_SMALLER_OR_EQUAL) reduce 59) ((T_LOGICAL_AND) reduce 59) ((T_LOGICAL_OR) reduce 59) ((T_LOGICAL_XOR) reduce 59) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 59) ((T_OBJECT_OPERATOR) reduce 59) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 59) ((T_POW) reduce 59) ((T_SL) reduce 59) ((T_SPACESHIP) reduce 59) ((T_SR) reduce 59) (("[") reduce 59) (("^") reduce 59) (("{") reduce 59) (("|") reduce 59)) 14918 ((("%") reduce 60) (("(") reduce 60) ((")") reduce 60) (("*") reduce 60) (("+") reduce 60) (("-") reduce 60) ((".") reduce 60) (("/") reduce 60) (("<") reduce 60) ((">") reduce 60) (("?") reduce 60) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_BOOLEAN_AND) reduce 60) ((T_BOOLEAN_OR) reduce 60) ((T_COALESCE) reduce 60) ((T_INSTANCEOF) reduce 60) ((T_IS_EQUAL) reduce 60) ((T_IS_GREATER_OR_EQUAL) reduce 60) ((T_IS_IDENTICAL) reduce 60) ((T_IS_NOT_EQUAL) reduce 60) ((T_IS_NOT_IDENTICAL) reduce 60) ((T_IS_SMALLER_OR_EQUAL) reduce 60) ((T_LOGICAL_AND) reduce 60) ((T_LOGICAL_OR) reduce 60) ((T_LOGICAL_XOR) reduce 60) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 60) ((T_OBJECT_OPERATOR) reduce 60) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 60) ((T_POW) reduce 60) ((T_SL) reduce 60) ((T_SPACESHIP) reduce 60) ((T_SR) reduce 60) (("[") reduce 60) (("^") reduce 60) (("{") reduce 60) (("|") reduce 60)) 14919 ((("%") reduce 11) (("(") reduce 11) ((")") reduce 11) (("*") reduce 11) (("+") reduce 11) (("-") reduce 11) ((".") reduce 11) (("/") reduce 11) (("<") reduce 11) ((">") reduce 11) (("?") reduce 11) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_BOOLEAN_AND) reduce 11) ((T_BOOLEAN_OR) reduce 11) ((T_COALESCE) reduce 11) ((T_INSTANCEOF) reduce 11) ((T_IS_EQUAL) reduce 11) ((T_IS_GREATER_OR_EQUAL) reduce 11) ((T_IS_IDENTICAL) reduce 11) ((T_IS_NOT_EQUAL) reduce 11) ((T_IS_NOT_IDENTICAL) reduce 11) ((T_IS_SMALLER_OR_EQUAL) reduce 11) ((T_LOGICAL_AND) reduce 11) ((T_LOGICAL_OR) reduce 11) ((T_LOGICAL_XOR) reduce 11) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 11) ((T_OBJECT_OPERATOR) reduce 11) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 11) ((T_POW) reduce 11) ((T_SL) reduce 11) ((T_SPACESHIP) reduce 11) ((T_SR) reduce 11) (("[") reduce 11) (("^") reduce 11) (("{") reduce 11) (("|") reduce 11)) 14920 ((("%") reduce 42) (("(") reduce 42) ((")") reduce 42) (("*") reduce 42) (("+") reduce 42) (("-") reduce 42) ((".") reduce 42) (("/") reduce 42) (("<") reduce 42) ((">") reduce 42) (("?") reduce 42) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_BOOLEAN_AND) reduce 42) ((T_BOOLEAN_OR) reduce 42) ((T_COALESCE) reduce 42) ((T_INSTANCEOF) reduce 42) ((T_IS_EQUAL) reduce 42) ((T_IS_GREATER_OR_EQUAL) reduce 42) ((T_IS_IDENTICAL) reduce 42) ((T_IS_NOT_EQUAL) reduce 42) ((T_IS_NOT_IDENTICAL) reduce 42) ((T_IS_SMALLER_OR_EQUAL) reduce 42) ((T_LOGICAL_AND) reduce 42) ((T_LOGICAL_OR) reduce 42) ((T_LOGICAL_XOR) reduce 42) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 42) ((T_OBJECT_OPERATOR) reduce 42) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 42) ((T_POW) reduce 42) ((T_SL) reduce 42) ((T_SPACESHIP) reduce 42) ((T_SR) reduce 42) (("[") reduce 42) (("^") reduce 42) (("{") reduce 42) (("|") reduce 42)) 14921 ((("%") reduce 39) (("(") reduce 39) ((")") reduce 39) (("*") reduce 39) (("+") reduce 39) (("-") reduce 39) ((".") reduce 39) (("/") reduce 39) (("<") reduce 39) ((">") reduce 39) (("?") reduce 39) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_BOOLEAN_AND) reduce 39) ((T_BOOLEAN_OR) reduce 39) ((T_COALESCE) reduce 39) ((T_INSTANCEOF) reduce 39) ((T_IS_EQUAL) reduce 39) ((T_IS_GREATER_OR_EQUAL) reduce 39) ((T_IS_IDENTICAL) reduce 39) ((T_IS_NOT_EQUAL) reduce 39) ((T_IS_NOT_IDENTICAL) reduce 39) ((T_IS_SMALLER_OR_EQUAL) reduce 39) ((T_LOGICAL_AND) reduce 39) ((T_LOGICAL_OR) reduce 39) ((T_LOGICAL_XOR) reduce 39) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 39) ((T_OBJECT_OPERATOR) reduce 39) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 39) ((T_POW) reduce 39) ((T_SL) reduce 39) ((T_SPACESHIP) reduce 39) ((T_SR) reduce 39) (("[") reduce 39) (("^") reduce 39) (("{") reduce 39) (("|") reduce 39)) 14922 ((("%") reduce 25) (("(") reduce 25) ((")") reduce 25) (("*") reduce 25) (("+") reduce 25) (("-") reduce 25) ((".") reduce 25) (("/") reduce 25) (("<") reduce 25) ((">") reduce 25) (("?") reduce 25) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_BOOLEAN_AND) reduce 25) ((T_BOOLEAN_OR) reduce 25) ((T_COALESCE) reduce 25) ((T_INSTANCEOF) reduce 25) ((T_IS_EQUAL) reduce 25) ((T_IS_GREATER_OR_EQUAL) reduce 25) ((T_IS_IDENTICAL) reduce 25) ((T_IS_NOT_EQUAL) reduce 25) ((T_IS_NOT_IDENTICAL) reduce 25) ((T_IS_SMALLER_OR_EQUAL) reduce 25) ((T_LOGICAL_AND) reduce 25) ((T_LOGICAL_OR) reduce 25) ((T_LOGICAL_XOR) reduce 25) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 25) ((T_OBJECT_OPERATOR) reduce 25) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 25) ((T_POW) reduce 25) ((T_SL) reduce 25) ((T_SPACESHIP) reduce 25) ((T_SR) reduce 25) (("[") reduce 25) (("^") reduce 25) (("{") reduce 25) (("|") reduce 25)) 14923 ((("%") reduce 50) (("(") reduce 50) ((")") reduce 50) (("*") reduce 50) (("+") reduce 50) (("-") reduce 50) ((".") reduce 50) (("/") reduce 50) (("<") reduce 50) ((">") reduce 50) (("?") reduce 50) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_BOOLEAN_AND) reduce 50) ((T_BOOLEAN_OR) reduce 50) ((T_COALESCE) reduce 50) ((T_INSTANCEOF) reduce 50) ((T_IS_EQUAL) reduce 50) ((T_IS_GREATER_OR_EQUAL) reduce 50) ((T_IS_IDENTICAL) reduce 50) ((T_IS_NOT_EQUAL) reduce 50) ((T_IS_NOT_IDENTICAL) reduce 50) ((T_IS_SMALLER_OR_EQUAL) reduce 50) ((T_LOGICAL_AND) reduce 50) ((T_LOGICAL_OR) reduce 50) ((T_LOGICAL_XOR) reduce 50) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 50) ((T_OBJECT_OPERATOR) reduce 50) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 50) ((T_POW) reduce 50) ((T_SL) reduce 50) ((T_SPACESHIP) reduce 50) ((T_SR) reduce 50) (("[") reduce 50) (("^") reduce 50) (("{") reduce 50) (("|") reduce 50)) 14924 ((("%") reduce 66) (("(") reduce 66) ((")") reduce 66) (("*") reduce 66) (("+") reduce 66) (("-") reduce 66) ((".") reduce 66) (("/") reduce 66) (("<") reduce 66) ((">") reduce 66) (("?") reduce 66) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_BOOLEAN_AND) reduce 66) ((T_BOOLEAN_OR) reduce 66) ((T_COALESCE) reduce 66) ((T_INSTANCEOF) reduce 66) ((T_IS_EQUAL) reduce 66) ((T_IS_GREATER_OR_EQUAL) reduce 66) ((T_IS_IDENTICAL) reduce 66) ((T_IS_NOT_EQUAL) reduce 66) ((T_IS_NOT_IDENTICAL) reduce 66) ((T_IS_SMALLER_OR_EQUAL) reduce 66) ((T_LOGICAL_AND) reduce 66) ((T_LOGICAL_OR) reduce 66) ((T_LOGICAL_XOR) reduce 66) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 66) ((T_OBJECT_OPERATOR) reduce 66) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 66) ((T_POW) reduce 66) ((T_SL) reduce 66) ((T_SPACESHIP) reduce 66) ((T_SR) reduce 66) (("[") reduce 66) (("^") reduce 66) (("{") reduce 66) (("|") reduce 66)) 14925 ((("%") reduce 18) (("(") reduce 18) ((")") reduce 18) (("*") reduce 18) (("+") reduce 18) (("-") reduce 18) ((".") reduce 18) (("/") reduce 18) (("<") reduce 18) ((">") reduce 18) (("?") reduce 18) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_BOOLEAN_AND) reduce 18) ((T_BOOLEAN_OR) reduce 18) ((T_COALESCE) reduce 18) ((T_INSTANCEOF) reduce 18) ((T_IS_EQUAL) reduce 18) ((T_IS_GREATER_OR_EQUAL) reduce 18) ((T_IS_IDENTICAL) reduce 18) ((T_IS_NOT_EQUAL) reduce 18) ((T_IS_NOT_IDENTICAL) reduce 18) ((T_IS_SMALLER_OR_EQUAL) reduce 18) ((T_LOGICAL_AND) reduce 18) ((T_LOGICAL_OR) reduce 18) ((T_LOGICAL_XOR) reduce 18) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 18) ((T_OBJECT_OPERATOR) reduce 18) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 18) ((T_POW) reduce 18) ((T_SL) reduce 18) ((T_SPACESHIP) reduce 18) ((T_SR) reduce 18) (("[") reduce 18) (("^") reduce 18) (("{") reduce 18) (("|") reduce 18)) 14926 ((("%") reduce 17) (("(") reduce 17) ((")") reduce 17) (("*") reduce 17) (("+") reduce 17) (("-") reduce 17) ((".") reduce 17) (("/") reduce 17) (("<") reduce 17) ((">") reduce 17) (("?") reduce 17) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_BOOLEAN_AND) reduce 17) ((T_BOOLEAN_OR) reduce 17) ((T_COALESCE) reduce 17) ((T_INSTANCEOF) reduce 17) ((T_IS_EQUAL) reduce 17) ((T_IS_GREATER_OR_EQUAL) reduce 17) ((T_IS_IDENTICAL) reduce 17) ((T_IS_NOT_EQUAL) reduce 17) ((T_IS_NOT_IDENTICAL) reduce 17) ((T_IS_SMALLER_OR_EQUAL) reduce 17) ((T_LOGICAL_AND) reduce 17) ((T_LOGICAL_OR) reduce 17) ((T_LOGICAL_XOR) reduce 17) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 17) ((T_OBJECT_OPERATOR) reduce 17) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 17) ((T_POW) reduce 17) ((T_SL) reduce 17) ((T_SPACESHIP) reduce 17) ((T_SR) reduce 17) (("[") reduce 17) (("^") reduce 17) (("{") reduce 17) (("|") reduce 17)) 14927 ((("%") reduce 15) (("(") reduce 15) ((")") reduce 15) (("*") reduce 15) (("+") reduce 15) (("-") reduce 15) ((".") reduce 15) (("/") reduce 15) (("<") reduce 15) ((">") reduce 15) (("?") reduce 15) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_BOOLEAN_AND) reduce 15) ((T_BOOLEAN_OR) reduce 15) ((T_COALESCE) reduce 15) ((T_INSTANCEOF) reduce 15) ((T_IS_EQUAL) reduce 15) ((T_IS_GREATER_OR_EQUAL) reduce 15) ((T_IS_IDENTICAL) reduce 15) ((T_IS_NOT_EQUAL) reduce 15) ((T_IS_NOT_IDENTICAL) reduce 15) ((T_IS_SMALLER_OR_EQUAL) reduce 15) ((T_LOGICAL_AND) reduce 15) ((T_LOGICAL_OR) reduce 15) ((T_LOGICAL_XOR) reduce 15) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 15) ((T_OBJECT_OPERATOR) reduce 15) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 15) ((T_POW) reduce 15) ((T_SL) reduce 15) ((T_SPACESHIP) reduce 15) ((T_SR) reduce 15) (("[") reduce 15) (("^") reduce 15) (("{") reduce 15) (("|") reduce 15)) 14928 ((("%") reduce 14) (("(") reduce 14) ((")") reduce 14) (("*") reduce 14) (("+") reduce 14) (("-") reduce 14) ((".") reduce 14) (("/") reduce 14) (("<") reduce 14) ((">") reduce 14) (("?") reduce 14) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_BOOLEAN_AND) reduce 14) ((T_BOOLEAN_OR) reduce 14) ((T_COALESCE) reduce 14) ((T_INSTANCEOF) reduce 14) ((T_IS_EQUAL) reduce 14) ((T_IS_GREATER_OR_EQUAL) reduce 14) ((T_IS_IDENTICAL) reduce 14) ((T_IS_NOT_EQUAL) reduce 14) ((T_IS_NOT_IDENTICAL) reduce 14) ((T_IS_SMALLER_OR_EQUAL) reduce 14) ((T_LOGICAL_AND) reduce 14) ((T_LOGICAL_OR) reduce 14) ((T_LOGICAL_XOR) reduce 14) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 14) ((T_OBJECT_OPERATOR) reduce 14) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 14) ((T_POW) reduce 14) ((T_SL) reduce 14) ((T_SPACESHIP) reduce 14) ((T_SR) reduce 14) (("[") reduce 14) (("^") reduce 14) (("{") reduce 14) (("|") reduce 14)) 14929 ((("%") reduce 38) (("(") reduce 38) ((")") reduce 38) (("*") reduce 38) (("+") reduce 38) (("-") reduce 38) ((".") reduce 38) (("/") reduce 38) (("<") reduce 38) ((">") reduce 38) (("?") reduce 38) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_BOOLEAN_AND) reduce 38) ((T_BOOLEAN_OR) reduce 38) ((T_COALESCE) reduce 38) ((T_INSTANCEOF) reduce 38) ((T_IS_EQUAL) reduce 38) ((T_IS_GREATER_OR_EQUAL) reduce 38) ((T_IS_IDENTICAL) reduce 38) ((T_IS_NOT_EQUAL) reduce 38) ((T_IS_NOT_IDENTICAL) reduce 38) ((T_IS_SMALLER_OR_EQUAL) reduce 38) ((T_LOGICAL_AND) reduce 38) ((T_LOGICAL_OR) reduce 38) ((T_LOGICAL_XOR) reduce 38) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 38) ((T_OBJECT_OPERATOR) reduce 38) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 38) ((T_POW) reduce 38) ((T_SL) reduce 38) ((T_SPACESHIP) reduce 38) ((T_SR) reduce 38) (("[") reduce 38) (("^") reduce 38) (("{") reduce 38) (("|") reduce 38)) 14930 ((("%") reduce 26) (("(") reduce 26) ((")") reduce 26) (("*") reduce 26) (("+") reduce 26) (("-") reduce 26) ((".") reduce 26) (("/") reduce 26) (("<") reduce 26) ((">") reduce 26) (("?") reduce 26) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_BOOLEAN_AND) reduce 26) ((T_BOOLEAN_OR) reduce 26) ((T_COALESCE) reduce 26) ((T_INSTANCEOF) reduce 26) ((T_IS_EQUAL) reduce 26) ((T_IS_GREATER_OR_EQUAL) reduce 26) ((T_IS_IDENTICAL) reduce 26) ((T_IS_NOT_EQUAL) reduce 26) ((T_IS_NOT_IDENTICAL) reduce 26) ((T_IS_SMALLER_OR_EQUAL) reduce 26) ((T_LOGICAL_AND) reduce 26) ((T_LOGICAL_OR) reduce 26) ((T_LOGICAL_XOR) reduce 26) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 26) ((T_OBJECT_OPERATOR) reduce 26) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 26) ((T_POW) reduce 26) ((T_SL) reduce 26) ((T_SPACESHIP) reduce 26) ((T_SR) reduce 26) (("[") reduce 26) (("^") reduce 26) (("{") reduce 26) (("|") reduce 26)) 14931 ((("%") reduce 22) (("(") reduce 22) ((")") reduce 22) (("*") reduce 22) (("+") reduce 22) (("-") reduce 22) ((".") reduce 22) (("/") reduce 22) (("<") reduce 22) ((">") reduce 22) (("?") reduce 22) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_BOOLEAN_AND) reduce 22) ((T_BOOLEAN_OR) reduce 22) ((T_COALESCE) reduce 22) ((T_INSTANCEOF) reduce 22) ((T_IS_EQUAL) reduce 22) ((T_IS_GREATER_OR_EQUAL) reduce 22) ((T_IS_IDENTICAL) reduce 22) ((T_IS_NOT_EQUAL) reduce 22) ((T_IS_NOT_IDENTICAL) reduce 22) ((T_IS_SMALLER_OR_EQUAL) reduce 22) ((T_LOGICAL_AND) reduce 22) ((T_LOGICAL_OR) reduce 22) ((T_LOGICAL_XOR) reduce 22) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 22) ((T_OBJECT_OPERATOR) reduce 22) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 22) ((T_POW) reduce 22) ((T_SL) reduce 22) ((T_SPACESHIP) reduce 22) ((T_SR) reduce 22) (("[") reduce 22) (("^") reduce 22) (("{") reduce 22) (("|") reduce 22)) 14932 ((("%") reduce 24) (("(") reduce 24) ((")") reduce 24) (("*") reduce 24) (("+") reduce 24) (("-") reduce 24) ((".") reduce 24) (("/") reduce 24) (("<") reduce 24) ((">") reduce 24) (("?") reduce 24) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_BOOLEAN_AND) reduce 24) ((T_BOOLEAN_OR) reduce 24) ((T_COALESCE) reduce 24) ((T_INSTANCEOF) reduce 24) ((T_IS_EQUAL) reduce 24) ((T_IS_GREATER_OR_EQUAL) reduce 24) ((T_IS_IDENTICAL) reduce 24) ((T_IS_NOT_EQUAL) reduce 24) ((T_IS_NOT_IDENTICAL) reduce 24) ((T_IS_SMALLER_OR_EQUAL) reduce 24) ((T_LOGICAL_AND) reduce 24) ((T_LOGICAL_OR) reduce 24) ((T_LOGICAL_XOR) reduce 24) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 24) ((T_OBJECT_OPERATOR) reduce 24) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 24) ((T_POW) reduce 24) ((T_SL) reduce 24) ((T_SPACESHIP) reduce 24) ((T_SR) reduce 24) (("[") reduce 24) (("^") reduce 24) (("{") reduce 24) (("|") reduce 24)) 14933 ((("%") reduce 16) (("(") reduce 16) ((")") reduce 16) (("*") reduce 16) (("+") reduce 16) (("-") reduce 16) ((".") reduce 16) (("/") reduce 16) (("<") reduce 16) ((">") reduce 16) (("?") reduce 16) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_BOOLEAN_AND) reduce 16) ((T_BOOLEAN_OR) reduce 16) ((T_COALESCE) reduce 16) ((T_INSTANCEOF) reduce 16) ((T_IS_EQUAL) reduce 16) ((T_IS_GREATER_OR_EQUAL) reduce 16) ((T_IS_IDENTICAL) reduce 16) ((T_IS_NOT_EQUAL) reduce 16) ((T_IS_NOT_IDENTICAL) reduce 16) ((T_IS_SMALLER_OR_EQUAL) reduce 16) ((T_LOGICAL_AND) reduce 16) ((T_LOGICAL_OR) reduce 16) ((T_LOGICAL_XOR) reduce 16) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 16) ((T_OBJECT_OPERATOR) reduce 16) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 16) ((T_POW) reduce 16) ((T_SL) reduce 16) ((T_SPACESHIP) reduce 16) ((T_SR) reduce 16) (("[") reduce 16) (("^") reduce 16) (("{") reduce 16) (("|") reduce 16)) 14934 ((("%") reduce 48) (("(") reduce 48) ((")") reduce 48) (("*") reduce 48) (("+") reduce 48) (("-") reduce 48) ((".") reduce 48) (("/") reduce 48) (("<") reduce 48) ((">") reduce 48) (("?") reduce 48) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_BOOLEAN_AND) reduce 48) ((T_BOOLEAN_OR) reduce 48) ((T_COALESCE) reduce 48) ((T_INSTANCEOF) reduce 48) ((T_IS_EQUAL) reduce 48) ((T_IS_GREATER_OR_EQUAL) reduce 48) ((T_IS_IDENTICAL) reduce 48) ((T_IS_NOT_EQUAL) reduce 48) ((T_IS_NOT_IDENTICAL) reduce 48) ((T_IS_SMALLER_OR_EQUAL) reduce 48) ((T_LOGICAL_AND) reduce 48) ((T_LOGICAL_OR) reduce 48) ((T_LOGICAL_XOR) reduce 48) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 48) ((T_OBJECT_OPERATOR) reduce 48) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 48) ((T_POW) reduce 48) ((T_SL) reduce 48) ((T_SPACESHIP) reduce 48) ((T_SR) reduce 48) (("[") reduce 48) (("^") reduce 48) (("{") reduce 48) (("|") reduce 48)) 14935 ((("%") reduce 20) (("(") reduce 20) ((")") reduce 20) (("*") reduce 20) (("+") reduce 20) (("-") reduce 20) ((".") reduce 20) (("/") reduce 20) (("<") reduce 20) ((">") reduce 20) (("?") reduce 20) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_BOOLEAN_AND) reduce 20) ((T_BOOLEAN_OR) reduce 20) ((T_COALESCE) reduce 20) ((T_INSTANCEOF) reduce 20) ((T_IS_EQUAL) reduce 20) ((T_IS_GREATER_OR_EQUAL) reduce 20) ((T_IS_IDENTICAL) reduce 20) ((T_IS_NOT_EQUAL) reduce 20) ((T_IS_NOT_IDENTICAL) reduce 20) ((T_IS_SMALLER_OR_EQUAL) reduce 20) ((T_LOGICAL_AND) reduce 20) ((T_LOGICAL_OR) reduce 20) ((T_LOGICAL_XOR) reduce 20) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 20) ((T_OBJECT_OPERATOR) reduce 20) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 20) ((T_POW) reduce 20) ((T_SL) reduce 20) ((T_SPACESHIP) reduce 20) ((T_SR) reduce 20) (("[") reduce 20) (("^") reduce 20) (("{") reduce 20) (("|") reduce 20)) 14936 ((("%") reduce 70) (("(") reduce 70) ((")") reduce 70) (("*") reduce 70) (("+") reduce 70) (("-") reduce 70) ((".") reduce 70) (("/") reduce 70) (("<") reduce 70) ((">") reduce 70) (("?") reduce 70) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_BOOLEAN_AND) reduce 70) ((T_BOOLEAN_OR) reduce 70) ((T_COALESCE) reduce 70) ((T_INSTANCEOF) reduce 70) ((T_IS_EQUAL) reduce 70) ((T_IS_GREATER_OR_EQUAL) reduce 70) ((T_IS_IDENTICAL) reduce 70) ((T_IS_NOT_EQUAL) reduce 70) ((T_IS_NOT_IDENTICAL) reduce 70) ((T_IS_SMALLER_OR_EQUAL) reduce 70) ((T_LOGICAL_AND) reduce 70) ((T_LOGICAL_OR) reduce 70) ((T_LOGICAL_XOR) reduce 70) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 70) ((T_OBJECT_OPERATOR) reduce 70) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 70) ((T_POW) reduce 70) ((T_SL) reduce 70) ((T_SPACESHIP) reduce 70) ((T_SR) reduce 70) (("[") reduce 70) (("^") reduce 70) (("{") reduce 70) (("|") reduce 70)) 14937 ((("%") reduce 3) (("(") reduce 3) ((")") reduce 3) (("*") reduce 3) (("+") reduce 3) (("-") reduce 3) ((".") reduce 3) (("/") reduce 3) (("<") reduce 3) ((">") reduce 3) (("?") reduce 3) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_BOOLEAN_AND) reduce 3) ((T_BOOLEAN_OR) reduce 3) ((T_COALESCE) reduce 3) ((T_INSTANCEOF) reduce 3) ((T_IS_EQUAL) reduce 3) ((T_IS_GREATER_OR_EQUAL) reduce 3) ((T_IS_IDENTICAL) reduce 3) ((T_IS_NOT_EQUAL) reduce 3) ((T_IS_NOT_IDENTICAL) reduce 3) ((T_IS_SMALLER_OR_EQUAL) reduce 3) ((T_LOGICAL_AND) reduce 3) ((T_LOGICAL_OR) reduce 3) ((T_LOGICAL_XOR) reduce 3) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 3) ((T_OBJECT_OPERATOR) reduce 3) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 3) ((T_POW) reduce 3) ((T_SL) reduce 3) ((T_SPACESHIP) reduce 3) ((T_SR) reduce 3) (("[") reduce 3) (("^") reduce 3) (("{") reduce 3) (("|") reduce 3)) 14938 ((("%") reduce 12) (("(") reduce 12) ((")") reduce 12) (("*") reduce 12) (("+") reduce 12) (("-") reduce 12) ((".") reduce 12) (("/") reduce 12) (("<") reduce 12) ((">") reduce 12) (("?") reduce 12) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_BOOLEAN_AND) reduce 12) ((T_BOOLEAN_OR) reduce 12) ((T_COALESCE) reduce 12) ((T_INSTANCEOF) reduce 12) ((T_IS_EQUAL) reduce 12) ((T_IS_GREATER_OR_EQUAL) reduce 12) ((T_IS_IDENTICAL) reduce 12) ((T_IS_NOT_EQUAL) reduce 12) ((T_IS_NOT_IDENTICAL) reduce 12) ((T_IS_SMALLER_OR_EQUAL) reduce 12) ((T_LOGICAL_AND) reduce 12) ((T_LOGICAL_OR) reduce 12) ((T_LOGICAL_XOR) reduce 12) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 12) ((T_OBJECT_OPERATOR) reduce 12) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 12) ((T_POW) reduce 12) ((T_SL) reduce 12) ((T_SPACESHIP) reduce 12) ((T_SR) reduce 12) (("[") reduce 12) (("^") reduce 12) (("{") reduce 12) (("|") reduce 12)) 14939 ((("%") reduce 54) (("(") reduce 54) ((")") reduce 54) (("*") reduce 54) (("+") reduce 54) (("-") reduce 54) ((".") reduce 54) (("/") reduce 54) (("<") reduce 54) ((">") reduce 54) (("?") reduce 54) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_BOOLEAN_AND) reduce 54) ((T_BOOLEAN_OR) reduce 54) ((T_COALESCE) reduce 54) ((T_INSTANCEOF) reduce 54) ((T_IS_EQUAL) reduce 54) ((T_IS_GREATER_OR_EQUAL) reduce 54) ((T_IS_IDENTICAL) reduce 54) ((T_IS_NOT_EQUAL) reduce 54) ((T_IS_NOT_IDENTICAL) reduce 54) ((T_IS_SMALLER_OR_EQUAL) reduce 54) ((T_LOGICAL_AND) reduce 54) ((T_LOGICAL_OR) reduce 54) ((T_LOGICAL_XOR) reduce 54) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 54) ((T_OBJECT_OPERATOR) reduce 54) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 54) ((T_POW) reduce 54) ((T_SL) reduce 54) ((T_SPACESHIP) reduce 54) ((T_SR) reduce 54) (("[") reduce 54) (("^") reduce 54) (("{") reduce 54) (("|") reduce 54)) 14940 ((("%") reduce 65) (("(") reduce 65) ((")") reduce 65) (("*") reduce 65) (("+") reduce 65) (("-") reduce 65) ((".") reduce 65) (("/") reduce 65) (("<") reduce 65) ((">") reduce 65) (("?") reduce 65) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_BOOLEAN_AND) reduce 65) ((T_BOOLEAN_OR) reduce 65) ((T_COALESCE) reduce 65) ((T_INSTANCEOF) reduce 65) ((T_IS_EQUAL) reduce 65) ((T_IS_GREATER_OR_EQUAL) reduce 65) ((T_IS_IDENTICAL) reduce 65) ((T_IS_NOT_EQUAL) reduce 65) ((T_IS_NOT_IDENTICAL) reduce 65) ((T_IS_SMALLER_OR_EQUAL) reduce 65) ((T_LOGICAL_AND) reduce 65) ((T_LOGICAL_OR) reduce 65) ((T_LOGICAL_XOR) reduce 65) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 65) ((T_OBJECT_OPERATOR) reduce 65) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 65) ((T_POW) reduce 65) ((T_SL) reduce 65) ((T_SPACESHIP) reduce 65) ((T_SR) reduce 65) (("[") reduce 65) (("^") reduce 65) (("{") reduce 65) (("|") reduce 65)) 14941 ((("%") reduce 74) (("(") reduce 74) ((")") reduce 74) (("*") reduce 74) (("+") reduce 74) (("-") reduce 74) ((".") reduce 74) (("/") reduce 74) (("<") reduce 74) ((">") reduce 74) (("?") reduce 74) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_BOOLEAN_AND) reduce 74) ((T_BOOLEAN_OR) reduce 74) ((T_COALESCE) reduce 74) ((T_INSTANCEOF) reduce 74) ((T_IS_EQUAL) reduce 74) ((T_IS_GREATER_OR_EQUAL) reduce 74) ((T_IS_IDENTICAL) reduce 74) ((T_IS_NOT_EQUAL) reduce 74) ((T_IS_NOT_IDENTICAL) reduce 74) ((T_IS_SMALLER_OR_EQUAL) reduce 74) ((T_LOGICAL_AND) reduce 74) ((T_LOGICAL_OR) reduce 74) ((T_LOGICAL_XOR) reduce 74) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 74) ((T_OBJECT_OPERATOR) reduce 74) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 74) ((T_POW) reduce 74) ((T_SL) reduce 74) ((T_SPACESHIP) reduce 74) ((T_SR) reduce 74) (("[") reduce 74) (("^") reduce 74) (("{") reduce 74) (("|") reduce 74)) 14942 ((("%") reduce 30) (("(") reduce 30) ((")") reduce 30) (("*") reduce 30) (("+") reduce 30) (("-") reduce 30) ((".") reduce 30) (("/") reduce 30) (("<") reduce 30) ((">") reduce 30) (("?") reduce 30) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_BOOLEAN_AND) reduce 30) ((T_BOOLEAN_OR) reduce 30) ((T_COALESCE) reduce 30) ((T_INSTANCEOF) reduce 30) ((T_IS_EQUAL) reduce 30) ((T_IS_GREATER_OR_EQUAL) reduce 30) ((T_IS_IDENTICAL) reduce 30) ((T_IS_NOT_EQUAL) reduce 30) ((T_IS_NOT_IDENTICAL) reduce 30) ((T_IS_SMALLER_OR_EQUAL) reduce 30) ((T_LOGICAL_AND) reduce 30) ((T_LOGICAL_OR) reduce 30) ((T_LOGICAL_XOR) reduce 30) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 30) ((T_OBJECT_OPERATOR) reduce 30) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 30) ((T_POW) reduce 30) ((T_SL) reduce 30) ((T_SPACESHIP) reduce 30) ((T_SR) reduce 30) (("[") reduce 30) (("^") reduce 30) (("{") reduce 30) (("|") reduce 30)) 14943 ((("%") reduce 68) (("(") reduce 68) ((")") reduce 68) (("*") reduce 68) (("+") reduce 68) (("-") reduce 68) ((".") reduce 68) (("/") reduce 68) (("<") reduce 68) ((">") reduce 68) (("?") reduce 68) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_BOOLEAN_AND) reduce 68) ((T_BOOLEAN_OR) reduce 68) ((T_COALESCE) reduce 68) ((T_INSTANCEOF) reduce 68) ((T_IS_EQUAL) reduce 68) ((T_IS_GREATER_OR_EQUAL) reduce 68) ((T_IS_IDENTICAL) reduce 68) ((T_IS_NOT_EQUAL) reduce 68) ((T_IS_NOT_IDENTICAL) reduce 68) ((T_IS_SMALLER_OR_EQUAL) reduce 68) ((T_LOGICAL_AND) reduce 68) ((T_LOGICAL_OR) reduce 68) ((T_LOGICAL_XOR) reduce 68) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 68) ((T_OBJECT_OPERATOR) reduce 68) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 68) ((T_POW) reduce 68) ((T_SL) reduce 68) ((T_SPACESHIP) reduce 68) ((T_SR) reduce 68) (("[") reduce 68) (("^") reduce 68) (("{") reduce 68) (("|") reduce 68)) 14944 ((("%") reduce 21) (("(") reduce 21) ((")") reduce 21) (("*") reduce 21) (("+") reduce 21) (("-") reduce 21) ((".") reduce 21) (("/") reduce 21) (("<") reduce 21) ((">") reduce 21) (("?") reduce 21) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_BOOLEAN_AND) reduce 21) ((T_BOOLEAN_OR) reduce 21) ((T_COALESCE) reduce 21) ((T_INSTANCEOF) reduce 21) ((T_IS_EQUAL) reduce 21) ((T_IS_GREATER_OR_EQUAL) reduce 21) ((T_IS_IDENTICAL) reduce 21) ((T_IS_NOT_EQUAL) reduce 21) ((T_IS_NOT_IDENTICAL) reduce 21) ((T_IS_SMALLER_OR_EQUAL) reduce 21) ((T_LOGICAL_AND) reduce 21) ((T_LOGICAL_OR) reduce 21) ((T_LOGICAL_XOR) reduce 21) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 21) ((T_OBJECT_OPERATOR) reduce 21) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 21) ((T_POW) reduce 21) ((T_SL) reduce 21) ((T_SPACESHIP) reduce 21) ((T_SR) reduce 21) (("[") reduce 21) (("^") reduce 21) (("{") reduce 21) (("|") reduce 21)) 14945 ((("%") reduce 23) (("(") reduce 23) ((")") reduce 23) (("*") reduce 23) (("+") reduce 23) (("-") reduce 23) ((".") reduce 23) (("/") reduce 23) (("<") reduce 23) ((">") reduce 23) (("?") reduce 23) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_BOOLEAN_AND) reduce 23) ((T_BOOLEAN_OR) reduce 23) ((T_COALESCE) reduce 23) ((T_INSTANCEOF) reduce 23) ((T_IS_EQUAL) reduce 23) ((T_IS_GREATER_OR_EQUAL) reduce 23) ((T_IS_IDENTICAL) reduce 23) ((T_IS_NOT_EQUAL) reduce 23) ((T_IS_NOT_IDENTICAL) reduce 23) ((T_IS_SMALLER_OR_EQUAL) reduce 23) ((T_LOGICAL_AND) reduce 23) ((T_LOGICAL_OR) reduce 23) ((T_LOGICAL_XOR) reduce 23) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 23) ((T_OBJECT_OPERATOR) reduce 23) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 23) ((T_POW) reduce 23) ((T_SL) reduce 23) ((T_SPACESHIP) reduce 23) ((T_SR) reduce 23) (("[") reduce 23) (("^") reduce 23) (("{") reduce 23) (("|") reduce 23)) 14946 ((("%") reduce 41) (("(") reduce 41) ((")") reduce 41) (("*") reduce 41) (("+") reduce 41) (("-") reduce 41) ((".") reduce 41) (("/") reduce 41) (("<") reduce 41) ((">") reduce 41) (("?") reduce 41) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_BOOLEAN_AND) reduce 41) ((T_BOOLEAN_OR) reduce 41) ((T_COALESCE) reduce 41) ((T_INSTANCEOF) reduce 41) ((T_IS_EQUAL) reduce 41) ((T_IS_GREATER_OR_EQUAL) reduce 41) ((T_IS_IDENTICAL) reduce 41) ((T_IS_NOT_EQUAL) reduce 41) ((T_IS_NOT_IDENTICAL) reduce 41) ((T_IS_SMALLER_OR_EQUAL) reduce 41) ((T_LOGICAL_AND) reduce 41) ((T_LOGICAL_OR) reduce 41) ((T_LOGICAL_XOR) reduce 41) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 41) ((T_OBJECT_OPERATOR) reduce 41) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 41) ((T_POW) reduce 41) ((T_SL) reduce 41) ((T_SPACESHIP) reduce 41) ((T_SR) reduce 41) (("[") reduce 41) (("^") reduce 41) (("{") reduce 41) (("|") reduce 41)) 14947 ((("%") reduce 62) (("(") reduce 62) ((")") reduce 62) (("*") reduce 62) (("+") reduce 62) (("-") reduce 62) ((".") reduce 62) (("/") reduce 62) (("<") reduce 62) ((">") reduce 62) (("?") reduce 62) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_BOOLEAN_AND) reduce 62) ((T_BOOLEAN_OR) reduce 62) ((T_COALESCE) reduce 62) ((T_INSTANCEOF) reduce 62) ((T_IS_EQUAL) reduce 62) ((T_IS_GREATER_OR_EQUAL) reduce 62) ((T_IS_IDENTICAL) reduce 62) ((T_IS_NOT_EQUAL) reduce 62) ((T_IS_NOT_IDENTICAL) reduce 62) ((T_IS_SMALLER_OR_EQUAL) reduce 62) ((T_LOGICAL_AND) reduce 62) ((T_LOGICAL_OR) reduce 62) ((T_LOGICAL_XOR) reduce 62) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 62) ((T_OBJECT_OPERATOR) reduce 62) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 62) ((T_POW) reduce 62) ((T_SL) reduce 62) ((T_SPACESHIP) reduce 62) ((T_SR) reduce 62) (("[") reduce 62) (("^") reduce 62) (("{") reduce 62) (("|") reduce 62)) 14948 ((("%") reduce 34) (("(") reduce 34) ((")") reduce 34) (("*") reduce 34) (("+") reduce 34) (("-") reduce 34) ((".") reduce 34) (("/") reduce 34) (("<") reduce 34) ((">") reduce 34) (("?") reduce 34) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_BOOLEAN_AND) reduce 34) ((T_BOOLEAN_OR) reduce 34) ((T_COALESCE) reduce 34) ((T_INSTANCEOF) reduce 34) ((T_IS_EQUAL) reduce 34) ((T_IS_GREATER_OR_EQUAL) reduce 34) ((T_IS_IDENTICAL) reduce 34) ((T_IS_NOT_EQUAL) reduce 34) ((T_IS_NOT_IDENTICAL) reduce 34) ((T_IS_SMALLER_OR_EQUAL) reduce 34) ((T_LOGICAL_AND) reduce 34) ((T_LOGICAL_OR) reduce 34) ((T_LOGICAL_XOR) reduce 34) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 34) ((T_OBJECT_OPERATOR) reduce 34) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 34) ((T_POW) reduce 34) ((T_SL) reduce 34) ((T_SPACESHIP) reduce 34) ((T_SR) reduce 34) (("[") reduce 34) (("^") reduce 34) (("{") reduce 34) (("|") reduce 34)) 14949 ((("%") reduce 40) (("(") reduce 40) ((")") reduce 40) (("*") reduce 40) (("+") reduce 40) (("-") reduce 40) ((".") reduce 40) (("/") reduce 40) (("<") reduce 40) ((">") reduce 40) (("?") reduce 40) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_BOOLEAN_AND) reduce 40) ((T_BOOLEAN_OR) reduce 40) ((T_COALESCE) reduce 40) ((T_INSTANCEOF) reduce 40) ((T_IS_EQUAL) reduce 40) ((T_IS_GREATER_OR_EQUAL) reduce 40) ((T_IS_IDENTICAL) reduce 40) ((T_IS_NOT_EQUAL) reduce 40) ((T_IS_NOT_IDENTICAL) reduce 40) ((T_IS_SMALLER_OR_EQUAL) reduce 40) ((T_LOGICAL_AND) reduce 40) ((T_LOGICAL_OR) reduce 40) ((T_LOGICAL_XOR) reduce 40) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 40) ((T_OBJECT_OPERATOR) reduce 40) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 40) ((T_POW) reduce 40) ((T_SL) reduce 40) ((T_SPACESHIP) reduce 40) ((T_SR) reduce 40) (("[") reduce 40) (("^") reduce 40) (("{") reduce 40) (("|") reduce 40)) 14950 ((("%") reduce 13) (("(") reduce 13) ((")") reduce 13) (("*") reduce 13) (("+") reduce 13) (("-") reduce 13) ((".") reduce 13) (("/") reduce 13) (("<") reduce 13) ((">") reduce 13) (("?") reduce 13) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_BOOLEAN_AND) reduce 13) ((T_BOOLEAN_OR) reduce 13) ((T_COALESCE) reduce 13) ((T_INSTANCEOF) reduce 13) ((T_IS_EQUAL) reduce 13) ((T_IS_GREATER_OR_EQUAL) reduce 13) ((T_IS_IDENTICAL) reduce 13) ((T_IS_NOT_EQUAL) reduce 13) ((T_IS_NOT_IDENTICAL) reduce 13) ((T_IS_SMALLER_OR_EQUAL) reduce 13) ((T_LOGICAL_AND) reduce 13) ((T_LOGICAL_OR) reduce 13) ((T_LOGICAL_XOR) reduce 13) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 13) ((T_OBJECT_OPERATOR) reduce 13) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 13) ((T_POW) reduce 13) ((T_SL) reduce 13) ((T_SPACESHIP) reduce 13) ((T_SR) reduce 13) (("[") reduce 13) (("^") reduce 13) (("{") reduce 13) (("|") reduce 13)) 14951 ((("%") reduce 55) (("(") reduce 55) ((")") reduce 55) (("*") reduce 55) (("+") reduce 55) (("-") reduce 55) ((".") reduce 55) (("/") reduce 55) (("<") reduce 55) ((">") reduce 55) (("?") reduce 55) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_BOOLEAN_AND) reduce 55) ((T_BOOLEAN_OR) reduce 55) ((T_COALESCE) reduce 55) ((T_INSTANCEOF) reduce 55) ((T_IS_EQUAL) reduce 55) ((T_IS_GREATER_OR_EQUAL) reduce 55) ((T_IS_IDENTICAL) reduce 55) ((T_IS_NOT_EQUAL) reduce 55) ((T_IS_NOT_IDENTICAL) reduce 55) ((T_IS_SMALLER_OR_EQUAL) reduce 55) ((T_LOGICAL_AND) reduce 55) ((T_LOGICAL_OR) reduce 55) ((T_LOGICAL_XOR) reduce 55) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 55) ((T_OBJECT_OPERATOR) reduce 55) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 55) ((T_POW) reduce 55) ((T_SL) reduce 55) ((T_SPACESHIP) reduce 55) ((T_SR) reduce 55) (("[") reduce 55) (("^") reduce 55) (("{") reduce 55) (("|") reduce 55)) 14952 ((("%") reduce 1) (("(") reduce 1) ((")") reduce 1) (("*") reduce 1) (("+") reduce 1) (("-") reduce 1) ((".") reduce 1) (("/") reduce 1) (("<") reduce 1) ((">") reduce 1) (("?") reduce 1) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_BOOLEAN_AND) reduce 1) ((T_BOOLEAN_OR) reduce 1) ((T_COALESCE) reduce 1) ((T_INSTANCEOF) reduce 1) ((T_IS_EQUAL) reduce 1) ((T_IS_GREATER_OR_EQUAL) reduce 1) ((T_IS_IDENTICAL) reduce 1) ((T_IS_NOT_EQUAL) reduce 1) ((T_IS_NOT_IDENTICAL) reduce 1) ((T_IS_SMALLER_OR_EQUAL) reduce 1) ((T_LOGICAL_AND) reduce 1) ((T_LOGICAL_OR) reduce 1) ((T_LOGICAL_XOR) reduce 1) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 1) ((T_OBJECT_OPERATOR) reduce 1) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 1) ((T_POW) reduce 1) ((T_SL) reduce 1) ((T_SPACESHIP) reduce 1) ((T_SR) reduce 1) (("[") reduce 1) (("^") reduce 1) (("{") reduce 1) (("|") reduce 1)) 14953 ((("%") reduce 2) (("(") reduce 2) ((")") reduce 2) (("*") reduce 2) (("+") reduce 2) (("-") reduce 2) ((".") reduce 2) (("/") reduce 2) (("<") reduce 2) ((">") reduce 2) (("?") reduce 2) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_BOOLEAN_AND) reduce 2) ((T_BOOLEAN_OR) reduce 2) ((T_COALESCE) reduce 2) ((T_INSTANCEOF) reduce 2) ((T_IS_EQUAL) reduce 2) ((T_IS_GREATER_OR_EQUAL) reduce 2) ((T_IS_IDENTICAL) reduce 2) ((T_IS_NOT_EQUAL) reduce 2) ((T_IS_NOT_IDENTICAL) reduce 2) ((T_IS_SMALLER_OR_EQUAL) reduce 2) ((T_LOGICAL_AND) reduce 2) ((T_LOGICAL_OR) reduce 2) ((T_LOGICAL_XOR) reduce 2) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 2) ((T_OBJECT_OPERATOR) reduce 2) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 2) ((T_POW) reduce 2) ((T_SL) reduce 2) ((T_SPACESHIP) reduce 2) ((T_SR) reduce 2) (("[") reduce 2) (("^") reduce 2) (("{") reduce 2) (("|") reduce 2)) 14954 ((("%") reduce 9) (("(") reduce 9) ((")") reduce 9) (("*") reduce 9) (("+") reduce 9) (("-") reduce 9) ((".") reduce 9) (("/") reduce 9) (("<") reduce 9) ((">") reduce 9) (("?") reduce 9) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_BOOLEAN_AND) reduce 9) ((T_BOOLEAN_OR) reduce 9) ((T_COALESCE) reduce 9) ((T_INSTANCEOF) reduce 9) ((T_IS_EQUAL) reduce 9) ((T_IS_GREATER_OR_EQUAL) reduce 9) ((T_IS_IDENTICAL) reduce 9) ((T_IS_NOT_EQUAL) reduce 9) ((T_IS_NOT_IDENTICAL) reduce 9) ((T_IS_SMALLER_OR_EQUAL) reduce 9) ((T_LOGICAL_AND) reduce 9) ((T_LOGICAL_OR) reduce 9) ((T_LOGICAL_XOR) reduce 9) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 9) ((T_OBJECT_OPERATOR) reduce 9) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 9) ((T_POW) reduce 9) ((T_SL) reduce 9) ((T_SPACESHIP) reduce 9) ((T_SR) reduce 9) (("[") reduce 9) (("^") reduce 9) (("{") reduce 9) (("|") reduce 9)) 14955 ((("%") reduce 33) (("(") reduce 33) ((")") reduce 33) (("*") reduce 33) (("+") reduce 33) (("-") reduce 33) ((".") reduce 33) (("/") reduce 33) (("<") reduce 33) ((">") reduce 33) (("?") reduce 33) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_BOOLEAN_AND) reduce 33) ((T_BOOLEAN_OR) reduce 33) ((T_COALESCE) reduce 33) ((T_INSTANCEOF) reduce 33) ((T_IS_EQUAL) reduce 33) ((T_IS_GREATER_OR_EQUAL) reduce 33) ((T_IS_IDENTICAL) reduce 33) ((T_IS_NOT_EQUAL) reduce 33) ((T_IS_NOT_IDENTICAL) reduce 33) ((T_IS_SMALLER_OR_EQUAL) reduce 33) ((T_LOGICAL_AND) reduce 33) ((T_LOGICAL_OR) reduce 33) ((T_LOGICAL_XOR) reduce 33) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 33) ((T_OBJECT_OPERATOR) reduce 33) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 33) ((T_POW) reduce 33) ((T_SL) reduce 33) ((T_SPACESHIP) reduce 33) ((T_SR) reduce 33) (("[") reduce 33) (("^") reduce 33) (("{") reduce 33) (("|") reduce 33)) 14956 ((("%") reduce 58) (("(") reduce 58) ((")") reduce 58) (("*") reduce 58) (("+") reduce 58) (("-") reduce 58) ((".") reduce 58) (("/") reduce 58) (("<") reduce 58) ((">") reduce 58) (("?") reduce 58) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_BOOLEAN_AND) reduce 58) ((T_BOOLEAN_OR) reduce 58) ((T_COALESCE) reduce 58) ((T_INSTANCEOF) reduce 58) ((T_IS_EQUAL) reduce 58) ((T_IS_GREATER_OR_EQUAL) reduce 58) ((T_IS_IDENTICAL) reduce 58) ((T_IS_NOT_EQUAL) reduce 58) ((T_IS_NOT_IDENTICAL) reduce 58) ((T_IS_SMALLER_OR_EQUAL) reduce 58) ((T_LOGICAL_AND) reduce 58) ((T_LOGICAL_OR) reduce 58) ((T_LOGICAL_XOR) reduce 58) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 58) ((T_OBJECT_OPERATOR) reduce 58) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 58) ((T_POW) reduce 58) ((T_SL) reduce 58) ((T_SPACESHIP) reduce 58) ((T_SR) reduce 58) (("[") reduce 58) (("^") reduce 58) (("{") reduce 58) (("|") reduce 58)) 14957 ((("%") reduce 37) (("(") reduce 37) ((")") reduce 37) (("*") reduce 37) (("+") reduce 37) (("-") reduce 37) ((".") reduce 37) (("/") reduce 37) (("<") reduce 37) ((">") reduce 37) (("?") reduce 37) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_BOOLEAN_AND) reduce 37) ((T_BOOLEAN_OR) reduce 37) ((T_COALESCE) reduce 37) ((T_INSTANCEOF) reduce 37) ((T_IS_EQUAL) reduce 37) ((T_IS_GREATER_OR_EQUAL) reduce 37) ((T_IS_IDENTICAL) reduce 37) ((T_IS_NOT_EQUAL) reduce 37) ((T_IS_NOT_IDENTICAL) reduce 37) ((T_IS_SMALLER_OR_EQUAL) reduce 37) ((T_LOGICAL_AND) reduce 37) ((T_LOGICAL_OR) reduce 37) ((T_LOGICAL_XOR) reduce 37) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 37) ((T_OBJECT_OPERATOR) reduce 37) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 37) ((T_POW) reduce 37) ((T_SL) reduce 37) ((T_SPACESHIP) reduce 37) ((T_SR) reduce 37) (("[") reduce 37) (("^") reduce 37) (("{") reduce 37) (("|") reduce 37)) 14958 ((("%") reduce 64) (("(") reduce 64) ((")") reduce 64) (("*") reduce 64) (("+") reduce 64) (("-") reduce 64) ((".") reduce 64) (("/") reduce 64) (("<") reduce 64) ((">") reduce 64) (("?") reduce 64) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_BOOLEAN_AND) reduce 64) ((T_BOOLEAN_OR) reduce 64) ((T_COALESCE) reduce 64) ((T_INSTANCEOF) reduce 64) ((T_IS_EQUAL) reduce 64) ((T_IS_GREATER_OR_EQUAL) reduce 64) ((T_IS_IDENTICAL) reduce 64) ((T_IS_NOT_EQUAL) reduce 64) ((T_IS_NOT_IDENTICAL) reduce 64) ((T_IS_SMALLER_OR_EQUAL) reduce 64) ((T_LOGICAL_AND) reduce 64) ((T_LOGICAL_OR) reduce 64) ((T_LOGICAL_XOR) reduce 64) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 64) ((T_OBJECT_OPERATOR) reduce 64) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 64) ((T_POW) reduce 64) ((T_SL) reduce 64) ((T_SPACESHIP) reduce 64) ((T_SR) reduce 64) (("[") reduce 64) (("^") reduce 64) (("{") reduce 64) (("|") reduce 64)) 14959 ((("%") reduce 46) (("(") reduce 46) ((")") reduce 46) (("*") reduce 46) (("+") reduce 46) (("-") reduce 46) ((".") reduce 46) (("/") reduce 46) (("<") reduce 46) ((">") reduce 46) (("?") reduce 46) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_BOOLEAN_AND) reduce 46) ((T_BOOLEAN_OR) reduce 46) ((T_COALESCE) reduce 46) ((T_INSTANCEOF) reduce 46) ((T_IS_EQUAL) reduce 46) ((T_IS_GREATER_OR_EQUAL) reduce 46) ((T_IS_IDENTICAL) reduce 46) ((T_IS_NOT_EQUAL) reduce 46) ((T_IS_NOT_IDENTICAL) reduce 46) ((T_IS_SMALLER_OR_EQUAL) reduce 46) ((T_LOGICAL_AND) reduce 46) ((T_LOGICAL_OR) reduce 46) ((T_LOGICAL_XOR) reduce 46) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 46) ((T_OBJECT_OPERATOR) reduce 46) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 46) ((T_POW) reduce 46) ((T_SL) reduce 46) ((T_SPACESHIP) reduce 46) ((T_SR) reduce 46) (("[") reduce 46) (("^") reduce 46) (("{") reduce 46) (("|") reduce 46)) 14960 ((("%") reduce 8) (("(") reduce 8) ((")") reduce 8) (("*") reduce 8) (("+") reduce 8) (("-") reduce 8) ((".") reduce 8) (("/") reduce 8) (("<") reduce 8) ((">") reduce 8) (("?") reduce 8) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_BOOLEAN_AND) reduce 8) ((T_BOOLEAN_OR) reduce 8) ((T_COALESCE) reduce 8) ((T_INSTANCEOF) reduce 8) ((T_IS_EQUAL) reduce 8) ((T_IS_GREATER_OR_EQUAL) reduce 8) ((T_IS_IDENTICAL) reduce 8) ((T_IS_NOT_EQUAL) reduce 8) ((T_IS_NOT_IDENTICAL) reduce 8) ((T_IS_SMALLER_OR_EQUAL) reduce 8) ((T_LOGICAL_AND) reduce 8) ((T_LOGICAL_OR) reduce 8) ((T_LOGICAL_XOR) reduce 8) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 8) ((T_OBJECT_OPERATOR) reduce 8) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 8) ((T_POW) reduce 8) ((T_SL) reduce 8) ((T_SPACESHIP) reduce 8) ((T_SR) reduce 8) (("[") reduce 8) (("^") reduce 8) (("{") reduce 8) (("|") reduce 8)) 14961 ((("%") reduce 6) (("(") reduce 6) ((")") reduce 6) (("*") reduce 6) (("+") reduce 6) (("-") reduce 6) ((".") reduce 6) (("/") reduce 6) (("<") reduce 6) ((">") reduce 6) (("?") reduce 6) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_BOOLEAN_AND) reduce 6) ((T_BOOLEAN_OR) reduce 6) ((T_COALESCE) reduce 6) ((T_INSTANCEOF) reduce 6) ((T_IS_EQUAL) reduce 6) ((T_IS_GREATER_OR_EQUAL) reduce 6) ((T_IS_IDENTICAL) reduce 6) ((T_IS_NOT_EQUAL) reduce 6) ((T_IS_NOT_IDENTICAL) reduce 6) ((T_IS_SMALLER_OR_EQUAL) reduce 6) ((T_LOGICAL_AND) reduce 6) ((T_LOGICAL_OR) reduce 6) ((T_LOGICAL_XOR) reduce 6) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 6) ((T_OBJECT_OPERATOR) reduce 6) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 6) ((T_POW) reduce 6) ((T_SL) reduce 6) ((T_SPACESHIP) reduce 6) ((T_SR) reduce 6) (("[") reduce 6) (("^") reduce 6) (("{") reduce 6) (("|") reduce 6)) 14962 ((("%") reduce 7) (("(") reduce 7) ((")") reduce 7) (("*") reduce 7) (("+") reduce 7) (("-") reduce 7) ((".") reduce 7) (("/") reduce 7) (("<") reduce 7) ((">") reduce 7) (("?") reduce 7) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_BOOLEAN_AND) reduce 7) ((T_BOOLEAN_OR) reduce 7) ((T_COALESCE) reduce 7) ((T_INSTANCEOF) reduce 7) ((T_IS_EQUAL) reduce 7) ((T_IS_GREATER_OR_EQUAL) reduce 7) ((T_IS_IDENTICAL) reduce 7) ((T_IS_NOT_EQUAL) reduce 7) ((T_IS_NOT_IDENTICAL) reduce 7) ((T_IS_SMALLER_OR_EQUAL) reduce 7) ((T_LOGICAL_AND) reduce 7) ((T_LOGICAL_OR) reduce 7) ((T_LOGICAL_XOR) reduce 7) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 7) ((T_OBJECT_OPERATOR) reduce 7) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 7) ((T_POW) reduce 7) ((T_SL) reduce 7) ((T_SPACESHIP) reduce 7) ((T_SR) reduce 7) (("[") reduce 7) (("^") reduce 7) (("{") reduce 7) (("|") reduce 7)) 14963 ((("%") reduce 69) (("(") reduce 69) ((")") reduce 69) (("*") reduce 69) (("+") reduce 69) (("-") reduce 69) ((".") reduce 69) (("/") reduce 69) (("<") reduce 69) ((">") reduce 69) (("?") reduce 69) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_BOOLEAN_AND) reduce 69) ((T_BOOLEAN_OR) reduce 69) ((T_COALESCE) reduce 69) ((T_INSTANCEOF) reduce 69) ((T_IS_EQUAL) reduce 69) ((T_IS_GREATER_OR_EQUAL) reduce 69) ((T_IS_IDENTICAL) reduce 69) ((T_IS_NOT_EQUAL) reduce 69) ((T_IS_NOT_IDENTICAL) reduce 69) ((T_IS_SMALLER_OR_EQUAL) reduce 69) ((T_LOGICAL_AND) reduce 69) ((T_LOGICAL_OR) reduce 69) ((T_LOGICAL_XOR) reduce 69) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 69) ((T_OBJECT_OPERATOR) reduce 69) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 69) ((T_POW) reduce 69) ((T_SL) reduce 69) ((T_SPACESHIP) reduce 69) ((T_SR) reduce 69) (("[") reduce 69) (("^") reduce 69) (("{") reduce 69) (("|") reduce 69)) 14964 ((("%") reduce 63) (("(") reduce 63) ((")") reduce 63) (("*") reduce 63) (("+") reduce 63) (("-") reduce 63) ((".") reduce 63) (("/") reduce 63) (("<") reduce 63) ((">") reduce 63) (("?") reduce 63) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_BOOLEAN_AND) reduce 63) ((T_BOOLEAN_OR) reduce 63) ((T_COALESCE) reduce 63) ((T_INSTANCEOF) reduce 63) ((T_IS_EQUAL) reduce 63) ((T_IS_GREATER_OR_EQUAL) reduce 63) ((T_IS_IDENTICAL) reduce 63) ((T_IS_NOT_EQUAL) reduce 63) ((T_IS_NOT_IDENTICAL) reduce 63) ((T_IS_SMALLER_OR_EQUAL) reduce 63) ((T_LOGICAL_AND) reduce 63) ((T_LOGICAL_OR) reduce 63) ((T_LOGICAL_XOR) reduce 63) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 63) ((T_OBJECT_OPERATOR) reduce 63) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 63) ((T_POW) reduce 63) ((T_SL) reduce 63) ((T_SPACESHIP) reduce 63) ((T_SR) reduce 63) (("[") reduce 63) (("^") reduce 63) (("{") reduce 63) (("|") reduce 63)) 14965 ((("%") reduce 56) (("(") reduce 56) ((")") reduce 56) (("*") reduce 56) (("+") reduce 56) (("-") reduce 56) ((".") reduce 56) (("/") reduce 56) (("<") reduce 56) ((">") reduce 56) (("?") reduce 56) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_BOOLEAN_AND) reduce 56) ((T_BOOLEAN_OR) reduce 56) ((T_COALESCE) reduce 56) ((T_INSTANCEOF) reduce 56) ((T_IS_EQUAL) reduce 56) ((T_IS_GREATER_OR_EQUAL) reduce 56) ((T_IS_IDENTICAL) reduce 56) ((T_IS_NOT_EQUAL) reduce 56) ((T_IS_NOT_IDENTICAL) reduce 56) ((T_IS_SMALLER_OR_EQUAL) reduce 56) ((T_LOGICAL_AND) reduce 56) ((T_LOGICAL_OR) reduce 56) ((T_LOGICAL_XOR) reduce 56) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 56) ((T_OBJECT_OPERATOR) reduce 56) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 56) ((T_POW) reduce 56) ((T_SL) reduce 56) ((T_SPACESHIP) reduce 56) ((T_SR) reduce 56) (("[") reduce 56) (("^") reduce 56) (("{") reduce 56) (("|") reduce 56)) 14966 ((("%") reduce 10) (("(") reduce 10) ((")") reduce 10) (("*") reduce 10) (("+") reduce 10) (("-") reduce 10) ((".") reduce 10) (("/") reduce 10) (("<") reduce 10) ((">") reduce 10) (("?") reduce 10) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_BOOLEAN_AND) reduce 10) ((T_BOOLEAN_OR) reduce 10) ((T_COALESCE) reduce 10) ((T_INSTANCEOF) reduce 10) ((T_IS_EQUAL) reduce 10) ((T_IS_GREATER_OR_EQUAL) reduce 10) ((T_IS_IDENTICAL) reduce 10) ((T_IS_NOT_EQUAL) reduce 10) ((T_IS_NOT_IDENTICAL) reduce 10) ((T_IS_SMALLER_OR_EQUAL) reduce 10) ((T_LOGICAL_AND) reduce 10) ((T_LOGICAL_OR) reduce 10) ((T_LOGICAL_XOR) reduce 10) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 10) ((T_OBJECT_OPERATOR) reduce 10) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 10) ((T_POW) reduce 10) ((T_SL) reduce 10) ((T_SPACESHIP) reduce 10) ((T_SR) reduce 10) (("[") reduce 10) (("^") reduce 10) (("{") reduce 10) (("|") reduce 10)) 14967 ((("%") reduce 67) (("(") reduce 67) ((")") reduce 67) (("*") reduce 67) (("+") reduce 67) (("-") reduce 67) ((".") reduce 67) (("/") reduce 67) (("<") reduce 67) ((">") reduce 67) (("?") reduce 67) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_BOOLEAN_AND) reduce 67) ((T_BOOLEAN_OR) reduce 67) ((T_COALESCE) reduce 67) ((T_INSTANCEOF) reduce 67) ((T_IS_EQUAL) reduce 67) ((T_IS_GREATER_OR_EQUAL) reduce 67) ((T_IS_IDENTICAL) reduce 67) ((T_IS_NOT_EQUAL) reduce 67) ((T_IS_NOT_IDENTICAL) reduce 67) ((T_IS_SMALLER_OR_EQUAL) reduce 67) ((T_LOGICAL_AND) reduce 67) ((T_LOGICAL_OR) reduce 67) ((T_LOGICAL_XOR) reduce 67) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 67) ((T_OBJECT_OPERATOR) reduce 67) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 67) ((T_POW) reduce 67) ((T_SL) reduce 67) ((T_SPACESHIP) reduce 67) ((T_SR) reduce 67) (("[") reduce 67) (("^") reduce 67) (("{") reduce 67) (("|") reduce 67)) 14968 ((("%") reduce 44) (("(") reduce 44) ((")") reduce 44) (("*") reduce 44) (("+") reduce 44) (("-") reduce 44) ((".") reduce 44) (("/") reduce 44) (("<") reduce 44) ((">") reduce 44) (("?") reduce 44) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_BOOLEAN_AND) reduce 44) ((T_BOOLEAN_OR) reduce 44) ((T_COALESCE) reduce 44) ((T_INSTANCEOF) reduce 44) ((T_IS_EQUAL) reduce 44) ((T_IS_GREATER_OR_EQUAL) reduce 44) ((T_IS_IDENTICAL) reduce 44) ((T_IS_NOT_EQUAL) reduce 44) ((T_IS_NOT_IDENTICAL) reduce 44) ((T_IS_SMALLER_OR_EQUAL) reduce 44) ((T_LOGICAL_AND) reduce 44) ((T_LOGICAL_OR) reduce 44) ((T_LOGICAL_XOR) reduce 44) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 44) ((T_OBJECT_OPERATOR) reduce 44) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 44) ((T_POW) reduce 44) ((T_SL) reduce 44) ((T_SPACESHIP) reduce 44) ((T_SR) reduce 44) (("[") reduce 44) (("^") reduce 44) (("{") reduce 44) (("|") reduce 44)) 14969 ((("%") reduce 75) (("(") reduce 75) ((")") reduce 75) (("*") reduce 75) (("+") reduce 75) (("-") reduce 75) ((".") reduce 75) (("/") reduce 75) (("<") reduce 75) ((">") reduce 75) (("?") reduce 75) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_BOOLEAN_AND) reduce 75) ((T_BOOLEAN_OR) reduce 75) ((T_COALESCE) reduce 75) ((T_INSTANCEOF) reduce 75) ((T_IS_EQUAL) reduce 75) ((T_IS_GREATER_OR_EQUAL) reduce 75) ((T_IS_IDENTICAL) reduce 75) ((T_IS_NOT_EQUAL) reduce 75) ((T_IS_NOT_IDENTICAL) reduce 75) ((T_IS_SMALLER_OR_EQUAL) reduce 75) ((T_LOGICAL_AND) reduce 75) ((T_LOGICAL_OR) reduce 75) ((T_LOGICAL_XOR) reduce 75) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 75) ((T_OBJECT_OPERATOR) reduce 75) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 75) ((T_POW) reduce 75) ((T_SL) reduce 75) ((T_SPACESHIP) reduce 75) ((T_SR) reduce 75) (("[") reduce 75) (("^") reduce 75) (("{") reduce 75) (("|") reduce 75)) 14970 ((("%") reduce 76) (("(") reduce 76) ((")") reduce 76) (("*") reduce 76) (("+") reduce 76) (("-") reduce 76) ((".") reduce 76) (("/") reduce 76) (("<") reduce 76) ((">") reduce 76) (("?") reduce 76) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_BOOLEAN_AND) reduce 76) ((T_BOOLEAN_OR) reduce 76) ((T_COALESCE) reduce 76) ((T_INSTANCEOF) reduce 76) ((T_IS_EQUAL) reduce 76) ((T_IS_GREATER_OR_EQUAL) reduce 76) ((T_IS_IDENTICAL) reduce 76) ((T_IS_NOT_EQUAL) reduce 76) ((T_IS_NOT_IDENTICAL) reduce 76) ((T_IS_SMALLER_OR_EQUAL) reduce 76) ((T_LOGICAL_AND) reduce 76) ((T_LOGICAL_OR) reduce 76) ((T_LOGICAL_XOR) reduce 76) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 76) ((T_OBJECT_OPERATOR) reduce 76) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 76) ((T_POW) reduce 76) ((T_SL) reduce 76) ((T_SPACESHIP) reduce 76) ((T_SR) reduce 76) (("[") reduce 76) (("^") reduce 76) (("{") reduce 76) (("|") reduce 76)) 14971 ((("%") reduce 77) (("(") reduce 77) ((")") reduce 77) (("*") reduce 77) (("+") reduce 77) (("-") reduce 77) ((".") reduce 77) (("/") reduce 77) (("<") reduce 77) ((">") reduce 77) (("?") reduce 77) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_BOOLEAN_AND) reduce 77) ((T_BOOLEAN_OR) reduce 77) ((T_COALESCE) reduce 77) ((T_INSTANCEOF) reduce 77) ((T_IS_EQUAL) reduce 77) ((T_IS_GREATER_OR_EQUAL) reduce 77) ((T_IS_IDENTICAL) reduce 77) ((T_IS_NOT_EQUAL) reduce 77) ((T_IS_NOT_IDENTICAL) reduce 77) ((T_IS_SMALLER_OR_EQUAL) reduce 77) ((T_LOGICAL_AND) reduce 77) ((T_LOGICAL_OR) reduce 77) ((T_LOGICAL_XOR) reduce 77) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 77) ((T_OBJECT_OPERATOR) reduce 77) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 77) ((T_POW) reduce 77) ((T_SL) reduce 77) ((T_SPACESHIP) reduce 77) ((T_SR) reduce 77) (("[") reduce 77) (("^") reduce 77) (("{") reduce 77) (("|") reduce 77)) 14972 ((("%") reduce 78) (("(") reduce 78) ((")") reduce 78) (("*") reduce 78) (("+") reduce 78) (("-") reduce 78) ((".") reduce 78) (("/") reduce 78) (("<") reduce 78) ((">") reduce 78) (("?") reduce 78) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_BOOLEAN_AND) reduce 78) ((T_BOOLEAN_OR) reduce 78) ((T_COALESCE) reduce 78) ((T_INSTANCEOF) reduce 78) ((T_IS_EQUAL) reduce 78) ((T_IS_GREATER_OR_EQUAL) reduce 78) ((T_IS_IDENTICAL) reduce 78) ((T_IS_NOT_EQUAL) reduce 78) ((T_IS_NOT_IDENTICAL) reduce 78) ((T_IS_SMALLER_OR_EQUAL) reduce 78) ((T_LOGICAL_AND) reduce 78) ((T_LOGICAL_OR) reduce 78) ((T_LOGICAL_XOR) reduce 78) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 78) ((T_OBJECT_OPERATOR) reduce 78) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 78) ((T_POW) reduce 78) ((T_SL) reduce 78) ((T_SPACESHIP) reduce 78) ((T_SR) reduce 78) (("[") reduce 78) (("^") reduce 78) (("{") reduce 78) (("|") reduce 78)) 14973 ((("%") reduce 4) (("(") reduce 4) ((")") reduce 4) (("*") reduce 4) (("+") reduce 4) (("-") reduce 4) ((".") reduce 4) (("/") reduce 4) (("<") reduce 4) ((">") reduce 4) (("?") reduce 4) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_BOOLEAN_AND) reduce 4) ((T_BOOLEAN_OR) reduce 4) ((T_COALESCE) reduce 4) ((T_INSTANCEOF) reduce 4) ((T_IS_EQUAL) reduce 4) ((T_IS_GREATER_OR_EQUAL) reduce 4) ((T_IS_IDENTICAL) reduce 4) ((T_IS_NOT_EQUAL) reduce 4) ((T_IS_NOT_IDENTICAL) reduce 4) ((T_IS_SMALLER_OR_EQUAL) reduce 4) ((T_LOGICAL_AND) reduce 4) ((T_LOGICAL_OR) reduce 4) ((T_LOGICAL_XOR) reduce 4) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 4) ((T_OBJECT_OPERATOR) reduce 4) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 4) ((T_POW) reduce 4) ((T_SL) reduce 4) ((T_SPACESHIP) reduce 4) ((T_SR) reduce 4) (("[") reduce 4) (("^") reduce 4) (("{") reduce 4) (("|") reduce 4)) 14974 ((("%") reduce 5) (("(") reduce 5) ((")") reduce 5) (("*") reduce 5) (("+") reduce 5) (("-") reduce 5) ((".") reduce 5) (("/") reduce 5) (("<") reduce 5) ((">") reduce 5) (("?") reduce 5) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_BOOLEAN_AND) reduce 5) ((T_BOOLEAN_OR) reduce 5) ((T_COALESCE) reduce 5) ((T_INSTANCEOF) reduce 5) ((T_IS_EQUAL) reduce 5) ((T_IS_GREATER_OR_EQUAL) reduce 5) ((T_IS_IDENTICAL) reduce 5) ((T_IS_NOT_EQUAL) reduce 5) ((T_IS_NOT_IDENTICAL) reduce 5) ((T_IS_SMALLER_OR_EQUAL) reduce 5) ((T_LOGICAL_AND) reduce 5) ((T_LOGICAL_OR) reduce 5) ((T_LOGICAL_XOR) reduce 5) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 5) ((T_OBJECT_OPERATOR) reduce 5) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 5) ((T_POW) reduce 5) ((T_SL) reduce 5) ((T_SPACESHIP) reduce 5) ((T_SR) reduce 5) (("[") reduce 5) (("^") reduce 5) (("{") reduce 5) (("|") reduce 5)) 14975 ((("%") reduce 43) (("(") reduce 43) ((")") reduce 43) (("*") reduce 43) (("+") reduce 43) (("-") reduce 43) ((".") reduce 43) (("/") reduce 43) (("<") reduce 43) ((">") reduce 43) (("?") reduce 43) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_BOOLEAN_AND) reduce 43) ((T_BOOLEAN_OR) reduce 43) ((T_COALESCE) reduce 43) ((T_INSTANCEOF) reduce 43) ((T_IS_EQUAL) reduce 43) ((T_IS_GREATER_OR_EQUAL) reduce 43) ((T_IS_IDENTICAL) reduce 43) ((T_IS_NOT_EQUAL) reduce 43) ((T_IS_NOT_IDENTICAL) reduce 43) ((T_IS_SMALLER_OR_EQUAL) reduce 43) ((T_LOGICAL_AND) reduce 43) ((T_LOGICAL_OR) reduce 43) ((T_LOGICAL_XOR) reduce 43) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 43) ((T_OBJECT_OPERATOR) reduce 43) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 43) ((T_POW) reduce 43) ((T_SL) reduce 43) ((T_SPACESHIP) reduce 43) ((T_SR) reduce 43) (("[") reduce 43) (("^") reduce 43) (("{") reduce 43) (("|") reduce 43)) 14976 ((("%") reduce 72) (("(") reduce 72) ((")") reduce 72) (("*") reduce 72) (("+") reduce 72) (("-") reduce 72) ((".") reduce 72) (("/") reduce 72) (("<") reduce 72) ((">") reduce 72) (("?") reduce 72) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_BOOLEAN_AND) reduce 72) ((T_BOOLEAN_OR) reduce 72) ((T_COALESCE) reduce 72) ((T_INSTANCEOF) reduce 72) ((T_IS_EQUAL) reduce 72) ((T_IS_GREATER_OR_EQUAL) reduce 72) ((T_IS_IDENTICAL) reduce 72) ((T_IS_NOT_EQUAL) reduce 72) ((T_IS_NOT_IDENTICAL) reduce 72) ((T_IS_SMALLER_OR_EQUAL) reduce 72) ((T_LOGICAL_AND) reduce 72) ((T_LOGICAL_OR) reduce 72) ((T_LOGICAL_XOR) reduce 72) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 72) ((T_OBJECT_OPERATOR) reduce 72) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 72) ((T_POW) reduce 72) ((T_SL) reduce 72) ((T_SPACESHIP) reduce 72) ((T_SR) reduce 72) (("[") reduce 72) (("^") reduce 72) (("{") reduce 72) (("|") reduce 72)) 14977 ((("%") reduce 81) (("(") reduce 81) ((")") reduce 81) (("*") reduce 81) (("+") reduce 81) (("-") reduce 81) ((".") reduce 81) (("/") reduce 81) (("<") reduce 81) ((">") reduce 81) (("?") reduce 81) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_BOOLEAN_AND) reduce 81) ((T_BOOLEAN_OR) reduce 81) ((T_COALESCE) reduce 81) ((T_INSTANCEOF) reduce 81) ((T_IS_EQUAL) reduce 81) ((T_IS_GREATER_OR_EQUAL) reduce 81) ((T_IS_IDENTICAL) reduce 81) ((T_IS_NOT_EQUAL) reduce 81) ((T_IS_NOT_IDENTICAL) reduce 81) ((T_IS_SMALLER_OR_EQUAL) reduce 81) ((T_LOGICAL_AND) reduce 81) ((T_LOGICAL_OR) reduce 81) ((T_LOGICAL_XOR) reduce 81) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 81) ((T_OBJECT_OPERATOR) reduce 81) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 81) ((T_POW) reduce 81) ((T_SL) reduce 81) ((T_SPACESHIP) reduce 81) ((T_SR) reduce 81) (("[") reduce 81) (("^") reduce 81) (("{") reduce 81) (("|") reduce 81)) 14978 ((("%") reduce 47) (("(") reduce 47) ((")") reduce 47) (("*") reduce 47) (("+") reduce 47) (("-") reduce 47) ((".") reduce 47) (("/") reduce 47) (("<") reduce 47) ((">") reduce 47) (("?") reduce 47) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_BOOLEAN_AND) reduce 47) ((T_BOOLEAN_OR) reduce 47) ((T_COALESCE) reduce 47) ((T_INSTANCEOF) reduce 47) ((T_IS_EQUAL) reduce 47) ((T_IS_GREATER_OR_EQUAL) reduce 47) ((T_IS_IDENTICAL) reduce 47) ((T_IS_NOT_EQUAL) reduce 47) ((T_IS_NOT_IDENTICAL) reduce 47) ((T_IS_SMALLER_OR_EQUAL) reduce 47) ((T_LOGICAL_AND) reduce 47) ((T_LOGICAL_OR) reduce 47) ((T_LOGICAL_XOR) reduce 47) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 47) ((T_OBJECT_OPERATOR) reduce 47) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 47) ((T_POW) reduce 47) ((T_SL) reduce 47) ((T_SPACESHIP) reduce 47) ((T_SR) reduce 47) (("[") reduce 47) (("^") reduce 47) (("{") reduce 47) (("|") reduce 47)) 14979 ((("%") reduce 31) (("(") reduce 31) ((")") reduce 31) (("*") reduce 31) (("+") reduce 31) (("-") reduce 31) ((".") reduce 31) (("/") reduce 31) (("<") reduce 31) ((">") reduce 31) (("?") reduce 31) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_BOOLEAN_AND) reduce 31) ((T_BOOLEAN_OR) reduce 31) ((T_COALESCE) reduce 31) ((T_INSTANCEOF) reduce 31) ((T_IS_EQUAL) reduce 31) ((T_IS_GREATER_OR_EQUAL) reduce 31) ((T_IS_IDENTICAL) reduce 31) ((T_IS_NOT_EQUAL) reduce 31) ((T_IS_NOT_IDENTICAL) reduce 31) ((T_IS_SMALLER_OR_EQUAL) reduce 31) ((T_LOGICAL_AND) reduce 31) ((T_LOGICAL_OR) reduce 31) ((T_LOGICAL_XOR) reduce 31) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 31) ((T_OBJECT_OPERATOR) reduce 31) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 31) ((T_POW) reduce 31) ((T_SL) reduce 31) ((T_SPACESHIP) reduce 31) ((T_SR) reduce 31) (("[") reduce 31) (("^") reduce 31) (("{") reduce 31) (("|") reduce 31)) 14980 ((("%") reduce 57) (("(") reduce 57) ((")") reduce 57) (("*") reduce 57) (("+") reduce 57) (("-") reduce 57) ((".") reduce 57) (("/") reduce 57) (("<") reduce 57) ((">") reduce 57) (("?") reduce 57) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_BOOLEAN_AND) reduce 57) ((T_BOOLEAN_OR) reduce 57) ((T_COALESCE) reduce 57) ((T_INSTANCEOF) reduce 57) ((T_IS_EQUAL) reduce 57) ((T_IS_GREATER_OR_EQUAL) reduce 57) ((T_IS_IDENTICAL) reduce 57) ((T_IS_NOT_EQUAL) reduce 57) ((T_IS_NOT_IDENTICAL) reduce 57) ((T_IS_SMALLER_OR_EQUAL) reduce 57) ((T_LOGICAL_AND) reduce 57) ((T_LOGICAL_OR) reduce 57) ((T_LOGICAL_XOR) reduce 57) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 57) ((T_OBJECT_OPERATOR) reduce 57) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 57) ((T_POW) reduce 57) ((T_SL) reduce 57) ((T_SPACESHIP) reduce 57) ((T_SR) reduce 57) (("[") reduce 57) (("^") reduce 57) (("{") reduce 57) (("|") reduce 57)) 14981 ((("%") reduce 61) (("(") reduce 61) ((")") reduce 61) (("*") reduce 61) (("+") reduce 61) (("-") reduce 61) ((".") reduce 61) (("/") reduce 61) (("<") reduce 61) ((">") reduce 61) (("?") reduce 61) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_BOOLEAN_AND) reduce 61) ((T_BOOLEAN_OR) reduce 61) ((T_COALESCE) reduce 61) ((T_INSTANCEOF) reduce 61) ((T_IS_EQUAL) reduce 61) ((T_IS_GREATER_OR_EQUAL) reduce 61) ((T_IS_IDENTICAL) reduce 61) ((T_IS_NOT_EQUAL) reduce 61) ((T_IS_NOT_IDENTICAL) reduce 61) ((T_IS_SMALLER_OR_EQUAL) reduce 61) ((T_LOGICAL_AND) reduce 61) ((T_LOGICAL_OR) reduce 61) ((T_LOGICAL_XOR) reduce 61) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 61) ((T_OBJECT_OPERATOR) reduce 61) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 61) ((T_POW) reduce 61) ((T_SL) reduce 61) ((T_SPACESHIP) reduce 61) ((T_SR) reduce 61) (("[") reduce 61) (("^") reduce 61) (("{") reduce 61) (("|") reduce 61)) 14982 ((("%") reduce 28) (("(") reduce 28) ((")") reduce 28) (("*") reduce 28) (("+") reduce 28) (("-") reduce 28) ((".") reduce 28) (("/") reduce 28) (("<") reduce 28) ((">") reduce 28) (("?") reduce 28) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_BOOLEAN_AND) reduce 28) ((T_BOOLEAN_OR) reduce 28) ((T_COALESCE) reduce 28) ((T_INSTANCEOF) reduce 28) ((T_IS_EQUAL) reduce 28) ((T_IS_GREATER_OR_EQUAL) reduce 28) ((T_IS_IDENTICAL) reduce 28) ((T_IS_NOT_EQUAL) reduce 28) ((T_IS_NOT_IDENTICAL) reduce 28) ((T_IS_SMALLER_OR_EQUAL) reduce 28) ((T_LOGICAL_AND) reduce 28) ((T_LOGICAL_OR) reduce 28) ((T_LOGICAL_XOR) reduce 28) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 28) ((T_OBJECT_OPERATOR) reduce 28) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 28) ((T_POW) reduce 28) ((T_SL) reduce 28) ((T_SPACESHIP) reduce 28) ((T_SR) reduce 28) (("[") reduce 28) (("^") reduce 28) (("{") reduce 28) (("|") reduce 28)) 14983 ((("%") reduce 36) (("(") reduce 36) ((")") reduce 36) (("*") reduce 36) (("+") reduce 36) (("-") reduce 36) ((".") reduce 36) (("/") reduce 36) (("<") reduce 36) ((">") reduce 36) (("?") reduce 36) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_BOOLEAN_AND) reduce 36) ((T_BOOLEAN_OR) reduce 36) ((T_COALESCE) reduce 36) ((T_INSTANCEOF) reduce 36) ((T_IS_EQUAL) reduce 36) ((T_IS_GREATER_OR_EQUAL) reduce 36) ((T_IS_IDENTICAL) reduce 36) ((T_IS_NOT_EQUAL) reduce 36) ((T_IS_NOT_IDENTICAL) reduce 36) ((T_IS_SMALLER_OR_EQUAL) reduce 36) ((T_LOGICAL_AND) reduce 36) ((T_LOGICAL_OR) reduce 36) ((T_LOGICAL_XOR) reduce 36) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 36) ((T_OBJECT_OPERATOR) reduce 36) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 36) ((T_POW) reduce 36) ((T_SL) reduce 36) ((T_SPACESHIP) reduce 36) ((T_SR) reduce 36) (("[") reduce 36) (("^") reduce 36) (("{") reduce 36) (("|") reduce 36)) 14984 ((("%") reduce 32) (("(") reduce 32) ((")") reduce 32) (("*") reduce 32) (("+") reduce 32) (("-") reduce 32) ((".") reduce 32) (("/") reduce 32) (("<") reduce 32) ((">") reduce 32) (("?") reduce 32) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_BOOLEAN_AND) reduce 32) ((T_BOOLEAN_OR) reduce 32) ((T_COALESCE) reduce 32) ((T_INSTANCEOF) reduce 32) ((T_IS_EQUAL) reduce 32) ((T_IS_GREATER_OR_EQUAL) reduce 32) ((T_IS_IDENTICAL) reduce 32) ((T_IS_NOT_EQUAL) reduce 32) ((T_IS_NOT_IDENTICAL) reduce 32) ((T_IS_SMALLER_OR_EQUAL) reduce 32) ((T_LOGICAL_AND) reduce 32) ((T_LOGICAL_OR) reduce 32) ((T_LOGICAL_XOR) reduce 32) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 32) ((T_OBJECT_OPERATOR) reduce 32) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 32) ((T_POW) reduce 32) ((T_SL) reduce 32) ((T_SPACESHIP) reduce 32) ((T_SR) reduce 32) (("[") reduce 32) (("^") reduce 32) (("{") reduce 32) (("|") reduce 32)) 14985 ((("%") reduce 35) (("(") reduce 35) ((")") reduce 35) (("*") reduce 35) (("+") reduce 35) (("-") reduce 35) ((".") reduce 35) (("/") reduce 35) (("<") reduce 35) ((">") reduce 35) (("?") reduce 35) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_BOOLEAN_AND) reduce 35) ((T_BOOLEAN_OR) reduce 35) ((T_COALESCE) reduce 35) ((T_INSTANCEOF) reduce 35) ((T_IS_EQUAL) reduce 35) ((T_IS_GREATER_OR_EQUAL) reduce 35) ((T_IS_IDENTICAL) reduce 35) ((T_IS_NOT_EQUAL) reduce 35) ((T_IS_NOT_IDENTICAL) reduce 35) ((T_IS_SMALLER_OR_EQUAL) reduce 35) ((T_LOGICAL_AND) reduce 35) ((T_LOGICAL_OR) reduce 35) ((T_LOGICAL_XOR) reduce 35) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 35) ((T_OBJECT_OPERATOR) reduce 35) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 35) ((T_POW) reduce 35) ((T_SL) reduce 35) ((T_SPACESHIP) reduce 35) ((T_SR) reduce 35) (("[") reduce 35) (("^") reduce 35) (("{") reduce 35) (("|") reduce 35)) 14986 ((("%") reduce 19) (("(") reduce 19) ((")") reduce 19) (("*") reduce 19) (("+") reduce 19) (("-") reduce 19) ((".") reduce 19) (("/") reduce 19) (("<") reduce 19) ((">") reduce 19) (("?") reduce 19) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_BOOLEAN_AND) reduce 19) ((T_BOOLEAN_OR) reduce 19) ((T_COALESCE) reduce 19) ((T_INSTANCEOF) reduce 19) ((T_IS_EQUAL) reduce 19) ((T_IS_GREATER_OR_EQUAL) reduce 19) ((T_IS_IDENTICAL) reduce 19) ((T_IS_NOT_EQUAL) reduce 19) ((T_IS_NOT_IDENTICAL) reduce 19) ((T_IS_SMALLER_OR_EQUAL) reduce 19) ((T_LOGICAL_AND) reduce 19) ((T_LOGICAL_OR) reduce 19) ((T_LOGICAL_XOR) reduce 19) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 19) ((T_OBJECT_OPERATOR) reduce 19) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 19) ((T_POW) reduce 19) ((T_SL) reduce 19) ((T_SPACESHIP) reduce 19) ((T_SR) reduce 19) (("[") reduce 19) (("^") reduce 19) (("{") reduce 19) (("|") reduce 19)) 14987 ((("%") reduce 45) (("(") reduce 45) ((")") reduce 45) (("*") reduce 45) (("+") reduce 45) (("-") reduce 45) ((".") reduce 45) (("/") reduce 45) (("<") reduce 45) ((">") reduce 45) (("?") reduce 45) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_BOOLEAN_AND) reduce 45) ((T_BOOLEAN_OR) reduce 45) ((T_COALESCE) reduce 45) ((T_INSTANCEOF) reduce 45) ((T_IS_EQUAL) reduce 45) ((T_IS_GREATER_OR_EQUAL) reduce 45) ((T_IS_IDENTICAL) reduce 45) ((T_IS_NOT_EQUAL) reduce 45) ((T_IS_NOT_IDENTICAL) reduce 45) ((T_IS_SMALLER_OR_EQUAL) reduce 45) ((T_LOGICAL_AND) reduce 45) ((T_LOGICAL_OR) reduce 45) ((T_LOGICAL_XOR) reduce 45) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 45) ((T_OBJECT_OPERATOR) reduce 45) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 45) ((T_POW) reduce 45) ((T_SL) reduce 45) ((T_SPACESHIP) reduce 45) ((T_SR) reduce 45) (("[") reduce 45) (("^") reduce 45) (("{") reduce 45) (("|") reduce 45)) 14988 ((("%") reduce 504) (("(") reduce 541) ((")") reduce 504) (("*") reduce 504) (("+") reduce 504) (("-") reduce 504) ((".") reduce 504) (("/") reduce 504) (("<") reduce 504) ((">") reduce 504) (("?") reduce 504) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_BOOLEAN_AND) reduce 504) ((T_BOOLEAN_OR) reduce 504) ((T_COALESCE) reduce 504) ((T_INSTANCEOF) reduce 504) ((T_IS_EQUAL) reduce 504) ((T_IS_GREATER_OR_EQUAL) reduce 504) ((T_IS_IDENTICAL) reduce 504) ((T_IS_NOT_EQUAL) reduce 504) ((T_IS_NOT_IDENTICAL) reduce 504) ((T_IS_SMALLER_OR_EQUAL) reduce 504) ((T_LOGICAL_AND) reduce 504) ((T_LOGICAL_OR) reduce 504) ((T_LOGICAL_XOR) reduce 504) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 504) ((T_OBJECT_OPERATOR) reduce 504) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 504) ((T_POW) reduce 504) ((T_SL) reduce 504) ((T_SPACESHIP) reduce 504) ((T_SR) reduce 504) (("[") reduce 504) (("^") reduce 504) (("{") reduce 504) (("|") reduce 504)) 14990 ((("%") reduce 71) (("(") reduce 71) ((")") reduce 71) (("*") reduce 71) (("+") reduce 71) (("-") reduce 71) ((".") reduce 71) (("/") reduce 71) (("<") reduce 71) ((">") reduce 71) (("?") reduce 71) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_BOOLEAN_AND) reduce 71) ((T_BOOLEAN_OR) reduce 71) ((T_COALESCE) reduce 71) ((T_INSTANCEOF) reduce 71) ((T_IS_EQUAL) reduce 71) ((T_IS_GREATER_OR_EQUAL) reduce 71) ((T_IS_IDENTICAL) reduce 71) ((T_IS_NOT_EQUAL) reduce 71) ((T_IS_NOT_IDENTICAL) reduce 71) ((T_IS_SMALLER_OR_EQUAL) reduce 71) ((T_LOGICAL_AND) reduce 71) ((T_LOGICAL_OR) reduce 71) ((T_LOGICAL_XOR) reduce 71) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 71) ((T_OBJECT_OPERATOR) reduce 71) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 71) ((T_POW) reduce 71) ((T_SL) reduce 71) ((T_SPACESHIP) reduce 71) ((T_SR) reduce 71) (("[") reduce 71) (("^") reduce 71) (("{") reduce 71) (("|") reduce 71)) 14991 ((("%") reduce 82) (("(") reduce 82) ((")") reduce 82) (("*") reduce 82) (("+") reduce 82) (("-") reduce 82) ((".") reduce 82) (("/") reduce 82) (("<") reduce 82) ((">") reduce 82) (("?") reduce 82) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_BOOLEAN_AND) reduce 82) ((T_BOOLEAN_OR) reduce 82) ((T_COALESCE) reduce 82) ((T_INSTANCEOF) reduce 82) ((T_IS_EQUAL) reduce 82) ((T_IS_GREATER_OR_EQUAL) reduce 82) ((T_IS_IDENTICAL) reduce 82) ((T_IS_NOT_EQUAL) reduce 82) ((T_IS_NOT_IDENTICAL) reduce 82) ((T_IS_SMALLER_OR_EQUAL) reduce 82) ((T_LOGICAL_AND) reduce 82) ((T_LOGICAL_OR) reduce 82) ((T_LOGICAL_XOR) reduce 82) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 82) ((T_OBJECT_OPERATOR) reduce 82) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 82) ((T_POW) reduce 82) ((T_SL) reduce 82) ((T_SPACESHIP) reduce 82) ((T_SR) reduce 82) (("[") reduce 82) (("^") reduce 82) (("{") reduce 82) (("|") reduce 82)) 14992 ((("%") reduce 533) (("(") reduce 543) ((")") reduce 533) (("*") reduce 533) (("+") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) (("<") reduce 533) (("=") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AND_EQUAL) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_COALESCE_EQUAL) reduce 533) ((T_CONCAT_EQUAL) reduce 533) ((T_DEC) reduce 533) ((T_DIV_EQUAL) reduce 533) ((T_INC) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_MINUS_EQUAL) reduce 533) ((T_MOD_EQUAL) reduce 533) ((T_MUL_EQUAL) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_OR_EQUAL) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_PLUS_EQUAL) reduce 533) ((T_POW) reduce 533) ((T_POW_EQUAL) reduce 533) ((T_SL) reduce 533) ((T_SL_EQUAL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) ((T_SR_EQUAL) reduce 533) ((T_XOR_EQUAL) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 14995 ((("%") reduce 506) (("(") reduce 542) ((")") reduce 506) (("*") reduce 506) (("+") reduce 506) (("-") reduce 506) ((".") reduce 506) (("/") reduce 506) (("<") reduce 506) ((">") reduce 506) (("?") reduce 506) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_BOOLEAN_AND) reduce 506) ((T_BOOLEAN_OR) reduce 506) ((T_COALESCE) reduce 506) ((T_INSTANCEOF) reduce 506) ((T_IS_EQUAL) reduce 506) ((T_IS_GREATER_OR_EQUAL) reduce 506) ((T_IS_IDENTICAL) reduce 506) ((T_IS_NOT_EQUAL) reduce 506) ((T_IS_NOT_IDENTICAL) reduce 506) ((T_IS_SMALLER_OR_EQUAL) reduce 506) ((T_LOGICAL_AND) reduce 506) ((T_LOGICAL_OR) reduce 506) ((T_LOGICAL_XOR) reduce 506) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 506) ((T_OBJECT_OPERATOR) reduce 506) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 506) ((T_POW) reduce 506) ((T_SL) reduce 506) ((T_SPACESHIP) reduce 506) ((T_SR) reduce 506) (("[") reduce 506) (("^") reduce 506) (("{") reduce 506) (("|") reduce 506)) 14997 ((("%") reduce 468) (("(") reduce 468) ((")") reduce 468) (("*") reduce 468) (("+") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) (("<") reduce 468) (("=") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AND_EQUAL) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_COALESCE_EQUAL) reduce 468) ((T_CONCAT_EQUAL) reduce 468) ((T_DEC) reduce 468) ((T_DIV_EQUAL) reduce 468) ((T_INC) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_MINUS_EQUAL) reduce 468) ((T_MOD_EQUAL) reduce 468) ((T_MUL_EQUAL) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_OR_EQUAL) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_PLUS_EQUAL) reduce 468) ((T_POW) reduce 468) ((T_POW_EQUAL) reduce 468) ((T_SL) reduce 468) ((T_SL_EQUAL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) ((T_SR_EQUAL) reduce 468) ((T_XOR_EQUAL) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 14998 ((("%") reduce 288) (("(") reduce 288) ((")") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) (("=") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AND_EQUAL) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_COALESCE_EQUAL) reduce 288) ((T_CONCAT_EQUAL) reduce 288) ((T_DEC) reduce 288) ((T_DIV_EQUAL) reduce 288) ((T_INC) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_MINUS_EQUAL) reduce 288) ((T_MOD_EQUAL) reduce 288) ((T_MUL_EQUAL) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_OR_EQUAL) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_PLUS_EQUAL) reduce 288) ((T_POW) reduce 288) ((T_POW_EQUAL) reduce 288) ((T_SL) reduce 288) ((T_SL_EQUAL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) ((T_SR_EQUAL) reduce 288) ((T_XOR_EQUAL) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 15002 ((("%") reduce 289) (("(") reduce 289) ((")") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) (("=") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AND_EQUAL) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_COALESCE_EQUAL) reduce 289) ((T_CONCAT_EQUAL) reduce 289) ((T_DEC) reduce 289) ((T_DIV_EQUAL) reduce 289) ((T_INC) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_MINUS_EQUAL) reduce 289) ((T_MOD_EQUAL) reduce 289) ((T_MUL_EQUAL) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_OR_EQUAL) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_PLUS_EQUAL) reduce 289) ((T_POW) reduce 289) ((T_POW_EQUAL) reduce 289) ((T_SL) reduce 289) ((T_SL_EQUAL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) ((T_SR_EQUAL) reduce 289) ((T_XOR_EQUAL) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 15003 ((("%") reduce 290) (("(") reduce 290) ((")") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) (("=") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AND_EQUAL) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_COALESCE_EQUAL) reduce 290) ((T_CONCAT_EQUAL) reduce 290) ((T_DEC) reduce 290) ((T_DIV_EQUAL) reduce 290) ((T_INC) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_MINUS_EQUAL) reduce 290) ((T_MOD_EQUAL) reduce 290) ((T_MUL_EQUAL) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_OR_EQUAL) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_PLUS_EQUAL) reduce 290) ((T_POW) reduce 290) ((T_POW_EQUAL) reduce 290) ((T_SL) reduce 290) ((T_SL_EQUAL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) ((T_SR_EQUAL) reduce 290) ((T_XOR_EQUAL) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 15008 ((("%") reduce 388) ((")") reduce 388) (("*") reduce 388) (("+") reduce 388) (("-") reduce 388) ((".") reduce 388) (("/") reduce 388) (("<") reduce 388) ((">") reduce 388) (("?") reduce 388) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_BOOLEAN_AND) reduce 388) ((T_BOOLEAN_OR) reduce 388) ((T_COALESCE) reduce 388) ((T_INSTANCEOF) reduce 388) ((T_IS_EQUAL) reduce 388) ((T_IS_GREATER_OR_EQUAL) reduce 388) ((T_IS_IDENTICAL) reduce 388) ((T_IS_NOT_EQUAL) reduce 388) ((T_IS_NOT_IDENTICAL) reduce 388) ((T_IS_SMALLER_OR_EQUAL) reduce 388) ((T_LOGICAL_AND) reduce 388) ((T_LOGICAL_OR) reduce 388) ((T_LOGICAL_XOR) reduce 388) ((T_POW) reduce 388) ((T_SL) reduce 388) ((T_SPACESHIP) reduce 388) ((T_SR) reduce 388) (("^") reduce 388) (("|") reduce 388)) 15010 ((("%") reduce 386) ((")") reduce 386) (("*") reduce 386) (("+") reduce 386) (("-") reduce 386) ((".") reduce 386) (("/") reduce 386) (("<") reduce 386) ((">") reduce 386) (("?") reduce 386) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_BOOLEAN_AND) reduce 386) ((T_BOOLEAN_OR) reduce 386) ((T_COALESCE) reduce 386) ((T_INSTANCEOF) reduce 386) ((T_IS_EQUAL) reduce 386) ((T_IS_GREATER_OR_EQUAL) reduce 386) ((T_IS_IDENTICAL) reduce 386) ((T_IS_NOT_EQUAL) reduce 386) ((T_IS_NOT_IDENTICAL) reduce 386) ((T_IS_SMALLER_OR_EQUAL) reduce 386) ((T_LOGICAL_AND) reduce 386) ((T_LOGICAL_OR) reduce 386) ((T_LOGICAL_XOR) reduce 386) ((T_POW) reduce 386) ((T_SL) reduce 386) ((T_SPACESHIP) reduce 386) ((T_SR) reduce 386) (("^") reduce 386) (("|") reduce 386)) 15020 ((("%") shift) ((")") reduce 382) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 382) ((T_LOGICAL_OR) reduce 382) ((T_LOGICAL_XOR) reduce 382) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15021 ((("%") shift) ((")") reduce 384) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 384) ((T_LOGICAL_OR) reduce 384) ((T_LOGICAL_XOR) reduce 384) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15022 ((("%") shift) ((")") reduce 383) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 383) ((T_LOGICAL_OR) reduce 383) ((T_LOGICAL_XOR) reduce 383) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15023 ((("%") shift) ((")") reduce 376) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 376) ((T_LOGICAL_OR) reduce 376) ((T_LOGICAL_XOR) reduce 376) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15024 ((("%") shift) ((")") reduce 373) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 373) ((T_LOGICAL_OR) reduce 373) ((T_LOGICAL_XOR) reduce 373) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15025 ((("%") shift) ((")") reduce 381) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 381) ((T_LOGICAL_OR) reduce 381) ((T_LOGICAL_XOR) reduce 381) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15026 ((("%") shift) ((")") reduce 375) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 375) ((T_LOGICAL_OR) reduce 375) ((T_LOGICAL_XOR) reduce 375) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15027 ((("%") shift) ((")") reduce 379) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 379) ((T_LOGICAL_OR) reduce 379) ((T_LOGICAL_XOR) reduce 379) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15028 ((("%") shift) ((")") reduce 374) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 374) ((T_LOGICAL_OR) reduce 374) ((T_LOGICAL_XOR) reduce 374) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15029 ((("%") shift) ((")") reduce 377) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 377) ((T_LOGICAL_OR) reduce 377) ((T_LOGICAL_XOR) reduce 377) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15030 ((("%") shift) ((")") reduce 378) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 378) ((T_LOGICAL_OR) reduce 378) ((T_LOGICAL_XOR) reduce 378) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15031 ((("%") shift) ((")") reduce 385) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 385) ((T_LOGICAL_OR) reduce 385) ((T_LOGICAL_XOR) reduce 385) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15032 ((("%") shift) ((")") reduce 380) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 380) ((T_LOGICAL_OR) reduce 380) ((T_LOGICAL_XOR) reduce 380) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15034 ((("%") shift) ((")") reduce 370) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 370) ((T_LOGICAL_OR) reduce 370) ((T_LOGICAL_XOR) reduce 370) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15037 ((("%") reduce 529) (("(") reduce 529) ((")") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 15040 ((("%") reduce 525) (("(") reduce 516) ((")") reduce 525) (("*") reduce 525) (("+") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) (("<") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_POW) reduce 525) ((T_SL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 15042 ((("%") reduce 524) (("(") reduce 524) ((")") reduce 524) (("*") reduce 524) (("+") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) (("<") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_POW) reduce 524) ((T_SL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 15044 ((("%") reduce 519) (("(") reduce 519) ((")") reduce 519) (("*") reduce 519) (("+") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) (("<") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_POW) reduce 519) ((T_SL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 15045 ((("%") reduce 526) ((")") reduce 526) (("*") reduce 526) (("+") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) (("<") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_POW) reduce 526) ((T_SL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 15046 ((("%") reduce 371) ((")") reduce 371) (("*") reduce 371) (("+") reduce 371) (("-") reduce 371) ((".") reduce 371) (("/") reduce 371) (("<") reduce 371) ((">") reduce 371) (("?") reduce 371) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_BOOLEAN_AND) reduce 371) ((T_BOOLEAN_OR) reduce 371) ((T_COALESCE) reduce 371) ((T_INSTANCEOF) reduce 371) ((T_IS_EQUAL) reduce 371) ((T_IS_GREATER_OR_EQUAL) reduce 371) ((T_IS_IDENTICAL) reduce 371) ((T_IS_NOT_EQUAL) reduce 371) ((T_IS_NOT_IDENTICAL) reduce 371) ((T_IS_SMALLER_OR_EQUAL) reduce 371) ((T_LOGICAL_AND) reduce 371) ((T_LOGICAL_OR) reduce 371) ((T_LOGICAL_XOR) reduce 371) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 371) ((T_SL) reduce 371) ((T_SPACESHIP) reduce 371) ((T_SR) reduce 371) (("[") reduce 510) (("^") reduce 371) (("{") reduce 510) (("|") reduce 371)) 15050 ((("%") reduce 533) (("(") reduce 543) ((")") reduce 533) (("*") reduce 533) (("+") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) (("<") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_POW) reduce 533) ((T_SL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 15052 ((("%") reduce 468) (("(") reduce 468) ((")") reduce 468) (("*") reduce 468) (("+") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) (("<") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_POW) reduce 468) ((T_SL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 15053 ((("%") reduce 288) (("(") reduce 288) ((")") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 15057 ((("%") reduce 289) (("(") reduce 289) ((")") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 15058 ((("%") reduce 290) (("(") reduce 290) ((")") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 15059 ((("%") reduce 465) (("(") reduce 465) ((")") reduce 465) (("*") reduce 465) (("+") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) (("<") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_POW) reduce 465) ((T_SL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 15062 ((("%") reduce 532) (("(") reduce 543) ((")") reduce 532) (("*") reduce 532) (("+") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) (("<") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_POW) reduce 532) ((T_SL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 15063 ((("%") reduce 467) (("(") reduce 467) ((")") reduce 467) (("*") reduce 467) (("+") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) (("<") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_POW) reduce 467) ((T_SL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 15064 ((("%") reduce 469) (("(") reduce 469) ((")") reduce 469) (("*") reduce 469) (("+") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) (("<") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_POW) reduce 469) ((T_SL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 15070 ((("%") reduce 521) (("(") reduce 521) ((")") reduce 521) (("*") reduce 521) (("+") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) (("<") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_POW) reduce 521) ((T_SL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 15072 ((("%") reduce 520) (("(") reduce 520) ((")") reduce 520) (("*") reduce 520) (("+") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) (("<") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_POW) reduce 520) ((T_SL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 15073 ((("%") reduce 544) (("(") reduce 544) ((")") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 15074 ((("%") reduce 527) (("(") shift) ((")") reduce 527) (("*") reduce 527) (("+") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) (("<") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_POW) reduce 527) ((T_SL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 15075 ((("%") reduce 546) (("(") reduce 546) ((")") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 15078 ((("%") reduce 545) (("(") reduce 545) ((")") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 15079 ((("%") reduce 522) (("(") reduce 522) ((")") reduce 522) (("*") reduce 522) (("+") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) (("<") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_POW) reduce 522) ((T_SL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 15080 ((("%") reduce 528) (("(") shift) ((")") reduce 528) (("*") reduce 528) (("+") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) (("<") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_POW) reduce 528) ((T_SL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 15081 ((("%") reduce 523) (("(") reduce 523) ((")") reduce 523) (("*") reduce 523) (("+") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) (("<") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_POW) reduce 523) ((T_SL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 15082 ((("%") reduce 466) (("(") reduce 466) ((")") reduce 466) (("*") reduce 466) (("+") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) (("<") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_POW) reduce 466) ((T_SL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 15083 ((("%") reduce 531) (("(") reduce 531) ((")") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 15086 ((("%") reduce 530) (("(") reduce 530) ((")") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 15087 ((("%") reduce 465) (("(") reduce 465) ((")") reduce 465) (("*") reduce 465) (("+") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) (("<") reduce 465) (("=") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AND_EQUAL) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_COALESCE_EQUAL) reduce 465) ((T_CONCAT_EQUAL) reduce 465) ((T_DEC) reduce 465) ((T_DIV_EQUAL) reduce 465) ((T_INC) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_MINUS_EQUAL) reduce 465) ((T_MOD_EQUAL) reduce 465) ((T_MUL_EQUAL) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_OR_EQUAL) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_PLUS_EQUAL) reduce 465) ((T_POW) reduce 465) ((T_POW_EQUAL) reduce 465) ((T_SL) reduce 465) ((T_SL_EQUAL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) ((T_SR_EQUAL) reduce 465) ((T_XOR_EQUAL) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 15098 ((("%") reduce 455) ((")") reduce 455) (("*") reduce 455) (("+") reduce 455) (("-") reduce 455) ((".") reduce 455) (("/") reduce 455) (("<") reduce 455) ((">") reduce 455) (("?") reduce 455) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_BOOLEAN_AND) reduce 455) ((T_BOOLEAN_OR) reduce 455) ((T_COALESCE) reduce 455) ((T_INSTANCEOF) reduce 455) ((T_IS_EQUAL) reduce 455) ((T_IS_GREATER_OR_EQUAL) reduce 455) ((T_IS_IDENTICAL) reduce 455) ((T_IS_NOT_EQUAL) reduce 455) ((T_IS_NOT_IDENTICAL) reduce 455) ((T_IS_SMALLER_OR_EQUAL) reduce 455) ((T_LOGICAL_AND) reduce 455) ((T_LOGICAL_OR) reduce 455) ((T_LOGICAL_XOR) reduce 455) ((T_POW) reduce 455) ((T_SL) reduce 455) ((T_SPACESHIP) reduce 455) ((T_SR) reduce 455) (("^") reduce 455) (("|") reduce 455)) 15099 ((("%") reduce 450) ((")") reduce 450) (("*") reduce 450) (("+") reduce 450) (("-") reduce 450) ((".") reduce 450) (("/") reduce 450) (("<") reduce 450) ((">") reduce 450) (("?") reduce 450) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_BOOLEAN_AND) reduce 450) ((T_BOOLEAN_OR) reduce 450) ((T_COALESCE) reduce 450) ((T_INSTANCEOF) reduce 450) ((T_IS_EQUAL) reduce 450) ((T_IS_GREATER_OR_EQUAL) reduce 450) ((T_IS_IDENTICAL) reduce 450) ((T_IS_NOT_EQUAL) reduce 450) ((T_IS_NOT_IDENTICAL) reduce 450) ((T_IS_SMALLER_OR_EQUAL) reduce 450) ((T_LOGICAL_AND) reduce 450) ((T_LOGICAL_OR) reduce 450) ((T_LOGICAL_XOR) reduce 450) ((T_POW) reduce 450) ((T_SL) reduce 450) ((T_SPACESHIP) reduce 450) ((T_SR) reduce 450) (("^") reduce 450) (("|") reduce 450)) 15171 ((("%") shift) ((")") reduce 455) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15489 ((("%") reduce 451) ((")") reduce 451) (("*") reduce 451) (("+") reduce 451) (("-") reduce 451) ((".") reduce 451) (("/") reduce 451) (("<") reduce 451) ((">") reduce 451) (("?") reduce 451) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_BOOLEAN_AND) reduce 451) ((T_BOOLEAN_OR) reduce 451) ((T_COALESCE) reduce 451) ((T_INSTANCEOF) reduce 451) ((T_IS_EQUAL) reduce 451) ((T_IS_GREATER_OR_EQUAL) reduce 451) ((T_IS_IDENTICAL) reduce 451) ((T_IS_NOT_EQUAL) reduce 451) ((T_IS_NOT_IDENTICAL) reduce 451) ((T_IS_SMALLER_OR_EQUAL) reduce 451) ((T_LOGICAL_AND) reduce 451) ((T_LOGICAL_OR) reduce 451) ((T_LOGICAL_XOR) reduce 451) ((T_POW) reduce 451) ((T_SL) reduce 451) ((T_SPACESHIP) reduce 451) ((T_SR) reduce 451) (("^") reduce 451) (("|") reduce 451)) 15492 ((("%") reduce 503) (("(") reduce 541) ((")") reduce 503) (("*") reduce 503) (("+") reduce 503) (("-") reduce 503) ((".") reduce 503) (("/") reduce 503) (("<") reduce 503) ((">") reduce 503) (("?") reduce 503) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_BOOLEAN_AND) reduce 503) ((T_BOOLEAN_OR) reduce 503) ((T_COALESCE) reduce 503) ((T_INSTANCEOF) reduce 503) ((T_IS_EQUAL) reduce 503) ((T_IS_GREATER_OR_EQUAL) reduce 503) ((T_IS_IDENTICAL) reduce 503) ((T_IS_NOT_EQUAL) reduce 503) ((T_IS_NOT_IDENTICAL) reduce 503) ((T_IS_SMALLER_OR_EQUAL) reduce 503) ((T_LOGICAL_AND) reduce 503) ((T_LOGICAL_OR) reduce 503) ((T_LOGICAL_XOR) reduce 503) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 503) ((T_OBJECT_OPERATOR) reduce 503) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 503) ((T_POW) reduce 503) ((T_SL) reduce 503) ((T_SPACESHIP) reduce 503) ((T_SR) reduce 503) (("[") reduce 503) (("^") reduce 503) (("{") reduce 503) (("|") reduce 503)) 15494 ((("%") reduce 532) (("(") reduce 543) ((")") reduce 532) (("*") reduce 532) (("+") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) (("<") reduce 532) (("=") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AND_EQUAL) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_COALESCE_EQUAL) reduce 532) ((T_CONCAT_EQUAL) reduce 532) ((T_DEC) reduce 532) ((T_DIV_EQUAL) reduce 532) ((T_INC) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_MINUS_EQUAL) reduce 532) ((T_MOD_EQUAL) reduce 532) ((T_MUL_EQUAL) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_OR_EQUAL) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_PLUS_EQUAL) reduce 532) ((T_POW) reduce 532) ((T_POW_EQUAL) reduce 532) ((T_SL) reduce 532) ((T_SL_EQUAL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) ((T_SR_EQUAL) reduce 532) ((T_XOR_EQUAL) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 15497 ((("%") reduce 505) (("(") reduce 542) ((")") reduce 505) (("*") reduce 505) (("+") reduce 505) (("-") reduce 505) ((".") reduce 505) (("/") reduce 505) (("<") reduce 505) ((">") reduce 505) (("?") reduce 505) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_BOOLEAN_AND) reduce 505) ((T_BOOLEAN_OR) reduce 505) ((T_COALESCE) reduce 505) ((T_INSTANCEOF) reduce 505) ((T_IS_EQUAL) reduce 505) ((T_IS_GREATER_OR_EQUAL) reduce 505) ((T_IS_IDENTICAL) reduce 505) ((T_IS_NOT_EQUAL) reduce 505) ((T_IS_NOT_IDENTICAL) reduce 505) ((T_IS_SMALLER_OR_EQUAL) reduce 505) ((T_LOGICAL_AND) reduce 505) ((T_LOGICAL_OR) reduce 505) ((T_LOGICAL_XOR) reduce 505) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 505) ((T_OBJECT_OPERATOR) reduce 505) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 505) ((T_POW) reduce 505) ((T_SL) reduce 505) ((T_SPACESHIP) reduce 505) ((T_SR) reduce 505) (("[") reduce 505) (("^") reduce 505) (("{") reduce 505) (("|") reduce 505)) 15498 ((("%") reduce 467) (("(") reduce 467) ((")") reduce 467) (("*") reduce 467) (("+") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) (("<") reduce 467) (("=") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AND_EQUAL) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_COALESCE_EQUAL) reduce 467) ((T_CONCAT_EQUAL) reduce 467) ((T_DEC) reduce 467) ((T_DIV_EQUAL) reduce 467) ((T_INC) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_MINUS_EQUAL) reduce 467) ((T_MOD_EQUAL) reduce 467) ((T_MUL_EQUAL) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_OR_EQUAL) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_PLUS_EQUAL) reduce 467) ((T_POW) reduce 467) ((T_POW_EQUAL) reduce 467) ((T_SL) reduce 467) ((T_SL_EQUAL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) ((T_SR_EQUAL) reduce 467) ((T_XOR_EQUAL) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 15499 ((("%") reduce 469) (("(") reduce 469) ((")") reduce 469) (("*") reduce 469) (("+") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) (("<") reduce 469) (("=") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AND_EQUAL) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_COALESCE_EQUAL) reduce 469) ((T_CONCAT_EQUAL) reduce 469) ((T_DEC) reduce 469) ((T_DIV_EQUAL) reduce 469) ((T_INC) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_MINUS_EQUAL) reduce 469) ((T_MOD_EQUAL) reduce 469) ((T_MUL_EQUAL) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_OR_EQUAL) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_PLUS_EQUAL) reduce 469) ((T_POW) reduce 469) ((T_POW_EQUAL) reduce 469) ((T_SL) reduce 469) ((T_SL_EQUAL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) ((T_SR_EQUAL) reduce 469) ((T_XOR_EQUAL) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 15501 ((("%") reduce 446) ((")") reduce 446) (("*") reduce 446) (("+") reduce 446) (("-") reduce 446) ((".") reduce 446) (("/") reduce 446) (("<") reduce 446) ((">") reduce 446) (("?") reduce 446) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_BOOLEAN_AND) reduce 446) ((T_BOOLEAN_OR) reduce 446) ((T_COALESCE) reduce 446) ((T_INSTANCEOF) reduce 446) ((T_IS_EQUAL) reduce 446) ((T_IS_GREATER_OR_EQUAL) reduce 446) ((T_IS_IDENTICAL) reduce 446) ((T_IS_NOT_EQUAL) reduce 446) ((T_IS_NOT_IDENTICAL) reduce 446) ((T_IS_SMALLER_OR_EQUAL) reduce 446) ((T_LOGICAL_AND) reduce 446) ((T_LOGICAL_OR) reduce 446) ((T_LOGICAL_XOR) reduce 446) ((T_POW) reduce 446) ((T_SL) reduce 446) ((T_SPACESHIP) reduce 446) ((T_SR) reduce 446) (("^") reduce 446) (("|") reduce 446)) 15502 ((("%") reduce 448) ((")") reduce 448) (("*") reduce 448) (("+") reduce 448) (("-") reduce 448) ((".") reduce 448) (("/") reduce 448) (("<") reduce 448) ((">") reduce 448) (("?") reduce 448) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_BOOLEAN_AND) reduce 448) ((T_BOOLEAN_OR) reduce 448) ((T_COALESCE) reduce 448) ((T_INSTANCEOF) reduce 448) ((T_IS_EQUAL) reduce 448) ((T_IS_GREATER_OR_EQUAL) reduce 448) ((T_IS_IDENTICAL) reduce 448) ((T_IS_NOT_EQUAL) reduce 448) ((T_IS_NOT_IDENTICAL) reduce 448) ((T_IS_SMALLER_OR_EQUAL) reduce 448) ((T_LOGICAL_AND) reduce 448) ((T_LOGICAL_OR) reduce 448) ((T_LOGICAL_XOR) reduce 448) ((T_POW) reduce 448) ((T_SL) reduce 448) ((T_SPACESHIP) reduce 448) ((T_SR) reduce 448) (("^") reduce 448) (("|") reduce 448)) 15508 ((("%") reduce 521) (("(") reduce 521) ((")") reduce 521) (("*") reduce 521) (("+") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) (("<") reduce 521) (("=") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AND_EQUAL) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_COALESCE_EQUAL) reduce 521) ((T_CONCAT_EQUAL) reduce 521) ((T_DEC) reduce 521) ((T_DIV_EQUAL) reduce 521) ((T_INC) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_MINUS_EQUAL) reduce 521) ((T_MOD_EQUAL) reduce 521) ((T_MUL_EQUAL) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_OR_EQUAL) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_PLUS_EQUAL) reduce 521) ((T_POW) reduce 521) ((T_POW_EQUAL) reduce 521) ((T_SL) reduce 521) ((T_SL_EQUAL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) ((T_SR_EQUAL) reduce 521) ((T_XOR_EQUAL) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 15510 ((("%") reduce 520) (("(") reduce 520) ((")") reduce 520) (("*") reduce 520) (("+") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) (("<") reduce 520) (("=") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AND_EQUAL) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_COALESCE_EQUAL) reduce 520) ((T_CONCAT_EQUAL) reduce 520) ((T_DEC) reduce 520) ((T_DIV_EQUAL) reduce 520) ((T_INC) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_MINUS_EQUAL) reduce 520) ((T_MOD_EQUAL) reduce 520) ((T_MUL_EQUAL) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_OR_EQUAL) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_PLUS_EQUAL) reduce 520) ((T_POW) reduce 520) ((T_POW_EQUAL) reduce 520) ((T_SL) reduce 520) ((T_SL_EQUAL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) ((T_SR_EQUAL) reduce 520) ((T_XOR_EQUAL) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 15511 ((("%") reduce 544) (("(") reduce 544) ((")") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) (("=") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AND_EQUAL) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_COALESCE_EQUAL) reduce 544) ((T_CONCAT_EQUAL) reduce 544) ((T_DEC) reduce 544) ((T_DIV_EQUAL) reduce 544) ((T_INC) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_MINUS_EQUAL) reduce 544) ((T_MOD_EQUAL) reduce 544) ((T_MUL_EQUAL) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_OR_EQUAL) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_PLUS_EQUAL) reduce 544) ((T_POW) reduce 544) ((T_POW_EQUAL) reduce 544) ((T_SL) reduce 544) ((T_SL_EQUAL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) ((T_SR_EQUAL) reduce 544) ((T_XOR_EQUAL) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 15512 ((("%") reduce 527) (("(") shift) ((")") reduce 527) (("*") reduce 527) (("+") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) (("<") reduce 527) (("=") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AND_EQUAL) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_COALESCE_EQUAL) reduce 527) ((T_CONCAT_EQUAL) reduce 527) ((T_DEC) reduce 527) ((T_DIV_EQUAL) reduce 527) ((T_INC) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_MINUS_EQUAL) reduce 527) ((T_MOD_EQUAL) reduce 527) ((T_MUL_EQUAL) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_OR_EQUAL) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_PLUS_EQUAL) reduce 527) ((T_POW) reduce 527) ((T_POW_EQUAL) reduce 527) ((T_SL) reduce 527) ((T_SL_EQUAL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) ((T_SR_EQUAL) reduce 527) ((T_XOR_EQUAL) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 15513 ((("%") reduce 546) (("(") reduce 546) ((")") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) (("=") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AND_EQUAL) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_COALESCE_EQUAL) reduce 546) ((T_CONCAT_EQUAL) reduce 546) ((T_DEC) reduce 546) ((T_DIV_EQUAL) reduce 546) ((T_INC) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_MINUS_EQUAL) reduce 546) ((T_MOD_EQUAL) reduce 546) ((T_MUL_EQUAL) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_OR_EQUAL) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_PLUS_EQUAL) reduce 546) ((T_POW) reduce 546) ((T_POW_EQUAL) reduce 546) ((T_SL) reduce 546) ((T_SL_EQUAL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) ((T_SR_EQUAL) reduce 546) ((T_XOR_EQUAL) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 15516 ((("%") reduce 545) (("(") reduce 545) ((")") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) (("=") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AND_EQUAL) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_COALESCE_EQUAL) reduce 545) ((T_CONCAT_EQUAL) reduce 545) ((T_DEC) reduce 545) ((T_DIV_EQUAL) reduce 545) ((T_INC) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_MINUS_EQUAL) reduce 545) ((T_MOD_EQUAL) reduce 545) ((T_MUL_EQUAL) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_OR_EQUAL) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_PLUS_EQUAL) reduce 545) ((T_POW) reduce 545) ((T_POW_EQUAL) reduce 545) ((T_SL) reduce 545) ((T_SL_EQUAL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) ((T_SR_EQUAL) reduce 545) ((T_XOR_EQUAL) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 15517 ((("%") reduce 522) (("(") reduce 522) ((")") reduce 522) (("*") reduce 522) (("+") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) (("<") reduce 522) (("=") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AND_EQUAL) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_COALESCE_EQUAL) reduce 522) ((T_CONCAT_EQUAL) reduce 522) ((T_DEC) reduce 522) ((T_DIV_EQUAL) reduce 522) ((T_INC) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_MINUS_EQUAL) reduce 522) ((T_MOD_EQUAL) reduce 522) ((T_MUL_EQUAL) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_OR_EQUAL) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_PLUS_EQUAL) reduce 522) ((T_POW) reduce 522) ((T_POW_EQUAL) reduce 522) ((T_SL) reduce 522) ((T_SL_EQUAL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) ((T_SR_EQUAL) reduce 522) ((T_XOR_EQUAL) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 15518 ((("%") reduce 528) (("(") shift) ((")") reduce 528) (("*") reduce 528) (("+") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) (("<") reduce 528) (("=") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AND_EQUAL) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_COALESCE_EQUAL) reduce 528) ((T_CONCAT_EQUAL) reduce 528) ((T_DEC) reduce 528) ((T_DIV_EQUAL) reduce 528) ((T_INC) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_MINUS_EQUAL) reduce 528) ((T_MOD_EQUAL) reduce 528) ((T_MUL_EQUAL) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_OR_EQUAL) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_PLUS_EQUAL) reduce 528) ((T_POW) reduce 528) ((T_POW_EQUAL) reduce 528) ((T_SL) reduce 528) ((T_SL_EQUAL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) ((T_SR_EQUAL) reduce 528) ((T_XOR_EQUAL) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 15519 ((("%") reduce 523) (("(") reduce 523) ((")") reduce 523) (("*") reduce 523) (("+") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) (("<") reduce 523) (("=") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AND_EQUAL) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_COALESCE_EQUAL) reduce 523) ((T_CONCAT_EQUAL) reduce 523) ((T_DEC) reduce 523) ((T_DIV_EQUAL) reduce 523) ((T_INC) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_MINUS_EQUAL) reduce 523) ((T_MOD_EQUAL) reduce 523) ((T_MUL_EQUAL) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_OR_EQUAL) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_PLUS_EQUAL) reduce 523) ((T_POW) reduce 523) ((T_POW_EQUAL) reduce 523) ((T_SL) reduce 523) ((T_SL_EQUAL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) ((T_SR_EQUAL) reduce 523) ((T_XOR_EQUAL) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 15521 ((("%") reduce 438) ((")") reduce 438) (("*") reduce 438) (("+") reduce 438) (("-") reduce 438) ((".") reduce 438) (("/") reduce 438) (("<") reduce 438) ((">") reduce 438) (("?") reduce 438) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_BOOLEAN_AND) reduce 438) ((T_BOOLEAN_OR) reduce 438) ((T_COALESCE) reduce 438) ((T_INSTANCEOF) reduce 438) ((T_IS_EQUAL) reduce 438) ((T_IS_GREATER_OR_EQUAL) reduce 438) ((T_IS_IDENTICAL) reduce 438) ((T_IS_NOT_EQUAL) reduce 438) ((T_IS_NOT_IDENTICAL) reduce 438) ((T_IS_SMALLER_OR_EQUAL) reduce 438) ((T_LOGICAL_AND) reduce 438) ((T_LOGICAL_OR) reduce 438) ((T_LOGICAL_XOR) reduce 438) ((T_POW) reduce 438) ((T_SL) reduce 438) ((T_SPACESHIP) reduce 438) ((T_SR) reduce 438) (("^") reduce 438) (("|") reduce 438)) 15523 ((("%") reduce 483) (("(") reduce 483) ((")") reduce 483) (("*") reduce 483) (("+") reduce 483) (("-") reduce 483) ((".") reduce 483) (("/") reduce 483) (("<") reduce 483) (("=") shift) ((">") reduce 483) (("?") reduce 483) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_BOOLEAN_AND) reduce 483) ((T_BOOLEAN_OR) reduce 483) ((T_COALESCE) reduce 483) ((T_INSTANCEOF) reduce 483) ((T_IS_EQUAL) reduce 483) ((T_IS_GREATER_OR_EQUAL) reduce 483) ((T_IS_IDENTICAL) reduce 483) ((T_IS_NOT_EQUAL) reduce 483) ((T_IS_NOT_IDENTICAL) reduce 483) ((T_IS_SMALLER_OR_EQUAL) reduce 483) ((T_LOGICAL_AND) reduce 483) ((T_LOGICAL_OR) reduce 483) ((T_LOGICAL_XOR) reduce 483) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 483) ((T_OBJECT_OPERATOR) reduce 483) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 483) ((T_POW) reduce 483) ((T_SL) reduce 483) ((T_SPACESHIP) reduce 483) ((T_SR) reduce 483) (("[") reduce 483) (("^") reduce 483) (("{") reduce 483) (("|") reduce 483)) 15525 ((("%") shift) ((")") reduce 369) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 369) ((T_LOGICAL_OR) reduce 369) ((T_LOGICAL_XOR) reduce 369) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15526 ((("%") shift) ((")") reduce 443) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 443) ((T_LOGICAL_OR) reduce 443) ((T_LOGICAL_XOR) reduce 443) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15537 ((("%") reduce 502) ((")") reduce 502) (("*") reduce 502) (("+") reduce 502) (("-") reduce 502) ((".") reduce 502) (("/") reduce 502) (("<") reduce 502) ((">") reduce 502) (("?") reduce 502) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_BOOLEAN_AND) reduce 502) ((T_BOOLEAN_OR) reduce 502) ((T_COALESCE) reduce 502) ((T_DOUBLE_ARROW) reduce 502) ((T_INSTANCEOF) reduce 502) ((T_IS_EQUAL) reduce 502) ((T_IS_GREATER_OR_EQUAL) reduce 502) ((T_IS_IDENTICAL) reduce 502) ((T_IS_NOT_EQUAL) reduce 502) ((T_IS_NOT_IDENTICAL) reduce 502) ((T_IS_SMALLER_OR_EQUAL) reduce 502) ((T_LOGICAL_AND) reduce 502) ((T_LOGICAL_OR) reduce 502) ((T_LOGICAL_XOR) reduce 502) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 502) ((T_OBJECT_OPERATOR) reduce 502) ((T_POW) reduce 502) ((T_SL) reduce 502) ((T_SPACESHIP) reduce 502) ((T_SR) reduce 502) (("[") reduce 502) (("^") reduce 502) (("{") reduce 502) (("|") reduce 502)) 15539 ((("%") reduce 484) (("(") reduce 484) ((")") reduce 484) (("*") reduce 484) (("+") reduce 484) (("-") reduce 484) ((".") reduce 484) (("/") reduce 484) (("<") reduce 484) ((">") reduce 484) (("?") reduce 484) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_BOOLEAN_AND) reduce 484) ((T_BOOLEAN_OR) reduce 484) ((T_COALESCE) reduce 484) ((T_DOUBLE_ARROW) reduce 484) ((T_INSTANCEOF) reduce 484) ((T_IS_EQUAL) reduce 484) ((T_IS_GREATER_OR_EQUAL) reduce 484) ((T_IS_IDENTICAL) reduce 484) ((T_IS_NOT_EQUAL) reduce 484) ((T_IS_NOT_IDENTICAL) reduce 484) ((T_IS_SMALLER_OR_EQUAL) reduce 484) ((T_LOGICAL_AND) reduce 484) ((T_LOGICAL_OR) reduce 484) ((T_LOGICAL_XOR) reduce 484) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 484) ((T_OBJECT_OPERATOR) reduce 484) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 484) ((T_POW) reduce 484) ((T_SL) reduce 484) ((T_SPACESHIP) reduce 484) ((T_SR) reduce 484) (("[") reduce 484) (("^") reduce 484) (("{") reduce 484) (("|") reduce 484)) 15541 ((("%") reduce 497) ((")") reduce 497) (("*") reduce 497) (("+") reduce 497) (("-") reduce 497) ((".") reduce 497) (("/") reduce 497) (("<") reduce 497) ((">") reduce 497) (("?") reduce 497) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_BOOLEAN_AND) reduce 497) ((T_BOOLEAN_OR) reduce 497) ((T_COALESCE) reduce 497) ((T_DOUBLE_ARROW) reduce 497) ((T_INSTANCEOF) reduce 497) ((T_IS_EQUAL) reduce 497) ((T_IS_GREATER_OR_EQUAL) reduce 497) ((T_IS_IDENTICAL) reduce 497) ((T_IS_NOT_EQUAL) reduce 497) ((T_IS_NOT_IDENTICAL) reduce 497) ((T_IS_SMALLER_OR_EQUAL) reduce 497) ((T_LOGICAL_AND) reduce 497) ((T_LOGICAL_OR) reduce 497) ((T_LOGICAL_XOR) reduce 497) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 497) ((T_OBJECT_OPERATOR) reduce 497) ((T_POW) reduce 497) ((T_SL) reduce 497) ((T_SPACESHIP) reduce 497) ((T_SR) reduce 497) (("[") reduce 497) (("^") reduce 497) (("{") reduce 497) (("|") reduce 497)) 15542 ((("%") reduce 487) ((")") reduce 487) (("*") reduce 487) (("+") reduce 487) (("-") reduce 487) ((".") reduce 487) (("/") reduce 487) (("<") reduce 487) ((">") reduce 487) (("?") reduce 487) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_BOOLEAN_AND) reduce 487) ((T_BOOLEAN_OR) reduce 487) ((T_COALESCE) reduce 487) ((T_DOUBLE_ARROW) reduce 487) ((T_INSTANCEOF) reduce 487) ((T_IS_EQUAL) reduce 487) ((T_IS_GREATER_OR_EQUAL) reduce 487) ((T_IS_IDENTICAL) reduce 487) ((T_IS_NOT_EQUAL) reduce 487) ((T_IS_NOT_IDENTICAL) reduce 487) ((T_IS_SMALLER_OR_EQUAL) reduce 487) ((T_LOGICAL_AND) reduce 487) ((T_LOGICAL_OR) reduce 487) ((T_LOGICAL_XOR) reduce 487) ((T_POW) reduce 487) ((T_SL) reduce 487) ((T_SPACESHIP) reduce 487) ((T_SR) reduce 487) (("^") reduce 487) (("|") reduce 487)) 15546 ((("%") reduce 475) (("(") shift) ((")") reduce 475) (("*") reduce 475) (("+") reduce 475) (("-") reduce 475) ((".") reduce 475) (("/") reduce 475) (("<") reduce 475) ((">") reduce 475) (("?") reduce 475) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_BOOLEAN_AND) reduce 475) ((T_BOOLEAN_OR) reduce 475) ((T_COALESCE) reduce 475) ((T_DOUBLE_ARROW) reduce 475) ((T_INSTANCEOF) reduce 475) ((T_IS_EQUAL) reduce 475) ((T_IS_GREATER_OR_EQUAL) reduce 475) ((T_IS_IDENTICAL) reduce 475) ((T_IS_NOT_EQUAL) reduce 475) ((T_IS_NOT_IDENTICAL) reduce 475) ((T_IS_SMALLER_OR_EQUAL) reduce 475) ((T_LOGICAL_AND) reduce 475) ((T_LOGICAL_OR) reduce 475) ((T_LOGICAL_XOR) reduce 475) ((T_POW) reduce 475) ((T_SL) reduce 475) ((T_SPACESHIP) reduce 475) ((T_SR) reduce 475) (("^") reduce 475) (("|") reduce 475)) 15547 ((("%") reduce 496) ((")") reduce 496) (("*") reduce 496) (("+") reduce 496) (("-") reduce 496) ((".") reduce 496) (("/") reduce 496) (("<") reduce 496) ((">") reduce 496) (("?") reduce 496) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_BOOLEAN_AND) reduce 496) ((T_BOOLEAN_OR) reduce 496) ((T_COALESCE) reduce 496) ((T_DOUBLE_ARROW) reduce 496) ((T_INSTANCEOF) reduce 496) ((T_IS_EQUAL) reduce 496) ((T_IS_GREATER_OR_EQUAL) reduce 496) ((T_IS_IDENTICAL) reduce 496) ((T_IS_NOT_EQUAL) reduce 496) ((T_IS_NOT_IDENTICAL) reduce 496) ((T_IS_SMALLER_OR_EQUAL) reduce 496) ((T_LOGICAL_AND) reduce 496) ((T_LOGICAL_OR) reduce 496) ((T_LOGICAL_XOR) reduce 496) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 496) ((T_OBJECT_OPERATOR) reduce 496) ((T_POW) reduce 496) ((T_SL) reduce 496) ((T_SPACESHIP) reduce 496) ((T_SR) reduce 496) (("[") reduce 496) (("^") reduce 496) (("{") reduce 496) (("|") reduce 496)) 15548 ((("%") reduce 500) ((")") reduce 500) (("*") reduce 500) (("+") reduce 500) (("-") reduce 500) ((".") reduce 500) (("/") reduce 500) (("<") reduce 500) ((">") reduce 500) (("?") reduce 500) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_BOOLEAN_AND) reduce 500) ((T_BOOLEAN_OR) reduce 500) ((T_COALESCE) reduce 500) ((T_DOUBLE_ARROW) reduce 500) ((T_INSTANCEOF) reduce 500) ((T_IS_EQUAL) reduce 500) ((T_IS_GREATER_OR_EQUAL) reduce 500) ((T_IS_IDENTICAL) reduce 500) ((T_IS_NOT_EQUAL) reduce 500) ((T_IS_NOT_IDENTICAL) reduce 500) ((T_IS_SMALLER_OR_EQUAL) reduce 500) ((T_LOGICAL_AND) reduce 500) ((T_LOGICAL_OR) reduce 500) ((T_LOGICAL_XOR) reduce 500) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 500) ((T_OBJECT_OPERATOR) reduce 500) ((T_POW) reduce 500) ((T_SL) reduce 500) ((T_SPACESHIP) reduce 500) ((T_SR) reduce 500) (("[") reduce 500) (("^") reduce 500) (("{") reduce 500) (("|") reduce 500)) 15554 ((("%") reduce 495) ((")") reduce 495) (("*") reduce 495) (("+") reduce 495) (("-") reduce 495) ((".") reduce 495) (("/") reduce 495) (("<") reduce 495) ((">") reduce 495) (("?") reduce 495) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_BOOLEAN_AND) reduce 495) ((T_BOOLEAN_OR) reduce 495) ((T_COALESCE) reduce 495) ((T_DOUBLE_ARROW) reduce 495) ((T_INSTANCEOF) reduce 495) ((T_IS_EQUAL) reduce 495) ((T_IS_GREATER_OR_EQUAL) reduce 495) ((T_IS_IDENTICAL) reduce 495) ((T_IS_NOT_EQUAL) reduce 495) ((T_IS_NOT_IDENTICAL) reduce 495) ((T_IS_SMALLER_OR_EQUAL) reduce 495) ((T_LOGICAL_AND) reduce 495) ((T_LOGICAL_OR) reduce 495) ((T_LOGICAL_XOR) reduce 495) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 495) ((T_OBJECT_OPERATOR) reduce 495) ((T_POW) reduce 495) ((T_SL) reduce 495) ((T_SPACESHIP) reduce 495) ((T_SR) reduce 495) (("[") reduce 495) (("^") reduce 495) (("{") reduce 495) (("|") reduce 495)) 15556 ((("%") reduce 486) ((")") reduce 486) (("*") reduce 486) (("+") reduce 486) (("-") reduce 486) ((".") reduce 486) (("/") reduce 486) (("<") reduce 486) ((">") reduce 486) (("?") reduce 486) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_BOOLEAN_AND) reduce 486) ((T_BOOLEAN_OR) reduce 486) ((T_COALESCE) reduce 486) ((T_DOUBLE_ARROW) reduce 486) ((T_INSTANCEOF) reduce 486) ((T_IS_EQUAL) reduce 486) ((T_IS_GREATER_OR_EQUAL) reduce 486) ((T_IS_IDENTICAL) reduce 486) ((T_IS_NOT_EQUAL) reduce 486) ((T_IS_NOT_IDENTICAL) reduce 486) ((T_IS_SMALLER_OR_EQUAL) reduce 486) ((T_LOGICAL_AND) reduce 486) ((T_LOGICAL_OR) reduce 486) ((T_LOGICAL_XOR) reduce 486) ((T_POW) reduce 486) ((T_SL) reduce 486) ((T_SPACESHIP) reduce 486) ((T_SR) reduce 486) (("^") reduce 486) (("|") reduce 486)) 15558 ((("%") reduce 499) ((")") reduce 499) (("*") reduce 499) (("+") reduce 499) (("-") reduce 499) ((".") reduce 499) (("/") reduce 499) (("<") reduce 499) ((">") reduce 499) (("?") reduce 499) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_BOOLEAN_AND) reduce 499) ((T_BOOLEAN_OR) reduce 499) ((T_COALESCE) reduce 499) ((T_DOUBLE_ARROW) reduce 499) ((T_INSTANCEOF) reduce 499) ((T_IS_EQUAL) reduce 499) ((T_IS_GREATER_OR_EQUAL) reduce 499) ((T_IS_IDENTICAL) reduce 499) ((T_IS_NOT_EQUAL) reduce 499) ((T_IS_NOT_IDENTICAL) reduce 499) ((T_IS_SMALLER_OR_EQUAL) reduce 499) ((T_LOGICAL_AND) reduce 499) ((T_LOGICAL_OR) reduce 499) ((T_LOGICAL_XOR) reduce 499) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 499) ((T_OBJECT_OPERATOR) reduce 499) ((T_POW) reduce 499) ((T_SL) reduce 499) ((T_SPACESHIP) reduce 499) ((T_SR) reduce 499) (("[") reduce 499) (("^") reduce 499) (("{") reduce 499) (("|") reduce 499)) 15559 ((("%") reduce 93) (("(") reduce 93) ((")") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 93) ((T_OBJECT_OPERATOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("[") reduce 93) (("^") reduce 93) (("{") reduce 93) (("|") reduce 93)) 15560 ((("%") reduce 92) (("(") reduce 92) ((")") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 92) ((T_OBJECT_OPERATOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("[") reduce 92) (("^") reduce 92) (("{") reduce 92) (("|") reduce 92)) 15561 ((("%") reduce 94) (("(") reduce 94) ((")") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 94) ((T_OBJECT_OPERATOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("[") reduce 94) (("^") reduce 94) (("{") reduce 94) (("|") reduce 94)) 15563 ((("%") reduce 501) ((")") reduce 501) (("*") reduce 501) (("+") reduce 501) (("-") reduce 501) ((".") reduce 501) (("/") reduce 501) (("<") reduce 501) ((">") reduce 501) (("?") reduce 501) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_BOOLEAN_AND) reduce 501) ((T_BOOLEAN_OR) reduce 501) ((T_COALESCE) reduce 501) ((T_DOUBLE_ARROW) reduce 501) ((T_INSTANCEOF) reduce 501) ((T_IS_EQUAL) reduce 501) ((T_IS_GREATER_OR_EQUAL) reduce 501) ((T_IS_IDENTICAL) reduce 501) ((T_IS_NOT_EQUAL) reduce 501) ((T_IS_NOT_IDENTICAL) reduce 501) ((T_IS_SMALLER_OR_EQUAL) reduce 501) ((T_LOGICAL_AND) reduce 501) ((T_LOGICAL_OR) reduce 501) ((T_LOGICAL_XOR) reduce 501) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 501) ((T_OBJECT_OPERATOR) reduce 501) ((T_POW) reduce 501) ((T_SL) reduce 501) ((T_SPACESHIP) reduce 501) ((T_SR) reduce 501) (("[") reduce 501) (("^") reduce 501) (("{") reduce 501) (("|") reduce 501)) 15571 ((("%") reduce 91) (("(") reduce 91) ((")") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 91) ((T_OBJECT_OPERATOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("[") reduce 91) (("^") reduce 91) (("{") reduce 91) (("|") reduce 91)) 15574 ((("%") reduce 498) ((")") reduce 498) (("*") reduce 498) (("+") reduce 498) (("-") reduce 498) ((".") reduce 498) (("/") reduce 498) (("<") reduce 498) ((">") reduce 498) (("?") reduce 498) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_BOOLEAN_AND) reduce 498) ((T_BOOLEAN_OR) reduce 498) ((T_COALESCE) reduce 498) ((T_DOUBLE_ARROW) reduce 498) ((T_INSTANCEOF) reduce 498) ((T_IS_EQUAL) reduce 498) ((T_IS_GREATER_OR_EQUAL) reduce 498) ((T_IS_IDENTICAL) reduce 498) ((T_IS_NOT_EQUAL) reduce 498) ((T_IS_NOT_IDENTICAL) reduce 498) ((T_IS_SMALLER_OR_EQUAL) reduce 498) ((T_LOGICAL_AND) reduce 498) ((T_LOGICAL_OR) reduce 498) ((T_LOGICAL_XOR) reduce 498) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 498) ((T_OBJECT_OPERATOR) reduce 498) ((T_POW) reduce 498) ((T_SL) reduce 498) ((T_SPACESHIP) reduce 498) ((T_SR) reduce 498) (("[") reduce 498) (("^") reduce 498) (("{") reduce 498) (("|") reduce 498)) 15576 ((("%") reduce 529) (("(") reduce 529) ((")") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) (("=") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AND_EQUAL) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_COALESCE_EQUAL) reduce 529) ((T_CONCAT_EQUAL) reduce 529) ((T_DEC) reduce 529) ((T_DIV_EQUAL) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INC) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_MINUS_EQUAL) reduce 529) ((T_MOD_EQUAL) reduce 529) ((T_MUL_EQUAL) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_OR_EQUAL) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_PLUS_EQUAL) reduce 529) ((T_POW) reduce 529) ((T_POW_EQUAL) reduce 529) ((T_SL) reduce 529) ((T_SL_EQUAL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) ((T_SR_EQUAL) reduce 529) ((T_XOR_EQUAL) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 15577 ((("!") shift) (("\"") shift) (("$") shift) (("%") reduce 440) (("(") shift) ((")") reduce 440) (("*") reduce 440) (("+") shift) (("-") shift) ((".") reduce 440) (("/") reduce 440) (("<") reduce 440) ((">") reduce 440) (("?") reduce 440) (("@") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOLEAN_AND) reduce 440) ((T_BOOLEAN_OR) reduce 440) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_COALESCE) reduce 440) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_ARROW) reduce 440) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INSTANCEOF) reduce 440) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_IS_EQUAL) reduce 440) ((T_IS_GREATER_OR_EQUAL) reduce 440) ((T_IS_IDENTICAL) reduce 440) ((T_IS_NOT_EQUAL) reduce 440) ((T_IS_NOT_IDENTICAL) reduce 440) ((T_IS_SMALLER_OR_EQUAL) reduce 440) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_LOGICAL_AND) reduce 440) ((T_LOGICAL_OR) reduce 440) ((T_LOGICAL_XOR) reduce 440) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_POW) reduce 440) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_SL) reduce 440) ((T_SPACESHIP) reduce 440) ((T_SR) reduce 440) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("^") reduce 440) (("`") shift) (("|") reduce 440) (("~") shift)) 15584 ((("%") reduce 525) (("(") reduce 516) ((")") reduce 525) (("*") reduce 525) (("+") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) (("<") reduce 525) (("=") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AND_EQUAL) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_COALESCE_EQUAL) reduce 525) ((T_CONCAT_EQUAL) reduce 525) ((T_DEC) reduce 525) ((T_DIV_EQUAL) reduce 525) ((T_DOUBLE_ARROW) reduce 525) ((T_INC) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_MINUS_EQUAL) reduce 525) ((T_MOD_EQUAL) reduce 525) ((T_MUL_EQUAL) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_OR_EQUAL) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_PLUS_EQUAL) reduce 525) ((T_POW) reduce 525) ((T_POW_EQUAL) reduce 525) ((T_SL) reduce 525) ((T_SL_EQUAL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) ((T_SR_EQUAL) reduce 525) ((T_XOR_EQUAL) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 15585 ((("%") reduce 493) ((")") reduce 493) (("*") reduce 493) (("+") reduce 493) (("-") reduce 493) ((".") reduce 493) (("/") reduce 493) (("<") reduce 493) ((">") reduce 493) (("?") reduce 493) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_BOOLEAN_AND) reduce 493) ((T_BOOLEAN_OR) reduce 493) ((T_COALESCE) reduce 493) ((T_DOUBLE_ARROW) reduce 493) ((T_INSTANCEOF) reduce 493) ((T_IS_EQUAL) reduce 493) ((T_IS_GREATER_OR_EQUAL) reduce 493) ((T_IS_IDENTICAL) reduce 493) ((T_IS_NOT_EQUAL) reduce 493) ((T_IS_NOT_IDENTICAL) reduce 493) ((T_IS_SMALLER_OR_EQUAL) reduce 493) ((T_LOGICAL_AND) reduce 493) ((T_LOGICAL_OR) reduce 493) ((T_LOGICAL_XOR) reduce 493) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 513) ((T_OBJECT_OPERATOR) reduce 513) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 513) ((T_POW) reduce 493) ((T_SL) reduce 493) ((T_SPACESHIP) reduce 493) ((T_SR) reduce 493) (("[") reduce 513) (("^") reduce 493) (("{") reduce 513) (("|") reduce 493)) 15587 ((("%") reduce 492) ((")") reduce 492) (("*") reduce 492) (("+") reduce 492) (("-") reduce 492) ((".") reduce 492) (("/") reduce 492) (("<") reduce 492) ((">") reduce 492) (("?") reduce 492) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_BOOLEAN_AND) reduce 492) ((T_BOOLEAN_OR) reduce 492) ((T_COALESCE) reduce 492) ((T_DOUBLE_ARROW) reduce 492) ((T_INSTANCEOF) reduce 492) ((T_IS_EQUAL) reduce 492) ((T_IS_GREATER_OR_EQUAL) reduce 492) ((T_IS_IDENTICAL) reduce 492) ((T_IS_NOT_EQUAL) reduce 492) ((T_IS_NOT_IDENTICAL) reduce 492) ((T_IS_SMALLER_OR_EQUAL) reduce 492) ((T_LOGICAL_AND) reduce 492) ((T_LOGICAL_OR) reduce 492) ((T_LOGICAL_XOR) reduce 492) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 515) ((T_OBJECT_OPERATOR) reduce 515) ((T_POW) reduce 492) ((T_SL) reduce 492) ((T_SPACESHIP) reduce 492) ((T_SR) reduce 492) (("[") reduce 515) (("^") reduce 492) (("{") reduce 515) (("|") reduce 492)) 15588 ((("%") reduce 491) (("(") reduce 518) ((")") reduce 491) (("*") reduce 491) (("+") reduce 491) (("-") reduce 491) ((".") reduce 491) (("/") reduce 491) (("<") reduce 491) ((">") reduce 491) (("?") reduce 491) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_BOOLEAN_AND) reduce 491) ((T_BOOLEAN_OR) reduce 491) ((T_COALESCE) reduce 491) ((T_DOUBLE_ARROW) reduce 491) ((T_INSTANCEOF) reduce 491) ((T_IS_EQUAL) reduce 491) ((T_IS_GREATER_OR_EQUAL) reduce 491) ((T_IS_IDENTICAL) reduce 491) ((T_IS_NOT_EQUAL) reduce 491) ((T_IS_NOT_IDENTICAL) reduce 491) ((T_IS_SMALLER_OR_EQUAL) reduce 491) ((T_LOGICAL_AND) reduce 491) ((T_LOGICAL_OR) reduce 491) ((T_LOGICAL_XOR) reduce 491) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 512) ((T_OBJECT_OPERATOR) reduce 512) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 512) ((T_POW) reduce 491) ((T_SL) reduce 491) ((T_SPACESHIP) reduce 491) ((T_SR) reduce 491) (("[") reduce 512) (("^") reduce 491) (("{") reduce 512) (("|") reduce 491)) 15589 ((("%") shift) ((")") reduce 441) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 441) ((T_LOGICAL_OR) reduce 441) ((T_LOGICAL_XOR) reduce 441) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15592 ((("%") reduce 524) (("(") reduce 524) ((")") reduce 524) (("*") reduce 524) (("+") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) (("<") reduce 524) (("=") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AND_EQUAL) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_COALESCE_EQUAL) reduce 524) ((T_CONCAT_EQUAL) reduce 524) ((T_DEC) reduce 524) ((T_DIV_EQUAL) reduce 524) ((T_DOUBLE_ARROW) reduce 524) ((T_INC) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_MINUS_EQUAL) reduce 524) ((T_MOD_EQUAL) reduce 524) ((T_MUL_EQUAL) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_OR_EQUAL) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_PLUS_EQUAL) reduce 524) ((T_POW) reduce 524) ((T_POW_EQUAL) reduce 524) ((T_SL) reduce 524) ((T_SL_EQUAL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) ((T_SR_EQUAL) reduce 524) ((T_XOR_EQUAL) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 15593 ((("%") reduce 445) ((")") reduce 445) (("*") reduce 445) (("+") reduce 445) (("-") reduce 445) ((".") reduce 445) (("/") reduce 445) (("<") reduce 445) ((">") reduce 445) (("?") reduce 445) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_BOOLEAN_AND) reduce 445) ((T_BOOLEAN_OR) reduce 445) ((T_COALESCE) reduce 445) ((T_DOUBLE_ARROW) reduce 445) ((T_INSTANCEOF) reduce 445) ((T_IS_EQUAL) reduce 445) ((T_IS_GREATER_OR_EQUAL) reduce 445) ((T_IS_IDENTICAL) reduce 445) ((T_IS_NOT_EQUAL) reduce 445) ((T_IS_NOT_IDENTICAL) reduce 445) ((T_IS_SMALLER_OR_EQUAL) reduce 445) ((T_LOGICAL_AND) reduce 445) ((T_LOGICAL_OR) reduce 445) ((T_LOGICAL_XOR) reduce 445) ((T_POW) reduce 445) ((T_SL) reduce 445) ((T_SPACESHIP) reduce 445) ((T_SR) reduce 445) (("^") reduce 445) (("|") reduce 445)) 15594 ((("%") reduce 427) ((")") reduce 427) (("*") reduce 427) (("+") reduce 427) (("-") reduce 427) ((".") reduce 427) (("/") reduce 427) (("<") reduce 427) ((">") reduce 427) (("?") reduce 427) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_BOOLEAN_AND) reduce 427) ((T_BOOLEAN_OR) reduce 427) ((T_COALESCE) reduce 427) ((T_DOUBLE_ARROW) reduce 427) ((T_INSTANCEOF) reduce 427) ((T_IS_EQUAL) reduce 427) ((T_IS_GREATER_OR_EQUAL) reduce 427) ((T_IS_IDENTICAL) reduce 427) ((T_IS_NOT_EQUAL) reduce 427) ((T_IS_NOT_IDENTICAL) reduce 427) ((T_IS_SMALLER_OR_EQUAL) reduce 427) ((T_LOGICAL_AND) reduce 427) ((T_LOGICAL_OR) reduce 427) ((T_LOGICAL_XOR) reduce 427) ((T_POW) reduce 427) ((T_SL) reduce 427) ((T_SPACESHIP) reduce 427) ((T_SR) reduce 427) (("^") reduce 427) (("|") reduce 427)) 15595 ((("%") reduce 449) ((")") reduce 449) (("*") reduce 449) (("+") reduce 449) (("-") reduce 449) ((".") reduce 449) (("/") reduce 449) (("<") reduce 449) ((">") reduce 449) (("?") reduce 449) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_BOOLEAN_AND) reduce 449) ((T_BOOLEAN_OR) reduce 449) ((T_COALESCE) reduce 449) ((T_DOUBLE_ARROW) reduce 449) ((T_INSTANCEOF) reduce 449) ((T_IS_EQUAL) reduce 449) ((T_IS_GREATER_OR_EQUAL) reduce 449) ((T_IS_IDENTICAL) reduce 449) ((T_IS_NOT_EQUAL) reduce 449) ((T_IS_NOT_IDENTICAL) reduce 449) ((T_IS_SMALLER_OR_EQUAL) reduce 449) ((T_LOGICAL_AND) reduce 449) ((T_LOGICAL_OR) reduce 449) ((T_LOGICAL_XOR) reduce 449) ((T_POW) reduce 449) ((T_SL) reduce 449) ((T_SPACESHIP) reduce 449) ((T_SR) reduce 449) (("^") reduce 449) (("|") reduce 449)) 15596 ((("%") reduce 494) (("(") shift) ((")") reduce 494) (("*") reduce 494) (("+") reduce 494) (("-") reduce 494) ((".") reduce 494) (("/") reduce 494) (("<") reduce 494) ((">") reduce 494) (("?") reduce 494) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_BOOLEAN_AND) reduce 494) ((T_BOOLEAN_OR) reduce 494) ((T_COALESCE) reduce 494) ((T_DOUBLE_ARROW) reduce 494) ((T_INSTANCEOF) reduce 494) ((T_IS_EQUAL) reduce 494) ((T_IS_GREATER_OR_EQUAL) reduce 494) ((T_IS_IDENTICAL) reduce 494) ((T_IS_NOT_EQUAL) reduce 494) ((T_IS_NOT_IDENTICAL) reduce 494) ((T_IS_SMALLER_OR_EQUAL) reduce 494) ((T_LOGICAL_AND) reduce 494) ((T_LOGICAL_OR) reduce 494) ((T_LOGICAL_XOR) reduce 494) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 494) ((T_OBJECT_OPERATOR) reduce 494) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 494) ((T_SL) reduce 494) ((T_SPACESHIP) reduce 494) ((T_SR) reduce 494) (("[") reduce 494) (("^") reduce 494) (("{") reduce 494) (("|") reduce 494)) 15597 ((("%") reduce 423) ((")") reduce 423) (("*") reduce 423) (("+") reduce 423) (("-") reduce 423) ((".") reduce 423) (("/") reduce 423) (("<") reduce 423) ((">") reduce 423) (("?") reduce 423) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_BOOLEAN_AND) reduce 423) ((T_BOOLEAN_OR) reduce 423) ((T_COALESCE) reduce 423) ((T_DOUBLE_ARROW) reduce 423) ((T_INSTANCEOF) reduce 423) ((T_IS_EQUAL) reduce 423) ((T_IS_GREATER_OR_EQUAL) reduce 423) ((T_IS_IDENTICAL) reduce 423) ((T_IS_NOT_EQUAL) reduce 423) ((T_IS_NOT_IDENTICAL) reduce 423) ((T_IS_SMALLER_OR_EQUAL) reduce 423) ((T_LOGICAL_AND) reduce 423) ((T_LOGICAL_OR) reduce 423) ((T_LOGICAL_XOR) reduce 423) ((T_POW) reduce 423) ((T_SL) reduce 423) ((T_SPACESHIP) reduce 423) ((T_SR) reduce 423) (("^") reduce 423) (("|") reduce 423)) 15598 ((("%") reduce 437) ((")") reduce 437) (("*") reduce 437) (("+") reduce 437) (("-") reduce 437) ((".") reduce 437) (("/") reduce 437) (("<") reduce 437) ((">") reduce 437) (("?") reduce 437) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_BOOLEAN_AND) reduce 437) ((T_BOOLEAN_OR) reduce 437) ((T_COALESCE) reduce 437) ((T_DOUBLE_ARROW) reduce 437) ((T_INSTANCEOF) reduce 437) ((T_IS_EQUAL) reduce 437) ((T_IS_GREATER_OR_EQUAL) reduce 437) ((T_IS_IDENTICAL) reduce 437) ((T_IS_NOT_EQUAL) reduce 437) ((T_IS_NOT_IDENTICAL) reduce 437) ((T_IS_SMALLER_OR_EQUAL) reduce 437) ((T_LOGICAL_AND) reduce 437) ((T_LOGICAL_OR) reduce 437) ((T_LOGICAL_XOR) reduce 437) ((T_POW) reduce 437) ((T_SL) reduce 437) ((T_SPACESHIP) reduce 437) ((T_SR) reduce 437) (("^") reduce 437) (("|") reduce 437)) 15599 ((("%") reduce 519) (("(") reduce 519) ((")") reduce 519) (("*") reduce 519) (("+") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) (("<") reduce 519) (("=") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AND_EQUAL) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_COALESCE_EQUAL) reduce 519) ((T_CONCAT_EQUAL) reduce 519) ((T_DEC) reduce 519) ((T_DIV_EQUAL) reduce 519) ((T_DOUBLE_ARROW) reduce 519) ((T_INC) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_MINUS_EQUAL) reduce 519) ((T_MOD_EQUAL) reduce 519) ((T_MUL_EQUAL) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_OR_EQUAL) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_PLUS_EQUAL) reduce 519) ((T_POW) reduce 519) ((T_POW_EQUAL) reduce 519) ((T_SL) reduce 519) ((T_SL_EQUAL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) ((T_SR_EQUAL) reduce 519) ((T_XOR_EQUAL) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 15600 ((("%") reduce 526) ((")") reduce 526) (("*") reduce 526) (("+") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) (("<") reduce 526) (("=") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AND_EQUAL) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_COALESCE_EQUAL) reduce 526) ((T_CONCAT_EQUAL) reduce 526) ((T_DEC) reduce 526) ((T_DIV_EQUAL) reduce 526) ((T_DOUBLE_ARROW) reduce 526) ((T_INC) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_MINUS_EQUAL) reduce 526) ((T_MOD_EQUAL) reduce 526) ((T_MUL_EQUAL) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_OR_EQUAL) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_PLUS_EQUAL) reduce 526) ((T_POW) reduce 526) ((T_POW_EQUAL) reduce 526) ((T_SL) reduce 526) ((T_SL_EQUAL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) ((T_SR_EQUAL) reduce 526) ((T_XOR_EQUAL) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 15601 ((("%") reduce 367) ((")") reduce 367) (("*") reduce 367) (("+") reduce 367) (("-") reduce 367) ((".") reduce 367) (("/") reduce 367) (("<") reduce 367) (("=") shift) ((">") reduce 367) (("?") reduce 367) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AND_EQUAL) shift) ((T_BOOLEAN_AND) reduce 367) ((T_BOOLEAN_OR) reduce 367) ((T_COALESCE) reduce 367) ((T_COALESCE_EQUAL) shift) ((T_CONCAT_EQUAL) shift) ((T_DEC) shift) ((T_DIV_EQUAL) shift) ((T_DOUBLE_ARROW) reduce 367) ((T_INC) shift) ((T_INSTANCEOF) reduce 367) ((T_IS_EQUAL) reduce 367) ((T_IS_GREATER_OR_EQUAL) reduce 367) ((T_IS_IDENTICAL) reduce 367) ((T_IS_NOT_EQUAL) reduce 367) ((T_IS_NOT_IDENTICAL) reduce 367) ((T_IS_SMALLER_OR_EQUAL) reduce 367) ((T_LOGICAL_AND) reduce 367) ((T_LOGICAL_OR) reduce 367) ((T_LOGICAL_XOR) reduce 367) ((T_MINUS_EQUAL) shift) ((T_MOD_EQUAL) shift) ((T_MUL_EQUAL) shift) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_OR_EQUAL) shift) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_PLUS_EQUAL) shift) ((T_POW) reduce 367) ((T_POW_EQUAL) shift) ((T_SL) reduce 367) ((T_SL_EQUAL) shift) ((T_SPACESHIP) reduce 367) ((T_SR) reduce 367) ((T_SR_EQUAL) shift) ((T_XOR_EQUAL) shift) (("[") reduce 510) (("^") reduce 367) (("{") reduce 510) (("|") reduce 367)) 15604 ((("%") reduce 411) ((")") reduce 411) (("*") reduce 411) (("+") reduce 411) (("-") reduce 411) ((".") reduce 411) (("/") reduce 411) (("<") reduce 411) ((">") reduce 411) (("?") reduce 411) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_BOOLEAN_AND) reduce 411) ((T_BOOLEAN_OR) reduce 411) ((T_COALESCE) reduce 411) ((T_DOUBLE_ARROW) reduce 411) ((T_INSTANCEOF) reduce 411) ((T_IS_EQUAL) reduce 411) ((T_IS_GREATER_OR_EQUAL) reduce 411) ((T_IS_IDENTICAL) reduce 411) ((T_IS_NOT_EQUAL) reduce 411) ((T_IS_NOT_IDENTICAL) reduce 411) ((T_IS_SMALLER_OR_EQUAL) reduce 411) ((T_LOGICAL_AND) reduce 411) ((T_LOGICAL_OR) reduce 411) ((T_LOGICAL_XOR) reduce 411) ((T_POW) shift) ((T_SL) reduce 411) ((T_SPACESHIP) reduce 411) ((T_SR) reduce 411) (("^") reduce 411) (("|") reduce 411)) 15635 ((("%") shift) ((")") reduce 395) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 395) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 395) ((T_BOOLEAN_OR) reduce 395) ((T_COALESCE) reduce 395) ((T_DOUBLE_ARROW) reduce 395) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 395) ((T_LOGICAL_OR) reduce 395) ((T_LOGICAL_XOR) reduce 395) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") reduce 395)) 15636 ((("%") shift) ((")") reduce 398) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 398) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 398) ((T_BOOLEAN_OR) reduce 398) ((T_COALESCE) reduce 398) ((T_DOUBLE_ARROW) reduce 398) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 398) ((T_LOGICAL_OR) reduce 398) ((T_LOGICAL_XOR) reduce 398) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 398) (("|") reduce 398)) 15637 ((("%") shift) ((")") reduce 407) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 407) (("/") shift) (("<") reduce 407) ((">") reduce 407) (("?") reduce 407) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_BOOLEAN_AND) reduce 407) ((T_BOOLEAN_OR) reduce 407) ((T_COALESCE) reduce 407) ((T_DOUBLE_ARROW) reduce 407) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 407) ((T_IS_GREATER_OR_EQUAL) reduce 407) ((T_IS_IDENTICAL) reduce 407) ((T_IS_NOT_EQUAL) reduce 407) ((T_IS_NOT_IDENTICAL) reduce 407) ((T_IS_SMALLER_OR_EQUAL) reduce 407) ((T_LOGICAL_AND) reduce 407) ((T_LOGICAL_OR) reduce 407) ((T_LOGICAL_XOR) reduce 407) ((T_POW) shift) ((T_SL) reduce 407) ((T_SPACESHIP) reduce 407) ((T_SR) reduce 407) (("^") reduce 407) (("|") reduce 407)) 15638 ((("%") shift) ((")") reduce 420) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 420) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_BOOLEAN_AND) reduce 420) ((T_BOOLEAN_OR) reduce 420) ((T_COALESCE) reduce 420) ((T_DOUBLE_ARROW) reduce 420) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 420) ((T_LOGICAL_OR) reduce 420) ((T_LOGICAL_XOR) reduce 420) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 420) (("|") reduce 420)) 15639 ((("%") shift) ((")") reduce 406) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 406) (("/") shift) (("<") reduce 406) ((">") reduce 406) (("?") reduce 406) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_BOOLEAN_AND) reduce 406) ((T_BOOLEAN_OR) reduce 406) ((T_COALESCE) reduce 406) ((T_DOUBLE_ARROW) reduce 406) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 406) ((T_IS_GREATER_OR_EQUAL) reduce 406) ((T_IS_IDENTICAL) reduce 406) ((T_IS_NOT_EQUAL) reduce 406) ((T_IS_NOT_IDENTICAL) reduce 406) ((T_IS_SMALLER_OR_EQUAL) reduce 406) ((T_LOGICAL_AND) reduce 406) ((T_LOGICAL_OR) reduce 406) ((T_LOGICAL_XOR) reduce 406) ((T_POW) shift) ((T_SL) reduce 406) ((T_SPACESHIP) reduce 406) ((T_SR) reduce 406) (("^") reduce 406) (("|") reduce 406)) 15640 ((("%") reduce 403) ((")") reduce 403) (("*") reduce 403) (("+") reduce 403) (("-") reduce 403) ((".") reduce 403) (("/") reduce 403) (("<") reduce 403) ((">") reduce 403) (("?") reduce 403) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_BOOLEAN_AND) reduce 403) ((T_BOOLEAN_OR) reduce 403) ((T_COALESCE) reduce 403) ((T_DOUBLE_ARROW) reduce 403) ((T_INSTANCEOF) reduce 403) ((T_IS_EQUAL) reduce 403) ((T_IS_GREATER_OR_EQUAL) reduce 403) ((T_IS_IDENTICAL) reduce 403) ((T_IS_NOT_EQUAL) reduce 403) ((T_IS_NOT_IDENTICAL) reduce 403) ((T_IS_SMALLER_OR_EQUAL) reduce 403) ((T_LOGICAL_AND) reduce 403) ((T_LOGICAL_OR) reduce 403) ((T_LOGICAL_XOR) reduce 403) ((T_POW) shift) ((T_SL) reduce 403) ((T_SPACESHIP) reduce 403) ((T_SR) reduce 403) (("^") reduce 403) (("|") reduce 403)) 15641 ((("%") shift) ((")") reduce 394) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 394) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 394) ((T_LOGICAL_XOR) reduce 394) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15642 ((("%") shift) ((")") reduce 392) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 392) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 392) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15643 ((("%") shift) ((")") reduce 393) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 393) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 393) ((T_LOGICAL_OR) reduce 393) ((T_LOGICAL_XOR) reduce 393) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15644 ((("%") shift) ((")") reduce 417) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 417) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_BOOLEAN_AND) reduce 417) ((T_BOOLEAN_OR) reduce 417) ((T_COALESCE) reduce 417) ((T_DOUBLE_ARROW) reduce 417) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 417) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 417) ((T_IS_NOT_EQUAL) reduce 417) ((T_IS_NOT_IDENTICAL) reduce 417) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 417) ((T_LOGICAL_OR) reduce 417) ((T_LOGICAL_XOR) reduce 417) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 417) ((T_SR) shift) (("^") reduce 417) (("|") reduce 417)) 15645 ((("%") shift) ((")") reduce 413) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 413) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_BOOLEAN_AND) reduce 413) ((T_BOOLEAN_OR) reduce 413) ((T_COALESCE) reduce 413) ((T_DOUBLE_ARROW) reduce 413) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 413) ((T_LOGICAL_OR) reduce 413) ((T_LOGICAL_XOR) reduce 413) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 413) (("|") reduce 413)) 15646 ((("%") shift) ((")") reduce 415) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 415) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_BOOLEAN_AND) reduce 415) ((T_BOOLEAN_OR) reduce 415) ((T_COALESCE) reduce 415) ((T_DOUBLE_ARROW) reduce 415) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 415) ((T_LOGICAL_OR) reduce 415) ((T_LOGICAL_XOR) reduce 415) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 415) (("|") reduce 415)) 15647 ((("%") shift) ((")") reduce 412) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 412) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_BOOLEAN_AND) reduce 412) ((T_BOOLEAN_OR) reduce 412) ((T_COALESCE) reduce 412) ((T_DOUBLE_ARROW) reduce 412) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 412) ((T_LOGICAL_OR) reduce 412) ((T_LOGICAL_XOR) reduce 412) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 412) (("|") reduce 412)) 15648 ((("%") shift) ((")") reduce 419) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 419) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_BOOLEAN_AND) reduce 419) ((T_BOOLEAN_OR) reduce 419) ((T_COALESCE) reduce 419) ((T_DOUBLE_ARROW) reduce 419) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 419) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 419) ((T_IS_NOT_EQUAL) reduce 419) ((T_IS_NOT_IDENTICAL) reduce 419) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 419) ((T_LOGICAL_OR) reduce 419) ((T_LOGICAL_XOR) reduce 419) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 419) ((T_SR) shift) (("^") reduce 419) (("|") reduce 419)) 15649 ((("%") shift) ((")") reduce 414) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 414) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_BOOLEAN_AND) reduce 414) ((T_BOOLEAN_OR) reduce 414) ((T_COALESCE) reduce 414) ((T_DOUBLE_ARROW) reduce 414) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 414) ((T_LOGICAL_OR) reduce 414) ((T_LOGICAL_XOR) reduce 414) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 414) (("|") reduce 414)) 15652 ((("%") reduce 93) ((")") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93)) 15653 ((("%") reduce 92) ((")") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92)) 15654 ((("%") reduce 94) ((")") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94)) 15655 ((("%") reduce 470) ((")") reduce 470) (("*") reduce 470) (("+") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_DOUBLE_ARROW) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470)) 15656 ((("%") reduce 91) ((")") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91)) 15657 ((("%") reduce 529) ((")") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 15658 ((("%") reduce 472) ((")") reduce 472) (("*") reduce 472) (("+") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_DOUBLE_ARROW) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472)) 15659 ((("%") reduce 421) ((")") reduce 421) (("*") reduce 421) (("+") reduce 421) (("-") reduce 421) ((".") reduce 421) (("/") reduce 421) (("<") reduce 421) ((">") reduce 421) (("?") reduce 421) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_BOOLEAN_AND) reduce 421) ((T_BOOLEAN_OR) reduce 421) ((T_COALESCE) reduce 421) ((T_DOUBLE_ARROW) reduce 421) ((T_INSTANCEOF) reduce 421) ((T_IS_EQUAL) reduce 421) ((T_IS_GREATER_OR_EQUAL) reduce 421) ((T_IS_IDENTICAL) reduce 421) ((T_IS_NOT_EQUAL) reduce 421) ((T_IS_NOT_IDENTICAL) reduce 421) ((T_IS_SMALLER_OR_EQUAL) reduce 421) ((T_LOGICAL_AND) reduce 421) ((T_LOGICAL_OR) reduce 421) ((T_LOGICAL_XOR) reduce 421) ((T_POW) reduce 421) ((T_SL) reduce 421) ((T_SPACESHIP) reduce 421) ((T_SR) reduce 421) (("^") reduce 421) (("|") reduce 421)) 15660 ((("%") reduce 471) ((")") reduce 471) (("*") reduce 471) (("+") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_DOUBLE_ARROW) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471)) 15661 ((("%") reduce 473) ((")") reduce 473) (("*") reduce 473) (("+") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_DOUBLE_ARROW) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 15662 ((("%") reduce 534) ((")") reduce 534) (("*") reduce 534) (("+") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_DOUBLE_ARROW) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 15669 ((("%") reduce 536) ((")") reduce 536) (("*") reduce 536) (("+") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_DOUBLE_ARROW) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 15671 ((("%") reduce 535) ((")") reduce 535) (("*") reduce 535) (("+") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_DOUBLE_ARROW) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 15672 ((("%") reduce 540) ((")") reduce 540) (("*") reduce 540) (("+") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_DOUBLE_ARROW) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 15673 ((("%") reduce 544) ((")") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 15674 ((("%") reduce 537) ((")") reduce 537) (("*") reduce 537) (("+") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_DOUBLE_ARROW) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 15675 ((("%") reduce 546) ((")") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 15678 ((("%") reduce 545) ((")") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 15679 ((("%") reduce 538) ((")") reduce 538) (("*") reduce 538) (("+") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_DOUBLE_ARROW) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 15681 ((("%") reduce 539) ((")") reduce 539) (("*") reduce 539) (("+") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_DOUBLE_ARROW) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 15683 ((("%") reduce 474) ((")") reduce 474) (("*") reduce 474) (("+") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_DOUBLE_ARROW) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474)) 15684 ((("%") reduce 531) ((")") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 15687 ((("%") reduce 530) ((")") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 15688 ((("%") shift) ((")") reduce 426) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 426) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 426) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 426) ((T_LOGICAL_OR) reduce 426) ((T_LOGICAL_XOR) reduce 426) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15689 ((("%") shift) ((")") reduce 390) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 390) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) reduce 390) ((T_COALESCE) reduce 390) ((T_DOUBLE_ARROW) reduce 390) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 390) ((T_LOGICAL_OR) reduce 390) ((T_LOGICAL_XOR) reduce 390) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15690 ((("%") shift) ((")") reduce 391) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 391) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 391) ((T_BOOLEAN_OR) reduce 391) ((T_COALESCE) reduce 391) ((T_DOUBLE_ARROW) reduce 391) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 391) ((T_LOGICAL_OR) reduce 391) ((T_LOGICAL_XOR) reduce 391) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15691 ((("%") shift) ((")") reduce 396) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 396) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_BOOLEAN_AND) reduce 396) ((T_BOOLEAN_OR) reduce 396) ((T_COALESCE) reduce 396) ((T_DOUBLE_ARROW) reduce 396) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 396) ((T_LOGICAL_OR) reduce 396) ((T_LOGICAL_XOR) reduce 396) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 396) (("|") reduce 396)) 15692 ((("%") shift) ((")") reduce 397) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 397) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_BOOLEAN_AND) reduce 397) ((T_BOOLEAN_OR) reduce 397) ((T_COALESCE) reduce 397) ((T_DOUBLE_ARROW) reduce 397) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 397) ((T_LOGICAL_OR) reduce 397) ((T_LOGICAL_XOR) reduce 397) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 397) (("|") reduce 397)) 15696 ((("%") shift) ((")") reduce 424) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 424) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 424) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 424) ((T_LOGICAL_OR) reduce 424) ((T_LOGICAL_XOR) reduce 424) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15697 ((("%") shift) ((")") reduce 425) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 425) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 425) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 425) ((T_LOGICAL_OR) reduce 425) ((T_LOGICAL_XOR) reduce 425) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15698 ((("%") shift) ((")") reduce 418) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 418) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_BOOLEAN_AND) reduce 418) ((T_BOOLEAN_OR) reduce 418) ((T_COALESCE) reduce 418) ((T_DOUBLE_ARROW) reduce 418) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 418) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 418) ((T_IS_NOT_EQUAL) reduce 418) ((T_IS_NOT_IDENTICAL) reduce 418) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 418) ((T_LOGICAL_OR) reduce 418) ((T_LOGICAL_XOR) reduce 418) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 418) ((T_SR) shift) (("^") reduce 418) (("|") reduce 418)) 15699 ((("%") shift) ((")") reduce 416) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 416) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_BOOLEAN_AND) reduce 416) ((T_BOOLEAN_OR) reduce 416) ((T_COALESCE) reduce 416) ((T_DOUBLE_ARROW) reduce 416) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 416) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 416) ((T_IS_NOT_EQUAL) reduce 416) ((T_IS_NOT_IDENTICAL) reduce 416) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 416) ((T_LOGICAL_OR) reduce 416) ((T_LOGICAL_XOR) reduce 416) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 416) ((T_SR) shift) (("^") reduce 416) (("|") reduce 416)) 15700 ((("%") reduce 404) ((")") reduce 404) (("*") reduce 404) (("+") reduce 404) (("-") reduce 404) ((".") reduce 404) (("/") reduce 404) (("<") reduce 404) ((">") reduce 404) (("?") reduce 404) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_BOOLEAN_AND) reduce 404) ((T_BOOLEAN_OR) reduce 404) ((T_COALESCE) reduce 404) ((T_DOUBLE_ARROW) reduce 404) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 404) ((T_IS_GREATER_OR_EQUAL) reduce 404) ((T_IS_IDENTICAL) reduce 404) ((T_IS_NOT_EQUAL) reduce 404) ((T_IS_NOT_IDENTICAL) reduce 404) ((T_IS_SMALLER_OR_EQUAL) reduce 404) ((T_LOGICAL_AND) reduce 404) ((T_LOGICAL_OR) reduce 404) ((T_LOGICAL_XOR) reduce 404) ((T_POW) shift) ((T_SL) reduce 404) ((T_SPACESHIP) reduce 404) ((T_SR) reduce 404) (("^") reduce 404) (("|") reduce 404)) 15701 ((("%") shift) ((")") reduce 399) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 399) (("/") shift) (("<") reduce 399) ((">") reduce 399) (("?") reduce 399) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_BOOLEAN_AND) reduce 399) ((T_BOOLEAN_OR) reduce 399) ((T_COALESCE) reduce 399) ((T_DOUBLE_ARROW) reduce 399) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 399) ((T_IS_GREATER_OR_EQUAL) reduce 399) ((T_IS_IDENTICAL) reduce 399) ((T_IS_NOT_EQUAL) reduce 399) ((T_IS_NOT_IDENTICAL) reduce 399) ((T_IS_SMALLER_OR_EQUAL) reduce 399) ((T_LOGICAL_AND) reduce 399) ((T_LOGICAL_OR) reduce 399) ((T_LOGICAL_XOR) reduce 399) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 399) ((T_SR) shift) (("^") reduce 399) (("|") reduce 399)) 15702 ((("%") shift) ((")") reduce 401) (("*") shift) (("+") reduce 401) (("-") reduce 401) ((".") reduce 401) (("/") shift) (("<") reduce 401) ((">") reduce 401) (("?") reduce 401) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_BOOLEAN_AND) reduce 401) ((T_BOOLEAN_OR) reduce 401) ((T_COALESCE) reduce 401) ((T_DOUBLE_ARROW) reduce 401) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 401) ((T_IS_GREATER_OR_EQUAL) reduce 401) ((T_IS_IDENTICAL) reduce 401) ((T_IS_NOT_EQUAL) reduce 401) ((T_IS_NOT_IDENTICAL) reduce 401) ((T_IS_SMALLER_OR_EQUAL) reduce 401) ((T_LOGICAL_AND) reduce 401) ((T_LOGICAL_OR) reduce 401) ((T_LOGICAL_XOR) reduce 401) ((T_POW) shift) ((T_SL) reduce 401) ((T_SPACESHIP) reduce 401) ((T_SR) reduce 401) (("^") reduce 401) (("|") reduce 401)) 15703 ((("%") shift) ((")") reduce 400) (("*") shift) (("+") reduce 400) (("-") reduce 400) ((".") reduce 400) (("/") shift) (("<") reduce 400) ((">") reduce 400) (("?") reduce 400) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_BOOLEAN_AND) reduce 400) ((T_BOOLEAN_OR) reduce 400) ((T_COALESCE) reduce 400) ((T_DOUBLE_ARROW) reduce 400) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 400) ((T_IS_GREATER_OR_EQUAL) reduce 400) ((T_IS_IDENTICAL) reduce 400) ((T_IS_NOT_EQUAL) reduce 400) ((T_IS_NOT_IDENTICAL) reduce 400) ((T_IS_SMALLER_OR_EQUAL) reduce 400) ((T_LOGICAL_AND) reduce 400) ((T_LOGICAL_OR) reduce 400) ((T_LOGICAL_XOR) reduce 400) ((T_POW) shift) ((T_SL) reduce 400) ((T_SPACESHIP) reduce 400) ((T_SR) reduce 400) (("^") reduce 400) (("|") reduce 400)) 15704 ((("%") reduce 402) ((")") reduce 402) (("*") reduce 402) (("+") reduce 402) (("-") reduce 402) ((".") reduce 402) (("/") reduce 402) (("<") reduce 402) ((">") reduce 402) (("?") reduce 402) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_BOOLEAN_AND) reduce 402) ((T_BOOLEAN_OR) reduce 402) ((T_COALESCE) reduce 402) ((T_DOUBLE_ARROW) reduce 402) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 402) ((T_IS_GREATER_OR_EQUAL) reduce 402) ((T_IS_IDENTICAL) reduce 402) ((T_IS_NOT_EQUAL) reduce 402) ((T_IS_NOT_IDENTICAL) reduce 402) ((T_IS_SMALLER_OR_EQUAL) reduce 402) ((T_LOGICAL_AND) reduce 402) ((T_LOGICAL_OR) reduce 402) ((T_LOGICAL_XOR) reduce 402) ((T_POW) shift) ((T_SL) reduce 402) ((T_SPACESHIP) reduce 402) ((T_SR) reduce 402) (("^") reduce 402) (("|") reduce 402)) 15705 ((("%") reduce 405) ((")") reduce 405) (("*") reduce 405) (("+") reduce 405) (("-") reduce 405) ((".") reduce 405) (("/") reduce 405) (("<") reduce 405) ((">") reduce 405) (("?") reduce 405) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_BOOLEAN_AND) reduce 405) ((T_BOOLEAN_OR) reduce 405) ((T_COALESCE) reduce 405) ((T_DOUBLE_ARROW) reduce 405) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 405) ((T_IS_GREATER_OR_EQUAL) reduce 405) ((T_IS_IDENTICAL) reduce 405) ((T_IS_NOT_EQUAL) reduce 405) ((T_IS_NOT_IDENTICAL) reduce 405) ((T_IS_SMALLER_OR_EQUAL) reduce 405) ((T_LOGICAL_AND) reduce 405) ((T_LOGICAL_OR) reduce 405) ((T_LOGICAL_XOR) reduce 405) ((T_POW) shift) ((T_SL) reduce 405) ((T_SPACESHIP) reduce 405) ((T_SR) reduce 405) (("^") reduce 405) (("|") reduce 405)) 15707 ((("%") reduce 73) (("(") reduce 73) ((")") reduce 73) (("*") reduce 73) (("+") reduce 73) (("-") reduce 73) ((".") reduce 73) (("/") reduce 73) (("<") reduce 73) ((">") reduce 73) (("?") reduce 73) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_BOOLEAN_AND) reduce 73) ((T_BOOLEAN_OR) reduce 73) ((T_COALESCE) reduce 73) ((T_DOUBLE_ARROW) reduce 73) ((T_INSTANCEOF) reduce 73) ((T_IS_EQUAL) reduce 73) ((T_IS_GREATER_OR_EQUAL) reduce 73) ((T_IS_IDENTICAL) reduce 73) ((T_IS_NOT_EQUAL) reduce 73) ((T_IS_NOT_IDENTICAL) reduce 73) ((T_IS_SMALLER_OR_EQUAL) reduce 73) ((T_LOGICAL_AND) reduce 73) ((T_LOGICAL_OR) reduce 73) ((T_LOGICAL_XOR) reduce 73) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 73) ((T_OBJECT_OPERATOR) reduce 73) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 73) ((T_POW) reduce 73) ((T_SL) reduce 73) ((T_SPACESHIP) reduce 73) ((T_SR) reduce 73) (("[") reduce 73) (("^") reduce 73) (("{") reduce 73) (("|") reduce 73)) 15708 ((("%") reduce 52) (("(") reduce 52) ((")") reduce 52) (("*") reduce 52) (("+") reduce 52) (("-") reduce 52) ((".") reduce 52) (("/") reduce 52) (("<") reduce 52) ((">") reduce 52) (("?") reduce 52) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_BOOLEAN_AND) reduce 52) ((T_BOOLEAN_OR) reduce 52) ((T_COALESCE) reduce 52) ((T_DOUBLE_ARROW) reduce 52) ((T_INSTANCEOF) reduce 52) ((T_IS_EQUAL) reduce 52) ((T_IS_GREATER_OR_EQUAL) reduce 52) ((T_IS_IDENTICAL) reduce 52) ((T_IS_NOT_EQUAL) reduce 52) ((T_IS_NOT_IDENTICAL) reduce 52) ((T_IS_SMALLER_OR_EQUAL) reduce 52) ((T_LOGICAL_AND) reduce 52) ((T_LOGICAL_OR) reduce 52) ((T_LOGICAL_XOR) reduce 52) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 52) ((T_OBJECT_OPERATOR) reduce 52) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 52) ((T_POW) reduce 52) ((T_SL) reduce 52) ((T_SPACESHIP) reduce 52) ((T_SR) reduce 52) (("[") reduce 52) (("^") reduce 52) (("{") reduce 52) (("|") reduce 52)) 15709 ((("%") reduce 27) (("(") reduce 27) ((")") reduce 27) (("*") reduce 27) (("+") reduce 27) (("-") reduce 27) ((".") reduce 27) (("/") reduce 27) (("<") reduce 27) ((">") reduce 27) (("?") reduce 27) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_BOOLEAN_AND) reduce 27) ((T_BOOLEAN_OR) reduce 27) ((T_COALESCE) reduce 27) ((T_DOUBLE_ARROW) reduce 27) ((T_INSTANCEOF) reduce 27) ((T_IS_EQUAL) reduce 27) ((T_IS_GREATER_OR_EQUAL) reduce 27) ((T_IS_IDENTICAL) reduce 27) ((T_IS_NOT_EQUAL) reduce 27) ((T_IS_NOT_IDENTICAL) reduce 27) ((T_IS_SMALLER_OR_EQUAL) reduce 27) ((T_LOGICAL_AND) reduce 27) ((T_LOGICAL_OR) reduce 27) ((T_LOGICAL_XOR) reduce 27) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 27) ((T_OBJECT_OPERATOR) reduce 27) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 27) ((T_POW) reduce 27) ((T_SL) reduce 27) ((T_SPACESHIP) reduce 27) ((T_SR) reduce 27) (("[") reduce 27) (("^") reduce 27) (("{") reduce 27) (("|") reduce 27)) 15710 ((("%") reduce 51) (("(") reduce 51) ((")") reduce 51) (("*") reduce 51) (("+") reduce 51) (("-") reduce 51) ((".") reduce 51) (("/") reduce 51) (("<") reduce 51) ((">") reduce 51) (("?") reduce 51) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_BOOLEAN_AND) reduce 51) ((T_BOOLEAN_OR) reduce 51) ((T_COALESCE) reduce 51) ((T_DOUBLE_ARROW) reduce 51) ((T_INSTANCEOF) reduce 51) ((T_IS_EQUAL) reduce 51) ((T_IS_GREATER_OR_EQUAL) reduce 51) ((T_IS_IDENTICAL) reduce 51) ((T_IS_NOT_EQUAL) reduce 51) ((T_IS_NOT_IDENTICAL) reduce 51) ((T_IS_SMALLER_OR_EQUAL) reduce 51) ((T_LOGICAL_AND) reduce 51) ((T_LOGICAL_OR) reduce 51) ((T_LOGICAL_XOR) reduce 51) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 51) ((T_OBJECT_OPERATOR) reduce 51) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 51) ((T_POW) reduce 51) ((T_SL) reduce 51) ((T_SPACESHIP) reduce 51) ((T_SR) reduce 51) (("[") reduce 51) (("^") reduce 51) (("{") reduce 51) (("|") reduce 51)) 15711 ((("%") reduce 53) (("(") reduce 53) ((")") reduce 53) (("*") reduce 53) (("+") reduce 53) (("-") reduce 53) ((".") reduce 53) (("/") reduce 53) (("<") reduce 53) ((">") reduce 53) (("?") reduce 53) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_BOOLEAN_AND) reduce 53) ((T_BOOLEAN_OR) reduce 53) ((T_COALESCE) reduce 53) ((T_DOUBLE_ARROW) reduce 53) ((T_INSTANCEOF) reduce 53) ((T_IS_EQUAL) reduce 53) ((T_IS_GREATER_OR_EQUAL) reduce 53) ((T_IS_IDENTICAL) reduce 53) ((T_IS_NOT_EQUAL) reduce 53) ((T_IS_NOT_IDENTICAL) reduce 53) ((T_IS_SMALLER_OR_EQUAL) reduce 53) ((T_LOGICAL_AND) reduce 53) ((T_LOGICAL_OR) reduce 53) ((T_LOGICAL_XOR) reduce 53) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 53) ((T_OBJECT_OPERATOR) reduce 53) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 53) ((T_POW) reduce 53) ((T_SL) reduce 53) ((T_SPACESHIP) reduce 53) ((T_SR) reduce 53) (("[") reduce 53) (("^") reduce 53) (("{") reduce 53) (("|") reduce 53)) 15712 ((("%") reduce 49) (("(") reduce 49) ((")") reduce 49) (("*") reduce 49) (("+") reduce 49) (("-") reduce 49) ((".") reduce 49) (("/") reduce 49) (("<") reduce 49) ((">") reduce 49) (("?") reduce 49) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_BOOLEAN_AND) reduce 49) ((T_BOOLEAN_OR) reduce 49) ((T_COALESCE) reduce 49) ((T_DOUBLE_ARROW) reduce 49) ((T_INSTANCEOF) reduce 49) ((T_IS_EQUAL) reduce 49) ((T_IS_GREATER_OR_EQUAL) reduce 49) ((T_IS_IDENTICAL) reduce 49) ((T_IS_NOT_EQUAL) reduce 49) ((T_IS_NOT_IDENTICAL) reduce 49) ((T_IS_SMALLER_OR_EQUAL) reduce 49) ((T_LOGICAL_AND) reduce 49) ((T_LOGICAL_OR) reduce 49) ((T_LOGICAL_XOR) reduce 49) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 49) ((T_OBJECT_OPERATOR) reduce 49) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 49) ((T_POW) reduce 49) ((T_SL) reduce 49) ((T_SPACESHIP) reduce 49) ((T_SR) reduce 49) (("[") reduce 49) (("^") reduce 49) (("{") reduce 49) (("|") reduce 49)) 15713 ((("%") reduce 29) (("(") reduce 29) ((")") reduce 29) (("*") reduce 29) (("+") reduce 29) (("-") reduce 29) ((".") reduce 29) (("/") reduce 29) (("<") reduce 29) ((">") reduce 29) (("?") reduce 29) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_BOOLEAN_AND) reduce 29) ((T_BOOLEAN_OR) reduce 29) ((T_COALESCE) reduce 29) ((T_DOUBLE_ARROW) reduce 29) ((T_INSTANCEOF) reduce 29) ((T_IS_EQUAL) reduce 29) ((T_IS_GREATER_OR_EQUAL) reduce 29) ((T_IS_IDENTICAL) reduce 29) ((T_IS_NOT_EQUAL) reduce 29) ((T_IS_NOT_IDENTICAL) reduce 29) ((T_IS_SMALLER_OR_EQUAL) reduce 29) ((T_LOGICAL_AND) reduce 29) ((T_LOGICAL_OR) reduce 29) ((T_LOGICAL_XOR) reduce 29) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 29) ((T_OBJECT_OPERATOR) reduce 29) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 29) ((T_POW) reduce 29) ((T_SL) reduce 29) ((T_SPACESHIP) reduce 29) ((T_SR) reduce 29) (("[") reduce 29) (("^") reduce 29) (("{") reduce 29) (("|") reduce 29)) 15714 ((("%") reduce 59) (("(") reduce 59) ((")") reduce 59) (("*") reduce 59) (("+") reduce 59) (("-") reduce 59) ((".") reduce 59) (("/") reduce 59) (("<") reduce 59) ((">") reduce 59) (("?") reduce 59) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_BOOLEAN_AND) reduce 59) ((T_BOOLEAN_OR) reduce 59) ((T_COALESCE) reduce 59) ((T_DOUBLE_ARROW) reduce 59) ((T_INSTANCEOF) reduce 59) ((T_IS_EQUAL) reduce 59) ((T_IS_GREATER_OR_EQUAL) reduce 59) ((T_IS_IDENTICAL) reduce 59) ((T_IS_NOT_EQUAL) reduce 59) ((T_IS_NOT_IDENTICAL) reduce 59) ((T_IS_SMALLER_OR_EQUAL) reduce 59) ((T_LOGICAL_AND) reduce 59) ((T_LOGICAL_OR) reduce 59) ((T_LOGICAL_XOR) reduce 59) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 59) ((T_OBJECT_OPERATOR) reduce 59) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 59) ((T_POW) reduce 59) ((T_SL) reduce 59) ((T_SPACESHIP) reduce 59) ((T_SR) reduce 59) (("[") reduce 59) (("^") reduce 59) (("{") reduce 59) (("|") reduce 59)) 15715 ((("%") reduce 60) (("(") reduce 60) ((")") reduce 60) (("*") reduce 60) (("+") reduce 60) (("-") reduce 60) ((".") reduce 60) (("/") reduce 60) (("<") reduce 60) ((">") reduce 60) (("?") reduce 60) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_BOOLEAN_AND) reduce 60) ((T_BOOLEAN_OR) reduce 60) ((T_COALESCE) reduce 60) ((T_DOUBLE_ARROW) reduce 60) ((T_INSTANCEOF) reduce 60) ((T_IS_EQUAL) reduce 60) ((T_IS_GREATER_OR_EQUAL) reduce 60) ((T_IS_IDENTICAL) reduce 60) ((T_IS_NOT_EQUAL) reduce 60) ((T_IS_NOT_IDENTICAL) reduce 60) ((T_IS_SMALLER_OR_EQUAL) reduce 60) ((T_LOGICAL_AND) reduce 60) ((T_LOGICAL_OR) reduce 60) ((T_LOGICAL_XOR) reduce 60) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 60) ((T_OBJECT_OPERATOR) reduce 60) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 60) ((T_POW) reduce 60) ((T_SL) reduce 60) ((T_SPACESHIP) reduce 60) ((T_SR) reduce 60) (("[") reduce 60) (("^") reduce 60) (("{") reduce 60) (("|") reduce 60)) 15716 ((("%") reduce 11) (("(") reduce 11) ((")") reduce 11) (("*") reduce 11) (("+") reduce 11) (("-") reduce 11) ((".") reduce 11) (("/") reduce 11) (("<") reduce 11) ((">") reduce 11) (("?") reduce 11) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_BOOLEAN_AND) reduce 11) ((T_BOOLEAN_OR) reduce 11) ((T_COALESCE) reduce 11) ((T_DOUBLE_ARROW) reduce 11) ((T_INSTANCEOF) reduce 11) ((T_IS_EQUAL) reduce 11) ((T_IS_GREATER_OR_EQUAL) reduce 11) ((T_IS_IDENTICAL) reduce 11) ((T_IS_NOT_EQUAL) reduce 11) ((T_IS_NOT_IDENTICAL) reduce 11) ((T_IS_SMALLER_OR_EQUAL) reduce 11) ((T_LOGICAL_AND) reduce 11) ((T_LOGICAL_OR) reduce 11) ((T_LOGICAL_XOR) reduce 11) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 11) ((T_OBJECT_OPERATOR) reduce 11) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 11) ((T_POW) reduce 11) ((T_SL) reduce 11) ((T_SPACESHIP) reduce 11) ((T_SR) reduce 11) (("[") reduce 11) (("^") reduce 11) (("{") reduce 11) (("|") reduce 11)) 15717 ((("%") reduce 42) (("(") reduce 42) ((")") reduce 42) (("*") reduce 42) (("+") reduce 42) (("-") reduce 42) ((".") reduce 42) (("/") reduce 42) (("<") reduce 42) ((">") reduce 42) (("?") reduce 42) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_BOOLEAN_AND) reduce 42) ((T_BOOLEAN_OR) reduce 42) ((T_COALESCE) reduce 42) ((T_DOUBLE_ARROW) reduce 42) ((T_INSTANCEOF) reduce 42) ((T_IS_EQUAL) reduce 42) ((T_IS_GREATER_OR_EQUAL) reduce 42) ((T_IS_IDENTICAL) reduce 42) ((T_IS_NOT_EQUAL) reduce 42) ((T_IS_NOT_IDENTICAL) reduce 42) ((T_IS_SMALLER_OR_EQUAL) reduce 42) ((T_LOGICAL_AND) reduce 42) ((T_LOGICAL_OR) reduce 42) ((T_LOGICAL_XOR) reduce 42) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 42) ((T_OBJECT_OPERATOR) reduce 42) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 42) ((T_POW) reduce 42) ((T_SL) reduce 42) ((T_SPACESHIP) reduce 42) ((T_SR) reduce 42) (("[") reduce 42) (("^") reduce 42) (("{") reduce 42) (("|") reduce 42)) 15718 ((("%") reduce 39) (("(") reduce 39) ((")") reduce 39) (("*") reduce 39) (("+") reduce 39) (("-") reduce 39) ((".") reduce 39) (("/") reduce 39) (("<") reduce 39) ((">") reduce 39) (("?") reduce 39) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_BOOLEAN_AND) reduce 39) ((T_BOOLEAN_OR) reduce 39) ((T_COALESCE) reduce 39) ((T_DOUBLE_ARROW) reduce 39) ((T_INSTANCEOF) reduce 39) ((T_IS_EQUAL) reduce 39) ((T_IS_GREATER_OR_EQUAL) reduce 39) ((T_IS_IDENTICAL) reduce 39) ((T_IS_NOT_EQUAL) reduce 39) ((T_IS_NOT_IDENTICAL) reduce 39) ((T_IS_SMALLER_OR_EQUAL) reduce 39) ((T_LOGICAL_AND) reduce 39) ((T_LOGICAL_OR) reduce 39) ((T_LOGICAL_XOR) reduce 39) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 39) ((T_OBJECT_OPERATOR) reduce 39) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 39) ((T_POW) reduce 39) ((T_SL) reduce 39) ((T_SPACESHIP) reduce 39) ((T_SR) reduce 39) (("[") reduce 39) (("^") reduce 39) (("{") reduce 39) (("|") reduce 39)) 15719 ((("%") reduce 25) (("(") reduce 25) ((")") reduce 25) (("*") reduce 25) (("+") reduce 25) (("-") reduce 25) ((".") reduce 25) (("/") reduce 25) (("<") reduce 25) ((">") reduce 25) (("?") reduce 25) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_BOOLEAN_AND) reduce 25) ((T_BOOLEAN_OR) reduce 25) ((T_COALESCE) reduce 25) ((T_DOUBLE_ARROW) reduce 25) ((T_INSTANCEOF) reduce 25) ((T_IS_EQUAL) reduce 25) ((T_IS_GREATER_OR_EQUAL) reduce 25) ((T_IS_IDENTICAL) reduce 25) ((T_IS_NOT_EQUAL) reduce 25) ((T_IS_NOT_IDENTICAL) reduce 25) ((T_IS_SMALLER_OR_EQUAL) reduce 25) ((T_LOGICAL_AND) reduce 25) ((T_LOGICAL_OR) reduce 25) ((T_LOGICAL_XOR) reduce 25) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 25) ((T_OBJECT_OPERATOR) reduce 25) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 25) ((T_POW) reduce 25) ((T_SL) reduce 25) ((T_SPACESHIP) reduce 25) ((T_SR) reduce 25) (("[") reduce 25) (("^") reduce 25) (("{") reduce 25) (("|") reduce 25)) 15720 ((("%") reduce 50) (("(") reduce 50) ((")") reduce 50) (("*") reduce 50) (("+") reduce 50) (("-") reduce 50) ((".") reduce 50) (("/") reduce 50) (("<") reduce 50) ((">") reduce 50) (("?") reduce 50) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_BOOLEAN_AND) reduce 50) ((T_BOOLEAN_OR) reduce 50) ((T_COALESCE) reduce 50) ((T_DOUBLE_ARROW) reduce 50) ((T_INSTANCEOF) reduce 50) ((T_IS_EQUAL) reduce 50) ((T_IS_GREATER_OR_EQUAL) reduce 50) ((T_IS_IDENTICAL) reduce 50) ((T_IS_NOT_EQUAL) reduce 50) ((T_IS_NOT_IDENTICAL) reduce 50) ((T_IS_SMALLER_OR_EQUAL) reduce 50) ((T_LOGICAL_AND) reduce 50) ((T_LOGICAL_OR) reduce 50) ((T_LOGICAL_XOR) reduce 50) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 50) ((T_OBJECT_OPERATOR) reduce 50) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 50) ((T_POW) reduce 50) ((T_SL) reduce 50) ((T_SPACESHIP) reduce 50) ((T_SR) reduce 50) (("[") reduce 50) (("^") reduce 50) (("{") reduce 50) (("|") reduce 50)) 15721 ((("%") reduce 66) (("(") reduce 66) ((")") reduce 66) (("*") reduce 66) (("+") reduce 66) (("-") reduce 66) ((".") reduce 66) (("/") reduce 66) (("<") reduce 66) ((">") reduce 66) (("?") reduce 66) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_BOOLEAN_AND) reduce 66) ((T_BOOLEAN_OR) reduce 66) ((T_COALESCE) reduce 66) ((T_DOUBLE_ARROW) reduce 66) ((T_INSTANCEOF) reduce 66) ((T_IS_EQUAL) reduce 66) ((T_IS_GREATER_OR_EQUAL) reduce 66) ((T_IS_IDENTICAL) reduce 66) ((T_IS_NOT_EQUAL) reduce 66) ((T_IS_NOT_IDENTICAL) reduce 66) ((T_IS_SMALLER_OR_EQUAL) reduce 66) ((T_LOGICAL_AND) reduce 66) ((T_LOGICAL_OR) reduce 66) ((T_LOGICAL_XOR) reduce 66) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 66) ((T_OBJECT_OPERATOR) reduce 66) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 66) ((T_POW) reduce 66) ((T_SL) reduce 66) ((T_SPACESHIP) reduce 66) ((T_SR) reduce 66) (("[") reduce 66) (("^") reduce 66) (("{") reduce 66) (("|") reduce 66)) 15722 ((("%") reduce 18) (("(") reduce 18) ((")") reduce 18) (("*") reduce 18) (("+") reduce 18) (("-") reduce 18) ((".") reduce 18) (("/") reduce 18) (("<") reduce 18) ((">") reduce 18) (("?") reduce 18) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_BOOLEAN_AND) reduce 18) ((T_BOOLEAN_OR) reduce 18) ((T_COALESCE) reduce 18) ((T_DOUBLE_ARROW) reduce 18) ((T_INSTANCEOF) reduce 18) ((T_IS_EQUAL) reduce 18) ((T_IS_GREATER_OR_EQUAL) reduce 18) ((T_IS_IDENTICAL) reduce 18) ((T_IS_NOT_EQUAL) reduce 18) ((T_IS_NOT_IDENTICAL) reduce 18) ((T_IS_SMALLER_OR_EQUAL) reduce 18) ((T_LOGICAL_AND) reduce 18) ((T_LOGICAL_OR) reduce 18) ((T_LOGICAL_XOR) reduce 18) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 18) ((T_OBJECT_OPERATOR) reduce 18) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 18) ((T_POW) reduce 18) ((T_SL) reduce 18) ((T_SPACESHIP) reduce 18) ((T_SR) reduce 18) (("[") reduce 18) (("^") reduce 18) (("{") reduce 18) (("|") reduce 18)) 15723 ((("%") reduce 17) (("(") reduce 17) ((")") reduce 17) (("*") reduce 17) (("+") reduce 17) (("-") reduce 17) ((".") reduce 17) (("/") reduce 17) (("<") reduce 17) ((">") reduce 17) (("?") reduce 17) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_BOOLEAN_AND) reduce 17) ((T_BOOLEAN_OR) reduce 17) ((T_COALESCE) reduce 17) ((T_DOUBLE_ARROW) reduce 17) ((T_INSTANCEOF) reduce 17) ((T_IS_EQUAL) reduce 17) ((T_IS_GREATER_OR_EQUAL) reduce 17) ((T_IS_IDENTICAL) reduce 17) ((T_IS_NOT_EQUAL) reduce 17) ((T_IS_NOT_IDENTICAL) reduce 17) ((T_IS_SMALLER_OR_EQUAL) reduce 17) ((T_LOGICAL_AND) reduce 17) ((T_LOGICAL_OR) reduce 17) ((T_LOGICAL_XOR) reduce 17) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 17) ((T_OBJECT_OPERATOR) reduce 17) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 17) ((T_POW) reduce 17) ((T_SL) reduce 17) ((T_SPACESHIP) reduce 17) ((T_SR) reduce 17) (("[") reduce 17) (("^") reduce 17) (("{") reduce 17) (("|") reduce 17)) 15724 ((("%") reduce 15) (("(") reduce 15) ((")") reduce 15) (("*") reduce 15) (("+") reduce 15) (("-") reduce 15) ((".") reduce 15) (("/") reduce 15) (("<") reduce 15) ((">") reduce 15) (("?") reduce 15) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_BOOLEAN_AND) reduce 15) ((T_BOOLEAN_OR) reduce 15) ((T_COALESCE) reduce 15) ((T_DOUBLE_ARROW) reduce 15) ((T_INSTANCEOF) reduce 15) ((T_IS_EQUAL) reduce 15) ((T_IS_GREATER_OR_EQUAL) reduce 15) ((T_IS_IDENTICAL) reduce 15) ((T_IS_NOT_EQUAL) reduce 15) ((T_IS_NOT_IDENTICAL) reduce 15) ((T_IS_SMALLER_OR_EQUAL) reduce 15) ((T_LOGICAL_AND) reduce 15) ((T_LOGICAL_OR) reduce 15) ((T_LOGICAL_XOR) reduce 15) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 15) ((T_OBJECT_OPERATOR) reduce 15) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 15) ((T_POW) reduce 15) ((T_SL) reduce 15) ((T_SPACESHIP) reduce 15) ((T_SR) reduce 15) (("[") reduce 15) (("^") reduce 15) (("{") reduce 15) (("|") reduce 15)) 15725 ((("%") reduce 14) (("(") reduce 14) ((")") reduce 14) (("*") reduce 14) (("+") reduce 14) (("-") reduce 14) ((".") reduce 14) (("/") reduce 14) (("<") reduce 14) ((">") reduce 14) (("?") reduce 14) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_BOOLEAN_AND) reduce 14) ((T_BOOLEAN_OR) reduce 14) ((T_COALESCE) reduce 14) ((T_DOUBLE_ARROW) reduce 14) ((T_INSTANCEOF) reduce 14) ((T_IS_EQUAL) reduce 14) ((T_IS_GREATER_OR_EQUAL) reduce 14) ((T_IS_IDENTICAL) reduce 14) ((T_IS_NOT_EQUAL) reduce 14) ((T_IS_NOT_IDENTICAL) reduce 14) ((T_IS_SMALLER_OR_EQUAL) reduce 14) ((T_LOGICAL_AND) reduce 14) ((T_LOGICAL_OR) reduce 14) ((T_LOGICAL_XOR) reduce 14) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 14) ((T_OBJECT_OPERATOR) reduce 14) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 14) ((T_POW) reduce 14) ((T_SL) reduce 14) ((T_SPACESHIP) reduce 14) ((T_SR) reduce 14) (("[") reduce 14) (("^") reduce 14) (("{") reduce 14) (("|") reduce 14)) 15726 ((("%") reduce 38) (("(") reduce 38) ((")") reduce 38) (("*") reduce 38) (("+") reduce 38) (("-") reduce 38) ((".") reduce 38) (("/") reduce 38) (("<") reduce 38) ((">") reduce 38) (("?") reduce 38) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_BOOLEAN_AND) reduce 38) ((T_BOOLEAN_OR) reduce 38) ((T_COALESCE) reduce 38) ((T_DOUBLE_ARROW) reduce 38) ((T_INSTANCEOF) reduce 38) ((T_IS_EQUAL) reduce 38) ((T_IS_GREATER_OR_EQUAL) reduce 38) ((T_IS_IDENTICAL) reduce 38) ((T_IS_NOT_EQUAL) reduce 38) ((T_IS_NOT_IDENTICAL) reduce 38) ((T_IS_SMALLER_OR_EQUAL) reduce 38) ((T_LOGICAL_AND) reduce 38) ((T_LOGICAL_OR) reduce 38) ((T_LOGICAL_XOR) reduce 38) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 38) ((T_OBJECT_OPERATOR) reduce 38) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 38) ((T_POW) reduce 38) ((T_SL) reduce 38) ((T_SPACESHIP) reduce 38) ((T_SR) reduce 38) (("[") reduce 38) (("^") reduce 38) (("{") reduce 38) (("|") reduce 38)) 15727 ((("%") reduce 26) (("(") reduce 26) ((")") reduce 26) (("*") reduce 26) (("+") reduce 26) (("-") reduce 26) ((".") reduce 26) (("/") reduce 26) (("<") reduce 26) ((">") reduce 26) (("?") reduce 26) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_BOOLEAN_AND) reduce 26) ((T_BOOLEAN_OR) reduce 26) ((T_COALESCE) reduce 26) ((T_DOUBLE_ARROW) reduce 26) ((T_INSTANCEOF) reduce 26) ((T_IS_EQUAL) reduce 26) ((T_IS_GREATER_OR_EQUAL) reduce 26) ((T_IS_IDENTICAL) reduce 26) ((T_IS_NOT_EQUAL) reduce 26) ((T_IS_NOT_IDENTICAL) reduce 26) ((T_IS_SMALLER_OR_EQUAL) reduce 26) ((T_LOGICAL_AND) reduce 26) ((T_LOGICAL_OR) reduce 26) ((T_LOGICAL_XOR) reduce 26) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 26) ((T_OBJECT_OPERATOR) reduce 26) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 26) ((T_POW) reduce 26) ((T_SL) reduce 26) ((T_SPACESHIP) reduce 26) ((T_SR) reduce 26) (("[") reduce 26) (("^") reduce 26) (("{") reduce 26) (("|") reduce 26)) 15728 ((("%") reduce 22) (("(") reduce 22) ((")") reduce 22) (("*") reduce 22) (("+") reduce 22) (("-") reduce 22) ((".") reduce 22) (("/") reduce 22) (("<") reduce 22) ((">") reduce 22) (("?") reduce 22) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_BOOLEAN_AND) reduce 22) ((T_BOOLEAN_OR) reduce 22) ((T_COALESCE) reduce 22) ((T_DOUBLE_ARROW) reduce 22) ((T_INSTANCEOF) reduce 22) ((T_IS_EQUAL) reduce 22) ((T_IS_GREATER_OR_EQUAL) reduce 22) ((T_IS_IDENTICAL) reduce 22) ((T_IS_NOT_EQUAL) reduce 22) ((T_IS_NOT_IDENTICAL) reduce 22) ((T_IS_SMALLER_OR_EQUAL) reduce 22) ((T_LOGICAL_AND) reduce 22) ((T_LOGICAL_OR) reduce 22) ((T_LOGICAL_XOR) reduce 22) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 22) ((T_OBJECT_OPERATOR) reduce 22) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 22) ((T_POW) reduce 22) ((T_SL) reduce 22) ((T_SPACESHIP) reduce 22) ((T_SR) reduce 22) (("[") reduce 22) (("^") reduce 22) (("{") reduce 22) (("|") reduce 22)) 15729 ((("%") reduce 24) (("(") reduce 24) ((")") reduce 24) (("*") reduce 24) (("+") reduce 24) (("-") reduce 24) ((".") reduce 24) (("/") reduce 24) (("<") reduce 24) ((">") reduce 24) (("?") reduce 24) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_BOOLEAN_AND) reduce 24) ((T_BOOLEAN_OR) reduce 24) ((T_COALESCE) reduce 24) ((T_DOUBLE_ARROW) reduce 24) ((T_INSTANCEOF) reduce 24) ((T_IS_EQUAL) reduce 24) ((T_IS_GREATER_OR_EQUAL) reduce 24) ((T_IS_IDENTICAL) reduce 24) ((T_IS_NOT_EQUAL) reduce 24) ((T_IS_NOT_IDENTICAL) reduce 24) ((T_IS_SMALLER_OR_EQUAL) reduce 24) ((T_LOGICAL_AND) reduce 24) ((T_LOGICAL_OR) reduce 24) ((T_LOGICAL_XOR) reduce 24) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 24) ((T_OBJECT_OPERATOR) reduce 24) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 24) ((T_POW) reduce 24) ((T_SL) reduce 24) ((T_SPACESHIP) reduce 24) ((T_SR) reduce 24) (("[") reduce 24) (("^") reduce 24) (("{") reduce 24) (("|") reduce 24)) 15730 ((("%") reduce 16) (("(") reduce 16) ((")") reduce 16) (("*") reduce 16) (("+") reduce 16) (("-") reduce 16) ((".") reduce 16) (("/") reduce 16) (("<") reduce 16) ((">") reduce 16) (("?") reduce 16) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_BOOLEAN_AND) reduce 16) ((T_BOOLEAN_OR) reduce 16) ((T_COALESCE) reduce 16) ((T_DOUBLE_ARROW) reduce 16) ((T_INSTANCEOF) reduce 16) ((T_IS_EQUAL) reduce 16) ((T_IS_GREATER_OR_EQUAL) reduce 16) ((T_IS_IDENTICAL) reduce 16) ((T_IS_NOT_EQUAL) reduce 16) ((T_IS_NOT_IDENTICAL) reduce 16) ((T_IS_SMALLER_OR_EQUAL) reduce 16) ((T_LOGICAL_AND) reduce 16) ((T_LOGICAL_OR) reduce 16) ((T_LOGICAL_XOR) reduce 16) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 16) ((T_OBJECT_OPERATOR) reduce 16) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 16) ((T_POW) reduce 16) ((T_SL) reduce 16) ((T_SPACESHIP) reduce 16) ((T_SR) reduce 16) (("[") reduce 16) (("^") reduce 16) (("{") reduce 16) (("|") reduce 16)) 15731 ((("%") reduce 48) (("(") reduce 48) ((")") reduce 48) (("*") reduce 48) (("+") reduce 48) (("-") reduce 48) ((".") reduce 48) (("/") reduce 48) (("<") reduce 48) ((">") reduce 48) (("?") reduce 48) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_BOOLEAN_AND) reduce 48) ((T_BOOLEAN_OR) reduce 48) ((T_COALESCE) reduce 48) ((T_DOUBLE_ARROW) reduce 48) ((T_INSTANCEOF) reduce 48) ((T_IS_EQUAL) reduce 48) ((T_IS_GREATER_OR_EQUAL) reduce 48) ((T_IS_IDENTICAL) reduce 48) ((T_IS_NOT_EQUAL) reduce 48) ((T_IS_NOT_IDENTICAL) reduce 48) ((T_IS_SMALLER_OR_EQUAL) reduce 48) ((T_LOGICAL_AND) reduce 48) ((T_LOGICAL_OR) reduce 48) ((T_LOGICAL_XOR) reduce 48) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 48) ((T_OBJECT_OPERATOR) reduce 48) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 48) ((T_POW) reduce 48) ((T_SL) reduce 48) ((T_SPACESHIP) reduce 48) ((T_SR) reduce 48) (("[") reduce 48) (("^") reduce 48) (("{") reduce 48) (("|") reduce 48)) 15732 ((("%") reduce 20) (("(") reduce 20) ((")") reduce 20) (("*") reduce 20) (("+") reduce 20) (("-") reduce 20) ((".") reduce 20) (("/") reduce 20) (("<") reduce 20) ((">") reduce 20) (("?") reduce 20) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_BOOLEAN_AND) reduce 20) ((T_BOOLEAN_OR) reduce 20) ((T_COALESCE) reduce 20) ((T_DOUBLE_ARROW) reduce 20) ((T_INSTANCEOF) reduce 20) ((T_IS_EQUAL) reduce 20) ((T_IS_GREATER_OR_EQUAL) reduce 20) ((T_IS_IDENTICAL) reduce 20) ((T_IS_NOT_EQUAL) reduce 20) ((T_IS_NOT_IDENTICAL) reduce 20) ((T_IS_SMALLER_OR_EQUAL) reduce 20) ((T_LOGICAL_AND) reduce 20) ((T_LOGICAL_OR) reduce 20) ((T_LOGICAL_XOR) reduce 20) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 20) ((T_OBJECT_OPERATOR) reduce 20) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 20) ((T_POW) reduce 20) ((T_SL) reduce 20) ((T_SPACESHIP) reduce 20) ((T_SR) reduce 20) (("[") reduce 20) (("^") reduce 20) (("{") reduce 20) (("|") reduce 20)) 15733 ((("%") reduce 70) (("(") reduce 70) ((")") reduce 70) (("*") reduce 70) (("+") reduce 70) (("-") reduce 70) ((".") reduce 70) (("/") reduce 70) (("<") reduce 70) ((">") reduce 70) (("?") reduce 70) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_BOOLEAN_AND) reduce 70) ((T_BOOLEAN_OR) reduce 70) ((T_COALESCE) reduce 70) ((T_DOUBLE_ARROW) reduce 70) ((T_INSTANCEOF) reduce 70) ((T_IS_EQUAL) reduce 70) ((T_IS_GREATER_OR_EQUAL) reduce 70) ((T_IS_IDENTICAL) reduce 70) ((T_IS_NOT_EQUAL) reduce 70) ((T_IS_NOT_IDENTICAL) reduce 70) ((T_IS_SMALLER_OR_EQUAL) reduce 70) ((T_LOGICAL_AND) reduce 70) ((T_LOGICAL_OR) reduce 70) ((T_LOGICAL_XOR) reduce 70) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 70) ((T_OBJECT_OPERATOR) reduce 70) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 70) ((T_POW) reduce 70) ((T_SL) reduce 70) ((T_SPACESHIP) reduce 70) ((T_SR) reduce 70) (("[") reduce 70) (("^") reduce 70) (("{") reduce 70) (("|") reduce 70)) 15734 ((("%") reduce 3) (("(") reduce 3) ((")") reduce 3) (("*") reduce 3) (("+") reduce 3) (("-") reduce 3) ((".") reduce 3) (("/") reduce 3) (("<") reduce 3) ((">") reduce 3) (("?") reduce 3) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_BOOLEAN_AND) reduce 3) ((T_BOOLEAN_OR) reduce 3) ((T_COALESCE) reduce 3) ((T_DOUBLE_ARROW) reduce 3) ((T_INSTANCEOF) reduce 3) ((T_IS_EQUAL) reduce 3) ((T_IS_GREATER_OR_EQUAL) reduce 3) ((T_IS_IDENTICAL) reduce 3) ((T_IS_NOT_EQUAL) reduce 3) ((T_IS_NOT_IDENTICAL) reduce 3) ((T_IS_SMALLER_OR_EQUAL) reduce 3) ((T_LOGICAL_AND) reduce 3) ((T_LOGICAL_OR) reduce 3) ((T_LOGICAL_XOR) reduce 3) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 3) ((T_OBJECT_OPERATOR) reduce 3) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 3) ((T_POW) reduce 3) ((T_SL) reduce 3) ((T_SPACESHIP) reduce 3) ((T_SR) reduce 3) (("[") reduce 3) (("^") reduce 3) (("{") reduce 3) (("|") reduce 3)) 15735 ((("%") reduce 12) (("(") reduce 12) ((")") reduce 12) (("*") reduce 12) (("+") reduce 12) (("-") reduce 12) ((".") reduce 12) (("/") reduce 12) (("<") reduce 12) ((">") reduce 12) (("?") reduce 12) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_BOOLEAN_AND) reduce 12) ((T_BOOLEAN_OR) reduce 12) ((T_COALESCE) reduce 12) ((T_DOUBLE_ARROW) reduce 12) ((T_INSTANCEOF) reduce 12) ((T_IS_EQUAL) reduce 12) ((T_IS_GREATER_OR_EQUAL) reduce 12) ((T_IS_IDENTICAL) reduce 12) ((T_IS_NOT_EQUAL) reduce 12) ((T_IS_NOT_IDENTICAL) reduce 12) ((T_IS_SMALLER_OR_EQUAL) reduce 12) ((T_LOGICAL_AND) reduce 12) ((T_LOGICAL_OR) reduce 12) ((T_LOGICAL_XOR) reduce 12) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 12) ((T_OBJECT_OPERATOR) reduce 12) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 12) ((T_POW) reduce 12) ((T_SL) reduce 12) ((T_SPACESHIP) reduce 12) ((T_SR) reduce 12) (("[") reduce 12) (("^") reduce 12) (("{") reduce 12) (("|") reduce 12)) 15736 ((("%") reduce 54) (("(") reduce 54) ((")") reduce 54) (("*") reduce 54) (("+") reduce 54) (("-") reduce 54) ((".") reduce 54) (("/") reduce 54) (("<") reduce 54) ((">") reduce 54) (("?") reduce 54) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_BOOLEAN_AND) reduce 54) ((T_BOOLEAN_OR) reduce 54) ((T_COALESCE) reduce 54) ((T_DOUBLE_ARROW) reduce 54) ((T_INSTANCEOF) reduce 54) ((T_IS_EQUAL) reduce 54) ((T_IS_GREATER_OR_EQUAL) reduce 54) ((T_IS_IDENTICAL) reduce 54) ((T_IS_NOT_EQUAL) reduce 54) ((T_IS_NOT_IDENTICAL) reduce 54) ((T_IS_SMALLER_OR_EQUAL) reduce 54) ((T_LOGICAL_AND) reduce 54) ((T_LOGICAL_OR) reduce 54) ((T_LOGICAL_XOR) reduce 54) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 54) ((T_OBJECT_OPERATOR) reduce 54) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 54) ((T_POW) reduce 54) ((T_SL) reduce 54) ((T_SPACESHIP) reduce 54) ((T_SR) reduce 54) (("[") reduce 54) (("^") reduce 54) (("{") reduce 54) (("|") reduce 54)) 15737 ((("%") reduce 65) (("(") reduce 65) ((")") reduce 65) (("*") reduce 65) (("+") reduce 65) (("-") reduce 65) ((".") reduce 65) (("/") reduce 65) (("<") reduce 65) ((">") reduce 65) (("?") reduce 65) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_BOOLEAN_AND) reduce 65) ((T_BOOLEAN_OR) reduce 65) ((T_COALESCE) reduce 65) ((T_DOUBLE_ARROW) reduce 65) ((T_INSTANCEOF) reduce 65) ((T_IS_EQUAL) reduce 65) ((T_IS_GREATER_OR_EQUAL) reduce 65) ((T_IS_IDENTICAL) reduce 65) ((T_IS_NOT_EQUAL) reduce 65) ((T_IS_NOT_IDENTICAL) reduce 65) ((T_IS_SMALLER_OR_EQUAL) reduce 65) ((T_LOGICAL_AND) reduce 65) ((T_LOGICAL_OR) reduce 65) ((T_LOGICAL_XOR) reduce 65) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 65) ((T_OBJECT_OPERATOR) reduce 65) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 65) ((T_POW) reduce 65) ((T_SL) reduce 65) ((T_SPACESHIP) reduce 65) ((T_SR) reduce 65) (("[") reduce 65) (("^") reduce 65) (("{") reduce 65) (("|") reduce 65)) 15738 ((("%") reduce 74) (("(") reduce 74) ((")") reduce 74) (("*") reduce 74) (("+") reduce 74) (("-") reduce 74) ((".") reduce 74) (("/") reduce 74) (("<") reduce 74) ((">") reduce 74) (("?") reduce 74) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_BOOLEAN_AND) reduce 74) ((T_BOOLEAN_OR) reduce 74) ((T_COALESCE) reduce 74) ((T_DOUBLE_ARROW) reduce 74) ((T_INSTANCEOF) reduce 74) ((T_IS_EQUAL) reduce 74) ((T_IS_GREATER_OR_EQUAL) reduce 74) ((T_IS_IDENTICAL) reduce 74) ((T_IS_NOT_EQUAL) reduce 74) ((T_IS_NOT_IDENTICAL) reduce 74) ((T_IS_SMALLER_OR_EQUAL) reduce 74) ((T_LOGICAL_AND) reduce 74) ((T_LOGICAL_OR) reduce 74) ((T_LOGICAL_XOR) reduce 74) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 74) ((T_OBJECT_OPERATOR) reduce 74) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 74) ((T_POW) reduce 74) ((T_SL) reduce 74) ((T_SPACESHIP) reduce 74) ((T_SR) reduce 74) (("[") reduce 74) (("^") reduce 74) (("{") reduce 74) (("|") reduce 74)) 15739 ((("%") reduce 30) (("(") reduce 30) ((")") reduce 30) (("*") reduce 30) (("+") reduce 30) (("-") reduce 30) ((".") reduce 30) (("/") reduce 30) (("<") reduce 30) ((">") reduce 30) (("?") reduce 30) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_BOOLEAN_AND) reduce 30) ((T_BOOLEAN_OR) reduce 30) ((T_COALESCE) reduce 30) ((T_DOUBLE_ARROW) reduce 30) ((T_INSTANCEOF) reduce 30) ((T_IS_EQUAL) reduce 30) ((T_IS_GREATER_OR_EQUAL) reduce 30) ((T_IS_IDENTICAL) reduce 30) ((T_IS_NOT_EQUAL) reduce 30) ((T_IS_NOT_IDENTICAL) reduce 30) ((T_IS_SMALLER_OR_EQUAL) reduce 30) ((T_LOGICAL_AND) reduce 30) ((T_LOGICAL_OR) reduce 30) ((T_LOGICAL_XOR) reduce 30) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 30) ((T_OBJECT_OPERATOR) reduce 30) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 30) ((T_POW) reduce 30) ((T_SL) reduce 30) ((T_SPACESHIP) reduce 30) ((T_SR) reduce 30) (("[") reduce 30) (("^") reduce 30) (("{") reduce 30) (("|") reduce 30)) 15740 ((("%") reduce 68) (("(") reduce 68) ((")") reduce 68) (("*") reduce 68) (("+") reduce 68) (("-") reduce 68) ((".") reduce 68) (("/") reduce 68) (("<") reduce 68) ((">") reduce 68) (("?") reduce 68) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_BOOLEAN_AND) reduce 68) ((T_BOOLEAN_OR) reduce 68) ((T_COALESCE) reduce 68) ((T_DOUBLE_ARROW) reduce 68) ((T_INSTANCEOF) reduce 68) ((T_IS_EQUAL) reduce 68) ((T_IS_GREATER_OR_EQUAL) reduce 68) ((T_IS_IDENTICAL) reduce 68) ((T_IS_NOT_EQUAL) reduce 68) ((T_IS_NOT_IDENTICAL) reduce 68) ((T_IS_SMALLER_OR_EQUAL) reduce 68) ((T_LOGICAL_AND) reduce 68) ((T_LOGICAL_OR) reduce 68) ((T_LOGICAL_XOR) reduce 68) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 68) ((T_OBJECT_OPERATOR) reduce 68) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 68) ((T_POW) reduce 68) ((T_SL) reduce 68) ((T_SPACESHIP) reduce 68) ((T_SR) reduce 68) (("[") reduce 68) (("^") reduce 68) (("{") reduce 68) (("|") reduce 68)) 15741 ((("%") reduce 21) (("(") reduce 21) ((")") reduce 21) (("*") reduce 21) (("+") reduce 21) (("-") reduce 21) ((".") reduce 21) (("/") reduce 21) (("<") reduce 21) ((">") reduce 21) (("?") reduce 21) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_BOOLEAN_AND) reduce 21) ((T_BOOLEAN_OR) reduce 21) ((T_COALESCE) reduce 21) ((T_DOUBLE_ARROW) reduce 21) ((T_INSTANCEOF) reduce 21) ((T_IS_EQUAL) reduce 21) ((T_IS_GREATER_OR_EQUAL) reduce 21) ((T_IS_IDENTICAL) reduce 21) ((T_IS_NOT_EQUAL) reduce 21) ((T_IS_NOT_IDENTICAL) reduce 21) ((T_IS_SMALLER_OR_EQUAL) reduce 21) ((T_LOGICAL_AND) reduce 21) ((T_LOGICAL_OR) reduce 21) ((T_LOGICAL_XOR) reduce 21) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 21) ((T_OBJECT_OPERATOR) reduce 21) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 21) ((T_POW) reduce 21) ((T_SL) reduce 21) ((T_SPACESHIP) reduce 21) ((T_SR) reduce 21) (("[") reduce 21) (("^") reduce 21) (("{") reduce 21) (("|") reduce 21)) 15742 ((("%") reduce 23) (("(") reduce 23) ((")") reduce 23) (("*") reduce 23) (("+") reduce 23) (("-") reduce 23) ((".") reduce 23) (("/") reduce 23) (("<") reduce 23) ((">") reduce 23) (("?") reduce 23) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_BOOLEAN_AND) reduce 23) ((T_BOOLEAN_OR) reduce 23) ((T_COALESCE) reduce 23) ((T_DOUBLE_ARROW) reduce 23) ((T_INSTANCEOF) reduce 23) ((T_IS_EQUAL) reduce 23) ((T_IS_GREATER_OR_EQUAL) reduce 23) ((T_IS_IDENTICAL) reduce 23) ((T_IS_NOT_EQUAL) reduce 23) ((T_IS_NOT_IDENTICAL) reduce 23) ((T_IS_SMALLER_OR_EQUAL) reduce 23) ((T_LOGICAL_AND) reduce 23) ((T_LOGICAL_OR) reduce 23) ((T_LOGICAL_XOR) reduce 23) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 23) ((T_OBJECT_OPERATOR) reduce 23) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 23) ((T_POW) reduce 23) ((T_SL) reduce 23) ((T_SPACESHIP) reduce 23) ((T_SR) reduce 23) (("[") reduce 23) (("^") reduce 23) (("{") reduce 23) (("|") reduce 23)) 15743 ((("%") reduce 41) (("(") reduce 41) ((")") reduce 41) (("*") reduce 41) (("+") reduce 41) (("-") reduce 41) ((".") reduce 41) (("/") reduce 41) (("<") reduce 41) ((">") reduce 41) (("?") reduce 41) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_BOOLEAN_AND) reduce 41) ((T_BOOLEAN_OR) reduce 41) ((T_COALESCE) reduce 41) ((T_DOUBLE_ARROW) reduce 41) ((T_INSTANCEOF) reduce 41) ((T_IS_EQUAL) reduce 41) ((T_IS_GREATER_OR_EQUAL) reduce 41) ((T_IS_IDENTICAL) reduce 41) ((T_IS_NOT_EQUAL) reduce 41) ((T_IS_NOT_IDENTICAL) reduce 41) ((T_IS_SMALLER_OR_EQUAL) reduce 41) ((T_LOGICAL_AND) reduce 41) ((T_LOGICAL_OR) reduce 41) ((T_LOGICAL_XOR) reduce 41) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 41) ((T_OBJECT_OPERATOR) reduce 41) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 41) ((T_POW) reduce 41) ((T_SL) reduce 41) ((T_SPACESHIP) reduce 41) ((T_SR) reduce 41) (("[") reduce 41) (("^") reduce 41) (("{") reduce 41) (("|") reduce 41)) 15744 ((("%") reduce 62) (("(") reduce 62) ((")") reduce 62) (("*") reduce 62) (("+") reduce 62) (("-") reduce 62) ((".") reduce 62) (("/") reduce 62) (("<") reduce 62) ((">") reduce 62) (("?") reduce 62) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_BOOLEAN_AND) reduce 62) ((T_BOOLEAN_OR) reduce 62) ((T_COALESCE) reduce 62) ((T_DOUBLE_ARROW) reduce 62) ((T_INSTANCEOF) reduce 62) ((T_IS_EQUAL) reduce 62) ((T_IS_GREATER_OR_EQUAL) reduce 62) ((T_IS_IDENTICAL) reduce 62) ((T_IS_NOT_EQUAL) reduce 62) ((T_IS_NOT_IDENTICAL) reduce 62) ((T_IS_SMALLER_OR_EQUAL) reduce 62) ((T_LOGICAL_AND) reduce 62) ((T_LOGICAL_OR) reduce 62) ((T_LOGICAL_XOR) reduce 62) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 62) ((T_OBJECT_OPERATOR) reduce 62) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 62) ((T_POW) reduce 62) ((T_SL) reduce 62) ((T_SPACESHIP) reduce 62) ((T_SR) reduce 62) (("[") reduce 62) (("^") reduce 62) (("{") reduce 62) (("|") reduce 62)) 15745 ((("%") reduce 34) (("(") reduce 34) ((")") reduce 34) (("*") reduce 34) (("+") reduce 34) (("-") reduce 34) ((".") reduce 34) (("/") reduce 34) (("<") reduce 34) ((">") reduce 34) (("?") reduce 34) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_BOOLEAN_AND) reduce 34) ((T_BOOLEAN_OR) reduce 34) ((T_COALESCE) reduce 34) ((T_DOUBLE_ARROW) reduce 34) ((T_INSTANCEOF) reduce 34) ((T_IS_EQUAL) reduce 34) ((T_IS_GREATER_OR_EQUAL) reduce 34) ((T_IS_IDENTICAL) reduce 34) ((T_IS_NOT_EQUAL) reduce 34) ((T_IS_NOT_IDENTICAL) reduce 34) ((T_IS_SMALLER_OR_EQUAL) reduce 34) ((T_LOGICAL_AND) reduce 34) ((T_LOGICAL_OR) reduce 34) ((T_LOGICAL_XOR) reduce 34) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 34) ((T_OBJECT_OPERATOR) reduce 34) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 34) ((T_POW) reduce 34) ((T_SL) reduce 34) ((T_SPACESHIP) reduce 34) ((T_SR) reduce 34) (("[") reduce 34) (("^") reduce 34) (("{") reduce 34) (("|") reduce 34)) 15746 ((("%") reduce 40) (("(") reduce 40) ((")") reduce 40) (("*") reduce 40) (("+") reduce 40) (("-") reduce 40) ((".") reduce 40) (("/") reduce 40) (("<") reduce 40) ((">") reduce 40) (("?") reduce 40) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_BOOLEAN_AND) reduce 40) ((T_BOOLEAN_OR) reduce 40) ((T_COALESCE) reduce 40) ((T_DOUBLE_ARROW) reduce 40) ((T_INSTANCEOF) reduce 40) ((T_IS_EQUAL) reduce 40) ((T_IS_GREATER_OR_EQUAL) reduce 40) ((T_IS_IDENTICAL) reduce 40) ((T_IS_NOT_EQUAL) reduce 40) ((T_IS_NOT_IDENTICAL) reduce 40) ((T_IS_SMALLER_OR_EQUAL) reduce 40) ((T_LOGICAL_AND) reduce 40) ((T_LOGICAL_OR) reduce 40) ((T_LOGICAL_XOR) reduce 40) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 40) ((T_OBJECT_OPERATOR) reduce 40) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 40) ((T_POW) reduce 40) ((T_SL) reduce 40) ((T_SPACESHIP) reduce 40) ((T_SR) reduce 40) (("[") reduce 40) (("^") reduce 40) (("{") reduce 40) (("|") reduce 40)) 15747 ((("%") reduce 13) (("(") reduce 13) ((")") reduce 13) (("*") reduce 13) (("+") reduce 13) (("-") reduce 13) ((".") reduce 13) (("/") reduce 13) (("<") reduce 13) ((">") reduce 13) (("?") reduce 13) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_BOOLEAN_AND) reduce 13) ((T_BOOLEAN_OR) reduce 13) ((T_COALESCE) reduce 13) ((T_DOUBLE_ARROW) reduce 13) ((T_INSTANCEOF) reduce 13) ((T_IS_EQUAL) reduce 13) ((T_IS_GREATER_OR_EQUAL) reduce 13) ((T_IS_IDENTICAL) reduce 13) ((T_IS_NOT_EQUAL) reduce 13) ((T_IS_NOT_IDENTICAL) reduce 13) ((T_IS_SMALLER_OR_EQUAL) reduce 13) ((T_LOGICAL_AND) reduce 13) ((T_LOGICAL_OR) reduce 13) ((T_LOGICAL_XOR) reduce 13) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 13) ((T_OBJECT_OPERATOR) reduce 13) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 13) ((T_POW) reduce 13) ((T_SL) reduce 13) ((T_SPACESHIP) reduce 13) ((T_SR) reduce 13) (("[") reduce 13) (("^") reduce 13) (("{") reduce 13) (("|") reduce 13)) 15748 ((("%") reduce 55) (("(") reduce 55) ((")") reduce 55) (("*") reduce 55) (("+") reduce 55) (("-") reduce 55) ((".") reduce 55) (("/") reduce 55) (("<") reduce 55) ((">") reduce 55) (("?") reduce 55) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_BOOLEAN_AND) reduce 55) ((T_BOOLEAN_OR) reduce 55) ((T_COALESCE) reduce 55) ((T_DOUBLE_ARROW) reduce 55) ((T_INSTANCEOF) reduce 55) ((T_IS_EQUAL) reduce 55) ((T_IS_GREATER_OR_EQUAL) reduce 55) ((T_IS_IDENTICAL) reduce 55) ((T_IS_NOT_EQUAL) reduce 55) ((T_IS_NOT_IDENTICAL) reduce 55) ((T_IS_SMALLER_OR_EQUAL) reduce 55) ((T_LOGICAL_AND) reduce 55) ((T_LOGICAL_OR) reduce 55) ((T_LOGICAL_XOR) reduce 55) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 55) ((T_OBJECT_OPERATOR) reduce 55) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 55) ((T_POW) reduce 55) ((T_SL) reduce 55) ((T_SPACESHIP) reduce 55) ((T_SR) reduce 55) (("[") reduce 55) (("^") reduce 55) (("{") reduce 55) (("|") reduce 55)) 15749 ((("%") reduce 1) (("(") reduce 1) ((")") reduce 1) (("*") reduce 1) (("+") reduce 1) (("-") reduce 1) ((".") reduce 1) (("/") reduce 1) (("<") reduce 1) ((">") reduce 1) (("?") reduce 1) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_BOOLEAN_AND) reduce 1) ((T_BOOLEAN_OR) reduce 1) ((T_COALESCE) reduce 1) ((T_DOUBLE_ARROW) reduce 1) ((T_INSTANCEOF) reduce 1) ((T_IS_EQUAL) reduce 1) ((T_IS_GREATER_OR_EQUAL) reduce 1) ((T_IS_IDENTICAL) reduce 1) ((T_IS_NOT_EQUAL) reduce 1) ((T_IS_NOT_IDENTICAL) reduce 1) ((T_IS_SMALLER_OR_EQUAL) reduce 1) ((T_LOGICAL_AND) reduce 1) ((T_LOGICAL_OR) reduce 1) ((T_LOGICAL_XOR) reduce 1) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 1) ((T_OBJECT_OPERATOR) reduce 1) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 1) ((T_POW) reduce 1) ((T_SL) reduce 1) ((T_SPACESHIP) reduce 1) ((T_SR) reduce 1) (("[") reduce 1) (("^") reduce 1) (("{") reduce 1) (("|") reduce 1)) 15750 ((("%") reduce 2) (("(") reduce 2) ((")") reduce 2) (("*") reduce 2) (("+") reduce 2) (("-") reduce 2) ((".") reduce 2) (("/") reduce 2) (("<") reduce 2) ((">") reduce 2) (("?") reduce 2) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_BOOLEAN_AND) reduce 2) ((T_BOOLEAN_OR) reduce 2) ((T_COALESCE) reduce 2) ((T_DOUBLE_ARROW) reduce 2) ((T_INSTANCEOF) reduce 2) ((T_IS_EQUAL) reduce 2) ((T_IS_GREATER_OR_EQUAL) reduce 2) ((T_IS_IDENTICAL) reduce 2) ((T_IS_NOT_EQUAL) reduce 2) ((T_IS_NOT_IDENTICAL) reduce 2) ((T_IS_SMALLER_OR_EQUAL) reduce 2) ((T_LOGICAL_AND) reduce 2) ((T_LOGICAL_OR) reduce 2) ((T_LOGICAL_XOR) reduce 2) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 2) ((T_OBJECT_OPERATOR) reduce 2) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 2) ((T_POW) reduce 2) ((T_SL) reduce 2) ((T_SPACESHIP) reduce 2) ((T_SR) reduce 2) (("[") reduce 2) (("^") reduce 2) (("{") reduce 2) (("|") reduce 2)) 15751 ((("%") reduce 9) (("(") reduce 9) ((")") reduce 9) (("*") reduce 9) (("+") reduce 9) (("-") reduce 9) ((".") reduce 9) (("/") reduce 9) (("<") reduce 9) ((">") reduce 9) (("?") reduce 9) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_BOOLEAN_AND) reduce 9) ((T_BOOLEAN_OR) reduce 9) ((T_COALESCE) reduce 9) ((T_DOUBLE_ARROW) reduce 9) ((T_INSTANCEOF) reduce 9) ((T_IS_EQUAL) reduce 9) ((T_IS_GREATER_OR_EQUAL) reduce 9) ((T_IS_IDENTICAL) reduce 9) ((T_IS_NOT_EQUAL) reduce 9) ((T_IS_NOT_IDENTICAL) reduce 9) ((T_IS_SMALLER_OR_EQUAL) reduce 9) ((T_LOGICAL_AND) reduce 9) ((T_LOGICAL_OR) reduce 9) ((T_LOGICAL_XOR) reduce 9) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 9) ((T_OBJECT_OPERATOR) reduce 9) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 9) ((T_POW) reduce 9) ((T_SL) reduce 9) ((T_SPACESHIP) reduce 9) ((T_SR) reduce 9) (("[") reduce 9) (("^") reduce 9) (("{") reduce 9) (("|") reduce 9)) 15752 ((("%") reduce 33) (("(") reduce 33) ((")") reduce 33) (("*") reduce 33) (("+") reduce 33) (("-") reduce 33) ((".") reduce 33) (("/") reduce 33) (("<") reduce 33) ((">") reduce 33) (("?") reduce 33) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_BOOLEAN_AND) reduce 33) ((T_BOOLEAN_OR) reduce 33) ((T_COALESCE) reduce 33) ((T_DOUBLE_ARROW) reduce 33) ((T_INSTANCEOF) reduce 33) ((T_IS_EQUAL) reduce 33) ((T_IS_GREATER_OR_EQUAL) reduce 33) ((T_IS_IDENTICAL) reduce 33) ((T_IS_NOT_EQUAL) reduce 33) ((T_IS_NOT_IDENTICAL) reduce 33) ((T_IS_SMALLER_OR_EQUAL) reduce 33) ((T_LOGICAL_AND) reduce 33) ((T_LOGICAL_OR) reduce 33) ((T_LOGICAL_XOR) reduce 33) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 33) ((T_OBJECT_OPERATOR) reduce 33) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 33) ((T_POW) reduce 33) ((T_SL) reduce 33) ((T_SPACESHIP) reduce 33) ((T_SR) reduce 33) (("[") reduce 33) (("^") reduce 33) (("{") reduce 33) (("|") reduce 33)) 15753 ((("%") reduce 58) (("(") reduce 58) ((")") reduce 58) (("*") reduce 58) (("+") reduce 58) (("-") reduce 58) ((".") reduce 58) (("/") reduce 58) (("<") reduce 58) ((">") reduce 58) (("?") reduce 58) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_BOOLEAN_AND) reduce 58) ((T_BOOLEAN_OR) reduce 58) ((T_COALESCE) reduce 58) ((T_DOUBLE_ARROW) reduce 58) ((T_INSTANCEOF) reduce 58) ((T_IS_EQUAL) reduce 58) ((T_IS_GREATER_OR_EQUAL) reduce 58) ((T_IS_IDENTICAL) reduce 58) ((T_IS_NOT_EQUAL) reduce 58) ((T_IS_NOT_IDENTICAL) reduce 58) ((T_IS_SMALLER_OR_EQUAL) reduce 58) ((T_LOGICAL_AND) reduce 58) ((T_LOGICAL_OR) reduce 58) ((T_LOGICAL_XOR) reduce 58) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 58) ((T_OBJECT_OPERATOR) reduce 58) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 58) ((T_POW) reduce 58) ((T_SL) reduce 58) ((T_SPACESHIP) reduce 58) ((T_SR) reduce 58) (("[") reduce 58) (("^") reduce 58) (("{") reduce 58) (("|") reduce 58)) 15754 ((("%") reduce 37) (("(") reduce 37) ((")") reduce 37) (("*") reduce 37) (("+") reduce 37) (("-") reduce 37) ((".") reduce 37) (("/") reduce 37) (("<") reduce 37) ((">") reduce 37) (("?") reduce 37) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_BOOLEAN_AND) reduce 37) ((T_BOOLEAN_OR) reduce 37) ((T_COALESCE) reduce 37) ((T_DOUBLE_ARROW) reduce 37) ((T_INSTANCEOF) reduce 37) ((T_IS_EQUAL) reduce 37) ((T_IS_GREATER_OR_EQUAL) reduce 37) ((T_IS_IDENTICAL) reduce 37) ((T_IS_NOT_EQUAL) reduce 37) ((T_IS_NOT_IDENTICAL) reduce 37) ((T_IS_SMALLER_OR_EQUAL) reduce 37) ((T_LOGICAL_AND) reduce 37) ((T_LOGICAL_OR) reduce 37) ((T_LOGICAL_XOR) reduce 37) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 37) ((T_OBJECT_OPERATOR) reduce 37) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 37) ((T_POW) reduce 37) ((T_SL) reduce 37) ((T_SPACESHIP) reduce 37) ((T_SR) reduce 37) (("[") reduce 37) (("^") reduce 37) (("{") reduce 37) (("|") reduce 37)) 15755 ((("%") reduce 64) (("(") reduce 64) ((")") reduce 64) (("*") reduce 64) (("+") reduce 64) (("-") reduce 64) ((".") reduce 64) (("/") reduce 64) (("<") reduce 64) ((">") reduce 64) (("?") reduce 64) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_BOOLEAN_AND) reduce 64) ((T_BOOLEAN_OR) reduce 64) ((T_COALESCE) reduce 64) ((T_DOUBLE_ARROW) reduce 64) ((T_INSTANCEOF) reduce 64) ((T_IS_EQUAL) reduce 64) ((T_IS_GREATER_OR_EQUAL) reduce 64) ((T_IS_IDENTICAL) reduce 64) ((T_IS_NOT_EQUAL) reduce 64) ((T_IS_NOT_IDENTICAL) reduce 64) ((T_IS_SMALLER_OR_EQUAL) reduce 64) ((T_LOGICAL_AND) reduce 64) ((T_LOGICAL_OR) reduce 64) ((T_LOGICAL_XOR) reduce 64) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 64) ((T_OBJECT_OPERATOR) reduce 64) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 64) ((T_POW) reduce 64) ((T_SL) reduce 64) ((T_SPACESHIP) reduce 64) ((T_SR) reduce 64) (("[") reduce 64) (("^") reduce 64) (("{") reduce 64) (("|") reduce 64)) 15756 ((("%") reduce 46) (("(") reduce 46) ((")") reduce 46) (("*") reduce 46) (("+") reduce 46) (("-") reduce 46) ((".") reduce 46) (("/") reduce 46) (("<") reduce 46) ((">") reduce 46) (("?") reduce 46) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_BOOLEAN_AND) reduce 46) ((T_BOOLEAN_OR) reduce 46) ((T_COALESCE) reduce 46) ((T_DOUBLE_ARROW) reduce 46) ((T_INSTANCEOF) reduce 46) ((T_IS_EQUAL) reduce 46) ((T_IS_GREATER_OR_EQUAL) reduce 46) ((T_IS_IDENTICAL) reduce 46) ((T_IS_NOT_EQUAL) reduce 46) ((T_IS_NOT_IDENTICAL) reduce 46) ((T_IS_SMALLER_OR_EQUAL) reduce 46) ((T_LOGICAL_AND) reduce 46) ((T_LOGICAL_OR) reduce 46) ((T_LOGICAL_XOR) reduce 46) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 46) ((T_OBJECT_OPERATOR) reduce 46) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 46) ((T_POW) reduce 46) ((T_SL) reduce 46) ((T_SPACESHIP) reduce 46) ((T_SR) reduce 46) (("[") reduce 46) (("^") reduce 46) (("{") reduce 46) (("|") reduce 46)) 15757 ((("%") reduce 8) (("(") reduce 8) ((")") reduce 8) (("*") reduce 8) (("+") reduce 8) (("-") reduce 8) ((".") reduce 8) (("/") reduce 8) (("<") reduce 8) ((">") reduce 8) (("?") reduce 8) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_BOOLEAN_AND) reduce 8) ((T_BOOLEAN_OR) reduce 8) ((T_COALESCE) reduce 8) ((T_DOUBLE_ARROW) reduce 8) ((T_INSTANCEOF) reduce 8) ((T_IS_EQUAL) reduce 8) ((T_IS_GREATER_OR_EQUAL) reduce 8) ((T_IS_IDENTICAL) reduce 8) ((T_IS_NOT_EQUAL) reduce 8) ((T_IS_NOT_IDENTICAL) reduce 8) ((T_IS_SMALLER_OR_EQUAL) reduce 8) ((T_LOGICAL_AND) reduce 8) ((T_LOGICAL_OR) reduce 8) ((T_LOGICAL_XOR) reduce 8) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 8) ((T_OBJECT_OPERATOR) reduce 8) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 8) ((T_POW) reduce 8) ((T_SL) reduce 8) ((T_SPACESHIP) reduce 8) ((T_SR) reduce 8) (("[") reduce 8) (("^") reduce 8) (("{") reduce 8) (("|") reduce 8)) 15758 ((("%") reduce 6) (("(") reduce 6) ((")") reduce 6) (("*") reduce 6) (("+") reduce 6) (("-") reduce 6) ((".") reduce 6) (("/") reduce 6) (("<") reduce 6) ((">") reduce 6) (("?") reduce 6) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_BOOLEAN_AND) reduce 6) ((T_BOOLEAN_OR) reduce 6) ((T_COALESCE) reduce 6) ((T_DOUBLE_ARROW) reduce 6) ((T_INSTANCEOF) reduce 6) ((T_IS_EQUAL) reduce 6) ((T_IS_GREATER_OR_EQUAL) reduce 6) ((T_IS_IDENTICAL) reduce 6) ((T_IS_NOT_EQUAL) reduce 6) ((T_IS_NOT_IDENTICAL) reduce 6) ((T_IS_SMALLER_OR_EQUAL) reduce 6) ((T_LOGICAL_AND) reduce 6) ((T_LOGICAL_OR) reduce 6) ((T_LOGICAL_XOR) reduce 6) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 6) ((T_OBJECT_OPERATOR) reduce 6) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 6) ((T_POW) reduce 6) ((T_SL) reduce 6) ((T_SPACESHIP) reduce 6) ((T_SR) reduce 6) (("[") reduce 6) (("^") reduce 6) (("{") reduce 6) (("|") reduce 6)) 15759 ((("%") reduce 7) (("(") reduce 7) ((")") reduce 7) (("*") reduce 7) (("+") reduce 7) (("-") reduce 7) ((".") reduce 7) (("/") reduce 7) (("<") reduce 7) ((">") reduce 7) (("?") reduce 7) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_BOOLEAN_AND) reduce 7) ((T_BOOLEAN_OR) reduce 7) ((T_COALESCE) reduce 7) ((T_DOUBLE_ARROW) reduce 7) ((T_INSTANCEOF) reduce 7) ((T_IS_EQUAL) reduce 7) ((T_IS_GREATER_OR_EQUAL) reduce 7) ((T_IS_IDENTICAL) reduce 7) ((T_IS_NOT_EQUAL) reduce 7) ((T_IS_NOT_IDENTICAL) reduce 7) ((T_IS_SMALLER_OR_EQUAL) reduce 7) ((T_LOGICAL_AND) reduce 7) ((T_LOGICAL_OR) reduce 7) ((T_LOGICAL_XOR) reduce 7) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 7) ((T_OBJECT_OPERATOR) reduce 7) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 7) ((T_POW) reduce 7) ((T_SL) reduce 7) ((T_SPACESHIP) reduce 7) ((T_SR) reduce 7) (("[") reduce 7) (("^") reduce 7) (("{") reduce 7) (("|") reduce 7)) 15760 ((("%") reduce 69) (("(") reduce 69) ((")") reduce 69) (("*") reduce 69) (("+") reduce 69) (("-") reduce 69) ((".") reduce 69) (("/") reduce 69) (("<") reduce 69) ((">") reduce 69) (("?") reduce 69) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_BOOLEAN_AND) reduce 69) ((T_BOOLEAN_OR) reduce 69) ((T_COALESCE) reduce 69) ((T_DOUBLE_ARROW) reduce 69) ((T_INSTANCEOF) reduce 69) ((T_IS_EQUAL) reduce 69) ((T_IS_GREATER_OR_EQUAL) reduce 69) ((T_IS_IDENTICAL) reduce 69) ((T_IS_NOT_EQUAL) reduce 69) ((T_IS_NOT_IDENTICAL) reduce 69) ((T_IS_SMALLER_OR_EQUAL) reduce 69) ((T_LOGICAL_AND) reduce 69) ((T_LOGICAL_OR) reduce 69) ((T_LOGICAL_XOR) reduce 69) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 69) ((T_OBJECT_OPERATOR) reduce 69) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 69) ((T_POW) reduce 69) ((T_SL) reduce 69) ((T_SPACESHIP) reduce 69) ((T_SR) reduce 69) (("[") reduce 69) (("^") reduce 69) (("{") reduce 69) (("|") reduce 69)) 15761 ((("%") reduce 63) (("(") reduce 63) ((")") reduce 63) (("*") reduce 63) (("+") reduce 63) (("-") reduce 63) ((".") reduce 63) (("/") reduce 63) (("<") reduce 63) ((">") reduce 63) (("?") reduce 63) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_BOOLEAN_AND) reduce 63) ((T_BOOLEAN_OR) reduce 63) ((T_COALESCE) reduce 63) ((T_DOUBLE_ARROW) reduce 63) ((T_INSTANCEOF) reduce 63) ((T_IS_EQUAL) reduce 63) ((T_IS_GREATER_OR_EQUAL) reduce 63) ((T_IS_IDENTICAL) reduce 63) ((T_IS_NOT_EQUAL) reduce 63) ((T_IS_NOT_IDENTICAL) reduce 63) ((T_IS_SMALLER_OR_EQUAL) reduce 63) ((T_LOGICAL_AND) reduce 63) ((T_LOGICAL_OR) reduce 63) ((T_LOGICAL_XOR) reduce 63) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 63) ((T_OBJECT_OPERATOR) reduce 63) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 63) ((T_POW) reduce 63) ((T_SL) reduce 63) ((T_SPACESHIP) reduce 63) ((T_SR) reduce 63) (("[") reduce 63) (("^") reduce 63) (("{") reduce 63) (("|") reduce 63)) 15762 ((("%") reduce 56) (("(") reduce 56) ((")") reduce 56) (("*") reduce 56) (("+") reduce 56) (("-") reduce 56) ((".") reduce 56) (("/") reduce 56) (("<") reduce 56) ((">") reduce 56) (("?") reduce 56) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_BOOLEAN_AND) reduce 56) ((T_BOOLEAN_OR) reduce 56) ((T_COALESCE) reduce 56) ((T_DOUBLE_ARROW) reduce 56) ((T_INSTANCEOF) reduce 56) ((T_IS_EQUAL) reduce 56) ((T_IS_GREATER_OR_EQUAL) reduce 56) ((T_IS_IDENTICAL) reduce 56) ((T_IS_NOT_EQUAL) reduce 56) ((T_IS_NOT_IDENTICAL) reduce 56) ((T_IS_SMALLER_OR_EQUAL) reduce 56) ((T_LOGICAL_AND) reduce 56) ((T_LOGICAL_OR) reduce 56) ((T_LOGICAL_XOR) reduce 56) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 56) ((T_OBJECT_OPERATOR) reduce 56) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 56) ((T_POW) reduce 56) ((T_SL) reduce 56) ((T_SPACESHIP) reduce 56) ((T_SR) reduce 56) (("[") reduce 56) (("^") reduce 56) (("{") reduce 56) (("|") reduce 56)) 15763 ((("%") reduce 10) (("(") reduce 10) ((")") reduce 10) (("*") reduce 10) (("+") reduce 10) (("-") reduce 10) ((".") reduce 10) (("/") reduce 10) (("<") reduce 10) ((">") reduce 10) (("?") reduce 10) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_BOOLEAN_AND) reduce 10) ((T_BOOLEAN_OR) reduce 10) ((T_COALESCE) reduce 10) ((T_DOUBLE_ARROW) reduce 10) ((T_INSTANCEOF) reduce 10) ((T_IS_EQUAL) reduce 10) ((T_IS_GREATER_OR_EQUAL) reduce 10) ((T_IS_IDENTICAL) reduce 10) ((T_IS_NOT_EQUAL) reduce 10) ((T_IS_NOT_IDENTICAL) reduce 10) ((T_IS_SMALLER_OR_EQUAL) reduce 10) ((T_LOGICAL_AND) reduce 10) ((T_LOGICAL_OR) reduce 10) ((T_LOGICAL_XOR) reduce 10) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 10) ((T_OBJECT_OPERATOR) reduce 10) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 10) ((T_POW) reduce 10) ((T_SL) reduce 10) ((T_SPACESHIP) reduce 10) ((T_SR) reduce 10) (("[") reduce 10) (("^") reduce 10) (("{") reduce 10) (("|") reduce 10)) 15764 ((("%") reduce 67) (("(") reduce 67) ((")") reduce 67) (("*") reduce 67) (("+") reduce 67) (("-") reduce 67) ((".") reduce 67) (("/") reduce 67) (("<") reduce 67) ((">") reduce 67) (("?") reduce 67) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_BOOLEAN_AND) reduce 67) ((T_BOOLEAN_OR) reduce 67) ((T_COALESCE) reduce 67) ((T_DOUBLE_ARROW) reduce 67) ((T_INSTANCEOF) reduce 67) ((T_IS_EQUAL) reduce 67) ((T_IS_GREATER_OR_EQUAL) reduce 67) ((T_IS_IDENTICAL) reduce 67) ((T_IS_NOT_EQUAL) reduce 67) ((T_IS_NOT_IDENTICAL) reduce 67) ((T_IS_SMALLER_OR_EQUAL) reduce 67) ((T_LOGICAL_AND) reduce 67) ((T_LOGICAL_OR) reduce 67) ((T_LOGICAL_XOR) reduce 67) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 67) ((T_OBJECT_OPERATOR) reduce 67) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 67) ((T_POW) reduce 67) ((T_SL) reduce 67) ((T_SPACESHIP) reduce 67) ((T_SR) reduce 67) (("[") reduce 67) (("^") reduce 67) (("{") reduce 67) (("|") reduce 67)) 15765 ((("%") reduce 44) (("(") reduce 44) ((")") reduce 44) (("*") reduce 44) (("+") reduce 44) (("-") reduce 44) ((".") reduce 44) (("/") reduce 44) (("<") reduce 44) ((">") reduce 44) (("?") reduce 44) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_BOOLEAN_AND) reduce 44) ((T_BOOLEAN_OR) reduce 44) ((T_COALESCE) reduce 44) ((T_DOUBLE_ARROW) reduce 44) ((T_INSTANCEOF) reduce 44) ((T_IS_EQUAL) reduce 44) ((T_IS_GREATER_OR_EQUAL) reduce 44) ((T_IS_IDENTICAL) reduce 44) ((T_IS_NOT_EQUAL) reduce 44) ((T_IS_NOT_IDENTICAL) reduce 44) ((T_IS_SMALLER_OR_EQUAL) reduce 44) ((T_LOGICAL_AND) reduce 44) ((T_LOGICAL_OR) reduce 44) ((T_LOGICAL_XOR) reduce 44) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 44) ((T_OBJECT_OPERATOR) reduce 44) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 44) ((T_POW) reduce 44) ((T_SL) reduce 44) ((T_SPACESHIP) reduce 44) ((T_SR) reduce 44) (("[") reduce 44) (("^") reduce 44) (("{") reduce 44) (("|") reduce 44)) 15766 ((("%") reduce 75) (("(") reduce 75) ((")") reduce 75) (("*") reduce 75) (("+") reduce 75) (("-") reduce 75) ((".") reduce 75) (("/") reduce 75) (("<") reduce 75) ((">") reduce 75) (("?") reduce 75) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_BOOLEAN_AND) reduce 75) ((T_BOOLEAN_OR) reduce 75) ((T_COALESCE) reduce 75) ((T_DOUBLE_ARROW) reduce 75) ((T_INSTANCEOF) reduce 75) ((T_IS_EQUAL) reduce 75) ((T_IS_GREATER_OR_EQUAL) reduce 75) ((T_IS_IDENTICAL) reduce 75) ((T_IS_NOT_EQUAL) reduce 75) ((T_IS_NOT_IDENTICAL) reduce 75) ((T_IS_SMALLER_OR_EQUAL) reduce 75) ((T_LOGICAL_AND) reduce 75) ((T_LOGICAL_OR) reduce 75) ((T_LOGICAL_XOR) reduce 75) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 75) ((T_OBJECT_OPERATOR) reduce 75) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 75) ((T_POW) reduce 75) ((T_SL) reduce 75) ((T_SPACESHIP) reduce 75) ((T_SR) reduce 75) (("[") reduce 75) (("^") reduce 75) (("{") reduce 75) (("|") reduce 75)) 15767 ((("%") reduce 76) (("(") reduce 76) ((")") reduce 76) (("*") reduce 76) (("+") reduce 76) (("-") reduce 76) ((".") reduce 76) (("/") reduce 76) (("<") reduce 76) ((">") reduce 76) (("?") reduce 76) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_BOOLEAN_AND) reduce 76) ((T_BOOLEAN_OR) reduce 76) ((T_COALESCE) reduce 76) ((T_DOUBLE_ARROW) reduce 76) ((T_INSTANCEOF) reduce 76) ((T_IS_EQUAL) reduce 76) ((T_IS_GREATER_OR_EQUAL) reduce 76) ((T_IS_IDENTICAL) reduce 76) ((T_IS_NOT_EQUAL) reduce 76) ((T_IS_NOT_IDENTICAL) reduce 76) ((T_IS_SMALLER_OR_EQUAL) reduce 76) ((T_LOGICAL_AND) reduce 76) ((T_LOGICAL_OR) reduce 76) ((T_LOGICAL_XOR) reduce 76) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 76) ((T_OBJECT_OPERATOR) reduce 76) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 76) ((T_POW) reduce 76) ((T_SL) reduce 76) ((T_SPACESHIP) reduce 76) ((T_SR) reduce 76) (("[") reduce 76) (("^") reduce 76) (("{") reduce 76) (("|") reduce 76)) 15768 ((("%") reduce 77) (("(") reduce 77) ((")") reduce 77) (("*") reduce 77) (("+") reduce 77) (("-") reduce 77) ((".") reduce 77) (("/") reduce 77) (("<") reduce 77) ((">") reduce 77) (("?") reduce 77) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_BOOLEAN_AND) reduce 77) ((T_BOOLEAN_OR) reduce 77) ((T_COALESCE) reduce 77) ((T_DOUBLE_ARROW) reduce 77) ((T_INSTANCEOF) reduce 77) ((T_IS_EQUAL) reduce 77) ((T_IS_GREATER_OR_EQUAL) reduce 77) ((T_IS_IDENTICAL) reduce 77) ((T_IS_NOT_EQUAL) reduce 77) ((T_IS_NOT_IDENTICAL) reduce 77) ((T_IS_SMALLER_OR_EQUAL) reduce 77) ((T_LOGICAL_AND) reduce 77) ((T_LOGICAL_OR) reduce 77) ((T_LOGICAL_XOR) reduce 77) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 77) ((T_OBJECT_OPERATOR) reduce 77) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 77) ((T_POW) reduce 77) ((T_SL) reduce 77) ((T_SPACESHIP) reduce 77) ((T_SR) reduce 77) (("[") reduce 77) (("^") reduce 77) (("{") reduce 77) (("|") reduce 77)) 15769 ((("%") reduce 78) (("(") reduce 78) ((")") reduce 78) (("*") reduce 78) (("+") reduce 78) (("-") reduce 78) ((".") reduce 78) (("/") reduce 78) (("<") reduce 78) ((">") reduce 78) (("?") reduce 78) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_BOOLEAN_AND) reduce 78) ((T_BOOLEAN_OR) reduce 78) ((T_COALESCE) reduce 78) ((T_DOUBLE_ARROW) reduce 78) ((T_INSTANCEOF) reduce 78) ((T_IS_EQUAL) reduce 78) ((T_IS_GREATER_OR_EQUAL) reduce 78) ((T_IS_IDENTICAL) reduce 78) ((T_IS_NOT_EQUAL) reduce 78) ((T_IS_NOT_IDENTICAL) reduce 78) ((T_IS_SMALLER_OR_EQUAL) reduce 78) ((T_LOGICAL_AND) reduce 78) ((T_LOGICAL_OR) reduce 78) ((T_LOGICAL_XOR) reduce 78) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 78) ((T_OBJECT_OPERATOR) reduce 78) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 78) ((T_POW) reduce 78) ((T_SL) reduce 78) ((T_SPACESHIP) reduce 78) ((T_SR) reduce 78) (("[") reduce 78) (("^") reduce 78) (("{") reduce 78) (("|") reduce 78)) 15770 ((("%") reduce 4) (("(") reduce 4) ((")") reduce 4) (("*") reduce 4) (("+") reduce 4) (("-") reduce 4) ((".") reduce 4) (("/") reduce 4) (("<") reduce 4) ((">") reduce 4) (("?") reduce 4) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_BOOLEAN_AND) reduce 4) ((T_BOOLEAN_OR) reduce 4) ((T_COALESCE) reduce 4) ((T_DOUBLE_ARROW) reduce 4) ((T_INSTANCEOF) reduce 4) ((T_IS_EQUAL) reduce 4) ((T_IS_GREATER_OR_EQUAL) reduce 4) ((T_IS_IDENTICAL) reduce 4) ((T_IS_NOT_EQUAL) reduce 4) ((T_IS_NOT_IDENTICAL) reduce 4) ((T_IS_SMALLER_OR_EQUAL) reduce 4) ((T_LOGICAL_AND) reduce 4) ((T_LOGICAL_OR) reduce 4) ((T_LOGICAL_XOR) reduce 4) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 4) ((T_OBJECT_OPERATOR) reduce 4) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 4) ((T_POW) reduce 4) ((T_SL) reduce 4) ((T_SPACESHIP) reduce 4) ((T_SR) reduce 4) (("[") reduce 4) (("^") reduce 4) (("{") reduce 4) (("|") reduce 4)) 15771 ((("%") reduce 5) (("(") reduce 5) ((")") reduce 5) (("*") reduce 5) (("+") reduce 5) (("-") reduce 5) ((".") reduce 5) (("/") reduce 5) (("<") reduce 5) ((">") reduce 5) (("?") reduce 5) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_BOOLEAN_AND) reduce 5) ((T_BOOLEAN_OR) reduce 5) ((T_COALESCE) reduce 5) ((T_DOUBLE_ARROW) reduce 5) ((T_INSTANCEOF) reduce 5) ((T_IS_EQUAL) reduce 5) ((T_IS_GREATER_OR_EQUAL) reduce 5) ((T_IS_IDENTICAL) reduce 5) ((T_IS_NOT_EQUAL) reduce 5) ((T_IS_NOT_IDENTICAL) reduce 5) ((T_IS_SMALLER_OR_EQUAL) reduce 5) ((T_LOGICAL_AND) reduce 5) ((T_LOGICAL_OR) reduce 5) ((T_LOGICAL_XOR) reduce 5) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 5) ((T_OBJECT_OPERATOR) reduce 5) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 5) ((T_POW) reduce 5) ((T_SL) reduce 5) ((T_SPACESHIP) reduce 5) ((T_SR) reduce 5) (("[") reduce 5) (("^") reduce 5) (("{") reduce 5) (("|") reduce 5)) 15772 ((("%") reduce 43) (("(") reduce 43) ((")") reduce 43) (("*") reduce 43) (("+") reduce 43) (("-") reduce 43) ((".") reduce 43) (("/") reduce 43) (("<") reduce 43) ((">") reduce 43) (("?") reduce 43) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_BOOLEAN_AND) reduce 43) ((T_BOOLEAN_OR) reduce 43) ((T_COALESCE) reduce 43) ((T_DOUBLE_ARROW) reduce 43) ((T_INSTANCEOF) reduce 43) ((T_IS_EQUAL) reduce 43) ((T_IS_GREATER_OR_EQUAL) reduce 43) ((T_IS_IDENTICAL) reduce 43) ((T_IS_NOT_EQUAL) reduce 43) ((T_IS_NOT_IDENTICAL) reduce 43) ((T_IS_SMALLER_OR_EQUAL) reduce 43) ((T_LOGICAL_AND) reduce 43) ((T_LOGICAL_OR) reduce 43) ((T_LOGICAL_XOR) reduce 43) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 43) ((T_OBJECT_OPERATOR) reduce 43) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 43) ((T_POW) reduce 43) ((T_SL) reduce 43) ((T_SPACESHIP) reduce 43) ((T_SR) reduce 43) (("[") reduce 43) (("^") reduce 43) (("{") reduce 43) (("|") reduce 43)) 15773 ((("%") reduce 72) (("(") reduce 72) ((")") reduce 72) (("*") reduce 72) (("+") reduce 72) (("-") reduce 72) ((".") reduce 72) (("/") reduce 72) (("<") reduce 72) ((">") reduce 72) (("?") reduce 72) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_BOOLEAN_AND) reduce 72) ((T_BOOLEAN_OR) reduce 72) ((T_COALESCE) reduce 72) ((T_DOUBLE_ARROW) reduce 72) ((T_INSTANCEOF) reduce 72) ((T_IS_EQUAL) reduce 72) ((T_IS_GREATER_OR_EQUAL) reduce 72) ((T_IS_IDENTICAL) reduce 72) ((T_IS_NOT_EQUAL) reduce 72) ((T_IS_NOT_IDENTICAL) reduce 72) ((T_IS_SMALLER_OR_EQUAL) reduce 72) ((T_LOGICAL_AND) reduce 72) ((T_LOGICAL_OR) reduce 72) ((T_LOGICAL_XOR) reduce 72) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 72) ((T_OBJECT_OPERATOR) reduce 72) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 72) ((T_POW) reduce 72) ((T_SL) reduce 72) ((T_SPACESHIP) reduce 72) ((T_SR) reduce 72) (("[") reduce 72) (("^") reduce 72) (("{") reduce 72) (("|") reduce 72)) 15774 ((("%") reduce 81) (("(") reduce 81) ((")") reduce 81) (("*") reduce 81) (("+") reduce 81) (("-") reduce 81) ((".") reduce 81) (("/") reduce 81) (("<") reduce 81) ((">") reduce 81) (("?") reduce 81) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_BOOLEAN_AND) reduce 81) ((T_BOOLEAN_OR) reduce 81) ((T_COALESCE) reduce 81) ((T_DOUBLE_ARROW) reduce 81) ((T_INSTANCEOF) reduce 81) ((T_IS_EQUAL) reduce 81) ((T_IS_GREATER_OR_EQUAL) reduce 81) ((T_IS_IDENTICAL) reduce 81) ((T_IS_NOT_EQUAL) reduce 81) ((T_IS_NOT_IDENTICAL) reduce 81) ((T_IS_SMALLER_OR_EQUAL) reduce 81) ((T_LOGICAL_AND) reduce 81) ((T_LOGICAL_OR) reduce 81) ((T_LOGICAL_XOR) reduce 81) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 81) ((T_OBJECT_OPERATOR) reduce 81) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 81) ((T_POW) reduce 81) ((T_SL) reduce 81) ((T_SPACESHIP) reduce 81) ((T_SR) reduce 81) (("[") reduce 81) (("^") reduce 81) (("{") reduce 81) (("|") reduce 81)) 15775 ((("%") reduce 47) (("(") reduce 47) ((")") reduce 47) (("*") reduce 47) (("+") reduce 47) (("-") reduce 47) ((".") reduce 47) (("/") reduce 47) (("<") reduce 47) ((">") reduce 47) (("?") reduce 47) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_BOOLEAN_AND) reduce 47) ((T_BOOLEAN_OR) reduce 47) ((T_COALESCE) reduce 47) ((T_DOUBLE_ARROW) reduce 47) ((T_INSTANCEOF) reduce 47) ((T_IS_EQUAL) reduce 47) ((T_IS_GREATER_OR_EQUAL) reduce 47) ((T_IS_IDENTICAL) reduce 47) ((T_IS_NOT_EQUAL) reduce 47) ((T_IS_NOT_IDENTICAL) reduce 47) ((T_IS_SMALLER_OR_EQUAL) reduce 47) ((T_LOGICAL_AND) reduce 47) ((T_LOGICAL_OR) reduce 47) ((T_LOGICAL_XOR) reduce 47) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 47) ((T_OBJECT_OPERATOR) reduce 47) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 47) ((T_POW) reduce 47) ((T_SL) reduce 47) ((T_SPACESHIP) reduce 47) ((T_SR) reduce 47) (("[") reduce 47) (("^") reduce 47) (("{") reduce 47) (("|") reduce 47)) 15776 ((("%") reduce 31) (("(") reduce 31) ((")") reduce 31) (("*") reduce 31) (("+") reduce 31) (("-") reduce 31) ((".") reduce 31) (("/") reduce 31) (("<") reduce 31) ((">") reduce 31) (("?") reduce 31) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_BOOLEAN_AND) reduce 31) ((T_BOOLEAN_OR) reduce 31) ((T_COALESCE) reduce 31) ((T_DOUBLE_ARROW) reduce 31) ((T_INSTANCEOF) reduce 31) ((T_IS_EQUAL) reduce 31) ((T_IS_GREATER_OR_EQUAL) reduce 31) ((T_IS_IDENTICAL) reduce 31) ((T_IS_NOT_EQUAL) reduce 31) ((T_IS_NOT_IDENTICAL) reduce 31) ((T_IS_SMALLER_OR_EQUAL) reduce 31) ((T_LOGICAL_AND) reduce 31) ((T_LOGICAL_OR) reduce 31) ((T_LOGICAL_XOR) reduce 31) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 31) ((T_OBJECT_OPERATOR) reduce 31) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 31) ((T_POW) reduce 31) ((T_SL) reduce 31) ((T_SPACESHIP) reduce 31) ((T_SR) reduce 31) (("[") reduce 31) (("^") reduce 31) (("{") reduce 31) (("|") reduce 31)) 15777 ((("%") reduce 57) (("(") reduce 57) ((")") reduce 57) (("*") reduce 57) (("+") reduce 57) (("-") reduce 57) ((".") reduce 57) (("/") reduce 57) (("<") reduce 57) ((">") reduce 57) (("?") reduce 57) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_BOOLEAN_AND) reduce 57) ((T_BOOLEAN_OR) reduce 57) ((T_COALESCE) reduce 57) ((T_DOUBLE_ARROW) reduce 57) ((T_INSTANCEOF) reduce 57) ((T_IS_EQUAL) reduce 57) ((T_IS_GREATER_OR_EQUAL) reduce 57) ((T_IS_IDENTICAL) reduce 57) ((T_IS_NOT_EQUAL) reduce 57) ((T_IS_NOT_IDENTICAL) reduce 57) ((T_IS_SMALLER_OR_EQUAL) reduce 57) ((T_LOGICAL_AND) reduce 57) ((T_LOGICAL_OR) reduce 57) ((T_LOGICAL_XOR) reduce 57) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 57) ((T_OBJECT_OPERATOR) reduce 57) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 57) ((T_POW) reduce 57) ((T_SL) reduce 57) ((T_SPACESHIP) reduce 57) ((T_SR) reduce 57) (("[") reduce 57) (("^") reduce 57) (("{") reduce 57) (("|") reduce 57)) 15778 ((("%") reduce 61) (("(") reduce 61) ((")") reduce 61) (("*") reduce 61) (("+") reduce 61) (("-") reduce 61) ((".") reduce 61) (("/") reduce 61) (("<") reduce 61) ((">") reduce 61) (("?") reduce 61) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_BOOLEAN_AND) reduce 61) ((T_BOOLEAN_OR) reduce 61) ((T_COALESCE) reduce 61) ((T_DOUBLE_ARROW) reduce 61) ((T_INSTANCEOF) reduce 61) ((T_IS_EQUAL) reduce 61) ((T_IS_GREATER_OR_EQUAL) reduce 61) ((T_IS_IDENTICAL) reduce 61) ((T_IS_NOT_EQUAL) reduce 61) ((T_IS_NOT_IDENTICAL) reduce 61) ((T_IS_SMALLER_OR_EQUAL) reduce 61) ((T_LOGICAL_AND) reduce 61) ((T_LOGICAL_OR) reduce 61) ((T_LOGICAL_XOR) reduce 61) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 61) ((T_OBJECT_OPERATOR) reduce 61) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 61) ((T_POW) reduce 61) ((T_SL) reduce 61) ((T_SPACESHIP) reduce 61) ((T_SR) reduce 61) (("[") reduce 61) (("^") reduce 61) (("{") reduce 61) (("|") reduce 61)) 15779 ((("%") reduce 28) (("(") reduce 28) ((")") reduce 28) (("*") reduce 28) (("+") reduce 28) (("-") reduce 28) ((".") reduce 28) (("/") reduce 28) (("<") reduce 28) ((">") reduce 28) (("?") reduce 28) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_BOOLEAN_AND) reduce 28) ((T_BOOLEAN_OR) reduce 28) ((T_COALESCE) reduce 28) ((T_DOUBLE_ARROW) reduce 28) ((T_INSTANCEOF) reduce 28) ((T_IS_EQUAL) reduce 28) ((T_IS_GREATER_OR_EQUAL) reduce 28) ((T_IS_IDENTICAL) reduce 28) ((T_IS_NOT_EQUAL) reduce 28) ((T_IS_NOT_IDENTICAL) reduce 28) ((T_IS_SMALLER_OR_EQUAL) reduce 28) ((T_LOGICAL_AND) reduce 28) ((T_LOGICAL_OR) reduce 28) ((T_LOGICAL_XOR) reduce 28) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 28) ((T_OBJECT_OPERATOR) reduce 28) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 28) ((T_POW) reduce 28) ((T_SL) reduce 28) ((T_SPACESHIP) reduce 28) ((T_SR) reduce 28) (("[") reduce 28) (("^") reduce 28) (("{") reduce 28) (("|") reduce 28)) 15780 ((("%") reduce 36) (("(") reduce 36) ((")") reduce 36) (("*") reduce 36) (("+") reduce 36) (("-") reduce 36) ((".") reduce 36) (("/") reduce 36) (("<") reduce 36) ((">") reduce 36) (("?") reduce 36) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_BOOLEAN_AND) reduce 36) ((T_BOOLEAN_OR) reduce 36) ((T_COALESCE) reduce 36) ((T_DOUBLE_ARROW) reduce 36) ((T_INSTANCEOF) reduce 36) ((T_IS_EQUAL) reduce 36) ((T_IS_GREATER_OR_EQUAL) reduce 36) ((T_IS_IDENTICAL) reduce 36) ((T_IS_NOT_EQUAL) reduce 36) ((T_IS_NOT_IDENTICAL) reduce 36) ((T_IS_SMALLER_OR_EQUAL) reduce 36) ((T_LOGICAL_AND) reduce 36) ((T_LOGICAL_OR) reduce 36) ((T_LOGICAL_XOR) reduce 36) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 36) ((T_OBJECT_OPERATOR) reduce 36) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 36) ((T_POW) reduce 36) ((T_SL) reduce 36) ((T_SPACESHIP) reduce 36) ((T_SR) reduce 36) (("[") reduce 36) (("^") reduce 36) (("{") reduce 36) (("|") reduce 36)) 15781 ((("%") reduce 32) (("(") reduce 32) ((")") reduce 32) (("*") reduce 32) (("+") reduce 32) (("-") reduce 32) ((".") reduce 32) (("/") reduce 32) (("<") reduce 32) ((">") reduce 32) (("?") reduce 32) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_BOOLEAN_AND) reduce 32) ((T_BOOLEAN_OR) reduce 32) ((T_COALESCE) reduce 32) ((T_DOUBLE_ARROW) reduce 32) ((T_INSTANCEOF) reduce 32) ((T_IS_EQUAL) reduce 32) ((T_IS_GREATER_OR_EQUAL) reduce 32) ((T_IS_IDENTICAL) reduce 32) ((T_IS_NOT_EQUAL) reduce 32) ((T_IS_NOT_IDENTICAL) reduce 32) ((T_IS_SMALLER_OR_EQUAL) reduce 32) ((T_LOGICAL_AND) reduce 32) ((T_LOGICAL_OR) reduce 32) ((T_LOGICAL_XOR) reduce 32) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 32) ((T_OBJECT_OPERATOR) reduce 32) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 32) ((T_POW) reduce 32) ((T_SL) reduce 32) ((T_SPACESHIP) reduce 32) ((T_SR) reduce 32) (("[") reduce 32) (("^") reduce 32) (("{") reduce 32) (("|") reduce 32)) 15782 ((("%") reduce 35) (("(") reduce 35) ((")") reduce 35) (("*") reduce 35) (("+") reduce 35) (("-") reduce 35) ((".") reduce 35) (("/") reduce 35) (("<") reduce 35) ((">") reduce 35) (("?") reduce 35) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_BOOLEAN_AND) reduce 35) ((T_BOOLEAN_OR) reduce 35) ((T_COALESCE) reduce 35) ((T_DOUBLE_ARROW) reduce 35) ((T_INSTANCEOF) reduce 35) ((T_IS_EQUAL) reduce 35) ((T_IS_GREATER_OR_EQUAL) reduce 35) ((T_IS_IDENTICAL) reduce 35) ((T_IS_NOT_EQUAL) reduce 35) ((T_IS_NOT_IDENTICAL) reduce 35) ((T_IS_SMALLER_OR_EQUAL) reduce 35) ((T_LOGICAL_AND) reduce 35) ((T_LOGICAL_OR) reduce 35) ((T_LOGICAL_XOR) reduce 35) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 35) ((T_OBJECT_OPERATOR) reduce 35) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 35) ((T_POW) reduce 35) ((T_SL) reduce 35) ((T_SPACESHIP) reduce 35) ((T_SR) reduce 35) (("[") reduce 35) (("^") reduce 35) (("{") reduce 35) (("|") reduce 35)) 15783 ((("%") reduce 19) (("(") reduce 19) ((")") reduce 19) (("*") reduce 19) (("+") reduce 19) (("-") reduce 19) ((".") reduce 19) (("/") reduce 19) (("<") reduce 19) ((">") reduce 19) (("?") reduce 19) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_BOOLEAN_AND) reduce 19) ((T_BOOLEAN_OR) reduce 19) ((T_COALESCE) reduce 19) ((T_DOUBLE_ARROW) reduce 19) ((T_INSTANCEOF) reduce 19) ((T_IS_EQUAL) reduce 19) ((T_IS_GREATER_OR_EQUAL) reduce 19) ((T_IS_IDENTICAL) reduce 19) ((T_IS_NOT_EQUAL) reduce 19) ((T_IS_NOT_IDENTICAL) reduce 19) ((T_IS_SMALLER_OR_EQUAL) reduce 19) ((T_LOGICAL_AND) reduce 19) ((T_LOGICAL_OR) reduce 19) ((T_LOGICAL_XOR) reduce 19) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 19) ((T_OBJECT_OPERATOR) reduce 19) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 19) ((T_POW) reduce 19) ((T_SL) reduce 19) ((T_SPACESHIP) reduce 19) ((T_SR) reduce 19) (("[") reduce 19) (("^") reduce 19) (("{") reduce 19) (("|") reduce 19)) 15784 ((("%") reduce 45) (("(") reduce 45) ((")") reduce 45) (("*") reduce 45) (("+") reduce 45) (("-") reduce 45) ((".") reduce 45) (("/") reduce 45) (("<") reduce 45) ((">") reduce 45) (("?") reduce 45) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_BOOLEAN_AND) reduce 45) ((T_BOOLEAN_OR) reduce 45) ((T_COALESCE) reduce 45) ((T_DOUBLE_ARROW) reduce 45) ((T_INSTANCEOF) reduce 45) ((T_IS_EQUAL) reduce 45) ((T_IS_GREATER_OR_EQUAL) reduce 45) ((T_IS_IDENTICAL) reduce 45) ((T_IS_NOT_EQUAL) reduce 45) ((T_IS_NOT_IDENTICAL) reduce 45) ((T_IS_SMALLER_OR_EQUAL) reduce 45) ((T_LOGICAL_AND) reduce 45) ((T_LOGICAL_OR) reduce 45) ((T_LOGICAL_XOR) reduce 45) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 45) ((T_OBJECT_OPERATOR) reduce 45) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 45) ((T_POW) reduce 45) ((T_SL) reduce 45) ((T_SPACESHIP) reduce 45) ((T_SR) reduce 45) (("[") reduce 45) (("^") reduce 45) (("{") reduce 45) (("|") reduce 45)) 15785 ((("%") reduce 504) (("(") reduce 541) ((")") reduce 504) (("*") reduce 504) (("+") reduce 504) (("-") reduce 504) ((".") reduce 504) (("/") reduce 504) (("<") reduce 504) ((">") reduce 504) (("?") reduce 504) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_BOOLEAN_AND) reduce 504) ((T_BOOLEAN_OR) reduce 504) ((T_COALESCE) reduce 504) ((T_DOUBLE_ARROW) reduce 504) ((T_INSTANCEOF) reduce 504) ((T_IS_EQUAL) reduce 504) ((T_IS_GREATER_OR_EQUAL) reduce 504) ((T_IS_IDENTICAL) reduce 504) ((T_IS_NOT_EQUAL) reduce 504) ((T_IS_NOT_IDENTICAL) reduce 504) ((T_IS_SMALLER_OR_EQUAL) reduce 504) ((T_LOGICAL_AND) reduce 504) ((T_LOGICAL_OR) reduce 504) ((T_LOGICAL_XOR) reduce 504) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 504) ((T_OBJECT_OPERATOR) reduce 504) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 504) ((T_POW) reduce 504) ((T_SL) reduce 504) ((T_SPACESHIP) reduce 504) ((T_SR) reduce 504) (("[") reduce 504) (("^") reduce 504) (("{") reduce 504) (("|") reduce 504)) 15787 ((("%") reduce 71) (("(") reduce 71) ((")") reduce 71) (("*") reduce 71) (("+") reduce 71) (("-") reduce 71) ((".") reduce 71) (("/") reduce 71) (("<") reduce 71) ((">") reduce 71) (("?") reduce 71) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_BOOLEAN_AND) reduce 71) ((T_BOOLEAN_OR) reduce 71) ((T_COALESCE) reduce 71) ((T_DOUBLE_ARROW) reduce 71) ((T_INSTANCEOF) reduce 71) ((T_IS_EQUAL) reduce 71) ((T_IS_GREATER_OR_EQUAL) reduce 71) ((T_IS_IDENTICAL) reduce 71) ((T_IS_NOT_EQUAL) reduce 71) ((T_IS_NOT_IDENTICAL) reduce 71) ((T_IS_SMALLER_OR_EQUAL) reduce 71) ((T_LOGICAL_AND) reduce 71) ((T_LOGICAL_OR) reduce 71) ((T_LOGICAL_XOR) reduce 71) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 71) ((T_OBJECT_OPERATOR) reduce 71) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 71) ((T_POW) reduce 71) ((T_SL) reduce 71) ((T_SPACESHIP) reduce 71) ((T_SR) reduce 71) (("[") reduce 71) (("^") reduce 71) (("{") reduce 71) (("|") reduce 71)) 15788 ((("%") reduce 82) (("(") reduce 82) ((")") reduce 82) (("*") reduce 82) (("+") reduce 82) (("-") reduce 82) ((".") reduce 82) (("/") reduce 82) (("<") reduce 82) ((">") reduce 82) (("?") reduce 82) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_BOOLEAN_AND) reduce 82) ((T_BOOLEAN_OR) reduce 82) ((T_COALESCE) reduce 82) ((T_DOUBLE_ARROW) reduce 82) ((T_INSTANCEOF) reduce 82) ((T_IS_EQUAL) reduce 82) ((T_IS_GREATER_OR_EQUAL) reduce 82) ((T_IS_IDENTICAL) reduce 82) ((T_IS_NOT_EQUAL) reduce 82) ((T_IS_NOT_IDENTICAL) reduce 82) ((T_IS_SMALLER_OR_EQUAL) reduce 82) ((T_LOGICAL_AND) reduce 82) ((T_LOGICAL_OR) reduce 82) ((T_LOGICAL_XOR) reduce 82) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 82) ((T_OBJECT_OPERATOR) reduce 82) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 82) ((T_POW) reduce 82) ((T_SL) reduce 82) ((T_SPACESHIP) reduce 82) ((T_SR) reduce 82) (("[") reduce 82) (("^") reduce 82) (("{") reduce 82) (("|") reduce 82)) 15789 ((("%") reduce 533) (("(") reduce 543) ((")") reduce 533) (("*") reduce 533) (("+") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) (("<") reduce 533) (("=") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AND_EQUAL) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_COALESCE_EQUAL) reduce 533) ((T_CONCAT_EQUAL) reduce 533) ((T_DEC) reduce 533) ((T_DIV_EQUAL) reduce 533) ((T_DOUBLE_ARROW) reduce 533) ((T_INC) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_MINUS_EQUAL) reduce 533) ((T_MOD_EQUAL) reduce 533) ((T_MUL_EQUAL) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_OR_EQUAL) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_PLUS_EQUAL) reduce 533) ((T_POW) reduce 533) ((T_POW_EQUAL) reduce 533) ((T_SL) reduce 533) ((T_SL_EQUAL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) ((T_SR_EQUAL) reduce 533) ((T_XOR_EQUAL) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 15792 ((("%") reduce 506) (("(") reduce 542) ((")") reduce 506) (("*") reduce 506) (("+") reduce 506) (("-") reduce 506) ((".") reduce 506) (("/") reduce 506) (("<") reduce 506) ((">") reduce 506) (("?") reduce 506) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_BOOLEAN_AND) reduce 506) ((T_BOOLEAN_OR) reduce 506) ((T_COALESCE) reduce 506) ((T_DOUBLE_ARROW) reduce 506) ((T_INSTANCEOF) reduce 506) ((T_IS_EQUAL) reduce 506) ((T_IS_GREATER_OR_EQUAL) reduce 506) ((T_IS_IDENTICAL) reduce 506) ((T_IS_NOT_EQUAL) reduce 506) ((T_IS_NOT_IDENTICAL) reduce 506) ((T_IS_SMALLER_OR_EQUAL) reduce 506) ((T_LOGICAL_AND) reduce 506) ((T_LOGICAL_OR) reduce 506) ((T_LOGICAL_XOR) reduce 506) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 506) ((T_OBJECT_OPERATOR) reduce 506) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 506) ((T_POW) reduce 506) ((T_SL) reduce 506) ((T_SPACESHIP) reduce 506) ((T_SR) reduce 506) (("[") reduce 506) (("^") reduce 506) (("{") reduce 506) (("|") reduce 506)) 15794 ((("%") reduce 468) (("(") reduce 468) ((")") reduce 468) (("*") reduce 468) (("+") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) (("<") reduce 468) (("=") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AND_EQUAL) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_COALESCE_EQUAL) reduce 468) ((T_CONCAT_EQUAL) reduce 468) ((T_DEC) reduce 468) ((T_DIV_EQUAL) reduce 468) ((T_DOUBLE_ARROW) reduce 468) ((T_INC) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_MINUS_EQUAL) reduce 468) ((T_MOD_EQUAL) reduce 468) ((T_MUL_EQUAL) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_OR_EQUAL) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_PLUS_EQUAL) reduce 468) ((T_POW) reduce 468) ((T_POW_EQUAL) reduce 468) ((T_SL) reduce 468) ((T_SL_EQUAL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) ((T_SR_EQUAL) reduce 468) ((T_XOR_EQUAL) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 15795 ((("%") reduce 288) (("(") reduce 288) ((")") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) (("=") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AND_EQUAL) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_COALESCE_EQUAL) reduce 288) ((T_CONCAT_EQUAL) reduce 288) ((T_DEC) reduce 288) ((T_DIV_EQUAL) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INC) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_MINUS_EQUAL) reduce 288) ((T_MOD_EQUAL) reduce 288) ((T_MUL_EQUAL) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_OR_EQUAL) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_PLUS_EQUAL) reduce 288) ((T_POW) reduce 288) ((T_POW_EQUAL) reduce 288) ((T_SL) reduce 288) ((T_SL_EQUAL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) ((T_SR_EQUAL) reduce 288) ((T_XOR_EQUAL) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 15799 ((("%") reduce 289) (("(") reduce 289) ((")") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) (("=") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AND_EQUAL) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_COALESCE_EQUAL) reduce 289) ((T_CONCAT_EQUAL) reduce 289) ((T_DEC) reduce 289) ((T_DIV_EQUAL) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INC) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_MINUS_EQUAL) reduce 289) ((T_MOD_EQUAL) reduce 289) ((T_MUL_EQUAL) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_OR_EQUAL) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_PLUS_EQUAL) reduce 289) ((T_POW) reduce 289) ((T_POW_EQUAL) reduce 289) ((T_SL) reduce 289) ((T_SL_EQUAL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) ((T_SR_EQUAL) reduce 289) ((T_XOR_EQUAL) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 15800 ((("%") reduce 290) (("(") reduce 290) ((")") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) (("=") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AND_EQUAL) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_COALESCE_EQUAL) reduce 290) ((T_CONCAT_EQUAL) reduce 290) ((T_DEC) reduce 290) ((T_DIV_EQUAL) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INC) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_MINUS_EQUAL) reduce 290) ((T_MOD_EQUAL) reduce 290) ((T_MUL_EQUAL) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_OR_EQUAL) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_PLUS_EQUAL) reduce 290) ((T_POW) reduce 290) ((T_POW_EQUAL) reduce 290) ((T_SL) reduce 290) ((T_SL_EQUAL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) ((T_SR_EQUAL) reduce 290) ((T_XOR_EQUAL) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 15805 ((("%") reduce 388) ((")") reduce 388) (("*") reduce 388) (("+") reduce 388) (("-") reduce 388) ((".") reduce 388) (("/") reduce 388) (("<") reduce 388) ((">") reduce 388) (("?") reduce 388) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_BOOLEAN_AND) reduce 388) ((T_BOOLEAN_OR) reduce 388) ((T_COALESCE) reduce 388) ((T_DOUBLE_ARROW) reduce 388) ((T_INSTANCEOF) reduce 388) ((T_IS_EQUAL) reduce 388) ((T_IS_GREATER_OR_EQUAL) reduce 388) ((T_IS_IDENTICAL) reduce 388) ((T_IS_NOT_EQUAL) reduce 388) ((T_IS_NOT_IDENTICAL) reduce 388) ((T_IS_SMALLER_OR_EQUAL) reduce 388) ((T_LOGICAL_AND) reduce 388) ((T_LOGICAL_OR) reduce 388) ((T_LOGICAL_XOR) reduce 388) ((T_POW) reduce 388) ((T_SL) reduce 388) ((T_SPACESHIP) reduce 388) ((T_SR) reduce 388) (("^") reduce 388) (("|") reduce 388)) 15807 ((("%") reduce 386) ((")") reduce 386) (("*") reduce 386) (("+") reduce 386) (("-") reduce 386) ((".") reduce 386) (("/") reduce 386) (("<") reduce 386) ((">") reduce 386) (("?") reduce 386) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_BOOLEAN_AND) reduce 386) ((T_BOOLEAN_OR) reduce 386) ((T_COALESCE) reduce 386) ((T_DOUBLE_ARROW) reduce 386) ((T_INSTANCEOF) reduce 386) ((T_IS_EQUAL) reduce 386) ((T_IS_GREATER_OR_EQUAL) reduce 386) ((T_IS_IDENTICAL) reduce 386) ((T_IS_NOT_EQUAL) reduce 386) ((T_IS_NOT_IDENTICAL) reduce 386) ((T_IS_SMALLER_OR_EQUAL) reduce 386) ((T_LOGICAL_AND) reduce 386) ((T_LOGICAL_OR) reduce 386) ((T_LOGICAL_XOR) reduce 386) ((T_POW) reduce 386) ((T_SL) reduce 386) ((T_SPACESHIP) reduce 386) ((T_SR) reduce 386) (("^") reduce 386) (("|") reduce 386)) 15817 ((("%") shift) ((")") reduce 382) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 382) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 382) ((T_LOGICAL_OR) reduce 382) ((T_LOGICAL_XOR) reduce 382) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15818 ((("%") shift) ((")") reduce 384) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 384) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 384) ((T_LOGICAL_OR) reduce 384) ((T_LOGICAL_XOR) reduce 384) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15819 ((("%") shift) ((")") reduce 383) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 383) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 383) ((T_LOGICAL_OR) reduce 383) ((T_LOGICAL_XOR) reduce 383) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15820 ((("%") shift) ((")") reduce 376) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 376) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 376) ((T_LOGICAL_OR) reduce 376) ((T_LOGICAL_XOR) reduce 376) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15821 ((("%") shift) ((")") reduce 373) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 373) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 373) ((T_LOGICAL_OR) reduce 373) ((T_LOGICAL_XOR) reduce 373) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15822 ((("%") shift) ((")") reduce 381) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 381) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 381) ((T_LOGICAL_OR) reduce 381) ((T_LOGICAL_XOR) reduce 381) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15823 ((("%") shift) ((")") reduce 375) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 375) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 375) ((T_LOGICAL_OR) reduce 375) ((T_LOGICAL_XOR) reduce 375) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15824 ((("%") shift) ((")") reduce 379) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 379) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 379) ((T_LOGICAL_OR) reduce 379) ((T_LOGICAL_XOR) reduce 379) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15825 ((("%") shift) ((")") reduce 374) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 374) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 374) ((T_LOGICAL_OR) reduce 374) ((T_LOGICAL_XOR) reduce 374) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15826 ((("%") shift) ((")") reduce 377) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 377) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 377) ((T_LOGICAL_OR) reduce 377) ((T_LOGICAL_XOR) reduce 377) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15827 ((("%") shift) ((")") reduce 378) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 378) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 378) ((T_LOGICAL_OR) reduce 378) ((T_LOGICAL_XOR) reduce 378) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15828 ((("%") shift) ((")") reduce 385) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 385) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 385) ((T_LOGICAL_OR) reduce 385) ((T_LOGICAL_XOR) reduce 385) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15829 ((("%") shift) ((")") reduce 380) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 380) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 380) ((T_LOGICAL_OR) reduce 380) ((T_LOGICAL_XOR) reduce 380) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15831 ((("%") shift) ((")") reduce 370) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 370) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 370) ((T_LOGICAL_OR) reduce 370) ((T_LOGICAL_XOR) reduce 370) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15834 ((("%") reduce 529) (("(") reduce 529) ((")") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 15837 ((("%") reduce 525) (("(") reduce 516) ((")") reduce 525) (("*") reduce 525) (("+") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) (("<") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_DOUBLE_ARROW) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_POW) reduce 525) ((T_SL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 15839 ((("%") reduce 524) (("(") reduce 524) ((")") reduce 524) (("*") reduce 524) (("+") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) (("<") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_DOUBLE_ARROW) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_POW) reduce 524) ((T_SL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 15841 ((("%") reduce 519) (("(") reduce 519) ((")") reduce 519) (("*") reduce 519) (("+") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) (("<") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_DOUBLE_ARROW) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_POW) reduce 519) ((T_SL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 15842 ((("%") reduce 526) ((")") reduce 526) (("*") reduce 526) (("+") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) (("<") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_DOUBLE_ARROW) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_POW) reduce 526) ((T_SL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 15843 ((("%") reduce 371) ((")") reduce 371) (("*") reduce 371) (("+") reduce 371) (("-") reduce 371) ((".") reduce 371) (("/") reduce 371) (("<") reduce 371) ((">") reduce 371) (("?") reduce 371) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_BOOLEAN_AND) reduce 371) ((T_BOOLEAN_OR) reduce 371) ((T_COALESCE) reduce 371) ((T_DOUBLE_ARROW) reduce 371) ((T_INSTANCEOF) reduce 371) ((T_IS_EQUAL) reduce 371) ((T_IS_GREATER_OR_EQUAL) reduce 371) ((T_IS_IDENTICAL) reduce 371) ((T_IS_NOT_EQUAL) reduce 371) ((T_IS_NOT_IDENTICAL) reduce 371) ((T_IS_SMALLER_OR_EQUAL) reduce 371) ((T_LOGICAL_AND) reduce 371) ((T_LOGICAL_OR) reduce 371) ((T_LOGICAL_XOR) reduce 371) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 371) ((T_SL) reduce 371) ((T_SPACESHIP) reduce 371) ((T_SR) reduce 371) (("[") reduce 510) (("^") reduce 371) (("{") reduce 510) (("|") reduce 371)) 15847 ((("%") reduce 533) (("(") reduce 543) ((")") reduce 533) (("*") reduce 533) (("+") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) (("<") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_DOUBLE_ARROW) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_POW) reduce 533) ((T_SL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 15849 ((("%") reduce 468) (("(") reduce 468) ((")") reduce 468) (("*") reduce 468) (("+") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) (("<") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_DOUBLE_ARROW) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_POW) reduce 468) ((T_SL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 15850 ((("%") reduce 288) (("(") reduce 288) ((")") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 15854 ((("%") reduce 289) (("(") reduce 289) ((")") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 15855 ((("%") reduce 290) (("(") reduce 290) ((")") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 15856 ((("%") reduce 465) (("(") reduce 465) ((")") reduce 465) (("*") reduce 465) (("+") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) (("<") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_DOUBLE_ARROW) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_POW) reduce 465) ((T_SL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 15859 ((("%") reduce 532) (("(") reduce 543) ((")") reduce 532) (("*") reduce 532) (("+") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) (("<") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_DOUBLE_ARROW) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_POW) reduce 532) ((T_SL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 15860 ((("%") reduce 467) (("(") reduce 467) ((")") reduce 467) (("*") reduce 467) (("+") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) (("<") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_DOUBLE_ARROW) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_POW) reduce 467) ((T_SL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 15861 ((("%") reduce 469) (("(") reduce 469) ((")") reduce 469) (("*") reduce 469) (("+") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) (("<") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_DOUBLE_ARROW) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_POW) reduce 469) ((T_SL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 15867 ((("%") reduce 521) (("(") reduce 521) ((")") reduce 521) (("*") reduce 521) (("+") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) (("<") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_DOUBLE_ARROW) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_POW) reduce 521) ((T_SL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 15869 ((("%") reduce 520) (("(") reduce 520) ((")") reduce 520) (("*") reduce 520) (("+") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) (("<") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_DOUBLE_ARROW) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_POW) reduce 520) ((T_SL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 15870 ((("%") reduce 544) (("(") reduce 544) ((")") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 15871 ((("%") reduce 527) (("(") shift) ((")") reduce 527) (("*") reduce 527) (("+") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) (("<") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_DOUBLE_ARROW) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_POW) reduce 527) ((T_SL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 15872 ((("%") reduce 546) (("(") reduce 546) ((")") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 15875 ((("%") reduce 545) (("(") reduce 545) ((")") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 15876 ((("%") reduce 522) (("(") reduce 522) ((")") reduce 522) (("*") reduce 522) (("+") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) (("<") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_DOUBLE_ARROW) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_POW) reduce 522) ((T_SL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 15877 ((("%") reduce 528) (("(") shift) ((")") reduce 528) (("*") reduce 528) (("+") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) (("<") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_DOUBLE_ARROW) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_POW) reduce 528) ((T_SL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 15878 ((("%") reduce 523) (("(") reduce 523) ((")") reduce 523) (("*") reduce 523) (("+") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) (("<") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_DOUBLE_ARROW) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_POW) reduce 523) ((T_SL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 15879 ((("%") reduce 466) (("(") reduce 466) ((")") reduce 466) (("*") reduce 466) (("+") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) (("<") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_DOUBLE_ARROW) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_POW) reduce 466) ((T_SL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 15880 ((("%") reduce 531) (("(") reduce 531) ((")") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 15883 ((("%") reduce 530) (("(") reduce 530) ((")") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 15884 ((("%") reduce 465) (("(") reduce 465) ((")") reduce 465) (("*") reduce 465) (("+") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) (("<") reduce 465) (("=") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AND_EQUAL) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_COALESCE_EQUAL) reduce 465) ((T_CONCAT_EQUAL) reduce 465) ((T_DEC) reduce 465) ((T_DIV_EQUAL) reduce 465) ((T_DOUBLE_ARROW) reduce 465) ((T_INC) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_MINUS_EQUAL) reduce 465) ((T_MOD_EQUAL) reduce 465) ((T_MUL_EQUAL) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_OR_EQUAL) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_PLUS_EQUAL) reduce 465) ((T_POW) reduce 465) ((T_POW_EQUAL) reduce 465) ((T_SL) reduce 465) ((T_SL_EQUAL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) ((T_SR_EQUAL) reduce 465) ((T_XOR_EQUAL) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 15895 ((("%") reduce 455) ((")") reduce 455) (("*") reduce 455) (("+") reduce 455) (("-") reduce 455) ((".") reduce 455) (("/") reduce 455) (("<") reduce 455) ((">") reduce 455) (("?") reduce 455) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_BOOLEAN_AND) reduce 455) ((T_BOOLEAN_OR) reduce 455) ((T_COALESCE) reduce 455) ((T_DOUBLE_ARROW) reduce 455) ((T_INSTANCEOF) reduce 455) ((T_IS_EQUAL) reduce 455) ((T_IS_GREATER_OR_EQUAL) reduce 455) ((T_IS_IDENTICAL) reduce 455) ((T_IS_NOT_EQUAL) reduce 455) ((T_IS_NOT_IDENTICAL) reduce 455) ((T_IS_SMALLER_OR_EQUAL) reduce 455) ((T_LOGICAL_AND) reduce 455) ((T_LOGICAL_OR) reduce 455) ((T_LOGICAL_XOR) reduce 455) ((T_POW) reduce 455) ((T_SL) reduce 455) ((T_SPACESHIP) reduce 455) ((T_SR) reduce 455) (("^") reduce 455) (("|") reduce 455)) 15896 ((("%") reduce 450) ((")") reduce 450) (("*") reduce 450) (("+") reduce 450) (("-") reduce 450) ((".") reduce 450) (("/") reduce 450) (("<") reduce 450) ((">") reduce 450) (("?") reduce 450) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_BOOLEAN_AND) reduce 450) ((T_BOOLEAN_OR) reduce 450) ((T_COALESCE) reduce 450) ((T_DOUBLE_ARROW) reduce 450) ((T_INSTANCEOF) reduce 450) ((T_IS_EQUAL) reduce 450) ((T_IS_GREATER_OR_EQUAL) reduce 450) ((T_IS_IDENTICAL) reduce 450) ((T_IS_NOT_EQUAL) reduce 450) ((T_IS_NOT_IDENTICAL) reduce 450) ((T_IS_SMALLER_OR_EQUAL) reduce 450) ((T_LOGICAL_AND) reduce 450) ((T_LOGICAL_OR) reduce 450) ((T_LOGICAL_XOR) reduce 450) ((T_POW) reduce 450) ((T_SL) reduce 450) ((T_SPACESHIP) reduce 450) ((T_SR) reduce 450) (("^") reduce 450) (("|") reduce 450)) 15906 ((("%") shift) ((")") reduce 455) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 455) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15907 ((("%") reduce 451) ((")") reduce 451) (("*") reduce 451) (("+") reduce 451) (("-") reduce 451) ((".") reduce 451) (("/") reduce 451) (("<") reduce 451) ((">") reduce 451) (("?") reduce 451) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_BOOLEAN_AND) reduce 451) ((T_BOOLEAN_OR) reduce 451) ((T_COALESCE) reduce 451) ((T_DOUBLE_ARROW) reduce 451) ((T_INSTANCEOF) reduce 451) ((T_IS_EQUAL) reduce 451) ((T_IS_GREATER_OR_EQUAL) reduce 451) ((T_IS_IDENTICAL) reduce 451) ((T_IS_NOT_EQUAL) reduce 451) ((T_IS_NOT_IDENTICAL) reduce 451) ((T_IS_SMALLER_OR_EQUAL) reduce 451) ((T_LOGICAL_AND) reduce 451) ((T_LOGICAL_OR) reduce 451) ((T_LOGICAL_XOR) reduce 451) ((T_POW) reduce 451) ((T_SL) reduce 451) ((T_SPACESHIP) reduce 451) ((T_SR) reduce 451) (("^") reduce 451) (("|") reduce 451)) 15909 ((("%") shift) ((")") reduce 442) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 442) ((T_LOGICAL_OR) reduce 442) ((T_LOGICAL_XOR) reduce 442) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15911 ((("%") reduce 503) (("(") reduce 541) ((")") reduce 503) (("*") reduce 503) (("+") reduce 503) (("-") reduce 503) ((".") reduce 503) (("/") reduce 503) (("<") reduce 503) ((">") reduce 503) (("?") reduce 503) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_BOOLEAN_AND) reduce 503) ((T_BOOLEAN_OR) reduce 503) ((T_COALESCE) reduce 503) ((T_DOUBLE_ARROW) reduce 503) ((T_INSTANCEOF) reduce 503) ((T_IS_EQUAL) reduce 503) ((T_IS_GREATER_OR_EQUAL) reduce 503) ((T_IS_IDENTICAL) reduce 503) ((T_IS_NOT_EQUAL) reduce 503) ((T_IS_NOT_IDENTICAL) reduce 503) ((T_IS_SMALLER_OR_EQUAL) reduce 503) ((T_LOGICAL_AND) reduce 503) ((T_LOGICAL_OR) reduce 503) ((T_LOGICAL_XOR) reduce 503) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 503) ((T_OBJECT_OPERATOR) reduce 503) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 503) ((T_POW) reduce 503) ((T_SL) reduce 503) ((T_SPACESHIP) reduce 503) ((T_SR) reduce 503) (("[") reduce 503) (("^") reduce 503) (("{") reduce 503) (("|") reduce 503)) 15913 ((("%") reduce 532) (("(") reduce 543) ((")") reduce 532) (("*") reduce 532) (("+") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) (("<") reduce 532) (("=") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AND_EQUAL) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_COALESCE_EQUAL) reduce 532) ((T_CONCAT_EQUAL) reduce 532) ((T_DEC) reduce 532) ((T_DIV_EQUAL) reduce 532) ((T_DOUBLE_ARROW) reduce 532) ((T_INC) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_MINUS_EQUAL) reduce 532) ((T_MOD_EQUAL) reduce 532) ((T_MUL_EQUAL) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_OR_EQUAL) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_PLUS_EQUAL) reduce 532) ((T_POW) reduce 532) ((T_POW_EQUAL) reduce 532) ((T_SL) reduce 532) ((T_SL_EQUAL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) ((T_SR_EQUAL) reduce 532) ((T_XOR_EQUAL) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 15916 ((("%") reduce 505) (("(") reduce 542) ((")") reduce 505) (("*") reduce 505) (("+") reduce 505) (("-") reduce 505) ((".") reduce 505) (("/") reduce 505) (("<") reduce 505) ((">") reduce 505) (("?") reduce 505) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_BOOLEAN_AND) reduce 505) ((T_BOOLEAN_OR) reduce 505) ((T_COALESCE) reduce 505) ((T_DOUBLE_ARROW) reduce 505) ((T_INSTANCEOF) reduce 505) ((T_IS_EQUAL) reduce 505) ((T_IS_GREATER_OR_EQUAL) reduce 505) ((T_IS_IDENTICAL) reduce 505) ((T_IS_NOT_EQUAL) reduce 505) ((T_IS_NOT_IDENTICAL) reduce 505) ((T_IS_SMALLER_OR_EQUAL) reduce 505) ((T_LOGICAL_AND) reduce 505) ((T_LOGICAL_OR) reduce 505) ((T_LOGICAL_XOR) reduce 505) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 505) ((T_OBJECT_OPERATOR) reduce 505) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 505) ((T_POW) reduce 505) ((T_SL) reduce 505) ((T_SPACESHIP) reduce 505) ((T_SR) reduce 505) (("[") reduce 505) (("^") reduce 505) (("{") reduce 505) (("|") reduce 505)) 15917 ((("%") reduce 467) (("(") reduce 467) ((")") reduce 467) (("*") reduce 467) (("+") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) (("<") reduce 467) (("=") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AND_EQUAL) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_COALESCE_EQUAL) reduce 467) ((T_CONCAT_EQUAL) reduce 467) ((T_DEC) reduce 467) ((T_DIV_EQUAL) reduce 467) ((T_DOUBLE_ARROW) reduce 467) ((T_INC) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_MINUS_EQUAL) reduce 467) ((T_MOD_EQUAL) reduce 467) ((T_MUL_EQUAL) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_OR_EQUAL) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_PLUS_EQUAL) reduce 467) ((T_POW) reduce 467) ((T_POW_EQUAL) reduce 467) ((T_SL) reduce 467) ((T_SL_EQUAL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) ((T_SR_EQUAL) reduce 467) ((T_XOR_EQUAL) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 15918 ((("%") reduce 469) (("(") reduce 469) ((")") reduce 469) (("*") reduce 469) (("+") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) (("<") reduce 469) (("=") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AND_EQUAL) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_COALESCE_EQUAL) reduce 469) ((T_CONCAT_EQUAL) reduce 469) ((T_DEC) reduce 469) ((T_DIV_EQUAL) reduce 469) ((T_DOUBLE_ARROW) reduce 469) ((T_INC) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_MINUS_EQUAL) reduce 469) ((T_MOD_EQUAL) reduce 469) ((T_MUL_EQUAL) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_OR_EQUAL) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_PLUS_EQUAL) reduce 469) ((T_POW) reduce 469) ((T_POW_EQUAL) reduce 469) ((T_SL) reduce 469) ((T_SL_EQUAL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) ((T_SR_EQUAL) reduce 469) ((T_XOR_EQUAL) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 15920 ((("%") reduce 446) ((")") reduce 446) (("*") reduce 446) (("+") reduce 446) (("-") reduce 446) ((".") reduce 446) (("/") reduce 446) (("<") reduce 446) ((">") reduce 446) (("?") reduce 446) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_BOOLEAN_AND) reduce 446) ((T_BOOLEAN_OR) reduce 446) ((T_COALESCE) reduce 446) ((T_DOUBLE_ARROW) reduce 446) ((T_INSTANCEOF) reduce 446) ((T_IS_EQUAL) reduce 446) ((T_IS_GREATER_OR_EQUAL) reduce 446) ((T_IS_IDENTICAL) reduce 446) ((T_IS_NOT_EQUAL) reduce 446) ((T_IS_NOT_IDENTICAL) reduce 446) ((T_IS_SMALLER_OR_EQUAL) reduce 446) ((T_LOGICAL_AND) reduce 446) ((T_LOGICAL_OR) reduce 446) ((T_LOGICAL_XOR) reduce 446) ((T_POW) reduce 446) ((T_SL) reduce 446) ((T_SPACESHIP) reduce 446) ((T_SR) reduce 446) (("^") reduce 446) (("|") reduce 446)) 15921 ((("%") reduce 448) ((")") reduce 448) (("*") reduce 448) (("+") reduce 448) (("-") reduce 448) ((".") reduce 448) (("/") reduce 448) (("<") reduce 448) ((">") reduce 448) (("?") reduce 448) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_BOOLEAN_AND) reduce 448) ((T_BOOLEAN_OR) reduce 448) ((T_COALESCE) reduce 448) ((T_DOUBLE_ARROW) reduce 448) ((T_INSTANCEOF) reduce 448) ((T_IS_EQUAL) reduce 448) ((T_IS_GREATER_OR_EQUAL) reduce 448) ((T_IS_IDENTICAL) reduce 448) ((T_IS_NOT_EQUAL) reduce 448) ((T_IS_NOT_IDENTICAL) reduce 448) ((T_IS_SMALLER_OR_EQUAL) reduce 448) ((T_LOGICAL_AND) reduce 448) ((T_LOGICAL_OR) reduce 448) ((T_LOGICAL_XOR) reduce 448) ((T_POW) reduce 448) ((T_SL) reduce 448) ((T_SPACESHIP) reduce 448) ((T_SR) reduce 448) (("^") reduce 448) (("|") reduce 448)) 15927 ((("%") reduce 521) (("(") reduce 521) ((")") reduce 521) (("*") reduce 521) (("+") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) (("<") reduce 521) (("=") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AND_EQUAL) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_COALESCE_EQUAL) reduce 521) ((T_CONCAT_EQUAL) reduce 521) ((T_DEC) reduce 521) ((T_DIV_EQUAL) reduce 521) ((T_DOUBLE_ARROW) reduce 521) ((T_INC) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_MINUS_EQUAL) reduce 521) ((T_MOD_EQUAL) reduce 521) ((T_MUL_EQUAL) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_OR_EQUAL) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_PLUS_EQUAL) reduce 521) ((T_POW) reduce 521) ((T_POW_EQUAL) reduce 521) ((T_SL) reduce 521) ((T_SL_EQUAL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) ((T_SR_EQUAL) reduce 521) ((T_XOR_EQUAL) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 15929 ((("%") reduce 520) (("(") reduce 520) ((")") reduce 520) (("*") reduce 520) (("+") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) (("<") reduce 520) (("=") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AND_EQUAL) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_COALESCE_EQUAL) reduce 520) ((T_CONCAT_EQUAL) reduce 520) ((T_DEC) reduce 520) ((T_DIV_EQUAL) reduce 520) ((T_DOUBLE_ARROW) reduce 520) ((T_INC) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_MINUS_EQUAL) reduce 520) ((T_MOD_EQUAL) reduce 520) ((T_MUL_EQUAL) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_OR_EQUAL) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_PLUS_EQUAL) reduce 520) ((T_POW) reduce 520) ((T_POW_EQUAL) reduce 520) ((T_SL) reduce 520) ((T_SL_EQUAL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) ((T_SR_EQUAL) reduce 520) ((T_XOR_EQUAL) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 15930 ((("%") reduce 544) (("(") reduce 544) ((")") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) (("=") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AND_EQUAL) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_COALESCE_EQUAL) reduce 544) ((T_CONCAT_EQUAL) reduce 544) ((T_DEC) reduce 544) ((T_DIV_EQUAL) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INC) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_MINUS_EQUAL) reduce 544) ((T_MOD_EQUAL) reduce 544) ((T_MUL_EQUAL) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_OR_EQUAL) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_PLUS_EQUAL) reduce 544) ((T_POW) reduce 544) ((T_POW_EQUAL) reduce 544) ((T_SL) reduce 544) ((T_SL_EQUAL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) ((T_SR_EQUAL) reduce 544) ((T_XOR_EQUAL) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 15931 ((("%") reduce 527) (("(") shift) ((")") reduce 527) (("*") reduce 527) (("+") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) (("<") reduce 527) (("=") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AND_EQUAL) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_COALESCE_EQUAL) reduce 527) ((T_CONCAT_EQUAL) reduce 527) ((T_DEC) reduce 527) ((T_DIV_EQUAL) reduce 527) ((T_DOUBLE_ARROW) reduce 527) ((T_INC) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_MINUS_EQUAL) reduce 527) ((T_MOD_EQUAL) reduce 527) ((T_MUL_EQUAL) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_OR_EQUAL) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_PLUS_EQUAL) reduce 527) ((T_POW) reduce 527) ((T_POW_EQUAL) reduce 527) ((T_SL) reduce 527) ((T_SL_EQUAL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) ((T_SR_EQUAL) reduce 527) ((T_XOR_EQUAL) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 15932 ((("%") reduce 546) (("(") reduce 546) ((")") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) (("=") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AND_EQUAL) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_COALESCE_EQUAL) reduce 546) ((T_CONCAT_EQUAL) reduce 546) ((T_DEC) reduce 546) ((T_DIV_EQUAL) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INC) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_MINUS_EQUAL) reduce 546) ((T_MOD_EQUAL) reduce 546) ((T_MUL_EQUAL) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_OR_EQUAL) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_PLUS_EQUAL) reduce 546) ((T_POW) reduce 546) ((T_POW_EQUAL) reduce 546) ((T_SL) reduce 546) ((T_SL_EQUAL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) ((T_SR_EQUAL) reduce 546) ((T_XOR_EQUAL) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 15935 ((("%") reduce 545) (("(") reduce 545) ((")") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) (("=") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AND_EQUAL) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_COALESCE_EQUAL) reduce 545) ((T_CONCAT_EQUAL) reduce 545) ((T_DEC) reduce 545) ((T_DIV_EQUAL) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INC) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_MINUS_EQUAL) reduce 545) ((T_MOD_EQUAL) reduce 545) ((T_MUL_EQUAL) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_OR_EQUAL) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_PLUS_EQUAL) reduce 545) ((T_POW) reduce 545) ((T_POW_EQUAL) reduce 545) ((T_SL) reduce 545) ((T_SL_EQUAL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) ((T_SR_EQUAL) reduce 545) ((T_XOR_EQUAL) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 15936 ((("%") reduce 522) (("(") reduce 522) ((")") reduce 522) (("*") reduce 522) (("+") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) (("<") reduce 522) (("=") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AND_EQUAL) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_COALESCE_EQUAL) reduce 522) ((T_CONCAT_EQUAL) reduce 522) ((T_DEC) reduce 522) ((T_DIV_EQUAL) reduce 522) ((T_DOUBLE_ARROW) reduce 522) ((T_INC) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_MINUS_EQUAL) reduce 522) ((T_MOD_EQUAL) reduce 522) ((T_MUL_EQUAL) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_OR_EQUAL) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_PLUS_EQUAL) reduce 522) ((T_POW) reduce 522) ((T_POW_EQUAL) reduce 522) ((T_SL) reduce 522) ((T_SL_EQUAL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) ((T_SR_EQUAL) reduce 522) ((T_XOR_EQUAL) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 15937 ((("%") reduce 528) (("(") shift) ((")") reduce 528) (("*") reduce 528) (("+") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) (("<") reduce 528) (("=") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AND_EQUAL) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_COALESCE_EQUAL) reduce 528) ((T_CONCAT_EQUAL) reduce 528) ((T_DEC) reduce 528) ((T_DIV_EQUAL) reduce 528) ((T_DOUBLE_ARROW) reduce 528) ((T_INC) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_MINUS_EQUAL) reduce 528) ((T_MOD_EQUAL) reduce 528) ((T_MUL_EQUAL) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_OR_EQUAL) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_PLUS_EQUAL) reduce 528) ((T_POW) reduce 528) ((T_POW_EQUAL) reduce 528) ((T_SL) reduce 528) ((T_SL_EQUAL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) ((T_SR_EQUAL) reduce 528) ((T_XOR_EQUAL) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 15938 ((("%") reduce 523) (("(") reduce 523) ((")") reduce 523) (("*") reduce 523) (("+") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) (("<") reduce 523) (("=") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AND_EQUAL) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_COALESCE_EQUAL) reduce 523) ((T_CONCAT_EQUAL) reduce 523) ((T_DEC) reduce 523) ((T_DIV_EQUAL) reduce 523) ((T_DOUBLE_ARROW) reduce 523) ((T_INC) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_MINUS_EQUAL) reduce 523) ((T_MOD_EQUAL) reduce 523) ((T_MUL_EQUAL) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_OR_EQUAL) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_PLUS_EQUAL) reduce 523) ((T_POW) reduce 523) ((T_POW_EQUAL) reduce 523) ((T_SL) reduce 523) ((T_SL_EQUAL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) ((T_SR_EQUAL) reduce 523) ((T_XOR_EQUAL) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 15940 ((("%") reduce 438) ((")") reduce 438) (("*") reduce 438) (("+") reduce 438) (("-") reduce 438) ((".") reduce 438) (("/") reduce 438) (("<") reduce 438) ((">") reduce 438) (("?") reduce 438) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_BOOLEAN_AND) reduce 438) ((T_BOOLEAN_OR) reduce 438) ((T_COALESCE) reduce 438) ((T_DOUBLE_ARROW) reduce 438) ((T_INSTANCEOF) reduce 438) ((T_IS_EQUAL) reduce 438) ((T_IS_GREATER_OR_EQUAL) reduce 438) ((T_IS_IDENTICAL) reduce 438) ((T_IS_NOT_EQUAL) reduce 438) ((T_IS_NOT_IDENTICAL) reduce 438) ((T_IS_SMALLER_OR_EQUAL) reduce 438) ((T_LOGICAL_AND) reduce 438) ((T_LOGICAL_OR) reduce 438) ((T_LOGICAL_XOR) reduce 438) ((T_POW) reduce 438) ((T_SL) reduce 438) ((T_SPACESHIP) reduce 438) ((T_SR) reduce 438) (("^") reduce 438) (("|") reduce 438)) 15942 ((("%") reduce 483) (("(") reduce 483) ((")") reduce 483) (("*") reduce 483) (("+") reduce 483) (("-") reduce 483) ((".") reduce 483) (("/") reduce 483) (("<") reduce 483) (("=") shift) ((">") reduce 483) (("?") reduce 483) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_BOOLEAN_AND) reduce 483) ((T_BOOLEAN_OR) reduce 483) ((T_COALESCE) reduce 483) ((T_DOUBLE_ARROW) reduce 483) ((T_INSTANCEOF) reduce 483) ((T_IS_EQUAL) reduce 483) ((T_IS_GREATER_OR_EQUAL) reduce 483) ((T_IS_IDENTICAL) reduce 483) ((T_IS_NOT_EQUAL) reduce 483) ((T_IS_NOT_IDENTICAL) reduce 483) ((T_IS_SMALLER_OR_EQUAL) reduce 483) ((T_LOGICAL_AND) reduce 483) ((T_LOGICAL_OR) reduce 483) ((T_LOGICAL_XOR) reduce 483) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 483) ((T_OBJECT_OPERATOR) reduce 483) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 483) ((T_POW) reduce 483) ((T_SL) reduce 483) ((T_SPACESHIP) reduce 483) ((T_SR) reduce 483) (("[") reduce 483) (("^") reduce 483) (("{") reduce 483) (("|") reduce 483)) 15944 ((("%") shift) ((")") reduce 369) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 369) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 369) ((T_LOGICAL_OR) reduce 369) ((T_LOGICAL_XOR) reduce 369) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15945 ((("%") shift) ((")") reduce 443) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 443) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 443) ((T_LOGICAL_OR) reduce 443) ((T_LOGICAL_XOR) reduce 443) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15948 ((("%") shift) ((")") reduce 442) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 442) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 442) ((T_LOGICAL_OR) reduce 442) ((T_LOGICAL_XOR) reduce 442) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15949 ((("%") reduce 434) ((")") reduce 434) (("*") reduce 434) (("+") reduce 434) (("-") reduce 434) ((".") reduce 434) (("/") reduce 434) (("<") reduce 434) ((">") reduce 434) (("?") reduce 434) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_BOOLEAN_AND) reduce 434) ((T_BOOLEAN_OR) reduce 434) ((T_COALESCE) reduce 434) ((T_DOUBLE_ARROW) reduce 434) ((T_INSTANCEOF) reduce 434) ((T_IS_EQUAL) reduce 434) ((T_IS_GREATER_OR_EQUAL) reduce 434) ((T_IS_IDENTICAL) reduce 434) ((T_IS_NOT_EQUAL) reduce 434) ((T_IS_NOT_IDENTICAL) reduce 434) ((T_IS_SMALLER_OR_EQUAL) reduce 434) ((T_LOGICAL_AND) reduce 434) ((T_LOGICAL_OR) reduce 434) ((T_LOGICAL_XOR) reduce 434) ((T_POW) shift) ((T_SL) reduce 434) ((T_SPACESHIP) reduce 434) ((T_SR) reduce 434) (("^") reduce 434) (("|") reduce 434)) 15950 ((("%") shift) ((")") reduce 444) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 444) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15951 ((("%") reduce 430) ((")") reduce 430) (("*") reduce 430) (("+") reduce 430) (("-") reduce 430) ((".") reduce 430) (("/") reduce 430) (("<") reduce 430) ((">") reduce 430) (("?") reduce 430) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_BOOLEAN_AND) reduce 430) ((T_BOOLEAN_OR) reduce 430) ((T_COALESCE) reduce 430) ((T_DOUBLE_ARROW) reduce 430) ((T_INSTANCEOF) reduce 430) ((T_IS_EQUAL) reduce 430) ((T_IS_GREATER_OR_EQUAL) reduce 430) ((T_IS_IDENTICAL) reduce 430) ((T_IS_NOT_EQUAL) reduce 430) ((T_IS_NOT_IDENTICAL) reduce 430) ((T_IS_SMALLER_OR_EQUAL) reduce 430) ((T_LOGICAL_AND) reduce 430) ((T_LOGICAL_OR) reduce 430) ((T_LOGICAL_XOR) reduce 430) ((T_POW) shift) ((T_SL) reduce 430) ((T_SPACESHIP) reduce 430) ((T_SR) reduce 430) (("^") reduce 430) (("|") reduce 430)) 15952 ((("%") reduce 447) ((")") reduce 447) (("*") reduce 447) (("+") reduce 447) (("-") reduce 447) ((".") reduce 447) (("/") reduce 447) (("<") reduce 447) ((">") reduce 447) (("?") reduce 447) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_BOOLEAN_AND) reduce 447) ((T_BOOLEAN_OR) reduce 447) ((T_COALESCE) reduce 447) ((T_DOUBLE_ARROW) reduce 447) ((T_INSTANCEOF) reduce 447) ((T_IS_EQUAL) reduce 447) ((T_IS_GREATER_OR_EQUAL) reduce 447) ((T_IS_IDENTICAL) reduce 447) ((T_IS_NOT_EQUAL) reduce 447) ((T_IS_NOT_IDENTICAL) reduce 447) ((T_IS_SMALLER_OR_EQUAL) reduce 447) ((T_LOGICAL_AND) reduce 447) ((T_LOGICAL_OR) reduce 447) ((T_LOGICAL_XOR) reduce 447) ((T_POW) reduce 447) ((T_SL) reduce 447) ((T_SPACESHIP) reduce 447) ((T_SR) reduce 447) (("^") reduce 447) (("|") reduce 447)) 15954 ((("%") reduce 489) ((")") reduce 489) (("*") reduce 489) (("+") reduce 489) (("-") reduce 489) ((".") reduce 489) (("/") reduce 489) (("<") reduce 489) ((">") reduce 489) (("?") reduce 489) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_BOOLEAN_AND) reduce 489) ((T_BOOLEAN_OR) reduce 489) ((T_COALESCE) reduce 489) ((T_DOUBLE_ARROW) reduce 489) ((T_INSTANCEOF) reduce 489) ((T_IS_EQUAL) reduce 489) ((T_IS_GREATER_OR_EQUAL) reduce 489) ((T_IS_IDENTICAL) reduce 489) ((T_IS_NOT_EQUAL) reduce 489) ((T_IS_NOT_IDENTICAL) reduce 489) ((T_IS_SMALLER_OR_EQUAL) reduce 489) ((T_LOGICAL_AND) reduce 489) ((T_LOGICAL_OR) reduce 489) ((T_LOGICAL_XOR) reduce 489) ((T_POW) reduce 489) ((T_SL) reduce 489) ((T_SPACESHIP) reduce 489) ((T_SR) reduce 489) (("^") reduce 489) (("|") reduce 489)) 15956 ((("%") reduce 490) ((")") reduce 490) (("*") reduce 490) (("+") reduce 490) (("-") reduce 490) ((".") reduce 490) (("/") reduce 490) (("<") reduce 490) ((">") reduce 490) (("?") reduce 490) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_BOOLEAN_AND) reduce 490) ((T_BOOLEAN_OR) reduce 490) ((T_COALESCE) reduce 490) ((T_DOUBLE_ARROW) reduce 490) ((T_INSTANCEOF) reduce 490) ((T_IS_EQUAL) reduce 490) ((T_IS_GREATER_OR_EQUAL) reduce 490) ((T_IS_IDENTICAL) reduce 490) ((T_IS_NOT_EQUAL) reduce 490) ((T_IS_NOT_IDENTICAL) reduce 490) ((T_IS_SMALLER_OR_EQUAL) reduce 490) ((T_LOGICAL_AND) reduce 490) ((T_LOGICAL_OR) reduce 490) ((T_LOGICAL_XOR) reduce 490) ((T_POW) reduce 490) ((T_SL) reduce 490) ((T_SPACESHIP) reduce 490) ((T_SR) reduce 490) (("^") reduce 490) (("|") reduce 490)) 15957 ((("%") reduce 488) ((")") reduce 488) (("*") reduce 488) (("+") reduce 488) (("-") reduce 488) ((".") reduce 488) (("/") reduce 488) (("<") reduce 488) ((">") reduce 488) (("?") reduce 488) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_BOOLEAN_AND) reduce 488) ((T_BOOLEAN_OR) reduce 488) ((T_COALESCE) reduce 488) ((T_DOUBLE_ARROW) reduce 488) ((T_INSTANCEOF) reduce 488) ((T_IS_EQUAL) reduce 488) ((T_IS_GREATER_OR_EQUAL) reduce 488) ((T_IS_IDENTICAL) reduce 488) ((T_IS_NOT_EQUAL) reduce 488) ((T_IS_NOT_IDENTICAL) reduce 488) ((T_IS_SMALLER_OR_EQUAL) reduce 488) ((T_LOGICAL_AND) reduce 488) ((T_LOGICAL_OR) reduce 488) ((T_LOGICAL_XOR) reduce 488) ((T_POW) reduce 488) ((T_SL) reduce 488) ((T_SPACESHIP) reduce 488) ((T_SR) reduce 488) (("^") reduce 488) (("|") reduce 488)) 15958 ((("%") shift) ((")") reduce 581) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 581) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15959 ((("%") shift) ((")") reduce 580) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 580) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15960 ((("%") reduce 466) (("(") reduce 466) ((")") reduce 466) (("*") reduce 466) (("+") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) (("<") reduce 466) (("=") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AND_EQUAL) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_COALESCE_EQUAL) reduce 466) ((T_CONCAT_EQUAL) reduce 466) ((T_DEC) reduce 466) ((T_DIV_EQUAL) reduce 466) ((T_DOUBLE_ARROW) reduce 466) ((T_INC) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_MINUS_EQUAL) reduce 466) ((T_MOD_EQUAL) reduce 466) ((T_MUL_EQUAL) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_OR_EQUAL) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_PLUS_EQUAL) reduce 466) ((T_POW) reduce 466) ((T_POW_EQUAL) reduce 466) ((T_SL) reduce 466) ((T_SL_EQUAL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) ((T_SR_EQUAL) reduce 466) ((T_XOR_EQUAL) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 15961 ((("%") shift) ((")") reduce 439) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 439) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 439) ((T_LOGICAL_OR) reduce 439) ((T_LOGICAL_XOR) reduce 439) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 15962 ((("%") reduce 432) ((")") reduce 432) (("*") reduce 432) (("+") reduce 432) (("-") reduce 432) ((".") reduce 432) (("/") reduce 432) (("<") reduce 432) ((">") reduce 432) (("?") reduce 432) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_BOOLEAN_AND) reduce 432) ((T_BOOLEAN_OR) reduce 432) ((T_COALESCE) reduce 432) ((T_DOUBLE_ARROW) reduce 432) ((T_INSTANCEOF) reduce 432) ((T_IS_EQUAL) reduce 432) ((T_IS_GREATER_OR_EQUAL) reduce 432) ((T_IS_IDENTICAL) reduce 432) ((T_IS_NOT_EQUAL) reduce 432) ((T_IS_NOT_IDENTICAL) reduce 432) ((T_IS_SMALLER_OR_EQUAL) reduce 432) ((T_LOGICAL_AND) reduce 432) ((T_LOGICAL_OR) reduce 432) ((T_LOGICAL_XOR) reduce 432) ((T_POW) shift) ((T_SL) reduce 432) ((T_SPACESHIP) reduce 432) ((T_SR) reduce 432) (("^") reduce 432) (("|") reduce 432)) 15964 ((("%") reduce 93) (("(") reduce 93) ((")") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93)) 15965 ((("%") reduce 92) (("(") reduce 92) ((")") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92)) 15966 ((("%") reduce 94) (("(") reduce 94) ((")") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94)) 15967 ((("%") reduce 470) (("(") reduce 470) ((")") reduce 470) (("*") reduce 470) (("+") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_DOUBLE_ARROW) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470)) 15968 ((("%") reduce 91) (("(") reduce 91) ((")") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91)) 15969 ((("%") reduce 365) ((")") reduce 365) (("*") reduce 365) (("+") reduce 365) (("-") reduce 365) ((".") reduce 365) (("/") reduce 365) (("<") reduce 365) ((">") reduce 365) (("?") reduce 365) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_BOOLEAN_AND) reduce 365) ((T_BOOLEAN_OR) reduce 365) ((T_COALESCE) reduce 365) ((T_DOUBLE_ARROW) reduce 365) ((T_INSTANCEOF) reduce 365) ((T_IS_EQUAL) reduce 365) ((T_IS_GREATER_OR_EQUAL) reduce 365) ((T_IS_IDENTICAL) reduce 365) ((T_IS_NOT_EQUAL) reduce 365) ((T_IS_NOT_IDENTICAL) reduce 365) ((T_IS_SMALLER_OR_EQUAL) reduce 365) ((T_LOGICAL_AND) reduce 365) ((T_LOGICAL_OR) reduce 365) ((T_LOGICAL_XOR) reduce 365) ((T_POW) reduce 365) ((T_SL) reduce 365) ((T_SPACESHIP) reduce 365) ((T_SR) reduce 365) (("^") reduce 365) (("|") reduce 365)) 15972 ((("%") reduce 472) (("(") reduce 472) ((")") reduce 472) (("*") reduce 472) (("+") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_DOUBLE_ARROW) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472)) 15973 ((("%") reduce 480) (("(") shift) ((")") reduce 480) (("*") reduce 480) (("+") reduce 480) (("-") reduce 480) ((".") reduce 480) (("/") reduce 480) (("<") reduce 480) ((">") reduce 480) (("?") reduce 480) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_BOOLEAN_AND) reduce 480) ((T_BOOLEAN_OR) reduce 480) ((T_COALESCE) reduce 480) ((T_DOUBLE_ARROW) reduce 480) ((T_INSTANCEOF) reduce 480) ((T_IS_EQUAL) reduce 480) ((T_IS_GREATER_OR_EQUAL) reduce 480) ((T_IS_IDENTICAL) reduce 480) ((T_IS_NOT_EQUAL) reduce 480) ((T_IS_NOT_IDENTICAL) reduce 480) ((T_IS_SMALLER_OR_EQUAL) reduce 480) ((T_LOGICAL_AND) reduce 480) ((T_LOGICAL_OR) reduce 480) ((T_LOGICAL_XOR) reduce 480) ((T_POW) reduce 480) ((T_SL) reduce 480) ((T_SPACESHIP) reduce 480) ((T_SR) reduce 480) (("^") reduce 480) (("|") reduce 480)) 15974 ((("%") reduce 471) (("(") reduce 471) ((")") reduce 471) (("*") reduce 471) (("+") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_DOUBLE_ARROW) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471)) 15975 ((("%") reduce 473) (("(") reduce 473) ((")") reduce 473) (("*") reduce 473) (("+") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_DOUBLE_ARROW) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 15976 ((("%") reduce 534) (("(") reduce 534) ((")") reduce 534) (("*") reduce 534) (("+") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_DOUBLE_ARROW) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 15983 ((("%") reduce 536) (("(") reduce 536) ((")") reduce 536) (("*") reduce 536) (("+") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_DOUBLE_ARROW) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 15985 ((("%") reduce 535) (("(") reduce 535) ((")") reduce 535) (("*") reduce 535) (("+") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_DOUBLE_ARROW) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 15986 ((("%") reduce 540) (("(") reduce 540) ((")") reduce 540) (("*") reduce 540) (("+") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_DOUBLE_ARROW) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 15987 ((("%") reduce 537) (("(") reduce 537) ((")") reduce 537) (("*") reduce 537) (("+") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_DOUBLE_ARROW) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 15988 ((("%") reduce 538) (("(") reduce 538) ((")") reduce 538) (("*") reduce 538) (("+") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_DOUBLE_ARROW) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 15990 ((("%") reduce 481) ((")") reduce 481) (("*") reduce 481) (("+") reduce 481) (("-") reduce 481) ((".") reduce 481) (("/") reduce 481) (("<") reduce 481) ((">") reduce 481) (("?") reduce 481) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_BOOLEAN_AND) reduce 481) ((T_BOOLEAN_OR) reduce 481) ((T_COALESCE) reduce 481) ((T_DOUBLE_ARROW) reduce 481) ((T_INSTANCEOF) reduce 481) ((T_IS_EQUAL) reduce 481) ((T_IS_GREATER_OR_EQUAL) reduce 481) ((T_IS_IDENTICAL) reduce 481) ((T_IS_NOT_EQUAL) reduce 481) ((T_IS_NOT_IDENTICAL) reduce 481) ((T_IS_SMALLER_OR_EQUAL) reduce 481) ((T_LOGICAL_AND) reduce 481) ((T_LOGICAL_OR) reduce 481) ((T_LOGICAL_XOR) reduce 481) ((T_POW) reduce 481) ((T_SL) reduce 481) ((T_SPACESHIP) reduce 481) ((T_SR) reduce 481) (("^") reduce 481) (("|") reduce 481)) 15991 ((("%") reduce 364) ((")") reduce 364) (("*") reduce 364) (("+") reduce 364) (("-") reduce 364) ((".") reduce 364) (("/") reduce 364) (("<") reduce 364) ((">") reduce 364) (("?") reduce 364) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_BOOLEAN_AND) reduce 364) ((T_BOOLEAN_OR) reduce 364) ((T_COALESCE) reduce 364) ((T_DOUBLE_ARROW) reduce 364) ((T_INSTANCEOF) reduce 364) ((T_IS_EQUAL) reduce 364) ((T_IS_GREATER_OR_EQUAL) reduce 364) ((T_IS_IDENTICAL) reduce 364) ((T_IS_NOT_EQUAL) reduce 364) ((T_IS_NOT_IDENTICAL) reduce 364) ((T_IS_SMALLER_OR_EQUAL) reduce 364) ((T_LOGICAL_AND) reduce 364) ((T_LOGICAL_OR) reduce 364) ((T_LOGICAL_XOR) reduce 364) ((T_POW) reduce 364) ((T_SL) reduce 364) ((T_SPACESHIP) reduce 364) ((T_SR) reduce 364) (("^") reduce 364) (("|") reduce 364)) 15992 ((("%") reduce 288) ((")") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("^") reduce 288) (("|") reduce 288)) 15996 ((("%") reduce 289) ((")") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("^") reduce 289) (("|") reduce 289)) 15997 ((("%") reduce 290) ((")") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("^") reduce 290) (("|") reduce 290)) 15999 ((("%") reduce 539) (("(") reduce 539) ((")") reduce 539) (("*") reduce 539) (("+") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_DOUBLE_ARROW) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 16000 ((("%") reduce 366) ((")") reduce 366) (("*") reduce 366) (("+") reduce 366) (("-") reduce 366) ((".") reduce 366) (("/") reduce 366) (("<") reduce 366) ((">") reduce 366) (("?") reduce 366) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_BOOLEAN_AND) reduce 366) ((T_BOOLEAN_OR) reduce 366) ((T_COALESCE) reduce 366) ((T_DOUBLE_ARROW) reduce 366) ((T_INSTANCEOF) reduce 366) ((T_IS_EQUAL) reduce 366) ((T_IS_GREATER_OR_EQUAL) reduce 366) ((T_IS_IDENTICAL) reduce 366) ((T_IS_NOT_EQUAL) reduce 366) ((T_IS_NOT_IDENTICAL) reduce 366) ((T_IS_SMALLER_OR_EQUAL) reduce 366) ((T_LOGICAL_AND) reduce 366) ((T_LOGICAL_OR) reduce 366) ((T_LOGICAL_XOR) reduce 366) ((T_POW) reduce 366) ((T_SL) reduce 366) ((T_SPACESHIP) reduce 366) ((T_SR) reduce 366) (("^") reduce 366) (("|") reduce 366)) 16008 ((("%") reduce 363) ((")") reduce 363) (("*") reduce 363) (("+") reduce 363) (("-") reduce 363) ((".") reduce 363) (("/") reduce 363) (("<") reduce 363) ((">") reduce 363) (("?") reduce 363) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_BOOLEAN_AND) reduce 363) ((T_BOOLEAN_OR) reduce 363) ((T_COALESCE) reduce 363) ((T_DOUBLE_ARROW) reduce 363) ((T_INSTANCEOF) reduce 363) ((T_IS_EQUAL) reduce 363) ((T_IS_GREATER_OR_EQUAL) reduce 363) ((T_IS_IDENTICAL) reduce 363) ((T_IS_NOT_EQUAL) reduce 363) ((T_IS_NOT_IDENTICAL) reduce 363) ((T_IS_SMALLER_OR_EQUAL) reduce 363) ((T_LOGICAL_AND) reduce 363) ((T_LOGICAL_OR) reduce 363) ((T_LOGICAL_XOR) reduce 363) ((T_POW) reduce 363) ((T_SL) reduce 363) ((T_SPACESHIP) reduce 363) ((T_SR) reduce 363) (("^") reduce 363) (("|") reduce 363)) 16010 ((("%") reduce 474) (("(") reduce 474) ((")") reduce 474) (("*") reduce 474) (("+") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_DOUBLE_ARROW) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474)) 16016 ((("%") reduce 230) ((")") reduce 230) (("*") reduce 230) (("+") reduce 230) (("-") reduce 230) ((".") reduce 230) (("/") reduce 230) (("<") reduce 230) ((">") reduce 230) (("?") reduce 230) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_BOOLEAN_AND) reduce 230) ((T_BOOLEAN_OR) reduce 230) ((T_COALESCE) reduce 230) ((T_DOUBLE_ARROW) reduce 230) ((T_INSTANCEOF) reduce 230) ((T_IS_EQUAL) reduce 230) ((T_IS_GREATER_OR_EQUAL) reduce 230) ((T_IS_IDENTICAL) reduce 230) ((T_IS_NOT_EQUAL) reduce 230) ((T_IS_NOT_IDENTICAL) reduce 230) ((T_IS_SMALLER_OR_EQUAL) reduce 230) ((T_LOGICAL_AND) reduce 230) ((T_LOGICAL_OR) reduce 230) ((T_LOGICAL_XOR) reduce 230) ((T_POW) reduce 230) ((T_SL) reduce 230) ((T_SPACESHIP) reduce 230) ((T_SR) reduce 230) (("^") reduce 230) (("|") reduce 230)) 16021 ((("%") shift) ((")") reduce 368) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 368) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 368) ((T_LOGICAL_OR) reduce 368) ((T_LOGICAL_XOR) reduce 368) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 16025 ((("%") reduce 575) ((")") reduce 575) (("*") reduce 575) (("+") reduce 575) (("-") reduce 575) ((".") reduce 575) (("/") reduce 575) (("<") reduce 575) ((">") reduce 575) (("?") reduce 575) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_BOOLEAN_AND) reduce 575) ((T_BOOLEAN_OR) reduce 575) ((T_COALESCE) reduce 575) ((T_DOUBLE_ARROW) reduce 575) ((T_INSTANCEOF) reduce 575) ((T_IS_EQUAL) reduce 575) ((T_IS_GREATER_OR_EQUAL) reduce 575) ((T_IS_IDENTICAL) reduce 575) ((T_IS_NOT_EQUAL) reduce 575) ((T_IS_NOT_IDENTICAL) reduce 575) ((T_IS_SMALLER_OR_EQUAL) reduce 575) ((T_LOGICAL_AND) reduce 575) ((T_LOGICAL_OR) reduce 575) ((T_LOGICAL_XOR) reduce 575) ((T_POW) reduce 575) ((T_SL) reduce 575) ((T_SPACESHIP) reduce 575) ((T_SR) reduce 575) (("^") reduce 575) (("|") reduce 575)) 16026 ((("%") reduce 428) ((")") reduce 428) (("*") reduce 428) (("+") reduce 428) (("-") reduce 428) ((".") reduce 428) (("/") reduce 428) (("<") reduce 428) ((">") reduce 428) (("?") reduce 428) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_BOOLEAN_AND) reduce 428) ((T_BOOLEAN_OR) reduce 428) ((T_COALESCE) reduce 428) ((T_DOUBLE_ARROW) reduce 428) ((T_INSTANCEOF) reduce 428) ((T_IS_EQUAL) reduce 428) ((T_IS_GREATER_OR_EQUAL) reduce 428) ((T_IS_IDENTICAL) reduce 428) ((T_IS_NOT_EQUAL) reduce 428) ((T_IS_NOT_IDENTICAL) reduce 428) ((T_IS_SMALLER_OR_EQUAL) reduce 428) ((T_LOGICAL_AND) reduce 428) ((T_LOGICAL_OR) reduce 428) ((T_LOGICAL_XOR) reduce 428) ((T_POW) shift) ((T_SL) reduce 428) ((T_SPACESHIP) reduce 428) ((T_SR) reduce 428) (("^") reduce 428) (("|") reduce 428)) 16027 ((("%") shift) ((")") reduce 578) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 578) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 16028 ((("%") shift) ((")") reduce 577) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 577) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 16029 ((("%") reduce 387) ((")") reduce 387) (("*") reduce 387) (("+") reduce 387) (("-") reduce 387) ((".") reduce 387) (("/") reduce 387) (("<") reduce 387) ((">") reduce 387) (("?") reduce 387) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_BOOLEAN_AND) reduce 387) ((T_BOOLEAN_OR) reduce 387) ((T_COALESCE) reduce 387) ((T_DOUBLE_ARROW) reduce 387) ((T_INSTANCEOF) reduce 387) ((T_IS_EQUAL) reduce 387) ((T_IS_GREATER_OR_EQUAL) reduce 387) ((T_IS_IDENTICAL) reduce 387) ((T_IS_NOT_EQUAL) reduce 387) ((T_IS_NOT_IDENTICAL) reduce 387) ((T_IS_SMALLER_OR_EQUAL) reduce 387) ((T_LOGICAL_AND) reduce 387) ((T_LOGICAL_OR) reduce 387) ((T_LOGICAL_XOR) reduce 387) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 387) ((T_SL) reduce 387) ((T_SPACESHIP) reduce 387) ((T_SR) reduce 387) (("[") reduce 510) (("^") reduce 387) (("{") reduce 510) (("|") reduce 387)) 16031 ((("%") reduce 435) ((")") reduce 435) (("*") reduce 435) (("+") reduce 435) (("-") reduce 435) ((".") reduce 435) (("/") reduce 435) (("<") reduce 435) ((">") reduce 435) (("?") reduce 435) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_BOOLEAN_AND) reduce 435) ((T_BOOLEAN_OR) reduce 435) ((T_COALESCE) reduce 435) ((T_DOUBLE_ARROW) reduce 435) ((T_INSTANCEOF) reduce 435) ((T_IS_EQUAL) reduce 435) ((T_IS_GREATER_OR_EQUAL) reduce 435) ((T_IS_IDENTICAL) reduce 435) ((T_IS_NOT_EQUAL) reduce 435) ((T_IS_NOT_IDENTICAL) reduce 435) ((T_IS_SMALLER_OR_EQUAL) reduce 435) ((T_LOGICAL_AND) reduce 435) ((T_LOGICAL_OR) reduce 435) ((T_LOGICAL_XOR) reduce 435) ((T_POW) reduce 435) ((T_SL) reduce 435) ((T_SPACESHIP) reduce 435) ((T_SR) reduce 435) (("^") reduce 435) (("|") reduce 435)) 16033 ((("%") reduce 476) ((")") reduce 476) (("*") reduce 476) (("+") reduce 476) (("-") reduce 476) ((".") reduce 476) (("/") reduce 476) (("<") reduce 476) ((">") reduce 476) (("?") reduce 476) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_BOOLEAN_AND) reduce 476) ((T_BOOLEAN_OR) reduce 476) ((T_COALESCE) reduce 476) ((T_DOUBLE_ARROW) reduce 476) ((T_INSTANCEOF) reduce 476) ((T_IS_EQUAL) reduce 476) ((T_IS_GREATER_OR_EQUAL) reduce 476) ((T_IS_IDENTICAL) reduce 476) ((T_IS_NOT_EQUAL) reduce 476) ((T_IS_NOT_IDENTICAL) reduce 476) ((T_IS_SMALLER_OR_EQUAL) reduce 476) ((T_LOGICAL_AND) reduce 476) ((T_LOGICAL_OR) reduce 476) ((T_LOGICAL_XOR) reduce 476) ((T_POW) reduce 476) ((T_SL) reduce 476) ((T_SPACESHIP) reduce 476) ((T_SR) reduce 476) (("^") reduce 476) (("|") reduce 476)) 16036 ((("%") reduce 579) ((")") reduce 579) (("*") reduce 579) (("+") reduce 579) (("-") reduce 579) ((".") reduce 579) (("/") reduce 579) (("<") reduce 579) ((">") reduce 579) (("?") reduce 579) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_BOOLEAN_AND) reduce 579) ((T_BOOLEAN_OR) reduce 579) ((T_COALESCE) reduce 579) ((T_DOUBLE_ARROW) reduce 579) ((T_INSTANCEOF) reduce 579) ((T_IS_EQUAL) reduce 579) ((T_IS_GREATER_OR_EQUAL) reduce 579) ((T_IS_IDENTICAL) reduce 579) ((T_IS_NOT_EQUAL) reduce 579) ((T_IS_NOT_IDENTICAL) reduce 579) ((T_IS_SMALLER_OR_EQUAL) reduce 579) ((T_LOGICAL_AND) reduce 579) ((T_LOGICAL_OR) reduce 579) ((T_LOGICAL_XOR) reduce 579) ((T_POW) reduce 579) ((T_SL) reduce 579) ((T_SPACESHIP) reduce 579) ((T_SR) reduce 579) (("^") reduce 579) (("|") reduce 579)) 16039 ((("%") reduce 576) ((")") reduce 576) (("*") reduce 576) (("+") reduce 576) (("-") reduce 576) ((".") reduce 576) (("/") reduce 576) (("<") reduce 576) ((">") reduce 576) (("?") reduce 576) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_BOOLEAN_AND) reduce 576) ((T_BOOLEAN_OR) reduce 576) ((T_COALESCE) reduce 576) ((T_DOUBLE_ARROW) reduce 576) ((T_INSTANCEOF) reduce 576) ((T_IS_EQUAL) reduce 576) ((T_IS_GREATER_OR_EQUAL) reduce 576) ((T_IS_IDENTICAL) reduce 576) ((T_IS_NOT_EQUAL) reduce 576) ((T_IS_NOT_IDENTICAL) reduce 576) ((T_IS_SMALLER_OR_EQUAL) reduce 576) ((T_LOGICAL_AND) reduce 576) ((T_LOGICAL_OR) reduce 576) ((T_LOGICAL_XOR) reduce 576) ((T_POW) reduce 576) ((T_SL) reduce 576) ((T_SPACESHIP) reduce 576) ((T_SR) reduce 576) (("^") reduce 576) (("|") reduce 576)) 16040 ((("%") reduce 429) ((")") reduce 429) (("*") reduce 429) (("+") reduce 429) (("-") reduce 429) ((".") reduce 429) (("/") reduce 429) (("<") reduce 429) ((">") reduce 429) (("?") reduce 429) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_BOOLEAN_AND) reduce 429) ((T_BOOLEAN_OR) reduce 429) ((T_COALESCE) reduce 429) ((T_DOUBLE_ARROW) reduce 429) ((T_INSTANCEOF) reduce 429) ((T_IS_EQUAL) reduce 429) ((T_IS_GREATER_OR_EQUAL) reduce 429) ((T_IS_IDENTICAL) reduce 429) ((T_IS_NOT_EQUAL) reduce 429) ((T_IS_NOT_IDENTICAL) reduce 429) ((T_IS_SMALLER_OR_EQUAL) reduce 429) ((T_LOGICAL_AND) reduce 429) ((T_LOGICAL_OR) reduce 429) ((T_LOGICAL_XOR) reduce 429) ((T_POW) shift) ((T_SL) reduce 429) ((T_SPACESHIP) reduce 429) ((T_SR) reduce 429) (("^") reduce 429) (("|") reduce 429)) 16041 ((("%") reduce 389) ((")") reduce 389) (("*") reduce 389) (("+") reduce 389) (("-") reduce 389) ((".") reduce 389) (("/") reduce 389) (("<") reduce 389) ((">") reduce 389) (("?") reduce 389) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_BOOLEAN_AND) reduce 389) ((T_BOOLEAN_OR) reduce 389) ((T_COALESCE) reduce 389) ((T_DOUBLE_ARROW) reduce 389) ((T_INSTANCEOF) reduce 389) ((T_IS_EQUAL) reduce 389) ((T_IS_GREATER_OR_EQUAL) reduce 389) ((T_IS_IDENTICAL) reduce 389) ((T_IS_NOT_EQUAL) reduce 389) ((T_IS_NOT_IDENTICAL) reduce 389) ((T_IS_SMALLER_OR_EQUAL) reduce 389) ((T_LOGICAL_AND) reduce 389) ((T_LOGICAL_OR) reduce 389) ((T_LOGICAL_XOR) reduce 389) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 389) ((T_SL) reduce 389) ((T_SPACESHIP) reduce 389) ((T_SR) reduce 389) (("[") reduce 510) (("^") reduce 389) (("{") reduce 510) (("|") reduce 389)) 16042 ((("%") reduce 372) ((")") reduce 372) (("*") reduce 372) (("+") reduce 372) (("-") reduce 372) ((".") reduce 372) (("/") reduce 372) (("<") reduce 372) ((">") reduce 372) (("?") reduce 372) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_BOOLEAN_AND) reduce 372) ((T_BOOLEAN_OR) reduce 372) ((T_COALESCE) reduce 372) ((T_DOUBLE_ARROW) reduce 372) ((T_INSTANCEOF) reduce 372) ((T_IS_EQUAL) reduce 372) ((T_IS_GREATER_OR_EQUAL) reduce 372) ((T_IS_IDENTICAL) reduce 372) ((T_IS_NOT_EQUAL) reduce 372) ((T_IS_NOT_IDENTICAL) reduce 372) ((T_IS_SMALLER_OR_EQUAL) reduce 372) ((T_LOGICAL_AND) reduce 372) ((T_LOGICAL_OR) reduce 372) ((T_LOGICAL_XOR) reduce 372) ((T_POW) reduce 372) ((T_SL) reduce 372) ((T_SPACESHIP) reduce 372) ((T_SR) reduce 372) (("^") reduce 372) (("|") reduce 372)) 16043 ((("%") reduce 433) ((")") reduce 433) (("*") reduce 433) (("+") reduce 433) (("-") reduce 433) ((".") reduce 433) (("/") reduce 433) (("<") reduce 433) ((">") reduce 433) (("?") reduce 433) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_BOOLEAN_AND) reduce 433) ((T_BOOLEAN_OR) reduce 433) ((T_COALESCE) reduce 433) ((T_DOUBLE_ARROW) reduce 433) ((T_INSTANCEOF) reduce 433) ((T_IS_EQUAL) reduce 433) ((T_IS_GREATER_OR_EQUAL) reduce 433) ((T_IS_IDENTICAL) reduce 433) ((T_IS_NOT_EQUAL) reduce 433) ((T_IS_NOT_IDENTICAL) reduce 433) ((T_IS_SMALLER_OR_EQUAL) reduce 433) ((T_LOGICAL_AND) reduce 433) ((T_LOGICAL_OR) reduce 433) ((T_LOGICAL_XOR) reduce 433) ((T_POW) shift) ((T_SL) reduce 433) ((T_SPACESHIP) reduce 433) ((T_SR) reduce 433) (("^") reduce 433) (("|") reduce 433)) 16044 ((("%") reduce 431) ((")") reduce 431) (("*") reduce 431) (("+") reduce 431) (("-") reduce 431) ((".") reduce 431) (("/") reduce 431) (("<") reduce 431) ((">") reduce 431) (("?") reduce 431) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_BOOLEAN_AND) reduce 431) ((T_BOOLEAN_OR) reduce 431) ((T_COALESCE) reduce 431) ((T_DOUBLE_ARROW) reduce 431) ((T_INSTANCEOF) reduce 431) ((T_IS_EQUAL) reduce 431) ((T_IS_GREATER_OR_EQUAL) reduce 431) ((T_IS_IDENTICAL) reduce 431) ((T_IS_NOT_EQUAL) reduce 431) ((T_IS_NOT_IDENTICAL) reduce 431) ((T_IS_SMALLER_OR_EQUAL) reduce 431) ((T_LOGICAL_AND) reduce 431) ((T_LOGICAL_OR) reduce 431) ((T_LOGICAL_XOR) reduce 431) ((T_POW) shift) ((T_SL) reduce 431) ((T_SPACESHIP) reduce 431) ((T_SR) reduce 431) (("^") reduce 431) (("|") reduce 431)) 16047 ((("%") reduce 482) (("(") reduce 482) ((")") reduce 482) (("*") reduce 482) (("+") reduce 482) (("-") reduce 482) ((".") reduce 482) (("/") reduce 482) (("<") reduce 482) ((">") reduce 482) (("?") reduce 482) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_BOOLEAN_AND) reduce 482) ((T_BOOLEAN_OR) reduce 482) ((T_COALESCE) reduce 482) ((T_DOUBLE_ARROW) reduce 482) ((T_INSTANCEOF) reduce 482) ((T_IS_EQUAL) reduce 482) ((T_IS_GREATER_OR_EQUAL) reduce 482) ((T_IS_IDENTICAL) reduce 482) ((T_IS_NOT_EQUAL) reduce 482) ((T_IS_NOT_IDENTICAL) reduce 482) ((T_IS_SMALLER_OR_EQUAL) reduce 482) ((T_LOGICAL_AND) reduce 482) ((T_LOGICAL_OR) reduce 482) ((T_LOGICAL_XOR) reduce 482) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 482) ((T_OBJECT_OPERATOR) reduce 482) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 482) ((T_POW) reduce 482) ((T_SL) reduce 482) ((T_SPACESHIP) reduce 482) ((T_SR) reduce 482) (("[") reduce 482) (("^") reduce 482) (("{") reduce 482) (("|") reduce 482)) 16048 ((("%") reduce 436) ((")") reduce 436) (("*") reduce 436) (("+") reduce 436) (("-") reduce 436) ((".") reduce 436) (("/") reduce 436) (("<") reduce 436) ((">") reduce 436) (("?") reduce 436) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_BOOLEAN_AND) reduce 436) ((T_BOOLEAN_OR) reduce 436) ((T_COALESCE) reduce 436) ((T_DOUBLE_ARROW) reduce 436) ((T_INSTANCEOF) reduce 436) ((T_IS_EQUAL) reduce 436) ((T_IS_GREATER_OR_EQUAL) reduce 436) ((T_IS_IDENTICAL) reduce 436) ((T_IS_NOT_EQUAL) reduce 436) ((T_IS_NOT_IDENTICAL) reduce 436) ((T_IS_SMALLER_OR_EQUAL) reduce 436) ((T_LOGICAL_AND) reduce 436) ((T_LOGICAL_OR) reduce 436) ((T_LOGICAL_XOR) reduce 436) ((T_POW) shift) ((T_SL) reduce 436) ((T_SPACESHIP) reduce 436) ((T_SR) reduce 436) (("^") reduce 436) (("|") reduce 436)) 16049 ((("%") reduce 409) ((")") reduce 409) (("*") reduce 409) (("+") reduce 409) (("-") reduce 409) ((".") reduce 409) (("/") reduce 409) (("<") reduce 409) ((">") reduce 409) (("?") reduce 409) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_BOOLEAN_AND) reduce 409) ((T_BOOLEAN_OR) reduce 409) ((T_COALESCE) reduce 409) ((T_DOUBLE_ARROW) reduce 409) ((T_INSTANCEOF) reduce 409) ((T_IS_EQUAL) reduce 409) ((T_IS_GREATER_OR_EQUAL) reduce 409) ((T_IS_IDENTICAL) reduce 409) ((T_IS_NOT_EQUAL) reduce 409) ((T_IS_NOT_IDENTICAL) reduce 409) ((T_IS_SMALLER_OR_EQUAL) reduce 409) ((T_LOGICAL_AND) reduce 409) ((T_LOGICAL_OR) reduce 409) ((T_LOGICAL_XOR) reduce 409) ((T_POW) shift) ((T_SL) reduce 409) ((T_SPACESHIP) reduce 409) ((T_SR) reduce 409) (("^") reduce 409) (("|") reduce 409)) 16050 ((("%") reduce 408) ((")") reduce 408) (("*") reduce 408) (("+") reduce 408) (("-") reduce 408) ((".") reduce 408) (("/") reduce 408) (("<") reduce 408) ((">") reduce 408) (("?") reduce 408) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_BOOLEAN_AND) reduce 408) ((T_BOOLEAN_OR) reduce 408) ((T_COALESCE) reduce 408) ((T_DOUBLE_ARROW) reduce 408) ((T_INSTANCEOF) reduce 408) ((T_IS_EQUAL) reduce 408) ((T_IS_GREATER_OR_EQUAL) reduce 408) ((T_IS_IDENTICAL) reduce 408) ((T_IS_NOT_EQUAL) reduce 408) ((T_IS_NOT_IDENTICAL) reduce 408) ((T_IS_SMALLER_OR_EQUAL) reduce 408) ((T_LOGICAL_AND) reduce 408) ((T_LOGICAL_OR) reduce 408) ((T_LOGICAL_XOR) reduce 408) ((T_POW) shift) ((T_SL) reduce 408) ((T_SPACESHIP) reduce 408) ((T_SR) reduce 408) (("^") reduce 408) (("|") reduce 408)) 16052 ((("%") reduce 422) (("(") reduce 517) ((")") reduce 422) (("*") reduce 422) (("+") reduce 422) (("-") reduce 422) ((".") reduce 422) (("/") reduce 422) (("<") reduce 422) ((">") reduce 422) (("?") reduce 422) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_BOOLEAN_AND) reduce 422) ((T_BOOLEAN_OR) reduce 422) ((T_COALESCE) reduce 422) ((T_DOUBLE_ARROW) reduce 422) ((T_INSTANCEOF) reduce 422) ((T_IS_EQUAL) reduce 422) ((T_IS_GREATER_OR_EQUAL) reduce 422) ((T_IS_IDENTICAL) reduce 422) ((T_IS_NOT_EQUAL) reduce 422) ((T_IS_NOT_IDENTICAL) reduce 422) ((T_IS_SMALLER_OR_EQUAL) reduce 422) ((T_LOGICAL_AND) reduce 422) ((T_LOGICAL_OR) reduce 422) ((T_LOGICAL_XOR) reduce 422) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 511) ((T_OBJECT_OPERATOR) reduce 511) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 511) ((T_POW) reduce 422) ((T_SL) reduce 422) ((T_SPACESHIP) reduce 422) ((T_SR) reduce 422) (("[") reduce 511) (("^") reduce 422) (("{") reduce 511) (("|") reduce 422)) 16053 ((("%") reduce 531) (("(") reduce 531) ((")") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) (("=") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AND_EQUAL) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_COALESCE_EQUAL) reduce 531) ((T_CONCAT_EQUAL) reduce 531) ((T_DEC) reduce 531) ((T_DIV_EQUAL) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INC) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_MINUS_EQUAL) reduce 531) ((T_MOD_EQUAL) reduce 531) ((T_MUL_EQUAL) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_OR_EQUAL) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_PLUS_EQUAL) reduce 531) ((T_POW) reduce 531) ((T_POW_EQUAL) reduce 531) ((T_SL) reduce 531) ((T_SL_EQUAL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) ((T_SR_EQUAL) reduce 531) ((T_XOR_EQUAL) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 16056 ((("%") reduce 530) (("(") reduce 530) ((")") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) (("=") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AND_EQUAL) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_COALESCE_EQUAL) reduce 530) ((T_CONCAT_EQUAL) reduce 530) ((T_DEC) reduce 530) ((T_DIV_EQUAL) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INC) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_MINUS_EQUAL) reduce 530) ((T_MOD_EQUAL) reduce 530) ((T_MUL_EQUAL) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_OR_EQUAL) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_PLUS_EQUAL) reduce 530) ((T_POW) reduce 530) ((T_POW_EQUAL) reduce 530) ((T_SL) reduce 530) ((T_SL_EQUAL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) ((T_SR_EQUAL) reduce 530) ((T_XOR_EQUAL) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 16058 ((("%") reduce 485) (("(") reduce 485) ((")") reduce 485) (("*") reduce 485) (("+") reduce 485) (("-") reduce 485) ((".") reduce 485) (("/") reduce 485) (("<") reduce 485) ((">") reduce 485) (("?") reduce 485) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_BOOLEAN_AND) reduce 485) ((T_BOOLEAN_OR) reduce 485) ((T_COALESCE) reduce 485) ((T_DOUBLE_ARROW) reduce 485) ((T_INSTANCEOF) reduce 485) ((T_IS_EQUAL) reduce 485) ((T_IS_GREATER_OR_EQUAL) reduce 485) ((T_IS_IDENTICAL) reduce 485) ((T_IS_NOT_EQUAL) reduce 485) ((T_IS_NOT_IDENTICAL) reduce 485) ((T_IS_SMALLER_OR_EQUAL) reduce 485) ((T_LOGICAL_AND) reduce 485) ((T_LOGICAL_OR) reduce 485) ((T_LOGICAL_XOR) reduce 485) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 485) ((T_OBJECT_OPERATOR) reduce 485) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 485) ((T_POW) reduce 485) ((T_SL) reduce 485) ((T_SPACESHIP) reduce 485) ((T_SR) reduce 485) (("[") reduce 485) (("^") reduce 485) (("{") reduce 485) (("|") reduce 485)) 16059 ((("%") reduce 410) ((")") reduce 410) (("*") reduce 410) (("+") reduce 410) (("-") reduce 410) ((".") reduce 410) (("/") reduce 410) (("<") reduce 410) ((">") reduce 410) (("?") reduce 410) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_BOOLEAN_AND) reduce 410) ((T_BOOLEAN_OR) reduce 410) ((T_COALESCE) reduce 410) ((T_DOUBLE_ARROW) reduce 410) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 410) ((T_IS_GREATER_OR_EQUAL) reduce 410) ((T_IS_IDENTICAL) reduce 410) ((T_IS_NOT_EQUAL) reduce 410) ((T_IS_NOT_IDENTICAL) reduce 410) ((T_IS_SMALLER_OR_EQUAL) reduce 410) ((T_LOGICAL_AND) reduce 410) ((T_LOGICAL_OR) reduce 410) ((T_LOGICAL_XOR) reduce 410) ((T_POW) shift) ((T_SL) reduce 410) ((T_SPACESHIP) reduce 410) ((T_SR) reduce 410) (("^") reduce 410) (("|") reduce 410)) 16060 ((("%") reduce 434) ((")") reduce 434) (("*") reduce 434) (("+") reduce 434) (("-") reduce 434) ((".") reduce 434) (("/") reduce 434) (("<") reduce 434) ((">") reduce 434) (("?") reduce 434) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_BOOLEAN_AND) reduce 434) ((T_BOOLEAN_OR) reduce 434) ((T_COALESCE) reduce 434) ((T_INSTANCEOF) reduce 434) ((T_IS_EQUAL) reduce 434) ((T_IS_GREATER_OR_EQUAL) reduce 434) ((T_IS_IDENTICAL) reduce 434) ((T_IS_NOT_EQUAL) reduce 434) ((T_IS_NOT_IDENTICAL) reduce 434) ((T_IS_SMALLER_OR_EQUAL) reduce 434) ((T_LOGICAL_AND) reduce 434) ((T_LOGICAL_OR) reduce 434) ((T_LOGICAL_XOR) reduce 434) ((T_POW) shift) ((T_SL) reduce 434) ((T_SPACESHIP) reduce 434) ((T_SR) reduce 434) (("^") reduce 434) (("|") reduce 434)) 16061 ((("%") shift) ((")") reduce 444) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 16062 ((("%") reduce 430) ((")") reduce 430) (("*") reduce 430) (("+") reduce 430) (("-") reduce 430) ((".") reduce 430) (("/") reduce 430) (("<") reduce 430) ((">") reduce 430) (("?") reduce 430) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_BOOLEAN_AND) reduce 430) ((T_BOOLEAN_OR) reduce 430) ((T_COALESCE) reduce 430) ((T_INSTANCEOF) reduce 430) ((T_IS_EQUAL) reduce 430) ((T_IS_GREATER_OR_EQUAL) reduce 430) ((T_IS_IDENTICAL) reduce 430) ((T_IS_NOT_EQUAL) reduce 430) ((T_IS_NOT_IDENTICAL) reduce 430) ((T_IS_SMALLER_OR_EQUAL) reduce 430) ((T_LOGICAL_AND) reduce 430) ((T_LOGICAL_OR) reduce 430) ((T_LOGICAL_XOR) reduce 430) ((T_POW) shift) ((T_SL) reduce 430) ((T_SPACESHIP) reduce 430) ((T_SR) reduce 430) (("^") reduce 430) (("|") reduce 430)) 16063 ((("%") reduce 447) ((")") reduce 447) (("*") reduce 447) (("+") reduce 447) (("-") reduce 447) ((".") reduce 447) (("/") reduce 447) (("<") reduce 447) ((">") reduce 447) (("?") reduce 447) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_BOOLEAN_AND) reduce 447) ((T_BOOLEAN_OR) reduce 447) ((T_COALESCE) reduce 447) ((T_INSTANCEOF) reduce 447) ((T_IS_EQUAL) reduce 447) ((T_IS_GREATER_OR_EQUAL) reduce 447) ((T_IS_IDENTICAL) reduce 447) ((T_IS_NOT_EQUAL) reduce 447) ((T_IS_NOT_IDENTICAL) reduce 447) ((T_IS_SMALLER_OR_EQUAL) reduce 447) ((T_LOGICAL_AND) reduce 447) ((T_LOGICAL_OR) reduce 447) ((T_LOGICAL_XOR) reduce 447) ((T_POW) reduce 447) ((T_SL) reduce 447) ((T_SPACESHIP) reduce 447) ((T_SR) reduce 447) (("^") reduce 447) (("|") reduce 447)) 16065 ((("%") reduce 489) ((")") reduce 489) (("*") reduce 489) (("+") reduce 489) (("-") reduce 489) ((".") reduce 489) (("/") reduce 489) (("<") reduce 489) ((">") reduce 489) (("?") reduce 489) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_BOOLEAN_AND) reduce 489) ((T_BOOLEAN_OR) reduce 489) ((T_COALESCE) reduce 489) ((T_INSTANCEOF) reduce 489) ((T_IS_EQUAL) reduce 489) ((T_IS_GREATER_OR_EQUAL) reduce 489) ((T_IS_IDENTICAL) reduce 489) ((T_IS_NOT_EQUAL) reduce 489) ((T_IS_NOT_IDENTICAL) reduce 489) ((T_IS_SMALLER_OR_EQUAL) reduce 489) ((T_LOGICAL_AND) reduce 489) ((T_LOGICAL_OR) reduce 489) ((T_LOGICAL_XOR) reduce 489) ((T_POW) reduce 489) ((T_SL) reduce 489) ((T_SPACESHIP) reduce 489) ((T_SR) reduce 489) (("^") reduce 489) (("|") reduce 489)) 16067 ((("%") reduce 490) ((")") reduce 490) (("*") reduce 490) (("+") reduce 490) (("-") reduce 490) ((".") reduce 490) (("/") reduce 490) (("<") reduce 490) ((">") reduce 490) (("?") reduce 490) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_BOOLEAN_AND) reduce 490) ((T_BOOLEAN_OR) reduce 490) ((T_COALESCE) reduce 490) ((T_INSTANCEOF) reduce 490) ((T_IS_EQUAL) reduce 490) ((T_IS_GREATER_OR_EQUAL) reduce 490) ((T_IS_IDENTICAL) reduce 490) ((T_IS_NOT_EQUAL) reduce 490) ((T_IS_NOT_IDENTICAL) reduce 490) ((T_IS_SMALLER_OR_EQUAL) reduce 490) ((T_LOGICAL_AND) reduce 490) ((T_LOGICAL_OR) reduce 490) ((T_LOGICAL_XOR) reduce 490) ((T_POW) reduce 490) ((T_SL) reduce 490) ((T_SPACESHIP) reduce 490) ((T_SR) reduce 490) (("^") reduce 490) (("|") reduce 490)) 16068 ((("%") reduce 488) ((")") reduce 488) (("*") reduce 488) (("+") reduce 488) (("-") reduce 488) ((".") reduce 488) (("/") reduce 488) (("<") reduce 488) ((">") reduce 488) (("?") reduce 488) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_BOOLEAN_AND) reduce 488) ((T_BOOLEAN_OR) reduce 488) ((T_COALESCE) reduce 488) ((T_INSTANCEOF) reduce 488) ((T_IS_EQUAL) reduce 488) ((T_IS_GREATER_OR_EQUAL) reduce 488) ((T_IS_IDENTICAL) reduce 488) ((T_IS_NOT_EQUAL) reduce 488) ((T_IS_NOT_IDENTICAL) reduce 488) ((T_IS_SMALLER_OR_EQUAL) reduce 488) ((T_LOGICAL_AND) reduce 488) ((T_LOGICAL_OR) reduce 488) ((T_LOGICAL_XOR) reduce 488) ((T_POW) reduce 488) ((T_SL) reduce 488) ((T_SPACESHIP) reduce 488) ((T_SR) reduce 488) (("^") reduce 488) (("|") reduce 488)) 16069 ((("%") shift) ((")") reduce 581) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 16070 ((("%") shift) ((")") reduce 580) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 16071 ((("%") reduce 466) (("(") reduce 466) ((")") reduce 466) (("*") reduce 466) (("+") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) (("<") reduce 466) (("=") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AND_EQUAL) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_COALESCE_EQUAL) reduce 466) ((T_CONCAT_EQUAL) reduce 466) ((T_DEC) reduce 466) ((T_DIV_EQUAL) reduce 466) ((T_INC) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_MINUS_EQUAL) reduce 466) ((T_MOD_EQUAL) reduce 466) ((T_MUL_EQUAL) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_OR_EQUAL) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_PLUS_EQUAL) reduce 466) ((T_POW) reduce 466) ((T_POW_EQUAL) reduce 466) ((T_SL) reduce 466) ((T_SL_EQUAL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) ((T_SR_EQUAL) reduce 466) ((T_XOR_EQUAL) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 16072 ((("%") shift) ((")") reduce 439) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 439) ((T_LOGICAL_OR) reduce 439) ((T_LOGICAL_XOR) reduce 439) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 16073 ((("%") reduce 432) ((")") reduce 432) (("*") reduce 432) (("+") reduce 432) (("-") reduce 432) ((".") reduce 432) (("/") reduce 432) (("<") reduce 432) ((">") reduce 432) (("?") reduce 432) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_BOOLEAN_AND) reduce 432) ((T_BOOLEAN_OR) reduce 432) ((T_COALESCE) reduce 432) ((T_INSTANCEOF) reduce 432) ((T_IS_EQUAL) reduce 432) ((T_IS_GREATER_OR_EQUAL) reduce 432) ((T_IS_IDENTICAL) reduce 432) ((T_IS_NOT_EQUAL) reduce 432) ((T_IS_NOT_IDENTICAL) reduce 432) ((T_IS_SMALLER_OR_EQUAL) reduce 432) ((T_LOGICAL_AND) reduce 432) ((T_LOGICAL_OR) reduce 432) ((T_LOGICAL_XOR) reduce 432) ((T_POW) shift) ((T_SL) reduce 432) ((T_SPACESHIP) reduce 432) ((T_SR) reduce 432) (("^") reduce 432) (("|") reduce 432)) 16075 ((("%") reduce 93) (("(") reduce 93) ((")") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93)) 16076 ((("%") reduce 92) (("(") reduce 92) ((")") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92)) 16077 ((("%") reduce 94) (("(") reduce 94) ((")") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94)) 16078 ((("%") reduce 470) (("(") reduce 470) ((")") reduce 470) (("*") reduce 470) (("+") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470)) 16079 ((("%") reduce 91) (("(") reduce 91) ((")") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91)) 16080 ((("%") reduce 365) ((")") reduce 365) (("*") reduce 365) (("+") reduce 365) (("-") reduce 365) ((".") reduce 365) (("/") reduce 365) (("<") reduce 365) ((">") reduce 365) (("?") reduce 365) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_BOOLEAN_AND) reduce 365) ((T_BOOLEAN_OR) reduce 365) ((T_COALESCE) reduce 365) ((T_INSTANCEOF) reduce 365) ((T_IS_EQUAL) reduce 365) ((T_IS_GREATER_OR_EQUAL) reduce 365) ((T_IS_IDENTICAL) reduce 365) ((T_IS_NOT_EQUAL) reduce 365) ((T_IS_NOT_IDENTICAL) reduce 365) ((T_IS_SMALLER_OR_EQUAL) reduce 365) ((T_LOGICAL_AND) reduce 365) ((T_LOGICAL_OR) reduce 365) ((T_LOGICAL_XOR) reduce 365) ((T_POW) reduce 365) ((T_SL) reduce 365) ((T_SPACESHIP) reduce 365) ((T_SR) reduce 365) (("^") reduce 365) (("|") reduce 365)) 16083 ((("%") reduce 472) (("(") reduce 472) ((")") reduce 472) (("*") reduce 472) (("+") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472)) 16084 ((("%") reduce 480) (("(") shift) ((")") reduce 480) (("*") reduce 480) (("+") reduce 480) (("-") reduce 480) ((".") reduce 480) (("/") reduce 480) (("<") reduce 480) ((">") reduce 480) (("?") reduce 480) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_BOOLEAN_AND) reduce 480) ((T_BOOLEAN_OR) reduce 480) ((T_COALESCE) reduce 480) ((T_INSTANCEOF) reduce 480) ((T_IS_EQUAL) reduce 480) ((T_IS_GREATER_OR_EQUAL) reduce 480) ((T_IS_IDENTICAL) reduce 480) ((T_IS_NOT_EQUAL) reduce 480) ((T_IS_NOT_IDENTICAL) reduce 480) ((T_IS_SMALLER_OR_EQUAL) reduce 480) ((T_LOGICAL_AND) reduce 480) ((T_LOGICAL_OR) reduce 480) ((T_LOGICAL_XOR) reduce 480) ((T_POW) reduce 480) ((T_SL) reduce 480) ((T_SPACESHIP) reduce 480) ((T_SR) reduce 480) (("^") reduce 480) (("|") reduce 480)) 16085 ((("%") reduce 471) (("(") reduce 471) ((")") reduce 471) (("*") reduce 471) (("+") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471)) 16086 ((("%") reduce 473) (("(") reduce 473) ((")") reduce 473) (("*") reduce 473) (("+") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 16087 ((("%") reduce 534) (("(") reduce 534) ((")") reduce 534) (("*") reduce 534) (("+") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 16094 ((("%") reduce 536) (("(") reduce 536) ((")") reduce 536) (("*") reduce 536) (("+") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 16096 ((("%") reduce 535) (("(") reduce 535) ((")") reduce 535) (("*") reduce 535) (("+") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 16097 ((("%") reduce 540) (("(") reduce 540) ((")") reduce 540) (("*") reduce 540) (("+") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 16098 ((("%") reduce 537) (("(") reduce 537) ((")") reduce 537) (("*") reduce 537) (("+") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 16099 ((("%") reduce 538) (("(") reduce 538) ((")") reduce 538) (("*") reduce 538) (("+") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 16101 ((("%") reduce 481) ((")") reduce 481) (("*") reduce 481) (("+") reduce 481) (("-") reduce 481) ((".") reduce 481) (("/") reduce 481) (("<") reduce 481) ((">") reduce 481) (("?") reduce 481) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_BOOLEAN_AND) reduce 481) ((T_BOOLEAN_OR) reduce 481) ((T_COALESCE) reduce 481) ((T_INSTANCEOF) reduce 481) ((T_IS_EQUAL) reduce 481) ((T_IS_GREATER_OR_EQUAL) reduce 481) ((T_IS_IDENTICAL) reduce 481) ((T_IS_NOT_EQUAL) reduce 481) ((T_IS_NOT_IDENTICAL) reduce 481) ((T_IS_SMALLER_OR_EQUAL) reduce 481) ((T_LOGICAL_AND) reduce 481) ((T_LOGICAL_OR) reduce 481) ((T_LOGICAL_XOR) reduce 481) ((T_POW) reduce 481) ((T_SL) reduce 481) ((T_SPACESHIP) reduce 481) ((T_SR) reduce 481) (("^") reduce 481) (("|") reduce 481)) 16102 ((("%") reduce 364) ((")") reduce 364) (("*") reduce 364) (("+") reduce 364) (("-") reduce 364) ((".") reduce 364) (("/") reduce 364) (("<") reduce 364) ((">") reduce 364) (("?") reduce 364) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_BOOLEAN_AND) reduce 364) ((T_BOOLEAN_OR) reduce 364) ((T_COALESCE) reduce 364) ((T_INSTANCEOF) reduce 364) ((T_IS_EQUAL) reduce 364) ((T_IS_GREATER_OR_EQUAL) reduce 364) ((T_IS_IDENTICAL) reduce 364) ((T_IS_NOT_EQUAL) reduce 364) ((T_IS_NOT_IDENTICAL) reduce 364) ((T_IS_SMALLER_OR_EQUAL) reduce 364) ((T_LOGICAL_AND) reduce 364) ((T_LOGICAL_OR) reduce 364) ((T_LOGICAL_XOR) reduce 364) ((T_POW) reduce 364) ((T_SL) reduce 364) ((T_SPACESHIP) reduce 364) ((T_SR) reduce 364) (("^") reduce 364) (("|") reduce 364)) 16103 ((("%") reduce 288) ((")") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("^") reduce 288) (("|") reduce 288)) 16107 ((("%") reduce 289) ((")") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("^") reduce 289) (("|") reduce 289)) 16108 ((("%") reduce 290) ((")") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("^") reduce 290) (("|") reduce 290)) 16110 ((("%") reduce 539) (("(") reduce 539) ((")") reduce 539) (("*") reduce 539) (("+") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 16111 ((("%") reduce 366) ((")") reduce 366) (("*") reduce 366) (("+") reduce 366) (("-") reduce 366) ((".") reduce 366) (("/") reduce 366) (("<") reduce 366) ((">") reduce 366) (("?") reduce 366) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_BOOLEAN_AND) reduce 366) ((T_BOOLEAN_OR) reduce 366) ((T_COALESCE) reduce 366) ((T_INSTANCEOF) reduce 366) ((T_IS_EQUAL) reduce 366) ((T_IS_GREATER_OR_EQUAL) reduce 366) ((T_IS_IDENTICAL) reduce 366) ((T_IS_NOT_EQUAL) reduce 366) ((T_IS_NOT_IDENTICAL) reduce 366) ((T_IS_SMALLER_OR_EQUAL) reduce 366) ((T_LOGICAL_AND) reduce 366) ((T_LOGICAL_OR) reduce 366) ((T_LOGICAL_XOR) reduce 366) ((T_POW) reduce 366) ((T_SL) reduce 366) ((T_SPACESHIP) reduce 366) ((T_SR) reduce 366) (("^") reduce 366) (("|") reduce 366)) 16119 ((("%") reduce 363) ((")") reduce 363) (("*") reduce 363) (("+") reduce 363) (("-") reduce 363) ((".") reduce 363) (("/") reduce 363) (("<") reduce 363) ((">") reduce 363) (("?") reduce 363) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_BOOLEAN_AND) reduce 363) ((T_BOOLEAN_OR) reduce 363) ((T_COALESCE) reduce 363) ((T_INSTANCEOF) reduce 363) ((T_IS_EQUAL) reduce 363) ((T_IS_GREATER_OR_EQUAL) reduce 363) ((T_IS_IDENTICAL) reduce 363) ((T_IS_NOT_EQUAL) reduce 363) ((T_IS_NOT_IDENTICAL) reduce 363) ((T_IS_SMALLER_OR_EQUAL) reduce 363) ((T_LOGICAL_AND) reduce 363) ((T_LOGICAL_OR) reduce 363) ((T_LOGICAL_XOR) reduce 363) ((T_POW) reduce 363) ((T_SL) reduce 363) ((T_SPACESHIP) reduce 363) ((T_SR) reduce 363) (("^") reduce 363) (("|") reduce 363)) 16121 ((("%") reduce 474) (("(") reduce 474) ((")") reduce 474) (("*") reduce 474) (("+") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474)) 16127 ((("%") reduce 230) ((")") reduce 230) (("*") reduce 230) (("+") reduce 230) (("-") reduce 230) ((".") reduce 230) (("/") reduce 230) (("<") reduce 230) ((">") reduce 230) (("?") reduce 230) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_BOOLEAN_AND) reduce 230) ((T_BOOLEAN_OR) reduce 230) ((T_COALESCE) reduce 230) ((T_INSTANCEOF) reduce 230) ((T_IS_EQUAL) reduce 230) ((T_IS_GREATER_OR_EQUAL) reduce 230) ((T_IS_IDENTICAL) reduce 230) ((T_IS_NOT_EQUAL) reduce 230) ((T_IS_NOT_IDENTICAL) reduce 230) ((T_IS_SMALLER_OR_EQUAL) reduce 230) ((T_LOGICAL_AND) reduce 230) ((T_LOGICAL_OR) reduce 230) ((T_LOGICAL_XOR) reduce 230) ((T_POW) reduce 230) ((T_SL) reduce 230) ((T_SPACESHIP) reduce 230) ((T_SR) reduce 230) (("^") reduce 230) (("|") reduce 230)) 16132 ((("%") shift) ((")") reduce 368) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 368) ((T_LOGICAL_OR) reduce 368) ((T_LOGICAL_XOR) reduce 368) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 16136 ((("%") reduce 575) ((")") reduce 575) (("*") reduce 575) (("+") reduce 575) (("-") reduce 575) ((".") reduce 575) (("/") reduce 575) (("<") reduce 575) ((">") reduce 575) (("?") reduce 575) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_BOOLEAN_AND) reduce 575) ((T_BOOLEAN_OR) reduce 575) ((T_COALESCE) reduce 575) ((T_INSTANCEOF) reduce 575) ((T_IS_EQUAL) reduce 575) ((T_IS_GREATER_OR_EQUAL) reduce 575) ((T_IS_IDENTICAL) reduce 575) ((T_IS_NOT_EQUAL) reduce 575) ((T_IS_NOT_IDENTICAL) reduce 575) ((T_IS_SMALLER_OR_EQUAL) reduce 575) ((T_LOGICAL_AND) reduce 575) ((T_LOGICAL_OR) reduce 575) ((T_LOGICAL_XOR) reduce 575) ((T_POW) reduce 575) ((T_SL) reduce 575) ((T_SPACESHIP) reduce 575) ((T_SR) reduce 575) (("^") reduce 575) (("|") reduce 575)) 16137 ((("%") reduce 428) ((")") reduce 428) (("*") reduce 428) (("+") reduce 428) (("-") reduce 428) ((".") reduce 428) (("/") reduce 428) (("<") reduce 428) ((">") reduce 428) (("?") reduce 428) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_BOOLEAN_AND) reduce 428) ((T_BOOLEAN_OR) reduce 428) ((T_COALESCE) reduce 428) ((T_INSTANCEOF) reduce 428) ((T_IS_EQUAL) reduce 428) ((T_IS_GREATER_OR_EQUAL) reduce 428) ((T_IS_IDENTICAL) reduce 428) ((T_IS_NOT_EQUAL) reduce 428) ((T_IS_NOT_IDENTICAL) reduce 428) ((T_IS_SMALLER_OR_EQUAL) reduce 428) ((T_LOGICAL_AND) reduce 428) ((T_LOGICAL_OR) reduce 428) ((T_LOGICAL_XOR) reduce 428) ((T_POW) shift) ((T_SL) reduce 428) ((T_SPACESHIP) reduce 428) ((T_SR) reduce 428) (("^") reduce 428) (("|") reduce 428)) 16138 ((("%") shift) ((")") reduce 578) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 16139 ((("%") shift) ((")") reduce 577) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 16140 ((("%") reduce 387) ((")") reduce 387) (("*") reduce 387) (("+") reduce 387) (("-") reduce 387) ((".") reduce 387) (("/") reduce 387) (("<") reduce 387) ((">") reduce 387) (("?") reduce 387) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_BOOLEAN_AND) reduce 387) ((T_BOOLEAN_OR) reduce 387) ((T_COALESCE) reduce 387) ((T_INSTANCEOF) reduce 387) ((T_IS_EQUAL) reduce 387) ((T_IS_GREATER_OR_EQUAL) reduce 387) ((T_IS_IDENTICAL) reduce 387) ((T_IS_NOT_EQUAL) reduce 387) ((T_IS_NOT_IDENTICAL) reduce 387) ((T_IS_SMALLER_OR_EQUAL) reduce 387) ((T_LOGICAL_AND) reduce 387) ((T_LOGICAL_OR) reduce 387) ((T_LOGICAL_XOR) reduce 387) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 387) ((T_SL) reduce 387) ((T_SPACESHIP) reduce 387) ((T_SR) reduce 387) (("[") reduce 510) (("^") reduce 387) (("{") reduce 510) (("|") reduce 387)) 16142 ((("%") reduce 435) ((")") reduce 435) (("*") reduce 435) (("+") reduce 435) (("-") reduce 435) ((".") reduce 435) (("/") reduce 435) (("<") reduce 435) ((">") reduce 435) (("?") reduce 435) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_BOOLEAN_AND) reduce 435) ((T_BOOLEAN_OR) reduce 435) ((T_COALESCE) reduce 435) ((T_INSTANCEOF) reduce 435) ((T_IS_EQUAL) reduce 435) ((T_IS_GREATER_OR_EQUAL) reduce 435) ((T_IS_IDENTICAL) reduce 435) ((T_IS_NOT_EQUAL) reduce 435) ((T_IS_NOT_IDENTICAL) reduce 435) ((T_IS_SMALLER_OR_EQUAL) reduce 435) ((T_LOGICAL_AND) reduce 435) ((T_LOGICAL_OR) reduce 435) ((T_LOGICAL_XOR) reduce 435) ((T_POW) reduce 435) ((T_SL) reduce 435) ((T_SPACESHIP) reduce 435) ((T_SR) reduce 435) (("^") reduce 435) (("|") reduce 435)) 16144 ((("%") reduce 476) ((")") reduce 476) (("*") reduce 476) (("+") reduce 476) (("-") reduce 476) ((".") reduce 476) (("/") reduce 476) (("<") reduce 476) ((">") reduce 476) (("?") reduce 476) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_BOOLEAN_AND) reduce 476) ((T_BOOLEAN_OR) reduce 476) ((T_COALESCE) reduce 476) ((T_INSTANCEOF) reduce 476) ((T_IS_EQUAL) reduce 476) ((T_IS_GREATER_OR_EQUAL) reduce 476) ((T_IS_IDENTICAL) reduce 476) ((T_IS_NOT_EQUAL) reduce 476) ((T_IS_NOT_IDENTICAL) reduce 476) ((T_IS_SMALLER_OR_EQUAL) reduce 476) ((T_LOGICAL_AND) reduce 476) ((T_LOGICAL_OR) reduce 476) ((T_LOGICAL_XOR) reduce 476) ((T_POW) reduce 476) ((T_SL) reduce 476) ((T_SPACESHIP) reduce 476) ((T_SR) reduce 476) (("^") reduce 476) (("|") reduce 476)) 16147 ((("%") reduce 579) ((")") reduce 579) (("*") reduce 579) (("+") reduce 579) (("-") reduce 579) ((".") reduce 579) (("/") reduce 579) (("<") reduce 579) ((">") reduce 579) (("?") reduce 579) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_BOOLEAN_AND) reduce 579) ((T_BOOLEAN_OR) reduce 579) ((T_COALESCE) reduce 579) ((T_INSTANCEOF) reduce 579) ((T_IS_EQUAL) reduce 579) ((T_IS_GREATER_OR_EQUAL) reduce 579) ((T_IS_IDENTICAL) reduce 579) ((T_IS_NOT_EQUAL) reduce 579) ((T_IS_NOT_IDENTICAL) reduce 579) ((T_IS_SMALLER_OR_EQUAL) reduce 579) ((T_LOGICAL_AND) reduce 579) ((T_LOGICAL_OR) reduce 579) ((T_LOGICAL_XOR) reduce 579) ((T_POW) reduce 579) ((T_SL) reduce 579) ((T_SPACESHIP) reduce 579) ((T_SR) reduce 579) (("^") reduce 579) (("|") reduce 579)) 16150 ((("%") reduce 576) ((")") reduce 576) (("*") reduce 576) (("+") reduce 576) (("-") reduce 576) ((".") reduce 576) (("/") reduce 576) (("<") reduce 576) ((">") reduce 576) (("?") reduce 576) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_BOOLEAN_AND) reduce 576) ((T_BOOLEAN_OR) reduce 576) ((T_COALESCE) reduce 576) ((T_INSTANCEOF) reduce 576) ((T_IS_EQUAL) reduce 576) ((T_IS_GREATER_OR_EQUAL) reduce 576) ((T_IS_IDENTICAL) reduce 576) ((T_IS_NOT_EQUAL) reduce 576) ((T_IS_NOT_IDENTICAL) reduce 576) ((T_IS_SMALLER_OR_EQUAL) reduce 576) ((T_LOGICAL_AND) reduce 576) ((T_LOGICAL_OR) reduce 576) ((T_LOGICAL_XOR) reduce 576) ((T_POW) reduce 576) ((T_SL) reduce 576) ((T_SPACESHIP) reduce 576) ((T_SR) reduce 576) (("^") reduce 576) (("|") reduce 576)) 16151 ((("%") reduce 429) ((")") reduce 429) (("*") reduce 429) (("+") reduce 429) (("-") reduce 429) ((".") reduce 429) (("/") reduce 429) (("<") reduce 429) ((">") reduce 429) (("?") reduce 429) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_BOOLEAN_AND) reduce 429) ((T_BOOLEAN_OR) reduce 429) ((T_COALESCE) reduce 429) ((T_INSTANCEOF) reduce 429) ((T_IS_EQUAL) reduce 429) ((T_IS_GREATER_OR_EQUAL) reduce 429) ((T_IS_IDENTICAL) reduce 429) ((T_IS_NOT_EQUAL) reduce 429) ((T_IS_NOT_IDENTICAL) reduce 429) ((T_IS_SMALLER_OR_EQUAL) reduce 429) ((T_LOGICAL_AND) reduce 429) ((T_LOGICAL_OR) reduce 429) ((T_LOGICAL_XOR) reduce 429) ((T_POW) shift) ((T_SL) reduce 429) ((T_SPACESHIP) reduce 429) ((T_SR) reduce 429) (("^") reduce 429) (("|") reduce 429)) 16152 ((("%") reduce 389) ((")") reduce 389) (("*") reduce 389) (("+") reduce 389) (("-") reduce 389) ((".") reduce 389) (("/") reduce 389) (("<") reduce 389) ((">") reduce 389) (("?") reduce 389) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_BOOLEAN_AND) reduce 389) ((T_BOOLEAN_OR) reduce 389) ((T_COALESCE) reduce 389) ((T_INSTANCEOF) reduce 389) ((T_IS_EQUAL) reduce 389) ((T_IS_GREATER_OR_EQUAL) reduce 389) ((T_IS_IDENTICAL) reduce 389) ((T_IS_NOT_EQUAL) reduce 389) ((T_IS_NOT_IDENTICAL) reduce 389) ((T_IS_SMALLER_OR_EQUAL) reduce 389) ((T_LOGICAL_AND) reduce 389) ((T_LOGICAL_OR) reduce 389) ((T_LOGICAL_XOR) reduce 389) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 389) ((T_SL) reduce 389) ((T_SPACESHIP) reduce 389) ((T_SR) reduce 389) (("[") reduce 510) (("^") reduce 389) (("{") reduce 510) (("|") reduce 389)) 16153 ((("%") reduce 372) ((")") reduce 372) (("*") reduce 372) (("+") reduce 372) (("-") reduce 372) ((".") reduce 372) (("/") reduce 372) (("<") reduce 372) ((">") reduce 372) (("?") reduce 372) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_BOOLEAN_AND) reduce 372) ((T_BOOLEAN_OR) reduce 372) ((T_COALESCE) reduce 372) ((T_INSTANCEOF) reduce 372) ((T_IS_EQUAL) reduce 372) ((T_IS_GREATER_OR_EQUAL) reduce 372) ((T_IS_IDENTICAL) reduce 372) ((T_IS_NOT_EQUAL) reduce 372) ((T_IS_NOT_IDENTICAL) reduce 372) ((T_IS_SMALLER_OR_EQUAL) reduce 372) ((T_LOGICAL_AND) reduce 372) ((T_LOGICAL_OR) reduce 372) ((T_LOGICAL_XOR) reduce 372) ((T_POW) reduce 372) ((T_SL) reduce 372) ((T_SPACESHIP) reduce 372) ((T_SR) reduce 372) (("^") reduce 372) (("|") reduce 372)) 16154 ((("%") reduce 433) ((")") reduce 433) (("*") reduce 433) (("+") reduce 433) (("-") reduce 433) ((".") reduce 433) (("/") reduce 433) (("<") reduce 433) ((">") reduce 433) (("?") reduce 433) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_BOOLEAN_AND) reduce 433) ((T_BOOLEAN_OR) reduce 433) ((T_COALESCE) reduce 433) ((T_INSTANCEOF) reduce 433) ((T_IS_EQUAL) reduce 433) ((T_IS_GREATER_OR_EQUAL) reduce 433) ((T_IS_IDENTICAL) reduce 433) ((T_IS_NOT_EQUAL) reduce 433) ((T_IS_NOT_IDENTICAL) reduce 433) ((T_IS_SMALLER_OR_EQUAL) reduce 433) ((T_LOGICAL_AND) reduce 433) ((T_LOGICAL_OR) reduce 433) ((T_LOGICAL_XOR) reduce 433) ((T_POW) shift) ((T_SL) reduce 433) ((T_SPACESHIP) reduce 433) ((T_SR) reduce 433) (("^") reduce 433) (("|") reduce 433)) 16155 ((("%") reduce 431) ((")") reduce 431) (("*") reduce 431) (("+") reduce 431) (("-") reduce 431) ((".") reduce 431) (("/") reduce 431) (("<") reduce 431) ((">") reduce 431) (("?") reduce 431) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_BOOLEAN_AND) reduce 431) ((T_BOOLEAN_OR) reduce 431) ((T_COALESCE) reduce 431) ((T_INSTANCEOF) reduce 431) ((T_IS_EQUAL) reduce 431) ((T_IS_GREATER_OR_EQUAL) reduce 431) ((T_IS_IDENTICAL) reduce 431) ((T_IS_NOT_EQUAL) reduce 431) ((T_IS_NOT_IDENTICAL) reduce 431) ((T_IS_SMALLER_OR_EQUAL) reduce 431) ((T_LOGICAL_AND) reduce 431) ((T_LOGICAL_OR) reduce 431) ((T_LOGICAL_XOR) reduce 431) ((T_POW) shift) ((T_SL) reduce 431) ((T_SPACESHIP) reduce 431) ((T_SR) reduce 431) (("^") reduce 431) (("|") reduce 431)) 16158 ((("%") reduce 482) (("(") reduce 482) ((")") reduce 482) (("*") reduce 482) (("+") reduce 482) (("-") reduce 482) ((".") reduce 482) (("/") reduce 482) (("<") reduce 482) ((">") reduce 482) (("?") reduce 482) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_BOOLEAN_AND) reduce 482) ((T_BOOLEAN_OR) reduce 482) ((T_COALESCE) reduce 482) ((T_INSTANCEOF) reduce 482) ((T_IS_EQUAL) reduce 482) ((T_IS_GREATER_OR_EQUAL) reduce 482) ((T_IS_IDENTICAL) reduce 482) ((T_IS_NOT_EQUAL) reduce 482) ((T_IS_NOT_IDENTICAL) reduce 482) ((T_IS_SMALLER_OR_EQUAL) reduce 482) ((T_LOGICAL_AND) reduce 482) ((T_LOGICAL_OR) reduce 482) ((T_LOGICAL_XOR) reduce 482) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 482) ((T_OBJECT_OPERATOR) reduce 482) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 482) ((T_POW) reduce 482) ((T_SL) reduce 482) ((T_SPACESHIP) reduce 482) ((T_SR) reduce 482) (("[") reduce 482) (("^") reduce 482) (("{") reduce 482) (("|") reduce 482)) 16159 ((("%") reduce 436) ((")") reduce 436) (("*") reduce 436) (("+") reduce 436) (("-") reduce 436) ((".") reduce 436) (("/") reduce 436) (("<") reduce 436) ((">") reduce 436) (("?") reduce 436) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_BOOLEAN_AND) reduce 436) ((T_BOOLEAN_OR) reduce 436) ((T_COALESCE) reduce 436) ((T_INSTANCEOF) reduce 436) ((T_IS_EQUAL) reduce 436) ((T_IS_GREATER_OR_EQUAL) reduce 436) ((T_IS_IDENTICAL) reduce 436) ((T_IS_NOT_EQUAL) reduce 436) ((T_IS_NOT_IDENTICAL) reduce 436) ((T_IS_SMALLER_OR_EQUAL) reduce 436) ((T_LOGICAL_AND) reduce 436) ((T_LOGICAL_OR) reduce 436) ((T_LOGICAL_XOR) reduce 436) ((T_POW) shift) ((T_SL) reduce 436) ((T_SPACESHIP) reduce 436) ((T_SR) reduce 436) (("^") reduce 436) (("|") reduce 436)) 16160 ((("%") reduce 409) ((")") reduce 409) (("*") reduce 409) (("+") reduce 409) (("-") reduce 409) ((".") reduce 409) (("/") reduce 409) (("<") reduce 409) ((">") reduce 409) (("?") reduce 409) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_BOOLEAN_AND) reduce 409) ((T_BOOLEAN_OR) reduce 409) ((T_COALESCE) reduce 409) ((T_INSTANCEOF) reduce 409) ((T_IS_EQUAL) reduce 409) ((T_IS_GREATER_OR_EQUAL) reduce 409) ((T_IS_IDENTICAL) reduce 409) ((T_IS_NOT_EQUAL) reduce 409) ((T_IS_NOT_IDENTICAL) reduce 409) ((T_IS_SMALLER_OR_EQUAL) reduce 409) ((T_LOGICAL_AND) reduce 409) ((T_LOGICAL_OR) reduce 409) ((T_LOGICAL_XOR) reduce 409) ((T_POW) shift) ((T_SL) reduce 409) ((T_SPACESHIP) reduce 409) ((T_SR) reduce 409) (("^") reduce 409) (("|") reduce 409)) 16161 ((("%") reduce 408) ((")") reduce 408) (("*") reduce 408) (("+") reduce 408) (("-") reduce 408) ((".") reduce 408) (("/") reduce 408) (("<") reduce 408) ((">") reduce 408) (("?") reduce 408) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_BOOLEAN_AND) reduce 408) ((T_BOOLEAN_OR) reduce 408) ((T_COALESCE) reduce 408) ((T_INSTANCEOF) reduce 408) ((T_IS_EQUAL) reduce 408) ((T_IS_GREATER_OR_EQUAL) reduce 408) ((T_IS_IDENTICAL) reduce 408) ((T_IS_NOT_EQUAL) reduce 408) ((T_IS_NOT_IDENTICAL) reduce 408) ((T_IS_SMALLER_OR_EQUAL) reduce 408) ((T_LOGICAL_AND) reduce 408) ((T_LOGICAL_OR) reduce 408) ((T_LOGICAL_XOR) reduce 408) ((T_POW) shift) ((T_SL) reduce 408) ((T_SPACESHIP) reduce 408) ((T_SR) reduce 408) (("^") reduce 408) (("|") reduce 408)) 16163 ((("%") reduce 422) (("(") reduce 517) ((")") reduce 422) (("*") reduce 422) (("+") reduce 422) (("-") reduce 422) ((".") reduce 422) (("/") reduce 422) (("<") reduce 422) ((">") reduce 422) (("?") reduce 422) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_BOOLEAN_AND) reduce 422) ((T_BOOLEAN_OR) reduce 422) ((T_COALESCE) reduce 422) ((T_INSTANCEOF) reduce 422) ((T_IS_EQUAL) reduce 422) ((T_IS_GREATER_OR_EQUAL) reduce 422) ((T_IS_IDENTICAL) reduce 422) ((T_IS_NOT_EQUAL) reduce 422) ((T_IS_NOT_IDENTICAL) reduce 422) ((T_IS_SMALLER_OR_EQUAL) reduce 422) ((T_LOGICAL_AND) reduce 422) ((T_LOGICAL_OR) reduce 422) ((T_LOGICAL_XOR) reduce 422) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 511) ((T_OBJECT_OPERATOR) reduce 511) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 511) ((T_POW) reduce 422) ((T_SL) reduce 422) ((T_SPACESHIP) reduce 422) ((T_SR) reduce 422) (("[") reduce 511) (("^") reduce 422) (("{") reduce 511) (("|") reduce 422)) 16164 ((("%") reduce 531) (("(") reduce 531) ((")") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) (("=") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AND_EQUAL) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_COALESCE_EQUAL) reduce 531) ((T_CONCAT_EQUAL) reduce 531) ((T_DEC) reduce 531) ((T_DIV_EQUAL) reduce 531) ((T_INC) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_MINUS_EQUAL) reduce 531) ((T_MOD_EQUAL) reduce 531) ((T_MUL_EQUAL) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_OR_EQUAL) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_PLUS_EQUAL) reduce 531) ((T_POW) reduce 531) ((T_POW_EQUAL) reduce 531) ((T_SL) reduce 531) ((T_SL_EQUAL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) ((T_SR_EQUAL) reduce 531) ((T_XOR_EQUAL) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 16167 ((("%") reduce 530) (("(") reduce 530) ((")") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) (("=") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AND_EQUAL) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_COALESCE_EQUAL) reduce 530) ((T_CONCAT_EQUAL) reduce 530) ((T_DEC) reduce 530) ((T_DIV_EQUAL) reduce 530) ((T_INC) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_MINUS_EQUAL) reduce 530) ((T_MOD_EQUAL) reduce 530) ((T_MUL_EQUAL) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_OR_EQUAL) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_PLUS_EQUAL) reduce 530) ((T_POW) reduce 530) ((T_POW_EQUAL) reduce 530) ((T_SL) reduce 530) ((T_SL_EQUAL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) ((T_SR_EQUAL) reduce 530) ((T_XOR_EQUAL) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 16169 ((("%") reduce 485) (("(") reduce 485) ((")") reduce 485) (("*") reduce 485) (("+") reduce 485) (("-") reduce 485) ((".") reduce 485) (("/") reduce 485) (("<") reduce 485) ((">") reduce 485) (("?") reduce 485) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_BOOLEAN_AND) reduce 485) ((T_BOOLEAN_OR) reduce 485) ((T_COALESCE) reduce 485) ((T_INSTANCEOF) reduce 485) ((T_IS_EQUAL) reduce 485) ((T_IS_GREATER_OR_EQUAL) reduce 485) ((T_IS_IDENTICAL) reduce 485) ((T_IS_NOT_EQUAL) reduce 485) ((T_IS_NOT_IDENTICAL) reduce 485) ((T_IS_SMALLER_OR_EQUAL) reduce 485) ((T_LOGICAL_AND) reduce 485) ((T_LOGICAL_OR) reduce 485) ((T_LOGICAL_XOR) reduce 485) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 485) ((T_OBJECT_OPERATOR) reduce 485) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 485) ((T_POW) reduce 485) ((T_SL) reduce 485) ((T_SPACESHIP) reduce 485) ((T_SR) reduce 485) (("[") reduce 485) (("^") reduce 485) (("{") reduce 485) (("|") reduce 485)) 16170 ((("%") reduce 410) ((")") reduce 410) (("*") reduce 410) (("+") reduce 410) (("-") reduce 410) ((".") reduce 410) (("/") reduce 410) (("<") reduce 410) ((">") reduce 410) (("?") reduce 410) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_BOOLEAN_AND) reduce 410) ((T_BOOLEAN_OR) reduce 410) ((T_COALESCE) reduce 410) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 410) ((T_IS_GREATER_OR_EQUAL) reduce 410) ((T_IS_IDENTICAL) reduce 410) ((T_IS_NOT_EQUAL) reduce 410) ((T_IS_NOT_IDENTICAL) reduce 410) ((T_IS_SMALLER_OR_EQUAL) reduce 410) ((T_LOGICAL_AND) reduce 410) ((T_LOGICAL_OR) reduce 410) ((T_LOGICAL_XOR) reduce 410) ((T_POW) shift) ((T_SL) reduce 410) ((T_SPACESHIP) reduce 410) ((T_SR) reduce 410) (("^") reduce 410) (("|") reduce 410)) 16172 ((("!") reduce 164) (("\"") reduce 164) (("$") reduce 164) (("(") reduce 164) (("+") reduce 164) (("-") reduce 164) ((";") reduce 164) (("@") reduce 164) ((T_ABSTRACT) reduce 164) ((T_ARRAY) reduce 164) ((T_ARRAY_CAST) reduce 164) ((T_ATTRIBUTE) reduce 164) ((T_BOOL_CAST) reduce 164) ((T_BREAK) reduce 164) ((T_CLASS) reduce 164) ((T_CLASS_C) reduce 164) ((T_CLONE) reduce 164) ((T_CONSTANT_ENCAPSED_STRING) reduce 164) ((T_CONTINUE) reduce 164) ((T_DEC) reduce 164) ((T_DECLARE) reduce 164) ((T_DIR) reduce 164) ((T_DNUMBER) reduce 164) ((T_DO) reduce 164) ((T_DOUBLE_CAST) reduce 164) ((T_ECHO) reduce 164) ((T_ELSE) reduce 164) ((T_ELSEIF) reduce 164) ((T_EMPTY) reduce 164) ((T_ENUM) reduce 164) ((T_EVAL) reduce 164) ((T_EXIT) reduce 164) ((T_FILE) reduce 164) ((T_FINAL) reduce 164) ((T_FN) reduce 164) ((T_FOR) reduce 164) ((T_FOREACH) reduce 164) ((T_FUNCTION) reduce 164) ((T_FUNC_C) reduce 164) ((T_GLOBAL) reduce 164) ((T_GOTO) reduce 164) ((T_HALT_COMPILER) reduce 164) ((T_IF) reduce 164) ((T_INC) reduce 164) ((T_INCLUDE) reduce 164) ((T_INCLUDE_ONCE) reduce 164) ((T_INLINE_HTML) reduce 164) ((T_INTERFACE) reduce 164) ((T_INT_CAST) reduce 164) ((T_ISSET) reduce 164) ((T_LINE) reduce 164) ((T_LIST) reduce 164) ((T_LNUMBER) reduce 164) ((T_MATCH) reduce 164) ((T_METHOD_C) reduce 164) ((T_NAME_FULLY_QUALIFIED) reduce 164) ((T_NAME_QUALIFIED) reduce 164) ((T_NAME_RELATIVE) reduce 164) ((T_NEW) reduce 164) ((T_NS_C) reduce 164) ((T_OBJECT_CAST) reduce 164) ((T_PRINT) reduce 164) ((T_READONLY) reduce 164) ((T_REQUIRE) reduce 164) ((T_REQUIRE_ONCE) reduce 164) ((T_RETURN) reduce 164) ((T_START_HEREDOC) reduce 164) ((T_STATIC) reduce 164) ((T_STRING) reduce 164) ((T_STRING_CAST) reduce 164) ((T_SWITCH) reduce 164) ((T_THROW) reduce 164) ((T_TRAIT) reduce 164) ((T_TRAIT_C) reduce 164) ((T_TRY) reduce 164) ((T_UNSET) reduce 164) ((T_UNSET_CAST) reduce 164) ((T_VARIABLE) reduce 164) ((T_WHILE) reduce 164) ((T_YIELD) reduce 164) ((T_YIELD_FROM) reduce 164) (("[") reduce 164) (("`") reduce 164) (("{") reduce 164) (("}") reduce 164) (("~") reduce 164)) 16182 ((("!") reduce 158) (("\"") reduce 158) (("$") reduce 158) (("(") reduce 158) (("+") reduce 158) (("-") reduce 158) ((";") reduce 158) (("@") reduce 158) ((T_ABSTRACT) reduce 158) ((T_ARRAY) reduce 158) ((T_ARRAY_CAST) reduce 158) ((T_ATTRIBUTE) reduce 158) ((T_BOOL_CAST) reduce 158) ((T_BREAK) reduce 158) ((T_CLASS) reduce 158) ((T_CLASS_C) reduce 158) ((T_CLONE) reduce 158) ((T_CONSTANT_ENCAPSED_STRING) reduce 158) ((T_CONTINUE) reduce 158) ((T_DEC) reduce 158) ((T_DECLARE) reduce 158) ((T_DIR) reduce 158) ((T_DNUMBER) reduce 158) ((T_DO) reduce 158) ((T_DOUBLE_CAST) reduce 158) ((T_ECHO) reduce 158) ((T_ELSE) reduce 158) ((T_ELSEIF) reduce 158) ((T_EMPTY) reduce 158) ((T_ENUM) reduce 158) ((T_EVAL) reduce 158) ((T_EXIT) reduce 158) ((T_FILE) reduce 158) ((T_FINAL) reduce 158) ((T_FN) reduce 158) ((T_FOR) reduce 158) ((T_FOREACH) reduce 158) ((T_FUNCTION) reduce 158) ((T_FUNC_C) reduce 158) ((T_GLOBAL) reduce 158) ((T_GOTO) reduce 158) ((T_HALT_COMPILER) reduce 158) ((T_IF) reduce 158) ((T_INC) reduce 158) ((T_INCLUDE) reduce 158) ((T_INCLUDE_ONCE) reduce 158) ((T_INLINE_HTML) reduce 158) ((T_INTERFACE) reduce 158) ((T_INT_CAST) reduce 158) ((T_ISSET) reduce 158) ((T_LINE) reduce 158) ((T_LIST) reduce 158) ((T_LNUMBER) reduce 158) ((T_MATCH) reduce 158) ((T_METHOD_C) reduce 158) ((T_NAME_FULLY_QUALIFIED) reduce 158) ((T_NAME_QUALIFIED) reduce 158) ((T_NAME_RELATIVE) reduce 158) ((T_NEW) reduce 158) ((T_NS_C) reduce 158) ((T_OBJECT_CAST) reduce 158) ((T_PRINT) reduce 158) ((T_READONLY) reduce 158) ((T_REQUIRE) reduce 158) ((T_REQUIRE_ONCE) reduce 158) ((T_RETURN) reduce 158) ((T_START_HEREDOC) reduce 158) ((T_STATIC) reduce 158) ((T_STRING) reduce 158) ((T_STRING_CAST) reduce 158) ((T_SWITCH) reduce 158) ((T_THROW) reduce 158) ((T_TRAIT) reduce 158) ((T_TRAIT_C) reduce 158) ((T_TRY) reduce 158) ((T_UNSET) reduce 158) ((T_UNSET_CAST) reduce 158) ((T_VARIABLE) reduce 158) ((T_WHILE) reduce 158) ((T_YIELD) reduce 158) ((T_YIELD_FROM) reduce 158) (("[") reduce 158) (("`") reduce 158) (("{") reduce 158) (("}") reduce 158) (("~") reduce 158)) 16190 ((("!") reduce 147) (("\"") reduce 147) (("$") reduce 147) (("(") reduce 147) (("+") reduce 147) (("-") reduce 147) ((";") reduce 147) (("@") reduce 147) ((T_ABSTRACT) reduce 147) ((T_ARRAY) reduce 147) ((T_ARRAY_CAST) reduce 147) ((T_ATTRIBUTE) reduce 147) ((T_BOOL_CAST) reduce 147) ((T_BREAK) reduce 147) ((T_CLASS) reduce 147) ((T_CLASS_C) reduce 147) ((T_CLONE) reduce 147) ((T_CONSTANT_ENCAPSED_STRING) reduce 147) ((T_CONTINUE) reduce 147) ((T_DEC) reduce 147) ((T_DECLARE) reduce 147) ((T_DIR) reduce 147) ((T_DNUMBER) reduce 147) ((T_DO) reduce 147) ((T_DOUBLE_CAST) reduce 147) ((T_ECHO) reduce 147) ((T_ELSE) reduce 147) ((T_ELSEIF) reduce 147) ((T_EMPTY) reduce 147) ((T_ENUM) reduce 147) ((T_EVAL) reduce 147) ((T_EXIT) reduce 147) ((T_FILE) reduce 147) ((T_FINAL) reduce 147) ((T_FN) reduce 147) ((T_FOR) reduce 147) ((T_FOREACH) reduce 147) ((T_FUNCTION) reduce 147) ((T_FUNC_C) reduce 147) ((T_GLOBAL) reduce 147) ((T_GOTO) reduce 147) ((T_HALT_COMPILER) reduce 147) ((T_IF) reduce 147) ((T_INC) reduce 147) ((T_INCLUDE) reduce 147) ((T_INCLUDE_ONCE) reduce 147) ((T_INLINE_HTML) reduce 147) ((T_INTERFACE) reduce 147) ((T_INT_CAST) reduce 147) ((T_ISSET) reduce 147) ((T_LINE) reduce 147) ((T_LIST) reduce 147) ((T_LNUMBER) reduce 147) ((T_MATCH) reduce 147) ((T_METHOD_C) reduce 147) ((T_NAME_FULLY_QUALIFIED) reduce 147) ((T_NAME_QUALIFIED) reduce 147) ((T_NAME_RELATIVE) reduce 147) ((T_NEW) reduce 147) ((T_NS_C) reduce 147) ((T_OBJECT_CAST) reduce 147) ((T_PRINT) reduce 147) ((T_READONLY) reduce 147) ((T_REQUIRE) reduce 147) ((T_REQUIRE_ONCE) reduce 147) ((T_RETURN) reduce 147) ((T_START_HEREDOC) reduce 147) ((T_STATIC) reduce 147) ((T_STRING) reduce 147) ((T_STRING_CAST) reduce 147) ((T_SWITCH) reduce 147) ((T_THROW) reduce 147) ((T_TRAIT) reduce 147) ((T_TRAIT_C) reduce 147) ((T_TRY) reduce 147) ((T_UNSET) reduce 147) ((T_UNSET_CAST) reduce 147) ((T_VARIABLE) reduce 147) ((T_WHILE) reduce 147) ((T_YIELD) reduce 147) ((T_YIELD_FROM) reduce 147) (("[") reduce 147) (("`") reduce 147) (("{") reduce 147) (("}") reduce 147) (("~") reduce 147)) 16193 ((("!") reduce 146) (("\"") reduce 146) (("$") reduce 146) (("(") reduce 146) (("+") reduce 146) (("-") reduce 146) ((";") reduce 146) (("@") reduce 146) ((T_ABSTRACT) reduce 146) ((T_ARRAY) reduce 146) ((T_ARRAY_CAST) reduce 146) ((T_ATTRIBUTE) reduce 146) ((T_BOOL_CAST) reduce 146) ((T_BREAK) reduce 146) ((T_CLASS) reduce 146) ((T_CLASS_C) reduce 146) ((T_CLONE) reduce 146) ((T_CONSTANT_ENCAPSED_STRING) reduce 146) ((T_CONTINUE) reduce 146) ((T_DEC) reduce 146) ((T_DECLARE) reduce 146) ((T_DIR) reduce 146) ((T_DNUMBER) reduce 146) ((T_DO) reduce 146) ((T_DOUBLE_CAST) reduce 146) ((T_ECHO) reduce 146) ((T_ELSE) reduce 146) ((T_ELSEIF) reduce 146) ((T_EMPTY) reduce 146) ((T_ENUM) reduce 146) ((T_EVAL) reduce 146) ((T_EXIT) reduce 146) ((T_FILE) reduce 146) ((T_FINAL) reduce 146) ((T_FN) reduce 146) ((T_FOR) reduce 146) ((T_FOREACH) reduce 146) ((T_FUNCTION) reduce 146) ((T_FUNC_C) reduce 146) ((T_GLOBAL) reduce 146) ((T_GOTO) reduce 146) ((T_HALT_COMPILER) reduce 146) ((T_IF) reduce 146) ((T_INC) reduce 146) ((T_INCLUDE) reduce 146) ((T_INCLUDE_ONCE) reduce 146) ((T_INLINE_HTML) reduce 146) ((T_INTERFACE) reduce 146) ((T_INT_CAST) reduce 146) ((T_ISSET) reduce 146) ((T_LINE) reduce 146) ((T_LIST) reduce 146) ((T_LNUMBER) reduce 146) ((T_MATCH) reduce 146) ((T_METHOD_C) reduce 146) ((T_NAME_FULLY_QUALIFIED) reduce 146) ((T_NAME_QUALIFIED) reduce 146) ((T_NAME_RELATIVE) reduce 146) ((T_NEW) reduce 146) ((T_NS_C) reduce 146) ((T_OBJECT_CAST) reduce 146) ((T_PRINT) reduce 146) ((T_READONLY) reduce 146) ((T_REQUIRE) reduce 146) ((T_REQUIRE_ONCE) reduce 146) ((T_RETURN) reduce 146) ((T_START_HEREDOC) reduce 146) ((T_STATIC) reduce 146) ((T_STRING) reduce 146) ((T_STRING_CAST) reduce 146) ((T_SWITCH) reduce 146) ((T_THROW) reduce 146) ((T_TRAIT) reduce 146) ((T_TRAIT_C) reduce 146) ((T_TRY) reduce 146) ((T_UNSET) reduce 146) ((T_UNSET_CAST) reduce 146) ((T_VARIABLE) reduce 146) ((T_WHILE) reduce 146) ((T_YIELD) reduce 146) ((T_YIELD_FROM) reduce 146) (("[") reduce 146) (("`") reduce 146) (("{") reduce 146) (("}") reduce 146) (("~") reduce 146)) 16195 ((("!") reduce 242) (("\"") reduce 242) (("$") reduce 242) (("(") reduce 242) (("+") reduce 242) (("-") reduce 242) ((";") reduce 242) (("@") reduce 242) ((T_ABSTRACT) reduce 242) ((T_ARRAY) reduce 242) ((T_ARRAY_CAST) reduce 242) ((T_ATTRIBUTE) reduce 242) ((T_BOOL_CAST) reduce 242) ((T_BREAK) reduce 242) ((T_CLASS) reduce 242) ((T_CLASS_C) reduce 242) ((T_CLONE) reduce 242) ((T_CONSTANT_ENCAPSED_STRING) reduce 242) ((T_CONTINUE) reduce 242) ((T_DEC) reduce 242) ((T_DECLARE) reduce 242) ((T_DIR) reduce 242) ((T_DNUMBER) reduce 242) ((T_DO) reduce 242) ((T_DOUBLE_CAST) reduce 242) ((T_ECHO) reduce 242) ((T_ELSE) reduce 242) ((T_ELSEIF) reduce 242) ((T_EMPTY) reduce 242) ((T_ENUM) reduce 242) ((T_EVAL) reduce 242) ((T_EXIT) reduce 242) ((T_FILE) reduce 242) ((T_FINAL) reduce 242) ((T_FN) reduce 242) ((T_FOR) reduce 242) ((T_FOREACH) reduce 242) ((T_FUNCTION) reduce 242) ((T_FUNC_C) reduce 242) ((T_GLOBAL) reduce 242) ((T_GOTO) reduce 242) ((T_HALT_COMPILER) reduce 242) ((T_IF) reduce 242) ((T_INC) reduce 242) ((T_INCLUDE) reduce 242) ((T_INCLUDE_ONCE) reduce 242) ((T_INLINE_HTML) reduce 242) ((T_INTERFACE) reduce 242) ((T_INT_CAST) reduce 242) ((T_ISSET) reduce 242) ((T_LINE) reduce 242) ((T_LIST) reduce 242) ((T_LNUMBER) reduce 242) ((T_MATCH) reduce 242) ((T_METHOD_C) reduce 242) ((T_NAME_FULLY_QUALIFIED) reduce 242) ((T_NAME_QUALIFIED) reduce 242) ((T_NAME_RELATIVE) reduce 242) ((T_NEW) reduce 242) ((T_NS_C) reduce 242) ((T_OBJECT_CAST) reduce 242) ((T_PRINT) reduce 242) ((T_READONLY) reduce 242) ((T_REQUIRE) reduce 242) ((T_REQUIRE_ONCE) reduce 242) ((T_RETURN) reduce 242) ((T_START_HEREDOC) reduce 242) ((T_STATIC) reduce 242) ((T_STRING) reduce 242) ((T_STRING_CAST) reduce 242) ((T_SWITCH) reduce 242) ((T_THROW) reduce 242) ((T_TRAIT) reduce 242) ((T_TRAIT_C) reduce 242) ((T_TRY) reduce 242) ((T_UNSET) reduce 242) ((T_UNSET_CAST) reduce 242) ((T_VARIABLE) reduce 242) ((T_WHILE) reduce 242) ((T_YIELD) reduce 242) ((T_YIELD_FROM) reduce 242) (("[") reduce 242) (("`") reduce 242) (("{") reduce 242) (("}") reduce 242) (("~") reduce 242)) 16198 ((("!") reduce 145) (("\"") reduce 145) (("$") reduce 145) (("(") reduce 145) (("+") reduce 145) (("-") reduce 145) ((";") reduce 145) (("@") reduce 145) ((T_ABSTRACT) reduce 145) ((T_ARRAY) reduce 145) ((T_ARRAY_CAST) reduce 145) ((T_ATTRIBUTE) reduce 145) ((T_BOOL_CAST) reduce 145) ((T_BREAK) reduce 145) ((T_CLASS) reduce 145) ((T_CLASS_C) reduce 145) ((T_CLONE) reduce 145) ((T_CONSTANT_ENCAPSED_STRING) reduce 145) ((T_CONTINUE) reduce 145) ((T_DEC) reduce 145) ((T_DECLARE) reduce 145) ((T_DIR) reduce 145) ((T_DNUMBER) reduce 145) ((T_DO) reduce 145) ((T_DOUBLE_CAST) reduce 145) ((T_ECHO) reduce 145) ((T_ELSE) reduce 145) ((T_ELSEIF) reduce 145) ((T_EMPTY) reduce 145) ((T_ENUM) reduce 145) ((T_EVAL) reduce 145) ((T_EXIT) reduce 145) ((T_FILE) reduce 145) ((T_FINAL) reduce 145) ((T_FN) reduce 145) ((T_FOR) reduce 145) ((T_FOREACH) reduce 145) ((T_FUNCTION) reduce 145) ((T_FUNC_C) reduce 145) ((T_GLOBAL) reduce 145) ((T_GOTO) reduce 145) ((T_HALT_COMPILER) reduce 145) ((T_IF) reduce 145) ((T_INC) reduce 145) ((T_INCLUDE) reduce 145) ((T_INCLUDE_ONCE) reduce 145) ((T_INLINE_HTML) reduce 145) ((T_INTERFACE) reduce 145) ((T_INT_CAST) reduce 145) ((T_ISSET) reduce 145) ((T_LINE) reduce 145) ((T_LIST) reduce 145) ((T_LNUMBER) reduce 145) ((T_MATCH) reduce 145) ((T_METHOD_C) reduce 145) ((T_NAME_FULLY_QUALIFIED) reduce 145) ((T_NAME_QUALIFIED) reduce 145) ((T_NAME_RELATIVE) reduce 145) ((T_NEW) reduce 145) ((T_NS_C) reduce 145) ((T_OBJECT_CAST) reduce 145) ((T_PRINT) reduce 145) ((T_READONLY) reduce 145) ((T_REQUIRE) reduce 145) ((T_REQUIRE_ONCE) reduce 145) ((T_RETURN) reduce 145) ((T_START_HEREDOC) reduce 145) ((T_STATIC) reduce 145) ((T_STRING) reduce 145) ((T_STRING_CAST) reduce 145) ((T_SWITCH) reduce 145) ((T_THROW) reduce 145) ((T_TRAIT) reduce 145) ((T_TRAIT_C) reduce 145) ((T_TRY) reduce 145) ((T_UNSET) reduce 145) ((T_UNSET_CAST) reduce 145) ((T_VARIABLE) reduce 145) ((T_WHILE) reduce 145) ((T_YIELD) reduce 145) ((T_YIELD_FROM) reduce 145) (("[") reduce 145) (("`") reduce 145) (("{") reduce 145) (("}") reduce 145) (("~") reduce 145)) 16200 ((("!") reduce 244) (("\"") reduce 244) (("$") reduce 244) (("(") reduce 244) (("+") reduce 244) (("-") reduce 244) ((";") reduce 244) (("@") reduce 244) ((T_ABSTRACT) reduce 244) ((T_ARRAY) reduce 244) ((T_ARRAY_CAST) reduce 244) ((T_ATTRIBUTE) reduce 244) ((T_BOOL_CAST) reduce 244) ((T_BREAK) reduce 244) ((T_CLASS) reduce 244) ((T_CLASS_C) reduce 244) ((T_CLONE) reduce 244) ((T_CONSTANT_ENCAPSED_STRING) reduce 244) ((T_CONTINUE) reduce 244) ((T_DEC) reduce 244) ((T_DECLARE) reduce 244) ((T_DIR) reduce 244) ((T_DNUMBER) reduce 244) ((T_DO) reduce 244) ((T_DOUBLE_CAST) reduce 244) ((T_ECHO) reduce 244) ((T_ELSE) reduce 244) ((T_ELSEIF) reduce 244) ((T_EMPTY) reduce 244) ((T_ENUM) reduce 244) ((T_EVAL) reduce 244) ((T_EXIT) reduce 244) ((T_FILE) reduce 244) ((T_FINAL) reduce 244) ((T_FN) reduce 244) ((T_FOR) reduce 244) ((T_FOREACH) reduce 244) ((T_FUNCTION) reduce 244) ((T_FUNC_C) reduce 244) ((T_GLOBAL) reduce 244) ((T_GOTO) reduce 244) ((T_HALT_COMPILER) reduce 244) ((T_IF) reduce 244) ((T_INC) reduce 244) ((T_INCLUDE) reduce 244) ((T_INCLUDE_ONCE) reduce 244) ((T_INLINE_HTML) reduce 244) ((T_INTERFACE) reduce 244) ((T_INT_CAST) reduce 244) ((T_ISSET) reduce 244) ((T_LINE) reduce 244) ((T_LIST) reduce 244) ((T_LNUMBER) reduce 244) ((T_MATCH) reduce 244) ((T_METHOD_C) reduce 244) ((T_NAME_FULLY_QUALIFIED) reduce 244) ((T_NAME_QUALIFIED) reduce 244) ((T_NAME_RELATIVE) reduce 244) ((T_NEW) reduce 244) ((T_NS_C) reduce 244) ((T_OBJECT_CAST) reduce 244) ((T_PRINT) reduce 244) ((T_READONLY) reduce 244) ((T_REQUIRE) reduce 244) ((T_REQUIRE_ONCE) reduce 244) ((T_RETURN) reduce 244) ((T_START_HEREDOC) reduce 244) ((T_STATIC) reduce 244) ((T_STRING) reduce 244) ((T_STRING_CAST) reduce 244) ((T_SWITCH) reduce 244) ((T_THROW) reduce 244) ((T_TRAIT) reduce 244) ((T_TRAIT_C) reduce 244) ((T_TRY) reduce 244) ((T_UNSET) reduce 244) ((T_UNSET_CAST) reduce 244) ((T_VARIABLE) reduce 244) ((T_WHILE) reduce 244) ((T_YIELD) reduce 244) ((T_YIELD_FROM) reduce 244) (("[") reduce 244) (("`") reduce 244) (("{") reduce 244) (("}") reduce 244) (("~") reduce 244)) 16201 ((("!") reduce 159) (("\"") reduce 159) (("$") reduce 159) (("(") reduce 159) (("+") reduce 159) (("-") reduce 159) ((";") reduce 159) (("@") reduce 159) ((T_ABSTRACT) reduce 159) ((T_ARRAY) reduce 159) ((T_ARRAY_CAST) reduce 159) ((T_ATTRIBUTE) reduce 159) ((T_BOOL_CAST) reduce 159) ((T_BREAK) reduce 159) ((T_CLASS) reduce 159) ((T_CLASS_C) reduce 159) ((T_CLONE) reduce 159) ((T_CONSTANT_ENCAPSED_STRING) reduce 159) ((T_CONTINUE) reduce 159) ((T_DEC) reduce 159) ((T_DECLARE) reduce 159) ((T_DIR) reduce 159) ((T_DNUMBER) reduce 159) ((T_DO) reduce 159) ((T_DOUBLE_CAST) reduce 159) ((T_ECHO) reduce 159) ((T_ELSE) reduce 159) ((T_ELSEIF) reduce 159) ((T_EMPTY) reduce 159) ((T_ENUM) reduce 159) ((T_EVAL) reduce 159) ((T_EXIT) reduce 159) ((T_FILE) reduce 159) ((T_FINAL) reduce 159) ((T_FN) reduce 159) ((T_FOR) reduce 159) ((T_FOREACH) reduce 159) ((T_FUNCTION) reduce 159) ((T_FUNC_C) reduce 159) ((T_GLOBAL) reduce 159) ((T_GOTO) reduce 159) ((T_HALT_COMPILER) reduce 159) ((T_IF) reduce 159) ((T_INC) reduce 159) ((T_INCLUDE) reduce 159) ((T_INCLUDE_ONCE) reduce 159) ((T_INLINE_HTML) reduce 159) ((T_INTERFACE) reduce 159) ((T_INT_CAST) reduce 159) ((T_ISSET) reduce 159) ((T_LINE) reduce 159) ((T_LIST) reduce 159) ((T_LNUMBER) reduce 159) ((T_MATCH) reduce 159) ((T_METHOD_C) reduce 159) ((T_NAME_FULLY_QUALIFIED) reduce 159) ((T_NAME_QUALIFIED) reduce 159) ((T_NAME_RELATIVE) reduce 159) ((T_NEW) reduce 159) ((T_NS_C) reduce 159) ((T_OBJECT_CAST) reduce 159) ((T_PRINT) reduce 159) ((T_READONLY) reduce 159) ((T_REQUIRE) reduce 159) ((T_REQUIRE_ONCE) reduce 159) ((T_RETURN) reduce 159) ((T_START_HEREDOC) reduce 159) ((T_STATIC) reduce 159) ((T_STRING) reduce 159) ((T_STRING_CAST) reduce 159) ((T_SWITCH) reduce 159) ((T_THROW) reduce 159) ((T_TRAIT) reduce 159) ((T_TRAIT_C) reduce 159) ((T_TRY) reduce 159) ((T_UNSET) reduce 159) ((T_UNSET_CAST) reduce 159) ((T_VARIABLE) reduce 159) ((T_WHILE) reduce 159) ((T_YIELD) reduce 159) ((T_YIELD_FROM) reduce 159) (("[") reduce 159) (("`") reduce 159) (("{") reduce 159) (("}") reduce 159) (("~") reduce 159)) 16205 ((("!") reduce 247) (("\"") reduce 247) (("$") reduce 247) (("(") reduce 247) (("+") reduce 247) (("-") reduce 247) ((";") reduce 247) (("@") reduce 247) ((T_ABSTRACT) reduce 247) ((T_ARRAY) reduce 247) ((T_ARRAY_CAST) reduce 247) ((T_ATTRIBUTE) reduce 247) ((T_BOOL_CAST) reduce 247) ((T_BREAK) reduce 247) ((T_CLASS) reduce 247) ((T_CLASS_C) reduce 247) ((T_CLONE) reduce 247) ((T_CONSTANT_ENCAPSED_STRING) reduce 247) ((T_CONTINUE) reduce 247) ((T_DEC) reduce 247) ((T_DECLARE) reduce 247) ((T_DIR) reduce 247) ((T_DNUMBER) reduce 247) ((T_DO) reduce 247) ((T_DOUBLE_CAST) reduce 247) ((T_ECHO) reduce 247) ((T_ELSE) reduce 247) ((T_ELSEIF) reduce 247) ((T_EMPTY) reduce 247) ((T_ENUM) reduce 247) ((T_EVAL) reduce 247) ((T_EXIT) reduce 247) ((T_FILE) reduce 247) ((T_FINAL) reduce 247) ((T_FN) reduce 247) ((T_FOR) reduce 247) ((T_FOREACH) reduce 247) ((T_FUNCTION) reduce 247) ((T_FUNC_C) reduce 247) ((T_GLOBAL) reduce 247) ((T_GOTO) reduce 247) ((T_HALT_COMPILER) reduce 247) ((T_IF) reduce 247) ((T_INC) reduce 247) ((T_INCLUDE) reduce 247) ((T_INCLUDE_ONCE) reduce 247) ((T_INLINE_HTML) reduce 247) ((T_INTERFACE) reduce 247) ((T_INT_CAST) reduce 247) ((T_ISSET) reduce 247) ((T_LINE) reduce 247) ((T_LIST) reduce 247) ((T_LNUMBER) reduce 247) ((T_MATCH) reduce 247) ((T_METHOD_C) reduce 247) ((T_NAME_FULLY_QUALIFIED) reduce 247) ((T_NAME_QUALIFIED) reduce 247) ((T_NAME_RELATIVE) reduce 247) ((T_NEW) reduce 247) ((T_NS_C) reduce 247) ((T_OBJECT_CAST) reduce 247) ((T_PRINT) reduce 247) ((T_READONLY) reduce 247) ((T_REQUIRE) reduce 247) ((T_REQUIRE_ONCE) reduce 247) ((T_RETURN) reduce 247) ((T_START_HEREDOC) reduce 247) ((T_STATIC) reduce 247) ((T_STRING) reduce 247) ((T_STRING_CAST) reduce 247) ((T_SWITCH) reduce 247) ((T_THROW) reduce 247) ((T_TRAIT) reduce 247) ((T_TRAIT_C) reduce 247) ((T_TRY) reduce 247) ((T_UNSET) reduce 247) ((T_UNSET_CAST) reduce 247) ((T_VARIABLE) reduce 247) ((T_WHILE) reduce 247) ((T_YIELD) reduce 247) ((T_YIELD_FROM) reduce 247) (("[") reduce 247) (("`") reduce 247) (("{") reduce 247) (("}") reduce 247) (("~") reduce 247)) 16209 ((("!") reduce 140) (("\"") reduce 140) (("$") reduce 140) (("(") reduce 140) (("+") reduce 140) (("-") reduce 140) ((";") reduce 140) (("@") reduce 140) ((T_ABSTRACT) reduce 140) ((T_ARRAY) reduce 140) ((T_ARRAY_CAST) reduce 140) ((T_ATTRIBUTE) reduce 140) ((T_BOOL_CAST) reduce 140) ((T_BREAK) reduce 140) ((T_CLASS) reduce 140) ((T_CLASS_C) reduce 140) ((T_CLONE) reduce 140) ((T_CONSTANT_ENCAPSED_STRING) reduce 140) ((T_CONTINUE) reduce 140) ((T_DEC) reduce 140) ((T_DECLARE) reduce 140) ((T_DIR) reduce 140) ((T_DNUMBER) reduce 140) ((T_DO) reduce 140) ((T_DOUBLE_CAST) reduce 140) ((T_ECHO) reduce 140) ((T_ELSE) reduce 140) ((T_ELSEIF) reduce 140) ((T_EMPTY) reduce 140) ((T_ENDIF) reduce 140) ((T_ENUM) reduce 140) ((T_EVAL) reduce 140) ((T_EXIT) reduce 140) ((T_FILE) reduce 140) ((T_FINAL) reduce 140) ((T_FN) reduce 140) ((T_FOR) reduce 140) ((T_FOREACH) reduce 140) ((T_FUNCTION) reduce 140) ((T_FUNC_C) reduce 140) ((T_GLOBAL) reduce 140) ((T_GOTO) reduce 140) ((T_HALT_COMPILER) reduce 140) ((T_IF) reduce 140) ((T_INC) reduce 140) ((T_INCLUDE) reduce 140) ((T_INCLUDE_ONCE) reduce 140) ((T_INLINE_HTML) reduce 140) ((T_INTERFACE) reduce 140) ((T_INT_CAST) reduce 140) ((T_ISSET) reduce 140) ((T_LINE) reduce 140) ((T_LIST) reduce 140) ((T_LNUMBER) reduce 140) ((T_MATCH) reduce 140) ((T_METHOD_C) reduce 140) ((T_NAME_FULLY_QUALIFIED) reduce 140) ((T_NAME_QUALIFIED) reduce 140) ((T_NAME_RELATIVE) reduce 140) ((T_NEW) reduce 140) ((T_NS_C) reduce 140) ((T_OBJECT_CAST) reduce 140) ((T_PRINT) reduce 140) ((T_READONLY) reduce 140) ((T_REQUIRE) reduce 140) ((T_REQUIRE_ONCE) reduce 140) ((T_RETURN) reduce 140) ((T_START_HEREDOC) reduce 140) ((T_STATIC) reduce 140) ((T_STRING) reduce 140) ((T_STRING_CAST) reduce 140) ((T_SWITCH) reduce 140) ((T_THROW) reduce 140) ((T_TRAIT) reduce 140) ((T_TRAIT_C) reduce 140) ((T_TRY) reduce 140) ((T_UNSET) reduce 140) ((T_UNSET_CAST) reduce 140) ((T_VARIABLE) reduce 140) ((T_WHILE) reduce 140) ((T_YIELD) reduce 140) ((T_YIELD_FROM) reduce 140) (("[") reduce 140) (("`") reduce 140) (("{") reduce 140) (("~") reduce 140)) 16210 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) (("+") shift) (("-") shift) ((";") shift) (("@") shift) ((T_ABSTRACT) shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_BREAK) shift) ((T_CLASS) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_CONTINUE) shift) ((T_DEC) shift) ((T_DECLARE) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DO) shift) ((T_DOUBLE_CAST) shift) ((T_ECHO) shift) ((T_ELSE) reduce 246) ((T_ELSEIF) reduce 246) ((T_EMPTY) shift) ((T_ENDIF) reduce 246) ((T_ENUM) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FINAL) shift) ((T_FN) shift) ((T_FOR) shift) ((T_FOREACH) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_GLOBAL) shift) ((T_GOTO) shift) ((T_HALT_COMPILER) shift) ((T_IF) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INLINE_HTML) shift) ((T_INTERFACE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_RETURN) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_SWITCH) shift) ((T_THROW) shift) ((T_TRAIT) shift) ((T_TRAIT_C) shift) ((T_TRY) shift) ((T_UNSET) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_WHILE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("{") shift) (("~") shift)) 16211 ((("!") reduce 164) (("\"") reduce 164) (("$") reduce 164) (("(") reduce 164) (("+") reduce 164) (("-") reduce 164) ((";") reduce 164) (("@") reduce 164) ((T_ABSTRACT) reduce 164) ((T_ARRAY) reduce 164) ((T_ARRAY_CAST) reduce 164) ((T_ATTRIBUTE) reduce 164) ((T_BOOL_CAST) reduce 164) ((T_BREAK) reduce 164) ((T_CLASS) reduce 164) ((T_CLASS_C) reduce 164) ((T_CLONE) reduce 164) ((T_CONSTANT_ENCAPSED_STRING) reduce 164) ((T_CONTINUE) reduce 164) ((T_DEC) reduce 164) ((T_DECLARE) reduce 164) ((T_DIR) reduce 164) ((T_DNUMBER) reduce 164) ((T_DO) reduce 164) ((T_DOUBLE_CAST) reduce 164) ((T_ECHO) reduce 164) ((T_ELSE) reduce 164) ((T_ELSEIF) reduce 164) ((T_EMPTY) reduce 164) ((T_ENDIF) reduce 164) ((T_ENUM) reduce 164) ((T_EVAL) reduce 164) ((T_EXIT) reduce 164) ((T_FILE) reduce 164) ((T_FINAL) reduce 164) ((T_FN) reduce 164) ((T_FOR) reduce 164) ((T_FOREACH) reduce 164) ((T_FUNCTION) reduce 164) ((T_FUNC_C) reduce 164) ((T_GLOBAL) reduce 164) ((T_GOTO) reduce 164) ((T_HALT_COMPILER) reduce 164) ((T_IF) reduce 164) ((T_INC) reduce 164) ((T_INCLUDE) reduce 164) ((T_INCLUDE_ONCE) reduce 164) ((T_INLINE_HTML) reduce 164) ((T_INTERFACE) reduce 164) ((T_INT_CAST) reduce 164) ((T_ISSET) reduce 164) ((T_LINE) reduce 164) ((T_LIST) reduce 164) ((T_LNUMBER) reduce 164) ((T_MATCH) reduce 164) ((T_METHOD_C) reduce 164) ((T_NAME_FULLY_QUALIFIED) reduce 164) ((T_NAME_QUALIFIED) reduce 164) ((T_NAME_RELATIVE) reduce 164) ((T_NEW) reduce 164) ((T_NS_C) reduce 164) ((T_OBJECT_CAST) reduce 164) ((T_PRINT) reduce 164) ((T_READONLY) reduce 164) ((T_REQUIRE) reduce 164) ((T_REQUIRE_ONCE) reduce 164) ((T_RETURN) reduce 164) ((T_START_HEREDOC) reduce 164) ((T_STATIC) reduce 164) ((T_STRING) reduce 164) ((T_STRING_CAST) reduce 164) ((T_SWITCH) reduce 164) ((T_THROW) reduce 164) ((T_TRAIT) reduce 164) ((T_TRAIT_C) reduce 164) ((T_TRY) reduce 164) ((T_UNSET) reduce 164) ((T_UNSET_CAST) reduce 164) ((T_VARIABLE) reduce 164) ((T_WHILE) reduce 164) ((T_YIELD) reduce 164) ((T_YIELD_FROM) reduce 164) (("[") reduce 164) (("`") reduce 164) (("{") reduce 164) (("~") reduce 164)) 16225 ((("!") reduce 158) (("\"") reduce 158) (("$") reduce 158) (("(") reduce 158) (("+") reduce 158) (("-") reduce 158) ((";") reduce 158) (("@") reduce 158) ((T_ABSTRACT) reduce 158) ((T_ARRAY) reduce 158) ((T_ARRAY_CAST) reduce 158) ((T_ATTRIBUTE) reduce 158) ((T_BOOL_CAST) reduce 158) ((T_BREAK) reduce 158) ((T_CLASS) reduce 158) ((T_CLASS_C) reduce 158) ((T_CLONE) reduce 158) ((T_CONSTANT_ENCAPSED_STRING) reduce 158) ((T_CONTINUE) reduce 158) ((T_DEC) reduce 158) ((T_DECLARE) reduce 158) ((T_DIR) reduce 158) ((T_DNUMBER) reduce 158) ((T_DO) reduce 158) ((T_DOUBLE_CAST) reduce 158) ((T_ECHO) reduce 158) ((T_ELSE) reduce 158) ((T_ELSEIF) reduce 158) ((T_EMPTY) reduce 158) ((T_ENDIF) reduce 158) ((T_ENUM) reduce 158) ((T_EVAL) reduce 158) ((T_EXIT) reduce 158) ((T_FILE) reduce 158) ((T_FINAL) reduce 158) ((T_FN) reduce 158) ((T_FOR) reduce 158) ((T_FOREACH) reduce 158) ((T_FUNCTION) reduce 158) ((T_FUNC_C) reduce 158) ((T_GLOBAL) reduce 158) ((T_GOTO) reduce 158) ((T_HALT_COMPILER) reduce 158) ((T_IF) reduce 158) ((T_INC) reduce 158) ((T_INCLUDE) reduce 158) ((T_INCLUDE_ONCE) reduce 158) ((T_INLINE_HTML) reduce 158) ((T_INTERFACE) reduce 158) ((T_INT_CAST) reduce 158) ((T_ISSET) reduce 158) ((T_LINE) reduce 158) ((T_LIST) reduce 158) ((T_LNUMBER) reduce 158) ((T_MATCH) reduce 158) ((T_METHOD_C) reduce 158) ((T_NAME_FULLY_QUALIFIED) reduce 158) ((T_NAME_QUALIFIED) reduce 158) ((T_NAME_RELATIVE) reduce 158) ((T_NEW) reduce 158) ((T_NS_C) reduce 158) ((T_OBJECT_CAST) reduce 158) ((T_PRINT) reduce 158) ((T_READONLY) reduce 158) ((T_REQUIRE) reduce 158) ((T_REQUIRE_ONCE) reduce 158) ((T_RETURN) reduce 158) ((T_START_HEREDOC) reduce 158) ((T_STATIC) reduce 158) ((T_STRING) reduce 158) ((T_STRING_CAST) reduce 158) ((T_SWITCH) reduce 158) ((T_THROW) reduce 158) ((T_TRAIT) reduce 158) ((T_TRAIT_C) reduce 158) ((T_TRY) reduce 158) ((T_UNSET) reduce 158) ((T_UNSET_CAST) reduce 158) ((T_VARIABLE) reduce 158) ((T_WHILE) reduce 158) ((T_YIELD) reduce 158) ((T_YIELD_FROM) reduce 158) (("[") reduce 158) (("`") reduce 158) (("{") reduce 158) (("~") reduce 158)) 16235 ((("!") reduce 147) (("\"") reduce 147) (("$") reduce 147) (("(") reduce 147) (("+") reduce 147) (("-") reduce 147) ((";") reduce 147) (("@") reduce 147) ((T_ABSTRACT) reduce 147) ((T_ARRAY) reduce 147) ((T_ARRAY_CAST) reduce 147) ((T_ATTRIBUTE) reduce 147) ((T_BOOL_CAST) reduce 147) ((T_BREAK) reduce 147) ((T_CLASS) reduce 147) ((T_CLASS_C) reduce 147) ((T_CLONE) reduce 147) ((T_CONSTANT_ENCAPSED_STRING) reduce 147) ((T_CONTINUE) reduce 147) ((T_DEC) reduce 147) ((T_DECLARE) reduce 147) ((T_DIR) reduce 147) ((T_DNUMBER) reduce 147) ((T_DO) reduce 147) ((T_DOUBLE_CAST) reduce 147) ((T_ECHO) reduce 147) ((T_ELSE) reduce 147) ((T_ELSEIF) reduce 147) ((T_EMPTY) reduce 147) ((T_ENDIF) reduce 147) ((T_ENUM) reduce 147) ((T_EVAL) reduce 147) ((T_EXIT) reduce 147) ((T_FILE) reduce 147) ((T_FINAL) reduce 147) ((T_FN) reduce 147) ((T_FOR) reduce 147) ((T_FOREACH) reduce 147) ((T_FUNCTION) reduce 147) ((T_FUNC_C) reduce 147) ((T_GLOBAL) reduce 147) ((T_GOTO) reduce 147) ((T_HALT_COMPILER) reduce 147) ((T_IF) reduce 147) ((T_INC) reduce 147) ((T_INCLUDE) reduce 147) ((T_INCLUDE_ONCE) reduce 147) ((T_INLINE_HTML) reduce 147) ((T_INTERFACE) reduce 147) ((T_INT_CAST) reduce 147) ((T_ISSET) reduce 147) ((T_LINE) reduce 147) ((T_LIST) reduce 147) ((T_LNUMBER) reduce 147) ((T_MATCH) reduce 147) ((T_METHOD_C) reduce 147) ((T_NAME_FULLY_QUALIFIED) reduce 147) ((T_NAME_QUALIFIED) reduce 147) ((T_NAME_RELATIVE) reduce 147) ((T_NEW) reduce 147) ((T_NS_C) reduce 147) ((T_OBJECT_CAST) reduce 147) ((T_PRINT) reduce 147) ((T_READONLY) reduce 147) ((T_REQUIRE) reduce 147) ((T_REQUIRE_ONCE) reduce 147) ((T_RETURN) reduce 147) ((T_START_HEREDOC) reduce 147) ((T_STATIC) reduce 147) ((T_STRING) reduce 147) ((T_STRING_CAST) reduce 147) ((T_SWITCH) reduce 147) ((T_THROW) reduce 147) ((T_TRAIT) reduce 147) ((T_TRAIT_C) reduce 147) ((T_TRY) reduce 147) ((T_UNSET) reduce 147) ((T_UNSET_CAST) reduce 147) ((T_VARIABLE) reduce 147) ((T_WHILE) reduce 147) ((T_YIELD) reduce 147) ((T_YIELD_FROM) reduce 147) (("[") reduce 147) (("`") reduce 147) (("{") reduce 147) (("~") reduce 147)) 16237 ((("!") reduce 142) (("\"") reduce 142) (("$") reduce 142) (("(") reduce 142) (("+") reduce 142) (("-") reduce 142) ((";") reduce 142) (("@") reduce 142) ((T_ABSTRACT) reduce 142) ((T_ARRAY) reduce 142) ((T_ARRAY_CAST) reduce 142) ((T_ATTRIBUTE) reduce 142) ((T_BOOL_CAST) reduce 142) ((T_BREAK) reduce 142) ((T_CLASS) reduce 142) ((T_CLASS_C) reduce 142) ((T_CLONE) reduce 142) ((T_CONSTANT_ENCAPSED_STRING) reduce 142) ((T_CONTINUE) reduce 142) ((T_DEC) reduce 142) ((T_DECLARE) reduce 142) ((T_DIR) reduce 142) ((T_DNUMBER) reduce 142) ((T_DO) reduce 142) ((T_DOUBLE_CAST) reduce 142) ((T_ECHO) reduce 142) ((T_ELSE) reduce 142) ((T_ELSEIF) reduce 142) ((T_EMPTY) reduce 142) ((T_ENDIF) reduce 142) ((T_ENUM) reduce 142) ((T_EVAL) reduce 142) ((T_EXIT) reduce 142) ((T_FILE) reduce 142) ((T_FINAL) reduce 142) ((T_FN) reduce 142) ((T_FOR) reduce 142) ((T_FOREACH) reduce 142) ((T_FUNCTION) reduce 142) ((T_FUNC_C) reduce 142) ((T_GLOBAL) reduce 142) ((T_GOTO) reduce 142) ((T_HALT_COMPILER) reduce 142) ((T_IF) reduce 142) ((T_INC) reduce 142) ((T_INCLUDE) reduce 142) ((T_INCLUDE_ONCE) reduce 142) ((T_INLINE_HTML) reduce 142) ((T_INTERFACE) reduce 142) ((T_INT_CAST) reduce 142) ((T_ISSET) reduce 142) ((T_LINE) reduce 142) ((T_LIST) reduce 142) ((T_LNUMBER) reduce 142) ((T_MATCH) reduce 142) ((T_METHOD_C) reduce 142) ((T_NAME_FULLY_QUALIFIED) reduce 142) ((T_NAME_QUALIFIED) reduce 142) ((T_NAME_RELATIVE) reduce 142) ((T_NEW) reduce 142) ((T_NS_C) reduce 142) ((T_OBJECT_CAST) reduce 142) ((T_PRINT) reduce 142) ((T_READONLY) reduce 142) ((T_REQUIRE) reduce 142) ((T_REQUIRE_ONCE) reduce 142) ((T_RETURN) reduce 142) ((T_START_HEREDOC) reduce 142) ((T_STATIC) reduce 142) ((T_STRING) reduce 142) ((T_STRING_CAST) reduce 142) ((T_SWITCH) reduce 142) ((T_THROW) reduce 142) ((T_TRAIT) reduce 142) ((T_TRAIT_C) reduce 142) ((T_TRY) reduce 142) ((T_UNSET) reduce 142) ((T_UNSET_CAST) reduce 142) ((T_VARIABLE) reduce 142) ((T_WHILE) reduce 142) ((T_YIELD) reduce 142) ((T_YIELD_FROM) reduce 142) (("[") reduce 142) (("`") reduce 142) (("{") reduce 142) (("~") reduce 142)) 16239 ((("!") reduce 103) (("\"") reduce 103) (("$") reduce 103) (("(") reduce 103) (("+") reduce 103) (("-") reduce 103) ((";") reduce 103) (("@") reduce 103) ((T_ABSTRACT) reduce 103) ((T_ARRAY) reduce 103) ((T_ARRAY_CAST) reduce 103) ((T_ATTRIBUTE) reduce 103) ((T_BOOL_CAST) reduce 103) ((T_BREAK) reduce 103) ((T_CLASS) reduce 103) ((T_CLASS_C) reduce 103) ((T_CLONE) reduce 103) ((T_CONSTANT_ENCAPSED_STRING) reduce 103) ((T_CONTINUE) reduce 103) ((T_DEC) reduce 103) ((T_DECLARE) reduce 103) ((T_DIR) reduce 103) ((T_DNUMBER) reduce 103) ((T_DO) reduce 103) ((T_DOUBLE_CAST) reduce 103) ((T_ECHO) reduce 103) ((T_ELSE) reduce 103) ((T_ELSEIF) reduce 103) ((T_EMPTY) reduce 103) ((T_ENDIF) reduce 103) ((T_ENUM) reduce 103) ((T_EVAL) reduce 103) ((T_EXIT) reduce 103) ((T_FILE) reduce 103) ((T_FINAL) reduce 103) ((T_FN) reduce 103) ((T_FOR) reduce 103) ((T_FOREACH) reduce 103) ((T_FUNCTION) reduce 103) ((T_FUNC_C) reduce 103) ((T_GLOBAL) reduce 103) ((T_GOTO) reduce 103) ((T_HALT_COMPILER) reduce 103) ((T_IF) reduce 103) ((T_INC) reduce 103) ((T_INCLUDE) reduce 103) ((T_INCLUDE_ONCE) reduce 103) ((T_INLINE_HTML) reduce 103) ((T_INTERFACE) reduce 103) ((T_INT_CAST) reduce 103) ((T_ISSET) reduce 103) ((T_LINE) reduce 103) ((T_LIST) reduce 103) ((T_LNUMBER) reduce 103) ((T_MATCH) reduce 103) ((T_METHOD_C) reduce 103) ((T_NAME_FULLY_QUALIFIED) reduce 103) ((T_NAME_QUALIFIED) reduce 103) ((T_NAME_RELATIVE) reduce 103) ((T_NEW) reduce 103) ((T_NS_C) reduce 103) ((T_OBJECT_CAST) reduce 103) ((T_PRINT) reduce 103) ((T_READONLY) reduce 103) ((T_REQUIRE) reduce 103) ((T_REQUIRE_ONCE) reduce 103) ((T_RETURN) reduce 103) ((T_START_HEREDOC) reduce 103) ((T_STATIC) reduce 103) ((T_STRING) reduce 103) ((T_STRING_CAST) reduce 103) ((T_SWITCH) reduce 103) ((T_THROW) reduce 103) ((T_TRAIT) reduce 103) ((T_TRAIT_C) reduce 103) ((T_TRY) reduce 103) ((T_UNSET) reduce 103) ((T_UNSET_CAST) reduce 103) ((T_VARIABLE) reduce 103) ((T_WHILE) reduce 103) ((T_YIELD) reduce 103) ((T_YIELD_FROM) reduce 103) (("[") reduce 103) (("`") reduce 103) (("{") reduce 103) (("~") reduce 103)) 16241 ((("!") reduce 106) (("\"") reduce 106) (("$") reduce 106) (("(") reduce 106) (("+") reduce 106) (("-") reduce 106) ((";") reduce 106) (("@") reduce 106) ((T_ABSTRACT) reduce 106) ((T_ARRAY) reduce 106) ((T_ARRAY_CAST) reduce 106) ((T_ATTRIBUTE) reduce 106) ((T_BOOL_CAST) reduce 106) ((T_BREAK) reduce 106) ((T_CLASS) reduce 106) ((T_CLASS_C) reduce 106) ((T_CLONE) reduce 106) ((T_CONSTANT_ENCAPSED_STRING) reduce 106) ((T_CONTINUE) reduce 106) ((T_DEC) reduce 106) ((T_DECLARE) reduce 106) ((T_DIR) reduce 106) ((T_DNUMBER) reduce 106) ((T_DO) reduce 106) ((T_DOUBLE_CAST) reduce 106) ((T_ECHO) reduce 106) ((T_ELSE) reduce 106) ((T_ELSEIF) reduce 106) ((T_EMPTY) reduce 106) ((T_ENDIF) reduce 106) ((T_ENUM) reduce 106) ((T_EVAL) reduce 106) ((T_EXIT) reduce 106) ((T_FILE) reduce 106) ((T_FINAL) reduce 106) ((T_FN) reduce 106) ((T_FOR) reduce 106) ((T_FOREACH) reduce 106) ((T_FUNCTION) reduce 106) ((T_FUNC_C) reduce 106) ((T_GLOBAL) reduce 106) ((T_GOTO) reduce 106) ((T_HALT_COMPILER) reduce 106) ((T_IF) reduce 106) ((T_INC) reduce 106) ((T_INCLUDE) reduce 106) ((T_INCLUDE_ONCE) reduce 106) ((T_INLINE_HTML) reduce 106) ((T_INTERFACE) reduce 106) ((T_INT_CAST) reduce 106) ((T_ISSET) reduce 106) ((T_LINE) reduce 106) ((T_LIST) reduce 106) ((T_LNUMBER) reduce 106) ((T_MATCH) reduce 106) ((T_METHOD_C) reduce 106) ((T_NAME_FULLY_QUALIFIED) reduce 106) ((T_NAME_QUALIFIED) reduce 106) ((T_NAME_RELATIVE) reduce 106) ((T_NEW) reduce 106) ((T_NS_C) reduce 106) ((T_OBJECT_CAST) reduce 106) ((T_PRINT) reduce 106) ((T_READONLY) reduce 106) ((T_REQUIRE) reduce 106) ((T_REQUIRE_ONCE) reduce 106) ((T_RETURN) reduce 106) ((T_START_HEREDOC) reduce 106) ((T_STATIC) reduce 106) ((T_STRING) reduce 106) ((T_STRING_CAST) reduce 106) ((T_SWITCH) reduce 106) ((T_THROW) reduce 106) ((T_TRAIT) reduce 106) ((T_TRAIT_C) reduce 106) ((T_TRY) reduce 106) ((T_UNSET) reduce 106) ((T_UNSET_CAST) reduce 106) ((T_VARIABLE) reduce 106) ((T_WHILE) reduce 106) ((T_YIELD) reduce 106) ((T_YIELD_FROM) reduce 106) (("[") reduce 106) (("`") reduce 106) (("{") reduce 106) (("~") reduce 106)) 16244 ((("!") reduce 102) (("\"") reduce 102) (("$") reduce 102) (("(") reduce 102) (("+") reduce 102) (("-") reduce 102) ((";") reduce 102) (("@") reduce 102) ((T_ABSTRACT) reduce 102) ((T_ARRAY) reduce 102) ((T_ARRAY_CAST) reduce 102) ((T_ATTRIBUTE) reduce 102) ((T_BOOL_CAST) reduce 102) ((T_BREAK) reduce 102) ((T_CLASS) reduce 102) ((T_CLASS_C) reduce 102) ((T_CLONE) reduce 102) ((T_CONSTANT_ENCAPSED_STRING) reduce 102) ((T_CONTINUE) reduce 102) ((T_DEC) reduce 102) ((T_DECLARE) reduce 102) ((T_DIR) reduce 102) ((T_DNUMBER) reduce 102) ((T_DO) reduce 102) ((T_DOUBLE_CAST) reduce 102) ((T_ECHO) reduce 102) ((T_ELSE) reduce 102) ((T_ELSEIF) reduce 102) ((T_EMPTY) reduce 102) ((T_ENDIF) reduce 102) ((T_ENUM) reduce 102) ((T_EVAL) reduce 102) ((T_EXIT) reduce 102) ((T_FILE) reduce 102) ((T_FINAL) reduce 102) ((T_FN) reduce 102) ((T_FOR) reduce 102) ((T_FOREACH) reduce 102) ((T_FUNCTION) reduce 102) ((T_FUNC_C) reduce 102) ((T_GLOBAL) reduce 102) ((T_GOTO) reduce 102) ((T_HALT_COMPILER) reduce 102) ((T_IF) reduce 102) ((T_INC) reduce 102) ((T_INCLUDE) reduce 102) ((T_INCLUDE_ONCE) reduce 102) ((T_INLINE_HTML) reduce 102) ((T_INTERFACE) reduce 102) ((T_INT_CAST) reduce 102) ((T_ISSET) reduce 102) ((T_LINE) reduce 102) ((T_LIST) reduce 102) ((T_LNUMBER) reduce 102) ((T_MATCH) reduce 102) ((T_METHOD_C) reduce 102) ((T_NAME_FULLY_QUALIFIED) reduce 102) ((T_NAME_QUALIFIED) reduce 102) ((T_NAME_RELATIVE) reduce 102) ((T_NEW) reduce 102) ((T_NS_C) reduce 102) ((T_OBJECT_CAST) reduce 102) ((T_PRINT) reduce 102) ((T_READONLY) reduce 102) ((T_REQUIRE) reduce 102) ((T_REQUIRE_ONCE) reduce 102) ((T_RETURN) reduce 102) ((T_START_HEREDOC) reduce 102) ((T_STATIC) reduce 102) ((T_STRING) reduce 102) ((T_STRING_CAST) reduce 102) ((T_SWITCH) reduce 102) ((T_THROW) reduce 102) ((T_TRAIT) reduce 102) ((T_TRAIT_C) reduce 102) ((T_TRY) reduce 102) ((T_UNSET) reduce 102) ((T_UNSET_CAST) reduce 102) ((T_VARIABLE) reduce 102) ((T_WHILE) reduce 102) ((T_YIELD) reduce 102) ((T_YIELD_FROM) reduce 102) (("[") reduce 102) (("`") reduce 102) (("{") reduce 102) (("~") reduce 102)) 16245 ((("!") reduce 146) (("\"") reduce 146) (("$") reduce 146) (("(") reduce 146) (("+") reduce 146) (("-") reduce 146) ((";") reduce 146) (("@") reduce 146) ((T_ABSTRACT) reduce 146) ((T_ARRAY) reduce 146) ((T_ARRAY_CAST) reduce 146) ((T_ATTRIBUTE) reduce 146) ((T_BOOL_CAST) reduce 146) ((T_BREAK) reduce 146) ((T_CLASS) reduce 146) ((T_CLASS_C) reduce 146) ((T_CLONE) reduce 146) ((T_CONSTANT_ENCAPSED_STRING) reduce 146) ((T_CONTINUE) reduce 146) ((T_DEC) reduce 146) ((T_DECLARE) reduce 146) ((T_DIR) reduce 146) ((T_DNUMBER) reduce 146) ((T_DO) reduce 146) ((T_DOUBLE_CAST) reduce 146) ((T_ECHO) reduce 146) ((T_ELSE) reduce 146) ((T_ELSEIF) reduce 146) ((T_EMPTY) reduce 146) ((T_ENDIF) reduce 146) ((T_ENUM) reduce 146) ((T_EVAL) reduce 146) ((T_EXIT) reduce 146) ((T_FILE) reduce 146) ((T_FINAL) reduce 146) ((T_FN) reduce 146) ((T_FOR) reduce 146) ((T_FOREACH) reduce 146) ((T_FUNCTION) reduce 146) ((T_FUNC_C) reduce 146) ((T_GLOBAL) reduce 146) ((T_GOTO) reduce 146) ((T_HALT_COMPILER) reduce 146) ((T_IF) reduce 146) ((T_INC) reduce 146) ((T_INCLUDE) reduce 146) ((T_INCLUDE_ONCE) reduce 146) ((T_INLINE_HTML) reduce 146) ((T_INTERFACE) reduce 146) ((T_INT_CAST) reduce 146) ((T_ISSET) reduce 146) ((T_LINE) reduce 146) ((T_LIST) reduce 146) ((T_LNUMBER) reduce 146) ((T_MATCH) reduce 146) ((T_METHOD_C) reduce 146) ((T_NAME_FULLY_QUALIFIED) reduce 146) ((T_NAME_QUALIFIED) reduce 146) ((T_NAME_RELATIVE) reduce 146) ((T_NEW) reduce 146) ((T_NS_C) reduce 146) ((T_OBJECT_CAST) reduce 146) ((T_PRINT) reduce 146) ((T_READONLY) reduce 146) ((T_REQUIRE) reduce 146) ((T_REQUIRE_ONCE) reduce 146) ((T_RETURN) reduce 146) ((T_START_HEREDOC) reduce 146) ((T_STATIC) reduce 146) ((T_STRING) reduce 146) ((T_STRING_CAST) reduce 146) ((T_SWITCH) reduce 146) ((T_THROW) reduce 146) ((T_TRAIT) reduce 146) ((T_TRAIT_C) reduce 146) ((T_TRY) reduce 146) ((T_UNSET) reduce 146) ((T_UNSET_CAST) reduce 146) ((T_VARIABLE) reduce 146) ((T_WHILE) reduce 146) ((T_YIELD) reduce 146) ((T_YIELD_FROM) reduce 146) (("[") reduce 146) (("`") reduce 146) (("{") reduce 146) (("~") reduce 146)) 16246 ((("!") reduce 243) (("\"") reduce 243) (("$") reduce 243) (("(") reduce 243) (("+") reduce 243) (("-") reduce 243) ((";") reduce 243) (("@") reduce 243) ((T_ABSTRACT) reduce 243) ((T_ARRAY) reduce 243) ((T_ARRAY_CAST) reduce 243) ((T_ATTRIBUTE) reduce 243) ((T_BOOL_CAST) reduce 243) ((T_BREAK) reduce 243) ((T_CLASS) reduce 243) ((T_CLASS_C) reduce 243) ((T_CLONE) reduce 243) ((T_CONSTANT_ENCAPSED_STRING) reduce 243) ((T_CONTINUE) reduce 243) ((T_DEC) reduce 243) ((T_DECLARE) reduce 243) ((T_DIR) reduce 243) ((T_DNUMBER) reduce 243) ((T_DO) reduce 243) ((T_DOUBLE_CAST) reduce 243) ((T_ECHO) reduce 243) ((T_ELSE) shift) ((T_ELSEIF) shift) ((T_EMPTY) reduce 243) ((T_ENDIF) reduce 243) ((T_ENUM) reduce 243) ((T_EVAL) reduce 243) ((T_EXIT) reduce 243) ((T_FILE) reduce 243) ((T_FINAL) reduce 243) ((T_FN) reduce 243) ((T_FOR) reduce 243) ((T_FOREACH) reduce 243) ((T_FUNCTION) reduce 243) ((T_FUNC_C) reduce 243) ((T_GLOBAL) reduce 243) ((T_GOTO) reduce 243) ((T_HALT_COMPILER) reduce 243) ((T_IF) reduce 243) ((T_INC) reduce 243) ((T_INCLUDE) reduce 243) ((T_INCLUDE_ONCE) reduce 243) ((T_INLINE_HTML) reduce 243) ((T_INTERFACE) reduce 243) ((T_INT_CAST) reduce 243) ((T_ISSET) reduce 243) ((T_LINE) reduce 243) ((T_LIST) reduce 243) ((T_LNUMBER) reduce 243) ((T_MATCH) reduce 243) ((T_METHOD_C) reduce 243) ((T_NAME_FULLY_QUALIFIED) reduce 243) ((T_NAME_QUALIFIED) reduce 243) ((T_NAME_RELATIVE) reduce 243) ((T_NEW) reduce 243) ((T_NS_C) reduce 243) ((T_OBJECT_CAST) reduce 243) ((T_PRINT) reduce 243) ((T_READONLY) reduce 243) ((T_REQUIRE) reduce 243) ((T_REQUIRE_ONCE) reduce 243) ((T_RETURN) reduce 243) ((T_START_HEREDOC) reduce 243) ((T_STATIC) reduce 243) ((T_STRING) reduce 243) ((T_STRING_CAST) reduce 243) ((T_SWITCH) reduce 243) ((T_THROW) reduce 243) ((T_TRAIT) reduce 243) ((T_TRAIT_C) reduce 243) ((T_TRY) reduce 243) ((T_UNSET) reduce 243) ((T_UNSET_CAST) reduce 243) ((T_VARIABLE) reduce 243) ((T_WHILE) reduce 243) ((T_YIELD) reduce 243) ((T_YIELD_FROM) reduce 243) (("[") reduce 243) (("`") reduce 243) (("{") reduce 243) (("~") reduce 243)) 16247 ((("!") reduce 139) (("\"") reduce 139) (("$") reduce 139) (("(") reduce 139) (("+") reduce 139) (("-") reduce 139) ((";") reduce 139) (("@") reduce 139) ((T_ABSTRACT) reduce 139) ((T_ARRAY) reduce 139) ((T_ARRAY_CAST) reduce 139) ((T_ATTRIBUTE) reduce 139) ((T_BOOL_CAST) reduce 139) ((T_BREAK) reduce 139) ((T_CLASS) reduce 139) ((T_CLASS_C) reduce 139) ((T_CLONE) reduce 139) ((T_CONSTANT_ENCAPSED_STRING) reduce 139) ((T_CONTINUE) reduce 139) ((T_DEC) reduce 139) ((T_DECLARE) reduce 139) ((T_DIR) reduce 139) ((T_DNUMBER) reduce 139) ((T_DO) reduce 139) ((T_DOUBLE_CAST) reduce 139) ((T_ECHO) reduce 139) ((T_ELSE) reduce 139) ((T_ELSEIF) reduce 139) ((T_EMPTY) reduce 139) ((T_ENDIF) reduce 139) ((T_ENUM) reduce 139) ((T_EVAL) reduce 139) ((T_EXIT) reduce 139) ((T_FILE) reduce 139) ((T_FINAL) reduce 139) ((T_FN) reduce 139) ((T_FOR) reduce 139) ((T_FOREACH) reduce 139) ((T_FUNCTION) reduce 139) ((T_FUNC_C) reduce 139) ((T_GLOBAL) reduce 139) ((T_GOTO) reduce 139) ((T_HALT_COMPILER) reduce 139) ((T_IF) reduce 139) ((T_INC) reduce 139) ((T_INCLUDE) reduce 139) ((T_INCLUDE_ONCE) reduce 139) ((T_INLINE_HTML) reduce 139) ((T_INTERFACE) reduce 139) ((T_INT_CAST) reduce 139) ((T_ISSET) reduce 139) ((T_LINE) reduce 139) ((T_LIST) reduce 139) ((T_LNUMBER) reduce 139) ((T_MATCH) reduce 139) ((T_METHOD_C) reduce 139) ((T_NAME_FULLY_QUALIFIED) reduce 139) ((T_NAME_QUALIFIED) reduce 139) ((T_NAME_RELATIVE) reduce 139) ((T_NEW) reduce 139) ((T_NS_C) reduce 139) ((T_OBJECT_CAST) reduce 139) ((T_PRINT) reduce 139) ((T_READONLY) reduce 139) ((T_REQUIRE) reduce 139) ((T_REQUIRE_ONCE) reduce 139) ((T_RETURN) reduce 139) ((T_START_HEREDOC) reduce 139) ((T_STATIC) reduce 139) ((T_STRING) reduce 139) ((T_STRING_CAST) reduce 139) ((T_SWITCH) reduce 139) ((T_THROW) reduce 139) ((T_TRAIT) reduce 139) ((T_TRAIT_C) reduce 139) ((T_TRY) reduce 139) ((T_UNSET) reduce 139) ((T_UNSET_CAST) reduce 139) ((T_VARIABLE) reduce 139) ((T_WHILE) reduce 139) ((T_YIELD) reduce 139) ((T_YIELD_FROM) reduce 139) (("[") reduce 139) (("`") reduce 139) (("{") reduce 139) (("~") reduce 139)) 16248 ((("!") reduce 105) (("\"") reduce 105) (("$") reduce 105) (("(") reduce 105) (("+") reduce 105) (("-") reduce 105) ((";") reduce 105) (("@") reduce 105) ((T_ABSTRACT) reduce 105) ((T_ARRAY) reduce 105) ((T_ARRAY_CAST) reduce 105) ((T_ATTRIBUTE) reduce 105) ((T_BOOL_CAST) reduce 105) ((T_BREAK) reduce 105) ((T_CLASS) reduce 105) ((T_CLASS_C) reduce 105) ((T_CLONE) reduce 105) ((T_CONSTANT_ENCAPSED_STRING) reduce 105) ((T_CONTINUE) reduce 105) ((T_DEC) reduce 105) ((T_DECLARE) reduce 105) ((T_DIR) reduce 105) ((T_DNUMBER) reduce 105) ((T_DO) reduce 105) ((T_DOUBLE_CAST) reduce 105) ((T_ECHO) reduce 105) ((T_ELSE) reduce 105) ((T_ELSEIF) reduce 105) ((T_EMPTY) reduce 105) ((T_ENDIF) reduce 105) ((T_ENUM) reduce 105) ((T_EVAL) reduce 105) ((T_EXIT) reduce 105) ((T_FILE) reduce 105) ((T_FINAL) reduce 105) ((T_FN) reduce 105) ((T_FOR) reduce 105) ((T_FOREACH) reduce 105) ((T_FUNCTION) reduce 105) ((T_FUNC_C) reduce 105) ((T_GLOBAL) reduce 105) ((T_GOTO) reduce 105) ((T_HALT_COMPILER) reduce 105) ((T_IF) reduce 105) ((T_INC) reduce 105) ((T_INCLUDE) reduce 105) ((T_INCLUDE_ONCE) reduce 105) ((T_INLINE_HTML) reduce 105) ((T_INTERFACE) reduce 105) ((T_INT_CAST) reduce 105) ((T_ISSET) reduce 105) ((T_LINE) reduce 105) ((T_LIST) reduce 105) ((T_LNUMBER) reduce 105) ((T_MATCH) reduce 105) ((T_METHOD_C) reduce 105) ((T_NAME_FULLY_QUALIFIED) reduce 105) ((T_NAME_QUALIFIED) reduce 105) ((T_NAME_RELATIVE) reduce 105) ((T_NEW) reduce 105) ((T_NS_C) reduce 105) ((T_OBJECT_CAST) reduce 105) ((T_PRINT) reduce 105) ((T_READONLY) reduce 105) ((T_REQUIRE) reduce 105) ((T_REQUIRE_ONCE) reduce 105) ((T_RETURN) reduce 105) ((T_START_HEREDOC) reduce 105) ((T_STATIC) reduce 105) ((T_STRING) reduce 105) ((T_STRING_CAST) reduce 105) ((T_SWITCH) reduce 105) ((T_THROW) reduce 105) ((T_TRAIT) reduce 105) ((T_TRAIT_C) reduce 105) ((T_TRY) reduce 105) ((T_UNSET) reduce 105) ((T_UNSET_CAST) reduce 105) ((T_VARIABLE) reduce 105) ((T_WHILE) reduce 105) ((T_YIELD) reduce 105) ((T_YIELD_FROM) reduce 105) (("[") reduce 105) (("`") reduce 105) (("{") reduce 105) (("~") reduce 105)) 16249 ((("!") reduce 141) (("\"") reduce 141) (("$") reduce 141) (("(") reduce 141) (("+") reduce 141) (("-") reduce 141) ((";") reduce 141) (("@") reduce 141) ((T_ABSTRACT) reduce 141) ((T_ARRAY) reduce 141) ((T_ARRAY_CAST) reduce 141) ((T_ATTRIBUTE) reduce 141) ((T_BOOL_CAST) reduce 141) ((T_BREAK) reduce 141) ((T_CLASS) reduce 141) ((T_CLASS_C) reduce 141) ((T_CLONE) reduce 141) ((T_CONSTANT_ENCAPSED_STRING) reduce 141) ((T_CONTINUE) reduce 141) ((T_DEC) reduce 141) ((T_DECLARE) reduce 141) ((T_DIR) reduce 141) ((T_DNUMBER) reduce 141) ((T_DO) reduce 141) ((T_DOUBLE_CAST) reduce 141) ((T_ECHO) reduce 141) ((T_ELSE) reduce 141) ((T_ELSEIF) reduce 141) ((T_EMPTY) reduce 141) ((T_ENDIF) reduce 141) ((T_ENUM) reduce 141) ((T_EVAL) reduce 141) ((T_EXIT) reduce 141) ((T_FILE) reduce 141) ((T_FINAL) reduce 141) ((T_FN) reduce 141) ((T_FOR) reduce 141) ((T_FOREACH) reduce 141) ((T_FUNCTION) reduce 141) ((T_FUNC_C) reduce 141) ((T_GLOBAL) reduce 141) ((T_GOTO) reduce 141) ((T_HALT_COMPILER) reduce 141) ((T_IF) reduce 141) ((T_INC) reduce 141) ((T_INCLUDE) reduce 141) ((T_INCLUDE_ONCE) reduce 141) ((T_INLINE_HTML) reduce 141) ((T_INTERFACE) reduce 141) ((T_INT_CAST) reduce 141) ((T_ISSET) reduce 141) ((T_LINE) reduce 141) ((T_LIST) reduce 141) ((T_LNUMBER) reduce 141) ((T_MATCH) reduce 141) ((T_METHOD_C) reduce 141) ((T_NAME_FULLY_QUALIFIED) reduce 141) ((T_NAME_QUALIFIED) reduce 141) ((T_NAME_RELATIVE) reduce 141) ((T_NEW) reduce 141) ((T_NS_C) reduce 141) ((T_OBJECT_CAST) reduce 141) ((T_PRINT) reduce 141) ((T_READONLY) reduce 141) ((T_REQUIRE) reduce 141) ((T_REQUIRE_ONCE) reduce 141) ((T_RETURN) reduce 141) ((T_START_HEREDOC) reduce 141) ((T_STATIC) reduce 141) ((T_STRING) reduce 141) ((T_STRING_CAST) reduce 141) ((T_SWITCH) reduce 141) ((T_THROW) reduce 141) ((T_TRAIT) reduce 141) ((T_TRAIT_C) reduce 141) ((T_TRY) reduce 141) ((T_UNSET) reduce 141) ((T_UNSET_CAST) reduce 141) ((T_VARIABLE) reduce 141) ((T_WHILE) reduce 141) ((T_YIELD) reduce 141) ((T_YIELD_FROM) reduce 141) (("[") reduce 141) (("`") reduce 141) (("{") reduce 141) (("~") reduce 141)) 16250 ((("!") reduce 104) (("\"") reduce 104) (("$") reduce 104) (("(") reduce 104) (("+") reduce 104) (("-") reduce 104) ((";") reduce 104) (("@") reduce 104) ((T_ABSTRACT) reduce 104) ((T_ARRAY) reduce 104) ((T_ARRAY_CAST) reduce 104) ((T_ATTRIBUTE) reduce 104) ((T_BOOL_CAST) reduce 104) ((T_BREAK) reduce 104) ((T_CLASS) reduce 104) ((T_CLASS_C) reduce 104) ((T_CLONE) reduce 104) ((T_CONSTANT_ENCAPSED_STRING) reduce 104) ((T_CONTINUE) reduce 104) ((T_DEC) reduce 104) ((T_DECLARE) reduce 104) ((T_DIR) reduce 104) ((T_DNUMBER) reduce 104) ((T_DO) reduce 104) ((T_DOUBLE_CAST) reduce 104) ((T_ECHO) reduce 104) ((T_ELSE) reduce 104) ((T_ELSEIF) reduce 104) ((T_EMPTY) reduce 104) ((T_ENDIF) reduce 104) ((T_ENUM) reduce 104) ((T_EVAL) reduce 104) ((T_EXIT) reduce 104) ((T_FILE) reduce 104) ((T_FINAL) reduce 104) ((T_FN) reduce 104) ((T_FOR) reduce 104) ((T_FOREACH) reduce 104) ((T_FUNCTION) reduce 104) ((T_FUNC_C) reduce 104) ((T_GLOBAL) reduce 104) ((T_GOTO) reduce 104) ((T_HALT_COMPILER) reduce 104) ((T_IF) reduce 104) ((T_INC) reduce 104) ((T_INCLUDE) reduce 104) ((T_INCLUDE_ONCE) reduce 104) ((T_INLINE_HTML) reduce 104) ((T_INTERFACE) reduce 104) ((T_INT_CAST) reduce 104) ((T_ISSET) reduce 104) ((T_LINE) reduce 104) ((T_LIST) reduce 104) ((T_LNUMBER) reduce 104) ((T_MATCH) reduce 104) ((T_METHOD_C) reduce 104) ((T_NAME_FULLY_QUALIFIED) reduce 104) ((T_NAME_QUALIFIED) reduce 104) ((T_NAME_RELATIVE) reduce 104) ((T_NEW) reduce 104) ((T_NS_C) reduce 104) ((T_OBJECT_CAST) reduce 104) ((T_PRINT) reduce 104) ((T_READONLY) reduce 104) ((T_REQUIRE) reduce 104) ((T_REQUIRE_ONCE) reduce 104) ((T_RETURN) reduce 104) ((T_START_HEREDOC) reduce 104) ((T_STATIC) reduce 104) ((T_STRING) reduce 104) ((T_STRING_CAST) reduce 104) ((T_SWITCH) reduce 104) ((T_THROW) reduce 104) ((T_TRAIT) reduce 104) ((T_TRAIT_C) reduce 104) ((T_TRY) reduce 104) ((T_UNSET) reduce 104) ((T_UNSET_CAST) reduce 104) ((T_VARIABLE) reduce 104) ((T_WHILE) reduce 104) ((T_YIELD) reduce 104) ((T_YIELD_FROM) reduce 104) (("[") reduce 104) (("`") reduce 104) (("{") reduce 104) (("~") reduce 104)) 16253 ((("!") reduce 145) (("\"") reduce 145) (("$") reduce 145) (("(") reduce 145) (("+") reduce 145) (("-") reduce 145) ((";") reduce 145) (("@") reduce 145) ((T_ABSTRACT) reduce 145) ((T_ARRAY) reduce 145) ((T_ARRAY_CAST) reduce 145) ((T_ATTRIBUTE) reduce 145) ((T_BOOL_CAST) reduce 145) ((T_BREAK) reduce 145) ((T_CLASS) reduce 145) ((T_CLASS_C) reduce 145) ((T_CLONE) reduce 145) ((T_CONSTANT_ENCAPSED_STRING) reduce 145) ((T_CONTINUE) reduce 145) ((T_DEC) reduce 145) ((T_DECLARE) reduce 145) ((T_DIR) reduce 145) ((T_DNUMBER) reduce 145) ((T_DO) reduce 145) ((T_DOUBLE_CAST) reduce 145) ((T_ECHO) reduce 145) ((T_ELSE) reduce 145) ((T_ELSEIF) reduce 145) ((T_EMPTY) reduce 145) ((T_ENDIF) reduce 145) ((T_ENUM) reduce 145) ((T_EVAL) reduce 145) ((T_EXIT) reduce 145) ((T_FILE) reduce 145) ((T_FINAL) reduce 145) ((T_FN) reduce 145) ((T_FOR) reduce 145) ((T_FOREACH) reduce 145) ((T_FUNCTION) reduce 145) ((T_FUNC_C) reduce 145) ((T_GLOBAL) reduce 145) ((T_GOTO) reduce 145) ((T_HALT_COMPILER) reduce 145) ((T_IF) reduce 145) ((T_INC) reduce 145) ((T_INCLUDE) reduce 145) ((T_INCLUDE_ONCE) reduce 145) ((T_INLINE_HTML) reduce 145) ((T_INTERFACE) reduce 145) ((T_INT_CAST) reduce 145) ((T_ISSET) reduce 145) ((T_LINE) reduce 145) ((T_LIST) reduce 145) ((T_LNUMBER) reduce 145) ((T_MATCH) reduce 145) ((T_METHOD_C) reduce 145) ((T_NAME_FULLY_QUALIFIED) reduce 145) ((T_NAME_QUALIFIED) reduce 145) ((T_NAME_RELATIVE) reduce 145) ((T_NEW) reduce 145) ((T_NS_C) reduce 145) ((T_OBJECT_CAST) reduce 145) ((T_PRINT) reduce 145) ((T_READONLY) reduce 145) ((T_REQUIRE) reduce 145) ((T_REQUIRE_ONCE) reduce 145) ((T_RETURN) reduce 145) ((T_START_HEREDOC) reduce 145) ((T_STATIC) reduce 145) ((T_STRING) reduce 145) ((T_STRING_CAST) reduce 145) ((T_SWITCH) reduce 145) ((T_THROW) reduce 145) ((T_TRAIT) reduce 145) ((T_TRAIT_C) reduce 145) ((T_TRY) reduce 145) ((T_UNSET) reduce 145) ((T_UNSET_CAST) reduce 145) ((T_VARIABLE) reduce 145) ((T_WHILE) reduce 145) ((T_YIELD) reduce 145) ((T_YIELD_FROM) reduce 145) (("[") reduce 145) (("`") reduce 145) (("{") reduce 145) (("~") reduce 145)) 16259 ((("!") reduce 242) (("\"") reduce 242) (("$") reduce 242) (("(") reduce 242) (("+") reduce 242) (("-") reduce 242) ((";") reduce 242) (("@") reduce 242) ((T_ABSTRACT) reduce 242) ((T_ARRAY) reduce 242) ((T_ARRAY_CAST) reduce 242) ((T_ATTRIBUTE) reduce 242) ((T_BOOL_CAST) reduce 242) ((T_BREAK) reduce 242) ((T_CLASS) reduce 242) ((T_CLASS_C) reduce 242) ((T_CLONE) reduce 242) ((T_CONSTANT_ENCAPSED_STRING) reduce 242) ((T_CONTINUE) reduce 242) ((T_DEC) reduce 242) ((T_DECLARE) reduce 242) ((T_DIR) reduce 242) ((T_DNUMBER) reduce 242) ((T_DO) reduce 242) ((T_DOUBLE_CAST) reduce 242) ((T_ECHO) reduce 242) ((T_ELSE) reduce 242) ((T_ELSEIF) reduce 242) ((T_EMPTY) reduce 242) ((T_ENDIF) reduce 242) ((T_ENUM) reduce 242) ((T_EVAL) reduce 242) ((T_EXIT) reduce 242) ((T_FILE) reduce 242) ((T_FINAL) reduce 242) ((T_FN) reduce 242) ((T_FOR) reduce 242) ((T_FOREACH) reduce 242) ((T_FUNCTION) reduce 242) ((T_FUNC_C) reduce 242) ((T_GLOBAL) reduce 242) ((T_GOTO) reduce 242) ((T_HALT_COMPILER) reduce 242) ((T_IF) reduce 242) ((T_INC) reduce 242) ((T_INCLUDE) reduce 242) ((T_INCLUDE_ONCE) reduce 242) ((T_INLINE_HTML) reduce 242) ((T_INTERFACE) reduce 242) ((T_INT_CAST) reduce 242) ((T_ISSET) reduce 242) ((T_LINE) reduce 242) ((T_LIST) reduce 242) ((T_LNUMBER) reduce 242) ((T_MATCH) reduce 242) ((T_METHOD_C) reduce 242) ((T_NAME_FULLY_QUALIFIED) reduce 242) ((T_NAME_QUALIFIED) reduce 242) ((T_NAME_RELATIVE) reduce 242) ((T_NEW) reduce 242) ((T_NS_C) reduce 242) ((T_OBJECT_CAST) reduce 242) ((T_PRINT) reduce 242) ((T_READONLY) reduce 242) ((T_REQUIRE) reduce 242) ((T_REQUIRE_ONCE) reduce 242) ((T_RETURN) reduce 242) ((T_START_HEREDOC) reduce 242) ((T_STATIC) reduce 242) ((T_STRING) reduce 242) ((T_STRING_CAST) reduce 242) ((T_SWITCH) reduce 242) ((T_THROW) reduce 242) ((T_TRAIT) reduce 242) ((T_TRAIT_C) reduce 242) ((T_TRY) reduce 242) ((T_UNSET) reduce 242) ((T_UNSET_CAST) reduce 242) ((T_VARIABLE) reduce 242) ((T_WHILE) reduce 242) ((T_YIELD) reduce 242) ((T_YIELD_FROM) reduce 242) (("[") reduce 242) (("`") reduce 242) (("{") reduce 242) (("~") reduce 242)) 16260 ((("!") reduce 244) (("\"") reduce 244) (("$") reduce 244) (("(") reduce 244) (("+") reduce 244) (("-") reduce 244) ((";") reduce 244) (("@") reduce 244) ((T_ABSTRACT) reduce 244) ((T_ARRAY) reduce 244) ((T_ARRAY_CAST) reduce 244) ((T_ATTRIBUTE) reduce 244) ((T_BOOL_CAST) reduce 244) ((T_BREAK) reduce 244) ((T_CLASS) reduce 244) ((T_CLASS_C) reduce 244) ((T_CLONE) reduce 244) ((T_CONSTANT_ENCAPSED_STRING) reduce 244) ((T_CONTINUE) reduce 244) ((T_DEC) reduce 244) ((T_DECLARE) reduce 244) ((T_DIR) reduce 244) ((T_DNUMBER) reduce 244) ((T_DO) reduce 244) ((T_DOUBLE_CAST) reduce 244) ((T_ECHO) reduce 244) ((T_ELSE) reduce 244) ((T_ELSEIF) reduce 244) ((T_EMPTY) reduce 244) ((T_ENDIF) reduce 244) ((T_ENUM) reduce 244) ((T_EVAL) reduce 244) ((T_EXIT) reduce 244) ((T_FILE) reduce 244) ((T_FINAL) reduce 244) ((T_FN) reduce 244) ((T_FOR) reduce 244) ((T_FOREACH) reduce 244) ((T_FUNCTION) reduce 244) ((T_FUNC_C) reduce 244) ((T_GLOBAL) reduce 244) ((T_GOTO) reduce 244) ((T_HALT_COMPILER) reduce 244) ((T_IF) reduce 244) ((T_INC) reduce 244) ((T_INCLUDE) reduce 244) ((T_INCLUDE_ONCE) reduce 244) ((T_INLINE_HTML) reduce 244) ((T_INTERFACE) reduce 244) ((T_INT_CAST) reduce 244) ((T_ISSET) reduce 244) ((T_LINE) reduce 244) ((T_LIST) reduce 244) ((T_LNUMBER) reduce 244) ((T_MATCH) reduce 244) ((T_METHOD_C) reduce 244) ((T_NAME_FULLY_QUALIFIED) reduce 244) ((T_NAME_QUALIFIED) reduce 244) ((T_NAME_RELATIVE) reduce 244) ((T_NEW) reduce 244) ((T_NS_C) reduce 244) ((T_OBJECT_CAST) reduce 244) ((T_PRINT) reduce 244) ((T_READONLY) reduce 244) ((T_REQUIRE) reduce 244) ((T_REQUIRE_ONCE) reduce 244) ((T_RETURN) reduce 244) ((T_START_HEREDOC) reduce 244) ((T_STATIC) reduce 244) ((T_STRING) reduce 244) ((T_STRING_CAST) reduce 244) ((T_SWITCH) reduce 244) ((T_THROW) reduce 244) ((T_TRAIT) reduce 244) ((T_TRAIT_C) reduce 244) ((T_TRY) reduce 244) ((T_UNSET) reduce 244) ((T_UNSET_CAST) reduce 244) ((T_VARIABLE) reduce 244) ((T_WHILE) reduce 244) ((T_YIELD) reduce 244) ((T_YIELD_FROM) reduce 244) (("[") reduce 244) (("`") reduce 244) (("{") reduce 244) (("~") reduce 244)) 16261 ((("(") reduce 79) ((T_READONLY) reduce 79) ((T_STRING) reduce 79)) 16262 ((("(") reduce 80) ((T_READONLY) reduce 80) ((T_STRING) reduce 80)) 16263 ((("(") reduce 458) ((T_READONLY) reduce 458) ((T_STRING) reduce 458)) 16264 ((("(") reduce 454) ((T_READONLY) shift) ((T_STRING) shift)) 16265 ((("(") reduce 180)) 16266 ((("(") reduce 179)) 16276 ((("!") reduce 455) (("\"") reduce 455) (("$") reduce 455) (("(") reduce 455) (("+") reduce 455) (("-") reduce 455) ((";") reduce 455) (("@") reduce 455) ((T_ABSTRACT) reduce 455) ((T_ARRAY) reduce 455) ((T_ARRAY_CAST) reduce 455) ((T_ATTRIBUTE) reduce 455) ((T_BOOL_CAST) reduce 455) ((T_BREAK) reduce 455) ((T_CLASS) reduce 455) ((T_CLASS_C) reduce 455) ((T_CLONE) reduce 455) ((T_CONSTANT_ENCAPSED_STRING) reduce 455) ((T_CONTINUE) reduce 455) ((T_DEC) reduce 455) ((T_DECLARE) reduce 455) ((T_DIR) reduce 455) ((T_DNUMBER) reduce 455) ((T_DO) reduce 455) ((T_DOUBLE_CAST) reduce 455) ((T_ECHO) reduce 455) ((T_ELSE) reduce 455) ((T_ELSEIF) reduce 455) ((T_EMPTY) reduce 455) ((T_ENDIF) reduce 455) ((T_ENUM) reduce 455) ((T_EVAL) reduce 455) ((T_EXIT) reduce 455) ((T_FILE) reduce 455) ((T_FINAL) reduce 455) ((T_FN) reduce 455) ((T_FOR) reduce 455) ((T_FOREACH) reduce 455) ((T_FUNCTION) reduce 455) ((T_FUNC_C) reduce 455) ((T_GLOBAL) reduce 455) ((T_GOTO) reduce 455) ((T_HALT_COMPILER) reduce 455) ((T_IF) reduce 455) ((T_INC) reduce 455) ((T_INCLUDE) reduce 455) ((T_INCLUDE_ONCE) reduce 455) ((T_INLINE_HTML) reduce 455) ((T_INTERFACE) reduce 455) ((T_INT_CAST) reduce 455) ((T_ISSET) reduce 455) ((T_LINE) reduce 455) ((T_LIST) reduce 455) ((T_LNUMBER) reduce 455) ((T_MATCH) reduce 455) ((T_METHOD_C) reduce 455) ((T_NAME_FULLY_QUALIFIED) reduce 455) ((T_NAME_QUALIFIED) reduce 455) ((T_NAME_RELATIVE) reduce 455) ((T_NEW) reduce 455) ((T_NS_C) reduce 455) ((T_OBJECT_CAST) reduce 455) ((T_PRINT) reduce 455) ((T_READONLY) reduce 455) ((T_REQUIRE) reduce 455) ((T_REQUIRE_ONCE) reduce 455) ((T_RETURN) reduce 455) ((T_START_HEREDOC) reduce 455) ((T_STATIC) reduce 455) ((T_STRING) reduce 455) ((T_STRING_CAST) reduce 455) ((T_SWITCH) reduce 455) ((T_THROW) reduce 455) ((T_TRAIT) reduce 455) ((T_TRAIT_C) reduce 455) ((T_TRY) reduce 455) ((T_UNSET) reduce 455) ((T_UNSET_CAST) reduce 455) ((T_VARIABLE) reduce 455) ((T_WHILE) reduce 455) ((T_YIELD) reduce 455) ((T_YIELD_FROM) reduce 455) (("[") reduce 455) (("`") reduce 455) (("{") reduce 455) (("~") reduce 455)) 16277 ((("!") reduce 181) (("\"") reduce 181) (("$") reduce 181) (("(") reduce 181) (("+") reduce 181) (("-") reduce 181) ((";") reduce 181) (("@") reduce 181) ((T_ABSTRACT) reduce 181) ((T_ARRAY) reduce 181) ((T_ARRAY_CAST) reduce 181) ((T_ATTRIBUTE) reduce 181) ((T_BOOL_CAST) reduce 181) ((T_BREAK) reduce 181) ((T_CLASS) reduce 181) ((T_CLASS_C) reduce 181) ((T_CLONE) reduce 181) ((T_CONSTANT_ENCAPSED_STRING) reduce 181) ((T_CONTINUE) reduce 181) ((T_DEC) reduce 181) ((T_DECLARE) reduce 181) ((T_DIR) reduce 181) ((T_DNUMBER) reduce 181) ((T_DO) reduce 181) ((T_DOUBLE_CAST) reduce 181) ((T_ECHO) reduce 181) ((T_ELSE) reduce 181) ((T_ELSEIF) reduce 181) ((T_EMPTY) reduce 181) ((T_ENDIF) reduce 181) ((T_ENUM) reduce 181) ((T_EVAL) reduce 181) ((T_EXIT) reduce 181) ((T_FILE) reduce 181) ((T_FINAL) reduce 181) ((T_FN) reduce 181) ((T_FOR) reduce 181) ((T_FOREACH) reduce 181) ((T_FUNCTION) reduce 181) ((T_FUNC_C) reduce 181) ((T_GLOBAL) reduce 181) ((T_GOTO) reduce 181) ((T_HALT_COMPILER) reduce 181) ((T_IF) reduce 181) ((T_INC) reduce 181) ((T_INCLUDE) reduce 181) ((T_INCLUDE_ONCE) reduce 181) ((T_INLINE_HTML) reduce 181) ((T_INTERFACE) reduce 181) ((T_INT_CAST) reduce 181) ((T_ISSET) reduce 181) ((T_LINE) reduce 181) ((T_LIST) reduce 181) ((T_LNUMBER) reduce 181) ((T_MATCH) reduce 181) ((T_METHOD_C) reduce 181) ((T_NAME_FULLY_QUALIFIED) reduce 181) ((T_NAME_QUALIFIED) reduce 181) ((T_NAME_RELATIVE) reduce 181) ((T_NEW) reduce 181) ((T_NS_C) reduce 181) ((T_OBJECT_CAST) reduce 181) ((T_PRINT) reduce 181) ((T_READONLY) reduce 181) ((T_REQUIRE) reduce 181) ((T_REQUIRE_ONCE) reduce 181) ((T_RETURN) reduce 181) ((T_START_HEREDOC) reduce 181) ((T_STATIC) reduce 181) ((T_STRING) reduce 181) ((T_STRING_CAST) reduce 181) ((T_SWITCH) reduce 181) ((T_THROW) reduce 181) ((T_TRAIT) reduce 181) ((T_TRAIT_C) reduce 181) ((T_TRY) reduce 181) ((T_UNSET) reduce 181) ((T_UNSET_CAST) reduce 181) ((T_VARIABLE) reduce 181) ((T_WHILE) reduce 181) ((T_YIELD) reduce 181) ((T_YIELD_FROM) reduce 181) (("[") reduce 181) (("`") reduce 181) (("{") reduce 181) (("~") reduce 181)) 16278 ((("!") reduce 159) (("\"") reduce 159) (("$") reduce 159) (("(") reduce 159) (("+") reduce 159) (("-") reduce 159) ((";") reduce 159) (("@") reduce 159) ((T_ABSTRACT) reduce 159) ((T_ARRAY) reduce 159) ((T_ARRAY_CAST) reduce 159) ((T_ATTRIBUTE) reduce 159) ((T_BOOL_CAST) reduce 159) ((T_BREAK) reduce 159) ((T_CLASS) reduce 159) ((T_CLASS_C) reduce 159) ((T_CLONE) reduce 159) ((T_CONSTANT_ENCAPSED_STRING) reduce 159) ((T_CONTINUE) reduce 159) ((T_DEC) reduce 159) ((T_DECLARE) reduce 159) ((T_DIR) reduce 159) ((T_DNUMBER) reduce 159) ((T_DO) reduce 159) ((T_DOUBLE_CAST) reduce 159) ((T_ECHO) reduce 159) ((T_ELSE) reduce 159) ((T_ELSEIF) reduce 159) ((T_EMPTY) reduce 159) ((T_ENDIF) reduce 159) ((T_ENUM) reduce 159) ((T_EVAL) reduce 159) ((T_EXIT) reduce 159) ((T_FILE) reduce 159) ((T_FINAL) reduce 159) ((T_FN) reduce 159) ((T_FOR) reduce 159) ((T_FOREACH) reduce 159) ((T_FUNCTION) reduce 159) ((T_FUNC_C) reduce 159) ((T_GLOBAL) reduce 159) ((T_GOTO) reduce 159) ((T_HALT_COMPILER) reduce 159) ((T_IF) reduce 159) ((T_INC) reduce 159) ((T_INCLUDE) reduce 159) ((T_INCLUDE_ONCE) reduce 159) ((T_INLINE_HTML) reduce 159) ((T_INTERFACE) reduce 159) ((T_INT_CAST) reduce 159) ((T_ISSET) reduce 159) ((T_LINE) reduce 159) ((T_LIST) reduce 159) ((T_LNUMBER) reduce 159) ((T_MATCH) reduce 159) ((T_METHOD_C) reduce 159) ((T_NAME_FULLY_QUALIFIED) reduce 159) ((T_NAME_QUALIFIED) reduce 159) ((T_NAME_RELATIVE) reduce 159) ((T_NEW) reduce 159) ((T_NS_C) reduce 159) ((T_OBJECT_CAST) reduce 159) ((T_PRINT) reduce 159) ((T_READONLY) reduce 159) ((T_REQUIRE) reduce 159) ((T_REQUIRE_ONCE) reduce 159) ((T_RETURN) reduce 159) ((T_START_HEREDOC) reduce 159) ((T_STATIC) reduce 159) ((T_STRING) reduce 159) ((T_STRING_CAST) reduce 159) ((T_SWITCH) reduce 159) ((T_THROW) reduce 159) ((T_TRAIT) reduce 159) ((T_TRAIT_C) reduce 159) ((T_TRY) reduce 159) ((T_UNSET) reduce 159) ((T_UNSET_CAST) reduce 159) ((T_VARIABLE) reduce 159) ((T_WHILE) reduce 159) ((T_YIELD) reduce 159) ((T_YIELD_FROM) reduce 159) (("[") reduce 159) (("`") reduce 159) (("{") reduce 159) (("~") reduce 159)) 16280 (((T_ABSTRACT) reduce 189) ((T_CLASS) reduce 189) ((T_FINAL) reduce 189) ((T_READONLY) reduce 189)) 16287 ((("!") reduce 186) (("\"") reduce 186) (("$") reduce 186) (("(") reduce 186) (("+") reduce 186) (("-") reduce 186) ((";") reduce 186) (("@") reduce 186) ((T_ABSTRACT) reduce 186) ((T_ARRAY) reduce 186) ((T_ARRAY_CAST) reduce 186) ((T_ATTRIBUTE) reduce 186) ((T_BOOL_CAST) reduce 186) ((T_BREAK) reduce 186) ((T_CLASS) reduce 186) ((T_CLASS_C) reduce 186) ((T_CLONE) reduce 186) ((T_CONSTANT_ENCAPSED_STRING) reduce 186) ((T_CONTINUE) reduce 186) ((T_DEC) reduce 186) ((T_DECLARE) reduce 186) ((T_DIR) reduce 186) ((T_DNUMBER) reduce 186) ((T_DO) reduce 186) ((T_DOUBLE_CAST) reduce 186) ((T_ECHO) reduce 186) ((T_ELSE) reduce 186) ((T_ELSEIF) reduce 186) ((T_EMPTY) reduce 186) ((T_ENDIF) reduce 186) ((T_ENUM) reduce 186) ((T_EVAL) reduce 186) ((T_EXIT) reduce 186) ((T_FILE) reduce 186) ((T_FINAL) reduce 186) ((T_FN) reduce 186) ((T_FOR) reduce 186) ((T_FOREACH) reduce 186) ((T_FUNCTION) reduce 186) ((T_FUNC_C) reduce 186) ((T_GLOBAL) reduce 186) ((T_GOTO) reduce 186) ((T_HALT_COMPILER) reduce 186) ((T_IF) reduce 186) ((T_INC) reduce 186) ((T_INCLUDE) reduce 186) ((T_INCLUDE_ONCE) reduce 186) ((T_INLINE_HTML) reduce 186) ((T_INTERFACE) reduce 186) ((T_INT_CAST) reduce 186) ((T_ISSET) reduce 186) ((T_LINE) reduce 186) ((T_LIST) reduce 186) ((T_LNUMBER) reduce 186) ((T_MATCH) reduce 186) ((T_METHOD_C) reduce 186) ((T_NAME_FULLY_QUALIFIED) reduce 186) ((T_NAME_QUALIFIED) reduce 186) ((T_NAME_RELATIVE) reduce 186) ((T_NEW) reduce 186) ((T_NS_C) reduce 186) ((T_OBJECT_CAST) reduce 186) ((T_PRINT) reduce 186) ((T_READONLY) reduce 186) ((T_REQUIRE) reduce 186) ((T_REQUIRE_ONCE) reduce 186) ((T_RETURN) reduce 186) ((T_START_HEREDOC) reduce 186) ((T_STATIC) reduce 186) ((T_STRING) reduce 186) ((T_STRING_CAST) reduce 186) ((T_SWITCH) reduce 186) ((T_THROW) reduce 186) ((T_TRAIT) reduce 186) ((T_TRAIT_C) reduce 186) ((T_TRY) reduce 186) ((T_UNSET) reduce 186) ((T_UNSET_CAST) reduce 186) ((T_VARIABLE) reduce 186) ((T_WHILE) reduce 186) ((T_YIELD) reduce 186) ((T_YIELD_FROM) reduce 186) (("[") reduce 186) (("`") reduce 186) (("{") reduce 186) (("~") reduce 186)) 16289 (((T_ABSTRACT) reduce 101) ((T_ATTRIBUTE) reduce 101) ((T_CLASS) reduce 101) ((T_ENUM) reduce 101) ((T_FINAL) reduce 101) ((T_FN) reduce 101) ((T_FUNCTION) reduce 101) ((T_INTERFACE) reduce 101) ((T_READONLY) reduce 101) ((T_STATIC) reduce 101) ((T_TRAIT) reduce 101)) 16290 ((("!") reduce 143) (("\"") reduce 143) (("$") reduce 143) (("(") reduce 143) (("+") reduce 143) (("-") reduce 143) ((";") reduce 143) (("@") reduce 143) ((T_ABSTRACT) reduce 143) ((T_ARRAY) reduce 143) ((T_ARRAY_CAST) reduce 143) ((T_ATTRIBUTE) reduce 143) ((T_BOOL_CAST) reduce 143) ((T_BREAK) reduce 143) ((T_CLASS) reduce 143) ((T_CLASS_C) reduce 143) ((T_CLONE) reduce 143) ((T_CONSTANT_ENCAPSED_STRING) reduce 143) ((T_CONTINUE) reduce 143) ((T_DEC) reduce 143) ((T_DECLARE) reduce 143) ((T_DIR) reduce 143) ((T_DNUMBER) reduce 143) ((T_DO) reduce 143) ((T_DOUBLE_CAST) reduce 143) ((T_ECHO) reduce 143) ((T_ELSE) reduce 143) ((T_ELSEIF) reduce 143) ((T_EMPTY) reduce 143) ((T_ENDIF) reduce 143) ((T_ENUM) reduce 143) ((T_EVAL) reduce 143) ((T_EXIT) reduce 143) ((T_FILE) reduce 143) ((T_FINAL) reduce 143) ((T_FN) reduce 143) ((T_FOR) reduce 143) ((T_FOREACH) reduce 143) ((T_FUNCTION) reduce 143) ((T_FUNC_C) reduce 143) ((T_GLOBAL) reduce 143) ((T_GOTO) reduce 143) ((T_HALT_COMPILER) reduce 143) ((T_IF) reduce 143) ((T_INC) reduce 143) ((T_INCLUDE) reduce 143) ((T_INCLUDE_ONCE) reduce 143) ((T_INLINE_HTML) reduce 143) ((T_INTERFACE) reduce 143) ((T_INT_CAST) reduce 143) ((T_ISSET) reduce 143) ((T_LINE) reduce 143) ((T_LIST) reduce 143) ((T_LNUMBER) reduce 143) ((T_MATCH) reduce 143) ((T_METHOD_C) reduce 143) ((T_NAME_FULLY_QUALIFIED) reduce 143) ((T_NAME_QUALIFIED) reduce 143) ((T_NAME_RELATIVE) reduce 143) ((T_NEW) reduce 143) ((T_NS_C) reduce 143) ((T_OBJECT_CAST) reduce 143) ((T_PRINT) reduce 143) ((T_READONLY) reduce 143) ((T_REQUIRE) reduce 143) ((T_REQUIRE_ONCE) reduce 143) ((T_RETURN) reduce 143) ((T_START_HEREDOC) reduce 143) ((T_STATIC) reduce 143) ((T_STRING) reduce 143) ((T_STRING_CAST) reduce 143) ((T_SWITCH) reduce 143) ((T_THROW) reduce 143) ((T_TRAIT) reduce 143) ((T_TRAIT_C) reduce 143) ((T_TRY) reduce 143) ((T_UNSET) reduce 143) ((T_UNSET_CAST) reduce 143) ((T_VARIABLE) reduce 143) ((T_WHILE) reduce 143) ((T_YIELD) reduce 143) ((T_YIELD_FROM) reduce 143) (("[") reduce 143) (("`") reduce 143) (("{") reduce 143) (("~") reduce 143)) 16291 ((("%") reduce 446) (("*") reduce 446) (("+") reduce 446) (("-") reduce 446) ((".") reduce 446) (("/") reduce 446) ((";") reduce 446) (("<") reduce 446) ((">") reduce 446) (("?") reduce 446) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_BOOLEAN_AND) reduce 446) ((T_BOOLEAN_OR) reduce 446) ((T_COALESCE) reduce 446) ((T_INSTANCEOF) reduce 446) ((T_IS_EQUAL) reduce 446) ((T_IS_GREATER_OR_EQUAL) reduce 446) ((T_IS_IDENTICAL) reduce 446) ((T_IS_NOT_EQUAL) reduce 446) ((T_IS_NOT_IDENTICAL) reduce 446) ((T_IS_SMALLER_OR_EQUAL) reduce 446) ((T_LOGICAL_AND) reduce 446) ((T_LOGICAL_OR) reduce 446) ((T_LOGICAL_XOR) reduce 446) ((T_POW) reduce 446) ((T_SL) reduce 446) ((T_SPACESHIP) reduce 446) ((T_SR) reduce 446) (("^") reduce 446) (("|") reduce 446)) 16292 ((("%") reduce 448) (("*") reduce 448) (("+") reduce 448) (("-") reduce 448) ((".") reduce 448) (("/") reduce 448) ((";") reduce 448) (("<") reduce 448) ((">") reduce 448) (("?") reduce 448) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_BOOLEAN_AND) reduce 448) ((T_BOOLEAN_OR) reduce 448) ((T_COALESCE) reduce 448) ((T_INSTANCEOF) reduce 448) ((T_IS_EQUAL) reduce 448) ((T_IS_GREATER_OR_EQUAL) reduce 448) ((T_IS_IDENTICAL) reduce 448) ((T_IS_NOT_EQUAL) reduce 448) ((T_IS_NOT_IDENTICAL) reduce 448) ((T_IS_SMALLER_OR_EQUAL) reduce 448) ((T_LOGICAL_AND) reduce 448) ((T_LOGICAL_OR) reduce 448) ((T_LOGICAL_XOR) reduce 448) ((T_POW) reduce 448) ((T_SL) reduce 448) ((T_SPACESHIP) reduce 448) ((T_SR) reduce 448) (("^") reduce 448) (("|") reduce 448)) 16295 ((("!") reduce 247) (("\"") reduce 247) (("$") reduce 247) (("(") reduce 247) (("+") reduce 247) (("-") reduce 247) ((";") reduce 247) (("@") reduce 247) ((T_ABSTRACT) reduce 247) ((T_ARRAY) reduce 247) ((T_ARRAY_CAST) reduce 247) ((T_ATTRIBUTE) reduce 247) ((T_BOOL_CAST) reduce 247) ((T_BREAK) reduce 247) ((T_CLASS) reduce 247) ((T_CLASS_C) reduce 247) ((T_CLONE) reduce 247) ((T_CONSTANT_ENCAPSED_STRING) reduce 247) ((T_CONTINUE) reduce 247) ((T_DEC) reduce 247) ((T_DECLARE) reduce 247) ((T_DIR) reduce 247) ((T_DNUMBER) reduce 247) ((T_DO) reduce 247) ((T_DOUBLE_CAST) reduce 247) ((T_ECHO) reduce 247) ((T_ELSE) reduce 247) ((T_ELSEIF) reduce 247) ((T_EMPTY) reduce 247) ((T_ENDIF) reduce 247) ((T_ENUM) reduce 247) ((T_EVAL) reduce 247) ((T_EXIT) reduce 247) ((T_FILE) reduce 247) ((T_FINAL) reduce 247) ((T_FN) reduce 247) ((T_FOR) reduce 247) ((T_FOREACH) reduce 247) ((T_FUNCTION) reduce 247) ((T_FUNC_C) reduce 247) ((T_GLOBAL) reduce 247) ((T_GOTO) reduce 247) ((T_HALT_COMPILER) reduce 247) ((T_IF) reduce 247) ((T_INC) reduce 247) ((T_INCLUDE) reduce 247) ((T_INCLUDE_ONCE) reduce 247) ((T_INLINE_HTML) reduce 247) ((T_INTERFACE) reduce 247) ((T_INT_CAST) reduce 247) ((T_ISSET) reduce 247) ((T_LINE) reduce 247) ((T_LIST) reduce 247) ((T_LNUMBER) reduce 247) ((T_MATCH) reduce 247) ((T_METHOD_C) reduce 247) ((T_NAME_FULLY_QUALIFIED) reduce 247) ((T_NAME_QUALIFIED) reduce 247) ((T_NAME_RELATIVE) reduce 247) ((T_NEW) reduce 247) ((T_NS_C) reduce 247) ((T_OBJECT_CAST) reduce 247) ((T_PRINT) reduce 247) ((T_READONLY) reduce 247) ((T_REQUIRE) reduce 247) ((T_REQUIRE_ONCE) reduce 247) ((T_RETURN) reduce 247) ((T_START_HEREDOC) reduce 247) ((T_STATIC) reduce 247) ((T_STRING) reduce 247) ((T_STRING_CAST) reduce 247) ((T_SWITCH) reduce 247) ((T_THROW) reduce 247) ((T_TRAIT) reduce 247) ((T_TRAIT_C) reduce 247) ((T_TRY) reduce 247) ((T_UNSET) reduce 247) ((T_UNSET_CAST) reduce 247) ((T_VARIABLE) reduce 247) ((T_WHILE) reduce 247) ((T_YIELD) reduce 247) ((T_YIELD_FROM) reduce 247) (("[") reduce 247) (("`") reduce 247) (("{") reduce 247) (("~") reduce 247)) 16296 ((("!") reduce 140) (("\"") reduce 140) (("$") reduce 140) (("(") reduce 140) (("+") reduce 140) (("-") reduce 140) ((";") reduce 140) (("@") reduce 140) ((T_ABSTRACT) reduce 140) ((T_ARRAY) reduce 140) ((T_ARRAY_CAST) reduce 140) ((T_ATTRIBUTE) reduce 140) ((T_BOOL_CAST) reduce 140) ((T_BREAK) reduce 140) ((T_CLASS) reduce 140) ((T_CLASS_C) reduce 140) ((T_CLONE) reduce 140) ((T_CONSTANT_ENCAPSED_STRING) reduce 140) ((T_CONTINUE) reduce 140) ((T_DEC) reduce 140) ((T_DECLARE) reduce 140) ((T_DIR) reduce 140) ((T_DNUMBER) reduce 140) ((T_DO) reduce 140) ((T_DOUBLE_CAST) reduce 140) ((T_ECHO) reduce 140) ((T_EMPTY) reduce 140) ((T_ENDIF) reduce 140) ((T_ENUM) reduce 140) ((T_EVAL) reduce 140) ((T_EXIT) reduce 140) ((T_FILE) reduce 140) ((T_FINAL) reduce 140) ((T_FN) reduce 140) ((T_FOR) reduce 140) ((T_FOREACH) reduce 140) ((T_FUNCTION) reduce 140) ((T_FUNC_C) reduce 140) ((T_GLOBAL) reduce 140) ((T_GOTO) reduce 140) ((T_HALT_COMPILER) reduce 140) ((T_IF) reduce 140) ((T_INC) reduce 140) ((T_INCLUDE) reduce 140) ((T_INCLUDE_ONCE) reduce 140) ((T_INLINE_HTML) reduce 140) ((T_INTERFACE) reduce 140) ((T_INT_CAST) reduce 140) ((T_ISSET) reduce 140) ((T_LINE) reduce 140) ((T_LIST) reduce 140) ((T_LNUMBER) reduce 140) ((T_MATCH) reduce 140) ((T_METHOD_C) reduce 140) ((T_NAME_FULLY_QUALIFIED) reduce 140) ((T_NAME_QUALIFIED) reduce 140) ((T_NAME_RELATIVE) reduce 140) ((T_NEW) reduce 140) ((T_NS_C) reduce 140) ((T_OBJECT_CAST) reduce 140) ((T_PRINT) reduce 140) ((T_READONLY) reduce 140) ((T_REQUIRE) reduce 140) ((T_REQUIRE_ONCE) reduce 140) ((T_RETURN) reduce 140) ((T_START_HEREDOC) reduce 140) ((T_STATIC) reduce 140) ((T_STRING) reduce 140) ((T_STRING_CAST) reduce 140) ((T_SWITCH) reduce 140) ((T_THROW) reduce 140) ((T_TRAIT) reduce 140) ((T_TRAIT_C) reduce 140) ((T_TRY) reduce 140) ((T_UNSET) reduce 140) ((T_UNSET_CAST) reduce 140) ((T_VARIABLE) reduce 140) ((T_WHILE) reduce 140) ((T_YIELD) reduce 140) ((T_YIELD_FROM) reduce 140) (("[") reduce 140) (("`") reduce 140) (("{") reduce 140) (("~") reduce 140)) 16297 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) (("+") shift) (("-") shift) ((";") shift) (("@") shift) ((T_ABSTRACT) shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_BREAK) shift) ((T_CLASS) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_CONTINUE) shift) ((T_DEC) shift) ((T_DECLARE) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DO) shift) ((T_DOUBLE_CAST) shift) ((T_ECHO) shift) ((T_EMPTY) shift) ((T_ENDIF) shift) ((T_ENUM) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FINAL) shift) ((T_FN) shift) ((T_FOR) shift) ((T_FOREACH) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_GLOBAL) shift) ((T_GOTO) shift) ((T_HALT_COMPILER) shift) ((T_IF) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INLINE_HTML) shift) ((T_INTERFACE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_RETURN) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_SWITCH) shift) ((T_THROW) shift) ((T_TRAIT) shift) ((T_TRAIT_C) shift) ((T_TRY) shift) ((T_UNSET) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_WHILE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("{") shift) (("~") shift)) 16298 ((("!") reduce 164) (("\"") reduce 164) (("$") reduce 164) (("(") reduce 164) (("+") reduce 164) (("-") reduce 164) ((";") reduce 164) (("@") reduce 164) ((T_ABSTRACT) reduce 164) ((T_ARRAY) reduce 164) ((T_ARRAY_CAST) reduce 164) ((T_ATTRIBUTE) reduce 164) ((T_BOOL_CAST) reduce 164) ((T_BREAK) reduce 164) ((T_CLASS) reduce 164) ((T_CLASS_C) reduce 164) ((T_CLONE) reduce 164) ((T_CONSTANT_ENCAPSED_STRING) reduce 164) ((T_CONTINUE) reduce 164) ((T_DEC) reduce 164) ((T_DECLARE) reduce 164) ((T_DIR) reduce 164) ((T_DNUMBER) reduce 164) ((T_DO) reduce 164) ((T_DOUBLE_CAST) reduce 164) ((T_ECHO) reduce 164) ((T_EMPTY) reduce 164) ((T_ENDIF) reduce 164) ((T_ENUM) reduce 164) ((T_EVAL) reduce 164) ((T_EXIT) reduce 164) ((T_FILE) reduce 164) ((T_FINAL) reduce 164) ((T_FN) reduce 164) ((T_FOR) reduce 164) ((T_FOREACH) reduce 164) ((T_FUNCTION) reduce 164) ((T_FUNC_C) reduce 164) ((T_GLOBAL) reduce 164) ((T_GOTO) reduce 164) ((T_HALT_COMPILER) reduce 164) ((T_IF) reduce 164) ((T_INC) reduce 164) ((T_INCLUDE) reduce 164) ((T_INCLUDE_ONCE) reduce 164) ((T_INLINE_HTML) reduce 164) ((T_INTERFACE) reduce 164) ((T_INT_CAST) reduce 164) ((T_ISSET) reduce 164) ((T_LINE) reduce 164) ((T_LIST) reduce 164) ((T_LNUMBER) reduce 164) ((T_MATCH) reduce 164) ((T_METHOD_C) reduce 164) ((T_NAME_FULLY_QUALIFIED) reduce 164) ((T_NAME_QUALIFIED) reduce 164) ((T_NAME_RELATIVE) reduce 164) ((T_NEW) reduce 164) ((T_NS_C) reduce 164) ((T_OBJECT_CAST) reduce 164) ((T_PRINT) reduce 164) ((T_READONLY) reduce 164) ((T_REQUIRE) reduce 164) ((T_REQUIRE_ONCE) reduce 164) ((T_RETURN) reduce 164) ((T_START_HEREDOC) reduce 164) ((T_STATIC) reduce 164) ((T_STRING) reduce 164) ((T_STRING_CAST) reduce 164) ((T_SWITCH) reduce 164) ((T_THROW) reduce 164) ((T_TRAIT) reduce 164) ((T_TRAIT_C) reduce 164) ((T_TRY) reduce 164) ((T_UNSET) reduce 164) ((T_UNSET_CAST) reduce 164) ((T_VARIABLE) reduce 164) ((T_WHILE) reduce 164) ((T_YIELD) reduce 164) ((T_YIELD_FROM) reduce 164) (("[") reduce 164) (("`") reduce 164) (("{") reduce 164) (("~") reduce 164)) 16312 ((("!") reduce 158) (("\"") reduce 158) (("$") reduce 158) (("(") reduce 158) (("+") reduce 158) (("-") reduce 158) ((";") reduce 158) (("@") reduce 158) ((T_ABSTRACT) reduce 158) ((T_ARRAY) reduce 158) ((T_ARRAY_CAST) reduce 158) ((T_ATTRIBUTE) reduce 158) ((T_BOOL_CAST) reduce 158) ((T_BREAK) reduce 158) ((T_CLASS) reduce 158) ((T_CLASS_C) reduce 158) ((T_CLONE) reduce 158) ((T_CONSTANT_ENCAPSED_STRING) reduce 158) ((T_CONTINUE) reduce 158) ((T_DEC) reduce 158) ((T_DECLARE) reduce 158) ((T_DIR) reduce 158) ((T_DNUMBER) reduce 158) ((T_DO) reduce 158) ((T_DOUBLE_CAST) reduce 158) ((T_ECHO) reduce 158) ((T_EMPTY) reduce 158) ((T_ENDIF) reduce 158) ((T_ENUM) reduce 158) ((T_EVAL) reduce 158) ((T_EXIT) reduce 158) ((T_FILE) reduce 158) ((T_FINAL) reduce 158) ((T_FN) reduce 158) ((T_FOR) reduce 158) ((T_FOREACH) reduce 158) ((T_FUNCTION) reduce 158) ((T_FUNC_C) reduce 158) ((T_GLOBAL) reduce 158) ((T_GOTO) reduce 158) ((T_HALT_COMPILER) reduce 158) ((T_IF) reduce 158) ((T_INC) reduce 158) ((T_INCLUDE) reduce 158) ((T_INCLUDE_ONCE) reduce 158) ((T_INLINE_HTML) reduce 158) ((T_INTERFACE) reduce 158) ((T_INT_CAST) reduce 158) ((T_ISSET) reduce 158) ((T_LINE) reduce 158) ((T_LIST) reduce 158) ((T_LNUMBER) reduce 158) ((T_MATCH) reduce 158) ((T_METHOD_C) reduce 158) ((T_NAME_FULLY_QUALIFIED) reduce 158) ((T_NAME_QUALIFIED) reduce 158) ((T_NAME_RELATIVE) reduce 158) ((T_NEW) reduce 158) ((T_NS_C) reduce 158) ((T_OBJECT_CAST) reduce 158) ((T_PRINT) reduce 158) ((T_READONLY) reduce 158) ((T_REQUIRE) reduce 158) ((T_REQUIRE_ONCE) reduce 158) ((T_RETURN) reduce 158) ((T_START_HEREDOC) reduce 158) ((T_STATIC) reduce 158) ((T_STRING) reduce 158) ((T_STRING_CAST) reduce 158) ((T_SWITCH) reduce 158) ((T_THROW) reduce 158) ((T_TRAIT) reduce 158) ((T_TRAIT_C) reduce 158) ((T_TRY) reduce 158) ((T_UNSET) reduce 158) ((T_UNSET_CAST) reduce 158) ((T_VARIABLE) reduce 158) ((T_WHILE) reduce 158) ((T_YIELD) reduce 158) ((T_YIELD_FROM) reduce 158) (("[") reduce 158) (("`") reduce 158) (("{") reduce 158) (("~") reduce 158)) 16322 ((("!") reduce 147) (("\"") reduce 147) (("$") reduce 147) (("(") reduce 147) (("+") reduce 147) (("-") reduce 147) ((";") reduce 147) (("@") reduce 147) ((T_ABSTRACT) reduce 147) ((T_ARRAY) reduce 147) ((T_ARRAY_CAST) reduce 147) ((T_ATTRIBUTE) reduce 147) ((T_BOOL_CAST) reduce 147) ((T_BREAK) reduce 147) ((T_CLASS) reduce 147) ((T_CLASS_C) reduce 147) ((T_CLONE) reduce 147) ((T_CONSTANT_ENCAPSED_STRING) reduce 147) ((T_CONTINUE) reduce 147) ((T_DEC) reduce 147) ((T_DECLARE) reduce 147) ((T_DIR) reduce 147) ((T_DNUMBER) reduce 147) ((T_DO) reduce 147) ((T_DOUBLE_CAST) reduce 147) ((T_ECHO) reduce 147) ((T_EMPTY) reduce 147) ((T_ENDIF) reduce 147) ((T_ENUM) reduce 147) ((T_EVAL) reduce 147) ((T_EXIT) reduce 147) ((T_FILE) reduce 147) ((T_FINAL) reduce 147) ((T_FN) reduce 147) ((T_FOR) reduce 147) ((T_FOREACH) reduce 147) ((T_FUNCTION) reduce 147) ((T_FUNC_C) reduce 147) ((T_GLOBAL) reduce 147) ((T_GOTO) reduce 147) ((T_HALT_COMPILER) reduce 147) ((T_IF) reduce 147) ((T_INC) reduce 147) ((T_INCLUDE) reduce 147) ((T_INCLUDE_ONCE) reduce 147) ((T_INLINE_HTML) reduce 147) ((T_INTERFACE) reduce 147) ((T_INT_CAST) reduce 147) ((T_ISSET) reduce 147) ((T_LINE) reduce 147) ((T_LIST) reduce 147) ((T_LNUMBER) reduce 147) ((T_MATCH) reduce 147) ((T_METHOD_C) reduce 147) ((T_NAME_FULLY_QUALIFIED) reduce 147) ((T_NAME_QUALIFIED) reduce 147) ((T_NAME_RELATIVE) reduce 147) ((T_NEW) reduce 147) ((T_NS_C) reduce 147) ((T_OBJECT_CAST) reduce 147) ((T_PRINT) reduce 147) ((T_READONLY) reduce 147) ((T_REQUIRE) reduce 147) ((T_REQUIRE_ONCE) reduce 147) ((T_RETURN) reduce 147) ((T_START_HEREDOC) reduce 147) ((T_STATIC) reduce 147) ((T_STRING) reduce 147) ((T_STRING_CAST) reduce 147) ((T_SWITCH) reduce 147) ((T_THROW) reduce 147) ((T_TRAIT) reduce 147) ((T_TRAIT_C) reduce 147) ((T_TRY) reduce 147) ((T_UNSET) reduce 147) ((T_UNSET_CAST) reduce 147) ((T_VARIABLE) reduce 147) ((T_WHILE) reduce 147) ((T_YIELD) reduce 147) ((T_YIELD_FROM) reduce 147) (("[") reduce 147) (("`") reduce 147) (("{") reduce 147) (("~") reduce 147)) 16324 ((("!") reduce 142) (("\"") reduce 142) (("$") reduce 142) (("(") reduce 142) (("+") reduce 142) (("-") reduce 142) ((";") reduce 142) (("@") reduce 142) ((T_ABSTRACT) reduce 142) ((T_ARRAY) reduce 142) ((T_ARRAY_CAST) reduce 142) ((T_ATTRIBUTE) reduce 142) ((T_BOOL_CAST) reduce 142) ((T_BREAK) reduce 142) ((T_CLASS) reduce 142) ((T_CLASS_C) reduce 142) ((T_CLONE) reduce 142) ((T_CONSTANT_ENCAPSED_STRING) reduce 142) ((T_CONTINUE) reduce 142) ((T_DEC) reduce 142) ((T_DECLARE) reduce 142) ((T_DIR) reduce 142) ((T_DNUMBER) reduce 142) ((T_DO) reduce 142) ((T_DOUBLE_CAST) reduce 142) ((T_ECHO) reduce 142) ((T_EMPTY) reduce 142) ((T_ENDIF) reduce 142) ((T_ENUM) reduce 142) ((T_EVAL) reduce 142) ((T_EXIT) reduce 142) ((T_FILE) reduce 142) ((T_FINAL) reduce 142) ((T_FN) reduce 142) ((T_FOR) reduce 142) ((T_FOREACH) reduce 142) ((T_FUNCTION) reduce 142) ((T_FUNC_C) reduce 142) ((T_GLOBAL) reduce 142) ((T_GOTO) reduce 142) ((T_HALT_COMPILER) reduce 142) ((T_IF) reduce 142) ((T_INC) reduce 142) ((T_INCLUDE) reduce 142) ((T_INCLUDE_ONCE) reduce 142) ((T_INLINE_HTML) reduce 142) ((T_INTERFACE) reduce 142) ((T_INT_CAST) reduce 142) ((T_ISSET) reduce 142) ((T_LINE) reduce 142) ((T_LIST) reduce 142) ((T_LNUMBER) reduce 142) ((T_MATCH) reduce 142) ((T_METHOD_C) reduce 142) ((T_NAME_FULLY_QUALIFIED) reduce 142) ((T_NAME_QUALIFIED) reduce 142) ((T_NAME_RELATIVE) reduce 142) ((T_NEW) reduce 142) ((T_NS_C) reduce 142) ((T_OBJECT_CAST) reduce 142) ((T_PRINT) reduce 142) ((T_READONLY) reduce 142) ((T_REQUIRE) reduce 142) ((T_REQUIRE_ONCE) reduce 142) ((T_RETURN) reduce 142) ((T_START_HEREDOC) reduce 142) ((T_STATIC) reduce 142) ((T_STRING) reduce 142) ((T_STRING_CAST) reduce 142) ((T_SWITCH) reduce 142) ((T_THROW) reduce 142) ((T_TRAIT) reduce 142) ((T_TRAIT_C) reduce 142) ((T_TRY) reduce 142) ((T_UNSET) reduce 142) ((T_UNSET_CAST) reduce 142) ((T_VARIABLE) reduce 142) ((T_WHILE) reduce 142) ((T_YIELD) reduce 142) ((T_YIELD_FROM) reduce 142) (("[") reduce 142) (("`") reduce 142) (("{") reduce 142) (("~") reduce 142)) 16326 ((("!") reduce 103) (("\"") reduce 103) (("$") reduce 103) (("(") reduce 103) (("+") reduce 103) (("-") reduce 103) ((";") reduce 103) (("@") reduce 103) ((T_ABSTRACT) reduce 103) ((T_ARRAY) reduce 103) ((T_ARRAY_CAST) reduce 103) ((T_ATTRIBUTE) reduce 103) ((T_BOOL_CAST) reduce 103) ((T_BREAK) reduce 103) ((T_CLASS) reduce 103) ((T_CLASS_C) reduce 103) ((T_CLONE) reduce 103) ((T_CONSTANT_ENCAPSED_STRING) reduce 103) ((T_CONTINUE) reduce 103) ((T_DEC) reduce 103) ((T_DECLARE) reduce 103) ((T_DIR) reduce 103) ((T_DNUMBER) reduce 103) ((T_DO) reduce 103) ((T_DOUBLE_CAST) reduce 103) ((T_ECHO) reduce 103) ((T_EMPTY) reduce 103) ((T_ENDIF) reduce 103) ((T_ENUM) reduce 103) ((T_EVAL) reduce 103) ((T_EXIT) reduce 103) ((T_FILE) reduce 103) ((T_FINAL) reduce 103) ((T_FN) reduce 103) ((T_FOR) reduce 103) ((T_FOREACH) reduce 103) ((T_FUNCTION) reduce 103) ((T_FUNC_C) reduce 103) ((T_GLOBAL) reduce 103) ((T_GOTO) reduce 103) ((T_HALT_COMPILER) reduce 103) ((T_IF) reduce 103) ((T_INC) reduce 103) ((T_INCLUDE) reduce 103) ((T_INCLUDE_ONCE) reduce 103) ((T_INLINE_HTML) reduce 103) ((T_INTERFACE) reduce 103) ((T_INT_CAST) reduce 103) ((T_ISSET) reduce 103) ((T_LINE) reduce 103) ((T_LIST) reduce 103) ((T_LNUMBER) reduce 103) ((T_MATCH) reduce 103) ((T_METHOD_C) reduce 103) ((T_NAME_FULLY_QUALIFIED) reduce 103) ((T_NAME_QUALIFIED) reduce 103) ((T_NAME_RELATIVE) reduce 103) ((T_NEW) reduce 103) ((T_NS_C) reduce 103) ((T_OBJECT_CAST) reduce 103) ((T_PRINT) reduce 103) ((T_READONLY) reduce 103) ((T_REQUIRE) reduce 103) ((T_REQUIRE_ONCE) reduce 103) ((T_RETURN) reduce 103) ((T_START_HEREDOC) reduce 103) ((T_STATIC) reduce 103) ((T_STRING) reduce 103) ((T_STRING_CAST) reduce 103) ((T_SWITCH) reduce 103) ((T_THROW) reduce 103) ((T_TRAIT) reduce 103) ((T_TRAIT_C) reduce 103) ((T_TRY) reduce 103) ((T_UNSET) reduce 103) ((T_UNSET_CAST) reduce 103) ((T_VARIABLE) reduce 103) ((T_WHILE) reduce 103) ((T_YIELD) reduce 103) ((T_YIELD_FROM) reduce 103) (("[") reduce 103) (("`") reduce 103) (("{") reduce 103) (("~") reduce 103)) 16328 ((("!") reduce 106) (("\"") reduce 106) (("$") reduce 106) (("(") reduce 106) (("+") reduce 106) (("-") reduce 106) ((";") reduce 106) (("@") reduce 106) ((T_ABSTRACT) reduce 106) ((T_ARRAY) reduce 106) ((T_ARRAY_CAST) reduce 106) ((T_ATTRIBUTE) reduce 106) ((T_BOOL_CAST) reduce 106) ((T_BREAK) reduce 106) ((T_CLASS) reduce 106) ((T_CLASS_C) reduce 106) ((T_CLONE) reduce 106) ((T_CONSTANT_ENCAPSED_STRING) reduce 106) ((T_CONTINUE) reduce 106) ((T_DEC) reduce 106) ((T_DECLARE) reduce 106) ((T_DIR) reduce 106) ((T_DNUMBER) reduce 106) ((T_DO) reduce 106) ((T_DOUBLE_CAST) reduce 106) ((T_ECHO) reduce 106) ((T_EMPTY) reduce 106) ((T_ENDIF) reduce 106) ((T_ENUM) reduce 106) ((T_EVAL) reduce 106) ((T_EXIT) reduce 106) ((T_FILE) reduce 106) ((T_FINAL) reduce 106) ((T_FN) reduce 106) ((T_FOR) reduce 106) ((T_FOREACH) reduce 106) ((T_FUNCTION) reduce 106) ((T_FUNC_C) reduce 106) ((T_GLOBAL) reduce 106) ((T_GOTO) reduce 106) ((T_HALT_COMPILER) reduce 106) ((T_IF) reduce 106) ((T_INC) reduce 106) ((T_INCLUDE) reduce 106) ((T_INCLUDE_ONCE) reduce 106) ((T_INLINE_HTML) reduce 106) ((T_INTERFACE) reduce 106) ((T_INT_CAST) reduce 106) ((T_ISSET) reduce 106) ((T_LINE) reduce 106) ((T_LIST) reduce 106) ((T_LNUMBER) reduce 106) ((T_MATCH) reduce 106) ((T_METHOD_C) reduce 106) ((T_NAME_FULLY_QUALIFIED) reduce 106) ((T_NAME_QUALIFIED) reduce 106) ((T_NAME_RELATIVE) reduce 106) ((T_NEW) reduce 106) ((T_NS_C) reduce 106) ((T_OBJECT_CAST) reduce 106) ((T_PRINT) reduce 106) ((T_READONLY) reduce 106) ((T_REQUIRE) reduce 106) ((T_REQUIRE_ONCE) reduce 106) ((T_RETURN) reduce 106) ((T_START_HEREDOC) reduce 106) ((T_STATIC) reduce 106) ((T_STRING) reduce 106) ((T_STRING_CAST) reduce 106) ((T_SWITCH) reduce 106) ((T_THROW) reduce 106) ((T_TRAIT) reduce 106) ((T_TRAIT_C) reduce 106) ((T_TRY) reduce 106) ((T_UNSET) reduce 106) ((T_UNSET_CAST) reduce 106) ((T_VARIABLE) reduce 106) ((T_WHILE) reduce 106) ((T_YIELD) reduce 106) ((T_YIELD_FROM) reduce 106) (("[") reduce 106) (("`") reduce 106) (("{") reduce 106) (("~") reduce 106)) 16331 ((("!") reduce 102) (("\"") reduce 102) (("$") reduce 102) (("(") reduce 102) (("+") reduce 102) (("-") reduce 102) ((";") reduce 102) (("@") reduce 102) ((T_ABSTRACT) reduce 102) ((T_ARRAY) reduce 102) ((T_ARRAY_CAST) reduce 102) ((T_ATTRIBUTE) reduce 102) ((T_BOOL_CAST) reduce 102) ((T_BREAK) reduce 102) ((T_CLASS) reduce 102) ((T_CLASS_C) reduce 102) ((T_CLONE) reduce 102) ((T_CONSTANT_ENCAPSED_STRING) reduce 102) ((T_CONTINUE) reduce 102) ((T_DEC) reduce 102) ((T_DECLARE) reduce 102) ((T_DIR) reduce 102) ((T_DNUMBER) reduce 102) ((T_DO) reduce 102) ((T_DOUBLE_CAST) reduce 102) ((T_ECHO) reduce 102) ((T_EMPTY) reduce 102) ((T_ENDIF) reduce 102) ((T_ENUM) reduce 102) ((T_EVAL) reduce 102) ((T_EXIT) reduce 102) ((T_FILE) reduce 102) ((T_FINAL) reduce 102) ((T_FN) reduce 102) ((T_FOR) reduce 102) ((T_FOREACH) reduce 102) ((T_FUNCTION) reduce 102) ((T_FUNC_C) reduce 102) ((T_GLOBAL) reduce 102) ((T_GOTO) reduce 102) ((T_HALT_COMPILER) reduce 102) ((T_IF) reduce 102) ((T_INC) reduce 102) ((T_INCLUDE) reduce 102) ((T_INCLUDE_ONCE) reduce 102) ((T_INLINE_HTML) reduce 102) ((T_INTERFACE) reduce 102) ((T_INT_CAST) reduce 102) ((T_ISSET) reduce 102) ((T_LINE) reduce 102) ((T_LIST) reduce 102) ((T_LNUMBER) reduce 102) ((T_MATCH) reduce 102) ((T_METHOD_C) reduce 102) ((T_NAME_FULLY_QUALIFIED) reduce 102) ((T_NAME_QUALIFIED) reduce 102) ((T_NAME_RELATIVE) reduce 102) ((T_NEW) reduce 102) ((T_NS_C) reduce 102) ((T_OBJECT_CAST) reduce 102) ((T_PRINT) reduce 102) ((T_READONLY) reduce 102) ((T_REQUIRE) reduce 102) ((T_REQUIRE_ONCE) reduce 102) ((T_RETURN) reduce 102) ((T_START_HEREDOC) reduce 102) ((T_STATIC) reduce 102) ((T_STRING) reduce 102) ((T_STRING_CAST) reduce 102) ((T_SWITCH) reduce 102) ((T_THROW) reduce 102) ((T_TRAIT) reduce 102) ((T_TRAIT_C) reduce 102) ((T_TRY) reduce 102) ((T_UNSET) reduce 102) ((T_UNSET_CAST) reduce 102) ((T_VARIABLE) reduce 102) ((T_WHILE) reduce 102) ((T_YIELD) reduce 102) ((T_YIELD_FROM) reduce 102) (("[") reduce 102) (("`") reduce 102) (("{") reduce 102) (("~") reduce 102)) 16332 ((("!") reduce 146) (("\"") reduce 146) (("$") reduce 146) (("(") reduce 146) (("+") reduce 146) (("-") reduce 146) ((";") reduce 146) (("@") reduce 146) ((T_ABSTRACT) reduce 146) ((T_ARRAY) reduce 146) ((T_ARRAY_CAST) reduce 146) ((T_ATTRIBUTE) reduce 146) ((T_BOOL_CAST) reduce 146) ((T_BREAK) reduce 146) ((T_CLASS) reduce 146) ((T_CLASS_C) reduce 146) ((T_CLONE) reduce 146) ((T_CONSTANT_ENCAPSED_STRING) reduce 146) ((T_CONTINUE) reduce 146) ((T_DEC) reduce 146) ((T_DECLARE) reduce 146) ((T_DIR) reduce 146) ((T_DNUMBER) reduce 146) ((T_DO) reduce 146) ((T_DOUBLE_CAST) reduce 146) ((T_ECHO) reduce 146) ((T_EMPTY) reduce 146) ((T_ENDIF) reduce 146) ((T_ENUM) reduce 146) ((T_EVAL) reduce 146) ((T_EXIT) reduce 146) ((T_FILE) reduce 146) ((T_FINAL) reduce 146) ((T_FN) reduce 146) ((T_FOR) reduce 146) ((T_FOREACH) reduce 146) ((T_FUNCTION) reduce 146) ((T_FUNC_C) reduce 146) ((T_GLOBAL) reduce 146) ((T_GOTO) reduce 146) ((T_HALT_COMPILER) reduce 146) ((T_IF) reduce 146) ((T_INC) reduce 146) ((T_INCLUDE) reduce 146) ((T_INCLUDE_ONCE) reduce 146) ((T_INLINE_HTML) reduce 146) ((T_INTERFACE) reduce 146) ((T_INT_CAST) reduce 146) ((T_ISSET) reduce 146) ((T_LINE) reduce 146) ((T_LIST) reduce 146) ((T_LNUMBER) reduce 146) ((T_MATCH) reduce 146) ((T_METHOD_C) reduce 146) ((T_NAME_FULLY_QUALIFIED) reduce 146) ((T_NAME_QUALIFIED) reduce 146) ((T_NAME_RELATIVE) reduce 146) ((T_NEW) reduce 146) ((T_NS_C) reduce 146) ((T_OBJECT_CAST) reduce 146) ((T_PRINT) reduce 146) ((T_READONLY) reduce 146) ((T_REQUIRE) reduce 146) ((T_REQUIRE_ONCE) reduce 146) ((T_RETURN) reduce 146) ((T_START_HEREDOC) reduce 146) ((T_STATIC) reduce 146) ((T_STRING) reduce 146) ((T_STRING_CAST) reduce 146) ((T_SWITCH) reduce 146) ((T_THROW) reduce 146) ((T_TRAIT) reduce 146) ((T_TRAIT_C) reduce 146) ((T_TRY) reduce 146) ((T_UNSET) reduce 146) ((T_UNSET_CAST) reduce 146) ((T_VARIABLE) reduce 146) ((T_WHILE) reduce 146) ((T_YIELD) reduce 146) ((T_YIELD_FROM) reduce 146) (("[") reduce 146) (("`") reduce 146) (("{") reduce 146) (("~") reduce 146)) 16334 ((("!") reduce 139) (("\"") reduce 139) (("$") reduce 139) (("(") reduce 139) (("+") reduce 139) (("-") reduce 139) ((";") reduce 139) (("@") reduce 139) ((T_ABSTRACT) reduce 139) ((T_ARRAY) reduce 139) ((T_ARRAY_CAST) reduce 139) ((T_ATTRIBUTE) reduce 139) ((T_BOOL_CAST) reduce 139) ((T_BREAK) reduce 139) ((T_CLASS) reduce 139) ((T_CLASS_C) reduce 139) ((T_CLONE) reduce 139) ((T_CONSTANT_ENCAPSED_STRING) reduce 139) ((T_CONTINUE) reduce 139) ((T_DEC) reduce 139) ((T_DECLARE) reduce 139) ((T_DIR) reduce 139) ((T_DNUMBER) reduce 139) ((T_DO) reduce 139) ((T_DOUBLE_CAST) reduce 139) ((T_ECHO) reduce 139) ((T_EMPTY) reduce 139) ((T_ENDIF) reduce 139) ((T_ENUM) reduce 139) ((T_EVAL) reduce 139) ((T_EXIT) reduce 139) ((T_FILE) reduce 139) ((T_FINAL) reduce 139) ((T_FN) reduce 139) ((T_FOR) reduce 139) ((T_FOREACH) reduce 139) ((T_FUNCTION) reduce 139) ((T_FUNC_C) reduce 139) ((T_GLOBAL) reduce 139) ((T_GOTO) reduce 139) ((T_HALT_COMPILER) reduce 139) ((T_IF) reduce 139) ((T_INC) reduce 139) ((T_INCLUDE) reduce 139) ((T_INCLUDE_ONCE) reduce 139) ((T_INLINE_HTML) reduce 139) ((T_INTERFACE) reduce 139) ((T_INT_CAST) reduce 139) ((T_ISSET) reduce 139) ((T_LINE) reduce 139) ((T_LIST) reduce 139) ((T_LNUMBER) reduce 139) ((T_MATCH) reduce 139) ((T_METHOD_C) reduce 139) ((T_NAME_FULLY_QUALIFIED) reduce 139) ((T_NAME_QUALIFIED) reduce 139) ((T_NAME_RELATIVE) reduce 139) ((T_NEW) reduce 139) ((T_NS_C) reduce 139) ((T_OBJECT_CAST) reduce 139) ((T_PRINT) reduce 139) ((T_READONLY) reduce 139) ((T_REQUIRE) reduce 139) ((T_REQUIRE_ONCE) reduce 139) ((T_RETURN) reduce 139) ((T_START_HEREDOC) reduce 139) ((T_STATIC) reduce 139) ((T_STRING) reduce 139) ((T_STRING_CAST) reduce 139) ((T_SWITCH) reduce 139) ((T_THROW) reduce 139) ((T_TRAIT) reduce 139) ((T_TRAIT_C) reduce 139) ((T_TRY) reduce 139) ((T_UNSET) reduce 139) ((T_UNSET_CAST) reduce 139) ((T_VARIABLE) reduce 139) ((T_WHILE) reduce 139) ((T_YIELD) reduce 139) ((T_YIELD_FROM) reduce 139) (("[") reduce 139) (("`") reduce 139) (("{") reduce 139) (("~") reduce 139)) 16335 ((("!") reduce 105) (("\"") reduce 105) (("$") reduce 105) (("(") reduce 105) (("+") reduce 105) (("-") reduce 105) ((";") reduce 105) (("@") reduce 105) ((T_ABSTRACT) reduce 105) ((T_ARRAY) reduce 105) ((T_ARRAY_CAST) reduce 105) ((T_ATTRIBUTE) reduce 105) ((T_BOOL_CAST) reduce 105) ((T_BREAK) reduce 105) ((T_CLASS) reduce 105) ((T_CLASS_C) reduce 105) ((T_CLONE) reduce 105) ((T_CONSTANT_ENCAPSED_STRING) reduce 105) ((T_CONTINUE) reduce 105) ((T_DEC) reduce 105) ((T_DECLARE) reduce 105) ((T_DIR) reduce 105) ((T_DNUMBER) reduce 105) ((T_DO) reduce 105) ((T_DOUBLE_CAST) reduce 105) ((T_ECHO) reduce 105) ((T_EMPTY) reduce 105) ((T_ENDIF) reduce 105) ((T_ENUM) reduce 105) ((T_EVAL) reduce 105) ((T_EXIT) reduce 105) ((T_FILE) reduce 105) ((T_FINAL) reduce 105) ((T_FN) reduce 105) ((T_FOR) reduce 105) ((T_FOREACH) reduce 105) ((T_FUNCTION) reduce 105) ((T_FUNC_C) reduce 105) ((T_GLOBAL) reduce 105) ((T_GOTO) reduce 105) ((T_HALT_COMPILER) reduce 105) ((T_IF) reduce 105) ((T_INC) reduce 105) ((T_INCLUDE) reduce 105) ((T_INCLUDE_ONCE) reduce 105) ((T_INLINE_HTML) reduce 105) ((T_INTERFACE) reduce 105) ((T_INT_CAST) reduce 105) ((T_ISSET) reduce 105) ((T_LINE) reduce 105) ((T_LIST) reduce 105) ((T_LNUMBER) reduce 105) ((T_MATCH) reduce 105) ((T_METHOD_C) reduce 105) ((T_NAME_FULLY_QUALIFIED) reduce 105) ((T_NAME_QUALIFIED) reduce 105) ((T_NAME_RELATIVE) reduce 105) ((T_NEW) reduce 105) ((T_NS_C) reduce 105) ((T_OBJECT_CAST) reduce 105) ((T_PRINT) reduce 105) ((T_READONLY) reduce 105) ((T_REQUIRE) reduce 105) ((T_REQUIRE_ONCE) reduce 105) ((T_RETURN) reduce 105) ((T_START_HEREDOC) reduce 105) ((T_STATIC) reduce 105) ((T_STRING) reduce 105) ((T_STRING_CAST) reduce 105) ((T_SWITCH) reduce 105) ((T_THROW) reduce 105) ((T_TRAIT) reduce 105) ((T_TRAIT_C) reduce 105) ((T_TRY) reduce 105) ((T_UNSET) reduce 105) ((T_UNSET_CAST) reduce 105) ((T_VARIABLE) reduce 105) ((T_WHILE) reduce 105) ((T_YIELD) reduce 105) ((T_YIELD_FROM) reduce 105) (("[") reduce 105) (("`") reduce 105) (("{") reduce 105) (("~") reduce 105)) 16336 ((("!") reduce 141) (("\"") reduce 141) (("$") reduce 141) (("(") reduce 141) (("+") reduce 141) (("-") reduce 141) ((";") reduce 141) (("@") reduce 141) ((T_ABSTRACT) reduce 141) ((T_ARRAY) reduce 141) ((T_ARRAY_CAST) reduce 141) ((T_ATTRIBUTE) reduce 141) ((T_BOOL_CAST) reduce 141) ((T_BREAK) reduce 141) ((T_CLASS) reduce 141) ((T_CLASS_C) reduce 141) ((T_CLONE) reduce 141) ((T_CONSTANT_ENCAPSED_STRING) reduce 141) ((T_CONTINUE) reduce 141) ((T_DEC) reduce 141) ((T_DECLARE) reduce 141) ((T_DIR) reduce 141) ((T_DNUMBER) reduce 141) ((T_DO) reduce 141) ((T_DOUBLE_CAST) reduce 141) ((T_ECHO) reduce 141) ((T_EMPTY) reduce 141) ((T_ENDIF) reduce 141) ((T_ENUM) reduce 141) ((T_EVAL) reduce 141) ((T_EXIT) reduce 141) ((T_FILE) reduce 141) ((T_FINAL) reduce 141) ((T_FN) reduce 141) ((T_FOR) reduce 141) ((T_FOREACH) reduce 141) ((T_FUNCTION) reduce 141) ((T_FUNC_C) reduce 141) ((T_GLOBAL) reduce 141) ((T_GOTO) reduce 141) ((T_HALT_COMPILER) reduce 141) ((T_IF) reduce 141) ((T_INC) reduce 141) ((T_INCLUDE) reduce 141) ((T_INCLUDE_ONCE) reduce 141) ((T_INLINE_HTML) reduce 141) ((T_INTERFACE) reduce 141) ((T_INT_CAST) reduce 141) ((T_ISSET) reduce 141) ((T_LINE) reduce 141) ((T_LIST) reduce 141) ((T_LNUMBER) reduce 141) ((T_MATCH) reduce 141) ((T_METHOD_C) reduce 141) ((T_NAME_FULLY_QUALIFIED) reduce 141) ((T_NAME_QUALIFIED) reduce 141) ((T_NAME_RELATIVE) reduce 141) ((T_NEW) reduce 141) ((T_NS_C) reduce 141) ((T_OBJECT_CAST) reduce 141) ((T_PRINT) reduce 141) ((T_READONLY) reduce 141) ((T_REQUIRE) reduce 141) ((T_REQUIRE_ONCE) reduce 141) ((T_RETURN) reduce 141) ((T_START_HEREDOC) reduce 141) ((T_STATIC) reduce 141) ((T_STRING) reduce 141) ((T_STRING_CAST) reduce 141) ((T_SWITCH) reduce 141) ((T_THROW) reduce 141) ((T_TRAIT) reduce 141) ((T_TRAIT_C) reduce 141) ((T_TRY) reduce 141) ((T_UNSET) reduce 141) ((T_UNSET_CAST) reduce 141) ((T_VARIABLE) reduce 141) ((T_WHILE) reduce 141) ((T_YIELD) reduce 141) ((T_YIELD_FROM) reduce 141) (("[") reduce 141) (("`") reduce 141) (("{") reduce 141) (("~") reduce 141)) 16337 ((("!") reduce 104) (("\"") reduce 104) (("$") reduce 104) (("(") reduce 104) (("+") reduce 104) (("-") reduce 104) ((";") reduce 104) (("@") reduce 104) ((T_ABSTRACT) reduce 104) ((T_ARRAY) reduce 104) ((T_ARRAY_CAST) reduce 104) ((T_ATTRIBUTE) reduce 104) ((T_BOOL_CAST) reduce 104) ((T_BREAK) reduce 104) ((T_CLASS) reduce 104) ((T_CLASS_C) reduce 104) ((T_CLONE) reduce 104) ((T_CONSTANT_ENCAPSED_STRING) reduce 104) ((T_CONTINUE) reduce 104) ((T_DEC) reduce 104) ((T_DECLARE) reduce 104) ((T_DIR) reduce 104) ((T_DNUMBER) reduce 104) ((T_DO) reduce 104) ((T_DOUBLE_CAST) reduce 104) ((T_ECHO) reduce 104) ((T_EMPTY) reduce 104) ((T_ENDIF) reduce 104) ((T_ENUM) reduce 104) ((T_EVAL) reduce 104) ((T_EXIT) reduce 104) ((T_FILE) reduce 104) ((T_FINAL) reduce 104) ((T_FN) reduce 104) ((T_FOR) reduce 104) ((T_FOREACH) reduce 104) ((T_FUNCTION) reduce 104) ((T_FUNC_C) reduce 104) ((T_GLOBAL) reduce 104) ((T_GOTO) reduce 104) ((T_HALT_COMPILER) reduce 104) ((T_IF) reduce 104) ((T_INC) reduce 104) ((T_INCLUDE) reduce 104) ((T_INCLUDE_ONCE) reduce 104) ((T_INLINE_HTML) reduce 104) ((T_INTERFACE) reduce 104) ((T_INT_CAST) reduce 104) ((T_ISSET) reduce 104) ((T_LINE) reduce 104) ((T_LIST) reduce 104) ((T_LNUMBER) reduce 104) ((T_MATCH) reduce 104) ((T_METHOD_C) reduce 104) ((T_NAME_FULLY_QUALIFIED) reduce 104) ((T_NAME_QUALIFIED) reduce 104) ((T_NAME_RELATIVE) reduce 104) ((T_NEW) reduce 104) ((T_NS_C) reduce 104) ((T_OBJECT_CAST) reduce 104) ((T_PRINT) reduce 104) ((T_READONLY) reduce 104) ((T_REQUIRE) reduce 104) ((T_REQUIRE_ONCE) reduce 104) ((T_RETURN) reduce 104) ((T_START_HEREDOC) reduce 104) ((T_STATIC) reduce 104) ((T_STRING) reduce 104) ((T_STRING_CAST) reduce 104) ((T_SWITCH) reduce 104) ((T_THROW) reduce 104) ((T_TRAIT) reduce 104) ((T_TRAIT_C) reduce 104) ((T_TRY) reduce 104) ((T_UNSET) reduce 104) ((T_UNSET_CAST) reduce 104) ((T_VARIABLE) reduce 104) ((T_WHILE) reduce 104) ((T_YIELD) reduce 104) ((T_YIELD_FROM) reduce 104) (("[") reduce 104) (("`") reduce 104) (("{") reduce 104) (("~") reduce 104)) 16340 ((("!") reduce 145) (("\"") reduce 145) (("$") reduce 145) (("(") reduce 145) (("+") reduce 145) (("-") reduce 145) ((";") reduce 145) (("@") reduce 145) ((T_ABSTRACT) reduce 145) ((T_ARRAY) reduce 145) ((T_ARRAY_CAST) reduce 145) ((T_ATTRIBUTE) reduce 145) ((T_BOOL_CAST) reduce 145) ((T_BREAK) reduce 145) ((T_CLASS) reduce 145) ((T_CLASS_C) reduce 145) ((T_CLONE) reduce 145) ((T_CONSTANT_ENCAPSED_STRING) reduce 145) ((T_CONTINUE) reduce 145) ((T_DEC) reduce 145) ((T_DECLARE) reduce 145) ((T_DIR) reduce 145) ((T_DNUMBER) reduce 145) ((T_DO) reduce 145) ((T_DOUBLE_CAST) reduce 145) ((T_ECHO) reduce 145) ((T_EMPTY) reduce 145) ((T_ENDIF) reduce 145) ((T_ENUM) reduce 145) ((T_EVAL) reduce 145) ((T_EXIT) reduce 145) ((T_FILE) reduce 145) ((T_FINAL) reduce 145) ((T_FN) reduce 145) ((T_FOR) reduce 145) ((T_FOREACH) reduce 145) ((T_FUNCTION) reduce 145) ((T_FUNC_C) reduce 145) ((T_GLOBAL) reduce 145) ((T_GOTO) reduce 145) ((T_HALT_COMPILER) reduce 145) ((T_IF) reduce 145) ((T_INC) reduce 145) ((T_INCLUDE) reduce 145) ((T_INCLUDE_ONCE) reduce 145) ((T_INLINE_HTML) reduce 145) ((T_INTERFACE) reduce 145) ((T_INT_CAST) reduce 145) ((T_ISSET) reduce 145) ((T_LINE) reduce 145) ((T_LIST) reduce 145) ((T_LNUMBER) reduce 145) ((T_MATCH) reduce 145) ((T_METHOD_C) reduce 145) ((T_NAME_FULLY_QUALIFIED) reduce 145) ((T_NAME_QUALIFIED) reduce 145) ((T_NAME_RELATIVE) reduce 145) ((T_NEW) reduce 145) ((T_NS_C) reduce 145) ((T_OBJECT_CAST) reduce 145) ((T_PRINT) reduce 145) ((T_READONLY) reduce 145) ((T_REQUIRE) reduce 145) ((T_REQUIRE_ONCE) reduce 145) ((T_RETURN) reduce 145) ((T_START_HEREDOC) reduce 145) ((T_STATIC) reduce 145) ((T_STRING) reduce 145) ((T_STRING_CAST) reduce 145) ((T_SWITCH) reduce 145) ((T_THROW) reduce 145) ((T_TRAIT) reduce 145) ((T_TRAIT_C) reduce 145) ((T_TRY) reduce 145) ((T_UNSET) reduce 145) ((T_UNSET_CAST) reduce 145) ((T_VARIABLE) reduce 145) ((T_WHILE) reduce 145) ((T_YIELD) reduce 145) ((T_YIELD_FROM) reduce 145) (("[") reduce 145) (("`") reduce 145) (("{") reduce 145) (("~") reduce 145)) 16342 ((("!") reduce 244) (("\"") reduce 244) (("$") reduce 244) (("(") reduce 244) (("+") reduce 244) (("-") reduce 244) ((";") reduce 244) (("@") reduce 244) ((T_ABSTRACT) reduce 244) ((T_ARRAY) reduce 244) ((T_ARRAY_CAST) reduce 244) ((T_ATTRIBUTE) reduce 244) ((T_BOOL_CAST) reduce 244) ((T_BREAK) reduce 244) ((T_CLASS) reduce 244) ((T_CLASS_C) reduce 244) ((T_CLONE) reduce 244) ((T_CONSTANT_ENCAPSED_STRING) reduce 244) ((T_CONTINUE) reduce 244) ((T_DEC) reduce 244) ((T_DECLARE) reduce 244) ((T_DIR) reduce 244) ((T_DNUMBER) reduce 244) ((T_DO) reduce 244) ((T_DOUBLE_CAST) reduce 244) ((T_ECHO) reduce 244) ((T_EMPTY) reduce 244) ((T_ENDIF) reduce 244) ((T_ENUM) reduce 244) ((T_EVAL) reduce 244) ((T_EXIT) reduce 244) ((T_FILE) reduce 244) ((T_FINAL) reduce 244) ((T_FN) reduce 244) ((T_FOR) reduce 244) ((T_FOREACH) reduce 244) ((T_FUNCTION) reduce 244) ((T_FUNC_C) reduce 244) ((T_GLOBAL) reduce 244) ((T_GOTO) reduce 244) ((T_HALT_COMPILER) reduce 244) ((T_IF) reduce 244) ((T_INC) reduce 244) ((T_INCLUDE) reduce 244) ((T_INCLUDE_ONCE) reduce 244) ((T_INLINE_HTML) reduce 244) ((T_INTERFACE) reduce 244) ((T_INT_CAST) reduce 244) ((T_ISSET) reduce 244) ((T_LINE) reduce 244) ((T_LIST) reduce 244) ((T_LNUMBER) reduce 244) ((T_MATCH) reduce 244) ((T_METHOD_C) reduce 244) ((T_NAME_FULLY_QUALIFIED) reduce 244) ((T_NAME_QUALIFIED) reduce 244) ((T_NAME_RELATIVE) reduce 244) ((T_NEW) reduce 244) ((T_NS_C) reduce 244) ((T_OBJECT_CAST) reduce 244) ((T_PRINT) reduce 244) ((T_READONLY) reduce 244) ((T_REQUIRE) reduce 244) ((T_REQUIRE_ONCE) reduce 244) ((T_RETURN) reduce 244) ((T_START_HEREDOC) reduce 244) ((T_STATIC) reduce 244) ((T_STRING) reduce 244) ((T_STRING_CAST) reduce 244) ((T_SWITCH) reduce 244) ((T_THROW) reduce 244) ((T_TRAIT) reduce 244) ((T_TRAIT_C) reduce 244) ((T_TRY) reduce 244) ((T_UNSET) reduce 244) ((T_UNSET_CAST) reduce 244) ((T_VARIABLE) reduce 244) ((T_WHILE) reduce 244) ((T_YIELD) reduce 244) ((T_YIELD_FROM) reduce 244) (("[") reduce 244) (("`") reduce 244) (("{") reduce 244) (("~") reduce 244)) 16353 ((("!") reduce 455) (("\"") reduce 455) (("$") reduce 455) (("(") reduce 455) (("+") reduce 455) (("-") reduce 455) ((";") reduce 455) (("@") reduce 455) ((T_ABSTRACT) reduce 455) ((T_ARRAY) reduce 455) ((T_ARRAY_CAST) reduce 455) ((T_ATTRIBUTE) reduce 455) ((T_BOOL_CAST) reduce 455) ((T_BREAK) reduce 455) ((T_CLASS) reduce 455) ((T_CLASS_C) reduce 455) ((T_CLONE) reduce 455) ((T_CONSTANT_ENCAPSED_STRING) reduce 455) ((T_CONTINUE) reduce 455) ((T_DEC) reduce 455) ((T_DECLARE) reduce 455) ((T_DIR) reduce 455) ((T_DNUMBER) reduce 455) ((T_DO) reduce 455) ((T_DOUBLE_CAST) reduce 455) ((T_ECHO) reduce 455) ((T_EMPTY) reduce 455) ((T_ENDIF) reduce 455) ((T_ENUM) reduce 455) ((T_EVAL) reduce 455) ((T_EXIT) reduce 455) ((T_FILE) reduce 455) ((T_FINAL) reduce 455) ((T_FN) reduce 455) ((T_FOR) reduce 455) ((T_FOREACH) reduce 455) ((T_FUNCTION) reduce 455) ((T_FUNC_C) reduce 455) ((T_GLOBAL) reduce 455) ((T_GOTO) reduce 455) ((T_HALT_COMPILER) reduce 455) ((T_IF) reduce 455) ((T_INC) reduce 455) ((T_INCLUDE) reduce 455) ((T_INCLUDE_ONCE) reduce 455) ((T_INLINE_HTML) reduce 455) ((T_INTERFACE) reduce 455) ((T_INT_CAST) reduce 455) ((T_ISSET) reduce 455) ((T_LINE) reduce 455) ((T_LIST) reduce 455) ((T_LNUMBER) reduce 455) ((T_MATCH) reduce 455) ((T_METHOD_C) reduce 455) ((T_NAME_FULLY_QUALIFIED) reduce 455) ((T_NAME_QUALIFIED) reduce 455) ((T_NAME_RELATIVE) reduce 455) ((T_NEW) reduce 455) ((T_NS_C) reduce 455) ((T_OBJECT_CAST) reduce 455) ((T_PRINT) reduce 455) ((T_READONLY) reduce 455) ((T_REQUIRE) reduce 455) ((T_REQUIRE_ONCE) reduce 455) ((T_RETURN) reduce 455) ((T_START_HEREDOC) reduce 455) ((T_STATIC) reduce 455) ((T_STRING) reduce 455) ((T_STRING_CAST) reduce 455) ((T_SWITCH) reduce 455) ((T_THROW) reduce 455) ((T_TRAIT) reduce 455) ((T_TRAIT_C) reduce 455) ((T_TRY) reduce 455) ((T_UNSET) reduce 455) ((T_UNSET_CAST) reduce 455) ((T_VARIABLE) reduce 455) ((T_WHILE) reduce 455) ((T_YIELD) reduce 455) ((T_YIELD_FROM) reduce 455) (("[") reduce 455) (("`") reduce 455) (("{") reduce 455) (("~") reduce 455)) 16354 ((("!") reduce 181) (("\"") reduce 181) (("$") reduce 181) (("(") reduce 181) (("+") reduce 181) (("-") reduce 181) ((";") reduce 181) (("@") reduce 181) ((T_ABSTRACT) reduce 181) ((T_ARRAY) reduce 181) ((T_ARRAY_CAST) reduce 181) ((T_ATTRIBUTE) reduce 181) ((T_BOOL_CAST) reduce 181) ((T_BREAK) reduce 181) ((T_CLASS) reduce 181) ((T_CLASS_C) reduce 181) ((T_CLONE) reduce 181) ((T_CONSTANT_ENCAPSED_STRING) reduce 181) ((T_CONTINUE) reduce 181) ((T_DEC) reduce 181) ((T_DECLARE) reduce 181) ((T_DIR) reduce 181) ((T_DNUMBER) reduce 181) ((T_DO) reduce 181) ((T_DOUBLE_CAST) reduce 181) ((T_ECHO) reduce 181) ((T_EMPTY) reduce 181) ((T_ENDIF) reduce 181) ((T_ENUM) reduce 181) ((T_EVAL) reduce 181) ((T_EXIT) reduce 181) ((T_FILE) reduce 181) ((T_FINAL) reduce 181) ((T_FN) reduce 181) ((T_FOR) reduce 181) ((T_FOREACH) reduce 181) ((T_FUNCTION) reduce 181) ((T_FUNC_C) reduce 181) ((T_GLOBAL) reduce 181) ((T_GOTO) reduce 181) ((T_HALT_COMPILER) reduce 181) ((T_IF) reduce 181) ((T_INC) reduce 181) ((T_INCLUDE) reduce 181) ((T_INCLUDE_ONCE) reduce 181) ((T_INLINE_HTML) reduce 181) ((T_INTERFACE) reduce 181) ((T_INT_CAST) reduce 181) ((T_ISSET) reduce 181) ((T_LINE) reduce 181) ((T_LIST) reduce 181) ((T_LNUMBER) reduce 181) ((T_MATCH) reduce 181) ((T_METHOD_C) reduce 181) ((T_NAME_FULLY_QUALIFIED) reduce 181) ((T_NAME_QUALIFIED) reduce 181) ((T_NAME_RELATIVE) reduce 181) ((T_NEW) reduce 181) ((T_NS_C) reduce 181) ((T_OBJECT_CAST) reduce 181) ((T_PRINT) reduce 181) ((T_READONLY) reduce 181) ((T_REQUIRE) reduce 181) ((T_REQUIRE_ONCE) reduce 181) ((T_RETURN) reduce 181) ((T_START_HEREDOC) reduce 181) ((T_STATIC) reduce 181) ((T_STRING) reduce 181) ((T_STRING_CAST) reduce 181) ((T_SWITCH) reduce 181) ((T_THROW) reduce 181) ((T_TRAIT) reduce 181) ((T_TRAIT_C) reduce 181) ((T_TRY) reduce 181) ((T_UNSET) reduce 181) ((T_UNSET_CAST) reduce 181) ((T_VARIABLE) reduce 181) ((T_WHILE) reduce 181) ((T_YIELD) reduce 181) ((T_YIELD_FROM) reduce 181) (("[") reduce 181) (("`") reduce 181) (("{") reduce 181) (("~") reduce 181)) 16355 ((("!") reduce 159) (("\"") reduce 159) (("$") reduce 159) (("(") reduce 159) (("+") reduce 159) (("-") reduce 159) ((";") reduce 159) (("@") reduce 159) ((T_ABSTRACT) reduce 159) ((T_ARRAY) reduce 159) ((T_ARRAY_CAST) reduce 159) ((T_ATTRIBUTE) reduce 159) ((T_BOOL_CAST) reduce 159) ((T_BREAK) reduce 159) ((T_CLASS) reduce 159) ((T_CLASS_C) reduce 159) ((T_CLONE) reduce 159) ((T_CONSTANT_ENCAPSED_STRING) reduce 159) ((T_CONTINUE) reduce 159) ((T_DEC) reduce 159) ((T_DECLARE) reduce 159) ((T_DIR) reduce 159) ((T_DNUMBER) reduce 159) ((T_DO) reduce 159) ((T_DOUBLE_CAST) reduce 159) ((T_ECHO) reduce 159) ((T_EMPTY) reduce 159) ((T_ENDIF) reduce 159) ((T_ENUM) reduce 159) ((T_EVAL) reduce 159) ((T_EXIT) reduce 159) ((T_FILE) reduce 159) ((T_FINAL) reduce 159) ((T_FN) reduce 159) ((T_FOR) reduce 159) ((T_FOREACH) reduce 159) ((T_FUNCTION) reduce 159) ((T_FUNC_C) reduce 159) ((T_GLOBAL) reduce 159) ((T_GOTO) reduce 159) ((T_HALT_COMPILER) reduce 159) ((T_IF) reduce 159) ((T_INC) reduce 159) ((T_INCLUDE) reduce 159) ((T_INCLUDE_ONCE) reduce 159) ((T_INLINE_HTML) reduce 159) ((T_INTERFACE) reduce 159) ((T_INT_CAST) reduce 159) ((T_ISSET) reduce 159) ((T_LINE) reduce 159) ((T_LIST) reduce 159) ((T_LNUMBER) reduce 159) ((T_MATCH) reduce 159) ((T_METHOD_C) reduce 159) ((T_NAME_FULLY_QUALIFIED) reduce 159) ((T_NAME_QUALIFIED) reduce 159) ((T_NAME_RELATIVE) reduce 159) ((T_NEW) reduce 159) ((T_NS_C) reduce 159) ((T_OBJECT_CAST) reduce 159) ((T_PRINT) reduce 159) ((T_READONLY) reduce 159) ((T_REQUIRE) reduce 159) ((T_REQUIRE_ONCE) reduce 159) ((T_RETURN) reduce 159) ((T_START_HEREDOC) reduce 159) ((T_STATIC) reduce 159) ((T_STRING) reduce 159) ((T_STRING_CAST) reduce 159) ((T_SWITCH) reduce 159) ((T_THROW) reduce 159) ((T_TRAIT) reduce 159) ((T_TRAIT_C) reduce 159) ((T_TRY) reduce 159) ((T_UNSET) reduce 159) ((T_UNSET_CAST) reduce 159) ((T_VARIABLE) reduce 159) ((T_WHILE) reduce 159) ((T_YIELD) reduce 159) ((T_YIELD_FROM) reduce 159) (("[") reduce 159) (("`") reduce 159) (("{") reduce 159) (("~") reduce 159)) 16363 ((("!") reduce 186) (("\"") reduce 186) (("$") reduce 186) (("(") reduce 186) (("+") reduce 186) (("-") reduce 186) ((";") reduce 186) (("@") reduce 186) ((T_ABSTRACT) reduce 186) ((T_ARRAY) reduce 186) ((T_ARRAY_CAST) reduce 186) ((T_ATTRIBUTE) reduce 186) ((T_BOOL_CAST) reduce 186) ((T_BREAK) reduce 186) ((T_CLASS) reduce 186) ((T_CLASS_C) reduce 186) ((T_CLONE) reduce 186) ((T_CONSTANT_ENCAPSED_STRING) reduce 186) ((T_CONTINUE) reduce 186) ((T_DEC) reduce 186) ((T_DECLARE) reduce 186) ((T_DIR) reduce 186) ((T_DNUMBER) reduce 186) ((T_DO) reduce 186) ((T_DOUBLE_CAST) reduce 186) ((T_ECHO) reduce 186) ((T_EMPTY) reduce 186) ((T_ENDIF) reduce 186) ((T_ENUM) reduce 186) ((T_EVAL) reduce 186) ((T_EXIT) reduce 186) ((T_FILE) reduce 186) ((T_FINAL) reduce 186) ((T_FN) reduce 186) ((T_FOR) reduce 186) ((T_FOREACH) reduce 186) ((T_FUNCTION) reduce 186) ((T_FUNC_C) reduce 186) ((T_GLOBAL) reduce 186) ((T_GOTO) reduce 186) ((T_HALT_COMPILER) reduce 186) ((T_IF) reduce 186) ((T_INC) reduce 186) ((T_INCLUDE) reduce 186) ((T_INCLUDE_ONCE) reduce 186) ((T_INLINE_HTML) reduce 186) ((T_INTERFACE) reduce 186) ((T_INT_CAST) reduce 186) ((T_ISSET) reduce 186) ((T_LINE) reduce 186) ((T_LIST) reduce 186) ((T_LNUMBER) reduce 186) ((T_MATCH) reduce 186) ((T_METHOD_C) reduce 186) ((T_NAME_FULLY_QUALIFIED) reduce 186) ((T_NAME_QUALIFIED) reduce 186) ((T_NAME_RELATIVE) reduce 186) ((T_NEW) reduce 186) ((T_NS_C) reduce 186) ((T_OBJECT_CAST) reduce 186) ((T_PRINT) reduce 186) ((T_READONLY) reduce 186) ((T_REQUIRE) reduce 186) ((T_REQUIRE_ONCE) reduce 186) ((T_RETURN) reduce 186) ((T_START_HEREDOC) reduce 186) ((T_STATIC) reduce 186) ((T_STRING) reduce 186) ((T_STRING_CAST) reduce 186) ((T_SWITCH) reduce 186) ((T_THROW) reduce 186) ((T_TRAIT) reduce 186) ((T_TRAIT_C) reduce 186) ((T_TRY) reduce 186) ((T_UNSET) reduce 186) ((T_UNSET_CAST) reduce 186) ((T_VARIABLE) reduce 186) ((T_WHILE) reduce 186) ((T_YIELD) reduce 186) ((T_YIELD_FROM) reduce 186) (("[") reduce 186) (("`") reduce 186) (("{") reduce 186) (("~") reduce 186)) 16364 ((("!") reduce 143) (("\"") reduce 143) (("$") reduce 143) (("(") reduce 143) (("+") reduce 143) (("-") reduce 143) ((";") reduce 143) (("@") reduce 143) ((T_ABSTRACT) reduce 143) ((T_ARRAY) reduce 143) ((T_ARRAY_CAST) reduce 143) ((T_ATTRIBUTE) reduce 143) ((T_BOOL_CAST) reduce 143) ((T_BREAK) reduce 143) ((T_CLASS) reduce 143) ((T_CLASS_C) reduce 143) ((T_CLONE) reduce 143) ((T_CONSTANT_ENCAPSED_STRING) reduce 143) ((T_CONTINUE) reduce 143) ((T_DEC) reduce 143) ((T_DECLARE) reduce 143) ((T_DIR) reduce 143) ((T_DNUMBER) reduce 143) ((T_DO) reduce 143) ((T_DOUBLE_CAST) reduce 143) ((T_ECHO) reduce 143) ((T_EMPTY) reduce 143) ((T_ENDIF) reduce 143) ((T_ENUM) reduce 143) ((T_EVAL) reduce 143) ((T_EXIT) reduce 143) ((T_FILE) reduce 143) ((T_FINAL) reduce 143) ((T_FN) reduce 143) ((T_FOR) reduce 143) ((T_FOREACH) reduce 143) ((T_FUNCTION) reduce 143) ((T_FUNC_C) reduce 143) ((T_GLOBAL) reduce 143) ((T_GOTO) reduce 143) ((T_HALT_COMPILER) reduce 143) ((T_IF) reduce 143) ((T_INC) reduce 143) ((T_INCLUDE) reduce 143) ((T_INCLUDE_ONCE) reduce 143) ((T_INLINE_HTML) reduce 143) ((T_INTERFACE) reduce 143) ((T_INT_CAST) reduce 143) ((T_ISSET) reduce 143) ((T_LINE) reduce 143) ((T_LIST) reduce 143) ((T_LNUMBER) reduce 143) ((T_MATCH) reduce 143) ((T_METHOD_C) reduce 143) ((T_NAME_FULLY_QUALIFIED) reduce 143) ((T_NAME_QUALIFIED) reduce 143) ((T_NAME_RELATIVE) reduce 143) ((T_NEW) reduce 143) ((T_NS_C) reduce 143) ((T_OBJECT_CAST) reduce 143) ((T_PRINT) reduce 143) ((T_READONLY) reduce 143) ((T_REQUIRE) reduce 143) ((T_REQUIRE_ONCE) reduce 143) ((T_RETURN) reduce 143) ((T_START_HEREDOC) reduce 143) ((T_STATIC) reduce 143) ((T_STRING) reduce 143) ((T_STRING_CAST) reduce 143) ((T_SWITCH) reduce 143) ((T_THROW) reduce 143) ((T_TRAIT) reduce 143) ((T_TRAIT_C) reduce 143) ((T_TRY) reduce 143) ((T_UNSET) reduce 143) ((T_UNSET_CAST) reduce 143) ((T_VARIABLE) reduce 143) ((T_WHILE) reduce 143) ((T_YIELD) reduce 143) ((T_YIELD_FROM) reduce 143) (("[") reduce 143) (("`") reduce 143) (("{") reduce 143) (("~") reduce 143)) 16367 ((("!") reduce 247) (("\"") reduce 247) (("$") reduce 247) (("(") reduce 247) (("+") reduce 247) (("-") reduce 247) ((";") reduce 247) (("@") reduce 247) ((T_ABSTRACT) reduce 247) ((T_ARRAY) reduce 247) ((T_ARRAY_CAST) reduce 247) ((T_ATTRIBUTE) reduce 247) ((T_BOOL_CAST) reduce 247) ((T_BREAK) reduce 247) ((T_CLASS) reduce 247) ((T_CLASS_C) reduce 247) ((T_CLONE) reduce 247) ((T_CONSTANT_ENCAPSED_STRING) reduce 247) ((T_CONTINUE) reduce 247) ((T_DEC) reduce 247) ((T_DECLARE) reduce 247) ((T_DIR) reduce 247) ((T_DNUMBER) reduce 247) ((T_DO) reduce 247) ((T_DOUBLE_CAST) reduce 247) ((T_ECHO) reduce 247) ((T_EMPTY) reduce 247) ((T_ENDIF) reduce 247) ((T_ENUM) reduce 247) ((T_EVAL) reduce 247) ((T_EXIT) reduce 247) ((T_FILE) reduce 247) ((T_FINAL) reduce 247) ((T_FN) reduce 247) ((T_FOR) reduce 247) ((T_FOREACH) reduce 247) ((T_FUNCTION) reduce 247) ((T_FUNC_C) reduce 247) ((T_GLOBAL) reduce 247) ((T_GOTO) reduce 247) ((T_HALT_COMPILER) reduce 247) ((T_IF) reduce 247) ((T_INC) reduce 247) ((T_INCLUDE) reduce 247) ((T_INCLUDE_ONCE) reduce 247) ((T_INLINE_HTML) reduce 247) ((T_INTERFACE) reduce 247) ((T_INT_CAST) reduce 247) ((T_ISSET) reduce 247) ((T_LINE) reduce 247) ((T_LIST) reduce 247) ((T_LNUMBER) reduce 247) ((T_MATCH) reduce 247) ((T_METHOD_C) reduce 247) ((T_NAME_FULLY_QUALIFIED) reduce 247) ((T_NAME_QUALIFIED) reduce 247) ((T_NAME_RELATIVE) reduce 247) ((T_NEW) reduce 247) ((T_NS_C) reduce 247) ((T_OBJECT_CAST) reduce 247) ((T_PRINT) reduce 247) ((T_READONLY) reduce 247) ((T_REQUIRE) reduce 247) ((T_REQUIRE_ONCE) reduce 247) ((T_RETURN) reduce 247) ((T_START_HEREDOC) reduce 247) ((T_STATIC) reduce 247) ((T_STRING) reduce 247) ((T_STRING_CAST) reduce 247) ((T_SWITCH) reduce 247) ((T_THROW) reduce 247) ((T_TRAIT) reduce 247) ((T_TRAIT_C) reduce 247) ((T_TRY) reduce 247) ((T_UNSET) reduce 247) ((T_UNSET_CAST) reduce 247) ((T_VARIABLE) reduce 247) ((T_WHILE) reduce 247) ((T_YIELD) reduce 247) ((T_YIELD_FROM) reduce 247) (("[") reduce 247) (("`") reduce 247) (("{") reduce 247) (("~") reduce 247)) 16371 ((("!") reduce 248) (("\"") reduce 248) (("$") reduce 248) (("(") reduce 248) (("+") reduce 248) (("-") reduce 248) ((";") reduce 248) (("@") reduce 248) ((T_ABSTRACT) reduce 248) ((T_ARRAY) reduce 248) ((T_ARRAY_CAST) reduce 248) ((T_ATTRIBUTE) reduce 248) ((T_BOOL_CAST) reduce 248) ((T_BREAK) reduce 248) ((T_CLASS) reduce 248) ((T_CLASS_C) reduce 248) ((T_CLONE) reduce 248) ((T_CONSTANT_ENCAPSED_STRING) reduce 248) ((T_CONTINUE) reduce 248) ((T_DEC) reduce 248) ((T_DECLARE) reduce 248) ((T_DIR) reduce 248) ((T_DNUMBER) reduce 248) ((T_DO) reduce 248) ((T_DOUBLE_CAST) reduce 248) ((T_ECHO) reduce 248) ((T_EMPTY) reduce 248) ((T_ENDIF) reduce 248) ((T_ENUM) reduce 248) ((T_EVAL) reduce 248) ((T_EXIT) reduce 248) ((T_FILE) reduce 248) ((T_FINAL) reduce 248) ((T_FN) reduce 248) ((T_FOR) reduce 248) ((T_FOREACH) reduce 248) ((T_FUNCTION) reduce 248) ((T_FUNC_C) reduce 248) ((T_GLOBAL) reduce 248) ((T_GOTO) reduce 248) ((T_HALT_COMPILER) reduce 248) ((T_IF) reduce 248) ((T_INC) reduce 248) ((T_INCLUDE) reduce 248) ((T_INCLUDE_ONCE) reduce 248) ((T_INLINE_HTML) reduce 248) ((T_INTERFACE) reduce 248) ((T_INT_CAST) reduce 248) ((T_ISSET) reduce 248) ((T_LINE) reduce 248) ((T_LIST) reduce 248) ((T_LNUMBER) reduce 248) ((T_MATCH) reduce 248) ((T_METHOD_C) reduce 248) ((T_NAME_FULLY_QUALIFIED) reduce 248) ((T_NAME_QUALIFIED) reduce 248) ((T_NAME_RELATIVE) reduce 248) ((T_NEW) reduce 248) ((T_NS_C) reduce 248) ((T_OBJECT_CAST) reduce 248) ((T_PRINT) reduce 248) ((T_READONLY) reduce 248) ((T_REQUIRE) reduce 248) ((T_REQUIRE_ONCE) reduce 248) ((T_RETURN) reduce 248) ((T_START_HEREDOC) reduce 248) ((T_STATIC) reduce 248) ((T_STRING) reduce 248) ((T_STRING_CAST) reduce 248) ((T_SWITCH) reduce 248) ((T_THROW) reduce 248) ((T_TRAIT) reduce 248) ((T_TRAIT_C) reduce 248) ((T_TRY) reduce 248) ((T_UNSET) reduce 248) ((T_UNSET_CAST) reduce 248) ((T_VARIABLE) reduce 248) ((T_WHILE) reduce 248) ((T_YIELD) reduce 248) ((T_YIELD_FROM) reduce 248) (("[") reduce 248) (("`") reduce 248) (("{") reduce 248) (("~") reduce 248)) 16374 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) (("+") shift) (("-") shift) ((":") shift) ((";") shift) (("@") shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_BREAK) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_CONTINUE) shift) ((T_DEC) shift) ((T_DECLARE) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DO) shift) ((T_DOUBLE_CAST) shift) ((T_ECHO) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FOR) shift) ((T_FOREACH) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_GLOBAL) shift) ((T_GOTO) shift) ((T_IF) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INLINE_HTML) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_RETURN) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_SWITCH) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_TRY) shift) ((T_UNSET) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_WHILE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("{") shift) (("~") shift)) 16375 ((("!") reduce 140) (("\"") reduce 140) (("$") reduce 140) (("(") reduce 140) (("+") reduce 140) (("-") reduce 140) ((";") reduce 140) (("@") reduce 140) ((T_ABSTRACT) reduce 140) ((T_ARRAY) reduce 140) ((T_ARRAY_CAST) reduce 140) ((T_ATTRIBUTE) reduce 140) ((T_BOOL_CAST) reduce 140) ((T_BREAK) reduce 140) ((T_CLASS) reduce 140) ((T_CLASS_C) reduce 140) ((T_CLONE) reduce 140) ((T_CONSTANT_ENCAPSED_STRING) reduce 140) ((T_CONTINUE) reduce 140) ((T_DEC) reduce 140) ((T_DECLARE) reduce 140) ((T_DIR) reduce 140) ((T_DNUMBER) reduce 140) ((T_DO) reduce 140) ((T_DOUBLE_CAST) reduce 140) ((T_ECHO) reduce 140) ((T_EMPTY) reduce 140) ((T_ENDWHILE) reduce 140) ((T_ENUM) reduce 140) ((T_EVAL) reduce 140) ((T_EXIT) reduce 140) ((T_FILE) reduce 140) ((T_FINAL) reduce 140) ((T_FN) reduce 140) ((T_FOR) reduce 140) ((T_FOREACH) reduce 140) ((T_FUNCTION) reduce 140) ((T_FUNC_C) reduce 140) ((T_GLOBAL) reduce 140) ((T_GOTO) reduce 140) ((T_HALT_COMPILER) reduce 140) ((T_IF) reduce 140) ((T_INC) reduce 140) ((T_INCLUDE) reduce 140) ((T_INCLUDE_ONCE) reduce 140) ((T_INLINE_HTML) reduce 140) ((T_INTERFACE) reduce 140) ((T_INT_CAST) reduce 140) ((T_ISSET) reduce 140) ((T_LINE) reduce 140) ((T_LIST) reduce 140) ((T_LNUMBER) reduce 140) ((T_MATCH) reduce 140) ((T_METHOD_C) reduce 140) ((T_NAME_FULLY_QUALIFIED) reduce 140) ((T_NAME_QUALIFIED) reduce 140) ((T_NAME_RELATIVE) reduce 140) ((T_NEW) reduce 140) ((T_NS_C) reduce 140) ((T_OBJECT_CAST) reduce 140) ((T_PRINT) reduce 140) ((T_READONLY) reduce 140) ((T_REQUIRE) reduce 140) ((T_REQUIRE_ONCE) reduce 140) ((T_RETURN) reduce 140) ((T_START_HEREDOC) reduce 140) ((T_STATIC) reduce 140) ((T_STRING) reduce 140) ((T_STRING_CAST) reduce 140) ((T_SWITCH) reduce 140) ((T_THROW) reduce 140) ((T_TRAIT) reduce 140) ((T_TRAIT_C) reduce 140) ((T_TRY) reduce 140) ((T_UNSET) reduce 140) ((T_UNSET_CAST) reduce 140) ((T_VARIABLE) reduce 140) ((T_WHILE) reduce 140) ((T_YIELD) reduce 140) ((T_YIELD_FROM) reduce 140) (("[") reduce 140) (("`") reduce 140) (("{") reduce 140) (("~") reduce 140)) 16376 ((("!") reduce 239) (("\"") reduce 239) (("$") reduce 239) (("(") reduce 239) (("+") reduce 239) (("-") reduce 239) ((";") reduce 239) (("@") reduce 239) ((T_ABSTRACT) reduce 239) ((T_ARRAY) reduce 239) ((T_ARRAY_CAST) reduce 239) ((T_ATTRIBUTE) reduce 239) ((T_BOOL_CAST) reduce 239) ((T_BREAK) reduce 239) ((T_CLASS) reduce 239) ((T_CLASS_C) reduce 239) ((T_CLONE) reduce 239) ((T_CONSTANT_ENCAPSED_STRING) reduce 239) ((T_CONTINUE) reduce 239) ((T_DEC) reduce 239) ((T_DECLARE) reduce 239) ((T_DIR) reduce 239) ((T_DNUMBER) reduce 239) ((T_DO) reduce 239) ((T_DOUBLE_CAST) reduce 239) ((T_ECHO) reduce 239) ((T_EMPTY) reduce 239) ((T_ENDIF) reduce 239) ((T_ENUM) reduce 239) ((T_EVAL) reduce 239) ((T_EXIT) reduce 239) ((T_FILE) reduce 239) ((T_FINAL) reduce 239) ((T_FN) reduce 239) ((T_FOR) reduce 239) ((T_FOREACH) reduce 239) ((T_FUNCTION) reduce 239) ((T_FUNC_C) reduce 239) ((T_GLOBAL) reduce 239) ((T_GOTO) reduce 239) ((T_HALT_COMPILER) reduce 239) ((T_IF) reduce 239) ((T_INC) reduce 239) ((T_INCLUDE) reduce 239) ((T_INCLUDE_ONCE) reduce 239) ((T_INLINE_HTML) reduce 239) ((T_INTERFACE) reduce 239) ((T_INT_CAST) reduce 239) ((T_ISSET) reduce 239) ((T_LINE) reduce 239) ((T_LIST) reduce 239) ((T_LNUMBER) reduce 239) ((T_MATCH) reduce 239) ((T_METHOD_C) reduce 239) ((T_NAME_FULLY_QUALIFIED) reduce 239) ((T_NAME_QUALIFIED) reduce 239) ((T_NAME_RELATIVE) reduce 239) ((T_NEW) reduce 239) ((T_NS_C) reduce 239) ((T_OBJECT_CAST) reduce 239) ((T_PRINT) reduce 239) ((T_READONLY) reduce 239) ((T_REQUIRE) reduce 239) ((T_REQUIRE_ONCE) reduce 239) ((T_RETURN) reduce 239) ((T_START_HEREDOC) reduce 239) ((T_STATIC) reduce 239) ((T_STRING) reduce 239) ((T_STRING_CAST) reduce 239) ((T_SWITCH) reduce 239) ((T_THROW) reduce 239) ((T_TRAIT) reduce 239) ((T_TRAIT_C) reduce 239) ((T_TRY) reduce 239) ((T_UNSET) reduce 239) ((T_UNSET_CAST) reduce 239) ((T_VARIABLE) reduce 239) ((T_WHILE) reduce 239) ((T_YIELD) reduce 239) ((T_YIELD_FROM) reduce 239) (("[") reduce 239) (("`") reduce 239) (("{") reduce 239) (("~") reduce 239)) 16377 ((("!") reduce 148) (("\"") reduce 148) (("$") reduce 148) (("(") reduce 148) (("+") reduce 148) (("-") reduce 148) ((";") reduce 148) (("@") reduce 148) ((T_ABSTRACT) reduce 148) ((T_ARRAY) reduce 148) ((T_ARRAY_CAST) reduce 148) ((T_ATTRIBUTE) reduce 148) ((T_BOOL_CAST) reduce 148) ((T_BREAK) reduce 148) ((T_CLASS) reduce 148) ((T_CLASS_C) reduce 148) ((T_CLONE) reduce 148) ((T_CONSTANT_ENCAPSED_STRING) reduce 148) ((T_CONTINUE) reduce 148) ((T_DEC) reduce 148) ((T_DECLARE) reduce 148) ((T_DIR) reduce 148) ((T_DNUMBER) reduce 148) ((T_DO) reduce 148) ((T_DOUBLE_CAST) reduce 148) ((T_ECHO) reduce 148) ((T_EMPTY) reduce 148) ((T_ENDIF) reduce 148) ((T_ENUM) reduce 148) ((T_EVAL) reduce 148) ((T_EXIT) reduce 148) ((T_FILE) reduce 148) ((T_FINAL) reduce 148) ((T_FN) reduce 148) ((T_FOR) reduce 148) ((T_FOREACH) reduce 148) ((T_FUNCTION) reduce 148) ((T_FUNC_C) reduce 148) ((T_GLOBAL) reduce 148) ((T_GOTO) reduce 148) ((T_HALT_COMPILER) reduce 148) ((T_IF) reduce 148) ((T_INC) reduce 148) ((T_INCLUDE) reduce 148) ((T_INCLUDE_ONCE) reduce 148) ((T_INLINE_HTML) reduce 148) ((T_INTERFACE) reduce 148) ((T_INT_CAST) reduce 148) ((T_ISSET) reduce 148) ((T_LINE) reduce 148) ((T_LIST) reduce 148) ((T_LNUMBER) reduce 148) ((T_MATCH) reduce 148) ((T_METHOD_C) reduce 148) ((T_NAME_FULLY_QUALIFIED) reduce 148) ((T_NAME_QUALIFIED) reduce 148) ((T_NAME_RELATIVE) reduce 148) ((T_NEW) reduce 148) ((T_NS_C) reduce 148) ((T_OBJECT_CAST) reduce 148) ((T_PRINT) reduce 148) ((T_READONLY) reduce 148) ((T_REQUIRE) reduce 148) ((T_REQUIRE_ONCE) reduce 148) ((T_RETURN) reduce 148) ((T_START_HEREDOC) reduce 148) ((T_STATIC) reduce 148) ((T_STRING) reduce 148) ((T_STRING_CAST) reduce 148) ((T_SWITCH) reduce 148) ((T_THROW) reduce 148) ((T_TRAIT) reduce 148) ((T_TRAIT_C) reduce 148) ((T_TRY) reduce 148) ((T_UNSET) reduce 148) ((T_UNSET_CAST) reduce 148) ((T_VARIABLE) reduce 148) ((T_WHILE) reduce 148) ((T_YIELD) reduce 148) ((T_YIELD_FROM) reduce 148) (("[") reduce 148) (("`") reduce 148) (("{") reduce 148) (("~") reduce 148)) 16378 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) (("+") shift) (("-") shift) ((";") shift) (("@") shift) ((T_ABSTRACT) shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_BREAK) shift) ((T_CLASS) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_CONTINUE) shift) ((T_DEC) shift) ((T_DECLARE) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DO) shift) ((T_DOUBLE_CAST) shift) ((T_ECHO) shift) ((T_EMPTY) shift) ((T_ENDWHILE) shift) ((T_ENUM) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FINAL) shift) ((T_FN) shift) ((T_FOR) shift) ((T_FOREACH) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_GLOBAL) shift) ((T_GOTO) shift) ((T_HALT_COMPILER) shift) ((T_IF) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INLINE_HTML) shift) ((T_INTERFACE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_RETURN) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_SWITCH) shift) ((T_THROW) shift) ((T_TRAIT) shift) ((T_TRAIT_C) shift) ((T_TRY) shift) ((T_UNSET) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_WHILE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("{") shift) (("~") shift)) 16379 ((("!") reduce 164) (("\"") reduce 164) (("$") reduce 164) (("(") reduce 164) (("+") reduce 164) (("-") reduce 164) ((";") reduce 164) (("@") reduce 164) ((T_ABSTRACT) reduce 164) ((T_ARRAY) reduce 164) ((T_ARRAY_CAST) reduce 164) ((T_ATTRIBUTE) reduce 164) ((T_BOOL_CAST) reduce 164) ((T_BREAK) reduce 164) ((T_CLASS) reduce 164) ((T_CLASS_C) reduce 164) ((T_CLONE) reduce 164) ((T_CONSTANT_ENCAPSED_STRING) reduce 164) ((T_CONTINUE) reduce 164) ((T_DEC) reduce 164) ((T_DECLARE) reduce 164) ((T_DIR) reduce 164) ((T_DNUMBER) reduce 164) ((T_DO) reduce 164) ((T_DOUBLE_CAST) reduce 164) ((T_ECHO) reduce 164) ((T_EMPTY) reduce 164) ((T_ENDWHILE) reduce 164) ((T_ENUM) reduce 164) ((T_EVAL) reduce 164) ((T_EXIT) reduce 164) ((T_FILE) reduce 164) ((T_FINAL) reduce 164) ((T_FN) reduce 164) ((T_FOR) reduce 164) ((T_FOREACH) reduce 164) ((T_FUNCTION) reduce 164) ((T_FUNC_C) reduce 164) ((T_GLOBAL) reduce 164) ((T_GOTO) reduce 164) ((T_HALT_COMPILER) reduce 164) ((T_IF) reduce 164) ((T_INC) reduce 164) ((T_INCLUDE) reduce 164) ((T_INCLUDE_ONCE) reduce 164) ((T_INLINE_HTML) reduce 164) ((T_INTERFACE) reduce 164) ((T_INT_CAST) reduce 164) ((T_ISSET) reduce 164) ((T_LINE) reduce 164) ((T_LIST) reduce 164) ((T_LNUMBER) reduce 164) ((T_MATCH) reduce 164) ((T_METHOD_C) reduce 164) ((T_NAME_FULLY_QUALIFIED) reduce 164) ((T_NAME_QUALIFIED) reduce 164) ((T_NAME_RELATIVE) reduce 164) ((T_NEW) reduce 164) ((T_NS_C) reduce 164) ((T_OBJECT_CAST) reduce 164) ((T_PRINT) reduce 164) ((T_READONLY) reduce 164) ((T_REQUIRE) reduce 164) ((T_REQUIRE_ONCE) reduce 164) ((T_RETURN) reduce 164) ((T_START_HEREDOC) reduce 164) ((T_STATIC) reduce 164) ((T_STRING) reduce 164) ((T_STRING_CAST) reduce 164) ((T_SWITCH) reduce 164) ((T_THROW) reduce 164) ((T_TRAIT) reduce 164) ((T_TRAIT_C) reduce 164) ((T_TRY) reduce 164) ((T_UNSET) reduce 164) ((T_UNSET_CAST) reduce 164) ((T_VARIABLE) reduce 164) ((T_WHILE) reduce 164) ((T_YIELD) reduce 164) ((T_YIELD_FROM) reduce 164) (("[") reduce 164) (("`") reduce 164) (("{") reduce 164) (("~") reduce 164)) 16394 ((("!") reduce 158) (("\"") reduce 158) (("$") reduce 158) (("(") reduce 158) (("+") reduce 158) (("-") reduce 158) ((";") reduce 158) (("@") reduce 158) ((T_ABSTRACT) reduce 158) ((T_ARRAY) reduce 158) ((T_ARRAY_CAST) reduce 158) ((T_ATTRIBUTE) reduce 158) ((T_BOOL_CAST) reduce 158) ((T_BREAK) reduce 158) ((T_CLASS) reduce 158) ((T_CLASS_C) reduce 158) ((T_CLONE) reduce 158) ((T_CONSTANT_ENCAPSED_STRING) reduce 158) ((T_CONTINUE) reduce 158) ((T_DEC) reduce 158) ((T_DECLARE) reduce 158) ((T_DIR) reduce 158) ((T_DNUMBER) reduce 158) ((T_DO) reduce 158) ((T_DOUBLE_CAST) reduce 158) ((T_ECHO) reduce 158) ((T_EMPTY) reduce 158) ((T_ENDWHILE) reduce 158) ((T_ENUM) reduce 158) ((T_EVAL) reduce 158) ((T_EXIT) reduce 158) ((T_FILE) reduce 158) ((T_FINAL) reduce 158) ((T_FN) reduce 158) ((T_FOR) reduce 158) ((T_FOREACH) reduce 158) ((T_FUNCTION) reduce 158) ((T_FUNC_C) reduce 158) ((T_GLOBAL) reduce 158) ((T_GOTO) reduce 158) ((T_HALT_COMPILER) reduce 158) ((T_IF) reduce 158) ((T_INC) reduce 158) ((T_INCLUDE) reduce 158) ((T_INCLUDE_ONCE) reduce 158) ((T_INLINE_HTML) reduce 158) ((T_INTERFACE) reduce 158) ((T_INT_CAST) reduce 158) ((T_ISSET) reduce 158) ((T_LINE) reduce 158) ((T_LIST) reduce 158) ((T_LNUMBER) reduce 158) ((T_MATCH) reduce 158) ((T_METHOD_C) reduce 158) ((T_NAME_FULLY_QUALIFIED) reduce 158) ((T_NAME_QUALIFIED) reduce 158) ((T_NAME_RELATIVE) reduce 158) ((T_NEW) reduce 158) ((T_NS_C) reduce 158) ((T_OBJECT_CAST) reduce 158) ((T_PRINT) reduce 158) ((T_READONLY) reduce 158) ((T_REQUIRE) reduce 158) ((T_REQUIRE_ONCE) reduce 158) ((T_RETURN) reduce 158) ((T_START_HEREDOC) reduce 158) ((T_STATIC) reduce 158) ((T_STRING) reduce 158) ((T_STRING_CAST) reduce 158) ((T_SWITCH) reduce 158) ((T_THROW) reduce 158) ((T_TRAIT) reduce 158) ((T_TRAIT_C) reduce 158) ((T_TRY) reduce 158) ((T_UNSET) reduce 158) ((T_UNSET_CAST) reduce 158) ((T_VARIABLE) reduce 158) ((T_WHILE) reduce 158) ((T_YIELD) reduce 158) ((T_YIELD_FROM) reduce 158) (("[") reduce 158) (("`") reduce 158) (("{") reduce 158) (("~") reduce 158)) 16404 ((("!") reduce 147) (("\"") reduce 147) (("$") reduce 147) (("(") reduce 147) (("+") reduce 147) (("-") reduce 147) ((";") reduce 147) (("@") reduce 147) ((T_ABSTRACT) reduce 147) ((T_ARRAY) reduce 147) ((T_ARRAY_CAST) reduce 147) ((T_ATTRIBUTE) reduce 147) ((T_BOOL_CAST) reduce 147) ((T_BREAK) reduce 147) ((T_CLASS) reduce 147) ((T_CLASS_C) reduce 147) ((T_CLONE) reduce 147) ((T_CONSTANT_ENCAPSED_STRING) reduce 147) ((T_CONTINUE) reduce 147) ((T_DEC) reduce 147) ((T_DECLARE) reduce 147) ((T_DIR) reduce 147) ((T_DNUMBER) reduce 147) ((T_DO) reduce 147) ((T_DOUBLE_CAST) reduce 147) ((T_ECHO) reduce 147) ((T_EMPTY) reduce 147) ((T_ENDWHILE) reduce 147) ((T_ENUM) reduce 147) ((T_EVAL) reduce 147) ((T_EXIT) reduce 147) ((T_FILE) reduce 147) ((T_FINAL) reduce 147) ((T_FN) reduce 147) ((T_FOR) reduce 147) ((T_FOREACH) reduce 147) ((T_FUNCTION) reduce 147) ((T_FUNC_C) reduce 147) ((T_GLOBAL) reduce 147) ((T_GOTO) reduce 147) ((T_HALT_COMPILER) reduce 147) ((T_IF) reduce 147) ((T_INC) reduce 147) ((T_INCLUDE) reduce 147) ((T_INCLUDE_ONCE) reduce 147) ((T_INLINE_HTML) reduce 147) ((T_INTERFACE) reduce 147) ((T_INT_CAST) reduce 147) ((T_ISSET) reduce 147) ((T_LINE) reduce 147) ((T_LIST) reduce 147) ((T_LNUMBER) reduce 147) ((T_MATCH) reduce 147) ((T_METHOD_C) reduce 147) ((T_NAME_FULLY_QUALIFIED) reduce 147) ((T_NAME_QUALIFIED) reduce 147) ((T_NAME_RELATIVE) reduce 147) ((T_NEW) reduce 147) ((T_NS_C) reduce 147) ((T_OBJECT_CAST) reduce 147) ((T_PRINT) reduce 147) ((T_READONLY) reduce 147) ((T_REQUIRE) reduce 147) ((T_REQUIRE_ONCE) reduce 147) ((T_RETURN) reduce 147) ((T_START_HEREDOC) reduce 147) ((T_STATIC) reduce 147) ((T_STRING) reduce 147) ((T_STRING_CAST) reduce 147) ((T_SWITCH) reduce 147) ((T_THROW) reduce 147) ((T_TRAIT) reduce 147) ((T_TRAIT_C) reduce 147) ((T_TRY) reduce 147) ((T_UNSET) reduce 147) ((T_UNSET_CAST) reduce 147) ((T_VARIABLE) reduce 147) ((T_WHILE) reduce 147) ((T_YIELD) reduce 147) ((T_YIELD_FROM) reduce 147) (("[") reduce 147) (("`") reduce 147) (("{") reduce 147) (("~") reduce 147)) 16406 ((("!") reduce 142) (("\"") reduce 142) (("$") reduce 142) (("(") reduce 142) (("+") reduce 142) (("-") reduce 142) ((";") reduce 142) (("@") reduce 142) ((T_ABSTRACT) reduce 142) ((T_ARRAY) reduce 142) ((T_ARRAY_CAST) reduce 142) ((T_ATTRIBUTE) reduce 142) ((T_BOOL_CAST) reduce 142) ((T_BREAK) reduce 142) ((T_CLASS) reduce 142) ((T_CLASS_C) reduce 142) ((T_CLONE) reduce 142) ((T_CONSTANT_ENCAPSED_STRING) reduce 142) ((T_CONTINUE) reduce 142) ((T_DEC) reduce 142) ((T_DECLARE) reduce 142) ((T_DIR) reduce 142) ((T_DNUMBER) reduce 142) ((T_DO) reduce 142) ((T_DOUBLE_CAST) reduce 142) ((T_ECHO) reduce 142) ((T_EMPTY) reduce 142) ((T_ENDWHILE) reduce 142) ((T_ENUM) reduce 142) ((T_EVAL) reduce 142) ((T_EXIT) reduce 142) ((T_FILE) reduce 142) ((T_FINAL) reduce 142) ((T_FN) reduce 142) ((T_FOR) reduce 142) ((T_FOREACH) reduce 142) ((T_FUNCTION) reduce 142) ((T_FUNC_C) reduce 142) ((T_GLOBAL) reduce 142) ((T_GOTO) reduce 142) ((T_HALT_COMPILER) reduce 142) ((T_IF) reduce 142) ((T_INC) reduce 142) ((T_INCLUDE) reduce 142) ((T_INCLUDE_ONCE) reduce 142) ((T_INLINE_HTML) reduce 142) ((T_INTERFACE) reduce 142) ((T_INT_CAST) reduce 142) ((T_ISSET) reduce 142) ((T_LINE) reduce 142) ((T_LIST) reduce 142) ((T_LNUMBER) reduce 142) ((T_MATCH) reduce 142) ((T_METHOD_C) reduce 142) ((T_NAME_FULLY_QUALIFIED) reduce 142) ((T_NAME_QUALIFIED) reduce 142) ((T_NAME_RELATIVE) reduce 142) ((T_NEW) reduce 142) ((T_NS_C) reduce 142) ((T_OBJECT_CAST) reduce 142) ((T_PRINT) reduce 142) ((T_READONLY) reduce 142) ((T_REQUIRE) reduce 142) ((T_REQUIRE_ONCE) reduce 142) ((T_RETURN) reduce 142) ((T_START_HEREDOC) reduce 142) ((T_STATIC) reduce 142) ((T_STRING) reduce 142) ((T_STRING_CAST) reduce 142) ((T_SWITCH) reduce 142) ((T_THROW) reduce 142) ((T_TRAIT) reduce 142) ((T_TRAIT_C) reduce 142) ((T_TRY) reduce 142) ((T_UNSET) reduce 142) ((T_UNSET_CAST) reduce 142) ((T_VARIABLE) reduce 142) ((T_WHILE) reduce 142) ((T_YIELD) reduce 142) ((T_YIELD_FROM) reduce 142) (("[") reduce 142) (("`") reduce 142) (("{") reduce 142) (("~") reduce 142)) 16408 ((("!") reduce 103) (("\"") reduce 103) (("$") reduce 103) (("(") reduce 103) (("+") reduce 103) (("-") reduce 103) ((";") reduce 103) (("@") reduce 103) ((T_ABSTRACT) reduce 103) ((T_ARRAY) reduce 103) ((T_ARRAY_CAST) reduce 103) ((T_ATTRIBUTE) reduce 103) ((T_BOOL_CAST) reduce 103) ((T_BREAK) reduce 103) ((T_CLASS) reduce 103) ((T_CLASS_C) reduce 103) ((T_CLONE) reduce 103) ((T_CONSTANT_ENCAPSED_STRING) reduce 103) ((T_CONTINUE) reduce 103) ((T_DEC) reduce 103) ((T_DECLARE) reduce 103) ((T_DIR) reduce 103) ((T_DNUMBER) reduce 103) ((T_DO) reduce 103) ((T_DOUBLE_CAST) reduce 103) ((T_ECHO) reduce 103) ((T_EMPTY) reduce 103) ((T_ENDWHILE) reduce 103) ((T_ENUM) reduce 103) ((T_EVAL) reduce 103) ((T_EXIT) reduce 103) ((T_FILE) reduce 103) ((T_FINAL) reduce 103) ((T_FN) reduce 103) ((T_FOR) reduce 103) ((T_FOREACH) reduce 103) ((T_FUNCTION) reduce 103) ((T_FUNC_C) reduce 103) ((T_GLOBAL) reduce 103) ((T_GOTO) reduce 103) ((T_HALT_COMPILER) reduce 103) ((T_IF) reduce 103) ((T_INC) reduce 103) ((T_INCLUDE) reduce 103) ((T_INCLUDE_ONCE) reduce 103) ((T_INLINE_HTML) reduce 103) ((T_INTERFACE) reduce 103) ((T_INT_CAST) reduce 103) ((T_ISSET) reduce 103) ((T_LINE) reduce 103) ((T_LIST) reduce 103) ((T_LNUMBER) reduce 103) ((T_MATCH) reduce 103) ((T_METHOD_C) reduce 103) ((T_NAME_FULLY_QUALIFIED) reduce 103) ((T_NAME_QUALIFIED) reduce 103) ((T_NAME_RELATIVE) reduce 103) ((T_NEW) reduce 103) ((T_NS_C) reduce 103) ((T_OBJECT_CAST) reduce 103) ((T_PRINT) reduce 103) ((T_READONLY) reduce 103) ((T_REQUIRE) reduce 103) ((T_REQUIRE_ONCE) reduce 103) ((T_RETURN) reduce 103) ((T_START_HEREDOC) reduce 103) ((T_STATIC) reduce 103) ((T_STRING) reduce 103) ((T_STRING_CAST) reduce 103) ((T_SWITCH) reduce 103) ((T_THROW) reduce 103) ((T_TRAIT) reduce 103) ((T_TRAIT_C) reduce 103) ((T_TRY) reduce 103) ((T_UNSET) reduce 103) ((T_UNSET_CAST) reduce 103) ((T_VARIABLE) reduce 103) ((T_WHILE) reduce 103) ((T_YIELD) reduce 103) ((T_YIELD_FROM) reduce 103) (("[") reduce 103) (("`") reduce 103) (("{") reduce 103) (("~") reduce 103)) 16410 ((("!") reduce 106) (("\"") reduce 106) (("$") reduce 106) (("(") reduce 106) (("+") reduce 106) (("-") reduce 106) ((";") reduce 106) (("@") reduce 106) ((T_ABSTRACT) reduce 106) ((T_ARRAY) reduce 106) ((T_ARRAY_CAST) reduce 106) ((T_ATTRIBUTE) reduce 106) ((T_BOOL_CAST) reduce 106) ((T_BREAK) reduce 106) ((T_CLASS) reduce 106) ((T_CLASS_C) reduce 106) ((T_CLONE) reduce 106) ((T_CONSTANT_ENCAPSED_STRING) reduce 106) ((T_CONTINUE) reduce 106) ((T_DEC) reduce 106) ((T_DECLARE) reduce 106) ((T_DIR) reduce 106) ((T_DNUMBER) reduce 106) ((T_DO) reduce 106) ((T_DOUBLE_CAST) reduce 106) ((T_ECHO) reduce 106) ((T_EMPTY) reduce 106) ((T_ENDWHILE) reduce 106) ((T_ENUM) reduce 106) ((T_EVAL) reduce 106) ((T_EXIT) reduce 106) ((T_FILE) reduce 106) ((T_FINAL) reduce 106) ((T_FN) reduce 106) ((T_FOR) reduce 106) ((T_FOREACH) reduce 106) ((T_FUNCTION) reduce 106) ((T_FUNC_C) reduce 106) ((T_GLOBAL) reduce 106) ((T_GOTO) reduce 106) ((T_HALT_COMPILER) reduce 106) ((T_IF) reduce 106) ((T_INC) reduce 106) ((T_INCLUDE) reduce 106) ((T_INCLUDE_ONCE) reduce 106) ((T_INLINE_HTML) reduce 106) ((T_INTERFACE) reduce 106) ((T_INT_CAST) reduce 106) ((T_ISSET) reduce 106) ((T_LINE) reduce 106) ((T_LIST) reduce 106) ((T_LNUMBER) reduce 106) ((T_MATCH) reduce 106) ((T_METHOD_C) reduce 106) ((T_NAME_FULLY_QUALIFIED) reduce 106) ((T_NAME_QUALIFIED) reduce 106) ((T_NAME_RELATIVE) reduce 106) ((T_NEW) reduce 106) ((T_NS_C) reduce 106) ((T_OBJECT_CAST) reduce 106) ((T_PRINT) reduce 106) ((T_READONLY) reduce 106) ((T_REQUIRE) reduce 106) ((T_REQUIRE_ONCE) reduce 106) ((T_RETURN) reduce 106) ((T_START_HEREDOC) reduce 106) ((T_STATIC) reduce 106) ((T_STRING) reduce 106) ((T_STRING_CAST) reduce 106) ((T_SWITCH) reduce 106) ((T_THROW) reduce 106) ((T_TRAIT) reduce 106) ((T_TRAIT_C) reduce 106) ((T_TRY) reduce 106) ((T_UNSET) reduce 106) ((T_UNSET_CAST) reduce 106) ((T_VARIABLE) reduce 106) ((T_WHILE) reduce 106) ((T_YIELD) reduce 106) ((T_YIELD_FROM) reduce 106) (("[") reduce 106) (("`") reduce 106) (("{") reduce 106) (("~") reduce 106)) 16413 ((("!") reduce 102) (("\"") reduce 102) (("$") reduce 102) (("(") reduce 102) (("+") reduce 102) (("-") reduce 102) ((";") reduce 102) (("@") reduce 102) ((T_ABSTRACT) reduce 102) ((T_ARRAY) reduce 102) ((T_ARRAY_CAST) reduce 102) ((T_ATTRIBUTE) reduce 102) ((T_BOOL_CAST) reduce 102) ((T_BREAK) reduce 102) ((T_CLASS) reduce 102) ((T_CLASS_C) reduce 102) ((T_CLONE) reduce 102) ((T_CONSTANT_ENCAPSED_STRING) reduce 102) ((T_CONTINUE) reduce 102) ((T_DEC) reduce 102) ((T_DECLARE) reduce 102) ((T_DIR) reduce 102) ((T_DNUMBER) reduce 102) ((T_DO) reduce 102) ((T_DOUBLE_CAST) reduce 102) ((T_ECHO) reduce 102) ((T_EMPTY) reduce 102) ((T_ENDWHILE) reduce 102) ((T_ENUM) reduce 102) ((T_EVAL) reduce 102) ((T_EXIT) reduce 102) ((T_FILE) reduce 102) ((T_FINAL) reduce 102) ((T_FN) reduce 102) ((T_FOR) reduce 102) ((T_FOREACH) reduce 102) ((T_FUNCTION) reduce 102) ((T_FUNC_C) reduce 102) ((T_GLOBAL) reduce 102) ((T_GOTO) reduce 102) ((T_HALT_COMPILER) reduce 102) ((T_IF) reduce 102) ((T_INC) reduce 102) ((T_INCLUDE) reduce 102) ((T_INCLUDE_ONCE) reduce 102) ((T_INLINE_HTML) reduce 102) ((T_INTERFACE) reduce 102) ((T_INT_CAST) reduce 102) ((T_ISSET) reduce 102) ((T_LINE) reduce 102) ((T_LIST) reduce 102) ((T_LNUMBER) reduce 102) ((T_MATCH) reduce 102) ((T_METHOD_C) reduce 102) ((T_NAME_FULLY_QUALIFIED) reduce 102) ((T_NAME_QUALIFIED) reduce 102) ((T_NAME_RELATIVE) reduce 102) ((T_NEW) reduce 102) ((T_NS_C) reduce 102) ((T_OBJECT_CAST) reduce 102) ((T_PRINT) reduce 102) ((T_READONLY) reduce 102) ((T_REQUIRE) reduce 102) ((T_REQUIRE_ONCE) reduce 102) ((T_RETURN) reduce 102) ((T_START_HEREDOC) reduce 102) ((T_STATIC) reduce 102) ((T_STRING) reduce 102) ((T_STRING_CAST) reduce 102) ((T_SWITCH) reduce 102) ((T_THROW) reduce 102) ((T_TRAIT) reduce 102) ((T_TRAIT_C) reduce 102) ((T_TRY) reduce 102) ((T_UNSET) reduce 102) ((T_UNSET_CAST) reduce 102) ((T_VARIABLE) reduce 102) ((T_WHILE) reduce 102) ((T_YIELD) reduce 102) ((T_YIELD_FROM) reduce 102) (("[") reduce 102) (("`") reduce 102) (("{") reduce 102) (("~") reduce 102)) 16414 ((("!") reduce 146) (("\"") reduce 146) (("$") reduce 146) (("(") reduce 146) (("+") reduce 146) (("-") reduce 146) ((";") reduce 146) (("@") reduce 146) ((T_ABSTRACT) reduce 146) ((T_ARRAY) reduce 146) ((T_ARRAY_CAST) reduce 146) ((T_ATTRIBUTE) reduce 146) ((T_BOOL_CAST) reduce 146) ((T_BREAK) reduce 146) ((T_CLASS) reduce 146) ((T_CLASS_C) reduce 146) ((T_CLONE) reduce 146) ((T_CONSTANT_ENCAPSED_STRING) reduce 146) ((T_CONTINUE) reduce 146) ((T_DEC) reduce 146) ((T_DECLARE) reduce 146) ((T_DIR) reduce 146) ((T_DNUMBER) reduce 146) ((T_DO) reduce 146) ((T_DOUBLE_CAST) reduce 146) ((T_ECHO) reduce 146) ((T_EMPTY) reduce 146) ((T_ENDWHILE) reduce 146) ((T_ENUM) reduce 146) ((T_EVAL) reduce 146) ((T_EXIT) reduce 146) ((T_FILE) reduce 146) ((T_FINAL) reduce 146) ((T_FN) reduce 146) ((T_FOR) reduce 146) ((T_FOREACH) reduce 146) ((T_FUNCTION) reduce 146) ((T_FUNC_C) reduce 146) ((T_GLOBAL) reduce 146) ((T_GOTO) reduce 146) ((T_HALT_COMPILER) reduce 146) ((T_IF) reduce 146) ((T_INC) reduce 146) ((T_INCLUDE) reduce 146) ((T_INCLUDE_ONCE) reduce 146) ((T_INLINE_HTML) reduce 146) ((T_INTERFACE) reduce 146) ((T_INT_CAST) reduce 146) ((T_ISSET) reduce 146) ((T_LINE) reduce 146) ((T_LIST) reduce 146) ((T_LNUMBER) reduce 146) ((T_MATCH) reduce 146) ((T_METHOD_C) reduce 146) ((T_NAME_FULLY_QUALIFIED) reduce 146) ((T_NAME_QUALIFIED) reduce 146) ((T_NAME_RELATIVE) reduce 146) ((T_NEW) reduce 146) ((T_NS_C) reduce 146) ((T_OBJECT_CAST) reduce 146) ((T_PRINT) reduce 146) ((T_READONLY) reduce 146) ((T_REQUIRE) reduce 146) ((T_REQUIRE_ONCE) reduce 146) ((T_RETURN) reduce 146) ((T_START_HEREDOC) reduce 146) ((T_STATIC) reduce 146) ((T_STRING) reduce 146) ((T_STRING_CAST) reduce 146) ((T_SWITCH) reduce 146) ((T_THROW) reduce 146) ((T_TRAIT) reduce 146) ((T_TRAIT_C) reduce 146) ((T_TRY) reduce 146) ((T_UNSET) reduce 146) ((T_UNSET_CAST) reduce 146) ((T_VARIABLE) reduce 146) ((T_WHILE) reduce 146) ((T_YIELD) reduce 146) ((T_YIELD_FROM) reduce 146) (("[") reduce 146) (("`") reduce 146) (("{") reduce 146) (("~") reduce 146)) 16415 ((("!") reduce 243) (("\"") reduce 243) (("$") reduce 243) (("(") reduce 243) (("+") reduce 243) (("-") reduce 243) ((";") reduce 243) (("@") reduce 243) ((T_ABSTRACT) reduce 243) ((T_ARRAY) reduce 243) ((T_ARRAY_CAST) reduce 243) ((T_ATTRIBUTE) reduce 243) ((T_BOOL_CAST) reduce 243) ((T_BREAK) reduce 243) ((T_CLASS) reduce 243) ((T_CLASS_C) reduce 243) ((T_CLONE) reduce 243) ((T_CONSTANT_ENCAPSED_STRING) reduce 243) ((T_CONTINUE) reduce 243) ((T_DEC) reduce 243) ((T_DECLARE) reduce 243) ((T_DIR) reduce 243) ((T_DNUMBER) reduce 243) ((T_DO) reduce 243) ((T_DOUBLE_CAST) reduce 243) ((T_ECHO) reduce 243) ((T_ELSE) shift) ((T_ELSEIF) shift) ((T_EMPTY) reduce 243) ((T_ENDWHILE) reduce 243) ((T_ENUM) reduce 243) ((T_EVAL) reduce 243) ((T_EXIT) reduce 243) ((T_FILE) reduce 243) ((T_FINAL) reduce 243) ((T_FN) reduce 243) ((T_FOR) reduce 243) ((T_FOREACH) reduce 243) ((T_FUNCTION) reduce 243) ((T_FUNC_C) reduce 243) ((T_GLOBAL) reduce 243) ((T_GOTO) reduce 243) ((T_HALT_COMPILER) reduce 243) ((T_IF) reduce 243) ((T_INC) reduce 243) ((T_INCLUDE) reduce 243) ((T_INCLUDE_ONCE) reduce 243) ((T_INLINE_HTML) reduce 243) ((T_INTERFACE) reduce 243) ((T_INT_CAST) reduce 243) ((T_ISSET) reduce 243) ((T_LINE) reduce 243) ((T_LIST) reduce 243) ((T_LNUMBER) reduce 243) ((T_MATCH) reduce 243) ((T_METHOD_C) reduce 243) ((T_NAME_FULLY_QUALIFIED) reduce 243) ((T_NAME_QUALIFIED) reduce 243) ((T_NAME_RELATIVE) reduce 243) ((T_NEW) reduce 243) ((T_NS_C) reduce 243) ((T_OBJECT_CAST) reduce 243) ((T_PRINT) reduce 243) ((T_READONLY) reduce 243) ((T_REQUIRE) reduce 243) ((T_REQUIRE_ONCE) reduce 243) ((T_RETURN) reduce 243) ((T_START_HEREDOC) reduce 243) ((T_STATIC) reduce 243) ((T_STRING) reduce 243) ((T_STRING_CAST) reduce 243) ((T_SWITCH) reduce 243) ((T_THROW) reduce 243) ((T_TRAIT) reduce 243) ((T_TRAIT_C) reduce 243) ((T_TRY) reduce 243) ((T_UNSET) reduce 243) ((T_UNSET_CAST) reduce 243) ((T_VARIABLE) reduce 243) ((T_WHILE) reduce 243) ((T_YIELD) reduce 243) ((T_YIELD_FROM) reduce 243) (("[") reduce 243) (("`") reduce 243) (("{") reduce 243) (("~") reduce 243)) 16416 ((("!") reduce 139) (("\"") reduce 139) (("$") reduce 139) (("(") reduce 139) (("+") reduce 139) (("-") reduce 139) ((";") reduce 139) (("@") reduce 139) ((T_ABSTRACT) reduce 139) ((T_ARRAY) reduce 139) ((T_ARRAY_CAST) reduce 139) ((T_ATTRIBUTE) reduce 139) ((T_BOOL_CAST) reduce 139) ((T_BREAK) reduce 139) ((T_CLASS) reduce 139) ((T_CLASS_C) reduce 139) ((T_CLONE) reduce 139) ((T_CONSTANT_ENCAPSED_STRING) reduce 139) ((T_CONTINUE) reduce 139) ((T_DEC) reduce 139) ((T_DECLARE) reduce 139) ((T_DIR) reduce 139) ((T_DNUMBER) reduce 139) ((T_DO) reduce 139) ((T_DOUBLE_CAST) reduce 139) ((T_ECHO) reduce 139) ((T_EMPTY) reduce 139) ((T_ENDWHILE) reduce 139) ((T_ENUM) reduce 139) ((T_EVAL) reduce 139) ((T_EXIT) reduce 139) ((T_FILE) reduce 139) ((T_FINAL) reduce 139) ((T_FN) reduce 139) ((T_FOR) reduce 139) ((T_FOREACH) reduce 139) ((T_FUNCTION) reduce 139) ((T_FUNC_C) reduce 139) ((T_GLOBAL) reduce 139) ((T_GOTO) reduce 139) ((T_HALT_COMPILER) reduce 139) ((T_IF) reduce 139) ((T_INC) reduce 139) ((T_INCLUDE) reduce 139) ((T_INCLUDE_ONCE) reduce 139) ((T_INLINE_HTML) reduce 139) ((T_INTERFACE) reduce 139) ((T_INT_CAST) reduce 139) ((T_ISSET) reduce 139) ((T_LINE) reduce 139) ((T_LIST) reduce 139) ((T_LNUMBER) reduce 139) ((T_MATCH) reduce 139) ((T_METHOD_C) reduce 139) ((T_NAME_FULLY_QUALIFIED) reduce 139) ((T_NAME_QUALIFIED) reduce 139) ((T_NAME_RELATIVE) reduce 139) ((T_NEW) reduce 139) ((T_NS_C) reduce 139) ((T_OBJECT_CAST) reduce 139) ((T_PRINT) reduce 139) ((T_READONLY) reduce 139) ((T_REQUIRE) reduce 139) ((T_REQUIRE_ONCE) reduce 139) ((T_RETURN) reduce 139) ((T_START_HEREDOC) reduce 139) ((T_STATIC) reduce 139) ((T_STRING) reduce 139) ((T_STRING_CAST) reduce 139) ((T_SWITCH) reduce 139) ((T_THROW) reduce 139) ((T_TRAIT) reduce 139) ((T_TRAIT_C) reduce 139) ((T_TRY) reduce 139) ((T_UNSET) reduce 139) ((T_UNSET_CAST) reduce 139) ((T_VARIABLE) reduce 139) ((T_WHILE) reduce 139) ((T_YIELD) reduce 139) ((T_YIELD_FROM) reduce 139) (("[") reduce 139) (("`") reduce 139) (("{") reduce 139) (("~") reduce 139)) 16417 ((("!") reduce 105) (("\"") reduce 105) (("$") reduce 105) (("(") reduce 105) (("+") reduce 105) (("-") reduce 105) ((";") reduce 105) (("@") reduce 105) ((T_ABSTRACT) reduce 105) ((T_ARRAY) reduce 105) ((T_ARRAY_CAST) reduce 105) ((T_ATTRIBUTE) reduce 105) ((T_BOOL_CAST) reduce 105) ((T_BREAK) reduce 105) ((T_CLASS) reduce 105) ((T_CLASS_C) reduce 105) ((T_CLONE) reduce 105) ((T_CONSTANT_ENCAPSED_STRING) reduce 105) ((T_CONTINUE) reduce 105) ((T_DEC) reduce 105) ((T_DECLARE) reduce 105) ((T_DIR) reduce 105) ((T_DNUMBER) reduce 105) ((T_DO) reduce 105) ((T_DOUBLE_CAST) reduce 105) ((T_ECHO) reduce 105) ((T_EMPTY) reduce 105) ((T_ENDWHILE) reduce 105) ((T_ENUM) reduce 105) ((T_EVAL) reduce 105) ((T_EXIT) reduce 105) ((T_FILE) reduce 105) ((T_FINAL) reduce 105) ((T_FN) reduce 105) ((T_FOR) reduce 105) ((T_FOREACH) reduce 105) ((T_FUNCTION) reduce 105) ((T_FUNC_C) reduce 105) ((T_GLOBAL) reduce 105) ((T_GOTO) reduce 105) ((T_HALT_COMPILER) reduce 105) ((T_IF) reduce 105) ((T_INC) reduce 105) ((T_INCLUDE) reduce 105) ((T_INCLUDE_ONCE) reduce 105) ((T_INLINE_HTML) reduce 105) ((T_INTERFACE) reduce 105) ((T_INT_CAST) reduce 105) ((T_ISSET) reduce 105) ((T_LINE) reduce 105) ((T_LIST) reduce 105) ((T_LNUMBER) reduce 105) ((T_MATCH) reduce 105) ((T_METHOD_C) reduce 105) ((T_NAME_FULLY_QUALIFIED) reduce 105) ((T_NAME_QUALIFIED) reduce 105) ((T_NAME_RELATIVE) reduce 105) ((T_NEW) reduce 105) ((T_NS_C) reduce 105) ((T_OBJECT_CAST) reduce 105) ((T_PRINT) reduce 105) ((T_READONLY) reduce 105) ((T_REQUIRE) reduce 105) ((T_REQUIRE_ONCE) reduce 105) ((T_RETURN) reduce 105) ((T_START_HEREDOC) reduce 105) ((T_STATIC) reduce 105) ((T_STRING) reduce 105) ((T_STRING_CAST) reduce 105) ((T_SWITCH) reduce 105) ((T_THROW) reduce 105) ((T_TRAIT) reduce 105) ((T_TRAIT_C) reduce 105) ((T_TRY) reduce 105) ((T_UNSET) reduce 105) ((T_UNSET_CAST) reduce 105) ((T_VARIABLE) reduce 105) ((T_WHILE) reduce 105) ((T_YIELD) reduce 105) ((T_YIELD_FROM) reduce 105) (("[") reduce 105) (("`") reduce 105) (("{") reduce 105) (("~") reduce 105)) 16418 ((("!") reduce 141) (("\"") reduce 141) (("$") reduce 141) (("(") reduce 141) (("+") reduce 141) (("-") reduce 141) ((";") reduce 141) (("@") reduce 141) ((T_ABSTRACT) reduce 141) ((T_ARRAY) reduce 141) ((T_ARRAY_CAST) reduce 141) ((T_ATTRIBUTE) reduce 141) ((T_BOOL_CAST) reduce 141) ((T_BREAK) reduce 141) ((T_CLASS) reduce 141) ((T_CLASS_C) reduce 141) ((T_CLONE) reduce 141) ((T_CONSTANT_ENCAPSED_STRING) reduce 141) ((T_CONTINUE) reduce 141) ((T_DEC) reduce 141) ((T_DECLARE) reduce 141) ((T_DIR) reduce 141) ((T_DNUMBER) reduce 141) ((T_DO) reduce 141) ((T_DOUBLE_CAST) reduce 141) ((T_ECHO) reduce 141) ((T_EMPTY) reduce 141) ((T_ENDWHILE) reduce 141) ((T_ENUM) reduce 141) ((T_EVAL) reduce 141) ((T_EXIT) reduce 141) ((T_FILE) reduce 141) ((T_FINAL) reduce 141) ((T_FN) reduce 141) ((T_FOR) reduce 141) ((T_FOREACH) reduce 141) ((T_FUNCTION) reduce 141) ((T_FUNC_C) reduce 141) ((T_GLOBAL) reduce 141) ((T_GOTO) reduce 141) ((T_HALT_COMPILER) reduce 141) ((T_IF) reduce 141) ((T_INC) reduce 141) ((T_INCLUDE) reduce 141) ((T_INCLUDE_ONCE) reduce 141) ((T_INLINE_HTML) reduce 141) ((T_INTERFACE) reduce 141) ((T_INT_CAST) reduce 141) ((T_ISSET) reduce 141) ((T_LINE) reduce 141) ((T_LIST) reduce 141) ((T_LNUMBER) reduce 141) ((T_MATCH) reduce 141) ((T_METHOD_C) reduce 141) ((T_NAME_FULLY_QUALIFIED) reduce 141) ((T_NAME_QUALIFIED) reduce 141) ((T_NAME_RELATIVE) reduce 141) ((T_NEW) reduce 141) ((T_NS_C) reduce 141) ((T_OBJECT_CAST) reduce 141) ((T_PRINT) reduce 141) ((T_READONLY) reduce 141) ((T_REQUIRE) reduce 141) ((T_REQUIRE_ONCE) reduce 141) ((T_RETURN) reduce 141) ((T_START_HEREDOC) reduce 141) ((T_STATIC) reduce 141) ((T_STRING) reduce 141) ((T_STRING_CAST) reduce 141) ((T_SWITCH) reduce 141) ((T_THROW) reduce 141) ((T_TRAIT) reduce 141) ((T_TRAIT_C) reduce 141) ((T_TRY) reduce 141) ((T_UNSET) reduce 141) ((T_UNSET_CAST) reduce 141) ((T_VARIABLE) reduce 141) ((T_WHILE) reduce 141) ((T_YIELD) reduce 141) ((T_YIELD_FROM) reduce 141) (("[") reduce 141) (("`") reduce 141) (("{") reduce 141) (("~") reduce 141)) 16419 ((("!") reduce 104) (("\"") reduce 104) (("$") reduce 104) (("(") reduce 104) (("+") reduce 104) (("-") reduce 104) ((";") reduce 104) (("@") reduce 104) ((T_ABSTRACT) reduce 104) ((T_ARRAY) reduce 104) ((T_ARRAY_CAST) reduce 104) ((T_ATTRIBUTE) reduce 104) ((T_BOOL_CAST) reduce 104) ((T_BREAK) reduce 104) ((T_CLASS) reduce 104) ((T_CLASS_C) reduce 104) ((T_CLONE) reduce 104) ((T_CONSTANT_ENCAPSED_STRING) reduce 104) ((T_CONTINUE) reduce 104) ((T_DEC) reduce 104) ((T_DECLARE) reduce 104) ((T_DIR) reduce 104) ((T_DNUMBER) reduce 104) ((T_DO) reduce 104) ((T_DOUBLE_CAST) reduce 104) ((T_ECHO) reduce 104) ((T_EMPTY) reduce 104) ((T_ENDWHILE) reduce 104) ((T_ENUM) reduce 104) ((T_EVAL) reduce 104) ((T_EXIT) reduce 104) ((T_FILE) reduce 104) ((T_FINAL) reduce 104) ((T_FN) reduce 104) ((T_FOR) reduce 104) ((T_FOREACH) reduce 104) ((T_FUNCTION) reduce 104) ((T_FUNC_C) reduce 104) ((T_GLOBAL) reduce 104) ((T_GOTO) reduce 104) ((T_HALT_COMPILER) reduce 104) ((T_IF) reduce 104) ((T_INC) reduce 104) ((T_INCLUDE) reduce 104) ((T_INCLUDE_ONCE) reduce 104) ((T_INLINE_HTML) reduce 104) ((T_INTERFACE) reduce 104) ((T_INT_CAST) reduce 104) ((T_ISSET) reduce 104) ((T_LINE) reduce 104) ((T_LIST) reduce 104) ((T_LNUMBER) reduce 104) ((T_MATCH) reduce 104) ((T_METHOD_C) reduce 104) ((T_NAME_FULLY_QUALIFIED) reduce 104) ((T_NAME_QUALIFIED) reduce 104) ((T_NAME_RELATIVE) reduce 104) ((T_NEW) reduce 104) ((T_NS_C) reduce 104) ((T_OBJECT_CAST) reduce 104) ((T_PRINT) reduce 104) ((T_READONLY) reduce 104) ((T_REQUIRE) reduce 104) ((T_REQUIRE_ONCE) reduce 104) ((T_RETURN) reduce 104) ((T_START_HEREDOC) reduce 104) ((T_STATIC) reduce 104) ((T_STRING) reduce 104) ((T_STRING_CAST) reduce 104) ((T_SWITCH) reduce 104) ((T_THROW) reduce 104) ((T_TRAIT) reduce 104) ((T_TRAIT_C) reduce 104) ((T_TRY) reduce 104) ((T_UNSET) reduce 104) ((T_UNSET_CAST) reduce 104) ((T_VARIABLE) reduce 104) ((T_WHILE) reduce 104) ((T_YIELD) reduce 104) ((T_YIELD_FROM) reduce 104) (("[") reduce 104) (("`") reduce 104) (("{") reduce 104) (("~") reduce 104)) 16422 ((("!") reduce 145) (("\"") reduce 145) (("$") reduce 145) (("(") reduce 145) (("+") reduce 145) (("-") reduce 145) ((";") reduce 145) (("@") reduce 145) ((T_ABSTRACT) reduce 145) ((T_ARRAY) reduce 145) ((T_ARRAY_CAST) reduce 145) ((T_ATTRIBUTE) reduce 145) ((T_BOOL_CAST) reduce 145) ((T_BREAK) reduce 145) ((T_CLASS) reduce 145) ((T_CLASS_C) reduce 145) ((T_CLONE) reduce 145) ((T_CONSTANT_ENCAPSED_STRING) reduce 145) ((T_CONTINUE) reduce 145) ((T_DEC) reduce 145) ((T_DECLARE) reduce 145) ((T_DIR) reduce 145) ((T_DNUMBER) reduce 145) ((T_DO) reduce 145) ((T_DOUBLE_CAST) reduce 145) ((T_ECHO) reduce 145) ((T_EMPTY) reduce 145) ((T_ENDWHILE) reduce 145) ((T_ENUM) reduce 145) ((T_EVAL) reduce 145) ((T_EXIT) reduce 145) ((T_FILE) reduce 145) ((T_FINAL) reduce 145) ((T_FN) reduce 145) ((T_FOR) reduce 145) ((T_FOREACH) reduce 145) ((T_FUNCTION) reduce 145) ((T_FUNC_C) reduce 145) ((T_GLOBAL) reduce 145) ((T_GOTO) reduce 145) ((T_HALT_COMPILER) reduce 145) ((T_IF) reduce 145) ((T_INC) reduce 145) ((T_INCLUDE) reduce 145) ((T_INCLUDE_ONCE) reduce 145) ((T_INLINE_HTML) reduce 145) ((T_INTERFACE) reduce 145) ((T_INT_CAST) reduce 145) ((T_ISSET) reduce 145) ((T_LINE) reduce 145) ((T_LIST) reduce 145) ((T_LNUMBER) reduce 145) ((T_MATCH) reduce 145) ((T_METHOD_C) reduce 145) ((T_NAME_FULLY_QUALIFIED) reduce 145) ((T_NAME_QUALIFIED) reduce 145) ((T_NAME_RELATIVE) reduce 145) ((T_NEW) reduce 145) ((T_NS_C) reduce 145) ((T_OBJECT_CAST) reduce 145) ((T_PRINT) reduce 145) ((T_READONLY) reduce 145) ((T_REQUIRE) reduce 145) ((T_REQUIRE_ONCE) reduce 145) ((T_RETURN) reduce 145) ((T_START_HEREDOC) reduce 145) ((T_STATIC) reduce 145) ((T_STRING) reduce 145) ((T_STRING_CAST) reduce 145) ((T_SWITCH) reduce 145) ((T_THROW) reduce 145) ((T_TRAIT) reduce 145) ((T_TRAIT_C) reduce 145) ((T_TRY) reduce 145) ((T_UNSET) reduce 145) ((T_UNSET_CAST) reduce 145) ((T_VARIABLE) reduce 145) ((T_WHILE) reduce 145) ((T_YIELD) reduce 145) ((T_YIELD_FROM) reduce 145) (("[") reduce 145) (("`") reduce 145) (("{") reduce 145) (("~") reduce 145)) 16428 ((("!") reduce 164) (("\"") reduce 164) (("$") reduce 164) (("(") reduce 164) (("+") reduce 164) (("-") reduce 164) ((";") reduce 164) (("@") reduce 164) ((T_ABSTRACT) reduce 164) ((T_ARRAY) reduce 164) ((T_ARRAY_CAST) reduce 164) ((T_ATTRIBUTE) reduce 164) ((T_BOOL_CAST) reduce 164) ((T_BREAK) reduce 164) ((T_CLASS) reduce 164) ((T_CLASS_C) reduce 164) ((T_CLONE) reduce 164) ((T_CONSTANT_ENCAPSED_STRING) reduce 164) ((T_CONTINUE) reduce 164) ((T_DEC) reduce 164) ((T_DECLARE) reduce 164) ((T_DIR) reduce 164) ((T_DNUMBER) reduce 164) ((T_DO) reduce 164) ((T_DOUBLE_CAST) reduce 164) ((T_ECHO) reduce 164) ((T_ELSE) reduce 164) ((T_ELSEIF) reduce 164) ((T_EMPTY) reduce 164) ((T_ENDWHILE) reduce 164) ((T_ENUM) reduce 164) ((T_EVAL) reduce 164) ((T_EXIT) reduce 164) ((T_FILE) reduce 164) ((T_FINAL) reduce 164) ((T_FN) reduce 164) ((T_FOR) reduce 164) ((T_FOREACH) reduce 164) ((T_FUNCTION) reduce 164) ((T_FUNC_C) reduce 164) ((T_GLOBAL) reduce 164) ((T_GOTO) reduce 164) ((T_HALT_COMPILER) reduce 164) ((T_IF) reduce 164) ((T_INC) reduce 164) ((T_INCLUDE) reduce 164) ((T_INCLUDE_ONCE) reduce 164) ((T_INLINE_HTML) reduce 164) ((T_INTERFACE) reduce 164) ((T_INT_CAST) reduce 164) ((T_ISSET) reduce 164) ((T_LINE) reduce 164) ((T_LIST) reduce 164) ((T_LNUMBER) reduce 164) ((T_MATCH) reduce 164) ((T_METHOD_C) reduce 164) ((T_NAME_FULLY_QUALIFIED) reduce 164) ((T_NAME_QUALIFIED) reduce 164) ((T_NAME_RELATIVE) reduce 164) ((T_NEW) reduce 164) ((T_NS_C) reduce 164) ((T_OBJECT_CAST) reduce 164) ((T_PRINT) reduce 164) ((T_READONLY) reduce 164) ((T_REQUIRE) reduce 164) ((T_REQUIRE_ONCE) reduce 164) ((T_RETURN) reduce 164) ((T_START_HEREDOC) reduce 164) ((T_STATIC) reduce 164) ((T_STRING) reduce 164) ((T_STRING_CAST) reduce 164) ((T_SWITCH) reduce 164) ((T_THROW) reduce 164) ((T_TRAIT) reduce 164) ((T_TRAIT_C) reduce 164) ((T_TRY) reduce 164) ((T_UNSET) reduce 164) ((T_UNSET_CAST) reduce 164) ((T_VARIABLE) reduce 164) ((T_WHILE) reduce 164) ((T_YIELD) reduce 164) ((T_YIELD_FROM) reduce 164) (("[") reduce 164) (("`") reduce 164) (("{") reduce 164) (("~") reduce 164)) 16438 ((("!") reduce 158) (("\"") reduce 158) (("$") reduce 158) (("(") reduce 158) (("+") reduce 158) (("-") reduce 158) ((";") reduce 158) (("@") reduce 158) ((T_ABSTRACT) reduce 158) ((T_ARRAY) reduce 158) ((T_ARRAY_CAST) reduce 158) ((T_ATTRIBUTE) reduce 158) ((T_BOOL_CAST) reduce 158) ((T_BREAK) reduce 158) ((T_CLASS) reduce 158) ((T_CLASS_C) reduce 158) ((T_CLONE) reduce 158) ((T_CONSTANT_ENCAPSED_STRING) reduce 158) ((T_CONTINUE) reduce 158) ((T_DEC) reduce 158) ((T_DECLARE) reduce 158) ((T_DIR) reduce 158) ((T_DNUMBER) reduce 158) ((T_DO) reduce 158) ((T_DOUBLE_CAST) reduce 158) ((T_ECHO) reduce 158) ((T_ELSE) reduce 158) ((T_ELSEIF) reduce 158) ((T_EMPTY) reduce 158) ((T_ENDWHILE) reduce 158) ((T_ENUM) reduce 158) ((T_EVAL) reduce 158) ((T_EXIT) reduce 158) ((T_FILE) reduce 158) ((T_FINAL) reduce 158) ((T_FN) reduce 158) ((T_FOR) reduce 158) ((T_FOREACH) reduce 158) ((T_FUNCTION) reduce 158) ((T_FUNC_C) reduce 158) ((T_GLOBAL) reduce 158) ((T_GOTO) reduce 158) ((T_HALT_COMPILER) reduce 158) ((T_IF) reduce 158) ((T_INC) reduce 158) ((T_INCLUDE) reduce 158) ((T_INCLUDE_ONCE) reduce 158) ((T_INLINE_HTML) reduce 158) ((T_INTERFACE) reduce 158) ((T_INT_CAST) reduce 158) ((T_ISSET) reduce 158) ((T_LINE) reduce 158) ((T_LIST) reduce 158) ((T_LNUMBER) reduce 158) ((T_MATCH) reduce 158) ((T_METHOD_C) reduce 158) ((T_NAME_FULLY_QUALIFIED) reduce 158) ((T_NAME_QUALIFIED) reduce 158) ((T_NAME_RELATIVE) reduce 158) ((T_NEW) reduce 158) ((T_NS_C) reduce 158) ((T_OBJECT_CAST) reduce 158) ((T_PRINT) reduce 158) ((T_READONLY) reduce 158) ((T_REQUIRE) reduce 158) ((T_REQUIRE_ONCE) reduce 158) ((T_RETURN) reduce 158) ((T_START_HEREDOC) reduce 158) ((T_STATIC) reduce 158) ((T_STRING) reduce 158) ((T_STRING_CAST) reduce 158) ((T_SWITCH) reduce 158) ((T_THROW) reduce 158) ((T_TRAIT) reduce 158) ((T_TRAIT_C) reduce 158) ((T_TRY) reduce 158) ((T_UNSET) reduce 158) ((T_UNSET_CAST) reduce 158) ((T_VARIABLE) reduce 158) ((T_WHILE) reduce 158) ((T_YIELD) reduce 158) ((T_YIELD_FROM) reduce 158) (("[") reduce 158) (("`") reduce 158) (("{") reduce 158) (("~") reduce 158)) 16446 ((("!") reduce 147) (("\"") reduce 147) (("$") reduce 147) (("(") reduce 147) (("+") reduce 147) (("-") reduce 147) ((";") reduce 147) (("@") reduce 147) ((T_ABSTRACT) reduce 147) ((T_ARRAY) reduce 147) ((T_ARRAY_CAST) reduce 147) ((T_ATTRIBUTE) reduce 147) ((T_BOOL_CAST) reduce 147) ((T_BREAK) reduce 147) ((T_CLASS) reduce 147) ((T_CLASS_C) reduce 147) ((T_CLONE) reduce 147) ((T_CONSTANT_ENCAPSED_STRING) reduce 147) ((T_CONTINUE) reduce 147) ((T_DEC) reduce 147) ((T_DECLARE) reduce 147) ((T_DIR) reduce 147) ((T_DNUMBER) reduce 147) ((T_DO) reduce 147) ((T_DOUBLE_CAST) reduce 147) ((T_ECHO) reduce 147) ((T_ELSE) reduce 147) ((T_ELSEIF) reduce 147) ((T_EMPTY) reduce 147) ((T_ENDWHILE) reduce 147) ((T_ENUM) reduce 147) ((T_EVAL) reduce 147) ((T_EXIT) reduce 147) ((T_FILE) reduce 147) ((T_FINAL) reduce 147) ((T_FN) reduce 147) ((T_FOR) reduce 147) ((T_FOREACH) reduce 147) ((T_FUNCTION) reduce 147) ((T_FUNC_C) reduce 147) ((T_GLOBAL) reduce 147) ((T_GOTO) reduce 147) ((T_HALT_COMPILER) reduce 147) ((T_IF) reduce 147) ((T_INC) reduce 147) ((T_INCLUDE) reduce 147) ((T_INCLUDE_ONCE) reduce 147) ((T_INLINE_HTML) reduce 147) ((T_INTERFACE) reduce 147) ((T_INT_CAST) reduce 147) ((T_ISSET) reduce 147) ((T_LINE) reduce 147) ((T_LIST) reduce 147) ((T_LNUMBER) reduce 147) ((T_MATCH) reduce 147) ((T_METHOD_C) reduce 147) ((T_NAME_FULLY_QUALIFIED) reduce 147) ((T_NAME_QUALIFIED) reduce 147) ((T_NAME_RELATIVE) reduce 147) ((T_NEW) reduce 147) ((T_NS_C) reduce 147) ((T_OBJECT_CAST) reduce 147) ((T_PRINT) reduce 147) ((T_READONLY) reduce 147) ((T_REQUIRE) reduce 147) ((T_REQUIRE_ONCE) reduce 147) ((T_RETURN) reduce 147) ((T_START_HEREDOC) reduce 147) ((T_STATIC) reduce 147) ((T_STRING) reduce 147) ((T_STRING_CAST) reduce 147) ((T_SWITCH) reduce 147) ((T_THROW) reduce 147) ((T_TRAIT) reduce 147) ((T_TRAIT_C) reduce 147) ((T_TRY) reduce 147) ((T_UNSET) reduce 147) ((T_UNSET_CAST) reduce 147) ((T_VARIABLE) reduce 147) ((T_WHILE) reduce 147) ((T_YIELD) reduce 147) ((T_YIELD_FROM) reduce 147) (("[") reduce 147) (("`") reduce 147) (("{") reduce 147) (("~") reduce 147)) 16449 ((("!") reduce 146) (("\"") reduce 146) (("$") reduce 146) (("(") reduce 146) (("+") reduce 146) (("-") reduce 146) ((";") reduce 146) (("@") reduce 146) ((T_ABSTRACT) reduce 146) ((T_ARRAY) reduce 146) ((T_ARRAY_CAST) reduce 146) ((T_ATTRIBUTE) reduce 146) ((T_BOOL_CAST) reduce 146) ((T_BREAK) reduce 146) ((T_CLASS) reduce 146) ((T_CLASS_C) reduce 146) ((T_CLONE) reduce 146) ((T_CONSTANT_ENCAPSED_STRING) reduce 146) ((T_CONTINUE) reduce 146) ((T_DEC) reduce 146) ((T_DECLARE) reduce 146) ((T_DIR) reduce 146) ((T_DNUMBER) reduce 146) ((T_DO) reduce 146) ((T_DOUBLE_CAST) reduce 146) ((T_ECHO) reduce 146) ((T_ELSE) reduce 146) ((T_ELSEIF) reduce 146) ((T_EMPTY) reduce 146) ((T_ENDWHILE) reduce 146) ((T_ENUM) reduce 146) ((T_EVAL) reduce 146) ((T_EXIT) reduce 146) ((T_FILE) reduce 146) ((T_FINAL) reduce 146) ((T_FN) reduce 146) ((T_FOR) reduce 146) ((T_FOREACH) reduce 146) ((T_FUNCTION) reduce 146) ((T_FUNC_C) reduce 146) ((T_GLOBAL) reduce 146) ((T_GOTO) reduce 146) ((T_HALT_COMPILER) reduce 146) ((T_IF) reduce 146) ((T_INC) reduce 146) ((T_INCLUDE) reduce 146) ((T_INCLUDE_ONCE) reduce 146) ((T_INLINE_HTML) reduce 146) ((T_INTERFACE) reduce 146) ((T_INT_CAST) reduce 146) ((T_ISSET) reduce 146) ((T_LINE) reduce 146) ((T_LIST) reduce 146) ((T_LNUMBER) reduce 146) ((T_MATCH) reduce 146) ((T_METHOD_C) reduce 146) ((T_NAME_FULLY_QUALIFIED) reduce 146) ((T_NAME_QUALIFIED) reduce 146) ((T_NAME_RELATIVE) reduce 146) ((T_NEW) reduce 146) ((T_NS_C) reduce 146) ((T_OBJECT_CAST) reduce 146) ((T_PRINT) reduce 146) ((T_READONLY) reduce 146) ((T_REQUIRE) reduce 146) ((T_REQUIRE_ONCE) reduce 146) ((T_RETURN) reduce 146) ((T_START_HEREDOC) reduce 146) ((T_STATIC) reduce 146) ((T_STRING) reduce 146) ((T_STRING_CAST) reduce 146) ((T_SWITCH) reduce 146) ((T_THROW) reduce 146) ((T_TRAIT) reduce 146) ((T_TRAIT_C) reduce 146) ((T_TRY) reduce 146) ((T_UNSET) reduce 146) ((T_UNSET_CAST) reduce 146) ((T_VARIABLE) reduce 146) ((T_WHILE) reduce 146) ((T_YIELD) reduce 146) ((T_YIELD_FROM) reduce 146) (("[") reduce 146) (("`") reduce 146) (("{") reduce 146) (("~") reduce 146)) 16451 ((("!") reduce 242) (("\"") reduce 242) (("$") reduce 242) (("(") reduce 242) (("+") reduce 242) (("-") reduce 242) ((";") reduce 242) (("@") reduce 242) ((T_ABSTRACT) reduce 242) ((T_ARRAY) reduce 242) ((T_ARRAY_CAST) reduce 242) ((T_ATTRIBUTE) reduce 242) ((T_BOOL_CAST) reduce 242) ((T_BREAK) reduce 242) ((T_CLASS) reduce 242) ((T_CLASS_C) reduce 242) ((T_CLONE) reduce 242) ((T_CONSTANT_ENCAPSED_STRING) reduce 242) ((T_CONTINUE) reduce 242) ((T_DEC) reduce 242) ((T_DECLARE) reduce 242) ((T_DIR) reduce 242) ((T_DNUMBER) reduce 242) ((T_DO) reduce 242) ((T_DOUBLE_CAST) reduce 242) ((T_ECHO) reduce 242) ((T_ELSE) reduce 242) ((T_ELSEIF) reduce 242) ((T_EMPTY) reduce 242) ((T_ENDWHILE) reduce 242) ((T_ENUM) reduce 242) ((T_EVAL) reduce 242) ((T_EXIT) reduce 242) ((T_FILE) reduce 242) ((T_FINAL) reduce 242) ((T_FN) reduce 242) ((T_FOR) reduce 242) ((T_FOREACH) reduce 242) ((T_FUNCTION) reduce 242) ((T_FUNC_C) reduce 242) ((T_GLOBAL) reduce 242) ((T_GOTO) reduce 242) ((T_HALT_COMPILER) reduce 242) ((T_IF) reduce 242) ((T_INC) reduce 242) ((T_INCLUDE) reduce 242) ((T_INCLUDE_ONCE) reduce 242) ((T_INLINE_HTML) reduce 242) ((T_INTERFACE) reduce 242) ((T_INT_CAST) reduce 242) ((T_ISSET) reduce 242) ((T_LINE) reduce 242) ((T_LIST) reduce 242) ((T_LNUMBER) reduce 242) ((T_MATCH) reduce 242) ((T_METHOD_C) reduce 242) ((T_NAME_FULLY_QUALIFIED) reduce 242) ((T_NAME_QUALIFIED) reduce 242) ((T_NAME_RELATIVE) reduce 242) ((T_NEW) reduce 242) ((T_NS_C) reduce 242) ((T_OBJECT_CAST) reduce 242) ((T_PRINT) reduce 242) ((T_READONLY) reduce 242) ((T_REQUIRE) reduce 242) ((T_REQUIRE_ONCE) reduce 242) ((T_RETURN) reduce 242) ((T_START_HEREDOC) reduce 242) ((T_STATIC) reduce 242) ((T_STRING) reduce 242) ((T_STRING_CAST) reduce 242) ((T_SWITCH) reduce 242) ((T_THROW) reduce 242) ((T_TRAIT) reduce 242) ((T_TRAIT_C) reduce 242) ((T_TRY) reduce 242) ((T_UNSET) reduce 242) ((T_UNSET_CAST) reduce 242) ((T_VARIABLE) reduce 242) ((T_WHILE) reduce 242) ((T_YIELD) reduce 242) ((T_YIELD_FROM) reduce 242) (("[") reduce 242) (("`") reduce 242) (("{") reduce 242) (("~") reduce 242)) 16454 ((("!") reduce 145) (("\"") reduce 145) (("$") reduce 145) (("(") reduce 145) (("+") reduce 145) (("-") reduce 145) ((";") reduce 145) (("@") reduce 145) ((T_ABSTRACT) reduce 145) ((T_ARRAY) reduce 145) ((T_ARRAY_CAST) reduce 145) ((T_ATTRIBUTE) reduce 145) ((T_BOOL_CAST) reduce 145) ((T_BREAK) reduce 145) ((T_CLASS) reduce 145) ((T_CLASS_C) reduce 145) ((T_CLONE) reduce 145) ((T_CONSTANT_ENCAPSED_STRING) reduce 145) ((T_CONTINUE) reduce 145) ((T_DEC) reduce 145) ((T_DECLARE) reduce 145) ((T_DIR) reduce 145) ((T_DNUMBER) reduce 145) ((T_DO) reduce 145) ((T_DOUBLE_CAST) reduce 145) ((T_ECHO) reduce 145) ((T_ELSE) reduce 145) ((T_ELSEIF) reduce 145) ((T_EMPTY) reduce 145) ((T_ENDWHILE) reduce 145) ((T_ENUM) reduce 145) ((T_EVAL) reduce 145) ((T_EXIT) reduce 145) ((T_FILE) reduce 145) ((T_FINAL) reduce 145) ((T_FN) reduce 145) ((T_FOR) reduce 145) ((T_FOREACH) reduce 145) ((T_FUNCTION) reduce 145) ((T_FUNC_C) reduce 145) ((T_GLOBAL) reduce 145) ((T_GOTO) reduce 145) ((T_HALT_COMPILER) reduce 145) ((T_IF) reduce 145) ((T_INC) reduce 145) ((T_INCLUDE) reduce 145) ((T_INCLUDE_ONCE) reduce 145) ((T_INLINE_HTML) reduce 145) ((T_INTERFACE) reduce 145) ((T_INT_CAST) reduce 145) ((T_ISSET) reduce 145) ((T_LINE) reduce 145) ((T_LIST) reduce 145) ((T_LNUMBER) reduce 145) ((T_MATCH) reduce 145) ((T_METHOD_C) reduce 145) ((T_NAME_FULLY_QUALIFIED) reduce 145) ((T_NAME_QUALIFIED) reduce 145) ((T_NAME_RELATIVE) reduce 145) ((T_NEW) reduce 145) ((T_NS_C) reduce 145) ((T_OBJECT_CAST) reduce 145) ((T_PRINT) reduce 145) ((T_READONLY) reduce 145) ((T_REQUIRE) reduce 145) ((T_REQUIRE_ONCE) reduce 145) ((T_RETURN) reduce 145) ((T_START_HEREDOC) reduce 145) ((T_STATIC) reduce 145) ((T_STRING) reduce 145) ((T_STRING_CAST) reduce 145) ((T_SWITCH) reduce 145) ((T_THROW) reduce 145) ((T_TRAIT) reduce 145) ((T_TRAIT_C) reduce 145) ((T_TRY) reduce 145) ((T_UNSET) reduce 145) ((T_UNSET_CAST) reduce 145) ((T_VARIABLE) reduce 145) ((T_WHILE) reduce 145) ((T_YIELD) reduce 145) ((T_YIELD_FROM) reduce 145) (("[") reduce 145) (("`") reduce 145) (("{") reduce 145) (("~") reduce 145)) 16456 ((("!") reduce 244) (("\"") reduce 244) (("$") reduce 244) (("(") reduce 244) (("+") reduce 244) (("-") reduce 244) ((";") reduce 244) (("@") reduce 244) ((T_ABSTRACT) reduce 244) ((T_ARRAY) reduce 244) ((T_ARRAY_CAST) reduce 244) ((T_ATTRIBUTE) reduce 244) ((T_BOOL_CAST) reduce 244) ((T_BREAK) reduce 244) ((T_CLASS) reduce 244) ((T_CLASS_C) reduce 244) ((T_CLONE) reduce 244) ((T_CONSTANT_ENCAPSED_STRING) reduce 244) ((T_CONTINUE) reduce 244) ((T_DEC) reduce 244) ((T_DECLARE) reduce 244) ((T_DIR) reduce 244) ((T_DNUMBER) reduce 244) ((T_DO) reduce 244) ((T_DOUBLE_CAST) reduce 244) ((T_ECHO) reduce 244) ((T_ELSE) reduce 244) ((T_ELSEIF) reduce 244) ((T_EMPTY) reduce 244) ((T_ENDWHILE) reduce 244) ((T_ENUM) reduce 244) ((T_EVAL) reduce 244) ((T_EXIT) reduce 244) ((T_FILE) reduce 244) ((T_FINAL) reduce 244) ((T_FN) reduce 244) ((T_FOR) reduce 244) ((T_FOREACH) reduce 244) ((T_FUNCTION) reduce 244) ((T_FUNC_C) reduce 244) ((T_GLOBAL) reduce 244) ((T_GOTO) reduce 244) ((T_HALT_COMPILER) reduce 244) ((T_IF) reduce 244) ((T_INC) reduce 244) ((T_INCLUDE) reduce 244) ((T_INCLUDE_ONCE) reduce 244) ((T_INLINE_HTML) reduce 244) ((T_INTERFACE) reduce 244) ((T_INT_CAST) reduce 244) ((T_ISSET) reduce 244) ((T_LINE) reduce 244) ((T_LIST) reduce 244) ((T_LNUMBER) reduce 244) ((T_MATCH) reduce 244) ((T_METHOD_C) reduce 244) ((T_NAME_FULLY_QUALIFIED) reduce 244) ((T_NAME_QUALIFIED) reduce 244) ((T_NAME_RELATIVE) reduce 244) ((T_NEW) reduce 244) ((T_NS_C) reduce 244) ((T_OBJECT_CAST) reduce 244) ((T_PRINT) reduce 244) ((T_READONLY) reduce 244) ((T_REQUIRE) reduce 244) ((T_REQUIRE_ONCE) reduce 244) ((T_RETURN) reduce 244) ((T_START_HEREDOC) reduce 244) ((T_STATIC) reduce 244) ((T_STRING) reduce 244) ((T_STRING_CAST) reduce 244) ((T_SWITCH) reduce 244) ((T_THROW) reduce 244) ((T_TRAIT) reduce 244) ((T_TRAIT_C) reduce 244) ((T_TRY) reduce 244) ((T_UNSET) reduce 244) ((T_UNSET_CAST) reduce 244) ((T_VARIABLE) reduce 244) ((T_WHILE) reduce 244) ((T_YIELD) reduce 244) ((T_YIELD_FROM) reduce 244) (("[") reduce 244) (("`") reduce 244) (("{") reduce 244) (("~") reduce 244)) 16457 ((("!") reduce 159) (("\"") reduce 159) (("$") reduce 159) (("(") reduce 159) (("+") reduce 159) (("-") reduce 159) ((";") reduce 159) (("@") reduce 159) ((T_ABSTRACT) reduce 159) ((T_ARRAY) reduce 159) ((T_ARRAY_CAST) reduce 159) ((T_ATTRIBUTE) reduce 159) ((T_BOOL_CAST) reduce 159) ((T_BREAK) reduce 159) ((T_CLASS) reduce 159) ((T_CLASS_C) reduce 159) ((T_CLONE) reduce 159) ((T_CONSTANT_ENCAPSED_STRING) reduce 159) ((T_CONTINUE) reduce 159) ((T_DEC) reduce 159) ((T_DECLARE) reduce 159) ((T_DIR) reduce 159) ((T_DNUMBER) reduce 159) ((T_DO) reduce 159) ((T_DOUBLE_CAST) reduce 159) ((T_ECHO) reduce 159) ((T_ELSE) reduce 159) ((T_ELSEIF) reduce 159) ((T_EMPTY) reduce 159) ((T_ENDWHILE) reduce 159) ((T_ENUM) reduce 159) ((T_EVAL) reduce 159) ((T_EXIT) reduce 159) ((T_FILE) reduce 159) ((T_FINAL) reduce 159) ((T_FN) reduce 159) ((T_FOR) reduce 159) ((T_FOREACH) reduce 159) ((T_FUNCTION) reduce 159) ((T_FUNC_C) reduce 159) ((T_GLOBAL) reduce 159) ((T_GOTO) reduce 159) ((T_HALT_COMPILER) reduce 159) ((T_IF) reduce 159) ((T_INC) reduce 159) ((T_INCLUDE) reduce 159) ((T_INCLUDE_ONCE) reduce 159) ((T_INLINE_HTML) reduce 159) ((T_INTERFACE) reduce 159) ((T_INT_CAST) reduce 159) ((T_ISSET) reduce 159) ((T_LINE) reduce 159) ((T_LIST) reduce 159) ((T_LNUMBER) reduce 159) ((T_MATCH) reduce 159) ((T_METHOD_C) reduce 159) ((T_NAME_FULLY_QUALIFIED) reduce 159) ((T_NAME_QUALIFIED) reduce 159) ((T_NAME_RELATIVE) reduce 159) ((T_NEW) reduce 159) ((T_NS_C) reduce 159) ((T_OBJECT_CAST) reduce 159) ((T_PRINT) reduce 159) ((T_READONLY) reduce 159) ((T_REQUIRE) reduce 159) ((T_REQUIRE_ONCE) reduce 159) ((T_RETURN) reduce 159) ((T_START_HEREDOC) reduce 159) ((T_STATIC) reduce 159) ((T_STRING) reduce 159) ((T_STRING_CAST) reduce 159) ((T_SWITCH) reduce 159) ((T_THROW) reduce 159) ((T_TRAIT) reduce 159) ((T_TRAIT_C) reduce 159) ((T_TRY) reduce 159) ((T_UNSET) reduce 159) ((T_UNSET_CAST) reduce 159) ((T_VARIABLE) reduce 159) ((T_WHILE) reduce 159) ((T_YIELD) reduce 159) ((T_YIELD_FROM) reduce 159) (("[") reduce 159) (("`") reduce 159) (("{") reduce 159) (("~") reduce 159)) 16460 ((("!") reduce 247) (("\"") reduce 247) (("$") reduce 247) (("(") reduce 247) (("+") reduce 247) (("-") reduce 247) ((";") reduce 247) (("@") reduce 247) ((T_ABSTRACT) reduce 247) ((T_ARRAY) reduce 247) ((T_ARRAY_CAST) reduce 247) ((T_ATTRIBUTE) reduce 247) ((T_BOOL_CAST) reduce 247) ((T_BREAK) reduce 247) ((T_CLASS) reduce 247) ((T_CLASS_C) reduce 247) ((T_CLONE) reduce 247) ((T_CONSTANT_ENCAPSED_STRING) reduce 247) ((T_CONTINUE) reduce 247) ((T_DEC) reduce 247) ((T_DECLARE) reduce 247) ((T_DIR) reduce 247) ((T_DNUMBER) reduce 247) ((T_DO) reduce 247) ((T_DOUBLE_CAST) reduce 247) ((T_ECHO) reduce 247) ((T_ELSE) reduce 247) ((T_ELSEIF) reduce 247) ((T_EMPTY) reduce 247) ((T_ENDWHILE) reduce 247) ((T_ENUM) reduce 247) ((T_EVAL) reduce 247) ((T_EXIT) reduce 247) ((T_FILE) reduce 247) ((T_FINAL) reduce 247) ((T_FN) reduce 247) ((T_FOR) reduce 247) ((T_FOREACH) reduce 247) ((T_FUNCTION) reduce 247) ((T_FUNC_C) reduce 247) ((T_GLOBAL) reduce 247) ((T_GOTO) reduce 247) ((T_HALT_COMPILER) reduce 247) ((T_IF) reduce 247) ((T_INC) reduce 247) ((T_INCLUDE) reduce 247) ((T_INCLUDE_ONCE) reduce 247) ((T_INLINE_HTML) reduce 247) ((T_INTERFACE) reduce 247) ((T_INT_CAST) reduce 247) ((T_ISSET) reduce 247) ((T_LINE) reduce 247) ((T_LIST) reduce 247) ((T_LNUMBER) reduce 247) ((T_MATCH) reduce 247) ((T_METHOD_C) reduce 247) ((T_NAME_FULLY_QUALIFIED) reduce 247) ((T_NAME_QUALIFIED) reduce 247) ((T_NAME_RELATIVE) reduce 247) ((T_NEW) reduce 247) ((T_NS_C) reduce 247) ((T_OBJECT_CAST) reduce 247) ((T_PRINT) reduce 247) ((T_READONLY) reduce 247) ((T_REQUIRE) reduce 247) ((T_REQUIRE_ONCE) reduce 247) ((T_RETURN) reduce 247) ((T_START_HEREDOC) reduce 247) ((T_STATIC) reduce 247) ((T_STRING) reduce 247) ((T_STRING_CAST) reduce 247) ((T_SWITCH) reduce 247) ((T_THROW) reduce 247) ((T_TRAIT) reduce 247) ((T_TRAIT_C) reduce 247) ((T_TRY) reduce 247) ((T_UNSET) reduce 247) ((T_UNSET_CAST) reduce 247) ((T_VARIABLE) reduce 247) ((T_WHILE) reduce 247) ((T_YIELD) reduce 247) ((T_YIELD_FROM) reduce 247) (("[") reduce 247) (("`") reduce 247) (("{") reduce 247) (("~") reduce 247)) 16464 ((("!") reduce 248) (("\"") reduce 248) (("$") reduce 248) (("(") reduce 248) (("+") reduce 248) (("-") reduce 248) ((";") reduce 248) (("@") reduce 248) ((T_ABSTRACT) reduce 248) ((T_ARRAY) reduce 248) ((T_ARRAY_CAST) reduce 248) ((T_ATTRIBUTE) reduce 248) ((T_BOOL_CAST) reduce 248) ((T_BREAK) reduce 248) ((T_CLASS) reduce 248) ((T_CLASS_C) reduce 248) ((T_CLONE) reduce 248) ((T_CONSTANT_ENCAPSED_STRING) reduce 248) ((T_CONTINUE) reduce 248) ((T_DEC) reduce 248) ((T_DECLARE) reduce 248) ((T_DIR) reduce 248) ((T_DNUMBER) reduce 248) ((T_DO) reduce 248) ((T_DOUBLE_CAST) reduce 248) ((T_ECHO) reduce 248) ((T_ELSE) reduce 248) ((T_ELSEIF) reduce 248) ((T_EMPTY) reduce 248) ((T_ENDWHILE) reduce 248) ((T_ENUM) reduce 248) ((T_EVAL) reduce 248) ((T_EXIT) reduce 248) ((T_FILE) reduce 248) ((T_FINAL) reduce 248) ((T_FN) reduce 248) ((T_FOR) reduce 248) ((T_FOREACH) reduce 248) ((T_FUNCTION) reduce 248) ((T_FUNC_C) reduce 248) ((T_GLOBAL) reduce 248) ((T_GOTO) reduce 248) ((T_HALT_COMPILER) reduce 248) ((T_IF) reduce 248) ((T_INC) reduce 248) ((T_INCLUDE) reduce 248) ((T_INCLUDE_ONCE) reduce 248) ((T_INLINE_HTML) reduce 248) ((T_INTERFACE) reduce 248) ((T_INT_CAST) reduce 248) ((T_ISSET) reduce 248) ((T_LINE) reduce 248) ((T_LIST) reduce 248) ((T_LNUMBER) reduce 248) ((T_MATCH) reduce 248) ((T_METHOD_C) reduce 248) ((T_NAME_FULLY_QUALIFIED) reduce 248) ((T_NAME_QUALIFIED) reduce 248) ((T_NAME_RELATIVE) reduce 248) ((T_NEW) reduce 248) ((T_NS_C) reduce 248) ((T_OBJECT_CAST) reduce 248) ((T_PRINT) reduce 248) ((T_READONLY) reduce 248) ((T_REQUIRE) reduce 248) ((T_REQUIRE_ONCE) reduce 248) ((T_RETURN) reduce 248) ((T_START_HEREDOC) reduce 248) ((T_STATIC) reduce 248) ((T_STRING) reduce 248) ((T_STRING_CAST) reduce 248) ((T_SWITCH) reduce 248) ((T_THROW) reduce 248) ((T_TRAIT) reduce 248) ((T_TRAIT_C) reduce 248) ((T_TRY) reduce 248) ((T_UNSET) reduce 248) ((T_UNSET_CAST) reduce 248) ((T_VARIABLE) reduce 248) ((T_WHILE) reduce 248) ((T_YIELD) reduce 248) ((T_YIELD_FROM) reduce 248) (("[") reduce 248) (("`") reduce 248) (("{") reduce 248) (("~") reduce 248)) 16469 ((("!") reduce 239) (("\"") reduce 239) (("$") reduce 239) (("(") reduce 239) (("+") reduce 239) (("-") reduce 239) ((";") reduce 239) (("@") reduce 239) ((T_ABSTRACT) reduce 239) ((T_ARRAY) reduce 239) ((T_ARRAY_CAST) reduce 239) ((T_ATTRIBUTE) reduce 239) ((T_BOOL_CAST) reduce 239) ((T_BREAK) reduce 239) ((T_CLASS) reduce 239) ((T_CLASS_C) reduce 239) ((T_CLONE) reduce 239) ((T_CONSTANT_ENCAPSED_STRING) reduce 239) ((T_CONTINUE) reduce 239) ((T_DEC) reduce 239) ((T_DECLARE) reduce 239) ((T_DIR) reduce 239) ((T_DNUMBER) reduce 239) ((T_DO) reduce 239) ((T_DOUBLE_CAST) reduce 239) ((T_ECHO) reduce 239) ((T_ELSE) reduce 239) ((T_ELSEIF) reduce 239) ((T_EMPTY) reduce 239) ((T_ENDWHILE) reduce 239) ((T_ENUM) reduce 239) ((T_EVAL) reduce 239) ((T_EXIT) reduce 239) ((T_FILE) reduce 239) ((T_FINAL) reduce 239) ((T_FN) reduce 239) ((T_FOR) reduce 239) ((T_FOREACH) reduce 239) ((T_FUNCTION) reduce 239) ((T_FUNC_C) reduce 239) ((T_GLOBAL) reduce 239) ((T_GOTO) reduce 239) ((T_HALT_COMPILER) reduce 239) ((T_IF) reduce 239) ((T_INC) reduce 239) ((T_INCLUDE) reduce 239) ((T_INCLUDE_ONCE) reduce 239) ((T_INLINE_HTML) reduce 239) ((T_INTERFACE) reduce 239) ((T_INT_CAST) reduce 239) ((T_ISSET) reduce 239) ((T_LINE) reduce 239) ((T_LIST) reduce 239) ((T_LNUMBER) reduce 239) ((T_MATCH) reduce 239) ((T_METHOD_C) reduce 239) ((T_NAME_FULLY_QUALIFIED) reduce 239) ((T_NAME_QUALIFIED) reduce 239) ((T_NAME_RELATIVE) reduce 239) ((T_NEW) reduce 239) ((T_NS_C) reduce 239) ((T_OBJECT_CAST) reduce 239) ((T_PRINT) reduce 239) ((T_READONLY) reduce 239) ((T_REQUIRE) reduce 239) ((T_REQUIRE_ONCE) reduce 239) ((T_RETURN) reduce 239) ((T_START_HEREDOC) reduce 239) ((T_STATIC) reduce 239) ((T_STRING) reduce 239) ((T_STRING_CAST) reduce 239) ((T_SWITCH) reduce 239) ((T_THROW) reduce 239) ((T_TRAIT) reduce 239) ((T_TRAIT_C) reduce 239) ((T_TRY) reduce 239) ((T_UNSET) reduce 239) ((T_UNSET_CAST) reduce 239) ((T_VARIABLE) reduce 239) ((T_WHILE) reduce 239) ((T_YIELD) reduce 239) ((T_YIELD_FROM) reduce 239) (("[") reduce 239) (("`") reduce 239) (("{") reduce 239) (("~") reduce 239)) 16470 ((("!") reduce 148) (("\"") reduce 148) (("$") reduce 148) (("(") reduce 148) (("+") reduce 148) (("-") reduce 148) ((";") reduce 148) (("@") reduce 148) ((T_ABSTRACT) reduce 148) ((T_ARRAY) reduce 148) ((T_ARRAY_CAST) reduce 148) ((T_ATTRIBUTE) reduce 148) ((T_BOOL_CAST) reduce 148) ((T_BREAK) reduce 148) ((T_CLASS) reduce 148) ((T_CLASS_C) reduce 148) ((T_CLONE) reduce 148) ((T_CONSTANT_ENCAPSED_STRING) reduce 148) ((T_CONTINUE) reduce 148) ((T_DEC) reduce 148) ((T_DECLARE) reduce 148) ((T_DIR) reduce 148) ((T_DNUMBER) reduce 148) ((T_DO) reduce 148) ((T_DOUBLE_CAST) reduce 148) ((T_ECHO) reduce 148) ((T_ELSE) reduce 148) ((T_ELSEIF) reduce 148) ((T_EMPTY) reduce 148) ((T_ENDWHILE) reduce 148) ((T_ENUM) reduce 148) ((T_EVAL) reduce 148) ((T_EXIT) reduce 148) ((T_FILE) reduce 148) ((T_FINAL) reduce 148) ((T_FN) reduce 148) ((T_FOR) reduce 148) ((T_FOREACH) reduce 148) ((T_FUNCTION) reduce 148) ((T_FUNC_C) reduce 148) ((T_GLOBAL) reduce 148) ((T_GOTO) reduce 148) ((T_HALT_COMPILER) reduce 148) ((T_IF) reduce 148) ((T_INC) reduce 148) ((T_INCLUDE) reduce 148) ((T_INCLUDE_ONCE) reduce 148) ((T_INLINE_HTML) reduce 148) ((T_INTERFACE) reduce 148) ((T_INT_CAST) reduce 148) ((T_ISSET) reduce 148) ((T_LINE) reduce 148) ((T_LIST) reduce 148) ((T_LNUMBER) reduce 148) ((T_MATCH) reduce 148) ((T_METHOD_C) reduce 148) ((T_NAME_FULLY_QUALIFIED) reduce 148) ((T_NAME_QUALIFIED) reduce 148) ((T_NAME_RELATIVE) reduce 148) ((T_NEW) reduce 148) ((T_NS_C) reduce 148) ((T_OBJECT_CAST) reduce 148) ((T_PRINT) reduce 148) ((T_READONLY) reduce 148) ((T_REQUIRE) reduce 148) ((T_REQUIRE_ONCE) reduce 148) ((T_RETURN) reduce 148) ((T_START_HEREDOC) reduce 148) ((T_STATIC) reduce 148) ((T_STRING) reduce 148) ((T_STRING_CAST) reduce 148) ((T_SWITCH) reduce 148) ((T_THROW) reduce 148) ((T_TRAIT) reduce 148) ((T_TRAIT_C) reduce 148) ((T_TRY) reduce 148) ((T_UNSET) reduce 148) ((T_UNSET_CAST) reduce 148) ((T_VARIABLE) reduce 148) ((T_WHILE) reduce 148) ((T_YIELD) reduce 148) ((T_YIELD_FROM) reduce 148) (("[") reduce 148) (("`") reduce 148) (("{") reduce 148) (("~") reduce 148)) 16473 ((("!") reduce 240) (("\"") reduce 240) (("$") reduce 240) (("(") reduce 240) (("+") reduce 240) (("-") reduce 240) ((";") reduce 240) (("@") reduce 240) ((T_ABSTRACT) reduce 240) ((T_ARRAY) reduce 240) ((T_ARRAY_CAST) reduce 240) ((T_ATTRIBUTE) reduce 240) ((T_BOOL_CAST) reduce 240) ((T_BREAK) reduce 240) ((T_CLASS) reduce 240) ((T_CLASS_C) reduce 240) ((T_CLONE) reduce 240) ((T_CONSTANT_ENCAPSED_STRING) reduce 240) ((T_CONTINUE) reduce 240) ((T_DEC) reduce 240) ((T_DECLARE) reduce 240) ((T_DIR) reduce 240) ((T_DNUMBER) reduce 240) ((T_DO) reduce 240) ((T_DOUBLE_CAST) reduce 240) ((T_ECHO) reduce 240) ((T_ELSE) reduce 240) ((T_ELSEIF) reduce 240) ((T_EMPTY) reduce 240) ((T_ENDWHILE) reduce 240) ((T_ENUM) reduce 240) ((T_EVAL) reduce 240) ((T_EXIT) reduce 240) ((T_FILE) reduce 240) ((T_FINAL) reduce 240) ((T_FN) reduce 240) ((T_FOR) reduce 240) ((T_FOREACH) reduce 240) ((T_FUNCTION) reduce 240) ((T_FUNC_C) reduce 240) ((T_GLOBAL) reduce 240) ((T_GOTO) reduce 240) ((T_HALT_COMPILER) reduce 240) ((T_IF) reduce 240) ((T_INC) reduce 240) ((T_INCLUDE) reduce 240) ((T_INCLUDE_ONCE) reduce 240) ((T_INLINE_HTML) reduce 240) ((T_INTERFACE) reduce 240) ((T_INT_CAST) reduce 240) ((T_ISSET) reduce 240) ((T_LINE) reduce 240) ((T_LIST) reduce 240) ((T_LNUMBER) reduce 240) ((T_MATCH) reduce 240) ((T_METHOD_C) reduce 240) ((T_NAME_FULLY_QUALIFIED) reduce 240) ((T_NAME_QUALIFIED) reduce 240) ((T_NAME_RELATIVE) reduce 240) ((T_NEW) reduce 240) ((T_NS_C) reduce 240) ((T_OBJECT_CAST) reduce 240) ((T_PRINT) reduce 240) ((T_READONLY) reduce 240) ((T_REQUIRE) reduce 240) ((T_REQUIRE_ONCE) reduce 240) ((T_RETURN) reduce 240) ((T_START_HEREDOC) reduce 240) ((T_STATIC) reduce 240) ((T_STRING) reduce 240) ((T_STRING_CAST) reduce 240) ((T_SWITCH) reduce 240) ((T_THROW) reduce 240) ((T_TRAIT) reduce 240) ((T_TRAIT_C) reduce 240) ((T_TRY) reduce 240) ((T_UNSET) reduce 240) ((T_UNSET_CAST) reduce 240) ((T_VARIABLE) reduce 240) ((T_WHILE) reduce 240) ((T_YIELD) reduce 240) ((T_YIELD_FROM) reduce 240) (("[") reduce 240) (("`") reduce 240) (("{") reduce 240) (("~") reduce 240)) 16486 (((")") reduce 176) ((",") reduce 176)) 16488 (((")") reduce 178) ((",") reduce 178) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) (("[") reduce 510) (("{") reduce 510)) 16501 ((("\"") shift) (("$") shift) (("(") shift) ((")") reduce 124) ((T_ARRAY) shift) ((T_CLASS_C) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DIR) shift) ((T_FILE) shift) ((T_FUNC_C) shift) ((T_LINE) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NS_C) shift) ((T_READONLY) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_TRAIT_C) shift) ((T_VARIABLE) shift) (("[") shift)) 16504 ((("!") reduce 160) (("\"") reduce 160) (("$") reduce 160) (("(") reduce 160) (("+") reduce 160) (("-") reduce 160) ((";") reduce 160) (("@") reduce 160) ((T_ABSTRACT) reduce 160) ((T_ARRAY) reduce 160) ((T_ARRAY_CAST) reduce 160) ((T_ATTRIBUTE) reduce 160) ((T_BOOL_CAST) reduce 160) ((T_BREAK) reduce 160) ((T_CLASS) reduce 160) ((T_CLASS_C) reduce 160) ((T_CLONE) reduce 160) ((T_CONSTANT_ENCAPSED_STRING) reduce 160) ((T_CONTINUE) reduce 160) ((T_DEC) reduce 160) ((T_DECLARE) reduce 160) ((T_DIR) reduce 160) ((T_DNUMBER) reduce 160) ((T_DO) reduce 160) ((T_DOUBLE_CAST) reduce 160) ((T_ECHO) reduce 160) ((T_ELSE) reduce 160) ((T_ELSEIF) reduce 160) ((T_EMPTY) reduce 160) ((T_ENDWHILE) reduce 160) ((T_ENUM) reduce 160) ((T_EVAL) reduce 160) ((T_EXIT) reduce 160) ((T_FILE) reduce 160) ((T_FINAL) reduce 160) ((T_FN) reduce 160) ((T_FOR) reduce 160) ((T_FOREACH) reduce 160) ((T_FUNCTION) reduce 160) ((T_FUNC_C) reduce 160) ((T_GLOBAL) reduce 160) ((T_GOTO) reduce 160) ((T_HALT_COMPILER) reduce 160) ((T_IF) reduce 160) ((T_INC) reduce 160) ((T_INCLUDE) reduce 160) ((T_INCLUDE_ONCE) reduce 160) ((T_INLINE_HTML) reduce 160) ((T_INTERFACE) reduce 160) ((T_INT_CAST) reduce 160) ((T_ISSET) reduce 160) ((T_LINE) reduce 160) ((T_LIST) reduce 160) ((T_LNUMBER) reduce 160) ((T_MATCH) reduce 160) ((T_METHOD_C) reduce 160) ((T_NAME_FULLY_QUALIFIED) reduce 160) ((T_NAME_QUALIFIED) reduce 160) ((T_NAME_RELATIVE) reduce 160) ((T_NEW) reduce 160) ((T_NS_C) reduce 160) ((T_OBJECT_CAST) reduce 160) ((T_PRINT) reduce 160) ((T_READONLY) reduce 160) ((T_REQUIRE) reduce 160) ((T_REQUIRE_ONCE) reduce 160) ((T_RETURN) reduce 160) ((T_START_HEREDOC) reduce 160) ((T_STATIC) reduce 160) ((T_STRING) reduce 160) ((T_STRING_CAST) reduce 160) ((T_SWITCH) reduce 160) ((T_THROW) reduce 160) ((T_TRAIT) reduce 160) ((T_TRAIT_C) reduce 160) ((T_TRY) reduce 160) ((T_UNSET) reduce 160) ((T_UNSET_CAST) reduce 160) ((T_VARIABLE) reduce 160) ((T_WHILE) reduce 160) ((T_YIELD) reduce 160) ((T_YIELD_FROM) reduce 160) (("[") reduce 160) (("`") reduce 160) (("{") reduce 160) (("~") reduce 160)) 16505 (((")") reduce 177) ((",") reduce 177)) 16536 ((("!") reduce 168) (("\"") reduce 168) (("$") reduce 168) (("(") reduce 168) (("+") reduce 168) (("-") reduce 168) ((";") reduce 168) (("@") reduce 168) ((T_ABSTRACT) reduce 168) ((T_ARRAY) reduce 168) ((T_ARRAY_CAST) reduce 168) ((T_ATTRIBUTE) reduce 168) ((T_BOOL_CAST) reduce 168) ((T_BREAK) reduce 168) ((T_CATCH) reduce 168) ((T_CLASS) reduce 168) ((T_CLASS_C) reduce 168) ((T_CLONE) reduce 168) ((T_CONSTANT_ENCAPSED_STRING) reduce 168) ((T_CONTINUE) reduce 168) ((T_DEC) reduce 168) ((T_DECLARE) reduce 168) ((T_DIR) reduce 168) ((T_DNUMBER) reduce 168) ((T_DO) reduce 168) ((T_DOUBLE_CAST) reduce 168) ((T_ECHO) reduce 168) ((T_ELSE) reduce 168) ((T_ELSEIF) reduce 168) ((T_EMPTY) reduce 168) ((T_ENDWHILE) reduce 168) ((T_ENUM) reduce 168) ((T_EVAL) reduce 168) ((T_EXIT) reduce 168) ((T_FILE) reduce 168) ((T_FINAL) reduce 168) ((T_FINALLY) reduce 168) ((T_FN) reduce 168) ((T_FOR) reduce 168) ((T_FOREACH) reduce 168) ((T_FUNCTION) reduce 168) ((T_FUNC_C) reduce 168) ((T_GLOBAL) reduce 168) ((T_GOTO) reduce 168) ((T_HALT_COMPILER) reduce 168) ((T_IF) reduce 168) ((T_INC) reduce 168) ((T_INCLUDE) reduce 168) ((T_INCLUDE_ONCE) reduce 168) ((T_INLINE_HTML) reduce 168) ((T_INTERFACE) reduce 168) ((T_INT_CAST) reduce 168) ((T_ISSET) reduce 168) ((T_LINE) reduce 168) ((T_LIST) reduce 168) ((T_LNUMBER) reduce 168) ((T_MATCH) reduce 168) ((T_METHOD_C) reduce 168) ((T_NAME_FULLY_QUALIFIED) reduce 168) ((T_NAME_QUALIFIED) reduce 168) ((T_NAME_RELATIVE) reduce 168) ((T_NEW) reduce 168) ((T_NS_C) reduce 168) ((T_OBJECT_CAST) reduce 168) ((T_PRINT) reduce 168) ((T_READONLY) reduce 168) ((T_REQUIRE) reduce 168) ((T_REQUIRE_ONCE) reduce 168) ((T_RETURN) reduce 168) ((T_START_HEREDOC) reduce 168) ((T_STATIC) reduce 168) ((T_STRING) reduce 168) ((T_STRING_CAST) reduce 168) ((T_SWITCH) reduce 168) ((T_THROW) reduce 168) ((T_TRAIT) reduce 168) ((T_TRAIT_C) reduce 168) ((T_TRY) reduce 168) ((T_UNSET) reduce 168) ((T_UNSET_CAST) reduce 168) ((T_VARIABLE) reduce 168) ((T_WHILE) reduce 168) ((T_YIELD) reduce 168) ((T_YIELD_FROM) reduce 168) (("[") reduce 168) (("`") reduce 168) (("{") reduce 168) (("~") reduce 168)) 16537 ((("!") reduce 174) (("\"") reduce 174) (("$") reduce 174) (("(") reduce 174) (("+") reduce 174) (("-") reduce 174) ((";") reduce 174) (("@") reduce 174) ((T_ABSTRACT) reduce 174) ((T_ARRAY) reduce 174) ((T_ARRAY_CAST) reduce 174) ((T_ATTRIBUTE) reduce 174) ((T_BOOL_CAST) reduce 174) ((T_BREAK) reduce 174) ((T_CATCH) shift) ((T_CLASS) reduce 174) ((T_CLASS_C) reduce 174) ((T_CLONE) reduce 174) ((T_CONSTANT_ENCAPSED_STRING) reduce 174) ((T_CONTINUE) reduce 174) ((T_DEC) reduce 174) ((T_DECLARE) reduce 174) ((T_DIR) reduce 174) ((T_DNUMBER) reduce 174) ((T_DO) reduce 174) ((T_DOUBLE_CAST) reduce 174) ((T_ECHO) reduce 174) ((T_ELSE) reduce 174) ((T_ELSEIF) reduce 174) ((T_EMPTY) reduce 174) ((T_ENDWHILE) reduce 174) ((T_ENUM) reduce 174) ((T_EVAL) reduce 174) ((T_EXIT) reduce 174) ((T_FILE) reduce 174) ((T_FINAL) reduce 174) ((T_FINALLY) shift) ((T_FN) reduce 174) ((T_FOR) reduce 174) ((T_FOREACH) reduce 174) ((T_FUNCTION) reduce 174) ((T_FUNC_C) reduce 174) ((T_GLOBAL) reduce 174) ((T_GOTO) reduce 174) ((T_HALT_COMPILER) reduce 174) ((T_IF) reduce 174) ((T_INC) reduce 174) ((T_INCLUDE) reduce 174) ((T_INCLUDE_ONCE) reduce 174) ((T_INLINE_HTML) reduce 174) ((T_INTERFACE) reduce 174) ((T_INT_CAST) reduce 174) ((T_ISSET) reduce 174) ((T_LINE) reduce 174) ((T_LIST) reduce 174) ((T_LNUMBER) reduce 174) ((T_MATCH) reduce 174) ((T_METHOD_C) reduce 174) ((T_NAME_FULLY_QUALIFIED) reduce 174) ((T_NAME_QUALIFIED) reduce 174) ((T_NAME_RELATIVE) reduce 174) ((T_NEW) reduce 174) ((T_NS_C) reduce 174) ((T_OBJECT_CAST) reduce 174) ((T_PRINT) reduce 174) ((T_READONLY) reduce 174) ((T_REQUIRE) reduce 174) ((T_REQUIRE_ONCE) reduce 174) ((T_RETURN) reduce 174) ((T_START_HEREDOC) reduce 174) ((T_STATIC) reduce 174) ((T_STRING) reduce 174) ((T_STRING_CAST) reduce 174) ((T_SWITCH) reduce 174) ((T_THROW) reduce 174) ((T_TRAIT) reduce 174) ((T_TRAIT_C) reduce 174) ((T_TRY) reduce 174) ((T_UNSET) reduce 174) ((T_UNSET_CAST) reduce 174) ((T_VARIABLE) reduce 174) ((T_WHILE) reduce 174) ((T_YIELD) reduce 174) ((T_YIELD_FROM) reduce 174) (("[") reduce 174) (("`") reduce 174) (("{") reduce 174) (("~") reduce 174)) 16540 ((("!") reduce 165) (("\"") reduce 165) (("$") reduce 165) (("(") reduce 165) (("+") reduce 165) (("-") reduce 165) ((";") reduce 165) (("@") reduce 165) ((T_ABSTRACT) reduce 165) ((T_ARRAY) reduce 165) ((T_ARRAY_CAST) reduce 165) ((T_ATTRIBUTE) reduce 165) ((T_BOOL_CAST) reduce 165) ((T_BREAK) reduce 165) ((T_CLASS) reduce 165) ((T_CLASS_C) reduce 165) ((T_CLONE) reduce 165) ((T_CONSTANT_ENCAPSED_STRING) reduce 165) ((T_CONTINUE) reduce 165) ((T_DEC) reduce 165) ((T_DECLARE) reduce 165) ((T_DIR) reduce 165) ((T_DNUMBER) reduce 165) ((T_DO) reduce 165) ((T_DOUBLE_CAST) reduce 165) ((T_ECHO) reduce 165) ((T_ELSE) reduce 165) ((T_ELSEIF) reduce 165) ((T_EMPTY) reduce 165) ((T_ENDWHILE) reduce 165) ((T_ENUM) reduce 165) ((T_EVAL) reduce 165) ((T_EXIT) reduce 165) ((T_FILE) reduce 165) ((T_FINAL) reduce 165) ((T_FN) reduce 165) ((T_FOR) reduce 165) ((T_FOREACH) reduce 165) ((T_FUNCTION) reduce 165) ((T_FUNC_C) reduce 165) ((T_GLOBAL) reduce 165) ((T_GOTO) reduce 165) ((T_HALT_COMPILER) reduce 165) ((T_IF) reduce 165) ((T_INC) reduce 165) ((T_INCLUDE) reduce 165) ((T_INCLUDE_ONCE) reduce 165) ((T_INLINE_HTML) reduce 165) ((T_INTERFACE) reduce 165) ((T_INT_CAST) reduce 165) ((T_ISSET) reduce 165) ((T_LINE) reduce 165) ((T_LIST) reduce 165) ((T_LNUMBER) reduce 165) ((T_MATCH) reduce 165) ((T_METHOD_C) reduce 165) ((T_NAME_FULLY_QUALIFIED) reduce 165) ((T_NAME_QUALIFIED) reduce 165) ((T_NAME_RELATIVE) reduce 165) ((T_NEW) reduce 165) ((T_NS_C) reduce 165) ((T_OBJECT_CAST) reduce 165) ((T_PRINT) reduce 165) ((T_READONLY) reduce 165) ((T_REQUIRE) reduce 165) ((T_REQUIRE_ONCE) reduce 165) ((T_RETURN) reduce 165) ((T_START_HEREDOC) reduce 165) ((T_STATIC) reduce 165) ((T_STRING) reduce 165) ((T_STRING_CAST) reduce 165) ((T_SWITCH) reduce 165) ((T_THROW) reduce 165) ((T_TRAIT) reduce 165) ((T_TRAIT_C) reduce 165) ((T_TRY) reduce 165) ((T_UNSET) reduce 165) ((T_UNSET_CAST) reduce 165) ((T_VARIABLE) reduce 165) ((T_WHILE) reduce 165) ((T_YIELD) reduce 165) ((T_YIELD_FROM) reduce 165) (("[") reduce 165) (("`") reduce 165) (("{") reduce 165) (("~") reduce 165)) 16543 ((("!") reduce 175) (("\"") reduce 175) (("$") reduce 175) (("(") reduce 175) (("+") reduce 175) (("-") reduce 175) ((";") reduce 175) (("@") reduce 175) ((T_ABSTRACT) reduce 175) ((T_ARRAY) reduce 175) ((T_ARRAY_CAST) reduce 175) ((T_ATTRIBUTE) reduce 175) ((T_BOOL_CAST) reduce 175) ((T_BREAK) reduce 175) ((T_CLASS) reduce 175) ((T_CLASS_C) reduce 175) ((T_CLONE) reduce 175) ((T_CONSTANT_ENCAPSED_STRING) reduce 175) ((T_CONTINUE) reduce 175) ((T_DEC) reduce 175) ((T_DECLARE) reduce 175) ((T_DIR) reduce 175) ((T_DNUMBER) reduce 175) ((T_DO) reduce 175) ((T_DOUBLE_CAST) reduce 175) ((T_ECHO) reduce 175) ((T_ELSE) reduce 175) ((T_ELSEIF) reduce 175) ((T_EMPTY) reduce 175) ((T_ENDWHILE) reduce 175) ((T_ENUM) reduce 175) ((T_EVAL) reduce 175) ((T_EXIT) reduce 175) ((T_FILE) reduce 175) ((T_FINAL) reduce 175) ((T_FN) reduce 175) ((T_FOR) reduce 175) ((T_FOREACH) reduce 175) ((T_FUNCTION) reduce 175) ((T_FUNC_C) reduce 175) ((T_GLOBAL) reduce 175) ((T_GOTO) reduce 175) ((T_HALT_COMPILER) reduce 175) ((T_IF) reduce 175) ((T_INC) reduce 175) ((T_INCLUDE) reduce 175) ((T_INCLUDE_ONCE) reduce 175) ((T_INLINE_HTML) reduce 175) ((T_INTERFACE) reduce 175) ((T_INT_CAST) reduce 175) ((T_ISSET) reduce 175) ((T_LINE) reduce 175) ((T_LIST) reduce 175) ((T_LNUMBER) reduce 175) ((T_MATCH) reduce 175) ((T_METHOD_C) reduce 175) ((T_NAME_FULLY_QUALIFIED) reduce 175) ((T_NAME_QUALIFIED) reduce 175) ((T_NAME_RELATIVE) reduce 175) ((T_NEW) reduce 175) ((T_NS_C) reduce 175) ((T_OBJECT_CAST) reduce 175) ((T_PRINT) reduce 175) ((T_READONLY) reduce 175) ((T_REQUIRE) reduce 175) ((T_REQUIRE_ONCE) reduce 175) ((T_RETURN) reduce 175) ((T_START_HEREDOC) reduce 175) ((T_STATIC) reduce 175) ((T_STRING) reduce 175) ((T_STRING_CAST) reduce 175) ((T_SWITCH) reduce 175) ((T_THROW) reduce 175) ((T_TRAIT) reduce 175) ((T_TRAIT_C) reduce 175) ((T_TRY) reduce 175) ((T_UNSET) reduce 175) ((T_UNSET_CAST) reduce 175) ((T_VARIABLE) reduce 175) ((T_WHILE) reduce 175) ((T_YIELD) reduce 175) ((T_YIELD_FROM) reduce 175) (("[") reduce 175) (("`") reduce 175) (("{") reduce 175) (("~") reduce 175)) 16545 (((")") reduce 93) ((T_VARIABLE) reduce 93) (("|") reduce 93)) 16546 (((")") reduce 92) ((T_VARIABLE) reduce 92) (("|") reduce 92)) 16547 (((")") reduce 94) ((T_VARIABLE) reduce 94) (("|") reduce 94)) 16548 (((")") reduce 470) ((T_VARIABLE) reduce 470) (("|") reduce 470)) 16549 (((")") reduce 91) ((T_VARIABLE) reduce 91) (("|") reduce 91)) 16550 (((")") reduce 172) ((T_VARIABLE) shift) (("|") shift)) 16551 (((")") reduce 170) ((T_VARIABLE) reduce 170) (("|") reduce 170)) 16552 (((")") reduce 471) ((T_VARIABLE) reduce 471) (("|") reduce 471)) 16553 (((")") reduce 173)) 16556 (((")") reduce 171) ((T_VARIABLE) reduce 171) (("|") reduce 171)) 16560 ((("!") reduce 169) (("\"") reduce 169) (("$") reduce 169) (("(") reduce 169) (("+") reduce 169) (("-") reduce 169) ((";") reduce 169) (("@") reduce 169) ((T_ABSTRACT) reduce 169) ((T_ARRAY) reduce 169) ((T_ARRAY_CAST) reduce 169) ((T_ATTRIBUTE) reduce 169) ((T_BOOL_CAST) reduce 169) ((T_BREAK) reduce 169) ((T_CATCH) reduce 169) ((T_CLASS) reduce 169) ((T_CLASS_C) reduce 169) ((T_CLONE) reduce 169) ((T_CONSTANT_ENCAPSED_STRING) reduce 169) ((T_CONTINUE) reduce 169) ((T_DEC) reduce 169) ((T_DECLARE) reduce 169) ((T_DIR) reduce 169) ((T_DNUMBER) reduce 169) ((T_DO) reduce 169) ((T_DOUBLE_CAST) reduce 169) ((T_ECHO) reduce 169) ((T_ELSE) reduce 169) ((T_ELSEIF) reduce 169) ((T_EMPTY) reduce 169) ((T_ENDWHILE) reduce 169) ((T_ENUM) reduce 169) ((T_EVAL) reduce 169) ((T_EXIT) reduce 169) ((T_FILE) reduce 169) ((T_FINAL) reduce 169) ((T_FINALLY) reduce 169) ((T_FN) reduce 169) ((T_FOR) reduce 169) ((T_FOREACH) reduce 169) ((T_FUNCTION) reduce 169) ((T_FUNC_C) reduce 169) ((T_GLOBAL) reduce 169) ((T_GOTO) reduce 169) ((T_HALT_COMPILER) reduce 169) ((T_IF) reduce 169) ((T_INC) reduce 169) ((T_INCLUDE) reduce 169) ((T_INCLUDE_ONCE) reduce 169) ((T_INLINE_HTML) reduce 169) ((T_INTERFACE) reduce 169) ((T_INT_CAST) reduce 169) ((T_ISSET) reduce 169) ((T_LINE) reduce 169) ((T_LIST) reduce 169) ((T_LNUMBER) reduce 169) ((T_MATCH) reduce 169) ((T_METHOD_C) reduce 169) ((T_NAME_FULLY_QUALIFIED) reduce 169) ((T_NAME_QUALIFIED) reduce 169) ((T_NAME_RELATIVE) reduce 169) ((T_NEW) reduce 169) ((T_NS_C) reduce 169) ((T_OBJECT_CAST) reduce 169) ((T_PRINT) reduce 169) ((T_READONLY) reduce 169) ((T_REQUIRE) reduce 169) ((T_REQUIRE_ONCE) reduce 169) ((T_RETURN) reduce 169) ((T_START_HEREDOC) reduce 169) ((T_STATIC) reduce 169) ((T_STRING) reduce 169) ((T_STRING_CAST) reduce 169) ((T_SWITCH) reduce 169) ((T_THROW) reduce 169) ((T_TRAIT) reduce 169) ((T_TRAIT_C) reduce 169) ((T_TRY) reduce 169) ((T_UNSET) reduce 169) ((T_UNSET_CAST) reduce 169) ((T_VARIABLE) reduce 169) ((T_WHILE) reduce 169) ((T_YIELD) reduce 169) ((T_YIELD_FROM) reduce 169) (("[") reduce 169) (("`") reduce 169) (("{") reduce 169) (("~") reduce 169)) 16563 (((":") shift) (("{") shift)) 16564 (((";") shift) ((T_CASE) reduce 225) ((T_DEFAULT) reduce 225) ((T_ENDSWITCH) reduce 225)) 16565 ((("!") reduce 151) (("\"") reduce 151) (("$") reduce 151) (("(") reduce 151) (("+") reduce 151) (("-") reduce 151) ((";") reduce 151) (("@") reduce 151) ((T_ABSTRACT) reduce 151) ((T_ARRAY) reduce 151) ((T_ARRAY_CAST) reduce 151) ((T_ATTRIBUTE) reduce 151) ((T_BOOL_CAST) reduce 151) ((T_BREAK) reduce 151) ((T_CLASS) reduce 151) ((T_CLASS_C) reduce 151) ((T_CLONE) reduce 151) ((T_CONSTANT_ENCAPSED_STRING) reduce 151) ((T_CONTINUE) reduce 151) ((T_DEC) reduce 151) ((T_DECLARE) reduce 151) ((T_DIR) reduce 151) ((T_DNUMBER) reduce 151) ((T_DO) reduce 151) ((T_DOUBLE_CAST) reduce 151) ((T_ECHO) reduce 151) ((T_ELSE) reduce 151) ((T_ELSEIF) reduce 151) ((T_EMPTY) reduce 151) ((T_ENDWHILE) reduce 151) ((T_ENUM) reduce 151) ((T_EVAL) reduce 151) ((T_EXIT) reduce 151) ((T_FILE) reduce 151) ((T_FINAL) reduce 151) ((T_FN) reduce 151) ((T_FOR) reduce 151) ((T_FOREACH) reduce 151) ((T_FUNCTION) reduce 151) ((T_FUNC_C) reduce 151) ((T_GLOBAL) reduce 151) ((T_GOTO) reduce 151) ((T_HALT_COMPILER) reduce 151) ((T_IF) reduce 151) ((T_INC) reduce 151) ((T_INCLUDE) reduce 151) ((T_INCLUDE_ONCE) reduce 151) ((T_INLINE_HTML) reduce 151) ((T_INTERFACE) reduce 151) ((T_INT_CAST) reduce 151) ((T_ISSET) reduce 151) ((T_LINE) reduce 151) ((T_LIST) reduce 151) ((T_LNUMBER) reduce 151) ((T_MATCH) reduce 151) ((T_METHOD_C) reduce 151) ((T_NAME_FULLY_QUALIFIED) reduce 151) ((T_NAME_QUALIFIED) reduce 151) ((T_NAME_RELATIVE) reduce 151) ((T_NEW) reduce 151) ((T_NS_C) reduce 151) ((T_OBJECT_CAST) reduce 151) ((T_PRINT) reduce 151) ((T_READONLY) reduce 151) ((T_REQUIRE) reduce 151) ((T_REQUIRE_ONCE) reduce 151) ((T_RETURN) reduce 151) ((T_START_HEREDOC) reduce 151) ((T_STATIC) reduce 151) ((T_STRING) reduce 151) ((T_STRING_CAST) reduce 151) ((T_SWITCH) reduce 151) ((T_THROW) reduce 151) ((T_TRAIT) reduce 151) ((T_TRAIT_C) reduce 151) ((T_TRY) reduce 151) ((T_UNSET) reduce 151) ((T_UNSET_CAST) reduce 151) ((T_VARIABLE) reduce 151) ((T_WHILE) reduce 151) ((T_YIELD) reduce 151) ((T_YIELD_FROM) reduce 151) (("[") reduce 151) (("`") reduce 151) (("{") reduce 151) (("~") reduce 151)) 16566 (((";") shift) ((T_CASE) reduce 225) ((T_DEFAULT) reduce 225) (("}") reduce 225)) 16567 (((T_CASE) reduce 225) ((T_DEFAULT) reduce 225) (("}") reduce 225)) 16568 (((T_CASE) shift) ((T_DEFAULT) shift) (("}") shift)) 16570 (((":") shift) ((";") shift)) 16571 ((("!") reduce 221) (("\"") reduce 221) (("$") reduce 221) (("(") reduce 221) (("+") reduce 221) (("-") reduce 221) ((";") reduce 221) (("@") reduce 221) ((T_ABSTRACT) reduce 221) ((T_ARRAY) reduce 221) ((T_ARRAY_CAST) reduce 221) ((T_ATTRIBUTE) reduce 221) ((T_BOOL_CAST) reduce 221) ((T_BREAK) reduce 221) ((T_CLASS) reduce 221) ((T_CLASS_C) reduce 221) ((T_CLONE) reduce 221) ((T_CONSTANT_ENCAPSED_STRING) reduce 221) ((T_CONTINUE) reduce 221) ((T_DEC) reduce 221) ((T_DECLARE) reduce 221) ((T_DIR) reduce 221) ((T_DNUMBER) reduce 221) ((T_DO) reduce 221) ((T_DOUBLE_CAST) reduce 221) ((T_ECHO) reduce 221) ((T_ELSE) reduce 221) ((T_ELSEIF) reduce 221) ((T_EMPTY) reduce 221) ((T_ENDWHILE) reduce 221) ((T_ENUM) reduce 221) ((T_EVAL) reduce 221) ((T_EXIT) reduce 221) ((T_FILE) reduce 221) ((T_FINAL) reduce 221) ((T_FN) reduce 221) ((T_FOR) reduce 221) ((T_FOREACH) reduce 221) ((T_FUNCTION) reduce 221) ((T_FUNC_C) reduce 221) ((T_GLOBAL) reduce 221) ((T_GOTO) reduce 221) ((T_HALT_COMPILER) reduce 221) ((T_IF) reduce 221) ((T_INC) reduce 221) ((T_INCLUDE) reduce 221) ((T_INCLUDE_ONCE) reduce 221) ((T_INLINE_HTML) reduce 221) ((T_INTERFACE) reduce 221) ((T_INT_CAST) reduce 221) ((T_ISSET) reduce 221) ((T_LINE) reduce 221) ((T_LIST) reduce 221) ((T_LNUMBER) reduce 221) ((T_MATCH) reduce 221) ((T_METHOD_C) reduce 221) ((T_NAME_FULLY_QUALIFIED) reduce 221) ((T_NAME_QUALIFIED) reduce 221) ((T_NAME_RELATIVE) reduce 221) ((T_NEW) reduce 221) ((T_NS_C) reduce 221) ((T_OBJECT_CAST) reduce 221) ((T_PRINT) reduce 221) ((T_READONLY) reduce 221) ((T_REQUIRE) reduce 221) ((T_REQUIRE_ONCE) reduce 221) ((T_RETURN) reduce 221) ((T_START_HEREDOC) reduce 221) ((T_STATIC) reduce 221) ((T_STRING) reduce 221) ((T_STRING_CAST) reduce 221) ((T_SWITCH) reduce 221) ((T_THROW) reduce 221) ((T_TRAIT) reduce 221) ((T_TRAIT_C) reduce 221) ((T_TRY) reduce 221) ((T_UNSET) reduce 221) ((T_UNSET_CAST) reduce 221) ((T_VARIABLE) reduce 221) ((T_WHILE) reduce 221) ((T_YIELD) reduce 221) ((T_YIELD_FROM) reduce 221) (("[") reduce 221) (("`") reduce 221) (("{") reduce 221) (("~") reduce 221)) 16572 ((("!") reduce 228) (("\"") reduce 228) (("$") reduce 228) (("(") reduce 228) (("+") reduce 228) (("-") reduce 228) ((";") reduce 228) (("@") reduce 228) ((T_ABSTRACT) reduce 228) ((T_ARRAY) reduce 228) ((T_ARRAY_CAST) reduce 228) ((T_ATTRIBUTE) reduce 228) ((T_BOOL_CAST) reduce 228) ((T_BREAK) reduce 228) ((T_CASE) reduce 228) ((T_CLASS) reduce 228) ((T_CLASS_C) reduce 228) ((T_CLONE) reduce 228) ((T_CONSTANT_ENCAPSED_STRING) reduce 228) ((T_CONTINUE) reduce 228) ((T_DEC) reduce 228) ((T_DECLARE) reduce 228) ((T_DEFAULT) reduce 228) ((T_DIR) reduce 228) ((T_DNUMBER) reduce 228) ((T_DO) reduce 228) ((T_DOUBLE_CAST) reduce 228) ((T_ECHO) reduce 228) ((T_EMPTY) reduce 228) ((T_ENUM) reduce 228) ((T_EVAL) reduce 228) ((T_EXIT) reduce 228) ((T_FILE) reduce 228) ((T_FINAL) reduce 228) ((T_FN) reduce 228) ((T_FOR) reduce 228) ((T_FOREACH) reduce 228) ((T_FUNCTION) reduce 228) ((T_FUNC_C) reduce 228) ((T_GLOBAL) reduce 228) ((T_GOTO) reduce 228) ((T_HALT_COMPILER) reduce 228) ((T_IF) reduce 228) ((T_INC) reduce 228) ((T_INCLUDE) reduce 228) ((T_INCLUDE_ONCE) reduce 228) ((T_INLINE_HTML) reduce 228) ((T_INTERFACE) reduce 228) ((T_INT_CAST) reduce 228) ((T_ISSET) reduce 228) ((T_LINE) reduce 228) ((T_LIST) reduce 228) ((T_LNUMBER) reduce 228) ((T_MATCH) reduce 228) ((T_METHOD_C) reduce 228) ((T_NAME_FULLY_QUALIFIED) reduce 228) ((T_NAME_QUALIFIED) reduce 228) ((T_NAME_RELATIVE) reduce 228) ((T_NEW) reduce 228) ((T_NS_C) reduce 228) ((T_OBJECT_CAST) reduce 228) ((T_PRINT) reduce 228) ((T_READONLY) reduce 228) ((T_REQUIRE) reduce 228) ((T_REQUIRE_ONCE) reduce 228) ((T_RETURN) reduce 228) ((T_START_HEREDOC) reduce 228) ((T_STATIC) reduce 228) ((T_STRING) reduce 228) ((T_STRING_CAST) reduce 228) ((T_SWITCH) reduce 228) ((T_THROW) reduce 228) ((T_TRAIT) reduce 228) ((T_TRAIT_C) reduce 228) ((T_TRY) reduce 228) ((T_UNSET) reduce 228) ((T_UNSET_CAST) reduce 228) ((T_VARIABLE) reduce 228) ((T_WHILE) reduce 228) ((T_YIELD) reduce 228) ((T_YIELD_FROM) reduce 228) (("[") reduce 228) (("`") reduce 228) (("{") reduce 228) (("}") reduce 228) (("~") reduce 228)) 16573 ((("!") reduce 229) (("\"") reduce 229) (("$") reduce 229) (("(") reduce 229) (("+") reduce 229) (("-") reduce 229) ((";") reduce 229) (("@") reduce 229) ((T_ABSTRACT) reduce 229) ((T_ARRAY) reduce 229) ((T_ARRAY_CAST) reduce 229) ((T_ATTRIBUTE) reduce 229) ((T_BOOL_CAST) reduce 229) ((T_BREAK) reduce 229) ((T_CASE) reduce 229) ((T_CLASS) reduce 229) ((T_CLASS_C) reduce 229) ((T_CLONE) reduce 229) ((T_CONSTANT_ENCAPSED_STRING) reduce 229) ((T_CONTINUE) reduce 229) ((T_DEC) reduce 229) ((T_DECLARE) reduce 229) ((T_DEFAULT) reduce 229) ((T_DIR) reduce 229) ((T_DNUMBER) reduce 229) ((T_DO) reduce 229) ((T_DOUBLE_CAST) reduce 229) ((T_ECHO) reduce 229) ((T_EMPTY) reduce 229) ((T_ENUM) reduce 229) ((T_EVAL) reduce 229) ((T_EXIT) reduce 229) ((T_FILE) reduce 229) ((T_FINAL) reduce 229) ((T_FN) reduce 229) ((T_FOR) reduce 229) ((T_FOREACH) reduce 229) ((T_FUNCTION) reduce 229) ((T_FUNC_C) reduce 229) ((T_GLOBAL) reduce 229) ((T_GOTO) reduce 229) ((T_HALT_COMPILER) reduce 229) ((T_IF) reduce 229) ((T_INC) reduce 229) ((T_INCLUDE) reduce 229) ((T_INCLUDE_ONCE) reduce 229) ((T_INLINE_HTML) reduce 229) ((T_INTERFACE) reduce 229) ((T_INT_CAST) reduce 229) ((T_ISSET) reduce 229) ((T_LINE) reduce 229) ((T_LIST) reduce 229) ((T_LNUMBER) reduce 229) ((T_MATCH) reduce 229) ((T_METHOD_C) reduce 229) ((T_NAME_FULLY_QUALIFIED) reduce 229) ((T_NAME_QUALIFIED) reduce 229) ((T_NAME_RELATIVE) reduce 229) ((T_NEW) reduce 229) ((T_NS_C) reduce 229) ((T_OBJECT_CAST) reduce 229) ((T_PRINT) reduce 229) ((T_READONLY) reduce 229) ((T_REQUIRE) reduce 229) ((T_REQUIRE_ONCE) reduce 229) ((T_RETURN) reduce 229) ((T_START_HEREDOC) reduce 229) ((T_STATIC) reduce 229) ((T_STRING) reduce 229) ((T_STRING_CAST) reduce 229) ((T_SWITCH) reduce 229) ((T_THROW) reduce 229) ((T_TRAIT) reduce 229) ((T_TRAIT_C) reduce 229) ((T_TRY) reduce 229) ((T_UNSET) reduce 229) ((T_UNSET_CAST) reduce 229) ((T_VARIABLE) reduce 229) ((T_WHILE) reduce 229) ((T_YIELD) reduce 229) ((T_YIELD_FROM) reduce 229) (("[") reduce 229) (("`") reduce 229) (("{") reduce 229) (("}") reduce 229) (("~") reduce 229)) 16574 ((("!") reduce 140) (("\"") reduce 140) (("$") reduce 140) (("(") reduce 140) (("+") reduce 140) (("-") reduce 140) ((";") reduce 140) (("@") reduce 140) ((T_ABSTRACT) reduce 140) ((T_ARRAY) reduce 140) ((T_ARRAY_CAST) reduce 140) ((T_ATTRIBUTE) reduce 140) ((T_BOOL_CAST) reduce 140) ((T_BREAK) reduce 140) ((T_CASE) reduce 140) ((T_CLASS) reduce 140) ((T_CLASS_C) reduce 140) ((T_CLONE) reduce 140) ((T_CONSTANT_ENCAPSED_STRING) reduce 140) ((T_CONTINUE) reduce 140) ((T_DEC) reduce 140) ((T_DECLARE) reduce 140) ((T_DEFAULT) reduce 140) ((T_DIR) reduce 140) ((T_DNUMBER) reduce 140) ((T_DO) reduce 140) ((T_DOUBLE_CAST) reduce 140) ((T_ECHO) reduce 140) ((T_EMPTY) reduce 140) ((T_ENUM) reduce 140) ((T_EVAL) reduce 140) ((T_EXIT) reduce 140) ((T_FILE) reduce 140) ((T_FINAL) reduce 140) ((T_FN) reduce 140) ((T_FOR) reduce 140) ((T_FOREACH) reduce 140) ((T_FUNCTION) reduce 140) ((T_FUNC_C) reduce 140) ((T_GLOBAL) reduce 140) ((T_GOTO) reduce 140) ((T_HALT_COMPILER) reduce 140) ((T_IF) reduce 140) ((T_INC) reduce 140) ((T_INCLUDE) reduce 140) ((T_INCLUDE_ONCE) reduce 140) ((T_INLINE_HTML) reduce 140) ((T_INTERFACE) reduce 140) ((T_INT_CAST) reduce 140) ((T_ISSET) reduce 140) ((T_LINE) reduce 140) ((T_LIST) reduce 140) ((T_LNUMBER) reduce 140) ((T_MATCH) reduce 140) ((T_METHOD_C) reduce 140) ((T_NAME_FULLY_QUALIFIED) reduce 140) ((T_NAME_QUALIFIED) reduce 140) ((T_NAME_RELATIVE) reduce 140) ((T_NEW) reduce 140) ((T_NS_C) reduce 140) ((T_OBJECT_CAST) reduce 140) ((T_PRINT) reduce 140) ((T_READONLY) reduce 140) ((T_REQUIRE) reduce 140) ((T_REQUIRE_ONCE) reduce 140) ((T_RETURN) reduce 140) ((T_START_HEREDOC) reduce 140) ((T_STATIC) reduce 140) ((T_STRING) reduce 140) ((T_STRING_CAST) reduce 140) ((T_SWITCH) reduce 140) ((T_THROW) reduce 140) ((T_TRAIT) reduce 140) ((T_TRAIT_C) reduce 140) ((T_TRY) reduce 140) ((T_UNSET) reduce 140) ((T_UNSET_CAST) reduce 140) ((T_VARIABLE) reduce 140) ((T_WHILE) reduce 140) ((T_YIELD) reduce 140) ((T_YIELD_FROM) reduce 140) (("[") reduce 140) (("`") reduce 140) (("{") reduce 140) (("}") reduce 140) (("~") reduce 140)) 16575 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) (("+") shift) (("-") shift) ((";") shift) (("@") shift) ((T_ABSTRACT) shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_BREAK) shift) ((T_CASE) reduce 227) ((T_CLASS) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_CONTINUE) shift) ((T_DEC) shift) ((T_DECLARE) shift) ((T_DEFAULT) reduce 227) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DO) shift) ((T_DOUBLE_CAST) shift) ((T_ECHO) shift) ((T_EMPTY) shift) ((T_ENUM) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FINAL) shift) ((T_FN) shift) ((T_FOR) shift) ((T_FOREACH) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_GLOBAL) shift) ((T_GOTO) shift) ((T_HALT_COMPILER) shift) ((T_IF) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INLINE_HTML) shift) ((T_INTERFACE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_RETURN) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_SWITCH) shift) ((T_THROW) shift) ((T_TRAIT) shift) ((T_TRAIT_C) shift) ((T_TRY) shift) ((T_UNSET) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_WHILE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("{") shift) (("}") reduce 227) (("~") shift)) 16576 ((("!") reduce 164) (("\"") reduce 164) (("$") reduce 164) (("(") reduce 164) (("+") reduce 164) (("-") reduce 164) ((";") reduce 164) (("@") reduce 164) ((T_ABSTRACT) reduce 164) ((T_ARRAY) reduce 164) ((T_ARRAY_CAST) reduce 164) ((T_ATTRIBUTE) reduce 164) ((T_BOOL_CAST) reduce 164) ((T_BREAK) reduce 164) ((T_CASE) reduce 164) ((T_CLASS) reduce 164) ((T_CLASS_C) reduce 164) ((T_CLONE) reduce 164) ((T_CONSTANT_ENCAPSED_STRING) reduce 164) ((T_CONTINUE) reduce 164) ((T_DEC) reduce 164) ((T_DECLARE) reduce 164) ((T_DEFAULT) reduce 164) ((T_DIR) reduce 164) ((T_DNUMBER) reduce 164) ((T_DO) reduce 164) ((T_DOUBLE_CAST) reduce 164) ((T_ECHO) reduce 164) ((T_EMPTY) reduce 164) ((T_ENUM) reduce 164) ((T_EVAL) reduce 164) ((T_EXIT) reduce 164) ((T_FILE) reduce 164) ((T_FINAL) reduce 164) ((T_FN) reduce 164) ((T_FOR) reduce 164) ((T_FOREACH) reduce 164) ((T_FUNCTION) reduce 164) ((T_FUNC_C) reduce 164) ((T_GLOBAL) reduce 164) ((T_GOTO) reduce 164) ((T_HALT_COMPILER) reduce 164) ((T_IF) reduce 164) ((T_INC) reduce 164) ((T_INCLUDE) reduce 164) ((T_INCLUDE_ONCE) reduce 164) ((T_INLINE_HTML) reduce 164) ((T_INTERFACE) reduce 164) ((T_INT_CAST) reduce 164) ((T_ISSET) reduce 164) ((T_LINE) reduce 164) ((T_LIST) reduce 164) ((T_LNUMBER) reduce 164) ((T_MATCH) reduce 164) ((T_METHOD_C) reduce 164) ((T_NAME_FULLY_QUALIFIED) reduce 164) ((T_NAME_QUALIFIED) reduce 164) ((T_NAME_RELATIVE) reduce 164) ((T_NEW) reduce 164) ((T_NS_C) reduce 164) ((T_OBJECT_CAST) reduce 164) ((T_PRINT) reduce 164) ((T_READONLY) reduce 164) ((T_REQUIRE) reduce 164) ((T_REQUIRE_ONCE) reduce 164) ((T_RETURN) reduce 164) ((T_START_HEREDOC) reduce 164) ((T_STATIC) reduce 164) ((T_STRING) reduce 164) ((T_STRING_CAST) reduce 164) ((T_SWITCH) reduce 164) ((T_THROW) reduce 164) ((T_TRAIT) reduce 164) ((T_TRAIT_C) reduce 164) ((T_TRY) reduce 164) ((T_UNSET) reduce 164) ((T_UNSET_CAST) reduce 164) ((T_VARIABLE) reduce 164) ((T_WHILE) reduce 164) ((T_YIELD) reduce 164) ((T_YIELD_FROM) reduce 164) (("[") reduce 164) (("`") reduce 164) (("{") reduce 164) (("}") reduce 164) (("~") reduce 164)) 16590 ((("!") reduce 158) (("\"") reduce 158) (("$") reduce 158) (("(") reduce 158) (("+") reduce 158) (("-") reduce 158) ((";") reduce 158) (("@") reduce 158) ((T_ABSTRACT) reduce 158) ((T_ARRAY) reduce 158) ((T_ARRAY_CAST) reduce 158) ((T_ATTRIBUTE) reduce 158) ((T_BOOL_CAST) reduce 158) ((T_BREAK) reduce 158) ((T_CASE) reduce 158) ((T_CLASS) reduce 158) ((T_CLASS_C) reduce 158) ((T_CLONE) reduce 158) ((T_CONSTANT_ENCAPSED_STRING) reduce 158) ((T_CONTINUE) reduce 158) ((T_DEC) reduce 158) ((T_DECLARE) reduce 158) ((T_DEFAULT) reduce 158) ((T_DIR) reduce 158) ((T_DNUMBER) reduce 158) ((T_DO) reduce 158) ((T_DOUBLE_CAST) reduce 158) ((T_ECHO) reduce 158) ((T_EMPTY) reduce 158) ((T_ENUM) reduce 158) ((T_EVAL) reduce 158) ((T_EXIT) reduce 158) ((T_FILE) reduce 158) ((T_FINAL) reduce 158) ((T_FN) reduce 158) ((T_FOR) reduce 158) ((T_FOREACH) reduce 158) ((T_FUNCTION) reduce 158) ((T_FUNC_C) reduce 158) ((T_GLOBAL) reduce 158) ((T_GOTO) reduce 158) ((T_HALT_COMPILER) reduce 158) ((T_IF) reduce 158) ((T_INC) reduce 158) ((T_INCLUDE) reduce 158) ((T_INCLUDE_ONCE) reduce 158) ((T_INLINE_HTML) reduce 158) ((T_INTERFACE) reduce 158) ((T_INT_CAST) reduce 158) ((T_ISSET) reduce 158) ((T_LINE) reduce 158) ((T_LIST) reduce 158) ((T_LNUMBER) reduce 158) ((T_MATCH) reduce 158) ((T_METHOD_C) reduce 158) ((T_NAME_FULLY_QUALIFIED) reduce 158) ((T_NAME_QUALIFIED) reduce 158) ((T_NAME_RELATIVE) reduce 158) ((T_NEW) reduce 158) ((T_NS_C) reduce 158) ((T_OBJECT_CAST) reduce 158) ((T_PRINT) reduce 158) ((T_READONLY) reduce 158) ((T_REQUIRE) reduce 158) ((T_REQUIRE_ONCE) reduce 158) ((T_RETURN) reduce 158) ((T_START_HEREDOC) reduce 158) ((T_STATIC) reduce 158) ((T_STRING) reduce 158) ((T_STRING_CAST) reduce 158) ((T_SWITCH) reduce 158) ((T_THROW) reduce 158) ((T_TRAIT) reduce 158) ((T_TRAIT_C) reduce 158) ((T_TRY) reduce 158) ((T_UNSET) reduce 158) ((T_UNSET_CAST) reduce 158) ((T_VARIABLE) reduce 158) ((T_WHILE) reduce 158) ((T_YIELD) reduce 158) ((T_YIELD_FROM) reduce 158) (("[") reduce 158) (("`") reduce 158) (("{") reduce 158) (("}") reduce 158) (("~") reduce 158)) 16600 ((("!") reduce 147) (("\"") reduce 147) (("$") reduce 147) (("(") reduce 147) (("+") reduce 147) (("-") reduce 147) ((";") reduce 147) (("@") reduce 147) ((T_ABSTRACT) reduce 147) ((T_ARRAY) reduce 147) ((T_ARRAY_CAST) reduce 147) ((T_ATTRIBUTE) reduce 147) ((T_BOOL_CAST) reduce 147) ((T_BREAK) reduce 147) ((T_CASE) reduce 147) ((T_CLASS) reduce 147) ((T_CLASS_C) reduce 147) ((T_CLONE) reduce 147) ((T_CONSTANT_ENCAPSED_STRING) reduce 147) ((T_CONTINUE) reduce 147) ((T_DEC) reduce 147) ((T_DECLARE) reduce 147) ((T_DEFAULT) reduce 147) ((T_DIR) reduce 147) ((T_DNUMBER) reduce 147) ((T_DO) reduce 147) ((T_DOUBLE_CAST) reduce 147) ((T_ECHO) reduce 147) ((T_EMPTY) reduce 147) ((T_ENUM) reduce 147) ((T_EVAL) reduce 147) ((T_EXIT) reduce 147) ((T_FILE) reduce 147) ((T_FINAL) reduce 147) ((T_FN) reduce 147) ((T_FOR) reduce 147) ((T_FOREACH) reduce 147) ((T_FUNCTION) reduce 147) ((T_FUNC_C) reduce 147) ((T_GLOBAL) reduce 147) ((T_GOTO) reduce 147) ((T_HALT_COMPILER) reduce 147) ((T_IF) reduce 147) ((T_INC) reduce 147) ((T_INCLUDE) reduce 147) ((T_INCLUDE_ONCE) reduce 147) ((T_INLINE_HTML) reduce 147) ((T_INTERFACE) reduce 147) ((T_INT_CAST) reduce 147) ((T_ISSET) reduce 147) ((T_LINE) reduce 147) ((T_LIST) reduce 147) ((T_LNUMBER) reduce 147) ((T_MATCH) reduce 147) ((T_METHOD_C) reduce 147) ((T_NAME_FULLY_QUALIFIED) reduce 147) ((T_NAME_QUALIFIED) reduce 147) ((T_NAME_RELATIVE) reduce 147) ((T_NEW) reduce 147) ((T_NS_C) reduce 147) ((T_OBJECT_CAST) reduce 147) ((T_PRINT) reduce 147) ((T_READONLY) reduce 147) ((T_REQUIRE) reduce 147) ((T_REQUIRE_ONCE) reduce 147) ((T_RETURN) reduce 147) ((T_START_HEREDOC) reduce 147) ((T_STATIC) reduce 147) ((T_STRING) reduce 147) ((T_STRING_CAST) reduce 147) ((T_SWITCH) reduce 147) ((T_THROW) reduce 147) ((T_TRAIT) reduce 147) ((T_TRAIT_C) reduce 147) ((T_TRY) reduce 147) ((T_UNSET) reduce 147) ((T_UNSET_CAST) reduce 147) ((T_VARIABLE) reduce 147) ((T_WHILE) reduce 147) ((T_YIELD) reduce 147) ((T_YIELD_FROM) reduce 147) (("[") reduce 147) (("`") reduce 147) (("{") reduce 147) (("}") reduce 147) (("~") reduce 147)) 16602 ((("!") reduce 142) (("\"") reduce 142) (("$") reduce 142) (("(") reduce 142) (("+") reduce 142) (("-") reduce 142) ((";") reduce 142) (("@") reduce 142) ((T_ABSTRACT) reduce 142) ((T_ARRAY) reduce 142) ((T_ARRAY_CAST) reduce 142) ((T_ATTRIBUTE) reduce 142) ((T_BOOL_CAST) reduce 142) ((T_BREAK) reduce 142) ((T_CASE) reduce 142) ((T_CLASS) reduce 142) ((T_CLASS_C) reduce 142) ((T_CLONE) reduce 142) ((T_CONSTANT_ENCAPSED_STRING) reduce 142) ((T_CONTINUE) reduce 142) ((T_DEC) reduce 142) ((T_DECLARE) reduce 142) ((T_DEFAULT) reduce 142) ((T_DIR) reduce 142) ((T_DNUMBER) reduce 142) ((T_DO) reduce 142) ((T_DOUBLE_CAST) reduce 142) ((T_ECHO) reduce 142) ((T_EMPTY) reduce 142) ((T_ENUM) reduce 142) ((T_EVAL) reduce 142) ((T_EXIT) reduce 142) ((T_FILE) reduce 142) ((T_FINAL) reduce 142) ((T_FN) reduce 142) ((T_FOR) reduce 142) ((T_FOREACH) reduce 142) ((T_FUNCTION) reduce 142) ((T_FUNC_C) reduce 142) ((T_GLOBAL) reduce 142) ((T_GOTO) reduce 142) ((T_HALT_COMPILER) reduce 142) ((T_IF) reduce 142) ((T_INC) reduce 142) ((T_INCLUDE) reduce 142) ((T_INCLUDE_ONCE) reduce 142) ((T_INLINE_HTML) reduce 142) ((T_INTERFACE) reduce 142) ((T_INT_CAST) reduce 142) ((T_ISSET) reduce 142) ((T_LINE) reduce 142) ((T_LIST) reduce 142) ((T_LNUMBER) reduce 142) ((T_MATCH) reduce 142) ((T_METHOD_C) reduce 142) ((T_NAME_FULLY_QUALIFIED) reduce 142) ((T_NAME_QUALIFIED) reduce 142) ((T_NAME_RELATIVE) reduce 142) ((T_NEW) reduce 142) ((T_NS_C) reduce 142) ((T_OBJECT_CAST) reduce 142) ((T_PRINT) reduce 142) ((T_READONLY) reduce 142) ((T_REQUIRE) reduce 142) ((T_REQUIRE_ONCE) reduce 142) ((T_RETURN) reduce 142) ((T_START_HEREDOC) reduce 142) ((T_STATIC) reduce 142) ((T_STRING) reduce 142) ((T_STRING_CAST) reduce 142) ((T_SWITCH) reduce 142) ((T_THROW) reduce 142) ((T_TRAIT) reduce 142) ((T_TRAIT_C) reduce 142) ((T_TRY) reduce 142) ((T_UNSET) reduce 142) ((T_UNSET_CAST) reduce 142) ((T_VARIABLE) reduce 142) ((T_WHILE) reduce 142) ((T_YIELD) reduce 142) ((T_YIELD_FROM) reduce 142) (("[") reduce 142) (("`") reduce 142) (("{") reduce 142) (("}") reduce 142) (("~") reduce 142)) 16604 ((("!") reduce 103) (("\"") reduce 103) (("$") reduce 103) (("(") reduce 103) (("+") reduce 103) (("-") reduce 103) ((";") reduce 103) (("@") reduce 103) ((T_ABSTRACT) reduce 103) ((T_ARRAY) reduce 103) ((T_ARRAY_CAST) reduce 103) ((T_ATTRIBUTE) reduce 103) ((T_BOOL_CAST) reduce 103) ((T_BREAK) reduce 103) ((T_CASE) reduce 103) ((T_CLASS) reduce 103) ((T_CLASS_C) reduce 103) ((T_CLONE) reduce 103) ((T_CONSTANT_ENCAPSED_STRING) reduce 103) ((T_CONTINUE) reduce 103) ((T_DEC) reduce 103) ((T_DECLARE) reduce 103) ((T_DEFAULT) reduce 103) ((T_DIR) reduce 103) ((T_DNUMBER) reduce 103) ((T_DO) reduce 103) ((T_DOUBLE_CAST) reduce 103) ((T_ECHO) reduce 103) ((T_EMPTY) reduce 103) ((T_ENUM) reduce 103) ((T_EVAL) reduce 103) ((T_EXIT) reduce 103) ((T_FILE) reduce 103) ((T_FINAL) reduce 103) ((T_FN) reduce 103) ((T_FOR) reduce 103) ((T_FOREACH) reduce 103) ((T_FUNCTION) reduce 103) ((T_FUNC_C) reduce 103) ((T_GLOBAL) reduce 103) ((T_GOTO) reduce 103) ((T_HALT_COMPILER) reduce 103) ((T_IF) reduce 103) ((T_INC) reduce 103) ((T_INCLUDE) reduce 103) ((T_INCLUDE_ONCE) reduce 103) ((T_INLINE_HTML) reduce 103) ((T_INTERFACE) reduce 103) ((T_INT_CAST) reduce 103) ((T_ISSET) reduce 103) ((T_LINE) reduce 103) ((T_LIST) reduce 103) ((T_LNUMBER) reduce 103) ((T_MATCH) reduce 103) ((T_METHOD_C) reduce 103) ((T_NAME_FULLY_QUALIFIED) reduce 103) ((T_NAME_QUALIFIED) reduce 103) ((T_NAME_RELATIVE) reduce 103) ((T_NEW) reduce 103) ((T_NS_C) reduce 103) ((T_OBJECT_CAST) reduce 103) ((T_PRINT) reduce 103) ((T_READONLY) reduce 103) ((T_REQUIRE) reduce 103) ((T_REQUIRE_ONCE) reduce 103) ((T_RETURN) reduce 103) ((T_START_HEREDOC) reduce 103) ((T_STATIC) reduce 103) ((T_STRING) reduce 103) ((T_STRING_CAST) reduce 103) ((T_SWITCH) reduce 103) ((T_THROW) reduce 103) ((T_TRAIT) reduce 103) ((T_TRAIT_C) reduce 103) ((T_TRY) reduce 103) ((T_UNSET) reduce 103) ((T_UNSET_CAST) reduce 103) ((T_VARIABLE) reduce 103) ((T_WHILE) reduce 103) ((T_YIELD) reduce 103) ((T_YIELD_FROM) reduce 103) (("[") reduce 103) (("`") reduce 103) (("{") reduce 103) (("}") reduce 103) (("~") reduce 103)) 16606 ((("!") reduce 106) (("\"") reduce 106) (("$") reduce 106) (("(") reduce 106) (("+") reduce 106) (("-") reduce 106) ((";") reduce 106) (("@") reduce 106) ((T_ABSTRACT) reduce 106) ((T_ARRAY) reduce 106) ((T_ARRAY_CAST) reduce 106) ((T_ATTRIBUTE) reduce 106) ((T_BOOL_CAST) reduce 106) ((T_BREAK) reduce 106) ((T_CASE) reduce 106) ((T_CLASS) reduce 106) ((T_CLASS_C) reduce 106) ((T_CLONE) reduce 106) ((T_CONSTANT_ENCAPSED_STRING) reduce 106) ((T_CONTINUE) reduce 106) ((T_DEC) reduce 106) ((T_DECLARE) reduce 106) ((T_DEFAULT) reduce 106) ((T_DIR) reduce 106) ((T_DNUMBER) reduce 106) ((T_DO) reduce 106) ((T_DOUBLE_CAST) reduce 106) ((T_ECHO) reduce 106) ((T_EMPTY) reduce 106) ((T_ENUM) reduce 106) ((T_EVAL) reduce 106) ((T_EXIT) reduce 106) ((T_FILE) reduce 106) ((T_FINAL) reduce 106) ((T_FN) reduce 106) ((T_FOR) reduce 106) ((T_FOREACH) reduce 106) ((T_FUNCTION) reduce 106) ((T_FUNC_C) reduce 106) ((T_GLOBAL) reduce 106) ((T_GOTO) reduce 106) ((T_HALT_COMPILER) reduce 106) ((T_IF) reduce 106) ((T_INC) reduce 106) ((T_INCLUDE) reduce 106) ((T_INCLUDE_ONCE) reduce 106) ((T_INLINE_HTML) reduce 106) ((T_INTERFACE) reduce 106) ((T_INT_CAST) reduce 106) ((T_ISSET) reduce 106) ((T_LINE) reduce 106) ((T_LIST) reduce 106) ((T_LNUMBER) reduce 106) ((T_MATCH) reduce 106) ((T_METHOD_C) reduce 106) ((T_NAME_FULLY_QUALIFIED) reduce 106) ((T_NAME_QUALIFIED) reduce 106) ((T_NAME_RELATIVE) reduce 106) ((T_NEW) reduce 106) ((T_NS_C) reduce 106) ((T_OBJECT_CAST) reduce 106) ((T_PRINT) reduce 106) ((T_READONLY) reduce 106) ((T_REQUIRE) reduce 106) ((T_REQUIRE_ONCE) reduce 106) ((T_RETURN) reduce 106) ((T_START_HEREDOC) reduce 106) ((T_STATIC) reduce 106) ((T_STRING) reduce 106) ((T_STRING_CAST) reduce 106) ((T_SWITCH) reduce 106) ((T_THROW) reduce 106) ((T_TRAIT) reduce 106) ((T_TRAIT_C) reduce 106) ((T_TRY) reduce 106) ((T_UNSET) reduce 106) ((T_UNSET_CAST) reduce 106) ((T_VARIABLE) reduce 106) ((T_WHILE) reduce 106) ((T_YIELD) reduce 106) ((T_YIELD_FROM) reduce 106) (("[") reduce 106) (("`") reduce 106) (("{") reduce 106) (("}") reduce 106) (("~") reduce 106)) 16609 ((("!") reduce 102) (("\"") reduce 102) (("$") reduce 102) (("(") reduce 102) (("+") reduce 102) (("-") reduce 102) ((";") reduce 102) (("@") reduce 102) ((T_ABSTRACT) reduce 102) ((T_ARRAY) reduce 102) ((T_ARRAY_CAST) reduce 102) ((T_ATTRIBUTE) reduce 102) ((T_BOOL_CAST) reduce 102) ((T_BREAK) reduce 102) ((T_CASE) reduce 102) ((T_CLASS) reduce 102) ((T_CLASS_C) reduce 102) ((T_CLONE) reduce 102) ((T_CONSTANT_ENCAPSED_STRING) reduce 102) ((T_CONTINUE) reduce 102) ((T_DEC) reduce 102) ((T_DECLARE) reduce 102) ((T_DEFAULT) reduce 102) ((T_DIR) reduce 102) ((T_DNUMBER) reduce 102) ((T_DO) reduce 102) ((T_DOUBLE_CAST) reduce 102) ((T_ECHO) reduce 102) ((T_EMPTY) reduce 102) ((T_ENUM) reduce 102) ((T_EVAL) reduce 102) ((T_EXIT) reduce 102) ((T_FILE) reduce 102) ((T_FINAL) reduce 102) ((T_FN) reduce 102) ((T_FOR) reduce 102) ((T_FOREACH) reduce 102) ((T_FUNCTION) reduce 102) ((T_FUNC_C) reduce 102) ((T_GLOBAL) reduce 102) ((T_GOTO) reduce 102) ((T_HALT_COMPILER) reduce 102) ((T_IF) reduce 102) ((T_INC) reduce 102) ((T_INCLUDE) reduce 102) ((T_INCLUDE_ONCE) reduce 102) ((T_INLINE_HTML) reduce 102) ((T_INTERFACE) reduce 102) ((T_INT_CAST) reduce 102) ((T_ISSET) reduce 102) ((T_LINE) reduce 102) ((T_LIST) reduce 102) ((T_LNUMBER) reduce 102) ((T_MATCH) reduce 102) ((T_METHOD_C) reduce 102) ((T_NAME_FULLY_QUALIFIED) reduce 102) ((T_NAME_QUALIFIED) reduce 102) ((T_NAME_RELATIVE) reduce 102) ((T_NEW) reduce 102) ((T_NS_C) reduce 102) ((T_OBJECT_CAST) reduce 102) ((T_PRINT) reduce 102) ((T_READONLY) reduce 102) ((T_REQUIRE) reduce 102) ((T_REQUIRE_ONCE) reduce 102) ((T_RETURN) reduce 102) ((T_START_HEREDOC) reduce 102) ((T_STATIC) reduce 102) ((T_STRING) reduce 102) ((T_STRING_CAST) reduce 102) ((T_SWITCH) reduce 102) ((T_THROW) reduce 102) ((T_TRAIT) reduce 102) ((T_TRAIT_C) reduce 102) ((T_TRY) reduce 102) ((T_UNSET) reduce 102) ((T_UNSET_CAST) reduce 102) ((T_VARIABLE) reduce 102) ((T_WHILE) reduce 102) ((T_YIELD) reduce 102) ((T_YIELD_FROM) reduce 102) (("[") reduce 102) (("`") reduce 102) (("{") reduce 102) (("}") reduce 102) (("~") reduce 102)) 16610 ((("!") reduce 146) (("\"") reduce 146) (("$") reduce 146) (("(") reduce 146) (("+") reduce 146) (("-") reduce 146) ((";") reduce 146) (("@") reduce 146) ((T_ABSTRACT) reduce 146) ((T_ARRAY) reduce 146) ((T_ARRAY_CAST) reduce 146) ((T_ATTRIBUTE) reduce 146) ((T_BOOL_CAST) reduce 146) ((T_BREAK) reduce 146) ((T_CASE) reduce 146) ((T_CLASS) reduce 146) ((T_CLASS_C) reduce 146) ((T_CLONE) reduce 146) ((T_CONSTANT_ENCAPSED_STRING) reduce 146) ((T_CONTINUE) reduce 146) ((T_DEC) reduce 146) ((T_DECLARE) reduce 146) ((T_DEFAULT) reduce 146) ((T_DIR) reduce 146) ((T_DNUMBER) reduce 146) ((T_DO) reduce 146) ((T_DOUBLE_CAST) reduce 146) ((T_ECHO) reduce 146) ((T_EMPTY) reduce 146) ((T_ENUM) reduce 146) ((T_EVAL) reduce 146) ((T_EXIT) reduce 146) ((T_FILE) reduce 146) ((T_FINAL) reduce 146) ((T_FN) reduce 146) ((T_FOR) reduce 146) ((T_FOREACH) reduce 146) ((T_FUNCTION) reduce 146) ((T_FUNC_C) reduce 146) ((T_GLOBAL) reduce 146) ((T_GOTO) reduce 146) ((T_HALT_COMPILER) reduce 146) ((T_IF) reduce 146) ((T_INC) reduce 146) ((T_INCLUDE) reduce 146) ((T_INCLUDE_ONCE) reduce 146) ((T_INLINE_HTML) reduce 146) ((T_INTERFACE) reduce 146) ((T_INT_CAST) reduce 146) ((T_ISSET) reduce 146) ((T_LINE) reduce 146) ((T_LIST) reduce 146) ((T_LNUMBER) reduce 146) ((T_MATCH) reduce 146) ((T_METHOD_C) reduce 146) ((T_NAME_FULLY_QUALIFIED) reduce 146) ((T_NAME_QUALIFIED) reduce 146) ((T_NAME_RELATIVE) reduce 146) ((T_NEW) reduce 146) ((T_NS_C) reduce 146) ((T_OBJECT_CAST) reduce 146) ((T_PRINT) reduce 146) ((T_READONLY) reduce 146) ((T_REQUIRE) reduce 146) ((T_REQUIRE_ONCE) reduce 146) ((T_RETURN) reduce 146) ((T_START_HEREDOC) reduce 146) ((T_STATIC) reduce 146) ((T_STRING) reduce 146) ((T_STRING_CAST) reduce 146) ((T_SWITCH) reduce 146) ((T_THROW) reduce 146) ((T_TRAIT) reduce 146) ((T_TRAIT_C) reduce 146) ((T_TRY) reduce 146) ((T_UNSET) reduce 146) ((T_UNSET_CAST) reduce 146) ((T_VARIABLE) reduce 146) ((T_WHILE) reduce 146) ((T_YIELD) reduce 146) ((T_YIELD_FROM) reduce 146) (("[") reduce 146) (("`") reduce 146) (("{") reduce 146) (("}") reduce 146) (("~") reduce 146)) 16611 ((("!") reduce 243) (("\"") reduce 243) (("$") reduce 243) (("(") reduce 243) (("+") reduce 243) (("-") reduce 243) ((";") reduce 243) (("@") reduce 243) ((T_ABSTRACT) reduce 243) ((T_ARRAY) reduce 243) ((T_ARRAY_CAST) reduce 243) ((T_ATTRIBUTE) reduce 243) ((T_BOOL_CAST) reduce 243) ((T_BREAK) reduce 243) ((T_CASE) reduce 243) ((T_CLASS) reduce 243) ((T_CLASS_C) reduce 243) ((T_CLONE) reduce 243) ((T_CONSTANT_ENCAPSED_STRING) reduce 243) ((T_CONTINUE) reduce 243) ((T_DEC) reduce 243) ((T_DECLARE) reduce 243) ((T_DEFAULT) reduce 243) ((T_DIR) reduce 243) ((T_DNUMBER) reduce 243) ((T_DO) reduce 243) ((T_DOUBLE_CAST) reduce 243) ((T_ECHO) reduce 243) ((T_ELSE) shift) ((T_ELSEIF) shift) ((T_EMPTY) reduce 243) ((T_ENUM) reduce 243) ((T_EVAL) reduce 243) ((T_EXIT) reduce 243) ((T_FILE) reduce 243) ((T_FINAL) reduce 243) ((T_FN) reduce 243) ((T_FOR) reduce 243) ((T_FOREACH) reduce 243) ((T_FUNCTION) reduce 243) ((T_FUNC_C) reduce 243) ((T_GLOBAL) reduce 243) ((T_GOTO) reduce 243) ((T_HALT_COMPILER) reduce 243) ((T_IF) reduce 243) ((T_INC) reduce 243) ((T_INCLUDE) reduce 243) ((T_INCLUDE_ONCE) reduce 243) ((T_INLINE_HTML) reduce 243) ((T_INTERFACE) reduce 243) ((T_INT_CAST) reduce 243) ((T_ISSET) reduce 243) ((T_LINE) reduce 243) ((T_LIST) reduce 243) ((T_LNUMBER) reduce 243) ((T_MATCH) reduce 243) ((T_METHOD_C) reduce 243) ((T_NAME_FULLY_QUALIFIED) reduce 243) ((T_NAME_QUALIFIED) reduce 243) ((T_NAME_RELATIVE) reduce 243) ((T_NEW) reduce 243) ((T_NS_C) reduce 243) ((T_OBJECT_CAST) reduce 243) ((T_PRINT) reduce 243) ((T_READONLY) reduce 243) ((T_REQUIRE) reduce 243) ((T_REQUIRE_ONCE) reduce 243) ((T_RETURN) reduce 243) ((T_START_HEREDOC) reduce 243) ((T_STATIC) reduce 243) ((T_STRING) reduce 243) ((T_STRING_CAST) reduce 243) ((T_SWITCH) reduce 243) ((T_THROW) reduce 243) ((T_TRAIT) reduce 243) ((T_TRAIT_C) reduce 243) ((T_TRY) reduce 243) ((T_UNSET) reduce 243) ((T_UNSET_CAST) reduce 243) ((T_VARIABLE) reduce 243) ((T_WHILE) reduce 243) ((T_YIELD) reduce 243) ((T_YIELD_FROM) reduce 243) (("[") reduce 243) (("`") reduce 243) (("{") reduce 243) (("}") reduce 243) (("~") reduce 243)) 16612 ((("!") reduce 139) (("\"") reduce 139) (("$") reduce 139) (("(") reduce 139) (("+") reduce 139) (("-") reduce 139) ((";") reduce 139) (("@") reduce 139) ((T_ABSTRACT) reduce 139) ((T_ARRAY) reduce 139) ((T_ARRAY_CAST) reduce 139) ((T_ATTRIBUTE) reduce 139) ((T_BOOL_CAST) reduce 139) ((T_BREAK) reduce 139) ((T_CASE) reduce 139) ((T_CLASS) reduce 139) ((T_CLASS_C) reduce 139) ((T_CLONE) reduce 139) ((T_CONSTANT_ENCAPSED_STRING) reduce 139) ((T_CONTINUE) reduce 139) ((T_DEC) reduce 139) ((T_DECLARE) reduce 139) ((T_DEFAULT) reduce 139) ((T_DIR) reduce 139) ((T_DNUMBER) reduce 139) ((T_DO) reduce 139) ((T_DOUBLE_CAST) reduce 139) ((T_ECHO) reduce 139) ((T_EMPTY) reduce 139) ((T_ENUM) reduce 139) ((T_EVAL) reduce 139) ((T_EXIT) reduce 139) ((T_FILE) reduce 139) ((T_FINAL) reduce 139) ((T_FN) reduce 139) ((T_FOR) reduce 139) ((T_FOREACH) reduce 139) ((T_FUNCTION) reduce 139) ((T_FUNC_C) reduce 139) ((T_GLOBAL) reduce 139) ((T_GOTO) reduce 139) ((T_HALT_COMPILER) reduce 139) ((T_IF) reduce 139) ((T_INC) reduce 139) ((T_INCLUDE) reduce 139) ((T_INCLUDE_ONCE) reduce 139) ((T_INLINE_HTML) reduce 139) ((T_INTERFACE) reduce 139) ((T_INT_CAST) reduce 139) ((T_ISSET) reduce 139) ((T_LINE) reduce 139) ((T_LIST) reduce 139) ((T_LNUMBER) reduce 139) ((T_MATCH) reduce 139) ((T_METHOD_C) reduce 139) ((T_NAME_FULLY_QUALIFIED) reduce 139) ((T_NAME_QUALIFIED) reduce 139) ((T_NAME_RELATIVE) reduce 139) ((T_NEW) reduce 139) ((T_NS_C) reduce 139) ((T_OBJECT_CAST) reduce 139) ((T_PRINT) reduce 139) ((T_READONLY) reduce 139) ((T_REQUIRE) reduce 139) ((T_REQUIRE_ONCE) reduce 139) ((T_RETURN) reduce 139) ((T_START_HEREDOC) reduce 139) ((T_STATIC) reduce 139) ((T_STRING) reduce 139) ((T_STRING_CAST) reduce 139) ((T_SWITCH) reduce 139) ((T_THROW) reduce 139) ((T_TRAIT) reduce 139) ((T_TRAIT_C) reduce 139) ((T_TRY) reduce 139) ((T_UNSET) reduce 139) ((T_UNSET_CAST) reduce 139) ((T_VARIABLE) reduce 139) ((T_WHILE) reduce 139) ((T_YIELD) reduce 139) ((T_YIELD_FROM) reduce 139) (("[") reduce 139) (("`") reduce 139) (("{") reduce 139) (("}") reduce 139) (("~") reduce 139)) 16613 ((("!") reduce 105) (("\"") reduce 105) (("$") reduce 105) (("(") reduce 105) (("+") reduce 105) (("-") reduce 105) ((";") reduce 105) (("@") reduce 105) ((T_ABSTRACT) reduce 105) ((T_ARRAY) reduce 105) ((T_ARRAY_CAST) reduce 105) ((T_ATTRIBUTE) reduce 105) ((T_BOOL_CAST) reduce 105) ((T_BREAK) reduce 105) ((T_CASE) reduce 105) ((T_CLASS) reduce 105) ((T_CLASS_C) reduce 105) ((T_CLONE) reduce 105) ((T_CONSTANT_ENCAPSED_STRING) reduce 105) ((T_CONTINUE) reduce 105) ((T_DEC) reduce 105) ((T_DECLARE) reduce 105) ((T_DEFAULT) reduce 105) ((T_DIR) reduce 105) ((T_DNUMBER) reduce 105) ((T_DO) reduce 105) ((T_DOUBLE_CAST) reduce 105) ((T_ECHO) reduce 105) ((T_EMPTY) reduce 105) ((T_ENUM) reduce 105) ((T_EVAL) reduce 105) ((T_EXIT) reduce 105) ((T_FILE) reduce 105) ((T_FINAL) reduce 105) ((T_FN) reduce 105) ((T_FOR) reduce 105) ((T_FOREACH) reduce 105) ((T_FUNCTION) reduce 105) ((T_FUNC_C) reduce 105) ((T_GLOBAL) reduce 105) ((T_GOTO) reduce 105) ((T_HALT_COMPILER) reduce 105) ((T_IF) reduce 105) ((T_INC) reduce 105) ((T_INCLUDE) reduce 105) ((T_INCLUDE_ONCE) reduce 105) ((T_INLINE_HTML) reduce 105) ((T_INTERFACE) reduce 105) ((T_INT_CAST) reduce 105) ((T_ISSET) reduce 105) ((T_LINE) reduce 105) ((T_LIST) reduce 105) ((T_LNUMBER) reduce 105) ((T_MATCH) reduce 105) ((T_METHOD_C) reduce 105) ((T_NAME_FULLY_QUALIFIED) reduce 105) ((T_NAME_QUALIFIED) reduce 105) ((T_NAME_RELATIVE) reduce 105) ((T_NEW) reduce 105) ((T_NS_C) reduce 105) ((T_OBJECT_CAST) reduce 105) ((T_PRINT) reduce 105) ((T_READONLY) reduce 105) ((T_REQUIRE) reduce 105) ((T_REQUIRE_ONCE) reduce 105) ((T_RETURN) reduce 105) ((T_START_HEREDOC) reduce 105) ((T_STATIC) reduce 105) ((T_STRING) reduce 105) ((T_STRING_CAST) reduce 105) ((T_SWITCH) reduce 105) ((T_THROW) reduce 105) ((T_TRAIT) reduce 105) ((T_TRAIT_C) reduce 105) ((T_TRY) reduce 105) ((T_UNSET) reduce 105) ((T_UNSET_CAST) reduce 105) ((T_VARIABLE) reduce 105) ((T_WHILE) reduce 105) ((T_YIELD) reduce 105) ((T_YIELD_FROM) reduce 105) (("[") reduce 105) (("`") reduce 105) (("{") reduce 105) (("}") reduce 105) (("~") reduce 105)) 16614 ((("!") reduce 141) (("\"") reduce 141) (("$") reduce 141) (("(") reduce 141) (("+") reduce 141) (("-") reduce 141) ((";") reduce 141) (("@") reduce 141) ((T_ABSTRACT) reduce 141) ((T_ARRAY) reduce 141) ((T_ARRAY_CAST) reduce 141) ((T_ATTRIBUTE) reduce 141) ((T_BOOL_CAST) reduce 141) ((T_BREAK) reduce 141) ((T_CASE) reduce 141) ((T_CLASS) reduce 141) ((T_CLASS_C) reduce 141) ((T_CLONE) reduce 141) ((T_CONSTANT_ENCAPSED_STRING) reduce 141) ((T_CONTINUE) reduce 141) ((T_DEC) reduce 141) ((T_DECLARE) reduce 141) ((T_DEFAULT) reduce 141) ((T_DIR) reduce 141) ((T_DNUMBER) reduce 141) ((T_DO) reduce 141) ((T_DOUBLE_CAST) reduce 141) ((T_ECHO) reduce 141) ((T_EMPTY) reduce 141) ((T_ENUM) reduce 141) ((T_EVAL) reduce 141) ((T_EXIT) reduce 141) ((T_FILE) reduce 141) ((T_FINAL) reduce 141) ((T_FN) reduce 141) ((T_FOR) reduce 141) ((T_FOREACH) reduce 141) ((T_FUNCTION) reduce 141) ((T_FUNC_C) reduce 141) ((T_GLOBAL) reduce 141) ((T_GOTO) reduce 141) ((T_HALT_COMPILER) reduce 141) ((T_IF) reduce 141) ((T_INC) reduce 141) ((T_INCLUDE) reduce 141) ((T_INCLUDE_ONCE) reduce 141) ((T_INLINE_HTML) reduce 141) ((T_INTERFACE) reduce 141) ((T_INT_CAST) reduce 141) ((T_ISSET) reduce 141) ((T_LINE) reduce 141) ((T_LIST) reduce 141) ((T_LNUMBER) reduce 141) ((T_MATCH) reduce 141) ((T_METHOD_C) reduce 141) ((T_NAME_FULLY_QUALIFIED) reduce 141) ((T_NAME_QUALIFIED) reduce 141) ((T_NAME_RELATIVE) reduce 141) ((T_NEW) reduce 141) ((T_NS_C) reduce 141) ((T_OBJECT_CAST) reduce 141) ((T_PRINT) reduce 141) ((T_READONLY) reduce 141) ((T_REQUIRE) reduce 141) ((T_REQUIRE_ONCE) reduce 141) ((T_RETURN) reduce 141) ((T_START_HEREDOC) reduce 141) ((T_STATIC) reduce 141) ((T_STRING) reduce 141) ((T_STRING_CAST) reduce 141) ((T_SWITCH) reduce 141) ((T_THROW) reduce 141) ((T_TRAIT) reduce 141) ((T_TRAIT_C) reduce 141) ((T_TRY) reduce 141) ((T_UNSET) reduce 141) ((T_UNSET_CAST) reduce 141) ((T_VARIABLE) reduce 141) ((T_WHILE) reduce 141) ((T_YIELD) reduce 141) ((T_YIELD_FROM) reduce 141) (("[") reduce 141) (("`") reduce 141) (("{") reduce 141) (("}") reduce 141) (("~") reduce 141)) 16615 ((("!") reduce 104) (("\"") reduce 104) (("$") reduce 104) (("(") reduce 104) (("+") reduce 104) (("-") reduce 104) ((";") reduce 104) (("@") reduce 104) ((T_ABSTRACT) reduce 104) ((T_ARRAY) reduce 104) ((T_ARRAY_CAST) reduce 104) ((T_ATTRIBUTE) reduce 104) ((T_BOOL_CAST) reduce 104) ((T_BREAK) reduce 104) ((T_CASE) reduce 104) ((T_CLASS) reduce 104) ((T_CLASS_C) reduce 104) ((T_CLONE) reduce 104) ((T_CONSTANT_ENCAPSED_STRING) reduce 104) ((T_CONTINUE) reduce 104) ((T_DEC) reduce 104) ((T_DECLARE) reduce 104) ((T_DEFAULT) reduce 104) ((T_DIR) reduce 104) ((T_DNUMBER) reduce 104) ((T_DO) reduce 104) ((T_DOUBLE_CAST) reduce 104) ((T_ECHO) reduce 104) ((T_EMPTY) reduce 104) ((T_ENUM) reduce 104) ((T_EVAL) reduce 104) ((T_EXIT) reduce 104) ((T_FILE) reduce 104) ((T_FINAL) reduce 104) ((T_FN) reduce 104) ((T_FOR) reduce 104) ((T_FOREACH) reduce 104) ((T_FUNCTION) reduce 104) ((T_FUNC_C) reduce 104) ((T_GLOBAL) reduce 104) ((T_GOTO) reduce 104) ((T_HALT_COMPILER) reduce 104) ((T_IF) reduce 104) ((T_INC) reduce 104) ((T_INCLUDE) reduce 104) ((T_INCLUDE_ONCE) reduce 104) ((T_INLINE_HTML) reduce 104) ((T_INTERFACE) reduce 104) ((T_INT_CAST) reduce 104) ((T_ISSET) reduce 104) ((T_LINE) reduce 104) ((T_LIST) reduce 104) ((T_LNUMBER) reduce 104) ((T_MATCH) reduce 104) ((T_METHOD_C) reduce 104) ((T_NAME_FULLY_QUALIFIED) reduce 104) ((T_NAME_QUALIFIED) reduce 104) ((T_NAME_RELATIVE) reduce 104) ((T_NEW) reduce 104) ((T_NS_C) reduce 104) ((T_OBJECT_CAST) reduce 104) ((T_PRINT) reduce 104) ((T_READONLY) reduce 104) ((T_REQUIRE) reduce 104) ((T_REQUIRE_ONCE) reduce 104) ((T_RETURN) reduce 104) ((T_START_HEREDOC) reduce 104) ((T_STATIC) reduce 104) ((T_STRING) reduce 104) ((T_STRING_CAST) reduce 104) ((T_SWITCH) reduce 104) ((T_THROW) reduce 104) ((T_TRAIT) reduce 104) ((T_TRAIT_C) reduce 104) ((T_TRY) reduce 104) ((T_UNSET) reduce 104) ((T_UNSET_CAST) reduce 104) ((T_VARIABLE) reduce 104) ((T_WHILE) reduce 104) ((T_YIELD) reduce 104) ((T_YIELD_FROM) reduce 104) (("[") reduce 104) (("`") reduce 104) (("{") reduce 104) (("}") reduce 104) (("~") reduce 104)) 16618 ((("!") reduce 145) (("\"") reduce 145) (("$") reduce 145) (("(") reduce 145) (("+") reduce 145) (("-") reduce 145) ((";") reduce 145) (("@") reduce 145) ((T_ABSTRACT) reduce 145) ((T_ARRAY) reduce 145) ((T_ARRAY_CAST) reduce 145) ((T_ATTRIBUTE) reduce 145) ((T_BOOL_CAST) reduce 145) ((T_BREAK) reduce 145) ((T_CASE) reduce 145) ((T_CLASS) reduce 145) ((T_CLASS_C) reduce 145) ((T_CLONE) reduce 145) ((T_CONSTANT_ENCAPSED_STRING) reduce 145) ((T_CONTINUE) reduce 145) ((T_DEC) reduce 145) ((T_DECLARE) reduce 145) ((T_DEFAULT) reduce 145) ((T_DIR) reduce 145) ((T_DNUMBER) reduce 145) ((T_DO) reduce 145) ((T_DOUBLE_CAST) reduce 145) ((T_ECHO) reduce 145) ((T_EMPTY) reduce 145) ((T_ENUM) reduce 145) ((T_EVAL) reduce 145) ((T_EXIT) reduce 145) ((T_FILE) reduce 145) ((T_FINAL) reduce 145) ((T_FN) reduce 145) ((T_FOR) reduce 145) ((T_FOREACH) reduce 145) ((T_FUNCTION) reduce 145) ((T_FUNC_C) reduce 145) ((T_GLOBAL) reduce 145) ((T_GOTO) reduce 145) ((T_HALT_COMPILER) reduce 145) ((T_IF) reduce 145) ((T_INC) reduce 145) ((T_INCLUDE) reduce 145) ((T_INCLUDE_ONCE) reduce 145) ((T_INLINE_HTML) reduce 145) ((T_INTERFACE) reduce 145) ((T_INT_CAST) reduce 145) ((T_ISSET) reduce 145) ((T_LINE) reduce 145) ((T_LIST) reduce 145) ((T_LNUMBER) reduce 145) ((T_MATCH) reduce 145) ((T_METHOD_C) reduce 145) ((T_NAME_FULLY_QUALIFIED) reduce 145) ((T_NAME_QUALIFIED) reduce 145) ((T_NAME_RELATIVE) reduce 145) ((T_NEW) reduce 145) ((T_NS_C) reduce 145) ((T_OBJECT_CAST) reduce 145) ((T_PRINT) reduce 145) ((T_READONLY) reduce 145) ((T_REQUIRE) reduce 145) ((T_REQUIRE_ONCE) reduce 145) ((T_RETURN) reduce 145) ((T_START_HEREDOC) reduce 145) ((T_STATIC) reduce 145) ((T_STRING) reduce 145) ((T_STRING_CAST) reduce 145) ((T_SWITCH) reduce 145) ((T_THROW) reduce 145) ((T_TRAIT) reduce 145) ((T_TRAIT_C) reduce 145) ((T_TRY) reduce 145) ((T_UNSET) reduce 145) ((T_UNSET_CAST) reduce 145) ((T_VARIABLE) reduce 145) ((T_WHILE) reduce 145) ((T_YIELD) reduce 145) ((T_YIELD_FROM) reduce 145) (("[") reduce 145) (("`") reduce 145) (("{") reduce 145) (("}") reduce 145) (("~") reduce 145)) 16624 ((("!") reduce 164) (("\"") reduce 164) (("$") reduce 164) (("(") reduce 164) (("+") reduce 164) (("-") reduce 164) ((";") reduce 164) (("@") reduce 164) ((T_ABSTRACT) reduce 164) ((T_ARRAY) reduce 164) ((T_ARRAY_CAST) reduce 164) ((T_ATTRIBUTE) reduce 164) ((T_BOOL_CAST) reduce 164) ((T_BREAK) reduce 164) ((T_CASE) reduce 164) ((T_CLASS) reduce 164) ((T_CLASS_C) reduce 164) ((T_CLONE) reduce 164) ((T_CONSTANT_ENCAPSED_STRING) reduce 164) ((T_CONTINUE) reduce 164) ((T_DEC) reduce 164) ((T_DECLARE) reduce 164) ((T_DEFAULT) reduce 164) ((T_DIR) reduce 164) ((T_DNUMBER) reduce 164) ((T_DO) reduce 164) ((T_DOUBLE_CAST) reduce 164) ((T_ECHO) reduce 164) ((T_ELSE) reduce 164) ((T_ELSEIF) reduce 164) ((T_EMPTY) reduce 164) ((T_ENUM) reduce 164) ((T_EVAL) reduce 164) ((T_EXIT) reduce 164) ((T_FILE) reduce 164) ((T_FINAL) reduce 164) ((T_FN) reduce 164) ((T_FOR) reduce 164) ((T_FOREACH) reduce 164) ((T_FUNCTION) reduce 164) ((T_FUNC_C) reduce 164) ((T_GLOBAL) reduce 164) ((T_GOTO) reduce 164) ((T_HALT_COMPILER) reduce 164) ((T_IF) reduce 164) ((T_INC) reduce 164) ((T_INCLUDE) reduce 164) ((T_INCLUDE_ONCE) reduce 164) ((T_INLINE_HTML) reduce 164) ((T_INTERFACE) reduce 164) ((T_INT_CAST) reduce 164) ((T_ISSET) reduce 164) ((T_LINE) reduce 164) ((T_LIST) reduce 164) ((T_LNUMBER) reduce 164) ((T_MATCH) reduce 164) ((T_METHOD_C) reduce 164) ((T_NAME_FULLY_QUALIFIED) reduce 164) ((T_NAME_QUALIFIED) reduce 164) ((T_NAME_RELATIVE) reduce 164) ((T_NEW) reduce 164) ((T_NS_C) reduce 164) ((T_OBJECT_CAST) reduce 164) ((T_PRINT) reduce 164) ((T_READONLY) reduce 164) ((T_REQUIRE) reduce 164) ((T_REQUIRE_ONCE) reduce 164) ((T_RETURN) reduce 164) ((T_START_HEREDOC) reduce 164) ((T_STATIC) reduce 164) ((T_STRING) reduce 164) ((T_STRING_CAST) reduce 164) ((T_SWITCH) reduce 164) ((T_THROW) reduce 164) ((T_TRAIT) reduce 164) ((T_TRAIT_C) reduce 164) ((T_TRY) reduce 164) ((T_UNSET) reduce 164) ((T_UNSET_CAST) reduce 164) ((T_VARIABLE) reduce 164) ((T_WHILE) reduce 164) ((T_YIELD) reduce 164) ((T_YIELD_FROM) reduce 164) (("[") reduce 164) (("`") reduce 164) (("{") reduce 164) (("}") reduce 164) (("~") reduce 164)) 16634 ((("!") reduce 158) (("\"") reduce 158) (("$") reduce 158) (("(") reduce 158) (("+") reduce 158) (("-") reduce 158) ((";") reduce 158) (("@") reduce 158) ((T_ABSTRACT) reduce 158) ((T_ARRAY) reduce 158) ((T_ARRAY_CAST) reduce 158) ((T_ATTRIBUTE) reduce 158) ((T_BOOL_CAST) reduce 158) ((T_BREAK) reduce 158) ((T_CASE) reduce 158) ((T_CLASS) reduce 158) ((T_CLASS_C) reduce 158) ((T_CLONE) reduce 158) ((T_CONSTANT_ENCAPSED_STRING) reduce 158) ((T_CONTINUE) reduce 158) ((T_DEC) reduce 158) ((T_DECLARE) reduce 158) ((T_DEFAULT) reduce 158) ((T_DIR) reduce 158) ((T_DNUMBER) reduce 158) ((T_DO) reduce 158) ((T_DOUBLE_CAST) reduce 158) ((T_ECHO) reduce 158) ((T_ELSE) reduce 158) ((T_ELSEIF) reduce 158) ((T_EMPTY) reduce 158) ((T_ENUM) reduce 158) ((T_EVAL) reduce 158) ((T_EXIT) reduce 158) ((T_FILE) reduce 158) ((T_FINAL) reduce 158) ((T_FN) reduce 158) ((T_FOR) reduce 158) ((T_FOREACH) reduce 158) ((T_FUNCTION) reduce 158) ((T_FUNC_C) reduce 158) ((T_GLOBAL) reduce 158) ((T_GOTO) reduce 158) ((T_HALT_COMPILER) reduce 158) ((T_IF) reduce 158) ((T_INC) reduce 158) ((T_INCLUDE) reduce 158) ((T_INCLUDE_ONCE) reduce 158) ((T_INLINE_HTML) reduce 158) ((T_INTERFACE) reduce 158) ((T_INT_CAST) reduce 158) ((T_ISSET) reduce 158) ((T_LINE) reduce 158) ((T_LIST) reduce 158) ((T_LNUMBER) reduce 158) ((T_MATCH) reduce 158) ((T_METHOD_C) reduce 158) ((T_NAME_FULLY_QUALIFIED) reduce 158) ((T_NAME_QUALIFIED) reduce 158) ((T_NAME_RELATIVE) reduce 158) ((T_NEW) reduce 158) ((T_NS_C) reduce 158) ((T_OBJECT_CAST) reduce 158) ((T_PRINT) reduce 158) ((T_READONLY) reduce 158) ((T_REQUIRE) reduce 158) ((T_REQUIRE_ONCE) reduce 158) ((T_RETURN) reduce 158) ((T_START_HEREDOC) reduce 158) ((T_STATIC) reduce 158) ((T_STRING) reduce 158) ((T_STRING_CAST) reduce 158) ((T_SWITCH) reduce 158) ((T_THROW) reduce 158) ((T_TRAIT) reduce 158) ((T_TRAIT_C) reduce 158) ((T_TRY) reduce 158) ((T_UNSET) reduce 158) ((T_UNSET_CAST) reduce 158) ((T_VARIABLE) reduce 158) ((T_WHILE) reduce 158) ((T_YIELD) reduce 158) ((T_YIELD_FROM) reduce 158) (("[") reduce 158) (("`") reduce 158) (("{") reduce 158) (("}") reduce 158) (("~") reduce 158)) 16642 ((("!") reduce 147) (("\"") reduce 147) (("$") reduce 147) (("(") reduce 147) (("+") reduce 147) (("-") reduce 147) ((";") reduce 147) (("@") reduce 147) ((T_ABSTRACT) reduce 147) ((T_ARRAY) reduce 147) ((T_ARRAY_CAST) reduce 147) ((T_ATTRIBUTE) reduce 147) ((T_BOOL_CAST) reduce 147) ((T_BREAK) reduce 147) ((T_CASE) reduce 147) ((T_CLASS) reduce 147) ((T_CLASS_C) reduce 147) ((T_CLONE) reduce 147) ((T_CONSTANT_ENCAPSED_STRING) reduce 147) ((T_CONTINUE) reduce 147) ((T_DEC) reduce 147) ((T_DECLARE) reduce 147) ((T_DEFAULT) reduce 147) ((T_DIR) reduce 147) ((T_DNUMBER) reduce 147) ((T_DO) reduce 147) ((T_DOUBLE_CAST) reduce 147) ((T_ECHO) reduce 147) ((T_ELSE) reduce 147) ((T_ELSEIF) reduce 147) ((T_EMPTY) reduce 147) ((T_ENUM) reduce 147) ((T_EVAL) reduce 147) ((T_EXIT) reduce 147) ((T_FILE) reduce 147) ((T_FINAL) reduce 147) ((T_FN) reduce 147) ((T_FOR) reduce 147) ((T_FOREACH) reduce 147) ((T_FUNCTION) reduce 147) ((T_FUNC_C) reduce 147) ((T_GLOBAL) reduce 147) ((T_GOTO) reduce 147) ((T_HALT_COMPILER) reduce 147) ((T_IF) reduce 147) ((T_INC) reduce 147) ((T_INCLUDE) reduce 147) ((T_INCLUDE_ONCE) reduce 147) ((T_INLINE_HTML) reduce 147) ((T_INTERFACE) reduce 147) ((T_INT_CAST) reduce 147) ((T_ISSET) reduce 147) ((T_LINE) reduce 147) ((T_LIST) reduce 147) ((T_LNUMBER) reduce 147) ((T_MATCH) reduce 147) ((T_METHOD_C) reduce 147) ((T_NAME_FULLY_QUALIFIED) reduce 147) ((T_NAME_QUALIFIED) reduce 147) ((T_NAME_RELATIVE) reduce 147) ((T_NEW) reduce 147) ((T_NS_C) reduce 147) ((T_OBJECT_CAST) reduce 147) ((T_PRINT) reduce 147) ((T_READONLY) reduce 147) ((T_REQUIRE) reduce 147) ((T_REQUIRE_ONCE) reduce 147) ((T_RETURN) reduce 147) ((T_START_HEREDOC) reduce 147) ((T_STATIC) reduce 147) ((T_STRING) reduce 147) ((T_STRING_CAST) reduce 147) ((T_SWITCH) reduce 147) ((T_THROW) reduce 147) ((T_TRAIT) reduce 147) ((T_TRAIT_C) reduce 147) ((T_TRY) reduce 147) ((T_UNSET) reduce 147) ((T_UNSET_CAST) reduce 147) ((T_VARIABLE) reduce 147) ((T_WHILE) reduce 147) ((T_YIELD) reduce 147) ((T_YIELD_FROM) reduce 147) (("[") reduce 147) (("`") reduce 147) (("{") reduce 147) (("}") reduce 147) (("~") reduce 147)) 16645 ((("!") reduce 146) (("\"") reduce 146) (("$") reduce 146) (("(") reduce 146) (("+") reduce 146) (("-") reduce 146) ((";") reduce 146) (("@") reduce 146) ((T_ABSTRACT) reduce 146) ((T_ARRAY) reduce 146) ((T_ARRAY_CAST) reduce 146) ((T_ATTRIBUTE) reduce 146) ((T_BOOL_CAST) reduce 146) ((T_BREAK) reduce 146) ((T_CASE) reduce 146) ((T_CLASS) reduce 146) ((T_CLASS_C) reduce 146) ((T_CLONE) reduce 146) ((T_CONSTANT_ENCAPSED_STRING) reduce 146) ((T_CONTINUE) reduce 146) ((T_DEC) reduce 146) ((T_DECLARE) reduce 146) ((T_DEFAULT) reduce 146) ((T_DIR) reduce 146) ((T_DNUMBER) reduce 146) ((T_DO) reduce 146) ((T_DOUBLE_CAST) reduce 146) ((T_ECHO) reduce 146) ((T_ELSE) reduce 146) ((T_ELSEIF) reduce 146) ((T_EMPTY) reduce 146) ((T_ENUM) reduce 146) ((T_EVAL) reduce 146) ((T_EXIT) reduce 146) ((T_FILE) reduce 146) ((T_FINAL) reduce 146) ((T_FN) reduce 146) ((T_FOR) reduce 146) ((T_FOREACH) reduce 146) ((T_FUNCTION) reduce 146) ((T_FUNC_C) reduce 146) ((T_GLOBAL) reduce 146) ((T_GOTO) reduce 146) ((T_HALT_COMPILER) reduce 146) ((T_IF) reduce 146) ((T_INC) reduce 146) ((T_INCLUDE) reduce 146) ((T_INCLUDE_ONCE) reduce 146) ((T_INLINE_HTML) reduce 146) ((T_INTERFACE) reduce 146) ((T_INT_CAST) reduce 146) ((T_ISSET) reduce 146) ((T_LINE) reduce 146) ((T_LIST) reduce 146) ((T_LNUMBER) reduce 146) ((T_MATCH) reduce 146) ((T_METHOD_C) reduce 146) ((T_NAME_FULLY_QUALIFIED) reduce 146) ((T_NAME_QUALIFIED) reduce 146) ((T_NAME_RELATIVE) reduce 146) ((T_NEW) reduce 146) ((T_NS_C) reduce 146) ((T_OBJECT_CAST) reduce 146) ((T_PRINT) reduce 146) ((T_READONLY) reduce 146) ((T_REQUIRE) reduce 146) ((T_REQUIRE_ONCE) reduce 146) ((T_RETURN) reduce 146) ((T_START_HEREDOC) reduce 146) ((T_STATIC) reduce 146) ((T_STRING) reduce 146) ((T_STRING_CAST) reduce 146) ((T_SWITCH) reduce 146) ((T_THROW) reduce 146) ((T_TRAIT) reduce 146) ((T_TRAIT_C) reduce 146) ((T_TRY) reduce 146) ((T_UNSET) reduce 146) ((T_UNSET_CAST) reduce 146) ((T_VARIABLE) reduce 146) ((T_WHILE) reduce 146) ((T_YIELD) reduce 146) ((T_YIELD_FROM) reduce 146) (("[") reduce 146) (("`") reduce 146) (("{") reduce 146) (("}") reduce 146) (("~") reduce 146)) 16647 ((("!") reduce 242) (("\"") reduce 242) (("$") reduce 242) (("(") reduce 242) (("+") reduce 242) (("-") reduce 242) ((";") reduce 242) (("@") reduce 242) ((T_ABSTRACT) reduce 242) ((T_ARRAY) reduce 242) ((T_ARRAY_CAST) reduce 242) ((T_ATTRIBUTE) reduce 242) ((T_BOOL_CAST) reduce 242) ((T_BREAK) reduce 242) ((T_CASE) reduce 242) ((T_CLASS) reduce 242) ((T_CLASS_C) reduce 242) ((T_CLONE) reduce 242) ((T_CONSTANT_ENCAPSED_STRING) reduce 242) ((T_CONTINUE) reduce 242) ((T_DEC) reduce 242) ((T_DECLARE) reduce 242) ((T_DEFAULT) reduce 242) ((T_DIR) reduce 242) ((T_DNUMBER) reduce 242) ((T_DO) reduce 242) ((T_DOUBLE_CAST) reduce 242) ((T_ECHO) reduce 242) ((T_ELSE) reduce 242) ((T_ELSEIF) reduce 242) ((T_EMPTY) reduce 242) ((T_ENUM) reduce 242) ((T_EVAL) reduce 242) ((T_EXIT) reduce 242) ((T_FILE) reduce 242) ((T_FINAL) reduce 242) ((T_FN) reduce 242) ((T_FOR) reduce 242) ((T_FOREACH) reduce 242) ((T_FUNCTION) reduce 242) ((T_FUNC_C) reduce 242) ((T_GLOBAL) reduce 242) ((T_GOTO) reduce 242) ((T_HALT_COMPILER) reduce 242) ((T_IF) reduce 242) ((T_INC) reduce 242) ((T_INCLUDE) reduce 242) ((T_INCLUDE_ONCE) reduce 242) ((T_INLINE_HTML) reduce 242) ((T_INTERFACE) reduce 242) ((T_INT_CAST) reduce 242) ((T_ISSET) reduce 242) ((T_LINE) reduce 242) ((T_LIST) reduce 242) ((T_LNUMBER) reduce 242) ((T_MATCH) reduce 242) ((T_METHOD_C) reduce 242) ((T_NAME_FULLY_QUALIFIED) reduce 242) ((T_NAME_QUALIFIED) reduce 242) ((T_NAME_RELATIVE) reduce 242) ((T_NEW) reduce 242) ((T_NS_C) reduce 242) ((T_OBJECT_CAST) reduce 242) ((T_PRINT) reduce 242) ((T_READONLY) reduce 242) ((T_REQUIRE) reduce 242) ((T_REQUIRE_ONCE) reduce 242) ((T_RETURN) reduce 242) ((T_START_HEREDOC) reduce 242) ((T_STATIC) reduce 242) ((T_STRING) reduce 242) ((T_STRING_CAST) reduce 242) ((T_SWITCH) reduce 242) ((T_THROW) reduce 242) ((T_TRAIT) reduce 242) ((T_TRAIT_C) reduce 242) ((T_TRY) reduce 242) ((T_UNSET) reduce 242) ((T_UNSET_CAST) reduce 242) ((T_VARIABLE) reduce 242) ((T_WHILE) reduce 242) ((T_YIELD) reduce 242) ((T_YIELD_FROM) reduce 242) (("[") reduce 242) (("`") reduce 242) (("{") reduce 242) (("}") reduce 242) (("~") reduce 242)) 16650 ((("!") reduce 145) (("\"") reduce 145) (("$") reduce 145) (("(") reduce 145) (("+") reduce 145) (("-") reduce 145) ((";") reduce 145) (("@") reduce 145) ((T_ABSTRACT) reduce 145) ((T_ARRAY) reduce 145) ((T_ARRAY_CAST) reduce 145) ((T_ATTRIBUTE) reduce 145) ((T_BOOL_CAST) reduce 145) ((T_BREAK) reduce 145) ((T_CASE) reduce 145) ((T_CLASS) reduce 145) ((T_CLASS_C) reduce 145) ((T_CLONE) reduce 145) ((T_CONSTANT_ENCAPSED_STRING) reduce 145) ((T_CONTINUE) reduce 145) ((T_DEC) reduce 145) ((T_DECLARE) reduce 145) ((T_DEFAULT) reduce 145) ((T_DIR) reduce 145) ((T_DNUMBER) reduce 145) ((T_DO) reduce 145) ((T_DOUBLE_CAST) reduce 145) ((T_ECHO) reduce 145) ((T_ELSE) reduce 145) ((T_ELSEIF) reduce 145) ((T_EMPTY) reduce 145) ((T_ENUM) reduce 145) ((T_EVAL) reduce 145) ((T_EXIT) reduce 145) ((T_FILE) reduce 145) ((T_FINAL) reduce 145) ((T_FN) reduce 145) ((T_FOR) reduce 145) ((T_FOREACH) reduce 145) ((T_FUNCTION) reduce 145) ((T_FUNC_C) reduce 145) ((T_GLOBAL) reduce 145) ((T_GOTO) reduce 145) ((T_HALT_COMPILER) reduce 145) ((T_IF) reduce 145) ((T_INC) reduce 145) ((T_INCLUDE) reduce 145) ((T_INCLUDE_ONCE) reduce 145) ((T_INLINE_HTML) reduce 145) ((T_INTERFACE) reduce 145) ((T_INT_CAST) reduce 145) ((T_ISSET) reduce 145) ((T_LINE) reduce 145) ((T_LIST) reduce 145) ((T_LNUMBER) reduce 145) ((T_MATCH) reduce 145) ((T_METHOD_C) reduce 145) ((T_NAME_FULLY_QUALIFIED) reduce 145) ((T_NAME_QUALIFIED) reduce 145) ((T_NAME_RELATIVE) reduce 145) ((T_NEW) reduce 145) ((T_NS_C) reduce 145) ((T_OBJECT_CAST) reduce 145) ((T_PRINT) reduce 145) ((T_READONLY) reduce 145) ((T_REQUIRE) reduce 145) ((T_REQUIRE_ONCE) reduce 145) ((T_RETURN) reduce 145) ((T_START_HEREDOC) reduce 145) ((T_STATIC) reduce 145) ((T_STRING) reduce 145) ((T_STRING_CAST) reduce 145) ((T_SWITCH) reduce 145) ((T_THROW) reduce 145) ((T_TRAIT) reduce 145) ((T_TRAIT_C) reduce 145) ((T_TRY) reduce 145) ((T_UNSET) reduce 145) ((T_UNSET_CAST) reduce 145) ((T_VARIABLE) reduce 145) ((T_WHILE) reduce 145) ((T_YIELD) reduce 145) ((T_YIELD_FROM) reduce 145) (("[") reduce 145) (("`") reduce 145) (("{") reduce 145) (("}") reduce 145) (("~") reduce 145)) 16652 ((("!") reduce 244) (("\"") reduce 244) (("$") reduce 244) (("(") reduce 244) (("+") reduce 244) (("-") reduce 244) ((";") reduce 244) (("@") reduce 244) ((T_ABSTRACT) reduce 244) ((T_ARRAY) reduce 244) ((T_ARRAY_CAST) reduce 244) ((T_ATTRIBUTE) reduce 244) ((T_BOOL_CAST) reduce 244) ((T_BREAK) reduce 244) ((T_CASE) reduce 244) ((T_CLASS) reduce 244) ((T_CLASS_C) reduce 244) ((T_CLONE) reduce 244) ((T_CONSTANT_ENCAPSED_STRING) reduce 244) ((T_CONTINUE) reduce 244) ((T_DEC) reduce 244) ((T_DECLARE) reduce 244) ((T_DEFAULT) reduce 244) ((T_DIR) reduce 244) ((T_DNUMBER) reduce 244) ((T_DO) reduce 244) ((T_DOUBLE_CAST) reduce 244) ((T_ECHO) reduce 244) ((T_ELSE) reduce 244) ((T_ELSEIF) reduce 244) ((T_EMPTY) reduce 244) ((T_ENUM) reduce 244) ((T_EVAL) reduce 244) ((T_EXIT) reduce 244) ((T_FILE) reduce 244) ((T_FINAL) reduce 244) ((T_FN) reduce 244) ((T_FOR) reduce 244) ((T_FOREACH) reduce 244) ((T_FUNCTION) reduce 244) ((T_FUNC_C) reduce 244) ((T_GLOBAL) reduce 244) ((T_GOTO) reduce 244) ((T_HALT_COMPILER) reduce 244) ((T_IF) reduce 244) ((T_INC) reduce 244) ((T_INCLUDE) reduce 244) ((T_INCLUDE_ONCE) reduce 244) ((T_INLINE_HTML) reduce 244) ((T_INTERFACE) reduce 244) ((T_INT_CAST) reduce 244) ((T_ISSET) reduce 244) ((T_LINE) reduce 244) ((T_LIST) reduce 244) ((T_LNUMBER) reduce 244) ((T_MATCH) reduce 244) ((T_METHOD_C) reduce 244) ((T_NAME_FULLY_QUALIFIED) reduce 244) ((T_NAME_QUALIFIED) reduce 244) ((T_NAME_RELATIVE) reduce 244) ((T_NEW) reduce 244) ((T_NS_C) reduce 244) ((T_OBJECT_CAST) reduce 244) ((T_PRINT) reduce 244) ((T_READONLY) reduce 244) ((T_REQUIRE) reduce 244) ((T_REQUIRE_ONCE) reduce 244) ((T_RETURN) reduce 244) ((T_START_HEREDOC) reduce 244) ((T_STATIC) reduce 244) ((T_STRING) reduce 244) ((T_STRING_CAST) reduce 244) ((T_SWITCH) reduce 244) ((T_THROW) reduce 244) ((T_TRAIT) reduce 244) ((T_TRAIT_C) reduce 244) ((T_TRY) reduce 244) ((T_UNSET) reduce 244) ((T_UNSET_CAST) reduce 244) ((T_VARIABLE) reduce 244) ((T_WHILE) reduce 244) ((T_YIELD) reduce 244) ((T_YIELD_FROM) reduce 244) (("[") reduce 244) (("`") reduce 244) (("{") reduce 244) (("}") reduce 244) (("~") reduce 244)) 16653 ((("!") reduce 159) (("\"") reduce 159) (("$") reduce 159) (("(") reduce 159) (("+") reduce 159) (("-") reduce 159) ((";") reduce 159) (("@") reduce 159) ((T_ABSTRACT) reduce 159) ((T_ARRAY) reduce 159) ((T_ARRAY_CAST) reduce 159) ((T_ATTRIBUTE) reduce 159) ((T_BOOL_CAST) reduce 159) ((T_BREAK) reduce 159) ((T_CASE) reduce 159) ((T_CLASS) reduce 159) ((T_CLASS_C) reduce 159) ((T_CLONE) reduce 159) ((T_CONSTANT_ENCAPSED_STRING) reduce 159) ((T_CONTINUE) reduce 159) ((T_DEC) reduce 159) ((T_DECLARE) reduce 159) ((T_DEFAULT) reduce 159) ((T_DIR) reduce 159) ((T_DNUMBER) reduce 159) ((T_DO) reduce 159) ((T_DOUBLE_CAST) reduce 159) ((T_ECHO) reduce 159) ((T_ELSE) reduce 159) ((T_ELSEIF) reduce 159) ((T_EMPTY) reduce 159) ((T_ENUM) reduce 159) ((T_EVAL) reduce 159) ((T_EXIT) reduce 159) ((T_FILE) reduce 159) ((T_FINAL) reduce 159) ((T_FN) reduce 159) ((T_FOR) reduce 159) ((T_FOREACH) reduce 159) ((T_FUNCTION) reduce 159) ((T_FUNC_C) reduce 159) ((T_GLOBAL) reduce 159) ((T_GOTO) reduce 159) ((T_HALT_COMPILER) reduce 159) ((T_IF) reduce 159) ((T_INC) reduce 159) ((T_INCLUDE) reduce 159) ((T_INCLUDE_ONCE) reduce 159) ((T_INLINE_HTML) reduce 159) ((T_INTERFACE) reduce 159) ((T_INT_CAST) reduce 159) ((T_ISSET) reduce 159) ((T_LINE) reduce 159) ((T_LIST) reduce 159) ((T_LNUMBER) reduce 159) ((T_MATCH) reduce 159) ((T_METHOD_C) reduce 159) ((T_NAME_FULLY_QUALIFIED) reduce 159) ((T_NAME_QUALIFIED) reduce 159) ((T_NAME_RELATIVE) reduce 159) ((T_NEW) reduce 159) ((T_NS_C) reduce 159) ((T_OBJECT_CAST) reduce 159) ((T_PRINT) reduce 159) ((T_READONLY) reduce 159) ((T_REQUIRE) reduce 159) ((T_REQUIRE_ONCE) reduce 159) ((T_RETURN) reduce 159) ((T_START_HEREDOC) reduce 159) ((T_STATIC) reduce 159) ((T_STRING) reduce 159) ((T_STRING_CAST) reduce 159) ((T_SWITCH) reduce 159) ((T_THROW) reduce 159) ((T_TRAIT) reduce 159) ((T_TRAIT_C) reduce 159) ((T_TRY) reduce 159) ((T_UNSET) reduce 159) ((T_UNSET_CAST) reduce 159) ((T_VARIABLE) reduce 159) ((T_WHILE) reduce 159) ((T_YIELD) reduce 159) ((T_YIELD_FROM) reduce 159) (("[") reduce 159) (("`") reduce 159) (("{") reduce 159) (("}") reduce 159) (("~") reduce 159)) 16656 ((("!") reduce 247) (("\"") reduce 247) (("$") reduce 247) (("(") reduce 247) (("+") reduce 247) (("-") reduce 247) ((";") reduce 247) (("@") reduce 247) ((T_ABSTRACT) reduce 247) ((T_ARRAY) reduce 247) ((T_ARRAY_CAST) reduce 247) ((T_ATTRIBUTE) reduce 247) ((T_BOOL_CAST) reduce 247) ((T_BREAK) reduce 247) ((T_CASE) reduce 247) ((T_CLASS) reduce 247) ((T_CLASS_C) reduce 247) ((T_CLONE) reduce 247) ((T_CONSTANT_ENCAPSED_STRING) reduce 247) ((T_CONTINUE) reduce 247) ((T_DEC) reduce 247) ((T_DECLARE) reduce 247) ((T_DEFAULT) reduce 247) ((T_DIR) reduce 247) ((T_DNUMBER) reduce 247) ((T_DO) reduce 247) ((T_DOUBLE_CAST) reduce 247) ((T_ECHO) reduce 247) ((T_ELSE) reduce 247) ((T_ELSEIF) reduce 247) ((T_EMPTY) reduce 247) ((T_ENUM) reduce 247) ((T_EVAL) reduce 247) ((T_EXIT) reduce 247) ((T_FILE) reduce 247) ((T_FINAL) reduce 247) ((T_FN) reduce 247) ((T_FOR) reduce 247) ((T_FOREACH) reduce 247) ((T_FUNCTION) reduce 247) ((T_FUNC_C) reduce 247) ((T_GLOBAL) reduce 247) ((T_GOTO) reduce 247) ((T_HALT_COMPILER) reduce 247) ((T_IF) reduce 247) ((T_INC) reduce 247) ((T_INCLUDE) reduce 247) ((T_INCLUDE_ONCE) reduce 247) ((T_INLINE_HTML) reduce 247) ((T_INTERFACE) reduce 247) ((T_INT_CAST) reduce 247) ((T_ISSET) reduce 247) ((T_LINE) reduce 247) ((T_LIST) reduce 247) ((T_LNUMBER) reduce 247) ((T_MATCH) reduce 247) ((T_METHOD_C) reduce 247) ((T_NAME_FULLY_QUALIFIED) reduce 247) ((T_NAME_QUALIFIED) reduce 247) ((T_NAME_RELATIVE) reduce 247) ((T_NEW) reduce 247) ((T_NS_C) reduce 247) ((T_OBJECT_CAST) reduce 247) ((T_PRINT) reduce 247) ((T_READONLY) reduce 247) ((T_REQUIRE) reduce 247) ((T_REQUIRE_ONCE) reduce 247) ((T_RETURN) reduce 247) ((T_START_HEREDOC) reduce 247) ((T_STATIC) reduce 247) ((T_STRING) reduce 247) ((T_STRING_CAST) reduce 247) ((T_SWITCH) reduce 247) ((T_THROW) reduce 247) ((T_TRAIT) reduce 247) ((T_TRAIT_C) reduce 247) ((T_TRY) reduce 247) ((T_UNSET) reduce 247) ((T_UNSET_CAST) reduce 247) ((T_VARIABLE) reduce 247) ((T_WHILE) reduce 247) ((T_YIELD) reduce 247) ((T_YIELD_FROM) reduce 247) (("[") reduce 247) (("`") reduce 247) (("{") reduce 247) (("}") reduce 247) (("~") reduce 247)) 16660 ((("!") reduce 248) (("\"") reduce 248) (("$") reduce 248) (("(") reduce 248) (("+") reduce 248) (("-") reduce 248) ((";") reduce 248) (("@") reduce 248) ((T_ABSTRACT) reduce 248) ((T_ARRAY) reduce 248) ((T_ARRAY_CAST) reduce 248) ((T_ATTRIBUTE) reduce 248) ((T_BOOL_CAST) reduce 248) ((T_BREAK) reduce 248) ((T_CASE) reduce 248) ((T_CLASS) reduce 248) ((T_CLASS_C) reduce 248) ((T_CLONE) reduce 248) ((T_CONSTANT_ENCAPSED_STRING) reduce 248) ((T_CONTINUE) reduce 248) ((T_DEC) reduce 248) ((T_DECLARE) reduce 248) ((T_DEFAULT) reduce 248) ((T_DIR) reduce 248) ((T_DNUMBER) reduce 248) ((T_DO) reduce 248) ((T_DOUBLE_CAST) reduce 248) ((T_ECHO) reduce 248) ((T_ELSE) reduce 248) ((T_ELSEIF) reduce 248) ((T_EMPTY) reduce 248) ((T_ENUM) reduce 248) ((T_EVAL) reduce 248) ((T_EXIT) reduce 248) ((T_FILE) reduce 248) ((T_FINAL) reduce 248) ((T_FN) reduce 248) ((T_FOR) reduce 248) ((T_FOREACH) reduce 248) ((T_FUNCTION) reduce 248) ((T_FUNC_C) reduce 248) ((T_GLOBAL) reduce 248) ((T_GOTO) reduce 248) ((T_HALT_COMPILER) reduce 248) ((T_IF) reduce 248) ((T_INC) reduce 248) ((T_INCLUDE) reduce 248) ((T_INCLUDE_ONCE) reduce 248) ((T_INLINE_HTML) reduce 248) ((T_INTERFACE) reduce 248) ((T_INT_CAST) reduce 248) ((T_ISSET) reduce 248) ((T_LINE) reduce 248) ((T_LIST) reduce 248) ((T_LNUMBER) reduce 248) ((T_MATCH) reduce 248) ((T_METHOD_C) reduce 248) ((T_NAME_FULLY_QUALIFIED) reduce 248) ((T_NAME_QUALIFIED) reduce 248) ((T_NAME_RELATIVE) reduce 248) ((T_NEW) reduce 248) ((T_NS_C) reduce 248) ((T_OBJECT_CAST) reduce 248) ((T_PRINT) reduce 248) ((T_READONLY) reduce 248) ((T_REQUIRE) reduce 248) ((T_REQUIRE_ONCE) reduce 248) ((T_RETURN) reduce 248) ((T_START_HEREDOC) reduce 248) ((T_STATIC) reduce 248) ((T_STRING) reduce 248) ((T_STRING_CAST) reduce 248) ((T_SWITCH) reduce 248) ((T_THROW) reduce 248) ((T_TRAIT) reduce 248) ((T_TRAIT_C) reduce 248) ((T_TRY) reduce 248) ((T_UNSET) reduce 248) ((T_UNSET_CAST) reduce 248) ((T_VARIABLE) reduce 248) ((T_WHILE) reduce 248) ((T_YIELD) reduce 248) ((T_YIELD_FROM) reduce 248) (("[") reduce 248) (("`") reduce 248) (("{") reduce 248) (("}") reduce 248) (("~") reduce 248)) 16665 ((("!") reduce 239) (("\"") reduce 239) (("$") reduce 239) (("(") reduce 239) (("+") reduce 239) (("-") reduce 239) ((";") reduce 239) (("@") reduce 239) ((T_ABSTRACT) reduce 239) ((T_ARRAY) reduce 239) ((T_ARRAY_CAST) reduce 239) ((T_ATTRIBUTE) reduce 239) ((T_BOOL_CAST) reduce 239) ((T_BREAK) reduce 239) ((T_CASE) reduce 239) ((T_CLASS) reduce 239) ((T_CLASS_C) reduce 239) ((T_CLONE) reduce 239) ((T_CONSTANT_ENCAPSED_STRING) reduce 239) ((T_CONTINUE) reduce 239) ((T_DEC) reduce 239) ((T_DECLARE) reduce 239) ((T_DEFAULT) reduce 239) ((T_DIR) reduce 239) ((T_DNUMBER) reduce 239) ((T_DO) reduce 239) ((T_DOUBLE_CAST) reduce 239) ((T_ECHO) reduce 239) ((T_ELSE) reduce 239) ((T_ELSEIF) reduce 239) ((T_EMPTY) reduce 239) ((T_ENUM) reduce 239) ((T_EVAL) reduce 239) ((T_EXIT) reduce 239) ((T_FILE) reduce 239) ((T_FINAL) reduce 239) ((T_FN) reduce 239) ((T_FOR) reduce 239) ((T_FOREACH) reduce 239) ((T_FUNCTION) reduce 239) ((T_FUNC_C) reduce 239) ((T_GLOBAL) reduce 239) ((T_GOTO) reduce 239) ((T_HALT_COMPILER) reduce 239) ((T_IF) reduce 239) ((T_INC) reduce 239) ((T_INCLUDE) reduce 239) ((T_INCLUDE_ONCE) reduce 239) ((T_INLINE_HTML) reduce 239) ((T_INTERFACE) reduce 239) ((T_INT_CAST) reduce 239) ((T_ISSET) reduce 239) ((T_LINE) reduce 239) ((T_LIST) reduce 239) ((T_LNUMBER) reduce 239) ((T_MATCH) reduce 239) ((T_METHOD_C) reduce 239) ((T_NAME_FULLY_QUALIFIED) reduce 239) ((T_NAME_QUALIFIED) reduce 239) ((T_NAME_RELATIVE) reduce 239) ((T_NEW) reduce 239) ((T_NS_C) reduce 239) ((T_OBJECT_CAST) reduce 239) ((T_PRINT) reduce 239) ((T_READONLY) reduce 239) ((T_REQUIRE) reduce 239) ((T_REQUIRE_ONCE) reduce 239) ((T_RETURN) reduce 239) ((T_START_HEREDOC) reduce 239) ((T_STATIC) reduce 239) ((T_STRING) reduce 239) ((T_STRING_CAST) reduce 239) ((T_SWITCH) reduce 239) ((T_THROW) reduce 239) ((T_TRAIT) reduce 239) ((T_TRAIT_C) reduce 239) ((T_TRY) reduce 239) ((T_UNSET) reduce 239) ((T_UNSET_CAST) reduce 239) ((T_VARIABLE) reduce 239) ((T_WHILE) reduce 239) ((T_YIELD) reduce 239) ((T_YIELD_FROM) reduce 239) (("[") reduce 239) (("`") reduce 239) (("{") reduce 239) (("}") reduce 239) (("~") reduce 239)) 16666 ((("!") reduce 148) (("\"") reduce 148) (("$") reduce 148) (("(") reduce 148) (("+") reduce 148) (("-") reduce 148) ((";") reduce 148) (("@") reduce 148) ((T_ABSTRACT) reduce 148) ((T_ARRAY) reduce 148) ((T_ARRAY_CAST) reduce 148) ((T_ATTRIBUTE) reduce 148) ((T_BOOL_CAST) reduce 148) ((T_BREAK) reduce 148) ((T_CASE) reduce 148) ((T_CLASS) reduce 148) ((T_CLASS_C) reduce 148) ((T_CLONE) reduce 148) ((T_CONSTANT_ENCAPSED_STRING) reduce 148) ((T_CONTINUE) reduce 148) ((T_DEC) reduce 148) ((T_DECLARE) reduce 148) ((T_DEFAULT) reduce 148) ((T_DIR) reduce 148) ((T_DNUMBER) reduce 148) ((T_DO) reduce 148) ((T_DOUBLE_CAST) reduce 148) ((T_ECHO) reduce 148) ((T_ELSE) reduce 148) ((T_ELSEIF) reduce 148) ((T_EMPTY) reduce 148) ((T_ENUM) reduce 148) ((T_EVAL) reduce 148) ((T_EXIT) reduce 148) ((T_FILE) reduce 148) ((T_FINAL) reduce 148) ((T_FN) reduce 148) ((T_FOR) reduce 148) ((T_FOREACH) reduce 148) ((T_FUNCTION) reduce 148) ((T_FUNC_C) reduce 148) ((T_GLOBAL) reduce 148) ((T_GOTO) reduce 148) ((T_HALT_COMPILER) reduce 148) ((T_IF) reduce 148) ((T_INC) reduce 148) ((T_INCLUDE) reduce 148) ((T_INCLUDE_ONCE) reduce 148) ((T_INLINE_HTML) reduce 148) ((T_INTERFACE) reduce 148) ((T_INT_CAST) reduce 148) ((T_ISSET) reduce 148) ((T_LINE) reduce 148) ((T_LIST) reduce 148) ((T_LNUMBER) reduce 148) ((T_MATCH) reduce 148) ((T_METHOD_C) reduce 148) ((T_NAME_FULLY_QUALIFIED) reduce 148) ((T_NAME_QUALIFIED) reduce 148) ((T_NAME_RELATIVE) reduce 148) ((T_NEW) reduce 148) ((T_NS_C) reduce 148) ((T_OBJECT_CAST) reduce 148) ((T_PRINT) reduce 148) ((T_READONLY) reduce 148) ((T_REQUIRE) reduce 148) ((T_REQUIRE_ONCE) reduce 148) ((T_RETURN) reduce 148) ((T_START_HEREDOC) reduce 148) ((T_STATIC) reduce 148) ((T_STRING) reduce 148) ((T_STRING_CAST) reduce 148) ((T_SWITCH) reduce 148) ((T_THROW) reduce 148) ((T_TRAIT) reduce 148) ((T_TRAIT_C) reduce 148) ((T_TRY) reduce 148) ((T_UNSET) reduce 148) ((T_UNSET_CAST) reduce 148) ((T_VARIABLE) reduce 148) ((T_WHILE) reduce 148) ((T_YIELD) reduce 148) ((T_YIELD_FROM) reduce 148) (("[") reduce 148) (("`") reduce 148) (("{") reduce 148) (("}") reduce 148) (("~") reduce 148)) 16669 ((("!") reduce 240) (("\"") reduce 240) (("$") reduce 240) (("(") reduce 240) (("+") reduce 240) (("-") reduce 240) ((";") reduce 240) (("@") reduce 240) ((T_ABSTRACT) reduce 240) ((T_ARRAY) reduce 240) ((T_ARRAY_CAST) reduce 240) ((T_ATTRIBUTE) reduce 240) ((T_BOOL_CAST) reduce 240) ((T_BREAK) reduce 240) ((T_CASE) reduce 240) ((T_CLASS) reduce 240) ((T_CLASS_C) reduce 240) ((T_CLONE) reduce 240) ((T_CONSTANT_ENCAPSED_STRING) reduce 240) ((T_CONTINUE) reduce 240) ((T_DEC) reduce 240) ((T_DECLARE) reduce 240) ((T_DEFAULT) reduce 240) ((T_DIR) reduce 240) ((T_DNUMBER) reduce 240) ((T_DO) reduce 240) ((T_DOUBLE_CAST) reduce 240) ((T_ECHO) reduce 240) ((T_ELSE) reduce 240) ((T_ELSEIF) reduce 240) ((T_EMPTY) reduce 240) ((T_ENUM) reduce 240) ((T_EVAL) reduce 240) ((T_EXIT) reduce 240) ((T_FILE) reduce 240) ((T_FINAL) reduce 240) ((T_FN) reduce 240) ((T_FOR) reduce 240) ((T_FOREACH) reduce 240) ((T_FUNCTION) reduce 240) ((T_FUNC_C) reduce 240) ((T_GLOBAL) reduce 240) ((T_GOTO) reduce 240) ((T_HALT_COMPILER) reduce 240) ((T_IF) reduce 240) ((T_INC) reduce 240) ((T_INCLUDE) reduce 240) ((T_INCLUDE_ONCE) reduce 240) ((T_INLINE_HTML) reduce 240) ((T_INTERFACE) reduce 240) ((T_INT_CAST) reduce 240) ((T_ISSET) reduce 240) ((T_LINE) reduce 240) ((T_LIST) reduce 240) ((T_LNUMBER) reduce 240) ((T_MATCH) reduce 240) ((T_METHOD_C) reduce 240) ((T_NAME_FULLY_QUALIFIED) reduce 240) ((T_NAME_QUALIFIED) reduce 240) ((T_NAME_RELATIVE) reduce 240) ((T_NEW) reduce 240) ((T_NS_C) reduce 240) ((T_OBJECT_CAST) reduce 240) ((T_PRINT) reduce 240) ((T_READONLY) reduce 240) ((T_REQUIRE) reduce 240) ((T_REQUIRE_ONCE) reduce 240) ((T_RETURN) reduce 240) ((T_START_HEREDOC) reduce 240) ((T_STATIC) reduce 240) ((T_STRING) reduce 240) ((T_STRING_CAST) reduce 240) ((T_SWITCH) reduce 240) ((T_THROW) reduce 240) ((T_TRAIT) reduce 240) ((T_TRAIT_C) reduce 240) ((T_TRY) reduce 240) ((T_UNSET) reduce 240) ((T_UNSET_CAST) reduce 240) ((T_VARIABLE) reduce 240) ((T_WHILE) reduce 240) ((T_YIELD) reduce 240) ((T_YIELD_FROM) reduce 240) (("[") reduce 240) (("`") reduce 240) (("{") reduce 240) (("}") reduce 240) (("~") reduce 240)) 16674 ((("!") reduce 160) (("\"") reduce 160) (("$") reduce 160) (("(") reduce 160) (("+") reduce 160) (("-") reduce 160) ((";") reduce 160) (("@") reduce 160) ((T_ABSTRACT) reduce 160) ((T_ARRAY) reduce 160) ((T_ARRAY_CAST) reduce 160) ((T_ATTRIBUTE) reduce 160) ((T_BOOL_CAST) reduce 160) ((T_BREAK) reduce 160) ((T_CASE) reduce 160) ((T_CLASS) reduce 160) ((T_CLASS_C) reduce 160) ((T_CLONE) reduce 160) ((T_CONSTANT_ENCAPSED_STRING) reduce 160) ((T_CONTINUE) reduce 160) ((T_DEC) reduce 160) ((T_DECLARE) reduce 160) ((T_DEFAULT) reduce 160) ((T_DIR) reduce 160) ((T_DNUMBER) reduce 160) ((T_DO) reduce 160) ((T_DOUBLE_CAST) reduce 160) ((T_ECHO) reduce 160) ((T_ELSE) reduce 160) ((T_ELSEIF) reduce 160) ((T_EMPTY) reduce 160) ((T_ENUM) reduce 160) ((T_EVAL) reduce 160) ((T_EXIT) reduce 160) ((T_FILE) reduce 160) ((T_FINAL) reduce 160) ((T_FN) reduce 160) ((T_FOR) reduce 160) ((T_FOREACH) reduce 160) ((T_FUNCTION) reduce 160) ((T_FUNC_C) reduce 160) ((T_GLOBAL) reduce 160) ((T_GOTO) reduce 160) ((T_HALT_COMPILER) reduce 160) ((T_IF) reduce 160) ((T_INC) reduce 160) ((T_INCLUDE) reduce 160) ((T_INCLUDE_ONCE) reduce 160) ((T_INLINE_HTML) reduce 160) ((T_INTERFACE) reduce 160) ((T_INT_CAST) reduce 160) ((T_ISSET) reduce 160) ((T_LINE) reduce 160) ((T_LIST) reduce 160) ((T_LNUMBER) reduce 160) ((T_MATCH) reduce 160) ((T_METHOD_C) reduce 160) ((T_NAME_FULLY_QUALIFIED) reduce 160) ((T_NAME_QUALIFIED) reduce 160) ((T_NAME_RELATIVE) reduce 160) ((T_NEW) reduce 160) ((T_NS_C) reduce 160) ((T_OBJECT_CAST) reduce 160) ((T_PRINT) reduce 160) ((T_READONLY) reduce 160) ((T_REQUIRE) reduce 160) ((T_REQUIRE_ONCE) reduce 160) ((T_RETURN) reduce 160) ((T_START_HEREDOC) reduce 160) ((T_STATIC) reduce 160) ((T_STRING) reduce 160) ((T_STRING_CAST) reduce 160) ((T_SWITCH) reduce 160) ((T_THROW) reduce 160) ((T_TRAIT) reduce 160) ((T_TRAIT_C) reduce 160) ((T_TRY) reduce 160) ((T_UNSET) reduce 160) ((T_UNSET_CAST) reduce 160) ((T_VARIABLE) reduce 160) ((T_WHILE) reduce 160) ((T_YIELD) reduce 160) ((T_YIELD_FROM) reduce 160) (("[") reduce 160) (("`") reduce 160) (("{") reduce 160) (("}") reduce 160) (("~") reduce 160)) 16677 ((("!") reduce 168) (("\"") reduce 168) (("$") reduce 168) (("(") reduce 168) (("+") reduce 168) (("-") reduce 168) ((";") reduce 168) (("@") reduce 168) ((T_ABSTRACT) reduce 168) ((T_ARRAY) reduce 168) ((T_ARRAY_CAST) reduce 168) ((T_ATTRIBUTE) reduce 168) ((T_BOOL_CAST) reduce 168) ((T_BREAK) reduce 168) ((T_CASE) reduce 168) ((T_CATCH) reduce 168) ((T_CLASS) reduce 168) ((T_CLASS_C) reduce 168) ((T_CLONE) reduce 168) ((T_CONSTANT_ENCAPSED_STRING) reduce 168) ((T_CONTINUE) reduce 168) ((T_DEC) reduce 168) ((T_DECLARE) reduce 168) ((T_DEFAULT) reduce 168) ((T_DIR) reduce 168) ((T_DNUMBER) reduce 168) ((T_DO) reduce 168) ((T_DOUBLE_CAST) reduce 168) ((T_ECHO) reduce 168) ((T_ELSE) reduce 168) ((T_ELSEIF) reduce 168) ((T_EMPTY) reduce 168) ((T_ENUM) reduce 168) ((T_EVAL) reduce 168) ((T_EXIT) reduce 168) ((T_FILE) reduce 168) ((T_FINAL) reduce 168) ((T_FINALLY) reduce 168) ((T_FN) reduce 168) ((T_FOR) reduce 168) ((T_FOREACH) reduce 168) ((T_FUNCTION) reduce 168) ((T_FUNC_C) reduce 168) ((T_GLOBAL) reduce 168) ((T_GOTO) reduce 168) ((T_HALT_COMPILER) reduce 168) ((T_IF) reduce 168) ((T_INC) reduce 168) ((T_INCLUDE) reduce 168) ((T_INCLUDE_ONCE) reduce 168) ((T_INLINE_HTML) reduce 168) ((T_INTERFACE) reduce 168) ((T_INT_CAST) reduce 168) ((T_ISSET) reduce 168) ((T_LINE) reduce 168) ((T_LIST) reduce 168) ((T_LNUMBER) reduce 168) ((T_MATCH) reduce 168) ((T_METHOD_C) reduce 168) ((T_NAME_FULLY_QUALIFIED) reduce 168) ((T_NAME_QUALIFIED) reduce 168) ((T_NAME_RELATIVE) reduce 168) ((T_NEW) reduce 168) ((T_NS_C) reduce 168) ((T_OBJECT_CAST) reduce 168) ((T_PRINT) reduce 168) ((T_READONLY) reduce 168) ((T_REQUIRE) reduce 168) ((T_REQUIRE_ONCE) reduce 168) ((T_RETURN) reduce 168) ((T_START_HEREDOC) reduce 168) ((T_STATIC) reduce 168) ((T_STRING) reduce 168) ((T_STRING_CAST) reduce 168) ((T_SWITCH) reduce 168) ((T_THROW) reduce 168) ((T_TRAIT) reduce 168) ((T_TRAIT_C) reduce 168) ((T_TRY) reduce 168) ((T_UNSET) reduce 168) ((T_UNSET_CAST) reduce 168) ((T_VARIABLE) reduce 168) ((T_WHILE) reduce 168) ((T_YIELD) reduce 168) ((T_YIELD_FROM) reduce 168) (("[") reduce 168) (("`") reduce 168) (("{") reduce 168) (("}") reduce 168) (("~") reduce 168)) 16678 ((("!") reduce 174) (("\"") reduce 174) (("$") reduce 174) (("(") reduce 174) (("+") reduce 174) (("-") reduce 174) ((";") reduce 174) (("@") reduce 174) ((T_ABSTRACT) reduce 174) ((T_ARRAY) reduce 174) ((T_ARRAY_CAST) reduce 174) ((T_ATTRIBUTE) reduce 174) ((T_BOOL_CAST) reduce 174) ((T_BREAK) reduce 174) ((T_CASE) reduce 174) ((T_CATCH) shift) ((T_CLASS) reduce 174) ((T_CLASS_C) reduce 174) ((T_CLONE) reduce 174) ((T_CONSTANT_ENCAPSED_STRING) reduce 174) ((T_CONTINUE) reduce 174) ((T_DEC) reduce 174) ((T_DECLARE) reduce 174) ((T_DEFAULT) reduce 174) ((T_DIR) reduce 174) ((T_DNUMBER) reduce 174) ((T_DO) reduce 174) ((T_DOUBLE_CAST) reduce 174) ((T_ECHO) reduce 174) ((T_ELSE) reduce 174) ((T_ELSEIF) reduce 174) ((T_EMPTY) reduce 174) ((T_ENUM) reduce 174) ((T_EVAL) reduce 174) ((T_EXIT) reduce 174) ((T_FILE) reduce 174) ((T_FINAL) reduce 174) ((T_FINALLY) shift) ((T_FN) reduce 174) ((T_FOR) reduce 174) ((T_FOREACH) reduce 174) ((T_FUNCTION) reduce 174) ((T_FUNC_C) reduce 174) ((T_GLOBAL) reduce 174) ((T_GOTO) reduce 174) ((T_HALT_COMPILER) reduce 174) ((T_IF) reduce 174) ((T_INC) reduce 174) ((T_INCLUDE) reduce 174) ((T_INCLUDE_ONCE) reduce 174) ((T_INLINE_HTML) reduce 174) ((T_INTERFACE) reduce 174) ((T_INT_CAST) reduce 174) ((T_ISSET) reduce 174) ((T_LINE) reduce 174) ((T_LIST) reduce 174) ((T_LNUMBER) reduce 174) ((T_MATCH) reduce 174) ((T_METHOD_C) reduce 174) ((T_NAME_FULLY_QUALIFIED) reduce 174) ((T_NAME_QUALIFIED) reduce 174) ((T_NAME_RELATIVE) reduce 174) ((T_NEW) reduce 174) ((T_NS_C) reduce 174) ((T_OBJECT_CAST) reduce 174) ((T_PRINT) reduce 174) ((T_READONLY) reduce 174) ((T_REQUIRE) reduce 174) ((T_REQUIRE_ONCE) reduce 174) ((T_RETURN) reduce 174) ((T_START_HEREDOC) reduce 174) ((T_STATIC) reduce 174) ((T_STRING) reduce 174) ((T_STRING_CAST) reduce 174) ((T_SWITCH) reduce 174) ((T_THROW) reduce 174) ((T_TRAIT) reduce 174) ((T_TRAIT_C) reduce 174) ((T_TRY) reduce 174) ((T_UNSET) reduce 174) ((T_UNSET_CAST) reduce 174) ((T_VARIABLE) reduce 174) ((T_WHILE) reduce 174) ((T_YIELD) reduce 174) ((T_YIELD_FROM) reduce 174) (("[") reduce 174) (("`") reduce 174) (("{") reduce 174) (("}") reduce 174) (("~") reduce 174)) 16681 ((("!") reduce 165) (("\"") reduce 165) (("$") reduce 165) (("(") reduce 165) (("+") reduce 165) (("-") reduce 165) ((";") reduce 165) (("@") reduce 165) ((T_ABSTRACT) reduce 165) ((T_ARRAY) reduce 165) ((T_ARRAY_CAST) reduce 165) ((T_ATTRIBUTE) reduce 165) ((T_BOOL_CAST) reduce 165) ((T_BREAK) reduce 165) ((T_CASE) reduce 165) ((T_CLASS) reduce 165) ((T_CLASS_C) reduce 165) ((T_CLONE) reduce 165) ((T_CONSTANT_ENCAPSED_STRING) reduce 165) ((T_CONTINUE) reduce 165) ((T_DEC) reduce 165) ((T_DECLARE) reduce 165) ((T_DEFAULT) reduce 165) ((T_DIR) reduce 165) ((T_DNUMBER) reduce 165) ((T_DO) reduce 165) ((T_DOUBLE_CAST) reduce 165) ((T_ECHO) reduce 165) ((T_ELSE) reduce 165) ((T_ELSEIF) reduce 165) ((T_EMPTY) reduce 165) ((T_ENUM) reduce 165) ((T_EVAL) reduce 165) ((T_EXIT) reduce 165) ((T_FILE) reduce 165) ((T_FINAL) reduce 165) ((T_FN) reduce 165) ((T_FOR) reduce 165) ((T_FOREACH) reduce 165) ((T_FUNCTION) reduce 165) ((T_FUNC_C) reduce 165) ((T_GLOBAL) reduce 165) ((T_GOTO) reduce 165) ((T_HALT_COMPILER) reduce 165) ((T_IF) reduce 165) ((T_INC) reduce 165) ((T_INCLUDE) reduce 165) ((T_INCLUDE_ONCE) reduce 165) ((T_INLINE_HTML) reduce 165) ((T_INTERFACE) reduce 165) ((T_INT_CAST) reduce 165) ((T_ISSET) reduce 165) ((T_LINE) reduce 165) ((T_LIST) reduce 165) ((T_LNUMBER) reduce 165) ((T_MATCH) reduce 165) ((T_METHOD_C) reduce 165) ((T_NAME_FULLY_QUALIFIED) reduce 165) ((T_NAME_QUALIFIED) reduce 165) ((T_NAME_RELATIVE) reduce 165) ((T_NEW) reduce 165) ((T_NS_C) reduce 165) ((T_OBJECT_CAST) reduce 165) ((T_PRINT) reduce 165) ((T_READONLY) reduce 165) ((T_REQUIRE) reduce 165) ((T_REQUIRE_ONCE) reduce 165) ((T_RETURN) reduce 165) ((T_START_HEREDOC) reduce 165) ((T_STATIC) reduce 165) ((T_STRING) reduce 165) ((T_STRING_CAST) reduce 165) ((T_SWITCH) reduce 165) ((T_THROW) reduce 165) ((T_TRAIT) reduce 165) ((T_TRAIT_C) reduce 165) ((T_TRY) reduce 165) ((T_UNSET) reduce 165) ((T_UNSET_CAST) reduce 165) ((T_VARIABLE) reduce 165) ((T_WHILE) reduce 165) ((T_YIELD) reduce 165) ((T_YIELD_FROM) reduce 165) (("[") reduce 165) (("`") reduce 165) (("{") reduce 165) (("}") reduce 165) (("~") reduce 165)) 16684 ((("!") reduce 175) (("\"") reduce 175) (("$") reduce 175) (("(") reduce 175) (("+") reduce 175) (("-") reduce 175) ((";") reduce 175) (("@") reduce 175) ((T_ABSTRACT) reduce 175) ((T_ARRAY) reduce 175) ((T_ARRAY_CAST) reduce 175) ((T_ATTRIBUTE) reduce 175) ((T_BOOL_CAST) reduce 175) ((T_BREAK) reduce 175) ((T_CASE) reduce 175) ((T_CLASS) reduce 175) ((T_CLASS_C) reduce 175) ((T_CLONE) reduce 175) ((T_CONSTANT_ENCAPSED_STRING) reduce 175) ((T_CONTINUE) reduce 175) ((T_DEC) reduce 175) ((T_DECLARE) reduce 175) ((T_DEFAULT) reduce 175) ((T_DIR) reduce 175) ((T_DNUMBER) reduce 175) ((T_DO) reduce 175) ((T_DOUBLE_CAST) reduce 175) ((T_ECHO) reduce 175) ((T_ELSE) reduce 175) ((T_ELSEIF) reduce 175) ((T_EMPTY) reduce 175) ((T_ENUM) reduce 175) ((T_EVAL) reduce 175) ((T_EXIT) reduce 175) ((T_FILE) reduce 175) ((T_FINAL) reduce 175) ((T_FN) reduce 175) ((T_FOR) reduce 175) ((T_FOREACH) reduce 175) ((T_FUNCTION) reduce 175) ((T_FUNC_C) reduce 175) ((T_GLOBAL) reduce 175) ((T_GOTO) reduce 175) ((T_HALT_COMPILER) reduce 175) ((T_IF) reduce 175) ((T_INC) reduce 175) ((T_INCLUDE) reduce 175) ((T_INCLUDE_ONCE) reduce 175) ((T_INLINE_HTML) reduce 175) ((T_INTERFACE) reduce 175) ((T_INT_CAST) reduce 175) ((T_ISSET) reduce 175) ((T_LINE) reduce 175) ((T_LIST) reduce 175) ((T_LNUMBER) reduce 175) ((T_MATCH) reduce 175) ((T_METHOD_C) reduce 175) ((T_NAME_FULLY_QUALIFIED) reduce 175) ((T_NAME_QUALIFIED) reduce 175) ((T_NAME_RELATIVE) reduce 175) ((T_NEW) reduce 175) ((T_NS_C) reduce 175) ((T_OBJECT_CAST) reduce 175) ((T_PRINT) reduce 175) ((T_READONLY) reduce 175) ((T_REQUIRE) reduce 175) ((T_REQUIRE_ONCE) reduce 175) ((T_RETURN) reduce 175) ((T_START_HEREDOC) reduce 175) ((T_STATIC) reduce 175) ((T_STRING) reduce 175) ((T_STRING_CAST) reduce 175) ((T_SWITCH) reduce 175) ((T_THROW) reduce 175) ((T_TRAIT) reduce 175) ((T_TRAIT_C) reduce 175) ((T_TRY) reduce 175) ((T_UNSET) reduce 175) ((T_UNSET_CAST) reduce 175) ((T_VARIABLE) reduce 175) ((T_WHILE) reduce 175) ((T_YIELD) reduce 175) ((T_YIELD_FROM) reduce 175) (("[") reduce 175) (("`") reduce 175) (("{") reduce 175) (("}") reduce 175) (("~") reduce 175)) 16691 ((("!") reduce 169) (("\"") reduce 169) (("$") reduce 169) (("(") reduce 169) (("+") reduce 169) (("-") reduce 169) ((";") reduce 169) (("@") reduce 169) ((T_ABSTRACT) reduce 169) ((T_ARRAY) reduce 169) ((T_ARRAY_CAST) reduce 169) ((T_ATTRIBUTE) reduce 169) ((T_BOOL_CAST) reduce 169) ((T_BREAK) reduce 169) ((T_CASE) reduce 169) ((T_CATCH) reduce 169) ((T_CLASS) reduce 169) ((T_CLASS_C) reduce 169) ((T_CLONE) reduce 169) ((T_CONSTANT_ENCAPSED_STRING) reduce 169) ((T_CONTINUE) reduce 169) ((T_DEC) reduce 169) ((T_DECLARE) reduce 169) ((T_DEFAULT) reduce 169) ((T_DIR) reduce 169) ((T_DNUMBER) reduce 169) ((T_DO) reduce 169) ((T_DOUBLE_CAST) reduce 169) ((T_ECHO) reduce 169) ((T_ELSE) reduce 169) ((T_ELSEIF) reduce 169) ((T_EMPTY) reduce 169) ((T_ENUM) reduce 169) ((T_EVAL) reduce 169) ((T_EXIT) reduce 169) ((T_FILE) reduce 169) ((T_FINAL) reduce 169) ((T_FINALLY) reduce 169) ((T_FN) reduce 169) ((T_FOR) reduce 169) ((T_FOREACH) reduce 169) ((T_FUNCTION) reduce 169) ((T_FUNC_C) reduce 169) ((T_GLOBAL) reduce 169) ((T_GOTO) reduce 169) ((T_HALT_COMPILER) reduce 169) ((T_IF) reduce 169) ((T_INC) reduce 169) ((T_INCLUDE) reduce 169) ((T_INCLUDE_ONCE) reduce 169) ((T_INLINE_HTML) reduce 169) ((T_INTERFACE) reduce 169) ((T_INT_CAST) reduce 169) ((T_ISSET) reduce 169) ((T_LINE) reduce 169) ((T_LIST) reduce 169) ((T_LNUMBER) reduce 169) ((T_MATCH) reduce 169) ((T_METHOD_C) reduce 169) ((T_NAME_FULLY_QUALIFIED) reduce 169) ((T_NAME_QUALIFIED) reduce 169) ((T_NAME_RELATIVE) reduce 169) ((T_NEW) reduce 169) ((T_NS_C) reduce 169) ((T_OBJECT_CAST) reduce 169) ((T_PRINT) reduce 169) ((T_READONLY) reduce 169) ((T_REQUIRE) reduce 169) ((T_REQUIRE_ONCE) reduce 169) ((T_RETURN) reduce 169) ((T_START_HEREDOC) reduce 169) ((T_STATIC) reduce 169) ((T_STRING) reduce 169) ((T_STRING_CAST) reduce 169) ((T_SWITCH) reduce 169) ((T_THROW) reduce 169) ((T_TRAIT) reduce 169) ((T_TRAIT_C) reduce 169) ((T_TRY) reduce 169) ((T_UNSET) reduce 169) ((T_UNSET_CAST) reduce 169) ((T_VARIABLE) reduce 169) ((T_WHILE) reduce 169) ((T_YIELD) reduce 169) ((T_YIELD_FROM) reduce 169) (("[") reduce 169) (("`") reduce 169) (("{") reduce 169) (("}") reduce 169) (("~") reduce 169)) 16696 ((("!") reduce 151) (("\"") reduce 151) (("$") reduce 151) (("(") reduce 151) (("+") reduce 151) (("-") reduce 151) ((";") reduce 151) (("@") reduce 151) ((T_ABSTRACT) reduce 151) ((T_ARRAY) reduce 151) ((T_ARRAY_CAST) reduce 151) ((T_ATTRIBUTE) reduce 151) ((T_BOOL_CAST) reduce 151) ((T_BREAK) reduce 151) ((T_CASE) reduce 151) ((T_CLASS) reduce 151) ((T_CLASS_C) reduce 151) ((T_CLONE) reduce 151) ((T_CONSTANT_ENCAPSED_STRING) reduce 151) ((T_CONTINUE) reduce 151) ((T_DEC) reduce 151) ((T_DECLARE) reduce 151) ((T_DEFAULT) reduce 151) ((T_DIR) reduce 151) ((T_DNUMBER) reduce 151) ((T_DO) reduce 151) ((T_DOUBLE_CAST) reduce 151) ((T_ECHO) reduce 151) ((T_ELSE) reduce 151) ((T_ELSEIF) reduce 151) ((T_EMPTY) reduce 151) ((T_ENUM) reduce 151) ((T_EVAL) reduce 151) ((T_EXIT) reduce 151) ((T_FILE) reduce 151) ((T_FINAL) reduce 151) ((T_FN) reduce 151) ((T_FOR) reduce 151) ((T_FOREACH) reduce 151) ((T_FUNCTION) reduce 151) ((T_FUNC_C) reduce 151) ((T_GLOBAL) reduce 151) ((T_GOTO) reduce 151) ((T_HALT_COMPILER) reduce 151) ((T_IF) reduce 151) ((T_INC) reduce 151) ((T_INCLUDE) reduce 151) ((T_INCLUDE_ONCE) reduce 151) ((T_INLINE_HTML) reduce 151) ((T_INTERFACE) reduce 151) ((T_INT_CAST) reduce 151) ((T_ISSET) reduce 151) ((T_LINE) reduce 151) ((T_LIST) reduce 151) ((T_LNUMBER) reduce 151) ((T_MATCH) reduce 151) ((T_METHOD_C) reduce 151) ((T_NAME_FULLY_QUALIFIED) reduce 151) ((T_NAME_QUALIFIED) reduce 151) ((T_NAME_RELATIVE) reduce 151) ((T_NEW) reduce 151) ((T_NS_C) reduce 151) ((T_OBJECT_CAST) reduce 151) ((T_PRINT) reduce 151) ((T_READONLY) reduce 151) ((T_REQUIRE) reduce 151) ((T_REQUIRE_ONCE) reduce 151) ((T_RETURN) reduce 151) ((T_START_HEREDOC) reduce 151) ((T_STATIC) reduce 151) ((T_STRING) reduce 151) ((T_STRING_CAST) reduce 151) ((T_SWITCH) reduce 151) ((T_THROW) reduce 151) ((T_TRAIT) reduce 151) ((T_TRAIT_C) reduce 151) ((T_TRY) reduce 151) ((T_UNSET) reduce 151) ((T_UNSET_CAST) reduce 151) ((T_VARIABLE) reduce 151) ((T_WHILE) reduce 151) ((T_YIELD) reduce 151) ((T_YIELD_FROM) reduce 151) (("[") reduce 151) (("`") reduce 151) (("{") reduce 151) (("}") reduce 151) (("~") reduce 151)) 16700 ((("!") reduce 221) (("\"") reduce 221) (("$") reduce 221) (("(") reduce 221) (("+") reduce 221) (("-") reduce 221) ((";") reduce 221) (("@") reduce 221) ((T_ABSTRACT) reduce 221) ((T_ARRAY) reduce 221) ((T_ARRAY_CAST) reduce 221) ((T_ATTRIBUTE) reduce 221) ((T_BOOL_CAST) reduce 221) ((T_BREAK) reduce 221) ((T_CASE) reduce 221) ((T_CLASS) reduce 221) ((T_CLASS_C) reduce 221) ((T_CLONE) reduce 221) ((T_CONSTANT_ENCAPSED_STRING) reduce 221) ((T_CONTINUE) reduce 221) ((T_DEC) reduce 221) ((T_DECLARE) reduce 221) ((T_DEFAULT) reduce 221) ((T_DIR) reduce 221) ((T_DNUMBER) reduce 221) ((T_DO) reduce 221) ((T_DOUBLE_CAST) reduce 221) ((T_ECHO) reduce 221) ((T_ELSE) reduce 221) ((T_ELSEIF) reduce 221) ((T_EMPTY) reduce 221) ((T_ENUM) reduce 221) ((T_EVAL) reduce 221) ((T_EXIT) reduce 221) ((T_FILE) reduce 221) ((T_FINAL) reduce 221) ((T_FN) reduce 221) ((T_FOR) reduce 221) ((T_FOREACH) reduce 221) ((T_FUNCTION) reduce 221) ((T_FUNC_C) reduce 221) ((T_GLOBAL) reduce 221) ((T_GOTO) reduce 221) ((T_HALT_COMPILER) reduce 221) ((T_IF) reduce 221) ((T_INC) reduce 221) ((T_INCLUDE) reduce 221) ((T_INCLUDE_ONCE) reduce 221) ((T_INLINE_HTML) reduce 221) ((T_INTERFACE) reduce 221) ((T_INT_CAST) reduce 221) ((T_ISSET) reduce 221) ((T_LINE) reduce 221) ((T_LIST) reduce 221) ((T_LNUMBER) reduce 221) ((T_MATCH) reduce 221) ((T_METHOD_C) reduce 221) ((T_NAME_FULLY_QUALIFIED) reduce 221) ((T_NAME_QUALIFIED) reduce 221) ((T_NAME_RELATIVE) reduce 221) ((T_NEW) reduce 221) ((T_NS_C) reduce 221) ((T_OBJECT_CAST) reduce 221) ((T_PRINT) reduce 221) ((T_READONLY) reduce 221) ((T_REQUIRE) reduce 221) ((T_REQUIRE_ONCE) reduce 221) ((T_RETURN) reduce 221) ((T_START_HEREDOC) reduce 221) ((T_STATIC) reduce 221) ((T_STRING) reduce 221) ((T_STRING_CAST) reduce 221) ((T_SWITCH) reduce 221) ((T_THROW) reduce 221) ((T_TRAIT) reduce 221) ((T_TRAIT_C) reduce 221) ((T_TRY) reduce 221) ((T_UNSET) reduce 221) ((T_UNSET_CAST) reduce 221) ((T_VARIABLE) reduce 221) ((T_WHILE) reduce 221) ((T_YIELD) reduce 221) ((T_YIELD_FROM) reduce 221) (("[") reduce 221) (("`") reduce 221) (("{") reduce 221) (("}") reduce 221) (("~") reduce 221)) 16702 ((("!") reduce 222) (("\"") reduce 222) (("$") reduce 222) (("(") reduce 222) (("+") reduce 222) (("-") reduce 222) ((";") reduce 222) (("@") reduce 222) ((T_ABSTRACT) reduce 222) ((T_ARRAY) reduce 222) ((T_ARRAY_CAST) reduce 222) ((T_ATTRIBUTE) reduce 222) ((T_BOOL_CAST) reduce 222) ((T_BREAK) reduce 222) ((T_CASE) reduce 222) ((T_CLASS) reduce 222) ((T_CLASS_C) reduce 222) ((T_CLONE) reduce 222) ((T_CONSTANT_ENCAPSED_STRING) reduce 222) ((T_CONTINUE) reduce 222) ((T_DEC) reduce 222) ((T_DECLARE) reduce 222) ((T_DEFAULT) reduce 222) ((T_DIR) reduce 222) ((T_DNUMBER) reduce 222) ((T_DO) reduce 222) ((T_DOUBLE_CAST) reduce 222) ((T_ECHO) reduce 222) ((T_ELSE) reduce 222) ((T_ELSEIF) reduce 222) ((T_EMPTY) reduce 222) ((T_ENUM) reduce 222) ((T_EVAL) reduce 222) ((T_EXIT) reduce 222) ((T_FILE) reduce 222) ((T_FINAL) reduce 222) ((T_FN) reduce 222) ((T_FOR) reduce 222) ((T_FOREACH) reduce 222) ((T_FUNCTION) reduce 222) ((T_FUNC_C) reduce 222) ((T_GLOBAL) reduce 222) ((T_GOTO) reduce 222) ((T_HALT_COMPILER) reduce 222) ((T_IF) reduce 222) ((T_INC) reduce 222) ((T_INCLUDE) reduce 222) ((T_INCLUDE_ONCE) reduce 222) ((T_INLINE_HTML) reduce 222) ((T_INTERFACE) reduce 222) ((T_INT_CAST) reduce 222) ((T_ISSET) reduce 222) ((T_LINE) reduce 222) ((T_LIST) reduce 222) ((T_LNUMBER) reduce 222) ((T_MATCH) reduce 222) ((T_METHOD_C) reduce 222) ((T_NAME_FULLY_QUALIFIED) reduce 222) ((T_NAME_QUALIFIED) reduce 222) ((T_NAME_RELATIVE) reduce 222) ((T_NEW) reduce 222) ((T_NS_C) reduce 222) ((T_OBJECT_CAST) reduce 222) ((T_PRINT) reduce 222) ((T_READONLY) reduce 222) ((T_REQUIRE) reduce 222) ((T_REQUIRE_ONCE) reduce 222) ((T_RETURN) reduce 222) ((T_START_HEREDOC) reduce 222) ((T_STATIC) reduce 222) ((T_STRING) reduce 222) ((T_STRING_CAST) reduce 222) ((T_SWITCH) reduce 222) ((T_THROW) reduce 222) ((T_TRAIT) reduce 222) ((T_TRAIT_C) reduce 222) ((T_TRY) reduce 222) ((T_UNSET) reduce 222) ((T_UNSET_CAST) reduce 222) ((T_VARIABLE) reduce 222) ((T_WHILE) reduce 222) ((T_YIELD) reduce 222) ((T_YIELD_FROM) reduce 222) (("[") reduce 222) (("`") reduce 222) (("{") reduce 222) (("}") reduce 222) (("~") reduce 222)) 16703 (((T_CASE) reduce 225) ((T_DEFAULT) reduce 225) ((T_ENDSWITCH) reduce 225)) 16704 (((T_CASE) shift) ((T_DEFAULT) shift) ((T_ENDSWITCH) shift)) 16708 ((("!") reduce 223) (("\"") reduce 223) (("$") reduce 223) (("(") reduce 223) (("+") reduce 223) (("-") reduce 223) ((";") reduce 223) (("@") reduce 223) ((T_ABSTRACT) reduce 223) ((T_ARRAY) reduce 223) ((T_ARRAY_CAST) reduce 223) ((T_ATTRIBUTE) reduce 223) ((T_BOOL_CAST) reduce 223) ((T_BREAK) reduce 223) ((T_CASE) reduce 223) ((T_CLASS) reduce 223) ((T_CLASS_C) reduce 223) ((T_CLONE) reduce 223) ((T_CONSTANT_ENCAPSED_STRING) reduce 223) ((T_CONTINUE) reduce 223) ((T_DEC) reduce 223) ((T_DECLARE) reduce 223) ((T_DEFAULT) reduce 223) ((T_DIR) reduce 223) ((T_DNUMBER) reduce 223) ((T_DO) reduce 223) ((T_DOUBLE_CAST) reduce 223) ((T_ECHO) reduce 223) ((T_ELSE) reduce 223) ((T_ELSEIF) reduce 223) ((T_EMPTY) reduce 223) ((T_ENUM) reduce 223) ((T_EVAL) reduce 223) ((T_EXIT) reduce 223) ((T_FILE) reduce 223) ((T_FINAL) reduce 223) ((T_FN) reduce 223) ((T_FOR) reduce 223) ((T_FOREACH) reduce 223) ((T_FUNCTION) reduce 223) ((T_FUNC_C) reduce 223) ((T_GLOBAL) reduce 223) ((T_GOTO) reduce 223) ((T_HALT_COMPILER) reduce 223) ((T_IF) reduce 223) ((T_INC) reduce 223) ((T_INCLUDE) reduce 223) ((T_INCLUDE_ONCE) reduce 223) ((T_INLINE_HTML) reduce 223) ((T_INTERFACE) reduce 223) ((T_INT_CAST) reduce 223) ((T_ISSET) reduce 223) ((T_LINE) reduce 223) ((T_LIST) reduce 223) ((T_LNUMBER) reduce 223) ((T_MATCH) reduce 223) ((T_METHOD_C) reduce 223) ((T_NAME_FULLY_QUALIFIED) reduce 223) ((T_NAME_QUALIFIED) reduce 223) ((T_NAME_RELATIVE) reduce 223) ((T_NEW) reduce 223) ((T_NS_C) reduce 223) ((T_OBJECT_CAST) reduce 223) ((T_PRINT) reduce 223) ((T_READONLY) reduce 223) ((T_REQUIRE) reduce 223) ((T_REQUIRE_ONCE) reduce 223) ((T_RETURN) reduce 223) ((T_START_HEREDOC) reduce 223) ((T_STATIC) reduce 223) ((T_STRING) reduce 223) ((T_STRING_CAST) reduce 223) ((T_SWITCH) reduce 223) ((T_THROW) reduce 223) ((T_TRAIT) reduce 223) ((T_TRAIT_C) reduce 223) ((T_TRY) reduce 223) ((T_UNSET) reduce 223) ((T_UNSET_CAST) reduce 223) ((T_VARIABLE) reduce 223) ((T_WHILE) reduce 223) ((T_YIELD) reduce 223) ((T_YIELD_FROM) reduce 223) (("[") reduce 223) (("`") reduce 223) (("{") reduce 223) (("}") reduce 223) (("~") reduce 223)) 16709 ((("!") reduce 228) (("\"") reduce 228) (("$") reduce 228) (("(") reduce 228) (("+") reduce 228) (("-") reduce 228) ((";") reduce 228) (("@") reduce 228) ((T_ABSTRACT) reduce 228) ((T_ARRAY) reduce 228) ((T_ARRAY_CAST) reduce 228) ((T_ATTRIBUTE) reduce 228) ((T_BOOL_CAST) reduce 228) ((T_BREAK) reduce 228) ((T_CASE) reduce 228) ((T_CLASS) reduce 228) ((T_CLASS_C) reduce 228) ((T_CLONE) reduce 228) ((T_CONSTANT_ENCAPSED_STRING) reduce 228) ((T_CONTINUE) reduce 228) ((T_DEC) reduce 228) ((T_DECLARE) reduce 228) ((T_DEFAULT) reduce 228) ((T_DIR) reduce 228) ((T_DNUMBER) reduce 228) ((T_DO) reduce 228) ((T_DOUBLE_CAST) reduce 228) ((T_ECHO) reduce 228) ((T_EMPTY) reduce 228) ((T_ENDSWITCH) reduce 228) ((T_ENUM) reduce 228) ((T_EVAL) reduce 228) ((T_EXIT) reduce 228) ((T_FILE) reduce 228) ((T_FINAL) reduce 228) ((T_FN) reduce 228) ((T_FOR) reduce 228) ((T_FOREACH) reduce 228) ((T_FUNCTION) reduce 228) ((T_FUNC_C) reduce 228) ((T_GLOBAL) reduce 228) ((T_GOTO) reduce 228) ((T_HALT_COMPILER) reduce 228) ((T_IF) reduce 228) ((T_INC) reduce 228) ((T_INCLUDE) reduce 228) ((T_INCLUDE_ONCE) reduce 228) ((T_INLINE_HTML) reduce 228) ((T_INTERFACE) reduce 228) ((T_INT_CAST) reduce 228) ((T_ISSET) reduce 228) ((T_LINE) reduce 228) ((T_LIST) reduce 228) ((T_LNUMBER) reduce 228) ((T_MATCH) reduce 228) ((T_METHOD_C) reduce 228) ((T_NAME_FULLY_QUALIFIED) reduce 228) ((T_NAME_QUALIFIED) reduce 228) ((T_NAME_RELATIVE) reduce 228) ((T_NEW) reduce 228) ((T_NS_C) reduce 228) ((T_OBJECT_CAST) reduce 228) ((T_PRINT) reduce 228) ((T_READONLY) reduce 228) ((T_REQUIRE) reduce 228) ((T_REQUIRE_ONCE) reduce 228) ((T_RETURN) reduce 228) ((T_START_HEREDOC) reduce 228) ((T_STATIC) reduce 228) ((T_STRING) reduce 228) ((T_STRING_CAST) reduce 228) ((T_SWITCH) reduce 228) ((T_THROW) reduce 228) ((T_TRAIT) reduce 228) ((T_TRAIT_C) reduce 228) ((T_TRY) reduce 228) ((T_UNSET) reduce 228) ((T_UNSET_CAST) reduce 228) ((T_VARIABLE) reduce 228) ((T_WHILE) reduce 228) ((T_YIELD) reduce 228) ((T_YIELD_FROM) reduce 228) (("[") reduce 228) (("`") reduce 228) (("{") reduce 228) (("~") reduce 228)) 16710 ((("!") reduce 229) (("\"") reduce 229) (("$") reduce 229) (("(") reduce 229) (("+") reduce 229) (("-") reduce 229) ((";") reduce 229) (("@") reduce 229) ((T_ABSTRACT) reduce 229) ((T_ARRAY) reduce 229) ((T_ARRAY_CAST) reduce 229) ((T_ATTRIBUTE) reduce 229) ((T_BOOL_CAST) reduce 229) ((T_BREAK) reduce 229) ((T_CASE) reduce 229) ((T_CLASS) reduce 229) ((T_CLASS_C) reduce 229) ((T_CLONE) reduce 229) ((T_CONSTANT_ENCAPSED_STRING) reduce 229) ((T_CONTINUE) reduce 229) ((T_DEC) reduce 229) ((T_DECLARE) reduce 229) ((T_DEFAULT) reduce 229) ((T_DIR) reduce 229) ((T_DNUMBER) reduce 229) ((T_DO) reduce 229) ((T_DOUBLE_CAST) reduce 229) ((T_ECHO) reduce 229) ((T_EMPTY) reduce 229) ((T_ENDSWITCH) reduce 229) ((T_ENUM) reduce 229) ((T_EVAL) reduce 229) ((T_EXIT) reduce 229) ((T_FILE) reduce 229) ((T_FINAL) reduce 229) ((T_FN) reduce 229) ((T_FOR) reduce 229) ((T_FOREACH) reduce 229) ((T_FUNCTION) reduce 229) ((T_FUNC_C) reduce 229) ((T_GLOBAL) reduce 229) ((T_GOTO) reduce 229) ((T_HALT_COMPILER) reduce 229) ((T_IF) reduce 229) ((T_INC) reduce 229) ((T_INCLUDE) reduce 229) ((T_INCLUDE_ONCE) reduce 229) ((T_INLINE_HTML) reduce 229) ((T_INTERFACE) reduce 229) ((T_INT_CAST) reduce 229) ((T_ISSET) reduce 229) ((T_LINE) reduce 229) ((T_LIST) reduce 229) ((T_LNUMBER) reduce 229) ((T_MATCH) reduce 229) ((T_METHOD_C) reduce 229) ((T_NAME_FULLY_QUALIFIED) reduce 229) ((T_NAME_QUALIFIED) reduce 229) ((T_NAME_RELATIVE) reduce 229) ((T_NEW) reduce 229) ((T_NS_C) reduce 229) ((T_OBJECT_CAST) reduce 229) ((T_PRINT) reduce 229) ((T_READONLY) reduce 229) ((T_REQUIRE) reduce 229) ((T_REQUIRE_ONCE) reduce 229) ((T_RETURN) reduce 229) ((T_START_HEREDOC) reduce 229) ((T_STATIC) reduce 229) ((T_STRING) reduce 229) ((T_STRING_CAST) reduce 229) ((T_SWITCH) reduce 229) ((T_THROW) reduce 229) ((T_TRAIT) reduce 229) ((T_TRAIT_C) reduce 229) ((T_TRY) reduce 229) ((T_UNSET) reduce 229) ((T_UNSET_CAST) reduce 229) ((T_VARIABLE) reduce 229) ((T_WHILE) reduce 229) ((T_YIELD) reduce 229) ((T_YIELD_FROM) reduce 229) (("[") reduce 229) (("`") reduce 229) (("{") reduce 229) (("~") reduce 229)) 16711 ((("!") reduce 140) (("\"") reduce 140) (("$") reduce 140) (("(") reduce 140) (("+") reduce 140) (("-") reduce 140) ((";") reduce 140) (("@") reduce 140) ((T_ABSTRACT) reduce 140) ((T_ARRAY) reduce 140) ((T_ARRAY_CAST) reduce 140) ((T_ATTRIBUTE) reduce 140) ((T_BOOL_CAST) reduce 140) ((T_BREAK) reduce 140) ((T_CASE) reduce 140) ((T_CLASS) reduce 140) ((T_CLASS_C) reduce 140) ((T_CLONE) reduce 140) ((T_CONSTANT_ENCAPSED_STRING) reduce 140) ((T_CONTINUE) reduce 140) ((T_DEC) reduce 140) ((T_DECLARE) reduce 140) ((T_DEFAULT) reduce 140) ((T_DIR) reduce 140) ((T_DNUMBER) reduce 140) ((T_DO) reduce 140) ((T_DOUBLE_CAST) reduce 140) ((T_ECHO) reduce 140) ((T_EMPTY) reduce 140) ((T_ENDSWITCH) reduce 140) ((T_ENUM) reduce 140) ((T_EVAL) reduce 140) ((T_EXIT) reduce 140) ((T_FILE) reduce 140) ((T_FINAL) reduce 140) ((T_FN) reduce 140) ((T_FOR) reduce 140) ((T_FOREACH) reduce 140) ((T_FUNCTION) reduce 140) ((T_FUNC_C) reduce 140) ((T_GLOBAL) reduce 140) ((T_GOTO) reduce 140) ((T_HALT_COMPILER) reduce 140) ((T_IF) reduce 140) ((T_INC) reduce 140) ((T_INCLUDE) reduce 140) ((T_INCLUDE_ONCE) reduce 140) ((T_INLINE_HTML) reduce 140) ((T_INTERFACE) reduce 140) ((T_INT_CAST) reduce 140) ((T_ISSET) reduce 140) ((T_LINE) reduce 140) ((T_LIST) reduce 140) ((T_LNUMBER) reduce 140) ((T_MATCH) reduce 140) ((T_METHOD_C) reduce 140) ((T_NAME_FULLY_QUALIFIED) reduce 140) ((T_NAME_QUALIFIED) reduce 140) ((T_NAME_RELATIVE) reduce 140) ((T_NEW) reduce 140) ((T_NS_C) reduce 140) ((T_OBJECT_CAST) reduce 140) ((T_PRINT) reduce 140) ((T_READONLY) reduce 140) ((T_REQUIRE) reduce 140) ((T_REQUIRE_ONCE) reduce 140) ((T_RETURN) reduce 140) ((T_START_HEREDOC) reduce 140) ((T_STATIC) reduce 140) ((T_STRING) reduce 140) ((T_STRING_CAST) reduce 140) ((T_SWITCH) reduce 140) ((T_THROW) reduce 140) ((T_TRAIT) reduce 140) ((T_TRAIT_C) reduce 140) ((T_TRY) reduce 140) ((T_UNSET) reduce 140) ((T_UNSET_CAST) reduce 140) ((T_VARIABLE) reduce 140) ((T_WHILE) reduce 140) ((T_YIELD) reduce 140) ((T_YIELD_FROM) reduce 140) (("[") reduce 140) (("`") reduce 140) (("{") reduce 140) (("~") reduce 140)) 16712 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) (("+") shift) (("-") shift) ((";") shift) (("@") shift) ((T_ABSTRACT) shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_BREAK) shift) ((T_CASE) reduce 227) ((T_CLASS) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_CONTINUE) shift) ((T_DEC) shift) ((T_DECLARE) shift) ((T_DEFAULT) reduce 227) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DO) shift) ((T_DOUBLE_CAST) shift) ((T_ECHO) shift) ((T_EMPTY) shift) ((T_ENDSWITCH) reduce 227) ((T_ENUM) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FINAL) shift) ((T_FN) shift) ((T_FOR) shift) ((T_FOREACH) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_GLOBAL) shift) ((T_GOTO) shift) ((T_HALT_COMPILER) shift) ((T_IF) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INLINE_HTML) shift) ((T_INTERFACE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_RETURN) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_SWITCH) shift) ((T_THROW) shift) ((T_TRAIT) shift) ((T_TRAIT_C) shift) ((T_TRY) shift) ((T_UNSET) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_WHILE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("{") shift) (("~") shift)) 16713 ((("!") reduce 164) (("\"") reduce 164) (("$") reduce 164) (("(") reduce 164) (("+") reduce 164) (("-") reduce 164) ((";") reduce 164) (("@") reduce 164) ((T_ABSTRACT) reduce 164) ((T_ARRAY) reduce 164) ((T_ARRAY_CAST) reduce 164) ((T_ATTRIBUTE) reduce 164) ((T_BOOL_CAST) reduce 164) ((T_BREAK) reduce 164) ((T_CASE) reduce 164) ((T_CLASS) reduce 164) ((T_CLASS_C) reduce 164) ((T_CLONE) reduce 164) ((T_CONSTANT_ENCAPSED_STRING) reduce 164) ((T_CONTINUE) reduce 164) ((T_DEC) reduce 164) ((T_DECLARE) reduce 164) ((T_DEFAULT) reduce 164) ((T_DIR) reduce 164) ((T_DNUMBER) reduce 164) ((T_DO) reduce 164) ((T_DOUBLE_CAST) reduce 164) ((T_ECHO) reduce 164) ((T_EMPTY) reduce 164) ((T_ENDSWITCH) reduce 164) ((T_ENUM) reduce 164) ((T_EVAL) reduce 164) ((T_EXIT) reduce 164) ((T_FILE) reduce 164) ((T_FINAL) reduce 164) ((T_FN) reduce 164) ((T_FOR) reduce 164) ((T_FOREACH) reduce 164) ((T_FUNCTION) reduce 164) ((T_FUNC_C) reduce 164) ((T_GLOBAL) reduce 164) ((T_GOTO) reduce 164) ((T_HALT_COMPILER) reduce 164) ((T_IF) reduce 164) ((T_INC) reduce 164) ((T_INCLUDE) reduce 164) ((T_INCLUDE_ONCE) reduce 164) ((T_INLINE_HTML) reduce 164) ((T_INTERFACE) reduce 164) ((T_INT_CAST) reduce 164) ((T_ISSET) reduce 164) ((T_LINE) reduce 164) ((T_LIST) reduce 164) ((T_LNUMBER) reduce 164) ((T_MATCH) reduce 164) ((T_METHOD_C) reduce 164) ((T_NAME_FULLY_QUALIFIED) reduce 164) ((T_NAME_QUALIFIED) reduce 164) ((T_NAME_RELATIVE) reduce 164) ((T_NEW) reduce 164) ((T_NS_C) reduce 164) ((T_OBJECT_CAST) reduce 164) ((T_PRINT) reduce 164) ((T_READONLY) reduce 164) ((T_REQUIRE) reduce 164) ((T_REQUIRE_ONCE) reduce 164) ((T_RETURN) reduce 164) ((T_START_HEREDOC) reduce 164) ((T_STATIC) reduce 164) ((T_STRING) reduce 164) ((T_STRING_CAST) reduce 164) ((T_SWITCH) reduce 164) ((T_THROW) reduce 164) ((T_TRAIT) reduce 164) ((T_TRAIT_C) reduce 164) ((T_TRY) reduce 164) ((T_UNSET) reduce 164) ((T_UNSET_CAST) reduce 164) ((T_VARIABLE) reduce 164) ((T_WHILE) reduce 164) ((T_YIELD) reduce 164) ((T_YIELD_FROM) reduce 164) (("[") reduce 164) (("`") reduce 164) (("{") reduce 164) (("~") reduce 164)) 16727 ((("!") reduce 158) (("\"") reduce 158) (("$") reduce 158) (("(") reduce 158) (("+") reduce 158) (("-") reduce 158) ((";") reduce 158) (("@") reduce 158) ((T_ABSTRACT) reduce 158) ((T_ARRAY) reduce 158) ((T_ARRAY_CAST) reduce 158) ((T_ATTRIBUTE) reduce 158) ((T_BOOL_CAST) reduce 158) ((T_BREAK) reduce 158) ((T_CASE) reduce 158) ((T_CLASS) reduce 158) ((T_CLASS_C) reduce 158) ((T_CLONE) reduce 158) ((T_CONSTANT_ENCAPSED_STRING) reduce 158) ((T_CONTINUE) reduce 158) ((T_DEC) reduce 158) ((T_DECLARE) reduce 158) ((T_DEFAULT) reduce 158) ((T_DIR) reduce 158) ((T_DNUMBER) reduce 158) ((T_DO) reduce 158) ((T_DOUBLE_CAST) reduce 158) ((T_ECHO) reduce 158) ((T_EMPTY) reduce 158) ((T_ENDSWITCH) reduce 158) ((T_ENUM) reduce 158) ((T_EVAL) reduce 158) ((T_EXIT) reduce 158) ((T_FILE) reduce 158) ((T_FINAL) reduce 158) ((T_FN) reduce 158) ((T_FOR) reduce 158) ((T_FOREACH) reduce 158) ((T_FUNCTION) reduce 158) ((T_FUNC_C) reduce 158) ((T_GLOBAL) reduce 158) ((T_GOTO) reduce 158) ((T_HALT_COMPILER) reduce 158) ((T_IF) reduce 158) ((T_INC) reduce 158) ((T_INCLUDE) reduce 158) ((T_INCLUDE_ONCE) reduce 158) ((T_INLINE_HTML) reduce 158) ((T_INTERFACE) reduce 158) ((T_INT_CAST) reduce 158) ((T_ISSET) reduce 158) ((T_LINE) reduce 158) ((T_LIST) reduce 158) ((T_LNUMBER) reduce 158) ((T_MATCH) reduce 158) ((T_METHOD_C) reduce 158) ((T_NAME_FULLY_QUALIFIED) reduce 158) ((T_NAME_QUALIFIED) reduce 158) ((T_NAME_RELATIVE) reduce 158) ((T_NEW) reduce 158) ((T_NS_C) reduce 158) ((T_OBJECT_CAST) reduce 158) ((T_PRINT) reduce 158) ((T_READONLY) reduce 158) ((T_REQUIRE) reduce 158) ((T_REQUIRE_ONCE) reduce 158) ((T_RETURN) reduce 158) ((T_START_HEREDOC) reduce 158) ((T_STATIC) reduce 158) ((T_STRING) reduce 158) ((T_STRING_CAST) reduce 158) ((T_SWITCH) reduce 158) ((T_THROW) reduce 158) ((T_TRAIT) reduce 158) ((T_TRAIT_C) reduce 158) ((T_TRY) reduce 158) ((T_UNSET) reduce 158) ((T_UNSET_CAST) reduce 158) ((T_VARIABLE) reduce 158) ((T_WHILE) reduce 158) ((T_YIELD) reduce 158) ((T_YIELD_FROM) reduce 158) (("[") reduce 158) (("`") reduce 158) (("{") reduce 158) (("~") reduce 158)) 16737 ((("!") reduce 147) (("\"") reduce 147) (("$") reduce 147) (("(") reduce 147) (("+") reduce 147) (("-") reduce 147) ((";") reduce 147) (("@") reduce 147) ((T_ABSTRACT) reduce 147) ((T_ARRAY) reduce 147) ((T_ARRAY_CAST) reduce 147) ((T_ATTRIBUTE) reduce 147) ((T_BOOL_CAST) reduce 147) ((T_BREAK) reduce 147) ((T_CASE) reduce 147) ((T_CLASS) reduce 147) ((T_CLASS_C) reduce 147) ((T_CLONE) reduce 147) ((T_CONSTANT_ENCAPSED_STRING) reduce 147) ((T_CONTINUE) reduce 147) ((T_DEC) reduce 147) ((T_DECLARE) reduce 147) ((T_DEFAULT) reduce 147) ((T_DIR) reduce 147) ((T_DNUMBER) reduce 147) ((T_DO) reduce 147) ((T_DOUBLE_CAST) reduce 147) ((T_ECHO) reduce 147) ((T_EMPTY) reduce 147) ((T_ENDSWITCH) reduce 147) ((T_ENUM) reduce 147) ((T_EVAL) reduce 147) ((T_EXIT) reduce 147) ((T_FILE) reduce 147) ((T_FINAL) reduce 147) ((T_FN) reduce 147) ((T_FOR) reduce 147) ((T_FOREACH) reduce 147) ((T_FUNCTION) reduce 147) ((T_FUNC_C) reduce 147) ((T_GLOBAL) reduce 147) ((T_GOTO) reduce 147) ((T_HALT_COMPILER) reduce 147) ((T_IF) reduce 147) ((T_INC) reduce 147) ((T_INCLUDE) reduce 147) ((T_INCLUDE_ONCE) reduce 147) ((T_INLINE_HTML) reduce 147) ((T_INTERFACE) reduce 147) ((T_INT_CAST) reduce 147) ((T_ISSET) reduce 147) ((T_LINE) reduce 147) ((T_LIST) reduce 147) ((T_LNUMBER) reduce 147) ((T_MATCH) reduce 147) ((T_METHOD_C) reduce 147) ((T_NAME_FULLY_QUALIFIED) reduce 147) ((T_NAME_QUALIFIED) reduce 147) ((T_NAME_RELATIVE) reduce 147) ((T_NEW) reduce 147) ((T_NS_C) reduce 147) ((T_OBJECT_CAST) reduce 147) ((T_PRINT) reduce 147) ((T_READONLY) reduce 147) ((T_REQUIRE) reduce 147) ((T_REQUIRE_ONCE) reduce 147) ((T_RETURN) reduce 147) ((T_START_HEREDOC) reduce 147) ((T_STATIC) reduce 147) ((T_STRING) reduce 147) ((T_STRING_CAST) reduce 147) ((T_SWITCH) reduce 147) ((T_THROW) reduce 147) ((T_TRAIT) reduce 147) ((T_TRAIT_C) reduce 147) ((T_TRY) reduce 147) ((T_UNSET) reduce 147) ((T_UNSET_CAST) reduce 147) ((T_VARIABLE) reduce 147) ((T_WHILE) reduce 147) ((T_YIELD) reduce 147) ((T_YIELD_FROM) reduce 147) (("[") reduce 147) (("`") reduce 147) (("{") reduce 147) (("~") reduce 147)) 16739 ((("!") reduce 142) (("\"") reduce 142) (("$") reduce 142) (("(") reduce 142) (("+") reduce 142) (("-") reduce 142) ((";") reduce 142) (("@") reduce 142) ((T_ABSTRACT) reduce 142) ((T_ARRAY) reduce 142) ((T_ARRAY_CAST) reduce 142) ((T_ATTRIBUTE) reduce 142) ((T_BOOL_CAST) reduce 142) ((T_BREAK) reduce 142) ((T_CASE) reduce 142) ((T_CLASS) reduce 142) ((T_CLASS_C) reduce 142) ((T_CLONE) reduce 142) ((T_CONSTANT_ENCAPSED_STRING) reduce 142) ((T_CONTINUE) reduce 142) ((T_DEC) reduce 142) ((T_DECLARE) reduce 142) ((T_DEFAULT) reduce 142) ((T_DIR) reduce 142) ((T_DNUMBER) reduce 142) ((T_DO) reduce 142) ((T_DOUBLE_CAST) reduce 142) ((T_ECHO) reduce 142) ((T_EMPTY) reduce 142) ((T_ENDSWITCH) reduce 142) ((T_ENUM) reduce 142) ((T_EVAL) reduce 142) ((T_EXIT) reduce 142) ((T_FILE) reduce 142) ((T_FINAL) reduce 142) ((T_FN) reduce 142) ((T_FOR) reduce 142) ((T_FOREACH) reduce 142) ((T_FUNCTION) reduce 142) ((T_FUNC_C) reduce 142) ((T_GLOBAL) reduce 142) ((T_GOTO) reduce 142) ((T_HALT_COMPILER) reduce 142) ((T_IF) reduce 142) ((T_INC) reduce 142) ((T_INCLUDE) reduce 142) ((T_INCLUDE_ONCE) reduce 142) ((T_INLINE_HTML) reduce 142) ((T_INTERFACE) reduce 142) ((T_INT_CAST) reduce 142) ((T_ISSET) reduce 142) ((T_LINE) reduce 142) ((T_LIST) reduce 142) ((T_LNUMBER) reduce 142) ((T_MATCH) reduce 142) ((T_METHOD_C) reduce 142) ((T_NAME_FULLY_QUALIFIED) reduce 142) ((T_NAME_QUALIFIED) reduce 142) ((T_NAME_RELATIVE) reduce 142) ((T_NEW) reduce 142) ((T_NS_C) reduce 142) ((T_OBJECT_CAST) reduce 142) ((T_PRINT) reduce 142) ((T_READONLY) reduce 142) ((T_REQUIRE) reduce 142) ((T_REQUIRE_ONCE) reduce 142) ((T_RETURN) reduce 142) ((T_START_HEREDOC) reduce 142) ((T_STATIC) reduce 142) ((T_STRING) reduce 142) ((T_STRING_CAST) reduce 142) ((T_SWITCH) reduce 142) ((T_THROW) reduce 142) ((T_TRAIT) reduce 142) ((T_TRAIT_C) reduce 142) ((T_TRY) reduce 142) ((T_UNSET) reduce 142) ((T_UNSET_CAST) reduce 142) ((T_VARIABLE) reduce 142) ((T_WHILE) reduce 142) ((T_YIELD) reduce 142) ((T_YIELD_FROM) reduce 142) (("[") reduce 142) (("`") reduce 142) (("{") reduce 142) (("~") reduce 142)) 16741 ((("!") reduce 103) (("\"") reduce 103) (("$") reduce 103) (("(") reduce 103) (("+") reduce 103) (("-") reduce 103) ((";") reduce 103) (("@") reduce 103) ((T_ABSTRACT) reduce 103) ((T_ARRAY) reduce 103) ((T_ARRAY_CAST) reduce 103) ((T_ATTRIBUTE) reduce 103) ((T_BOOL_CAST) reduce 103) ((T_BREAK) reduce 103) ((T_CASE) reduce 103) ((T_CLASS) reduce 103) ((T_CLASS_C) reduce 103) ((T_CLONE) reduce 103) ((T_CONSTANT_ENCAPSED_STRING) reduce 103) ((T_CONTINUE) reduce 103) ((T_DEC) reduce 103) ((T_DECLARE) reduce 103) ((T_DEFAULT) reduce 103) ((T_DIR) reduce 103) ((T_DNUMBER) reduce 103) ((T_DO) reduce 103) ((T_DOUBLE_CAST) reduce 103) ((T_ECHO) reduce 103) ((T_EMPTY) reduce 103) ((T_ENDSWITCH) reduce 103) ((T_ENUM) reduce 103) ((T_EVAL) reduce 103) ((T_EXIT) reduce 103) ((T_FILE) reduce 103) ((T_FINAL) reduce 103) ((T_FN) reduce 103) ((T_FOR) reduce 103) ((T_FOREACH) reduce 103) ((T_FUNCTION) reduce 103) ((T_FUNC_C) reduce 103) ((T_GLOBAL) reduce 103) ((T_GOTO) reduce 103) ((T_HALT_COMPILER) reduce 103) ((T_IF) reduce 103) ((T_INC) reduce 103) ((T_INCLUDE) reduce 103) ((T_INCLUDE_ONCE) reduce 103) ((T_INLINE_HTML) reduce 103) ((T_INTERFACE) reduce 103) ((T_INT_CAST) reduce 103) ((T_ISSET) reduce 103) ((T_LINE) reduce 103) ((T_LIST) reduce 103) ((T_LNUMBER) reduce 103) ((T_MATCH) reduce 103) ((T_METHOD_C) reduce 103) ((T_NAME_FULLY_QUALIFIED) reduce 103) ((T_NAME_QUALIFIED) reduce 103) ((T_NAME_RELATIVE) reduce 103) ((T_NEW) reduce 103) ((T_NS_C) reduce 103) ((T_OBJECT_CAST) reduce 103) ((T_PRINT) reduce 103) ((T_READONLY) reduce 103) ((T_REQUIRE) reduce 103) ((T_REQUIRE_ONCE) reduce 103) ((T_RETURN) reduce 103) ((T_START_HEREDOC) reduce 103) ((T_STATIC) reduce 103) ((T_STRING) reduce 103) ((T_STRING_CAST) reduce 103) ((T_SWITCH) reduce 103) ((T_THROW) reduce 103) ((T_TRAIT) reduce 103) ((T_TRAIT_C) reduce 103) ((T_TRY) reduce 103) ((T_UNSET) reduce 103) ((T_UNSET_CAST) reduce 103) ((T_VARIABLE) reduce 103) ((T_WHILE) reduce 103) ((T_YIELD) reduce 103) ((T_YIELD_FROM) reduce 103) (("[") reduce 103) (("`") reduce 103) (("{") reduce 103) (("~") reduce 103)) 16743 ((("!") reduce 106) (("\"") reduce 106) (("$") reduce 106) (("(") reduce 106) (("+") reduce 106) (("-") reduce 106) ((";") reduce 106) (("@") reduce 106) ((T_ABSTRACT) reduce 106) ((T_ARRAY) reduce 106) ((T_ARRAY_CAST) reduce 106) ((T_ATTRIBUTE) reduce 106) ((T_BOOL_CAST) reduce 106) ((T_BREAK) reduce 106) ((T_CASE) reduce 106) ((T_CLASS) reduce 106) ((T_CLASS_C) reduce 106) ((T_CLONE) reduce 106) ((T_CONSTANT_ENCAPSED_STRING) reduce 106) ((T_CONTINUE) reduce 106) ((T_DEC) reduce 106) ((T_DECLARE) reduce 106) ((T_DEFAULT) reduce 106) ((T_DIR) reduce 106) ((T_DNUMBER) reduce 106) ((T_DO) reduce 106) ((T_DOUBLE_CAST) reduce 106) ((T_ECHO) reduce 106) ((T_EMPTY) reduce 106) ((T_ENDSWITCH) reduce 106) ((T_ENUM) reduce 106) ((T_EVAL) reduce 106) ((T_EXIT) reduce 106) ((T_FILE) reduce 106) ((T_FINAL) reduce 106) ((T_FN) reduce 106) ((T_FOR) reduce 106) ((T_FOREACH) reduce 106) ((T_FUNCTION) reduce 106) ((T_FUNC_C) reduce 106) ((T_GLOBAL) reduce 106) ((T_GOTO) reduce 106) ((T_HALT_COMPILER) reduce 106) ((T_IF) reduce 106) ((T_INC) reduce 106) ((T_INCLUDE) reduce 106) ((T_INCLUDE_ONCE) reduce 106) ((T_INLINE_HTML) reduce 106) ((T_INTERFACE) reduce 106) ((T_INT_CAST) reduce 106) ((T_ISSET) reduce 106) ((T_LINE) reduce 106) ((T_LIST) reduce 106) ((T_LNUMBER) reduce 106) ((T_MATCH) reduce 106) ((T_METHOD_C) reduce 106) ((T_NAME_FULLY_QUALIFIED) reduce 106) ((T_NAME_QUALIFIED) reduce 106) ((T_NAME_RELATIVE) reduce 106) ((T_NEW) reduce 106) ((T_NS_C) reduce 106) ((T_OBJECT_CAST) reduce 106) ((T_PRINT) reduce 106) ((T_READONLY) reduce 106) ((T_REQUIRE) reduce 106) ((T_REQUIRE_ONCE) reduce 106) ((T_RETURN) reduce 106) ((T_START_HEREDOC) reduce 106) ((T_STATIC) reduce 106) ((T_STRING) reduce 106) ((T_STRING_CAST) reduce 106) ((T_SWITCH) reduce 106) ((T_THROW) reduce 106) ((T_TRAIT) reduce 106) ((T_TRAIT_C) reduce 106) ((T_TRY) reduce 106) ((T_UNSET) reduce 106) ((T_UNSET_CAST) reduce 106) ((T_VARIABLE) reduce 106) ((T_WHILE) reduce 106) ((T_YIELD) reduce 106) ((T_YIELD_FROM) reduce 106) (("[") reduce 106) (("`") reduce 106) (("{") reduce 106) (("~") reduce 106)) 16746 ((("!") reduce 102) (("\"") reduce 102) (("$") reduce 102) (("(") reduce 102) (("+") reduce 102) (("-") reduce 102) ((";") reduce 102) (("@") reduce 102) ((T_ABSTRACT) reduce 102) ((T_ARRAY) reduce 102) ((T_ARRAY_CAST) reduce 102) ((T_ATTRIBUTE) reduce 102) ((T_BOOL_CAST) reduce 102) ((T_BREAK) reduce 102) ((T_CASE) reduce 102) ((T_CLASS) reduce 102) ((T_CLASS_C) reduce 102) ((T_CLONE) reduce 102) ((T_CONSTANT_ENCAPSED_STRING) reduce 102) ((T_CONTINUE) reduce 102) ((T_DEC) reduce 102) ((T_DECLARE) reduce 102) ((T_DEFAULT) reduce 102) ((T_DIR) reduce 102) ((T_DNUMBER) reduce 102) ((T_DO) reduce 102) ((T_DOUBLE_CAST) reduce 102) ((T_ECHO) reduce 102) ((T_EMPTY) reduce 102) ((T_ENDSWITCH) reduce 102) ((T_ENUM) reduce 102) ((T_EVAL) reduce 102) ((T_EXIT) reduce 102) ((T_FILE) reduce 102) ((T_FINAL) reduce 102) ((T_FN) reduce 102) ((T_FOR) reduce 102) ((T_FOREACH) reduce 102) ((T_FUNCTION) reduce 102) ((T_FUNC_C) reduce 102) ((T_GLOBAL) reduce 102) ((T_GOTO) reduce 102) ((T_HALT_COMPILER) reduce 102) ((T_IF) reduce 102) ((T_INC) reduce 102) ((T_INCLUDE) reduce 102) ((T_INCLUDE_ONCE) reduce 102) ((T_INLINE_HTML) reduce 102) ((T_INTERFACE) reduce 102) ((T_INT_CAST) reduce 102) ((T_ISSET) reduce 102) ((T_LINE) reduce 102) ((T_LIST) reduce 102) ((T_LNUMBER) reduce 102) ((T_MATCH) reduce 102) ((T_METHOD_C) reduce 102) ((T_NAME_FULLY_QUALIFIED) reduce 102) ((T_NAME_QUALIFIED) reduce 102) ((T_NAME_RELATIVE) reduce 102) ((T_NEW) reduce 102) ((T_NS_C) reduce 102) ((T_OBJECT_CAST) reduce 102) ((T_PRINT) reduce 102) ((T_READONLY) reduce 102) ((T_REQUIRE) reduce 102) ((T_REQUIRE_ONCE) reduce 102) ((T_RETURN) reduce 102) ((T_START_HEREDOC) reduce 102) ((T_STATIC) reduce 102) ((T_STRING) reduce 102) ((T_STRING_CAST) reduce 102) ((T_SWITCH) reduce 102) ((T_THROW) reduce 102) ((T_TRAIT) reduce 102) ((T_TRAIT_C) reduce 102) ((T_TRY) reduce 102) ((T_UNSET) reduce 102) ((T_UNSET_CAST) reduce 102) ((T_VARIABLE) reduce 102) ((T_WHILE) reduce 102) ((T_YIELD) reduce 102) ((T_YIELD_FROM) reduce 102) (("[") reduce 102) (("`") reduce 102) (("{") reduce 102) (("~") reduce 102)) 16747 ((("!") reduce 146) (("\"") reduce 146) (("$") reduce 146) (("(") reduce 146) (("+") reduce 146) (("-") reduce 146) ((";") reduce 146) (("@") reduce 146) ((T_ABSTRACT) reduce 146) ((T_ARRAY) reduce 146) ((T_ARRAY_CAST) reduce 146) ((T_ATTRIBUTE) reduce 146) ((T_BOOL_CAST) reduce 146) ((T_BREAK) reduce 146) ((T_CASE) reduce 146) ((T_CLASS) reduce 146) ((T_CLASS_C) reduce 146) ((T_CLONE) reduce 146) ((T_CONSTANT_ENCAPSED_STRING) reduce 146) ((T_CONTINUE) reduce 146) ((T_DEC) reduce 146) ((T_DECLARE) reduce 146) ((T_DEFAULT) reduce 146) ((T_DIR) reduce 146) ((T_DNUMBER) reduce 146) ((T_DO) reduce 146) ((T_DOUBLE_CAST) reduce 146) ((T_ECHO) reduce 146) ((T_EMPTY) reduce 146) ((T_ENDSWITCH) reduce 146) ((T_ENUM) reduce 146) ((T_EVAL) reduce 146) ((T_EXIT) reduce 146) ((T_FILE) reduce 146) ((T_FINAL) reduce 146) ((T_FN) reduce 146) ((T_FOR) reduce 146) ((T_FOREACH) reduce 146) ((T_FUNCTION) reduce 146) ((T_FUNC_C) reduce 146) ((T_GLOBAL) reduce 146) ((T_GOTO) reduce 146) ((T_HALT_COMPILER) reduce 146) ((T_IF) reduce 146) ((T_INC) reduce 146) ((T_INCLUDE) reduce 146) ((T_INCLUDE_ONCE) reduce 146) ((T_INLINE_HTML) reduce 146) ((T_INTERFACE) reduce 146) ((T_INT_CAST) reduce 146) ((T_ISSET) reduce 146) ((T_LINE) reduce 146) ((T_LIST) reduce 146) ((T_LNUMBER) reduce 146) ((T_MATCH) reduce 146) ((T_METHOD_C) reduce 146) ((T_NAME_FULLY_QUALIFIED) reduce 146) ((T_NAME_QUALIFIED) reduce 146) ((T_NAME_RELATIVE) reduce 146) ((T_NEW) reduce 146) ((T_NS_C) reduce 146) ((T_OBJECT_CAST) reduce 146) ((T_PRINT) reduce 146) ((T_READONLY) reduce 146) ((T_REQUIRE) reduce 146) ((T_REQUIRE_ONCE) reduce 146) ((T_RETURN) reduce 146) ((T_START_HEREDOC) reduce 146) ((T_STATIC) reduce 146) ((T_STRING) reduce 146) ((T_STRING_CAST) reduce 146) ((T_SWITCH) reduce 146) ((T_THROW) reduce 146) ((T_TRAIT) reduce 146) ((T_TRAIT_C) reduce 146) ((T_TRY) reduce 146) ((T_UNSET) reduce 146) ((T_UNSET_CAST) reduce 146) ((T_VARIABLE) reduce 146) ((T_WHILE) reduce 146) ((T_YIELD) reduce 146) ((T_YIELD_FROM) reduce 146) (("[") reduce 146) (("`") reduce 146) (("{") reduce 146) (("~") reduce 146)) 16748 ((("!") reduce 243) (("\"") reduce 243) (("$") reduce 243) (("(") reduce 243) (("+") reduce 243) (("-") reduce 243) ((";") reduce 243) (("@") reduce 243) ((T_ABSTRACT) reduce 243) ((T_ARRAY) reduce 243) ((T_ARRAY_CAST) reduce 243) ((T_ATTRIBUTE) reduce 243) ((T_BOOL_CAST) reduce 243) ((T_BREAK) reduce 243) ((T_CASE) reduce 243) ((T_CLASS) reduce 243) ((T_CLASS_C) reduce 243) ((T_CLONE) reduce 243) ((T_CONSTANT_ENCAPSED_STRING) reduce 243) ((T_CONTINUE) reduce 243) ((T_DEC) reduce 243) ((T_DECLARE) reduce 243) ((T_DEFAULT) reduce 243) ((T_DIR) reduce 243) ((T_DNUMBER) reduce 243) ((T_DO) reduce 243) ((T_DOUBLE_CAST) reduce 243) ((T_ECHO) reduce 243) ((T_ELSE) shift) ((T_ELSEIF) shift) ((T_EMPTY) reduce 243) ((T_ENDSWITCH) reduce 243) ((T_ENUM) reduce 243) ((T_EVAL) reduce 243) ((T_EXIT) reduce 243) ((T_FILE) reduce 243) ((T_FINAL) reduce 243) ((T_FN) reduce 243) ((T_FOR) reduce 243) ((T_FOREACH) reduce 243) ((T_FUNCTION) reduce 243) ((T_FUNC_C) reduce 243) ((T_GLOBAL) reduce 243) ((T_GOTO) reduce 243) ((T_HALT_COMPILER) reduce 243) ((T_IF) reduce 243) ((T_INC) reduce 243) ((T_INCLUDE) reduce 243) ((T_INCLUDE_ONCE) reduce 243) ((T_INLINE_HTML) reduce 243) ((T_INTERFACE) reduce 243) ((T_INT_CAST) reduce 243) ((T_ISSET) reduce 243) ((T_LINE) reduce 243) ((T_LIST) reduce 243) ((T_LNUMBER) reduce 243) ((T_MATCH) reduce 243) ((T_METHOD_C) reduce 243) ((T_NAME_FULLY_QUALIFIED) reduce 243) ((T_NAME_QUALIFIED) reduce 243) ((T_NAME_RELATIVE) reduce 243) ((T_NEW) reduce 243) ((T_NS_C) reduce 243) ((T_OBJECT_CAST) reduce 243) ((T_PRINT) reduce 243) ((T_READONLY) reduce 243) ((T_REQUIRE) reduce 243) ((T_REQUIRE_ONCE) reduce 243) ((T_RETURN) reduce 243) ((T_START_HEREDOC) reduce 243) ((T_STATIC) reduce 243) ((T_STRING) reduce 243) ((T_STRING_CAST) reduce 243) ((T_SWITCH) reduce 243) ((T_THROW) reduce 243) ((T_TRAIT) reduce 243) ((T_TRAIT_C) reduce 243) ((T_TRY) reduce 243) ((T_UNSET) reduce 243) ((T_UNSET_CAST) reduce 243) ((T_VARIABLE) reduce 243) ((T_WHILE) reduce 243) ((T_YIELD) reduce 243) ((T_YIELD_FROM) reduce 243) (("[") reduce 243) (("`") reduce 243) (("{") reduce 243) (("~") reduce 243)) 16749 ((("!") reduce 139) (("\"") reduce 139) (("$") reduce 139) (("(") reduce 139) (("+") reduce 139) (("-") reduce 139) ((";") reduce 139) (("@") reduce 139) ((T_ABSTRACT) reduce 139) ((T_ARRAY) reduce 139) ((T_ARRAY_CAST) reduce 139) ((T_ATTRIBUTE) reduce 139) ((T_BOOL_CAST) reduce 139) ((T_BREAK) reduce 139) ((T_CASE) reduce 139) ((T_CLASS) reduce 139) ((T_CLASS_C) reduce 139) ((T_CLONE) reduce 139) ((T_CONSTANT_ENCAPSED_STRING) reduce 139) ((T_CONTINUE) reduce 139) ((T_DEC) reduce 139) ((T_DECLARE) reduce 139) ((T_DEFAULT) reduce 139) ((T_DIR) reduce 139) ((T_DNUMBER) reduce 139) ((T_DO) reduce 139) ((T_DOUBLE_CAST) reduce 139) ((T_ECHO) reduce 139) ((T_EMPTY) reduce 139) ((T_ENDSWITCH) reduce 139) ((T_ENUM) reduce 139) ((T_EVAL) reduce 139) ((T_EXIT) reduce 139) ((T_FILE) reduce 139) ((T_FINAL) reduce 139) ((T_FN) reduce 139) ((T_FOR) reduce 139) ((T_FOREACH) reduce 139) ((T_FUNCTION) reduce 139) ((T_FUNC_C) reduce 139) ((T_GLOBAL) reduce 139) ((T_GOTO) reduce 139) ((T_HALT_COMPILER) reduce 139) ((T_IF) reduce 139) ((T_INC) reduce 139) ((T_INCLUDE) reduce 139) ((T_INCLUDE_ONCE) reduce 139) ((T_INLINE_HTML) reduce 139) ((T_INTERFACE) reduce 139) ((T_INT_CAST) reduce 139) ((T_ISSET) reduce 139) ((T_LINE) reduce 139) ((T_LIST) reduce 139) ((T_LNUMBER) reduce 139) ((T_MATCH) reduce 139) ((T_METHOD_C) reduce 139) ((T_NAME_FULLY_QUALIFIED) reduce 139) ((T_NAME_QUALIFIED) reduce 139) ((T_NAME_RELATIVE) reduce 139) ((T_NEW) reduce 139) ((T_NS_C) reduce 139) ((T_OBJECT_CAST) reduce 139) ((T_PRINT) reduce 139) ((T_READONLY) reduce 139) ((T_REQUIRE) reduce 139) ((T_REQUIRE_ONCE) reduce 139) ((T_RETURN) reduce 139) ((T_START_HEREDOC) reduce 139) ((T_STATIC) reduce 139) ((T_STRING) reduce 139) ((T_STRING_CAST) reduce 139) ((T_SWITCH) reduce 139) ((T_THROW) reduce 139) ((T_TRAIT) reduce 139) ((T_TRAIT_C) reduce 139) ((T_TRY) reduce 139) ((T_UNSET) reduce 139) ((T_UNSET_CAST) reduce 139) ((T_VARIABLE) reduce 139) ((T_WHILE) reduce 139) ((T_YIELD) reduce 139) ((T_YIELD_FROM) reduce 139) (("[") reduce 139) (("`") reduce 139) (("{") reduce 139) (("~") reduce 139)) 16750 ((("!") reduce 105) (("\"") reduce 105) (("$") reduce 105) (("(") reduce 105) (("+") reduce 105) (("-") reduce 105) ((";") reduce 105) (("@") reduce 105) ((T_ABSTRACT) reduce 105) ((T_ARRAY) reduce 105) ((T_ARRAY_CAST) reduce 105) ((T_ATTRIBUTE) reduce 105) ((T_BOOL_CAST) reduce 105) ((T_BREAK) reduce 105) ((T_CASE) reduce 105) ((T_CLASS) reduce 105) ((T_CLASS_C) reduce 105) ((T_CLONE) reduce 105) ((T_CONSTANT_ENCAPSED_STRING) reduce 105) ((T_CONTINUE) reduce 105) ((T_DEC) reduce 105) ((T_DECLARE) reduce 105) ((T_DEFAULT) reduce 105) ((T_DIR) reduce 105) ((T_DNUMBER) reduce 105) ((T_DO) reduce 105) ((T_DOUBLE_CAST) reduce 105) ((T_ECHO) reduce 105) ((T_EMPTY) reduce 105) ((T_ENDSWITCH) reduce 105) ((T_ENUM) reduce 105) ((T_EVAL) reduce 105) ((T_EXIT) reduce 105) ((T_FILE) reduce 105) ((T_FINAL) reduce 105) ((T_FN) reduce 105) ((T_FOR) reduce 105) ((T_FOREACH) reduce 105) ((T_FUNCTION) reduce 105) ((T_FUNC_C) reduce 105) ((T_GLOBAL) reduce 105) ((T_GOTO) reduce 105) ((T_HALT_COMPILER) reduce 105) ((T_IF) reduce 105) ((T_INC) reduce 105) ((T_INCLUDE) reduce 105) ((T_INCLUDE_ONCE) reduce 105) ((T_INLINE_HTML) reduce 105) ((T_INTERFACE) reduce 105) ((T_INT_CAST) reduce 105) ((T_ISSET) reduce 105) ((T_LINE) reduce 105) ((T_LIST) reduce 105) ((T_LNUMBER) reduce 105) ((T_MATCH) reduce 105) ((T_METHOD_C) reduce 105) ((T_NAME_FULLY_QUALIFIED) reduce 105) ((T_NAME_QUALIFIED) reduce 105) ((T_NAME_RELATIVE) reduce 105) ((T_NEW) reduce 105) ((T_NS_C) reduce 105) ((T_OBJECT_CAST) reduce 105) ((T_PRINT) reduce 105) ((T_READONLY) reduce 105) ((T_REQUIRE) reduce 105) ((T_REQUIRE_ONCE) reduce 105) ((T_RETURN) reduce 105) ((T_START_HEREDOC) reduce 105) ((T_STATIC) reduce 105) ((T_STRING) reduce 105) ((T_STRING_CAST) reduce 105) ((T_SWITCH) reduce 105) ((T_THROW) reduce 105) ((T_TRAIT) reduce 105) ((T_TRAIT_C) reduce 105) ((T_TRY) reduce 105) ((T_UNSET) reduce 105) ((T_UNSET_CAST) reduce 105) ((T_VARIABLE) reduce 105) ((T_WHILE) reduce 105) ((T_YIELD) reduce 105) ((T_YIELD_FROM) reduce 105) (("[") reduce 105) (("`") reduce 105) (("{") reduce 105) (("~") reduce 105)) 16751 ((("!") reduce 141) (("\"") reduce 141) (("$") reduce 141) (("(") reduce 141) (("+") reduce 141) (("-") reduce 141) ((";") reduce 141) (("@") reduce 141) ((T_ABSTRACT) reduce 141) ((T_ARRAY) reduce 141) ((T_ARRAY_CAST) reduce 141) ((T_ATTRIBUTE) reduce 141) ((T_BOOL_CAST) reduce 141) ((T_BREAK) reduce 141) ((T_CASE) reduce 141) ((T_CLASS) reduce 141) ((T_CLASS_C) reduce 141) ((T_CLONE) reduce 141) ((T_CONSTANT_ENCAPSED_STRING) reduce 141) ((T_CONTINUE) reduce 141) ((T_DEC) reduce 141) ((T_DECLARE) reduce 141) ((T_DEFAULT) reduce 141) ((T_DIR) reduce 141) ((T_DNUMBER) reduce 141) ((T_DO) reduce 141) ((T_DOUBLE_CAST) reduce 141) ((T_ECHO) reduce 141) ((T_EMPTY) reduce 141) ((T_ENDSWITCH) reduce 141) ((T_ENUM) reduce 141) ((T_EVAL) reduce 141) ((T_EXIT) reduce 141) ((T_FILE) reduce 141) ((T_FINAL) reduce 141) ((T_FN) reduce 141) ((T_FOR) reduce 141) ((T_FOREACH) reduce 141) ((T_FUNCTION) reduce 141) ((T_FUNC_C) reduce 141) ((T_GLOBAL) reduce 141) ((T_GOTO) reduce 141) ((T_HALT_COMPILER) reduce 141) ((T_IF) reduce 141) ((T_INC) reduce 141) ((T_INCLUDE) reduce 141) ((T_INCLUDE_ONCE) reduce 141) ((T_INLINE_HTML) reduce 141) ((T_INTERFACE) reduce 141) ((T_INT_CAST) reduce 141) ((T_ISSET) reduce 141) ((T_LINE) reduce 141) ((T_LIST) reduce 141) ((T_LNUMBER) reduce 141) ((T_MATCH) reduce 141) ((T_METHOD_C) reduce 141) ((T_NAME_FULLY_QUALIFIED) reduce 141) ((T_NAME_QUALIFIED) reduce 141) ((T_NAME_RELATIVE) reduce 141) ((T_NEW) reduce 141) ((T_NS_C) reduce 141) ((T_OBJECT_CAST) reduce 141) ((T_PRINT) reduce 141) ((T_READONLY) reduce 141) ((T_REQUIRE) reduce 141) ((T_REQUIRE_ONCE) reduce 141) ((T_RETURN) reduce 141) ((T_START_HEREDOC) reduce 141) ((T_STATIC) reduce 141) ((T_STRING) reduce 141) ((T_STRING_CAST) reduce 141) ((T_SWITCH) reduce 141) ((T_THROW) reduce 141) ((T_TRAIT) reduce 141) ((T_TRAIT_C) reduce 141) ((T_TRY) reduce 141) ((T_UNSET) reduce 141) ((T_UNSET_CAST) reduce 141) ((T_VARIABLE) reduce 141) ((T_WHILE) reduce 141) ((T_YIELD) reduce 141) ((T_YIELD_FROM) reduce 141) (("[") reduce 141) (("`") reduce 141) (("{") reduce 141) (("~") reduce 141)) 16752 ((("!") reduce 104) (("\"") reduce 104) (("$") reduce 104) (("(") reduce 104) (("+") reduce 104) (("-") reduce 104) ((";") reduce 104) (("@") reduce 104) ((T_ABSTRACT) reduce 104) ((T_ARRAY) reduce 104) ((T_ARRAY_CAST) reduce 104) ((T_ATTRIBUTE) reduce 104) ((T_BOOL_CAST) reduce 104) ((T_BREAK) reduce 104) ((T_CASE) reduce 104) ((T_CLASS) reduce 104) ((T_CLASS_C) reduce 104) ((T_CLONE) reduce 104) ((T_CONSTANT_ENCAPSED_STRING) reduce 104) ((T_CONTINUE) reduce 104) ((T_DEC) reduce 104) ((T_DECLARE) reduce 104) ((T_DEFAULT) reduce 104) ((T_DIR) reduce 104) ((T_DNUMBER) reduce 104) ((T_DO) reduce 104) ((T_DOUBLE_CAST) reduce 104) ((T_ECHO) reduce 104) ((T_EMPTY) reduce 104) ((T_ENDSWITCH) reduce 104) ((T_ENUM) reduce 104) ((T_EVAL) reduce 104) ((T_EXIT) reduce 104) ((T_FILE) reduce 104) ((T_FINAL) reduce 104) ((T_FN) reduce 104) ((T_FOR) reduce 104) ((T_FOREACH) reduce 104) ((T_FUNCTION) reduce 104) ((T_FUNC_C) reduce 104) ((T_GLOBAL) reduce 104) ((T_GOTO) reduce 104) ((T_HALT_COMPILER) reduce 104) ((T_IF) reduce 104) ((T_INC) reduce 104) ((T_INCLUDE) reduce 104) ((T_INCLUDE_ONCE) reduce 104) ((T_INLINE_HTML) reduce 104) ((T_INTERFACE) reduce 104) ((T_INT_CAST) reduce 104) ((T_ISSET) reduce 104) ((T_LINE) reduce 104) ((T_LIST) reduce 104) ((T_LNUMBER) reduce 104) ((T_MATCH) reduce 104) ((T_METHOD_C) reduce 104) ((T_NAME_FULLY_QUALIFIED) reduce 104) ((T_NAME_QUALIFIED) reduce 104) ((T_NAME_RELATIVE) reduce 104) ((T_NEW) reduce 104) ((T_NS_C) reduce 104) ((T_OBJECT_CAST) reduce 104) ((T_PRINT) reduce 104) ((T_READONLY) reduce 104) ((T_REQUIRE) reduce 104) ((T_REQUIRE_ONCE) reduce 104) ((T_RETURN) reduce 104) ((T_START_HEREDOC) reduce 104) ((T_STATIC) reduce 104) ((T_STRING) reduce 104) ((T_STRING_CAST) reduce 104) ((T_SWITCH) reduce 104) ((T_THROW) reduce 104) ((T_TRAIT) reduce 104) ((T_TRAIT_C) reduce 104) ((T_TRY) reduce 104) ((T_UNSET) reduce 104) ((T_UNSET_CAST) reduce 104) ((T_VARIABLE) reduce 104) ((T_WHILE) reduce 104) ((T_YIELD) reduce 104) ((T_YIELD_FROM) reduce 104) (("[") reduce 104) (("`") reduce 104) (("{") reduce 104) (("~") reduce 104)) 16755 ((("!") reduce 145) (("\"") reduce 145) (("$") reduce 145) (("(") reduce 145) (("+") reduce 145) (("-") reduce 145) ((";") reduce 145) (("@") reduce 145) ((T_ABSTRACT) reduce 145) ((T_ARRAY) reduce 145) ((T_ARRAY_CAST) reduce 145) ((T_ATTRIBUTE) reduce 145) ((T_BOOL_CAST) reduce 145) ((T_BREAK) reduce 145) ((T_CASE) reduce 145) ((T_CLASS) reduce 145) ((T_CLASS_C) reduce 145) ((T_CLONE) reduce 145) ((T_CONSTANT_ENCAPSED_STRING) reduce 145) ((T_CONTINUE) reduce 145) ((T_DEC) reduce 145) ((T_DECLARE) reduce 145) ((T_DEFAULT) reduce 145) ((T_DIR) reduce 145) ((T_DNUMBER) reduce 145) ((T_DO) reduce 145) ((T_DOUBLE_CAST) reduce 145) ((T_ECHO) reduce 145) ((T_EMPTY) reduce 145) ((T_ENDSWITCH) reduce 145) ((T_ENUM) reduce 145) ((T_EVAL) reduce 145) ((T_EXIT) reduce 145) ((T_FILE) reduce 145) ((T_FINAL) reduce 145) ((T_FN) reduce 145) ((T_FOR) reduce 145) ((T_FOREACH) reduce 145) ((T_FUNCTION) reduce 145) ((T_FUNC_C) reduce 145) ((T_GLOBAL) reduce 145) ((T_GOTO) reduce 145) ((T_HALT_COMPILER) reduce 145) ((T_IF) reduce 145) ((T_INC) reduce 145) ((T_INCLUDE) reduce 145) ((T_INCLUDE_ONCE) reduce 145) ((T_INLINE_HTML) reduce 145) ((T_INTERFACE) reduce 145) ((T_INT_CAST) reduce 145) ((T_ISSET) reduce 145) ((T_LINE) reduce 145) ((T_LIST) reduce 145) ((T_LNUMBER) reduce 145) ((T_MATCH) reduce 145) ((T_METHOD_C) reduce 145) ((T_NAME_FULLY_QUALIFIED) reduce 145) ((T_NAME_QUALIFIED) reduce 145) ((T_NAME_RELATIVE) reduce 145) ((T_NEW) reduce 145) ((T_NS_C) reduce 145) ((T_OBJECT_CAST) reduce 145) ((T_PRINT) reduce 145) ((T_READONLY) reduce 145) ((T_REQUIRE) reduce 145) ((T_REQUIRE_ONCE) reduce 145) ((T_RETURN) reduce 145) ((T_START_HEREDOC) reduce 145) ((T_STATIC) reduce 145) ((T_STRING) reduce 145) ((T_STRING_CAST) reduce 145) ((T_SWITCH) reduce 145) ((T_THROW) reduce 145) ((T_TRAIT) reduce 145) ((T_TRAIT_C) reduce 145) ((T_TRY) reduce 145) ((T_UNSET) reduce 145) ((T_UNSET_CAST) reduce 145) ((T_VARIABLE) reduce 145) ((T_WHILE) reduce 145) ((T_YIELD) reduce 145) ((T_YIELD_FROM) reduce 145) (("[") reduce 145) (("`") reduce 145) (("{") reduce 145) (("~") reduce 145)) 16761 ((("!") reduce 164) (("\"") reduce 164) (("$") reduce 164) (("(") reduce 164) (("+") reduce 164) (("-") reduce 164) ((";") reduce 164) (("@") reduce 164) ((T_ABSTRACT) reduce 164) ((T_ARRAY) reduce 164) ((T_ARRAY_CAST) reduce 164) ((T_ATTRIBUTE) reduce 164) ((T_BOOL_CAST) reduce 164) ((T_BREAK) reduce 164) ((T_CASE) reduce 164) ((T_CLASS) reduce 164) ((T_CLASS_C) reduce 164) ((T_CLONE) reduce 164) ((T_CONSTANT_ENCAPSED_STRING) reduce 164) ((T_CONTINUE) reduce 164) ((T_DEC) reduce 164) ((T_DECLARE) reduce 164) ((T_DEFAULT) reduce 164) ((T_DIR) reduce 164) ((T_DNUMBER) reduce 164) ((T_DO) reduce 164) ((T_DOUBLE_CAST) reduce 164) ((T_ECHO) reduce 164) ((T_ELSE) reduce 164) ((T_ELSEIF) reduce 164) ((T_EMPTY) reduce 164) ((T_ENDSWITCH) reduce 164) ((T_ENUM) reduce 164) ((T_EVAL) reduce 164) ((T_EXIT) reduce 164) ((T_FILE) reduce 164) ((T_FINAL) reduce 164) ((T_FN) reduce 164) ((T_FOR) reduce 164) ((T_FOREACH) reduce 164) ((T_FUNCTION) reduce 164) ((T_FUNC_C) reduce 164) ((T_GLOBAL) reduce 164) ((T_GOTO) reduce 164) ((T_HALT_COMPILER) reduce 164) ((T_IF) reduce 164) ((T_INC) reduce 164) ((T_INCLUDE) reduce 164) ((T_INCLUDE_ONCE) reduce 164) ((T_INLINE_HTML) reduce 164) ((T_INTERFACE) reduce 164) ((T_INT_CAST) reduce 164) ((T_ISSET) reduce 164) ((T_LINE) reduce 164) ((T_LIST) reduce 164) ((T_LNUMBER) reduce 164) ((T_MATCH) reduce 164) ((T_METHOD_C) reduce 164) ((T_NAME_FULLY_QUALIFIED) reduce 164) ((T_NAME_QUALIFIED) reduce 164) ((T_NAME_RELATIVE) reduce 164) ((T_NEW) reduce 164) ((T_NS_C) reduce 164) ((T_OBJECT_CAST) reduce 164) ((T_PRINT) reduce 164) ((T_READONLY) reduce 164) ((T_REQUIRE) reduce 164) ((T_REQUIRE_ONCE) reduce 164) ((T_RETURN) reduce 164) ((T_START_HEREDOC) reduce 164) ((T_STATIC) reduce 164) ((T_STRING) reduce 164) ((T_STRING_CAST) reduce 164) ((T_SWITCH) reduce 164) ((T_THROW) reduce 164) ((T_TRAIT) reduce 164) ((T_TRAIT_C) reduce 164) ((T_TRY) reduce 164) ((T_UNSET) reduce 164) ((T_UNSET_CAST) reduce 164) ((T_VARIABLE) reduce 164) ((T_WHILE) reduce 164) ((T_YIELD) reduce 164) ((T_YIELD_FROM) reduce 164) (("[") reduce 164) (("`") reduce 164) (("{") reduce 164) (("~") reduce 164)) 16771 ((("!") reduce 158) (("\"") reduce 158) (("$") reduce 158) (("(") reduce 158) (("+") reduce 158) (("-") reduce 158) ((";") reduce 158) (("@") reduce 158) ((T_ABSTRACT) reduce 158) ((T_ARRAY) reduce 158) ((T_ARRAY_CAST) reduce 158) ((T_ATTRIBUTE) reduce 158) ((T_BOOL_CAST) reduce 158) ((T_BREAK) reduce 158) ((T_CASE) reduce 158) ((T_CLASS) reduce 158) ((T_CLASS_C) reduce 158) ((T_CLONE) reduce 158) ((T_CONSTANT_ENCAPSED_STRING) reduce 158) ((T_CONTINUE) reduce 158) ((T_DEC) reduce 158) ((T_DECLARE) reduce 158) ((T_DEFAULT) reduce 158) ((T_DIR) reduce 158) ((T_DNUMBER) reduce 158) ((T_DO) reduce 158) ((T_DOUBLE_CAST) reduce 158) ((T_ECHO) reduce 158) ((T_ELSE) reduce 158) ((T_ELSEIF) reduce 158) ((T_EMPTY) reduce 158) ((T_ENDSWITCH) reduce 158) ((T_ENUM) reduce 158) ((T_EVAL) reduce 158) ((T_EXIT) reduce 158) ((T_FILE) reduce 158) ((T_FINAL) reduce 158) ((T_FN) reduce 158) ((T_FOR) reduce 158) ((T_FOREACH) reduce 158) ((T_FUNCTION) reduce 158) ((T_FUNC_C) reduce 158) ((T_GLOBAL) reduce 158) ((T_GOTO) reduce 158) ((T_HALT_COMPILER) reduce 158) ((T_IF) reduce 158) ((T_INC) reduce 158) ((T_INCLUDE) reduce 158) ((T_INCLUDE_ONCE) reduce 158) ((T_INLINE_HTML) reduce 158) ((T_INTERFACE) reduce 158) ((T_INT_CAST) reduce 158) ((T_ISSET) reduce 158) ((T_LINE) reduce 158) ((T_LIST) reduce 158) ((T_LNUMBER) reduce 158) ((T_MATCH) reduce 158) ((T_METHOD_C) reduce 158) ((T_NAME_FULLY_QUALIFIED) reduce 158) ((T_NAME_QUALIFIED) reduce 158) ((T_NAME_RELATIVE) reduce 158) ((T_NEW) reduce 158) ((T_NS_C) reduce 158) ((T_OBJECT_CAST) reduce 158) ((T_PRINT) reduce 158) ((T_READONLY) reduce 158) ((T_REQUIRE) reduce 158) ((T_REQUIRE_ONCE) reduce 158) ((T_RETURN) reduce 158) ((T_START_HEREDOC) reduce 158) ((T_STATIC) reduce 158) ((T_STRING) reduce 158) ((T_STRING_CAST) reduce 158) ((T_SWITCH) reduce 158) ((T_THROW) reduce 158) ((T_TRAIT) reduce 158) ((T_TRAIT_C) reduce 158) ((T_TRY) reduce 158) ((T_UNSET) reduce 158) ((T_UNSET_CAST) reduce 158) ((T_VARIABLE) reduce 158) ((T_WHILE) reduce 158) ((T_YIELD) reduce 158) ((T_YIELD_FROM) reduce 158) (("[") reduce 158) (("`") reduce 158) (("{") reduce 158) (("~") reduce 158)) 16779 ((("!") reduce 147) (("\"") reduce 147) (("$") reduce 147) (("(") reduce 147) (("+") reduce 147) (("-") reduce 147) ((";") reduce 147) (("@") reduce 147) ((T_ABSTRACT) reduce 147) ((T_ARRAY) reduce 147) ((T_ARRAY_CAST) reduce 147) ((T_ATTRIBUTE) reduce 147) ((T_BOOL_CAST) reduce 147) ((T_BREAK) reduce 147) ((T_CASE) reduce 147) ((T_CLASS) reduce 147) ((T_CLASS_C) reduce 147) ((T_CLONE) reduce 147) ((T_CONSTANT_ENCAPSED_STRING) reduce 147) ((T_CONTINUE) reduce 147) ((T_DEC) reduce 147) ((T_DECLARE) reduce 147) ((T_DEFAULT) reduce 147) ((T_DIR) reduce 147) ((T_DNUMBER) reduce 147) ((T_DO) reduce 147) ((T_DOUBLE_CAST) reduce 147) ((T_ECHO) reduce 147) ((T_ELSE) reduce 147) ((T_ELSEIF) reduce 147) ((T_EMPTY) reduce 147) ((T_ENDSWITCH) reduce 147) ((T_ENUM) reduce 147) ((T_EVAL) reduce 147) ((T_EXIT) reduce 147) ((T_FILE) reduce 147) ((T_FINAL) reduce 147) ((T_FN) reduce 147) ((T_FOR) reduce 147) ((T_FOREACH) reduce 147) ((T_FUNCTION) reduce 147) ((T_FUNC_C) reduce 147) ((T_GLOBAL) reduce 147) ((T_GOTO) reduce 147) ((T_HALT_COMPILER) reduce 147) ((T_IF) reduce 147) ((T_INC) reduce 147) ((T_INCLUDE) reduce 147) ((T_INCLUDE_ONCE) reduce 147) ((T_INLINE_HTML) reduce 147) ((T_INTERFACE) reduce 147) ((T_INT_CAST) reduce 147) ((T_ISSET) reduce 147) ((T_LINE) reduce 147) ((T_LIST) reduce 147) ((T_LNUMBER) reduce 147) ((T_MATCH) reduce 147) ((T_METHOD_C) reduce 147) ((T_NAME_FULLY_QUALIFIED) reduce 147) ((T_NAME_QUALIFIED) reduce 147) ((T_NAME_RELATIVE) reduce 147) ((T_NEW) reduce 147) ((T_NS_C) reduce 147) ((T_OBJECT_CAST) reduce 147) ((T_PRINT) reduce 147) ((T_READONLY) reduce 147) ((T_REQUIRE) reduce 147) ((T_REQUIRE_ONCE) reduce 147) ((T_RETURN) reduce 147) ((T_START_HEREDOC) reduce 147) ((T_STATIC) reduce 147) ((T_STRING) reduce 147) ((T_STRING_CAST) reduce 147) ((T_SWITCH) reduce 147) ((T_THROW) reduce 147) ((T_TRAIT) reduce 147) ((T_TRAIT_C) reduce 147) ((T_TRY) reduce 147) ((T_UNSET) reduce 147) ((T_UNSET_CAST) reduce 147) ((T_VARIABLE) reduce 147) ((T_WHILE) reduce 147) ((T_YIELD) reduce 147) ((T_YIELD_FROM) reduce 147) (("[") reduce 147) (("`") reduce 147) (("{") reduce 147) (("~") reduce 147)) 16782 ((("!") reduce 146) (("\"") reduce 146) (("$") reduce 146) (("(") reduce 146) (("+") reduce 146) (("-") reduce 146) ((";") reduce 146) (("@") reduce 146) ((T_ABSTRACT) reduce 146) ((T_ARRAY) reduce 146) ((T_ARRAY_CAST) reduce 146) ((T_ATTRIBUTE) reduce 146) ((T_BOOL_CAST) reduce 146) ((T_BREAK) reduce 146) ((T_CASE) reduce 146) ((T_CLASS) reduce 146) ((T_CLASS_C) reduce 146) ((T_CLONE) reduce 146) ((T_CONSTANT_ENCAPSED_STRING) reduce 146) ((T_CONTINUE) reduce 146) ((T_DEC) reduce 146) ((T_DECLARE) reduce 146) ((T_DEFAULT) reduce 146) ((T_DIR) reduce 146) ((T_DNUMBER) reduce 146) ((T_DO) reduce 146) ((T_DOUBLE_CAST) reduce 146) ((T_ECHO) reduce 146) ((T_ELSE) reduce 146) ((T_ELSEIF) reduce 146) ((T_EMPTY) reduce 146) ((T_ENDSWITCH) reduce 146) ((T_ENUM) reduce 146) ((T_EVAL) reduce 146) ((T_EXIT) reduce 146) ((T_FILE) reduce 146) ((T_FINAL) reduce 146) ((T_FN) reduce 146) ((T_FOR) reduce 146) ((T_FOREACH) reduce 146) ((T_FUNCTION) reduce 146) ((T_FUNC_C) reduce 146) ((T_GLOBAL) reduce 146) ((T_GOTO) reduce 146) ((T_HALT_COMPILER) reduce 146) ((T_IF) reduce 146) ((T_INC) reduce 146) ((T_INCLUDE) reduce 146) ((T_INCLUDE_ONCE) reduce 146) ((T_INLINE_HTML) reduce 146) ((T_INTERFACE) reduce 146) ((T_INT_CAST) reduce 146) ((T_ISSET) reduce 146) ((T_LINE) reduce 146) ((T_LIST) reduce 146) ((T_LNUMBER) reduce 146) ((T_MATCH) reduce 146) ((T_METHOD_C) reduce 146) ((T_NAME_FULLY_QUALIFIED) reduce 146) ((T_NAME_QUALIFIED) reduce 146) ((T_NAME_RELATIVE) reduce 146) ((T_NEW) reduce 146) ((T_NS_C) reduce 146) ((T_OBJECT_CAST) reduce 146) ((T_PRINT) reduce 146) ((T_READONLY) reduce 146) ((T_REQUIRE) reduce 146) ((T_REQUIRE_ONCE) reduce 146) ((T_RETURN) reduce 146) ((T_START_HEREDOC) reduce 146) ((T_STATIC) reduce 146) ((T_STRING) reduce 146) ((T_STRING_CAST) reduce 146) ((T_SWITCH) reduce 146) ((T_THROW) reduce 146) ((T_TRAIT) reduce 146) ((T_TRAIT_C) reduce 146) ((T_TRY) reduce 146) ((T_UNSET) reduce 146) ((T_UNSET_CAST) reduce 146) ((T_VARIABLE) reduce 146) ((T_WHILE) reduce 146) ((T_YIELD) reduce 146) ((T_YIELD_FROM) reduce 146) (("[") reduce 146) (("`") reduce 146) (("{") reduce 146) (("~") reduce 146)) 16784 ((("!") reduce 242) (("\"") reduce 242) (("$") reduce 242) (("(") reduce 242) (("+") reduce 242) (("-") reduce 242) ((";") reduce 242) (("@") reduce 242) ((T_ABSTRACT) reduce 242) ((T_ARRAY) reduce 242) ((T_ARRAY_CAST) reduce 242) ((T_ATTRIBUTE) reduce 242) ((T_BOOL_CAST) reduce 242) ((T_BREAK) reduce 242) ((T_CASE) reduce 242) ((T_CLASS) reduce 242) ((T_CLASS_C) reduce 242) ((T_CLONE) reduce 242) ((T_CONSTANT_ENCAPSED_STRING) reduce 242) ((T_CONTINUE) reduce 242) ((T_DEC) reduce 242) ((T_DECLARE) reduce 242) ((T_DEFAULT) reduce 242) ((T_DIR) reduce 242) ((T_DNUMBER) reduce 242) ((T_DO) reduce 242) ((T_DOUBLE_CAST) reduce 242) ((T_ECHO) reduce 242) ((T_ELSE) reduce 242) ((T_ELSEIF) reduce 242) ((T_EMPTY) reduce 242) ((T_ENDSWITCH) reduce 242) ((T_ENUM) reduce 242) ((T_EVAL) reduce 242) ((T_EXIT) reduce 242) ((T_FILE) reduce 242) ((T_FINAL) reduce 242) ((T_FN) reduce 242) ((T_FOR) reduce 242) ((T_FOREACH) reduce 242) ((T_FUNCTION) reduce 242) ((T_FUNC_C) reduce 242) ((T_GLOBAL) reduce 242) ((T_GOTO) reduce 242) ((T_HALT_COMPILER) reduce 242) ((T_IF) reduce 242) ((T_INC) reduce 242) ((T_INCLUDE) reduce 242) ((T_INCLUDE_ONCE) reduce 242) ((T_INLINE_HTML) reduce 242) ((T_INTERFACE) reduce 242) ((T_INT_CAST) reduce 242) ((T_ISSET) reduce 242) ((T_LINE) reduce 242) ((T_LIST) reduce 242) ((T_LNUMBER) reduce 242) ((T_MATCH) reduce 242) ((T_METHOD_C) reduce 242) ((T_NAME_FULLY_QUALIFIED) reduce 242) ((T_NAME_QUALIFIED) reduce 242) ((T_NAME_RELATIVE) reduce 242) ((T_NEW) reduce 242) ((T_NS_C) reduce 242) ((T_OBJECT_CAST) reduce 242) ((T_PRINT) reduce 242) ((T_READONLY) reduce 242) ((T_REQUIRE) reduce 242) ((T_REQUIRE_ONCE) reduce 242) ((T_RETURN) reduce 242) ((T_START_HEREDOC) reduce 242) ((T_STATIC) reduce 242) ((T_STRING) reduce 242) ((T_STRING_CAST) reduce 242) ((T_SWITCH) reduce 242) ((T_THROW) reduce 242) ((T_TRAIT) reduce 242) ((T_TRAIT_C) reduce 242) ((T_TRY) reduce 242) ((T_UNSET) reduce 242) ((T_UNSET_CAST) reduce 242) ((T_VARIABLE) reduce 242) ((T_WHILE) reduce 242) ((T_YIELD) reduce 242) ((T_YIELD_FROM) reduce 242) (("[") reduce 242) (("`") reduce 242) (("{") reduce 242) (("~") reduce 242)) 16787 ((("!") reduce 145) (("\"") reduce 145) (("$") reduce 145) (("(") reduce 145) (("+") reduce 145) (("-") reduce 145) ((";") reduce 145) (("@") reduce 145) ((T_ABSTRACT) reduce 145) ((T_ARRAY) reduce 145) ((T_ARRAY_CAST) reduce 145) ((T_ATTRIBUTE) reduce 145) ((T_BOOL_CAST) reduce 145) ((T_BREAK) reduce 145) ((T_CASE) reduce 145) ((T_CLASS) reduce 145) ((T_CLASS_C) reduce 145) ((T_CLONE) reduce 145) ((T_CONSTANT_ENCAPSED_STRING) reduce 145) ((T_CONTINUE) reduce 145) ((T_DEC) reduce 145) ((T_DECLARE) reduce 145) ((T_DEFAULT) reduce 145) ((T_DIR) reduce 145) ((T_DNUMBER) reduce 145) ((T_DO) reduce 145) ((T_DOUBLE_CAST) reduce 145) ((T_ECHO) reduce 145) ((T_ELSE) reduce 145) ((T_ELSEIF) reduce 145) ((T_EMPTY) reduce 145) ((T_ENDSWITCH) reduce 145) ((T_ENUM) reduce 145) ((T_EVAL) reduce 145) ((T_EXIT) reduce 145) ((T_FILE) reduce 145) ((T_FINAL) reduce 145) ((T_FN) reduce 145) ((T_FOR) reduce 145) ((T_FOREACH) reduce 145) ((T_FUNCTION) reduce 145) ((T_FUNC_C) reduce 145) ((T_GLOBAL) reduce 145) ((T_GOTO) reduce 145) ((T_HALT_COMPILER) reduce 145) ((T_IF) reduce 145) ((T_INC) reduce 145) ((T_INCLUDE) reduce 145) ((T_INCLUDE_ONCE) reduce 145) ((T_INLINE_HTML) reduce 145) ((T_INTERFACE) reduce 145) ((T_INT_CAST) reduce 145) ((T_ISSET) reduce 145) ((T_LINE) reduce 145) ((T_LIST) reduce 145) ((T_LNUMBER) reduce 145) ((T_MATCH) reduce 145) ((T_METHOD_C) reduce 145) ((T_NAME_FULLY_QUALIFIED) reduce 145) ((T_NAME_QUALIFIED) reduce 145) ((T_NAME_RELATIVE) reduce 145) ((T_NEW) reduce 145) ((T_NS_C) reduce 145) ((T_OBJECT_CAST) reduce 145) ((T_PRINT) reduce 145) ((T_READONLY) reduce 145) ((T_REQUIRE) reduce 145) ((T_REQUIRE_ONCE) reduce 145) ((T_RETURN) reduce 145) ((T_START_HEREDOC) reduce 145) ((T_STATIC) reduce 145) ((T_STRING) reduce 145) ((T_STRING_CAST) reduce 145) ((T_SWITCH) reduce 145) ((T_THROW) reduce 145) ((T_TRAIT) reduce 145) ((T_TRAIT_C) reduce 145) ((T_TRY) reduce 145) ((T_UNSET) reduce 145) ((T_UNSET_CAST) reduce 145) ((T_VARIABLE) reduce 145) ((T_WHILE) reduce 145) ((T_YIELD) reduce 145) ((T_YIELD_FROM) reduce 145) (("[") reduce 145) (("`") reduce 145) (("{") reduce 145) (("~") reduce 145)) 16789 ((("!") reduce 244) (("\"") reduce 244) (("$") reduce 244) (("(") reduce 244) (("+") reduce 244) (("-") reduce 244) ((";") reduce 244) (("@") reduce 244) ((T_ABSTRACT) reduce 244) ((T_ARRAY) reduce 244) ((T_ARRAY_CAST) reduce 244) ((T_ATTRIBUTE) reduce 244) ((T_BOOL_CAST) reduce 244) ((T_BREAK) reduce 244) ((T_CASE) reduce 244) ((T_CLASS) reduce 244) ((T_CLASS_C) reduce 244) ((T_CLONE) reduce 244) ((T_CONSTANT_ENCAPSED_STRING) reduce 244) ((T_CONTINUE) reduce 244) ((T_DEC) reduce 244) ((T_DECLARE) reduce 244) ((T_DEFAULT) reduce 244) ((T_DIR) reduce 244) ((T_DNUMBER) reduce 244) ((T_DO) reduce 244) ((T_DOUBLE_CAST) reduce 244) ((T_ECHO) reduce 244) ((T_ELSE) reduce 244) ((T_ELSEIF) reduce 244) ((T_EMPTY) reduce 244) ((T_ENDSWITCH) reduce 244) ((T_ENUM) reduce 244) ((T_EVAL) reduce 244) ((T_EXIT) reduce 244) ((T_FILE) reduce 244) ((T_FINAL) reduce 244) ((T_FN) reduce 244) ((T_FOR) reduce 244) ((T_FOREACH) reduce 244) ((T_FUNCTION) reduce 244) ((T_FUNC_C) reduce 244) ((T_GLOBAL) reduce 244) ((T_GOTO) reduce 244) ((T_HALT_COMPILER) reduce 244) ((T_IF) reduce 244) ((T_INC) reduce 244) ((T_INCLUDE) reduce 244) ((T_INCLUDE_ONCE) reduce 244) ((T_INLINE_HTML) reduce 244) ((T_INTERFACE) reduce 244) ((T_INT_CAST) reduce 244) ((T_ISSET) reduce 244) ((T_LINE) reduce 244) ((T_LIST) reduce 244) ((T_LNUMBER) reduce 244) ((T_MATCH) reduce 244) ((T_METHOD_C) reduce 244) ((T_NAME_FULLY_QUALIFIED) reduce 244) ((T_NAME_QUALIFIED) reduce 244) ((T_NAME_RELATIVE) reduce 244) ((T_NEW) reduce 244) ((T_NS_C) reduce 244) ((T_OBJECT_CAST) reduce 244) ((T_PRINT) reduce 244) ((T_READONLY) reduce 244) ((T_REQUIRE) reduce 244) ((T_REQUIRE_ONCE) reduce 244) ((T_RETURN) reduce 244) ((T_START_HEREDOC) reduce 244) ((T_STATIC) reduce 244) ((T_STRING) reduce 244) ((T_STRING_CAST) reduce 244) ((T_SWITCH) reduce 244) ((T_THROW) reduce 244) ((T_TRAIT) reduce 244) ((T_TRAIT_C) reduce 244) ((T_TRY) reduce 244) ((T_UNSET) reduce 244) ((T_UNSET_CAST) reduce 244) ((T_VARIABLE) reduce 244) ((T_WHILE) reduce 244) ((T_YIELD) reduce 244) ((T_YIELD_FROM) reduce 244) (("[") reduce 244) (("`") reduce 244) (("{") reduce 244) (("~") reduce 244)) 16790 ((("!") reduce 159) (("\"") reduce 159) (("$") reduce 159) (("(") reduce 159) (("+") reduce 159) (("-") reduce 159) ((";") reduce 159) (("@") reduce 159) ((T_ABSTRACT) reduce 159) ((T_ARRAY) reduce 159) ((T_ARRAY_CAST) reduce 159) ((T_ATTRIBUTE) reduce 159) ((T_BOOL_CAST) reduce 159) ((T_BREAK) reduce 159) ((T_CASE) reduce 159) ((T_CLASS) reduce 159) ((T_CLASS_C) reduce 159) ((T_CLONE) reduce 159) ((T_CONSTANT_ENCAPSED_STRING) reduce 159) ((T_CONTINUE) reduce 159) ((T_DEC) reduce 159) ((T_DECLARE) reduce 159) ((T_DEFAULT) reduce 159) ((T_DIR) reduce 159) ((T_DNUMBER) reduce 159) ((T_DO) reduce 159) ((T_DOUBLE_CAST) reduce 159) ((T_ECHO) reduce 159) ((T_ELSE) reduce 159) ((T_ELSEIF) reduce 159) ((T_EMPTY) reduce 159) ((T_ENDSWITCH) reduce 159) ((T_ENUM) reduce 159) ((T_EVAL) reduce 159) ((T_EXIT) reduce 159) ((T_FILE) reduce 159) ((T_FINAL) reduce 159) ((T_FN) reduce 159) ((T_FOR) reduce 159) ((T_FOREACH) reduce 159) ((T_FUNCTION) reduce 159) ((T_FUNC_C) reduce 159) ((T_GLOBAL) reduce 159) ((T_GOTO) reduce 159) ((T_HALT_COMPILER) reduce 159) ((T_IF) reduce 159) ((T_INC) reduce 159) ((T_INCLUDE) reduce 159) ((T_INCLUDE_ONCE) reduce 159) ((T_INLINE_HTML) reduce 159) ((T_INTERFACE) reduce 159) ((T_INT_CAST) reduce 159) ((T_ISSET) reduce 159) ((T_LINE) reduce 159) ((T_LIST) reduce 159) ((T_LNUMBER) reduce 159) ((T_MATCH) reduce 159) ((T_METHOD_C) reduce 159) ((T_NAME_FULLY_QUALIFIED) reduce 159) ((T_NAME_QUALIFIED) reduce 159) ((T_NAME_RELATIVE) reduce 159) ((T_NEW) reduce 159) ((T_NS_C) reduce 159) ((T_OBJECT_CAST) reduce 159) ((T_PRINT) reduce 159) ((T_READONLY) reduce 159) ((T_REQUIRE) reduce 159) ((T_REQUIRE_ONCE) reduce 159) ((T_RETURN) reduce 159) ((T_START_HEREDOC) reduce 159) ((T_STATIC) reduce 159) ((T_STRING) reduce 159) ((T_STRING_CAST) reduce 159) ((T_SWITCH) reduce 159) ((T_THROW) reduce 159) ((T_TRAIT) reduce 159) ((T_TRAIT_C) reduce 159) ((T_TRY) reduce 159) ((T_UNSET) reduce 159) ((T_UNSET_CAST) reduce 159) ((T_VARIABLE) reduce 159) ((T_WHILE) reduce 159) ((T_YIELD) reduce 159) ((T_YIELD_FROM) reduce 159) (("[") reduce 159) (("`") reduce 159) (("{") reduce 159) (("~") reduce 159)) 16793 ((("!") reduce 247) (("\"") reduce 247) (("$") reduce 247) (("(") reduce 247) (("+") reduce 247) (("-") reduce 247) ((";") reduce 247) (("@") reduce 247) ((T_ABSTRACT) reduce 247) ((T_ARRAY) reduce 247) ((T_ARRAY_CAST) reduce 247) ((T_ATTRIBUTE) reduce 247) ((T_BOOL_CAST) reduce 247) ((T_BREAK) reduce 247) ((T_CASE) reduce 247) ((T_CLASS) reduce 247) ((T_CLASS_C) reduce 247) ((T_CLONE) reduce 247) ((T_CONSTANT_ENCAPSED_STRING) reduce 247) ((T_CONTINUE) reduce 247) ((T_DEC) reduce 247) ((T_DECLARE) reduce 247) ((T_DEFAULT) reduce 247) ((T_DIR) reduce 247) ((T_DNUMBER) reduce 247) ((T_DO) reduce 247) ((T_DOUBLE_CAST) reduce 247) ((T_ECHO) reduce 247) ((T_ELSE) reduce 247) ((T_ELSEIF) reduce 247) ((T_EMPTY) reduce 247) ((T_ENDSWITCH) reduce 247) ((T_ENUM) reduce 247) ((T_EVAL) reduce 247) ((T_EXIT) reduce 247) ((T_FILE) reduce 247) ((T_FINAL) reduce 247) ((T_FN) reduce 247) ((T_FOR) reduce 247) ((T_FOREACH) reduce 247) ((T_FUNCTION) reduce 247) ((T_FUNC_C) reduce 247) ((T_GLOBAL) reduce 247) ((T_GOTO) reduce 247) ((T_HALT_COMPILER) reduce 247) ((T_IF) reduce 247) ((T_INC) reduce 247) ((T_INCLUDE) reduce 247) ((T_INCLUDE_ONCE) reduce 247) ((T_INLINE_HTML) reduce 247) ((T_INTERFACE) reduce 247) ((T_INT_CAST) reduce 247) ((T_ISSET) reduce 247) ((T_LINE) reduce 247) ((T_LIST) reduce 247) ((T_LNUMBER) reduce 247) ((T_MATCH) reduce 247) ((T_METHOD_C) reduce 247) ((T_NAME_FULLY_QUALIFIED) reduce 247) ((T_NAME_QUALIFIED) reduce 247) ((T_NAME_RELATIVE) reduce 247) ((T_NEW) reduce 247) ((T_NS_C) reduce 247) ((T_OBJECT_CAST) reduce 247) ((T_PRINT) reduce 247) ((T_READONLY) reduce 247) ((T_REQUIRE) reduce 247) ((T_REQUIRE_ONCE) reduce 247) ((T_RETURN) reduce 247) ((T_START_HEREDOC) reduce 247) ((T_STATIC) reduce 247) ((T_STRING) reduce 247) ((T_STRING_CAST) reduce 247) ((T_SWITCH) reduce 247) ((T_THROW) reduce 247) ((T_TRAIT) reduce 247) ((T_TRAIT_C) reduce 247) ((T_TRY) reduce 247) ((T_UNSET) reduce 247) ((T_UNSET_CAST) reduce 247) ((T_VARIABLE) reduce 247) ((T_WHILE) reduce 247) ((T_YIELD) reduce 247) ((T_YIELD_FROM) reduce 247) (("[") reduce 247) (("`") reduce 247) (("{") reduce 247) (("~") reduce 247)) 16797 ((("!") reduce 248) (("\"") reduce 248) (("$") reduce 248) (("(") reduce 248) (("+") reduce 248) (("-") reduce 248) ((";") reduce 248) (("@") reduce 248) ((T_ABSTRACT) reduce 248) ((T_ARRAY) reduce 248) ((T_ARRAY_CAST) reduce 248) ((T_ATTRIBUTE) reduce 248) ((T_BOOL_CAST) reduce 248) ((T_BREAK) reduce 248) ((T_CASE) reduce 248) ((T_CLASS) reduce 248) ((T_CLASS_C) reduce 248) ((T_CLONE) reduce 248) ((T_CONSTANT_ENCAPSED_STRING) reduce 248) ((T_CONTINUE) reduce 248) ((T_DEC) reduce 248) ((T_DECLARE) reduce 248) ((T_DEFAULT) reduce 248) ((T_DIR) reduce 248) ((T_DNUMBER) reduce 248) ((T_DO) reduce 248) ((T_DOUBLE_CAST) reduce 248) ((T_ECHO) reduce 248) ((T_ELSE) reduce 248) ((T_ELSEIF) reduce 248) ((T_EMPTY) reduce 248) ((T_ENDSWITCH) reduce 248) ((T_ENUM) reduce 248) ((T_EVAL) reduce 248) ((T_EXIT) reduce 248) ((T_FILE) reduce 248) ((T_FINAL) reduce 248) ((T_FN) reduce 248) ((T_FOR) reduce 248) ((T_FOREACH) reduce 248) ((T_FUNCTION) reduce 248) ((T_FUNC_C) reduce 248) ((T_GLOBAL) reduce 248) ((T_GOTO) reduce 248) ((T_HALT_COMPILER) reduce 248) ((T_IF) reduce 248) ((T_INC) reduce 248) ((T_INCLUDE) reduce 248) ((T_INCLUDE_ONCE) reduce 248) ((T_INLINE_HTML) reduce 248) ((T_INTERFACE) reduce 248) ((T_INT_CAST) reduce 248) ((T_ISSET) reduce 248) ((T_LINE) reduce 248) ((T_LIST) reduce 248) ((T_LNUMBER) reduce 248) ((T_MATCH) reduce 248) ((T_METHOD_C) reduce 248) ((T_NAME_FULLY_QUALIFIED) reduce 248) ((T_NAME_QUALIFIED) reduce 248) ((T_NAME_RELATIVE) reduce 248) ((T_NEW) reduce 248) ((T_NS_C) reduce 248) ((T_OBJECT_CAST) reduce 248) ((T_PRINT) reduce 248) ((T_READONLY) reduce 248) ((T_REQUIRE) reduce 248) ((T_REQUIRE_ONCE) reduce 248) ((T_RETURN) reduce 248) ((T_START_HEREDOC) reduce 248) ((T_STATIC) reduce 248) ((T_STRING) reduce 248) ((T_STRING_CAST) reduce 248) ((T_SWITCH) reduce 248) ((T_THROW) reduce 248) ((T_TRAIT) reduce 248) ((T_TRAIT_C) reduce 248) ((T_TRY) reduce 248) ((T_UNSET) reduce 248) ((T_UNSET_CAST) reduce 248) ((T_VARIABLE) reduce 248) ((T_WHILE) reduce 248) ((T_YIELD) reduce 248) ((T_YIELD_FROM) reduce 248) (("[") reduce 248) (("`") reduce 248) (("{") reduce 248) (("~") reduce 248)) 16802 ((("!") reduce 239) (("\"") reduce 239) (("$") reduce 239) (("(") reduce 239) (("+") reduce 239) (("-") reduce 239) ((";") reduce 239) (("@") reduce 239) ((T_ABSTRACT) reduce 239) ((T_ARRAY) reduce 239) ((T_ARRAY_CAST) reduce 239) ((T_ATTRIBUTE) reduce 239) ((T_BOOL_CAST) reduce 239) ((T_BREAK) reduce 239) ((T_CASE) reduce 239) ((T_CLASS) reduce 239) ((T_CLASS_C) reduce 239) ((T_CLONE) reduce 239) ((T_CONSTANT_ENCAPSED_STRING) reduce 239) ((T_CONTINUE) reduce 239) ((T_DEC) reduce 239) ((T_DECLARE) reduce 239) ((T_DEFAULT) reduce 239) ((T_DIR) reduce 239) ((T_DNUMBER) reduce 239) ((T_DO) reduce 239) ((T_DOUBLE_CAST) reduce 239) ((T_ECHO) reduce 239) ((T_ELSE) reduce 239) ((T_ELSEIF) reduce 239) ((T_EMPTY) reduce 239) ((T_ENDSWITCH) reduce 239) ((T_ENUM) reduce 239) ((T_EVAL) reduce 239) ((T_EXIT) reduce 239) ((T_FILE) reduce 239) ((T_FINAL) reduce 239) ((T_FN) reduce 239) ((T_FOR) reduce 239) ((T_FOREACH) reduce 239) ((T_FUNCTION) reduce 239) ((T_FUNC_C) reduce 239) ((T_GLOBAL) reduce 239) ((T_GOTO) reduce 239) ((T_HALT_COMPILER) reduce 239) ((T_IF) reduce 239) ((T_INC) reduce 239) ((T_INCLUDE) reduce 239) ((T_INCLUDE_ONCE) reduce 239) ((T_INLINE_HTML) reduce 239) ((T_INTERFACE) reduce 239) ((T_INT_CAST) reduce 239) ((T_ISSET) reduce 239) ((T_LINE) reduce 239) ((T_LIST) reduce 239) ((T_LNUMBER) reduce 239) ((T_MATCH) reduce 239) ((T_METHOD_C) reduce 239) ((T_NAME_FULLY_QUALIFIED) reduce 239) ((T_NAME_QUALIFIED) reduce 239) ((T_NAME_RELATIVE) reduce 239) ((T_NEW) reduce 239) ((T_NS_C) reduce 239) ((T_OBJECT_CAST) reduce 239) ((T_PRINT) reduce 239) ((T_READONLY) reduce 239) ((T_REQUIRE) reduce 239) ((T_REQUIRE_ONCE) reduce 239) ((T_RETURN) reduce 239) ((T_START_HEREDOC) reduce 239) ((T_STATIC) reduce 239) ((T_STRING) reduce 239) ((T_STRING_CAST) reduce 239) ((T_SWITCH) reduce 239) ((T_THROW) reduce 239) ((T_TRAIT) reduce 239) ((T_TRAIT_C) reduce 239) ((T_TRY) reduce 239) ((T_UNSET) reduce 239) ((T_UNSET_CAST) reduce 239) ((T_VARIABLE) reduce 239) ((T_WHILE) reduce 239) ((T_YIELD) reduce 239) ((T_YIELD_FROM) reduce 239) (("[") reduce 239) (("`") reduce 239) (("{") reduce 239) (("~") reduce 239)) 16803 ((("!") reduce 148) (("\"") reduce 148) (("$") reduce 148) (("(") reduce 148) (("+") reduce 148) (("-") reduce 148) ((";") reduce 148) (("@") reduce 148) ((T_ABSTRACT) reduce 148) ((T_ARRAY) reduce 148) ((T_ARRAY_CAST) reduce 148) ((T_ATTRIBUTE) reduce 148) ((T_BOOL_CAST) reduce 148) ((T_BREAK) reduce 148) ((T_CASE) reduce 148) ((T_CLASS) reduce 148) ((T_CLASS_C) reduce 148) ((T_CLONE) reduce 148) ((T_CONSTANT_ENCAPSED_STRING) reduce 148) ((T_CONTINUE) reduce 148) ((T_DEC) reduce 148) ((T_DECLARE) reduce 148) ((T_DEFAULT) reduce 148) ((T_DIR) reduce 148) ((T_DNUMBER) reduce 148) ((T_DO) reduce 148) ((T_DOUBLE_CAST) reduce 148) ((T_ECHO) reduce 148) ((T_ELSE) reduce 148) ((T_ELSEIF) reduce 148) ((T_EMPTY) reduce 148) ((T_ENDSWITCH) reduce 148) ((T_ENUM) reduce 148) ((T_EVAL) reduce 148) ((T_EXIT) reduce 148) ((T_FILE) reduce 148) ((T_FINAL) reduce 148) ((T_FN) reduce 148) ((T_FOR) reduce 148) ((T_FOREACH) reduce 148) ((T_FUNCTION) reduce 148) ((T_FUNC_C) reduce 148) ((T_GLOBAL) reduce 148) ((T_GOTO) reduce 148) ((T_HALT_COMPILER) reduce 148) ((T_IF) reduce 148) ((T_INC) reduce 148) ((T_INCLUDE) reduce 148) ((T_INCLUDE_ONCE) reduce 148) ((T_INLINE_HTML) reduce 148) ((T_INTERFACE) reduce 148) ((T_INT_CAST) reduce 148) ((T_ISSET) reduce 148) ((T_LINE) reduce 148) ((T_LIST) reduce 148) ((T_LNUMBER) reduce 148) ((T_MATCH) reduce 148) ((T_METHOD_C) reduce 148) ((T_NAME_FULLY_QUALIFIED) reduce 148) ((T_NAME_QUALIFIED) reduce 148) ((T_NAME_RELATIVE) reduce 148) ((T_NEW) reduce 148) ((T_NS_C) reduce 148) ((T_OBJECT_CAST) reduce 148) ((T_PRINT) reduce 148) ((T_READONLY) reduce 148) ((T_REQUIRE) reduce 148) ((T_REQUIRE_ONCE) reduce 148) ((T_RETURN) reduce 148) ((T_START_HEREDOC) reduce 148) ((T_STATIC) reduce 148) ((T_STRING) reduce 148) ((T_STRING_CAST) reduce 148) ((T_SWITCH) reduce 148) ((T_THROW) reduce 148) ((T_TRAIT) reduce 148) ((T_TRAIT_C) reduce 148) ((T_TRY) reduce 148) ((T_UNSET) reduce 148) ((T_UNSET_CAST) reduce 148) ((T_VARIABLE) reduce 148) ((T_WHILE) reduce 148) ((T_YIELD) reduce 148) ((T_YIELD_FROM) reduce 148) (("[") reduce 148) (("`") reduce 148) (("{") reduce 148) (("~") reduce 148)) 16806 ((("!") reduce 240) (("\"") reduce 240) (("$") reduce 240) (("(") reduce 240) (("+") reduce 240) (("-") reduce 240) ((";") reduce 240) (("@") reduce 240) ((T_ABSTRACT) reduce 240) ((T_ARRAY) reduce 240) ((T_ARRAY_CAST) reduce 240) ((T_ATTRIBUTE) reduce 240) ((T_BOOL_CAST) reduce 240) ((T_BREAK) reduce 240) ((T_CASE) reduce 240) ((T_CLASS) reduce 240) ((T_CLASS_C) reduce 240) ((T_CLONE) reduce 240) ((T_CONSTANT_ENCAPSED_STRING) reduce 240) ((T_CONTINUE) reduce 240) ((T_DEC) reduce 240) ((T_DECLARE) reduce 240) ((T_DEFAULT) reduce 240) ((T_DIR) reduce 240) ((T_DNUMBER) reduce 240) ((T_DO) reduce 240) ((T_DOUBLE_CAST) reduce 240) ((T_ECHO) reduce 240) ((T_ELSE) reduce 240) ((T_ELSEIF) reduce 240) ((T_EMPTY) reduce 240) ((T_ENDSWITCH) reduce 240) ((T_ENUM) reduce 240) ((T_EVAL) reduce 240) ((T_EXIT) reduce 240) ((T_FILE) reduce 240) ((T_FINAL) reduce 240) ((T_FN) reduce 240) ((T_FOR) reduce 240) ((T_FOREACH) reduce 240) ((T_FUNCTION) reduce 240) ((T_FUNC_C) reduce 240) ((T_GLOBAL) reduce 240) ((T_GOTO) reduce 240) ((T_HALT_COMPILER) reduce 240) ((T_IF) reduce 240) ((T_INC) reduce 240) ((T_INCLUDE) reduce 240) ((T_INCLUDE_ONCE) reduce 240) ((T_INLINE_HTML) reduce 240) ((T_INTERFACE) reduce 240) ((T_INT_CAST) reduce 240) ((T_ISSET) reduce 240) ((T_LINE) reduce 240) ((T_LIST) reduce 240) ((T_LNUMBER) reduce 240) ((T_MATCH) reduce 240) ((T_METHOD_C) reduce 240) ((T_NAME_FULLY_QUALIFIED) reduce 240) ((T_NAME_QUALIFIED) reduce 240) ((T_NAME_RELATIVE) reduce 240) ((T_NEW) reduce 240) ((T_NS_C) reduce 240) ((T_OBJECT_CAST) reduce 240) ((T_PRINT) reduce 240) ((T_READONLY) reduce 240) ((T_REQUIRE) reduce 240) ((T_REQUIRE_ONCE) reduce 240) ((T_RETURN) reduce 240) ((T_START_HEREDOC) reduce 240) ((T_STATIC) reduce 240) ((T_STRING) reduce 240) ((T_STRING_CAST) reduce 240) ((T_SWITCH) reduce 240) ((T_THROW) reduce 240) ((T_TRAIT) reduce 240) ((T_TRAIT_C) reduce 240) ((T_TRY) reduce 240) ((T_UNSET) reduce 240) ((T_UNSET_CAST) reduce 240) ((T_VARIABLE) reduce 240) ((T_WHILE) reduce 240) ((T_YIELD) reduce 240) ((T_YIELD_FROM) reduce 240) (("[") reduce 240) (("`") reduce 240) (("{") reduce 240) (("~") reduce 240)) 16811 ((("!") reduce 160) (("\"") reduce 160) (("$") reduce 160) (("(") reduce 160) (("+") reduce 160) (("-") reduce 160) ((";") reduce 160) (("@") reduce 160) ((T_ABSTRACT) reduce 160) ((T_ARRAY) reduce 160) ((T_ARRAY_CAST) reduce 160) ((T_ATTRIBUTE) reduce 160) ((T_BOOL_CAST) reduce 160) ((T_BREAK) reduce 160) ((T_CASE) reduce 160) ((T_CLASS) reduce 160) ((T_CLASS_C) reduce 160) ((T_CLONE) reduce 160) ((T_CONSTANT_ENCAPSED_STRING) reduce 160) ((T_CONTINUE) reduce 160) ((T_DEC) reduce 160) ((T_DECLARE) reduce 160) ((T_DEFAULT) reduce 160) ((T_DIR) reduce 160) ((T_DNUMBER) reduce 160) ((T_DO) reduce 160) ((T_DOUBLE_CAST) reduce 160) ((T_ECHO) reduce 160) ((T_ELSE) reduce 160) ((T_ELSEIF) reduce 160) ((T_EMPTY) reduce 160) ((T_ENDSWITCH) reduce 160) ((T_ENUM) reduce 160) ((T_EVAL) reduce 160) ((T_EXIT) reduce 160) ((T_FILE) reduce 160) ((T_FINAL) reduce 160) ((T_FN) reduce 160) ((T_FOR) reduce 160) ((T_FOREACH) reduce 160) ((T_FUNCTION) reduce 160) ((T_FUNC_C) reduce 160) ((T_GLOBAL) reduce 160) ((T_GOTO) reduce 160) ((T_HALT_COMPILER) reduce 160) ((T_IF) reduce 160) ((T_INC) reduce 160) ((T_INCLUDE) reduce 160) ((T_INCLUDE_ONCE) reduce 160) ((T_INLINE_HTML) reduce 160) ((T_INTERFACE) reduce 160) ((T_INT_CAST) reduce 160) ((T_ISSET) reduce 160) ((T_LINE) reduce 160) ((T_LIST) reduce 160) ((T_LNUMBER) reduce 160) ((T_MATCH) reduce 160) ((T_METHOD_C) reduce 160) ((T_NAME_FULLY_QUALIFIED) reduce 160) ((T_NAME_QUALIFIED) reduce 160) ((T_NAME_RELATIVE) reduce 160) ((T_NEW) reduce 160) ((T_NS_C) reduce 160) ((T_OBJECT_CAST) reduce 160) ((T_PRINT) reduce 160) ((T_READONLY) reduce 160) ((T_REQUIRE) reduce 160) ((T_REQUIRE_ONCE) reduce 160) ((T_RETURN) reduce 160) ((T_START_HEREDOC) reduce 160) ((T_STATIC) reduce 160) ((T_STRING) reduce 160) ((T_STRING_CAST) reduce 160) ((T_SWITCH) reduce 160) ((T_THROW) reduce 160) ((T_TRAIT) reduce 160) ((T_TRAIT_C) reduce 160) ((T_TRY) reduce 160) ((T_UNSET) reduce 160) ((T_UNSET_CAST) reduce 160) ((T_VARIABLE) reduce 160) ((T_WHILE) reduce 160) ((T_YIELD) reduce 160) ((T_YIELD_FROM) reduce 160) (("[") reduce 160) (("`") reduce 160) (("{") reduce 160) (("~") reduce 160)) 16814 ((("!") reduce 168) (("\"") reduce 168) (("$") reduce 168) (("(") reduce 168) (("+") reduce 168) (("-") reduce 168) ((";") reduce 168) (("@") reduce 168) ((T_ABSTRACT) reduce 168) ((T_ARRAY) reduce 168) ((T_ARRAY_CAST) reduce 168) ((T_ATTRIBUTE) reduce 168) ((T_BOOL_CAST) reduce 168) ((T_BREAK) reduce 168) ((T_CASE) reduce 168) ((T_CATCH) reduce 168) ((T_CLASS) reduce 168) ((T_CLASS_C) reduce 168) ((T_CLONE) reduce 168) ((T_CONSTANT_ENCAPSED_STRING) reduce 168) ((T_CONTINUE) reduce 168) ((T_DEC) reduce 168) ((T_DECLARE) reduce 168) ((T_DEFAULT) reduce 168) ((T_DIR) reduce 168) ((T_DNUMBER) reduce 168) ((T_DO) reduce 168) ((T_DOUBLE_CAST) reduce 168) ((T_ECHO) reduce 168) ((T_ELSE) reduce 168) ((T_ELSEIF) reduce 168) ((T_EMPTY) reduce 168) ((T_ENDSWITCH) reduce 168) ((T_ENUM) reduce 168) ((T_EVAL) reduce 168) ((T_EXIT) reduce 168) ((T_FILE) reduce 168) ((T_FINAL) reduce 168) ((T_FINALLY) reduce 168) ((T_FN) reduce 168) ((T_FOR) reduce 168) ((T_FOREACH) reduce 168) ((T_FUNCTION) reduce 168) ((T_FUNC_C) reduce 168) ((T_GLOBAL) reduce 168) ((T_GOTO) reduce 168) ((T_HALT_COMPILER) reduce 168) ((T_IF) reduce 168) ((T_INC) reduce 168) ((T_INCLUDE) reduce 168) ((T_INCLUDE_ONCE) reduce 168) ((T_INLINE_HTML) reduce 168) ((T_INTERFACE) reduce 168) ((T_INT_CAST) reduce 168) ((T_ISSET) reduce 168) ((T_LINE) reduce 168) ((T_LIST) reduce 168) ((T_LNUMBER) reduce 168) ((T_MATCH) reduce 168) ((T_METHOD_C) reduce 168) ((T_NAME_FULLY_QUALIFIED) reduce 168) ((T_NAME_QUALIFIED) reduce 168) ((T_NAME_RELATIVE) reduce 168) ((T_NEW) reduce 168) ((T_NS_C) reduce 168) ((T_OBJECT_CAST) reduce 168) ((T_PRINT) reduce 168) ((T_READONLY) reduce 168) ((T_REQUIRE) reduce 168) ((T_REQUIRE_ONCE) reduce 168) ((T_RETURN) reduce 168) ((T_START_HEREDOC) reduce 168) ((T_STATIC) reduce 168) ((T_STRING) reduce 168) ((T_STRING_CAST) reduce 168) ((T_SWITCH) reduce 168) ((T_THROW) reduce 168) ((T_TRAIT) reduce 168) ((T_TRAIT_C) reduce 168) ((T_TRY) reduce 168) ((T_UNSET) reduce 168) ((T_UNSET_CAST) reduce 168) ((T_VARIABLE) reduce 168) ((T_WHILE) reduce 168) ((T_YIELD) reduce 168) ((T_YIELD_FROM) reduce 168) (("[") reduce 168) (("`") reduce 168) (("{") reduce 168) (("~") reduce 168)) 16815 ((("!") reduce 174) (("\"") reduce 174) (("$") reduce 174) (("(") reduce 174) (("+") reduce 174) (("-") reduce 174) ((";") reduce 174) (("@") reduce 174) ((T_ABSTRACT) reduce 174) ((T_ARRAY) reduce 174) ((T_ARRAY_CAST) reduce 174) ((T_ATTRIBUTE) reduce 174) ((T_BOOL_CAST) reduce 174) ((T_BREAK) reduce 174) ((T_CASE) reduce 174) ((T_CATCH) shift) ((T_CLASS) reduce 174) ((T_CLASS_C) reduce 174) ((T_CLONE) reduce 174) ((T_CONSTANT_ENCAPSED_STRING) reduce 174) ((T_CONTINUE) reduce 174) ((T_DEC) reduce 174) ((T_DECLARE) reduce 174) ((T_DEFAULT) reduce 174) ((T_DIR) reduce 174) ((T_DNUMBER) reduce 174) ((T_DO) reduce 174) ((T_DOUBLE_CAST) reduce 174) ((T_ECHO) reduce 174) ((T_ELSE) reduce 174) ((T_ELSEIF) reduce 174) ((T_EMPTY) reduce 174) ((T_ENDSWITCH) reduce 174) ((T_ENUM) reduce 174) ((T_EVAL) reduce 174) ((T_EXIT) reduce 174) ((T_FILE) reduce 174) ((T_FINAL) reduce 174) ((T_FINALLY) shift) ((T_FN) reduce 174) ((T_FOR) reduce 174) ((T_FOREACH) reduce 174) ((T_FUNCTION) reduce 174) ((T_FUNC_C) reduce 174) ((T_GLOBAL) reduce 174) ((T_GOTO) reduce 174) ((T_HALT_COMPILER) reduce 174) ((T_IF) reduce 174) ((T_INC) reduce 174) ((T_INCLUDE) reduce 174) ((T_INCLUDE_ONCE) reduce 174) ((T_INLINE_HTML) reduce 174) ((T_INTERFACE) reduce 174) ((T_INT_CAST) reduce 174) ((T_ISSET) reduce 174) ((T_LINE) reduce 174) ((T_LIST) reduce 174) ((T_LNUMBER) reduce 174) ((T_MATCH) reduce 174) ((T_METHOD_C) reduce 174) ((T_NAME_FULLY_QUALIFIED) reduce 174) ((T_NAME_QUALIFIED) reduce 174) ((T_NAME_RELATIVE) reduce 174) ((T_NEW) reduce 174) ((T_NS_C) reduce 174) ((T_OBJECT_CAST) reduce 174) ((T_PRINT) reduce 174) ((T_READONLY) reduce 174) ((T_REQUIRE) reduce 174) ((T_REQUIRE_ONCE) reduce 174) ((T_RETURN) reduce 174) ((T_START_HEREDOC) reduce 174) ((T_STATIC) reduce 174) ((T_STRING) reduce 174) ((T_STRING_CAST) reduce 174) ((T_SWITCH) reduce 174) ((T_THROW) reduce 174) ((T_TRAIT) reduce 174) ((T_TRAIT_C) reduce 174) ((T_TRY) reduce 174) ((T_UNSET) reduce 174) ((T_UNSET_CAST) reduce 174) ((T_VARIABLE) reduce 174) ((T_WHILE) reduce 174) ((T_YIELD) reduce 174) ((T_YIELD_FROM) reduce 174) (("[") reduce 174) (("`") reduce 174) (("{") reduce 174) (("~") reduce 174)) 16818 ((("!") reduce 165) (("\"") reduce 165) (("$") reduce 165) (("(") reduce 165) (("+") reduce 165) (("-") reduce 165) ((";") reduce 165) (("@") reduce 165) ((T_ABSTRACT) reduce 165) ((T_ARRAY) reduce 165) ((T_ARRAY_CAST) reduce 165) ((T_ATTRIBUTE) reduce 165) ((T_BOOL_CAST) reduce 165) ((T_BREAK) reduce 165) ((T_CASE) reduce 165) ((T_CLASS) reduce 165) ((T_CLASS_C) reduce 165) ((T_CLONE) reduce 165) ((T_CONSTANT_ENCAPSED_STRING) reduce 165) ((T_CONTINUE) reduce 165) ((T_DEC) reduce 165) ((T_DECLARE) reduce 165) ((T_DEFAULT) reduce 165) ((T_DIR) reduce 165) ((T_DNUMBER) reduce 165) ((T_DO) reduce 165) ((T_DOUBLE_CAST) reduce 165) ((T_ECHO) reduce 165) ((T_ELSE) reduce 165) ((T_ELSEIF) reduce 165) ((T_EMPTY) reduce 165) ((T_ENDSWITCH) reduce 165) ((T_ENUM) reduce 165) ((T_EVAL) reduce 165) ((T_EXIT) reduce 165) ((T_FILE) reduce 165) ((T_FINAL) reduce 165) ((T_FN) reduce 165) ((T_FOR) reduce 165) ((T_FOREACH) reduce 165) ((T_FUNCTION) reduce 165) ((T_FUNC_C) reduce 165) ((T_GLOBAL) reduce 165) ((T_GOTO) reduce 165) ((T_HALT_COMPILER) reduce 165) ((T_IF) reduce 165) ((T_INC) reduce 165) ((T_INCLUDE) reduce 165) ((T_INCLUDE_ONCE) reduce 165) ((T_INLINE_HTML) reduce 165) ((T_INTERFACE) reduce 165) ((T_INT_CAST) reduce 165) ((T_ISSET) reduce 165) ((T_LINE) reduce 165) ((T_LIST) reduce 165) ((T_LNUMBER) reduce 165) ((T_MATCH) reduce 165) ((T_METHOD_C) reduce 165) ((T_NAME_FULLY_QUALIFIED) reduce 165) ((T_NAME_QUALIFIED) reduce 165) ((T_NAME_RELATIVE) reduce 165) ((T_NEW) reduce 165) ((T_NS_C) reduce 165) ((T_OBJECT_CAST) reduce 165) ((T_PRINT) reduce 165) ((T_READONLY) reduce 165) ((T_REQUIRE) reduce 165) ((T_REQUIRE_ONCE) reduce 165) ((T_RETURN) reduce 165) ((T_START_HEREDOC) reduce 165) ((T_STATIC) reduce 165) ((T_STRING) reduce 165) ((T_STRING_CAST) reduce 165) ((T_SWITCH) reduce 165) ((T_THROW) reduce 165) ((T_TRAIT) reduce 165) ((T_TRAIT_C) reduce 165) ((T_TRY) reduce 165) ((T_UNSET) reduce 165) ((T_UNSET_CAST) reduce 165) ((T_VARIABLE) reduce 165) ((T_WHILE) reduce 165) ((T_YIELD) reduce 165) ((T_YIELD_FROM) reduce 165) (("[") reduce 165) (("`") reduce 165) (("{") reduce 165) (("~") reduce 165)) 16821 ((("!") reduce 175) (("\"") reduce 175) (("$") reduce 175) (("(") reduce 175) (("+") reduce 175) (("-") reduce 175) ((";") reduce 175) (("@") reduce 175) ((T_ABSTRACT) reduce 175) ((T_ARRAY) reduce 175) ((T_ARRAY_CAST) reduce 175) ((T_ATTRIBUTE) reduce 175) ((T_BOOL_CAST) reduce 175) ((T_BREAK) reduce 175) ((T_CASE) reduce 175) ((T_CLASS) reduce 175) ((T_CLASS_C) reduce 175) ((T_CLONE) reduce 175) ((T_CONSTANT_ENCAPSED_STRING) reduce 175) ((T_CONTINUE) reduce 175) ((T_DEC) reduce 175) ((T_DECLARE) reduce 175) ((T_DEFAULT) reduce 175) ((T_DIR) reduce 175) ((T_DNUMBER) reduce 175) ((T_DO) reduce 175) ((T_DOUBLE_CAST) reduce 175) ((T_ECHO) reduce 175) ((T_ELSE) reduce 175) ((T_ELSEIF) reduce 175) ((T_EMPTY) reduce 175) ((T_ENDSWITCH) reduce 175) ((T_ENUM) reduce 175) ((T_EVAL) reduce 175) ((T_EXIT) reduce 175) ((T_FILE) reduce 175) ((T_FINAL) reduce 175) ((T_FN) reduce 175) ((T_FOR) reduce 175) ((T_FOREACH) reduce 175) ((T_FUNCTION) reduce 175) ((T_FUNC_C) reduce 175) ((T_GLOBAL) reduce 175) ((T_GOTO) reduce 175) ((T_HALT_COMPILER) reduce 175) ((T_IF) reduce 175) ((T_INC) reduce 175) ((T_INCLUDE) reduce 175) ((T_INCLUDE_ONCE) reduce 175) ((T_INLINE_HTML) reduce 175) ((T_INTERFACE) reduce 175) ((T_INT_CAST) reduce 175) ((T_ISSET) reduce 175) ((T_LINE) reduce 175) ((T_LIST) reduce 175) ((T_LNUMBER) reduce 175) ((T_MATCH) reduce 175) ((T_METHOD_C) reduce 175) ((T_NAME_FULLY_QUALIFIED) reduce 175) ((T_NAME_QUALIFIED) reduce 175) ((T_NAME_RELATIVE) reduce 175) ((T_NEW) reduce 175) ((T_NS_C) reduce 175) ((T_OBJECT_CAST) reduce 175) ((T_PRINT) reduce 175) ((T_READONLY) reduce 175) ((T_REQUIRE) reduce 175) ((T_REQUIRE_ONCE) reduce 175) ((T_RETURN) reduce 175) ((T_START_HEREDOC) reduce 175) ((T_STATIC) reduce 175) ((T_STRING) reduce 175) ((T_STRING_CAST) reduce 175) ((T_SWITCH) reduce 175) ((T_THROW) reduce 175) ((T_TRAIT) reduce 175) ((T_TRAIT_C) reduce 175) ((T_TRY) reduce 175) ((T_UNSET) reduce 175) ((T_UNSET_CAST) reduce 175) ((T_VARIABLE) reduce 175) ((T_WHILE) reduce 175) ((T_YIELD) reduce 175) ((T_YIELD_FROM) reduce 175) (("[") reduce 175) (("`") reduce 175) (("{") reduce 175) (("~") reduce 175)) 16828 ((("!") reduce 169) (("\"") reduce 169) (("$") reduce 169) (("(") reduce 169) (("+") reduce 169) (("-") reduce 169) ((";") reduce 169) (("@") reduce 169) ((T_ABSTRACT) reduce 169) ((T_ARRAY) reduce 169) ((T_ARRAY_CAST) reduce 169) ((T_ATTRIBUTE) reduce 169) ((T_BOOL_CAST) reduce 169) ((T_BREAK) reduce 169) ((T_CASE) reduce 169) ((T_CATCH) reduce 169) ((T_CLASS) reduce 169) ((T_CLASS_C) reduce 169) ((T_CLONE) reduce 169) ((T_CONSTANT_ENCAPSED_STRING) reduce 169) ((T_CONTINUE) reduce 169) ((T_DEC) reduce 169) ((T_DECLARE) reduce 169) ((T_DEFAULT) reduce 169) ((T_DIR) reduce 169) ((T_DNUMBER) reduce 169) ((T_DO) reduce 169) ((T_DOUBLE_CAST) reduce 169) ((T_ECHO) reduce 169) ((T_ELSE) reduce 169) ((T_ELSEIF) reduce 169) ((T_EMPTY) reduce 169) ((T_ENDSWITCH) reduce 169) ((T_ENUM) reduce 169) ((T_EVAL) reduce 169) ((T_EXIT) reduce 169) ((T_FILE) reduce 169) ((T_FINAL) reduce 169) ((T_FINALLY) reduce 169) ((T_FN) reduce 169) ((T_FOR) reduce 169) ((T_FOREACH) reduce 169) ((T_FUNCTION) reduce 169) ((T_FUNC_C) reduce 169) ((T_GLOBAL) reduce 169) ((T_GOTO) reduce 169) ((T_HALT_COMPILER) reduce 169) ((T_IF) reduce 169) ((T_INC) reduce 169) ((T_INCLUDE) reduce 169) ((T_INCLUDE_ONCE) reduce 169) ((T_INLINE_HTML) reduce 169) ((T_INTERFACE) reduce 169) ((T_INT_CAST) reduce 169) ((T_ISSET) reduce 169) ((T_LINE) reduce 169) ((T_LIST) reduce 169) ((T_LNUMBER) reduce 169) ((T_MATCH) reduce 169) ((T_METHOD_C) reduce 169) ((T_NAME_FULLY_QUALIFIED) reduce 169) ((T_NAME_QUALIFIED) reduce 169) ((T_NAME_RELATIVE) reduce 169) ((T_NEW) reduce 169) ((T_NS_C) reduce 169) ((T_OBJECT_CAST) reduce 169) ((T_PRINT) reduce 169) ((T_READONLY) reduce 169) ((T_REQUIRE) reduce 169) ((T_REQUIRE_ONCE) reduce 169) ((T_RETURN) reduce 169) ((T_START_HEREDOC) reduce 169) ((T_STATIC) reduce 169) ((T_STRING) reduce 169) ((T_STRING_CAST) reduce 169) ((T_SWITCH) reduce 169) ((T_THROW) reduce 169) ((T_TRAIT) reduce 169) ((T_TRAIT_C) reduce 169) ((T_TRY) reduce 169) ((T_UNSET) reduce 169) ((T_UNSET_CAST) reduce 169) ((T_VARIABLE) reduce 169) ((T_WHILE) reduce 169) ((T_YIELD) reduce 169) ((T_YIELD_FROM) reduce 169) (("[") reduce 169) (("`") reduce 169) (("{") reduce 169) (("~") reduce 169)) 16833 ((("!") reduce 151) (("\"") reduce 151) (("$") reduce 151) (("(") reduce 151) (("+") reduce 151) (("-") reduce 151) ((";") reduce 151) (("@") reduce 151) ((T_ABSTRACT) reduce 151) ((T_ARRAY) reduce 151) ((T_ARRAY_CAST) reduce 151) ((T_ATTRIBUTE) reduce 151) ((T_BOOL_CAST) reduce 151) ((T_BREAK) reduce 151) ((T_CASE) reduce 151) ((T_CLASS) reduce 151) ((T_CLASS_C) reduce 151) ((T_CLONE) reduce 151) ((T_CONSTANT_ENCAPSED_STRING) reduce 151) ((T_CONTINUE) reduce 151) ((T_DEC) reduce 151) ((T_DECLARE) reduce 151) ((T_DEFAULT) reduce 151) ((T_DIR) reduce 151) ((T_DNUMBER) reduce 151) ((T_DO) reduce 151) ((T_DOUBLE_CAST) reduce 151) ((T_ECHO) reduce 151) ((T_ELSE) reduce 151) ((T_ELSEIF) reduce 151) ((T_EMPTY) reduce 151) ((T_ENDSWITCH) reduce 151) ((T_ENUM) reduce 151) ((T_EVAL) reduce 151) ((T_EXIT) reduce 151) ((T_FILE) reduce 151) ((T_FINAL) reduce 151) ((T_FN) reduce 151) ((T_FOR) reduce 151) ((T_FOREACH) reduce 151) ((T_FUNCTION) reduce 151) ((T_FUNC_C) reduce 151) ((T_GLOBAL) reduce 151) ((T_GOTO) reduce 151) ((T_HALT_COMPILER) reduce 151) ((T_IF) reduce 151) ((T_INC) reduce 151) ((T_INCLUDE) reduce 151) ((T_INCLUDE_ONCE) reduce 151) ((T_INLINE_HTML) reduce 151) ((T_INTERFACE) reduce 151) ((T_INT_CAST) reduce 151) ((T_ISSET) reduce 151) ((T_LINE) reduce 151) ((T_LIST) reduce 151) ((T_LNUMBER) reduce 151) ((T_MATCH) reduce 151) ((T_METHOD_C) reduce 151) ((T_NAME_FULLY_QUALIFIED) reduce 151) ((T_NAME_QUALIFIED) reduce 151) ((T_NAME_RELATIVE) reduce 151) ((T_NEW) reduce 151) ((T_NS_C) reduce 151) ((T_OBJECT_CAST) reduce 151) ((T_PRINT) reduce 151) ((T_READONLY) reduce 151) ((T_REQUIRE) reduce 151) ((T_REQUIRE_ONCE) reduce 151) ((T_RETURN) reduce 151) ((T_START_HEREDOC) reduce 151) ((T_STATIC) reduce 151) ((T_STRING) reduce 151) ((T_STRING_CAST) reduce 151) ((T_SWITCH) reduce 151) ((T_THROW) reduce 151) ((T_TRAIT) reduce 151) ((T_TRAIT_C) reduce 151) ((T_TRY) reduce 151) ((T_UNSET) reduce 151) ((T_UNSET_CAST) reduce 151) ((T_VARIABLE) reduce 151) ((T_WHILE) reduce 151) ((T_YIELD) reduce 151) ((T_YIELD_FROM) reduce 151) (("[") reduce 151) (("`") reduce 151) (("{") reduce 151) (("~") reduce 151)) 16837 ((("!") reduce 221) (("\"") reduce 221) (("$") reduce 221) (("(") reduce 221) (("+") reduce 221) (("-") reduce 221) ((";") reduce 221) (("@") reduce 221) ((T_ABSTRACT) reduce 221) ((T_ARRAY) reduce 221) ((T_ARRAY_CAST) reduce 221) ((T_ATTRIBUTE) reduce 221) ((T_BOOL_CAST) reduce 221) ((T_BREAK) reduce 221) ((T_CASE) reduce 221) ((T_CLASS) reduce 221) ((T_CLASS_C) reduce 221) ((T_CLONE) reduce 221) ((T_CONSTANT_ENCAPSED_STRING) reduce 221) ((T_CONTINUE) reduce 221) ((T_DEC) reduce 221) ((T_DECLARE) reduce 221) ((T_DEFAULT) reduce 221) ((T_DIR) reduce 221) ((T_DNUMBER) reduce 221) ((T_DO) reduce 221) ((T_DOUBLE_CAST) reduce 221) ((T_ECHO) reduce 221) ((T_ELSE) reduce 221) ((T_ELSEIF) reduce 221) ((T_EMPTY) reduce 221) ((T_ENDSWITCH) reduce 221) ((T_ENUM) reduce 221) ((T_EVAL) reduce 221) ((T_EXIT) reduce 221) ((T_FILE) reduce 221) ((T_FINAL) reduce 221) ((T_FN) reduce 221) ((T_FOR) reduce 221) ((T_FOREACH) reduce 221) ((T_FUNCTION) reduce 221) ((T_FUNC_C) reduce 221) ((T_GLOBAL) reduce 221) ((T_GOTO) reduce 221) ((T_HALT_COMPILER) reduce 221) ((T_IF) reduce 221) ((T_INC) reduce 221) ((T_INCLUDE) reduce 221) ((T_INCLUDE_ONCE) reduce 221) ((T_INLINE_HTML) reduce 221) ((T_INTERFACE) reduce 221) ((T_INT_CAST) reduce 221) ((T_ISSET) reduce 221) ((T_LINE) reduce 221) ((T_LIST) reduce 221) ((T_LNUMBER) reduce 221) ((T_MATCH) reduce 221) ((T_METHOD_C) reduce 221) ((T_NAME_FULLY_QUALIFIED) reduce 221) ((T_NAME_QUALIFIED) reduce 221) ((T_NAME_RELATIVE) reduce 221) ((T_NEW) reduce 221) ((T_NS_C) reduce 221) ((T_OBJECT_CAST) reduce 221) ((T_PRINT) reduce 221) ((T_READONLY) reduce 221) ((T_REQUIRE) reduce 221) ((T_REQUIRE_ONCE) reduce 221) ((T_RETURN) reduce 221) ((T_START_HEREDOC) reduce 221) ((T_STATIC) reduce 221) ((T_STRING) reduce 221) ((T_STRING_CAST) reduce 221) ((T_SWITCH) reduce 221) ((T_THROW) reduce 221) ((T_TRAIT) reduce 221) ((T_TRAIT_C) reduce 221) ((T_TRY) reduce 221) ((T_UNSET) reduce 221) ((T_UNSET_CAST) reduce 221) ((T_VARIABLE) reduce 221) ((T_WHILE) reduce 221) ((T_YIELD) reduce 221) ((T_YIELD_FROM) reduce 221) (("[") reduce 221) (("`") reduce 221) (("{") reduce 221) (("~") reduce 221)) 16839 ((("!") reduce 222) (("\"") reduce 222) (("$") reduce 222) (("(") reduce 222) (("+") reduce 222) (("-") reduce 222) ((";") reduce 222) (("@") reduce 222) ((T_ABSTRACT) reduce 222) ((T_ARRAY) reduce 222) ((T_ARRAY_CAST) reduce 222) ((T_ATTRIBUTE) reduce 222) ((T_BOOL_CAST) reduce 222) ((T_BREAK) reduce 222) ((T_CASE) reduce 222) ((T_CLASS) reduce 222) ((T_CLASS_C) reduce 222) ((T_CLONE) reduce 222) ((T_CONSTANT_ENCAPSED_STRING) reduce 222) ((T_CONTINUE) reduce 222) ((T_DEC) reduce 222) ((T_DECLARE) reduce 222) ((T_DEFAULT) reduce 222) ((T_DIR) reduce 222) ((T_DNUMBER) reduce 222) ((T_DO) reduce 222) ((T_DOUBLE_CAST) reduce 222) ((T_ECHO) reduce 222) ((T_ELSE) reduce 222) ((T_ELSEIF) reduce 222) ((T_EMPTY) reduce 222) ((T_ENDSWITCH) reduce 222) ((T_ENUM) reduce 222) ((T_EVAL) reduce 222) ((T_EXIT) reduce 222) ((T_FILE) reduce 222) ((T_FINAL) reduce 222) ((T_FN) reduce 222) ((T_FOR) reduce 222) ((T_FOREACH) reduce 222) ((T_FUNCTION) reduce 222) ((T_FUNC_C) reduce 222) ((T_GLOBAL) reduce 222) ((T_GOTO) reduce 222) ((T_HALT_COMPILER) reduce 222) ((T_IF) reduce 222) ((T_INC) reduce 222) ((T_INCLUDE) reduce 222) ((T_INCLUDE_ONCE) reduce 222) ((T_INLINE_HTML) reduce 222) ((T_INTERFACE) reduce 222) ((T_INT_CAST) reduce 222) ((T_ISSET) reduce 222) ((T_LINE) reduce 222) ((T_LIST) reduce 222) ((T_LNUMBER) reduce 222) ((T_MATCH) reduce 222) ((T_METHOD_C) reduce 222) ((T_NAME_FULLY_QUALIFIED) reduce 222) ((T_NAME_QUALIFIED) reduce 222) ((T_NAME_RELATIVE) reduce 222) ((T_NEW) reduce 222) ((T_NS_C) reduce 222) ((T_OBJECT_CAST) reduce 222) ((T_PRINT) reduce 222) ((T_READONLY) reduce 222) ((T_REQUIRE) reduce 222) ((T_REQUIRE_ONCE) reduce 222) ((T_RETURN) reduce 222) ((T_START_HEREDOC) reduce 222) ((T_STATIC) reduce 222) ((T_STRING) reduce 222) ((T_STRING_CAST) reduce 222) ((T_SWITCH) reduce 222) ((T_THROW) reduce 222) ((T_TRAIT) reduce 222) ((T_TRAIT_C) reduce 222) ((T_TRY) reduce 222) ((T_UNSET) reduce 222) ((T_UNSET_CAST) reduce 222) ((T_VARIABLE) reduce 222) ((T_WHILE) reduce 222) ((T_YIELD) reduce 222) ((T_YIELD_FROM) reduce 222) (("[") reduce 222) (("`") reduce 222) (("{") reduce 222) (("~") reduce 222)) 16843 ((("!") reduce 223) (("\"") reduce 223) (("$") reduce 223) (("(") reduce 223) (("+") reduce 223) (("-") reduce 223) ((";") reduce 223) (("@") reduce 223) ((T_ABSTRACT) reduce 223) ((T_ARRAY) reduce 223) ((T_ARRAY_CAST) reduce 223) ((T_ATTRIBUTE) reduce 223) ((T_BOOL_CAST) reduce 223) ((T_BREAK) reduce 223) ((T_CASE) reduce 223) ((T_CLASS) reduce 223) ((T_CLASS_C) reduce 223) ((T_CLONE) reduce 223) ((T_CONSTANT_ENCAPSED_STRING) reduce 223) ((T_CONTINUE) reduce 223) ((T_DEC) reduce 223) ((T_DECLARE) reduce 223) ((T_DEFAULT) reduce 223) ((T_DIR) reduce 223) ((T_DNUMBER) reduce 223) ((T_DO) reduce 223) ((T_DOUBLE_CAST) reduce 223) ((T_ECHO) reduce 223) ((T_ELSE) reduce 223) ((T_ELSEIF) reduce 223) ((T_EMPTY) reduce 223) ((T_ENDSWITCH) reduce 223) ((T_ENUM) reduce 223) ((T_EVAL) reduce 223) ((T_EXIT) reduce 223) ((T_FILE) reduce 223) ((T_FINAL) reduce 223) ((T_FN) reduce 223) ((T_FOR) reduce 223) ((T_FOREACH) reduce 223) ((T_FUNCTION) reduce 223) ((T_FUNC_C) reduce 223) ((T_GLOBAL) reduce 223) ((T_GOTO) reduce 223) ((T_HALT_COMPILER) reduce 223) ((T_IF) reduce 223) ((T_INC) reduce 223) ((T_INCLUDE) reduce 223) ((T_INCLUDE_ONCE) reduce 223) ((T_INLINE_HTML) reduce 223) ((T_INTERFACE) reduce 223) ((T_INT_CAST) reduce 223) ((T_ISSET) reduce 223) ((T_LINE) reduce 223) ((T_LIST) reduce 223) ((T_LNUMBER) reduce 223) ((T_MATCH) reduce 223) ((T_METHOD_C) reduce 223) ((T_NAME_FULLY_QUALIFIED) reduce 223) ((T_NAME_QUALIFIED) reduce 223) ((T_NAME_RELATIVE) reduce 223) ((T_NEW) reduce 223) ((T_NS_C) reduce 223) ((T_OBJECT_CAST) reduce 223) ((T_PRINT) reduce 223) ((T_READONLY) reduce 223) ((T_REQUIRE) reduce 223) ((T_REQUIRE_ONCE) reduce 223) ((T_RETURN) reduce 223) ((T_START_HEREDOC) reduce 223) ((T_STATIC) reduce 223) ((T_STRING) reduce 223) ((T_STRING_CAST) reduce 223) ((T_SWITCH) reduce 223) ((T_THROW) reduce 223) ((T_TRAIT) reduce 223) ((T_TRAIT_C) reduce 223) ((T_TRY) reduce 223) ((T_UNSET) reduce 223) ((T_UNSET_CAST) reduce 223) ((T_VARIABLE) reduce 223) ((T_WHILE) reduce 223) ((T_YIELD) reduce 223) ((T_YIELD_FROM) reduce 223) (("[") reduce 223) (("`") reduce 223) (("{") reduce 223) (("~") reduce 223)) 16846 ((("!") reduce 224) (("\"") reduce 224) (("$") reduce 224) (("(") reduce 224) (("+") reduce 224) (("-") reduce 224) ((";") reduce 224) (("@") reduce 224) ((T_ABSTRACT) reduce 224) ((T_ARRAY) reduce 224) ((T_ARRAY_CAST) reduce 224) ((T_ATTRIBUTE) reduce 224) ((T_BOOL_CAST) reduce 224) ((T_BREAK) reduce 224) ((T_CASE) reduce 224) ((T_CLASS) reduce 224) ((T_CLASS_C) reduce 224) ((T_CLONE) reduce 224) ((T_CONSTANT_ENCAPSED_STRING) reduce 224) ((T_CONTINUE) reduce 224) ((T_DEC) reduce 224) ((T_DECLARE) reduce 224) ((T_DEFAULT) reduce 224) ((T_DIR) reduce 224) ((T_DNUMBER) reduce 224) ((T_DO) reduce 224) ((T_DOUBLE_CAST) reduce 224) ((T_ECHO) reduce 224) ((T_ELSE) reduce 224) ((T_ELSEIF) reduce 224) ((T_EMPTY) reduce 224) ((T_ENDSWITCH) reduce 224) ((T_ENUM) reduce 224) ((T_EVAL) reduce 224) ((T_EXIT) reduce 224) ((T_FILE) reduce 224) ((T_FINAL) reduce 224) ((T_FN) reduce 224) ((T_FOR) reduce 224) ((T_FOREACH) reduce 224) ((T_FUNCTION) reduce 224) ((T_FUNC_C) reduce 224) ((T_GLOBAL) reduce 224) ((T_GOTO) reduce 224) ((T_HALT_COMPILER) reduce 224) ((T_IF) reduce 224) ((T_INC) reduce 224) ((T_INCLUDE) reduce 224) ((T_INCLUDE_ONCE) reduce 224) ((T_INLINE_HTML) reduce 224) ((T_INTERFACE) reduce 224) ((T_INT_CAST) reduce 224) ((T_ISSET) reduce 224) ((T_LINE) reduce 224) ((T_LIST) reduce 224) ((T_LNUMBER) reduce 224) ((T_MATCH) reduce 224) ((T_METHOD_C) reduce 224) ((T_NAME_FULLY_QUALIFIED) reduce 224) ((T_NAME_QUALIFIED) reduce 224) ((T_NAME_RELATIVE) reduce 224) ((T_NEW) reduce 224) ((T_NS_C) reduce 224) ((T_OBJECT_CAST) reduce 224) ((T_PRINT) reduce 224) ((T_READONLY) reduce 224) ((T_REQUIRE) reduce 224) ((T_REQUIRE_ONCE) reduce 224) ((T_RETURN) reduce 224) ((T_START_HEREDOC) reduce 224) ((T_STATIC) reduce 224) ((T_STRING) reduce 224) ((T_STRING_CAST) reduce 224) ((T_SWITCH) reduce 224) ((T_THROW) reduce 224) ((T_TRAIT) reduce 224) ((T_TRAIT_C) reduce 224) ((T_TRY) reduce 224) ((T_UNSET) reduce 224) ((T_UNSET_CAST) reduce 224) ((T_VARIABLE) reduce 224) ((T_WHILE) reduce 224) ((T_YIELD) reduce 224) ((T_YIELD_FROM) reduce 224) (("[") reduce 224) (("`") reduce 224) (("{") reduce 224) (("~") reduce 224)) 16847 ((("!") reduce 167) (("\"") reduce 167) (("$") reduce 167) (("(") reduce 167) (("+") reduce 167) (("-") reduce 167) ((";") reduce 167) (("@") reduce 167) ((T_ABSTRACT) reduce 167) ((T_ARRAY) reduce 167) ((T_ARRAY_CAST) reduce 167) ((T_ATTRIBUTE) reduce 167) ((T_BOOL_CAST) reduce 167) ((T_BREAK) reduce 167) ((T_CASE) reduce 167) ((T_CLASS) reduce 167) ((T_CLASS_C) reduce 167) ((T_CLONE) reduce 167) ((T_CONSTANT_ENCAPSED_STRING) reduce 167) ((T_CONTINUE) reduce 167) ((T_DEC) reduce 167) ((T_DECLARE) reduce 167) ((T_DEFAULT) reduce 167) ((T_DIR) reduce 167) ((T_DNUMBER) reduce 167) ((T_DO) reduce 167) ((T_DOUBLE_CAST) reduce 167) ((T_ECHO) reduce 167) ((T_ELSE) reduce 167) ((T_ELSEIF) reduce 167) ((T_EMPTY) reduce 167) ((T_ENDSWITCH) reduce 167) ((T_ENUM) reduce 167) ((T_EVAL) reduce 167) ((T_EXIT) reduce 167) ((T_FILE) reduce 167) ((T_FINAL) reduce 167) ((T_FN) reduce 167) ((T_FOR) reduce 167) ((T_FOREACH) reduce 167) ((T_FUNCTION) reduce 167) ((T_FUNC_C) reduce 167) ((T_GLOBAL) reduce 167) ((T_GOTO) reduce 167) ((T_HALT_COMPILER) reduce 167) ((T_IF) reduce 167) ((T_INC) reduce 167) ((T_INCLUDE) reduce 167) ((T_INCLUDE_ONCE) reduce 167) ((T_INLINE_HTML) reduce 167) ((T_INTERFACE) reduce 167) ((T_INT_CAST) reduce 167) ((T_ISSET) reduce 167) ((T_LINE) reduce 167) ((T_LIST) reduce 167) ((T_LNUMBER) reduce 167) ((T_MATCH) reduce 167) ((T_METHOD_C) reduce 167) ((T_NAME_FULLY_QUALIFIED) reduce 167) ((T_NAME_QUALIFIED) reduce 167) ((T_NAME_RELATIVE) reduce 167) ((T_NEW) reduce 167) ((T_NS_C) reduce 167) ((T_OBJECT_CAST) reduce 167) ((T_PRINT) reduce 167) ((T_READONLY) reduce 167) ((T_REQUIRE) reduce 167) ((T_REQUIRE_ONCE) reduce 167) ((T_RETURN) reduce 167) ((T_START_HEREDOC) reduce 167) ((T_STATIC) reduce 167) ((T_STRING) reduce 167) ((T_STRING_CAST) reduce 167) ((T_SWITCH) reduce 167) ((T_THROW) reduce 167) ((T_TRAIT) reduce 167) ((T_TRAIT_C) reduce 167) ((T_TRY) reduce 167) ((T_UNSET) reduce 167) ((T_UNSET_CAST) reduce 167) ((T_VARIABLE) reduce 167) ((T_WHILE) reduce 167) ((T_YIELD) reduce 167) ((T_YIELD_FROM) reduce 167) (("[") reduce 167) (("`") reduce 167) (("{") reduce 167) (("~") reduce 167)) 16848 (((",") reduce 301) ((";") reduce 301) (("=") shift)) 16849 ((("%") reduce 447) (("*") reduce 447) (("+") reduce 447) (("-") reduce 447) ((".") reduce 447) (("/") reduce 447) ((";") reduce 447) (("<") reduce 447) ((">") reduce 447) (("?") reduce 447) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_BOOLEAN_AND) reduce 447) ((T_BOOLEAN_OR) reduce 447) ((T_COALESCE) reduce 447) ((T_INSTANCEOF) reduce 447) ((T_IS_EQUAL) reduce 447) ((T_IS_GREATER_OR_EQUAL) reduce 447) ((T_IS_IDENTICAL) reduce 447) ((T_IS_NOT_EQUAL) reduce 447) ((T_IS_NOT_IDENTICAL) reduce 447) ((T_IS_SMALLER_OR_EQUAL) reduce 447) ((T_LOGICAL_AND) reduce 447) ((T_LOGICAL_OR) reduce 447) ((T_LOGICAL_XOR) reduce 447) ((T_POW) reduce 447) ((T_SL) reduce 447) ((T_SPACESHIP) reduce 447) ((T_SR) reduce 447) (("^") reduce 447) (("|") reduce 447)) 16850 (((",") reduce 300) ((";") reduce 300)) 16853 ((("!") reduce 156) (("\"") reduce 156) (("$") reduce 156) (("(") reduce 156) (("+") reduce 156) (("-") reduce 156) ((";") reduce 156) (("@") reduce 156) ((T_ABSTRACT) reduce 156) ((T_ARRAY) reduce 156) ((T_ARRAY_CAST) reduce 156) ((T_ATTRIBUTE) reduce 156) ((T_BOOL_CAST) reduce 156) ((T_BREAK) reduce 156) ((T_CASE) reduce 156) ((T_CLASS) reduce 156) ((T_CLASS_C) reduce 156) ((T_CLONE) reduce 156) ((T_CONSTANT_ENCAPSED_STRING) reduce 156) ((T_CONTINUE) reduce 156) ((T_DEC) reduce 156) ((T_DECLARE) reduce 156) ((T_DEFAULT) reduce 156) ((T_DIR) reduce 156) ((T_DNUMBER) reduce 156) ((T_DO) reduce 156) ((T_DOUBLE_CAST) reduce 156) ((T_ECHO) reduce 156) ((T_ELSE) reduce 156) ((T_ELSEIF) reduce 156) ((T_EMPTY) reduce 156) ((T_ENDSWITCH) reduce 156) ((T_ENUM) reduce 156) ((T_EVAL) reduce 156) ((T_EXIT) reduce 156) ((T_FILE) reduce 156) ((T_FINAL) reduce 156) ((T_FN) reduce 156) ((T_FOR) reduce 156) ((T_FOREACH) reduce 156) ((T_FUNCTION) reduce 156) ((T_FUNC_C) reduce 156) ((T_GLOBAL) reduce 156) ((T_GOTO) reduce 156) ((T_HALT_COMPILER) reduce 156) ((T_IF) reduce 156) ((T_INC) reduce 156) ((T_INCLUDE) reduce 156) ((T_INCLUDE_ONCE) reduce 156) ((T_INLINE_HTML) reduce 156) ((T_INTERFACE) reduce 156) ((T_INT_CAST) reduce 156) ((T_ISSET) reduce 156) ((T_LINE) reduce 156) ((T_LIST) reduce 156) ((T_LNUMBER) reduce 156) ((T_MATCH) reduce 156) ((T_METHOD_C) reduce 156) ((T_NAME_FULLY_QUALIFIED) reduce 156) ((T_NAME_QUALIFIED) reduce 156) ((T_NAME_RELATIVE) reduce 156) ((T_NEW) reduce 156) ((T_NS_C) reduce 156) ((T_OBJECT_CAST) reduce 156) ((T_PRINT) reduce 156) ((T_READONLY) reduce 156) ((T_REQUIRE) reduce 156) ((T_REQUIRE_ONCE) reduce 156) ((T_RETURN) reduce 156) ((T_START_HEREDOC) reduce 156) ((T_STATIC) reduce 156) ((T_STRING) reduce 156) ((T_STRING_CAST) reduce 156) ((T_SWITCH) reduce 156) ((T_THROW) reduce 156) ((T_TRAIT) reduce 156) ((T_TRAIT_C) reduce 156) ((T_TRY) reduce 156) ((T_UNSET) reduce 156) ((T_UNSET_CAST) reduce 156) ((T_VARIABLE) reduce 156) ((T_WHILE) reduce 156) ((T_YIELD) reduce 156) ((T_YIELD_FROM) reduce 156) (("[") reduce 156) (("`") reduce 156) (("{") reduce 156) (("~") reduce 156)) 16854 (((",") reduce 299) ((";") reduce 299)) 16918 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 302) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 302) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 17865 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 508) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 17867 ((("!") reduce 154) (("\"") reduce 154) (("$") reduce 154) (("(") reduce 154) (("+") reduce 154) (("-") reduce 154) ((";") reduce 154) (("@") reduce 154) ((T_ABSTRACT) reduce 154) ((T_ARRAY) reduce 154) ((T_ARRAY_CAST) reduce 154) ((T_ATTRIBUTE) reduce 154) ((T_BOOL_CAST) reduce 154) ((T_BREAK) reduce 154) ((T_CASE) reduce 154) ((T_CLASS) reduce 154) ((T_CLASS_C) reduce 154) ((T_CLONE) reduce 154) ((T_CONSTANT_ENCAPSED_STRING) reduce 154) ((T_CONTINUE) reduce 154) ((T_DEC) reduce 154) ((T_DECLARE) reduce 154) ((T_DEFAULT) reduce 154) ((T_DIR) reduce 154) ((T_DNUMBER) reduce 154) ((T_DO) reduce 154) ((T_DOUBLE_CAST) reduce 154) ((T_ECHO) reduce 154) ((T_ELSE) reduce 154) ((T_ELSEIF) reduce 154) ((T_EMPTY) reduce 154) ((T_ENDSWITCH) reduce 154) ((T_ENUM) reduce 154) ((T_EVAL) reduce 154) ((T_EXIT) reduce 154) ((T_FILE) reduce 154) ((T_FINAL) reduce 154) ((T_FN) reduce 154) ((T_FOR) reduce 154) ((T_FOREACH) reduce 154) ((T_FUNCTION) reduce 154) ((T_FUNC_C) reduce 154) ((T_GLOBAL) reduce 154) ((T_GOTO) reduce 154) ((T_HALT_COMPILER) reduce 154) ((T_IF) reduce 154) ((T_INC) reduce 154) ((T_INCLUDE) reduce 154) ((T_INCLUDE_ONCE) reduce 154) ((T_INLINE_HTML) reduce 154) ((T_INTERFACE) reduce 154) ((T_INT_CAST) reduce 154) ((T_ISSET) reduce 154) ((T_LINE) reduce 154) ((T_LIST) reduce 154) ((T_LNUMBER) reduce 154) ((T_MATCH) reduce 154) ((T_METHOD_C) reduce 154) ((T_NAME_FULLY_QUALIFIED) reduce 154) ((T_NAME_QUALIFIED) reduce 154) ((T_NAME_RELATIVE) reduce 154) ((T_NEW) reduce 154) ((T_NS_C) reduce 154) ((T_OBJECT_CAST) reduce 154) ((T_PRINT) reduce 154) ((T_READONLY) reduce 154) ((T_REQUIRE) reduce 154) ((T_REQUIRE_ONCE) reduce 154) ((T_RETURN) reduce 154) ((T_START_HEREDOC) reduce 154) ((T_STATIC) reduce 154) ((T_STRING) reduce 154) ((T_STRING_CAST) reduce 154) ((T_SWITCH) reduce 154) ((T_THROW) reduce 154) ((T_TRAIT) reduce 154) ((T_TRAIT_C) reduce 154) ((T_TRY) reduce 154) ((T_UNSET) reduce 154) ((T_UNSET_CAST) reduce 154) ((T_VARIABLE) reduce 154) ((T_WHILE) reduce 154) ((T_YIELD) reduce 154) ((T_YIELD_FROM) reduce 154) (("[") reduce 154) (("`") reduce 154) (("{") reduce 154) (("~") reduce 154)) 17869 ((("!") reduce 166) (("\"") reduce 166) (("$") reduce 166) (("(") reduce 166) (("+") reduce 166) (("-") reduce 166) ((";") reduce 166) (("@") reduce 166) ((T_ABSTRACT) reduce 166) ((T_ARRAY) reduce 166) ((T_ARRAY_CAST) reduce 166) ((T_ATTRIBUTE) reduce 166) ((T_BOOL_CAST) reduce 166) ((T_BREAK) reduce 166) ((T_CASE) reduce 166) ((T_CLASS) reduce 166) ((T_CLASS_C) reduce 166) ((T_CLONE) reduce 166) ((T_CONSTANT_ENCAPSED_STRING) reduce 166) ((T_CONTINUE) reduce 166) ((T_DEC) reduce 166) ((T_DECLARE) reduce 166) ((T_DEFAULT) reduce 166) ((T_DIR) reduce 166) ((T_DNUMBER) reduce 166) ((T_DO) reduce 166) ((T_DOUBLE_CAST) reduce 166) ((T_ECHO) reduce 166) ((T_ELSE) reduce 166) ((T_ELSEIF) reduce 166) ((T_EMPTY) reduce 166) ((T_ENDSWITCH) reduce 166) ((T_ENUM) reduce 166) ((T_EVAL) reduce 166) ((T_EXIT) reduce 166) ((T_FILE) reduce 166) ((T_FINAL) reduce 166) ((T_FN) reduce 166) ((T_FOR) reduce 166) ((T_FOREACH) reduce 166) ((T_FUNCTION) reduce 166) ((T_FUNC_C) reduce 166) ((T_GLOBAL) reduce 166) ((T_GOTO) reduce 166) ((T_HALT_COMPILER) reduce 166) ((T_IF) reduce 166) ((T_INC) reduce 166) ((T_INCLUDE) reduce 166) ((T_INCLUDE_ONCE) reduce 166) ((T_INLINE_HTML) reduce 166) ((T_INTERFACE) reduce 166) ((T_INT_CAST) reduce 166) ((T_ISSET) reduce 166) ((T_LINE) reduce 166) ((T_LIST) reduce 166) ((T_LNUMBER) reduce 166) ((T_MATCH) reduce 166) ((T_METHOD_C) reduce 166) ((T_NAME_FULLY_QUALIFIED) reduce 166) ((T_NAME_QUALIFIED) reduce 166) ((T_NAME_RELATIVE) reduce 166) ((T_NEW) reduce 166) ((T_NS_C) reduce 166) ((T_OBJECT_CAST) reduce 166) ((T_PRINT) reduce 166) ((T_READONLY) reduce 166) ((T_REQUIRE) reduce 166) ((T_REQUIRE_ONCE) reduce 166) ((T_RETURN) reduce 166) ((T_START_HEREDOC) reduce 166) ((T_STATIC) reduce 166) ((T_STRING) reduce 166) ((T_STRING_CAST) reduce 166) ((T_SWITCH) reduce 166) ((T_THROW) reduce 166) ((T_TRAIT) reduce 166) ((T_TRAIT_C) reduce 166) ((T_TRY) reduce 166) ((T_UNSET) reduce 166) ((T_UNSET_CAST) reduce 166) ((T_VARIABLE) reduce 166) ((T_WHILE) reduce 166) ((T_YIELD) reduce 166) ((T_YIELD_FROM) reduce 166) (("[") reduce 166) (("`") reduce 166) (("{") reduce 166) (("~") reduce 166)) 17871 (((",") reduce 529) ((";") reduce 529)) 17872 (((",") reduce 297) ((";") reduce 297)) 17874 (((",") reduce 298) ((";") reduce 298)) 17876 ((("!") reduce 155) (("\"") reduce 155) (("$") reduce 155) (("(") reduce 155) (("+") reduce 155) (("-") reduce 155) ((";") reduce 155) (("@") reduce 155) ((T_ABSTRACT) reduce 155) ((T_ARRAY) reduce 155) ((T_ARRAY_CAST) reduce 155) ((T_ATTRIBUTE) reduce 155) ((T_BOOL_CAST) reduce 155) ((T_BREAK) reduce 155) ((T_CASE) reduce 155) ((T_CLASS) reduce 155) ((T_CLASS_C) reduce 155) ((T_CLONE) reduce 155) ((T_CONSTANT_ENCAPSED_STRING) reduce 155) ((T_CONTINUE) reduce 155) ((T_DEC) reduce 155) ((T_DECLARE) reduce 155) ((T_DEFAULT) reduce 155) ((T_DIR) reduce 155) ((T_DNUMBER) reduce 155) ((T_DO) reduce 155) ((T_DOUBLE_CAST) reduce 155) ((T_ECHO) reduce 155) ((T_ELSE) reduce 155) ((T_ELSEIF) reduce 155) ((T_EMPTY) reduce 155) ((T_ENDSWITCH) reduce 155) ((T_ENUM) reduce 155) ((T_EVAL) reduce 155) ((T_EXIT) reduce 155) ((T_FILE) reduce 155) ((T_FINAL) reduce 155) ((T_FN) reduce 155) ((T_FOR) reduce 155) ((T_FOREACH) reduce 155) ((T_FUNCTION) reduce 155) ((T_FUNC_C) reduce 155) ((T_GLOBAL) reduce 155) ((T_GOTO) reduce 155) ((T_HALT_COMPILER) reduce 155) ((T_IF) reduce 155) ((T_INC) reduce 155) ((T_INCLUDE) reduce 155) ((T_INCLUDE_ONCE) reduce 155) ((T_INLINE_HTML) reduce 155) ((T_INTERFACE) reduce 155) ((T_INT_CAST) reduce 155) ((T_ISSET) reduce 155) ((T_LINE) reduce 155) ((T_LIST) reduce 155) ((T_LNUMBER) reduce 155) ((T_MATCH) reduce 155) ((T_METHOD_C) reduce 155) ((T_NAME_FULLY_QUALIFIED) reduce 155) ((T_NAME_QUALIFIED) reduce 155) ((T_NAME_RELATIVE) reduce 155) ((T_NEW) reduce 155) ((T_NS_C) reduce 155) ((T_OBJECT_CAST) reduce 155) ((T_PRINT) reduce 155) ((T_READONLY) reduce 155) ((T_REQUIRE) reduce 155) ((T_REQUIRE_ONCE) reduce 155) ((T_RETURN) reduce 155) ((T_START_HEREDOC) reduce 155) ((T_STATIC) reduce 155) ((T_STRING) reduce 155) ((T_STRING_CAST) reduce 155) ((T_SWITCH) reduce 155) ((T_THROW) reduce 155) ((T_TRAIT) reduce 155) ((T_TRAIT_C) reduce 155) ((T_TRY) reduce 155) ((T_UNSET) reduce 155) ((T_UNSET_CAST) reduce 155) ((T_VARIABLE) reduce 155) ((T_WHILE) reduce 155) ((T_YIELD) reduce 155) ((T_YIELD_FROM) reduce 155) (("[") reduce 155) (("`") reduce 155) (("{") reduce 155) (("~") reduce 155)) 17877 (((",") reduce 296) ((";") reduce 296)) 17878 (((",") reduce 531) ((";") reduce 531)) 17881 (((",") reduce 530) ((";") reduce 530)) 17893 ((("%") reduce 502) (("*") reduce 502) (("+") reduce 502) (("-") reduce 502) ((".") reduce 502) (("/") reduce 502) (("<") reduce 502) ((">") reduce 502) (("?") reduce 502) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_AS) reduce 502) ((T_BOOLEAN_AND) reduce 502) ((T_BOOLEAN_OR) reduce 502) ((T_COALESCE) reduce 502) ((T_INSTANCEOF) reduce 502) ((T_IS_EQUAL) reduce 502) ((T_IS_GREATER_OR_EQUAL) reduce 502) ((T_IS_IDENTICAL) reduce 502) ((T_IS_NOT_EQUAL) reduce 502) ((T_IS_NOT_IDENTICAL) reduce 502) ((T_IS_SMALLER_OR_EQUAL) reduce 502) ((T_LOGICAL_AND) reduce 502) ((T_LOGICAL_OR) reduce 502) ((T_LOGICAL_XOR) reduce 502) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 502) ((T_OBJECT_OPERATOR) reduce 502) ((T_POW) reduce 502) ((T_SL) reduce 502) ((T_SPACESHIP) reduce 502) ((T_SR) reduce 502) (("[") reduce 502) (("^") reduce 502) (("{") reduce 502) (("|") reduce 502)) 17895 ((("%") reduce 484) (("(") reduce 484) (("*") reduce 484) (("+") reduce 484) (("-") reduce 484) ((".") reduce 484) (("/") reduce 484) (("<") reduce 484) ((">") reduce 484) (("?") reduce 484) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_AS) reduce 484) ((T_BOOLEAN_AND) reduce 484) ((T_BOOLEAN_OR) reduce 484) ((T_COALESCE) reduce 484) ((T_INSTANCEOF) reduce 484) ((T_IS_EQUAL) reduce 484) ((T_IS_GREATER_OR_EQUAL) reduce 484) ((T_IS_IDENTICAL) reduce 484) ((T_IS_NOT_EQUAL) reduce 484) ((T_IS_NOT_IDENTICAL) reduce 484) ((T_IS_SMALLER_OR_EQUAL) reduce 484) ((T_LOGICAL_AND) reduce 484) ((T_LOGICAL_OR) reduce 484) ((T_LOGICAL_XOR) reduce 484) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 484) ((T_OBJECT_OPERATOR) reduce 484) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 484) ((T_POW) reduce 484) ((T_SL) reduce 484) ((T_SPACESHIP) reduce 484) ((T_SR) reduce 484) (("[") reduce 484) (("^") reduce 484) (("{") reduce 484) (("|") reduce 484)) 17897 ((("%") reduce 497) (("*") reduce 497) (("+") reduce 497) (("-") reduce 497) ((".") reduce 497) (("/") reduce 497) (("<") reduce 497) ((">") reduce 497) (("?") reduce 497) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_AS) reduce 497) ((T_BOOLEAN_AND) reduce 497) ((T_BOOLEAN_OR) reduce 497) ((T_COALESCE) reduce 497) ((T_INSTANCEOF) reduce 497) ((T_IS_EQUAL) reduce 497) ((T_IS_GREATER_OR_EQUAL) reduce 497) ((T_IS_IDENTICAL) reduce 497) ((T_IS_NOT_EQUAL) reduce 497) ((T_IS_NOT_IDENTICAL) reduce 497) ((T_IS_SMALLER_OR_EQUAL) reduce 497) ((T_LOGICAL_AND) reduce 497) ((T_LOGICAL_OR) reduce 497) ((T_LOGICAL_XOR) reduce 497) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 497) ((T_OBJECT_OPERATOR) reduce 497) ((T_POW) reduce 497) ((T_SL) reduce 497) ((T_SPACESHIP) reduce 497) ((T_SR) reduce 497) (("[") reduce 497) (("^") reduce 497) (("{") reduce 497) (("|") reduce 497)) 17898 ((("%") reduce 487) (("*") reduce 487) (("+") reduce 487) (("-") reduce 487) ((".") reduce 487) (("/") reduce 487) (("<") reduce 487) ((">") reduce 487) (("?") reduce 487) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_AS) reduce 487) ((T_BOOLEAN_AND) reduce 487) ((T_BOOLEAN_OR) reduce 487) ((T_COALESCE) reduce 487) ((T_INSTANCEOF) reduce 487) ((T_IS_EQUAL) reduce 487) ((T_IS_GREATER_OR_EQUAL) reduce 487) ((T_IS_IDENTICAL) reduce 487) ((T_IS_NOT_EQUAL) reduce 487) ((T_IS_NOT_IDENTICAL) reduce 487) ((T_IS_SMALLER_OR_EQUAL) reduce 487) ((T_LOGICAL_AND) reduce 487) ((T_LOGICAL_OR) reduce 487) ((T_LOGICAL_XOR) reduce 487) ((T_POW) reduce 487) ((T_SL) reduce 487) ((T_SPACESHIP) reduce 487) ((T_SR) reduce 487) (("^") reduce 487) (("|") reduce 487)) 17902 ((("%") reduce 475) (("(") shift) (("*") reduce 475) (("+") reduce 475) (("-") reduce 475) ((".") reduce 475) (("/") reduce 475) (("<") reduce 475) ((">") reduce 475) (("?") reduce 475) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_AS) reduce 475) ((T_BOOLEAN_AND) reduce 475) ((T_BOOLEAN_OR) reduce 475) ((T_COALESCE) reduce 475) ((T_INSTANCEOF) reduce 475) ((T_IS_EQUAL) reduce 475) ((T_IS_GREATER_OR_EQUAL) reduce 475) ((T_IS_IDENTICAL) reduce 475) ((T_IS_NOT_EQUAL) reduce 475) ((T_IS_NOT_IDENTICAL) reduce 475) ((T_IS_SMALLER_OR_EQUAL) reduce 475) ((T_LOGICAL_AND) reduce 475) ((T_LOGICAL_OR) reduce 475) ((T_LOGICAL_XOR) reduce 475) ((T_POW) reduce 475) ((T_SL) reduce 475) ((T_SPACESHIP) reduce 475) ((T_SR) reduce 475) (("^") reduce 475) (("|") reduce 475)) 17903 ((("%") reduce 496) (("*") reduce 496) (("+") reduce 496) (("-") reduce 496) ((".") reduce 496) (("/") reduce 496) (("<") reduce 496) ((">") reduce 496) (("?") reduce 496) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_AS) reduce 496) ((T_BOOLEAN_AND) reduce 496) ((T_BOOLEAN_OR) reduce 496) ((T_COALESCE) reduce 496) ((T_INSTANCEOF) reduce 496) ((T_IS_EQUAL) reduce 496) ((T_IS_GREATER_OR_EQUAL) reduce 496) ((T_IS_IDENTICAL) reduce 496) ((T_IS_NOT_EQUAL) reduce 496) ((T_IS_NOT_IDENTICAL) reduce 496) ((T_IS_SMALLER_OR_EQUAL) reduce 496) ((T_LOGICAL_AND) reduce 496) ((T_LOGICAL_OR) reduce 496) ((T_LOGICAL_XOR) reduce 496) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 496) ((T_OBJECT_OPERATOR) reduce 496) ((T_POW) reduce 496) ((T_SL) reduce 496) ((T_SPACESHIP) reduce 496) ((T_SR) reduce 496) (("[") reduce 496) (("^") reduce 496) (("{") reduce 496) (("|") reduce 496)) 17904 ((("%") reduce 500) (("*") reduce 500) (("+") reduce 500) (("-") reduce 500) ((".") reduce 500) (("/") reduce 500) (("<") reduce 500) ((">") reduce 500) (("?") reduce 500) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_AS) reduce 500) ((T_BOOLEAN_AND) reduce 500) ((T_BOOLEAN_OR) reduce 500) ((T_COALESCE) reduce 500) ((T_INSTANCEOF) reduce 500) ((T_IS_EQUAL) reduce 500) ((T_IS_GREATER_OR_EQUAL) reduce 500) ((T_IS_IDENTICAL) reduce 500) ((T_IS_NOT_EQUAL) reduce 500) ((T_IS_NOT_IDENTICAL) reduce 500) ((T_IS_SMALLER_OR_EQUAL) reduce 500) ((T_LOGICAL_AND) reduce 500) ((T_LOGICAL_OR) reduce 500) ((T_LOGICAL_XOR) reduce 500) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 500) ((T_OBJECT_OPERATOR) reduce 500) ((T_POW) reduce 500) ((T_SL) reduce 500) ((T_SPACESHIP) reduce 500) ((T_SR) reduce 500) (("[") reduce 500) (("^") reduce 500) (("{") reduce 500) (("|") reduce 500)) 17910 ((("%") reduce 495) (("*") reduce 495) (("+") reduce 495) (("-") reduce 495) ((".") reduce 495) (("/") reduce 495) (("<") reduce 495) ((">") reduce 495) (("?") reduce 495) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_AS) reduce 495) ((T_BOOLEAN_AND) reduce 495) ((T_BOOLEAN_OR) reduce 495) ((T_COALESCE) reduce 495) ((T_INSTANCEOF) reduce 495) ((T_IS_EQUAL) reduce 495) ((T_IS_GREATER_OR_EQUAL) reduce 495) ((T_IS_IDENTICAL) reduce 495) ((T_IS_NOT_EQUAL) reduce 495) ((T_IS_NOT_IDENTICAL) reduce 495) ((T_IS_SMALLER_OR_EQUAL) reduce 495) ((T_LOGICAL_AND) reduce 495) ((T_LOGICAL_OR) reduce 495) ((T_LOGICAL_XOR) reduce 495) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 495) ((T_OBJECT_OPERATOR) reduce 495) ((T_POW) reduce 495) ((T_SL) reduce 495) ((T_SPACESHIP) reduce 495) ((T_SR) reduce 495) (("[") reduce 495) (("^") reduce 495) (("{") reduce 495) (("|") reduce 495)) 17912 ((("%") reduce 486) (("*") reduce 486) (("+") reduce 486) (("-") reduce 486) ((".") reduce 486) (("/") reduce 486) (("<") reduce 486) ((">") reduce 486) (("?") reduce 486) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_AS) reduce 486) ((T_BOOLEAN_AND) reduce 486) ((T_BOOLEAN_OR) reduce 486) ((T_COALESCE) reduce 486) ((T_INSTANCEOF) reduce 486) ((T_IS_EQUAL) reduce 486) ((T_IS_GREATER_OR_EQUAL) reduce 486) ((T_IS_IDENTICAL) reduce 486) ((T_IS_NOT_EQUAL) reduce 486) ((T_IS_NOT_IDENTICAL) reduce 486) ((T_IS_SMALLER_OR_EQUAL) reduce 486) ((T_LOGICAL_AND) reduce 486) ((T_LOGICAL_OR) reduce 486) ((T_LOGICAL_XOR) reduce 486) ((T_POW) reduce 486) ((T_SL) reduce 486) ((T_SPACESHIP) reduce 486) ((T_SR) reduce 486) (("^") reduce 486) (("|") reduce 486)) 17914 ((("%") reduce 499) (("*") reduce 499) (("+") reduce 499) (("-") reduce 499) ((".") reduce 499) (("/") reduce 499) (("<") reduce 499) ((">") reduce 499) (("?") reduce 499) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_AS) reduce 499) ((T_BOOLEAN_AND) reduce 499) ((T_BOOLEAN_OR) reduce 499) ((T_COALESCE) reduce 499) ((T_INSTANCEOF) reduce 499) ((T_IS_EQUAL) reduce 499) ((T_IS_GREATER_OR_EQUAL) reduce 499) ((T_IS_IDENTICAL) reduce 499) ((T_IS_NOT_EQUAL) reduce 499) ((T_IS_NOT_IDENTICAL) reduce 499) ((T_IS_SMALLER_OR_EQUAL) reduce 499) ((T_LOGICAL_AND) reduce 499) ((T_LOGICAL_OR) reduce 499) ((T_LOGICAL_XOR) reduce 499) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 499) ((T_OBJECT_OPERATOR) reduce 499) ((T_POW) reduce 499) ((T_SL) reduce 499) ((T_SPACESHIP) reduce 499) ((T_SR) reduce 499) (("[") reduce 499) (("^") reduce 499) (("{") reduce 499) (("|") reduce 499)) 17915 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AS) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 93) ((T_OBJECT_OPERATOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("[") reduce 93) (("^") reduce 93) (("{") reduce 93) (("|") reduce 93)) 17916 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AS) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 92) ((T_OBJECT_OPERATOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("[") reduce 92) (("^") reduce 92) (("{") reduce 92) (("|") reduce 92)) 17917 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AS) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 94) ((T_OBJECT_OPERATOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("[") reduce 94) (("^") reduce 94) (("{") reduce 94) (("|") reduce 94)) 17919 ((("%") reduce 501) (("*") reduce 501) (("+") reduce 501) (("-") reduce 501) ((".") reduce 501) (("/") reduce 501) (("<") reduce 501) ((">") reduce 501) (("?") reduce 501) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_AS) reduce 501) ((T_BOOLEAN_AND) reduce 501) ((T_BOOLEAN_OR) reduce 501) ((T_COALESCE) reduce 501) ((T_INSTANCEOF) reduce 501) ((T_IS_EQUAL) reduce 501) ((T_IS_GREATER_OR_EQUAL) reduce 501) ((T_IS_IDENTICAL) reduce 501) ((T_IS_NOT_EQUAL) reduce 501) ((T_IS_NOT_IDENTICAL) reduce 501) ((T_IS_SMALLER_OR_EQUAL) reduce 501) ((T_LOGICAL_AND) reduce 501) ((T_LOGICAL_OR) reduce 501) ((T_LOGICAL_XOR) reduce 501) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 501) ((T_OBJECT_OPERATOR) reduce 501) ((T_POW) reduce 501) ((T_SL) reduce 501) ((T_SPACESHIP) reduce 501) ((T_SR) reduce 501) (("[") reduce 501) (("^") reduce 501) (("{") reduce 501) (("|") reduce 501)) 17927 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AS) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 91) ((T_OBJECT_OPERATOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("[") reduce 91) (("^") reduce 91) (("{") reduce 91) (("|") reduce 91)) 17930 ((("%") reduce 498) (("*") reduce 498) (("+") reduce 498) (("-") reduce 498) ((".") reduce 498) (("/") reduce 498) (("<") reduce 498) ((">") reduce 498) (("?") reduce 498) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_AS) reduce 498) ((T_BOOLEAN_AND) reduce 498) ((T_BOOLEAN_OR) reduce 498) ((T_COALESCE) reduce 498) ((T_INSTANCEOF) reduce 498) ((T_IS_EQUAL) reduce 498) ((T_IS_GREATER_OR_EQUAL) reduce 498) ((T_IS_IDENTICAL) reduce 498) ((T_IS_NOT_EQUAL) reduce 498) ((T_IS_NOT_IDENTICAL) reduce 498) ((T_IS_SMALLER_OR_EQUAL) reduce 498) ((T_LOGICAL_AND) reduce 498) ((T_LOGICAL_OR) reduce 498) ((T_LOGICAL_XOR) reduce 498) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 498) ((T_OBJECT_OPERATOR) reduce 498) ((T_POW) reduce 498) ((T_SL) reduce 498) ((T_SPACESHIP) reduce 498) ((T_SR) reduce 498) (("[") reduce 498) (("^") reduce 498) (("{") reduce 498) (("|") reduce 498)) 17932 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) (("=") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AND_EQUAL) reduce 529) ((T_AS) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_COALESCE_EQUAL) reduce 529) ((T_CONCAT_EQUAL) reduce 529) ((T_DEC) reduce 529) ((T_DIV_EQUAL) reduce 529) ((T_INC) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_MINUS_EQUAL) reduce 529) ((T_MOD_EQUAL) reduce 529) ((T_MUL_EQUAL) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_OR_EQUAL) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_PLUS_EQUAL) reduce 529) ((T_POW) reduce 529) ((T_POW_EQUAL) reduce 529) ((T_SL) reduce 529) ((T_SL_EQUAL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) ((T_SR_EQUAL) reduce 529) ((T_XOR_EQUAL) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 17933 ((("!") shift) (("\"") shift) (("$") shift) (("%") reduce 440) (("(") shift) (("*") reduce 440) (("+") shift) (("-") shift) ((".") reduce 440) (("/") reduce 440) (("<") reduce 440) ((">") reduce 440) (("?") reduce 440) (("@") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_AS) reduce 440) ((T_ATTRIBUTE) shift) ((T_BOOLEAN_AND) reduce 440) ((T_BOOLEAN_OR) reduce 440) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_COALESCE) reduce 440) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INSTANCEOF) reduce 440) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_IS_EQUAL) reduce 440) ((T_IS_GREATER_OR_EQUAL) reduce 440) ((T_IS_IDENTICAL) reduce 440) ((T_IS_NOT_EQUAL) reduce 440) ((T_IS_NOT_IDENTICAL) reduce 440) ((T_IS_SMALLER_OR_EQUAL) reduce 440) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_LOGICAL_AND) reduce 440) ((T_LOGICAL_OR) reduce 440) ((T_LOGICAL_XOR) reduce 440) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_POW) reduce 440) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_SL) reduce 440) ((T_SPACESHIP) reduce 440) ((T_SR) reduce 440) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("^") reduce 440) (("`") shift) (("|") reduce 440) (("~") shift)) 17940 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) (("<") reduce 525) (("=") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AND_EQUAL) reduce 525) ((T_AS) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_COALESCE_EQUAL) reduce 525) ((T_CONCAT_EQUAL) reduce 525) ((T_DEC) reduce 525) ((T_DIV_EQUAL) reduce 525) ((T_INC) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_MINUS_EQUAL) reduce 525) ((T_MOD_EQUAL) reduce 525) ((T_MUL_EQUAL) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_OR_EQUAL) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_PLUS_EQUAL) reduce 525) ((T_POW) reduce 525) ((T_POW_EQUAL) reduce 525) ((T_SL) reduce 525) ((T_SL_EQUAL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) ((T_SR_EQUAL) reduce 525) ((T_XOR_EQUAL) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 17941 ((("%") reduce 493) (("*") reduce 493) (("+") reduce 493) (("-") reduce 493) ((".") reduce 493) (("/") reduce 493) (("<") reduce 493) ((">") reduce 493) (("?") reduce 493) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_AS) reduce 493) ((T_BOOLEAN_AND) reduce 493) ((T_BOOLEAN_OR) reduce 493) ((T_COALESCE) reduce 493) ((T_INSTANCEOF) reduce 493) ((T_IS_EQUAL) reduce 493) ((T_IS_GREATER_OR_EQUAL) reduce 493) ((T_IS_IDENTICAL) reduce 493) ((T_IS_NOT_EQUAL) reduce 493) ((T_IS_NOT_IDENTICAL) reduce 493) ((T_IS_SMALLER_OR_EQUAL) reduce 493) ((T_LOGICAL_AND) reduce 493) ((T_LOGICAL_OR) reduce 493) ((T_LOGICAL_XOR) reduce 493) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 513) ((T_OBJECT_OPERATOR) reduce 513) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 513) ((T_POW) reduce 493) ((T_SL) reduce 493) ((T_SPACESHIP) reduce 493) ((T_SR) reduce 493) (("[") reduce 513) (("^") reduce 493) (("{") reduce 513) (("|") reduce 493)) 17943 ((("%") reduce 492) (("*") reduce 492) (("+") reduce 492) (("-") reduce 492) ((".") reduce 492) (("/") reduce 492) (("<") reduce 492) ((">") reduce 492) (("?") reduce 492) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_AS) reduce 492) ((T_BOOLEAN_AND) reduce 492) ((T_BOOLEAN_OR) reduce 492) ((T_COALESCE) reduce 492) ((T_INSTANCEOF) reduce 492) ((T_IS_EQUAL) reduce 492) ((T_IS_GREATER_OR_EQUAL) reduce 492) ((T_IS_IDENTICAL) reduce 492) ((T_IS_NOT_EQUAL) reduce 492) ((T_IS_NOT_IDENTICAL) reduce 492) ((T_IS_SMALLER_OR_EQUAL) reduce 492) ((T_LOGICAL_AND) reduce 492) ((T_LOGICAL_OR) reduce 492) ((T_LOGICAL_XOR) reduce 492) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 515) ((T_OBJECT_OPERATOR) reduce 515) ((T_POW) reduce 492) ((T_SL) reduce 492) ((T_SPACESHIP) reduce 492) ((T_SR) reduce 492) (("[") reduce 515) (("^") reduce 492) (("{") reduce 515) (("|") reduce 492)) 17944 ((("%") reduce 491) (("(") reduce 518) (("*") reduce 491) (("+") reduce 491) (("-") reduce 491) ((".") reduce 491) (("/") reduce 491) (("<") reduce 491) ((">") reduce 491) (("?") reduce 491) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_AS) reduce 491) ((T_BOOLEAN_AND) reduce 491) ((T_BOOLEAN_OR) reduce 491) ((T_COALESCE) reduce 491) ((T_INSTANCEOF) reduce 491) ((T_IS_EQUAL) reduce 491) ((T_IS_GREATER_OR_EQUAL) reduce 491) ((T_IS_IDENTICAL) reduce 491) ((T_IS_NOT_EQUAL) reduce 491) ((T_IS_NOT_IDENTICAL) reduce 491) ((T_IS_SMALLER_OR_EQUAL) reduce 491) ((T_LOGICAL_AND) reduce 491) ((T_LOGICAL_OR) reduce 491) ((T_LOGICAL_XOR) reduce 491) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 512) ((T_OBJECT_OPERATOR) reduce 512) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 512) ((T_POW) reduce 491) ((T_SL) reduce 491) ((T_SPACESHIP) reduce 491) ((T_SR) reduce 491) (("[") reduce 512) (("^") reduce 491) (("{") reduce 512) (("|") reduce 491)) 17945 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 17948 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) (("<") reduce 524) (("=") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AND_EQUAL) reduce 524) ((T_AS) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_COALESCE_EQUAL) reduce 524) ((T_CONCAT_EQUAL) reduce 524) ((T_DEC) reduce 524) ((T_DIV_EQUAL) reduce 524) ((T_INC) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_MINUS_EQUAL) reduce 524) ((T_MOD_EQUAL) reduce 524) ((T_MUL_EQUAL) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_OR_EQUAL) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_PLUS_EQUAL) reduce 524) ((T_POW) reduce 524) ((T_POW_EQUAL) reduce 524) ((T_SL) reduce 524) ((T_SL_EQUAL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) ((T_SR_EQUAL) reduce 524) ((T_XOR_EQUAL) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 17949 ((("%") reduce 445) (("*") reduce 445) (("+") reduce 445) (("-") reduce 445) ((".") reduce 445) (("/") reduce 445) (("<") reduce 445) ((">") reduce 445) (("?") reduce 445) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_AS) reduce 445) ((T_BOOLEAN_AND) reduce 445) ((T_BOOLEAN_OR) reduce 445) ((T_COALESCE) reduce 445) ((T_INSTANCEOF) reduce 445) ((T_IS_EQUAL) reduce 445) ((T_IS_GREATER_OR_EQUAL) reduce 445) ((T_IS_IDENTICAL) reduce 445) ((T_IS_NOT_EQUAL) reduce 445) ((T_IS_NOT_IDENTICAL) reduce 445) ((T_IS_SMALLER_OR_EQUAL) reduce 445) ((T_LOGICAL_AND) reduce 445) ((T_LOGICAL_OR) reduce 445) ((T_LOGICAL_XOR) reduce 445) ((T_POW) reduce 445) ((T_SL) reduce 445) ((T_SPACESHIP) reduce 445) ((T_SR) reduce 445) (("^") reduce 445) (("|") reduce 445)) 17950 ((("%") reduce 427) (("*") reduce 427) (("+") reduce 427) (("-") reduce 427) ((".") reduce 427) (("/") reduce 427) (("<") reduce 427) ((">") reduce 427) (("?") reduce 427) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_AS) reduce 427) ((T_BOOLEAN_AND) reduce 427) ((T_BOOLEAN_OR) reduce 427) ((T_COALESCE) reduce 427) ((T_INSTANCEOF) reduce 427) ((T_IS_EQUAL) reduce 427) ((T_IS_GREATER_OR_EQUAL) reduce 427) ((T_IS_IDENTICAL) reduce 427) ((T_IS_NOT_EQUAL) reduce 427) ((T_IS_NOT_IDENTICAL) reduce 427) ((T_IS_SMALLER_OR_EQUAL) reduce 427) ((T_LOGICAL_AND) reduce 427) ((T_LOGICAL_OR) reduce 427) ((T_LOGICAL_XOR) reduce 427) ((T_POW) reduce 427) ((T_SL) reduce 427) ((T_SPACESHIP) reduce 427) ((T_SR) reduce 427) (("^") reduce 427) (("|") reduce 427)) 17951 ((("%") reduce 449) (("*") reduce 449) (("+") reduce 449) (("-") reduce 449) ((".") reduce 449) (("/") reduce 449) (("<") reduce 449) ((">") reduce 449) (("?") reduce 449) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_AS) reduce 449) ((T_BOOLEAN_AND) reduce 449) ((T_BOOLEAN_OR) reduce 449) ((T_COALESCE) reduce 449) ((T_INSTANCEOF) reduce 449) ((T_IS_EQUAL) reduce 449) ((T_IS_GREATER_OR_EQUAL) reduce 449) ((T_IS_IDENTICAL) reduce 449) ((T_IS_NOT_EQUAL) reduce 449) ((T_IS_NOT_IDENTICAL) reduce 449) ((T_IS_SMALLER_OR_EQUAL) reduce 449) ((T_LOGICAL_AND) reduce 449) ((T_LOGICAL_OR) reduce 449) ((T_LOGICAL_XOR) reduce 449) ((T_POW) reduce 449) ((T_SL) reduce 449) ((T_SPACESHIP) reduce 449) ((T_SR) reduce 449) (("^") reduce 449) (("|") reduce 449)) 17952 ((("%") reduce 494) (("(") shift) (("*") reduce 494) (("+") reduce 494) (("-") reduce 494) ((".") reduce 494) (("/") reduce 494) (("<") reduce 494) ((">") reduce 494) (("?") reduce 494) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_AS) reduce 494) ((T_BOOLEAN_AND) reduce 494) ((T_BOOLEAN_OR) reduce 494) ((T_COALESCE) reduce 494) ((T_INSTANCEOF) reduce 494) ((T_IS_EQUAL) reduce 494) ((T_IS_GREATER_OR_EQUAL) reduce 494) ((T_IS_IDENTICAL) reduce 494) ((T_IS_NOT_EQUAL) reduce 494) ((T_IS_NOT_IDENTICAL) reduce 494) ((T_IS_SMALLER_OR_EQUAL) reduce 494) ((T_LOGICAL_AND) reduce 494) ((T_LOGICAL_OR) reduce 494) ((T_LOGICAL_XOR) reduce 494) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 494) ((T_OBJECT_OPERATOR) reduce 494) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 494) ((T_SL) reduce 494) ((T_SPACESHIP) reduce 494) ((T_SR) reduce 494) (("[") reduce 494) (("^") reduce 494) (("{") reduce 494) (("|") reduce 494)) 17953 ((("%") reduce 423) (("*") reduce 423) (("+") reduce 423) (("-") reduce 423) ((".") reduce 423) (("/") reduce 423) (("<") reduce 423) ((">") reduce 423) (("?") reduce 423) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_AS) reduce 423) ((T_BOOLEAN_AND) reduce 423) ((T_BOOLEAN_OR) reduce 423) ((T_COALESCE) reduce 423) ((T_INSTANCEOF) reduce 423) ((T_IS_EQUAL) reduce 423) ((T_IS_GREATER_OR_EQUAL) reduce 423) ((T_IS_IDENTICAL) reduce 423) ((T_IS_NOT_EQUAL) reduce 423) ((T_IS_NOT_IDENTICAL) reduce 423) ((T_IS_SMALLER_OR_EQUAL) reduce 423) ((T_LOGICAL_AND) reduce 423) ((T_LOGICAL_OR) reduce 423) ((T_LOGICAL_XOR) reduce 423) ((T_POW) reduce 423) ((T_SL) reduce 423) ((T_SPACESHIP) reduce 423) ((T_SR) reduce 423) (("^") reduce 423) (("|") reduce 423)) 17954 ((("%") reduce 437) (("*") reduce 437) (("+") reduce 437) (("-") reduce 437) ((".") reduce 437) (("/") reduce 437) (("<") reduce 437) ((">") reduce 437) (("?") reduce 437) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_AS) reduce 437) ((T_BOOLEAN_AND) reduce 437) ((T_BOOLEAN_OR) reduce 437) ((T_COALESCE) reduce 437) ((T_INSTANCEOF) reduce 437) ((T_IS_EQUAL) reduce 437) ((T_IS_GREATER_OR_EQUAL) reduce 437) ((T_IS_IDENTICAL) reduce 437) ((T_IS_NOT_EQUAL) reduce 437) ((T_IS_NOT_IDENTICAL) reduce 437) ((T_IS_SMALLER_OR_EQUAL) reduce 437) ((T_LOGICAL_AND) reduce 437) ((T_LOGICAL_OR) reduce 437) ((T_LOGICAL_XOR) reduce 437) ((T_POW) reduce 437) ((T_SL) reduce 437) ((T_SPACESHIP) reduce 437) ((T_SR) reduce 437) (("^") reduce 437) (("|") reduce 437)) 17955 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) (("<") reduce 519) (("=") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AND_EQUAL) reduce 519) ((T_AS) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_COALESCE_EQUAL) reduce 519) ((T_CONCAT_EQUAL) reduce 519) ((T_DEC) reduce 519) ((T_DIV_EQUAL) reduce 519) ((T_INC) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_MINUS_EQUAL) reduce 519) ((T_MOD_EQUAL) reduce 519) ((T_MUL_EQUAL) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_OR_EQUAL) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_PLUS_EQUAL) reduce 519) ((T_POW) reduce 519) ((T_POW_EQUAL) reduce 519) ((T_SL) reduce 519) ((T_SL_EQUAL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) ((T_SR_EQUAL) reduce 519) ((T_XOR_EQUAL) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 17956 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) (("<") reduce 526) (("=") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AND_EQUAL) reduce 526) ((T_AS) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_COALESCE_EQUAL) reduce 526) ((T_CONCAT_EQUAL) reduce 526) ((T_DEC) reduce 526) ((T_DIV_EQUAL) reduce 526) ((T_INC) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_MINUS_EQUAL) reduce 526) ((T_MOD_EQUAL) reduce 526) ((T_MUL_EQUAL) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_OR_EQUAL) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_PLUS_EQUAL) reduce 526) ((T_POW) reduce 526) ((T_POW_EQUAL) reduce 526) ((T_SL) reduce 526) ((T_SL_EQUAL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) ((T_SR_EQUAL) reduce 526) ((T_XOR_EQUAL) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 17957 ((("%") reduce 367) (("*") reduce 367) (("+") reduce 367) (("-") reduce 367) ((".") reduce 367) (("/") reduce 367) (("<") reduce 367) (("=") shift) ((">") reduce 367) (("?") reduce 367) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AND_EQUAL) shift) ((T_AS) reduce 367) ((T_BOOLEAN_AND) reduce 367) ((T_BOOLEAN_OR) reduce 367) ((T_COALESCE) reduce 367) ((T_COALESCE_EQUAL) shift) ((T_CONCAT_EQUAL) shift) ((T_DEC) shift) ((T_DIV_EQUAL) shift) ((T_INC) shift) ((T_INSTANCEOF) reduce 367) ((T_IS_EQUAL) reduce 367) ((T_IS_GREATER_OR_EQUAL) reduce 367) ((T_IS_IDENTICAL) reduce 367) ((T_IS_NOT_EQUAL) reduce 367) ((T_IS_NOT_IDENTICAL) reduce 367) ((T_IS_SMALLER_OR_EQUAL) reduce 367) ((T_LOGICAL_AND) reduce 367) ((T_LOGICAL_OR) reduce 367) ((T_LOGICAL_XOR) reduce 367) ((T_MINUS_EQUAL) shift) ((T_MOD_EQUAL) shift) ((T_MUL_EQUAL) shift) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_OR_EQUAL) shift) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_PLUS_EQUAL) shift) ((T_POW) reduce 367) ((T_POW_EQUAL) shift) ((T_SL) reduce 367) ((T_SL_EQUAL) shift) ((T_SPACESHIP) reduce 367) ((T_SR) reduce 367) ((T_SR_EQUAL) shift) ((T_XOR_EQUAL) shift) (("[") reduce 510) (("^") reduce 367) (("{") reduce 510) (("|") reduce 367)) 17960 ((("%") reduce 411) (("*") reduce 411) (("+") reduce 411) (("-") reduce 411) ((".") reduce 411) (("/") reduce 411) (("<") reduce 411) ((">") reduce 411) (("?") reduce 411) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_AS) reduce 411) ((T_BOOLEAN_AND) reduce 411) ((T_BOOLEAN_OR) reduce 411) ((T_COALESCE) reduce 411) ((T_INSTANCEOF) reduce 411) ((T_IS_EQUAL) reduce 411) ((T_IS_GREATER_OR_EQUAL) reduce 411) ((T_IS_IDENTICAL) reduce 411) ((T_IS_NOT_EQUAL) reduce 411) ((T_IS_NOT_IDENTICAL) reduce 411) ((T_IS_SMALLER_OR_EQUAL) reduce 411) ((T_LOGICAL_AND) reduce 411) ((T_LOGICAL_OR) reduce 411) ((T_LOGICAL_XOR) reduce 411) ((T_POW) shift) ((T_SL) reduce 411) ((T_SPACESHIP) reduce 411) ((T_SR) reduce 411) (("^") reduce 411) (("|") reduce 411)) 17991 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 395) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 395) ((T_BOOLEAN_AND) reduce 395) ((T_BOOLEAN_OR) reduce 395) ((T_COALESCE) reduce 395) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 395) ((T_LOGICAL_OR) reduce 395) ((T_LOGICAL_XOR) reduce 395) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") reduce 395)) 17992 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 398) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 398) ((T_BOOLEAN_AND) reduce 398) ((T_BOOLEAN_OR) reduce 398) ((T_COALESCE) reduce 398) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 398) ((T_LOGICAL_OR) reduce 398) ((T_LOGICAL_XOR) reduce 398) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 398) (("|") reduce 398)) 17993 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 407) (("/") shift) (("<") reduce 407) ((">") reduce 407) (("?") reduce 407) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_AS) reduce 407) ((T_BOOLEAN_AND) reduce 407) ((T_BOOLEAN_OR) reduce 407) ((T_COALESCE) reduce 407) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 407) ((T_IS_GREATER_OR_EQUAL) reduce 407) ((T_IS_IDENTICAL) reduce 407) ((T_IS_NOT_EQUAL) reduce 407) ((T_IS_NOT_IDENTICAL) reduce 407) ((T_IS_SMALLER_OR_EQUAL) reduce 407) ((T_LOGICAL_AND) reduce 407) ((T_LOGICAL_OR) reduce 407) ((T_LOGICAL_XOR) reduce 407) ((T_POW) shift) ((T_SL) reduce 407) ((T_SPACESHIP) reduce 407) ((T_SR) reduce 407) (("^") reduce 407) (("|") reduce 407)) 17994 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 420) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_AS) reduce 420) ((T_BOOLEAN_AND) reduce 420) ((T_BOOLEAN_OR) reduce 420) ((T_COALESCE) reduce 420) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 420) ((T_LOGICAL_OR) reduce 420) ((T_LOGICAL_XOR) reduce 420) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 420) (("|") reduce 420)) 17995 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 406) (("/") shift) (("<") reduce 406) ((">") reduce 406) (("?") reduce 406) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_AS) reduce 406) ((T_BOOLEAN_AND) reduce 406) ((T_BOOLEAN_OR) reduce 406) ((T_COALESCE) reduce 406) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 406) ((T_IS_GREATER_OR_EQUAL) reduce 406) ((T_IS_IDENTICAL) reduce 406) ((T_IS_NOT_EQUAL) reduce 406) ((T_IS_NOT_IDENTICAL) reduce 406) ((T_IS_SMALLER_OR_EQUAL) reduce 406) ((T_LOGICAL_AND) reduce 406) ((T_LOGICAL_OR) reduce 406) ((T_LOGICAL_XOR) reduce 406) ((T_POW) shift) ((T_SL) reduce 406) ((T_SPACESHIP) reduce 406) ((T_SR) reduce 406) (("^") reduce 406) (("|") reduce 406)) 17996 ((("%") reduce 403) (("*") reduce 403) (("+") reduce 403) (("-") reduce 403) ((".") reduce 403) (("/") reduce 403) (("<") reduce 403) ((">") reduce 403) (("?") reduce 403) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_AS) reduce 403) ((T_BOOLEAN_AND) reduce 403) ((T_BOOLEAN_OR) reduce 403) ((T_COALESCE) reduce 403) ((T_INSTANCEOF) reduce 403) ((T_IS_EQUAL) reduce 403) ((T_IS_GREATER_OR_EQUAL) reduce 403) ((T_IS_IDENTICAL) reduce 403) ((T_IS_NOT_EQUAL) reduce 403) ((T_IS_NOT_IDENTICAL) reduce 403) ((T_IS_SMALLER_OR_EQUAL) reduce 403) ((T_LOGICAL_AND) reduce 403) ((T_LOGICAL_OR) reduce 403) ((T_LOGICAL_XOR) reduce 403) ((T_POW) shift) ((T_SL) reduce 403) ((T_SPACESHIP) reduce 403) ((T_SR) reduce 403) (("^") reduce 403) (("|") reduce 403)) 17997 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 394) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 394) ((T_LOGICAL_XOR) reduce 394) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 17998 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 392) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 392) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 17999 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 393) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 393) ((T_LOGICAL_OR) reduce 393) ((T_LOGICAL_XOR) reduce 393) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18000 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 417) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_AS) reduce 417) ((T_BOOLEAN_AND) reduce 417) ((T_BOOLEAN_OR) reduce 417) ((T_COALESCE) reduce 417) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 417) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 417) ((T_IS_NOT_EQUAL) reduce 417) ((T_IS_NOT_IDENTICAL) reduce 417) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 417) ((T_LOGICAL_OR) reduce 417) ((T_LOGICAL_XOR) reduce 417) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 417) ((T_SR) shift) (("^") reduce 417) (("|") reduce 417)) 18001 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 413) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_AS) reduce 413) ((T_BOOLEAN_AND) reduce 413) ((T_BOOLEAN_OR) reduce 413) ((T_COALESCE) reduce 413) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 413) ((T_LOGICAL_OR) reduce 413) ((T_LOGICAL_XOR) reduce 413) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 413) (("|") reduce 413)) 18002 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 415) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_AS) reduce 415) ((T_BOOLEAN_AND) reduce 415) ((T_BOOLEAN_OR) reduce 415) ((T_COALESCE) reduce 415) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 415) ((T_LOGICAL_OR) reduce 415) ((T_LOGICAL_XOR) reduce 415) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 415) (("|") reduce 415)) 18003 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 412) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_AS) reduce 412) ((T_BOOLEAN_AND) reduce 412) ((T_BOOLEAN_OR) reduce 412) ((T_COALESCE) reduce 412) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 412) ((T_LOGICAL_OR) reduce 412) ((T_LOGICAL_XOR) reduce 412) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 412) (("|") reduce 412)) 18004 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 419) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_AS) reduce 419) ((T_BOOLEAN_AND) reduce 419) ((T_BOOLEAN_OR) reduce 419) ((T_COALESCE) reduce 419) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 419) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 419) ((T_IS_NOT_EQUAL) reduce 419) ((T_IS_NOT_IDENTICAL) reduce 419) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 419) ((T_LOGICAL_OR) reduce 419) ((T_LOGICAL_XOR) reduce 419) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 419) ((T_SR) shift) (("^") reduce 419) (("|") reduce 419)) 18005 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 414) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_AS) reduce 414) ((T_BOOLEAN_AND) reduce 414) ((T_BOOLEAN_OR) reduce 414) ((T_COALESCE) reduce 414) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 414) ((T_LOGICAL_OR) reduce 414) ((T_LOGICAL_XOR) reduce 414) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 414) (("|") reduce 414)) 18008 ((("%") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AS) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93)) 18009 ((("%") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AS) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92)) 18010 ((("%") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AS) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94)) 18011 ((("%") reduce 470) (("*") reduce 470) (("+") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AS) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470)) 18012 ((("%") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AS) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91)) 18013 ((("%") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AS) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 18014 ((("%") reduce 472) (("*") reduce 472) (("+") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AS) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472)) 18015 ((("%") reduce 421) (("*") reduce 421) (("+") reduce 421) (("-") reduce 421) ((".") reduce 421) (("/") reduce 421) (("<") reduce 421) ((">") reduce 421) (("?") reduce 421) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_AS) reduce 421) ((T_BOOLEAN_AND) reduce 421) ((T_BOOLEAN_OR) reduce 421) ((T_COALESCE) reduce 421) ((T_INSTANCEOF) reduce 421) ((T_IS_EQUAL) reduce 421) ((T_IS_GREATER_OR_EQUAL) reduce 421) ((T_IS_IDENTICAL) reduce 421) ((T_IS_NOT_EQUAL) reduce 421) ((T_IS_NOT_IDENTICAL) reduce 421) ((T_IS_SMALLER_OR_EQUAL) reduce 421) ((T_LOGICAL_AND) reduce 421) ((T_LOGICAL_OR) reduce 421) ((T_LOGICAL_XOR) reduce 421) ((T_POW) reduce 421) ((T_SL) reduce 421) ((T_SPACESHIP) reduce 421) ((T_SR) reduce 421) (("^") reduce 421) (("|") reduce 421)) 18016 ((("%") reduce 471) (("*") reduce 471) (("+") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AS) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471)) 18017 ((("%") reduce 473) (("*") reduce 473) (("+") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AS) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 18018 ((("%") reduce 534) (("*") reduce 534) (("+") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AS) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 18025 ((("%") reduce 536) (("*") reduce 536) (("+") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AS) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 18027 ((("%") reduce 535) (("*") reduce 535) (("+") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AS) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 18028 ((("%") reduce 540) (("*") reduce 540) (("+") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AS) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 18029 ((("%") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AS) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 18030 ((("%") reduce 537) (("*") reduce 537) (("+") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AS) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 18031 ((("%") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AS) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 18034 ((("%") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AS) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 18035 ((("%") reduce 538) (("*") reduce 538) (("+") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AS) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 18037 ((("%") reduce 539) (("*") reduce 539) (("+") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AS) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 18039 ((("%") reduce 474) (("*") reduce 474) (("+") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AS) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474)) 18040 ((("%") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AS) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 18043 ((("%") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AS) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 18044 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 426) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 426) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 426) ((T_LOGICAL_OR) reduce 426) ((T_LOGICAL_XOR) reduce 426) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18045 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 390) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 390) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) reduce 390) ((T_COALESCE) reduce 390) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 390) ((T_LOGICAL_OR) reduce 390) ((T_LOGICAL_XOR) reduce 390) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18046 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 391) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 391) ((T_BOOLEAN_AND) reduce 391) ((T_BOOLEAN_OR) reduce 391) ((T_COALESCE) reduce 391) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 391) ((T_LOGICAL_OR) reduce 391) ((T_LOGICAL_XOR) reduce 391) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18047 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 396) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_AS) reduce 396) ((T_BOOLEAN_AND) reduce 396) ((T_BOOLEAN_OR) reduce 396) ((T_COALESCE) reduce 396) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 396) ((T_LOGICAL_OR) reduce 396) ((T_LOGICAL_XOR) reduce 396) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 396) (("|") reduce 396)) 18048 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 397) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_AS) reduce 397) ((T_BOOLEAN_AND) reduce 397) ((T_BOOLEAN_OR) reduce 397) ((T_COALESCE) reduce 397) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 397) ((T_LOGICAL_OR) reduce 397) ((T_LOGICAL_XOR) reduce 397) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 397) (("|") reduce 397)) 18052 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 424) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 424) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 424) ((T_LOGICAL_OR) reduce 424) ((T_LOGICAL_XOR) reduce 424) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18053 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 425) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 425) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 425) ((T_LOGICAL_OR) reduce 425) ((T_LOGICAL_XOR) reduce 425) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18054 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 418) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_AS) reduce 418) ((T_BOOLEAN_AND) reduce 418) ((T_BOOLEAN_OR) reduce 418) ((T_COALESCE) reduce 418) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 418) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 418) ((T_IS_NOT_EQUAL) reduce 418) ((T_IS_NOT_IDENTICAL) reduce 418) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 418) ((T_LOGICAL_OR) reduce 418) ((T_LOGICAL_XOR) reduce 418) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 418) ((T_SR) shift) (("^") reduce 418) (("|") reduce 418)) 18055 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 416) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_AS) reduce 416) ((T_BOOLEAN_AND) reduce 416) ((T_BOOLEAN_OR) reduce 416) ((T_COALESCE) reduce 416) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 416) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 416) ((T_IS_NOT_EQUAL) reduce 416) ((T_IS_NOT_IDENTICAL) reduce 416) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 416) ((T_LOGICAL_OR) reduce 416) ((T_LOGICAL_XOR) reduce 416) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 416) ((T_SR) shift) (("^") reduce 416) (("|") reduce 416)) 18056 ((("%") reduce 404) (("*") reduce 404) (("+") reduce 404) (("-") reduce 404) ((".") reduce 404) (("/") reduce 404) (("<") reduce 404) ((">") reduce 404) (("?") reduce 404) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_AS) reduce 404) ((T_BOOLEAN_AND) reduce 404) ((T_BOOLEAN_OR) reduce 404) ((T_COALESCE) reduce 404) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 404) ((T_IS_GREATER_OR_EQUAL) reduce 404) ((T_IS_IDENTICAL) reduce 404) ((T_IS_NOT_EQUAL) reduce 404) ((T_IS_NOT_IDENTICAL) reduce 404) ((T_IS_SMALLER_OR_EQUAL) reduce 404) ((T_LOGICAL_AND) reduce 404) ((T_LOGICAL_OR) reduce 404) ((T_LOGICAL_XOR) reduce 404) ((T_POW) shift) ((T_SL) reduce 404) ((T_SPACESHIP) reduce 404) ((T_SR) reduce 404) (("^") reduce 404) (("|") reduce 404)) 18057 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 399) (("/") shift) (("<") reduce 399) ((">") reduce 399) (("?") reduce 399) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_AS) reduce 399) ((T_BOOLEAN_AND) reduce 399) ((T_BOOLEAN_OR) reduce 399) ((T_COALESCE) reduce 399) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 399) ((T_IS_GREATER_OR_EQUAL) reduce 399) ((T_IS_IDENTICAL) reduce 399) ((T_IS_NOT_EQUAL) reduce 399) ((T_IS_NOT_IDENTICAL) reduce 399) ((T_IS_SMALLER_OR_EQUAL) reduce 399) ((T_LOGICAL_AND) reduce 399) ((T_LOGICAL_OR) reduce 399) ((T_LOGICAL_XOR) reduce 399) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 399) ((T_SR) shift) (("^") reduce 399) (("|") reduce 399)) 18058 ((("%") shift) (("*") shift) (("+") reduce 401) (("-") reduce 401) ((".") reduce 401) (("/") shift) (("<") reduce 401) ((">") reduce 401) (("?") reduce 401) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_AS) reduce 401) ((T_BOOLEAN_AND) reduce 401) ((T_BOOLEAN_OR) reduce 401) ((T_COALESCE) reduce 401) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 401) ((T_IS_GREATER_OR_EQUAL) reduce 401) ((T_IS_IDENTICAL) reduce 401) ((T_IS_NOT_EQUAL) reduce 401) ((T_IS_NOT_IDENTICAL) reduce 401) ((T_IS_SMALLER_OR_EQUAL) reduce 401) ((T_LOGICAL_AND) reduce 401) ((T_LOGICAL_OR) reduce 401) ((T_LOGICAL_XOR) reduce 401) ((T_POW) shift) ((T_SL) reduce 401) ((T_SPACESHIP) reduce 401) ((T_SR) reduce 401) (("^") reduce 401) (("|") reduce 401)) 18059 ((("%") shift) (("*") shift) (("+") reduce 400) (("-") reduce 400) ((".") reduce 400) (("/") shift) (("<") reduce 400) ((">") reduce 400) (("?") reduce 400) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_AS) reduce 400) ((T_BOOLEAN_AND) reduce 400) ((T_BOOLEAN_OR) reduce 400) ((T_COALESCE) reduce 400) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 400) ((T_IS_GREATER_OR_EQUAL) reduce 400) ((T_IS_IDENTICAL) reduce 400) ((T_IS_NOT_EQUAL) reduce 400) ((T_IS_NOT_IDENTICAL) reduce 400) ((T_IS_SMALLER_OR_EQUAL) reduce 400) ((T_LOGICAL_AND) reduce 400) ((T_LOGICAL_OR) reduce 400) ((T_LOGICAL_XOR) reduce 400) ((T_POW) shift) ((T_SL) reduce 400) ((T_SPACESHIP) reduce 400) ((T_SR) reduce 400) (("^") reduce 400) (("|") reduce 400)) 18060 ((("%") reduce 402) (("*") reduce 402) (("+") reduce 402) (("-") reduce 402) ((".") reduce 402) (("/") reduce 402) (("<") reduce 402) ((">") reduce 402) (("?") reduce 402) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_AS) reduce 402) ((T_BOOLEAN_AND) reduce 402) ((T_BOOLEAN_OR) reduce 402) ((T_COALESCE) reduce 402) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 402) ((T_IS_GREATER_OR_EQUAL) reduce 402) ((T_IS_IDENTICAL) reduce 402) ((T_IS_NOT_EQUAL) reduce 402) ((T_IS_NOT_IDENTICAL) reduce 402) ((T_IS_SMALLER_OR_EQUAL) reduce 402) ((T_LOGICAL_AND) reduce 402) ((T_LOGICAL_OR) reduce 402) ((T_LOGICAL_XOR) reduce 402) ((T_POW) shift) ((T_SL) reduce 402) ((T_SPACESHIP) reduce 402) ((T_SR) reduce 402) (("^") reduce 402) (("|") reduce 402)) 18061 ((("%") reduce 405) (("*") reduce 405) (("+") reduce 405) (("-") reduce 405) ((".") reduce 405) (("/") reduce 405) (("<") reduce 405) ((">") reduce 405) (("?") reduce 405) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_AS) reduce 405) ((T_BOOLEAN_AND) reduce 405) ((T_BOOLEAN_OR) reduce 405) ((T_COALESCE) reduce 405) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 405) ((T_IS_GREATER_OR_EQUAL) reduce 405) ((T_IS_IDENTICAL) reduce 405) ((T_IS_NOT_EQUAL) reduce 405) ((T_IS_NOT_IDENTICAL) reduce 405) ((T_IS_SMALLER_OR_EQUAL) reduce 405) ((T_LOGICAL_AND) reduce 405) ((T_LOGICAL_OR) reduce 405) ((T_LOGICAL_XOR) reduce 405) ((T_POW) shift) ((T_SL) reduce 405) ((T_SPACESHIP) reduce 405) ((T_SR) reduce 405) (("^") reduce 405) (("|") reduce 405)) 18063 ((("%") reduce 73) (("(") reduce 73) (("*") reduce 73) (("+") reduce 73) (("-") reduce 73) ((".") reduce 73) (("/") reduce 73) (("<") reduce 73) ((">") reduce 73) (("?") reduce 73) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_AS) reduce 73) ((T_BOOLEAN_AND) reduce 73) ((T_BOOLEAN_OR) reduce 73) ((T_COALESCE) reduce 73) ((T_INSTANCEOF) reduce 73) ((T_IS_EQUAL) reduce 73) ((T_IS_GREATER_OR_EQUAL) reduce 73) ((T_IS_IDENTICAL) reduce 73) ((T_IS_NOT_EQUAL) reduce 73) ((T_IS_NOT_IDENTICAL) reduce 73) ((T_IS_SMALLER_OR_EQUAL) reduce 73) ((T_LOGICAL_AND) reduce 73) ((T_LOGICAL_OR) reduce 73) ((T_LOGICAL_XOR) reduce 73) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 73) ((T_OBJECT_OPERATOR) reduce 73) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 73) ((T_POW) reduce 73) ((T_SL) reduce 73) ((T_SPACESHIP) reduce 73) ((T_SR) reduce 73) (("[") reduce 73) (("^") reduce 73) (("{") reduce 73) (("|") reduce 73)) 18064 ((("%") reduce 52) (("(") reduce 52) (("*") reduce 52) (("+") reduce 52) (("-") reduce 52) ((".") reduce 52) (("/") reduce 52) (("<") reduce 52) ((">") reduce 52) (("?") reduce 52) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_AS) reduce 52) ((T_BOOLEAN_AND) reduce 52) ((T_BOOLEAN_OR) reduce 52) ((T_COALESCE) reduce 52) ((T_INSTANCEOF) reduce 52) ((T_IS_EQUAL) reduce 52) ((T_IS_GREATER_OR_EQUAL) reduce 52) ((T_IS_IDENTICAL) reduce 52) ((T_IS_NOT_EQUAL) reduce 52) ((T_IS_NOT_IDENTICAL) reduce 52) ((T_IS_SMALLER_OR_EQUAL) reduce 52) ((T_LOGICAL_AND) reduce 52) ((T_LOGICAL_OR) reduce 52) ((T_LOGICAL_XOR) reduce 52) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 52) ((T_OBJECT_OPERATOR) reduce 52) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 52) ((T_POW) reduce 52) ((T_SL) reduce 52) ((T_SPACESHIP) reduce 52) ((T_SR) reduce 52) (("[") reduce 52) (("^") reduce 52) (("{") reduce 52) (("|") reduce 52)) 18065 ((("%") reduce 27) (("(") reduce 27) (("*") reduce 27) (("+") reduce 27) (("-") reduce 27) ((".") reduce 27) (("/") reduce 27) (("<") reduce 27) ((">") reduce 27) (("?") reduce 27) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_AS) reduce 27) ((T_BOOLEAN_AND) reduce 27) ((T_BOOLEAN_OR) reduce 27) ((T_COALESCE) reduce 27) ((T_INSTANCEOF) reduce 27) ((T_IS_EQUAL) reduce 27) ((T_IS_GREATER_OR_EQUAL) reduce 27) ((T_IS_IDENTICAL) reduce 27) ((T_IS_NOT_EQUAL) reduce 27) ((T_IS_NOT_IDENTICAL) reduce 27) ((T_IS_SMALLER_OR_EQUAL) reduce 27) ((T_LOGICAL_AND) reduce 27) ((T_LOGICAL_OR) reduce 27) ((T_LOGICAL_XOR) reduce 27) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 27) ((T_OBJECT_OPERATOR) reduce 27) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 27) ((T_POW) reduce 27) ((T_SL) reduce 27) ((T_SPACESHIP) reduce 27) ((T_SR) reduce 27) (("[") reduce 27) (("^") reduce 27) (("{") reduce 27) (("|") reduce 27)) 18066 ((("%") reduce 51) (("(") reduce 51) (("*") reduce 51) (("+") reduce 51) (("-") reduce 51) ((".") reduce 51) (("/") reduce 51) (("<") reduce 51) ((">") reduce 51) (("?") reduce 51) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_AS) reduce 51) ((T_BOOLEAN_AND) reduce 51) ((T_BOOLEAN_OR) reduce 51) ((T_COALESCE) reduce 51) ((T_INSTANCEOF) reduce 51) ((T_IS_EQUAL) reduce 51) ((T_IS_GREATER_OR_EQUAL) reduce 51) ((T_IS_IDENTICAL) reduce 51) ((T_IS_NOT_EQUAL) reduce 51) ((T_IS_NOT_IDENTICAL) reduce 51) ((T_IS_SMALLER_OR_EQUAL) reduce 51) ((T_LOGICAL_AND) reduce 51) ((T_LOGICAL_OR) reduce 51) ((T_LOGICAL_XOR) reduce 51) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 51) ((T_OBJECT_OPERATOR) reduce 51) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 51) ((T_POW) reduce 51) ((T_SL) reduce 51) ((T_SPACESHIP) reduce 51) ((T_SR) reduce 51) (("[") reduce 51) (("^") reduce 51) (("{") reduce 51) (("|") reduce 51)) 18067 ((("%") reduce 53) (("(") reduce 53) (("*") reduce 53) (("+") reduce 53) (("-") reduce 53) ((".") reduce 53) (("/") reduce 53) (("<") reduce 53) ((">") reduce 53) (("?") reduce 53) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_AS) reduce 53) ((T_BOOLEAN_AND) reduce 53) ((T_BOOLEAN_OR) reduce 53) ((T_COALESCE) reduce 53) ((T_INSTANCEOF) reduce 53) ((T_IS_EQUAL) reduce 53) ((T_IS_GREATER_OR_EQUAL) reduce 53) ((T_IS_IDENTICAL) reduce 53) ((T_IS_NOT_EQUAL) reduce 53) ((T_IS_NOT_IDENTICAL) reduce 53) ((T_IS_SMALLER_OR_EQUAL) reduce 53) ((T_LOGICAL_AND) reduce 53) ((T_LOGICAL_OR) reduce 53) ((T_LOGICAL_XOR) reduce 53) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 53) ((T_OBJECT_OPERATOR) reduce 53) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 53) ((T_POW) reduce 53) ((T_SL) reduce 53) ((T_SPACESHIP) reduce 53) ((T_SR) reduce 53) (("[") reduce 53) (("^") reduce 53) (("{") reduce 53) (("|") reduce 53)) 18068 ((("%") reduce 49) (("(") reduce 49) (("*") reduce 49) (("+") reduce 49) (("-") reduce 49) ((".") reduce 49) (("/") reduce 49) (("<") reduce 49) ((">") reduce 49) (("?") reduce 49) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_AS) reduce 49) ((T_BOOLEAN_AND) reduce 49) ((T_BOOLEAN_OR) reduce 49) ((T_COALESCE) reduce 49) ((T_INSTANCEOF) reduce 49) ((T_IS_EQUAL) reduce 49) ((T_IS_GREATER_OR_EQUAL) reduce 49) ((T_IS_IDENTICAL) reduce 49) ((T_IS_NOT_EQUAL) reduce 49) ((T_IS_NOT_IDENTICAL) reduce 49) ((T_IS_SMALLER_OR_EQUAL) reduce 49) ((T_LOGICAL_AND) reduce 49) ((T_LOGICAL_OR) reduce 49) ((T_LOGICAL_XOR) reduce 49) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 49) ((T_OBJECT_OPERATOR) reduce 49) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 49) ((T_POW) reduce 49) ((T_SL) reduce 49) ((T_SPACESHIP) reduce 49) ((T_SR) reduce 49) (("[") reduce 49) (("^") reduce 49) (("{") reduce 49) (("|") reduce 49)) 18069 ((("%") reduce 29) (("(") reduce 29) (("*") reduce 29) (("+") reduce 29) (("-") reduce 29) ((".") reduce 29) (("/") reduce 29) (("<") reduce 29) ((">") reduce 29) (("?") reduce 29) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_AS) reduce 29) ((T_BOOLEAN_AND) reduce 29) ((T_BOOLEAN_OR) reduce 29) ((T_COALESCE) reduce 29) ((T_INSTANCEOF) reduce 29) ((T_IS_EQUAL) reduce 29) ((T_IS_GREATER_OR_EQUAL) reduce 29) ((T_IS_IDENTICAL) reduce 29) ((T_IS_NOT_EQUAL) reduce 29) ((T_IS_NOT_IDENTICAL) reduce 29) ((T_IS_SMALLER_OR_EQUAL) reduce 29) ((T_LOGICAL_AND) reduce 29) ((T_LOGICAL_OR) reduce 29) ((T_LOGICAL_XOR) reduce 29) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 29) ((T_OBJECT_OPERATOR) reduce 29) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 29) ((T_POW) reduce 29) ((T_SL) reduce 29) ((T_SPACESHIP) reduce 29) ((T_SR) reduce 29) (("[") reduce 29) (("^") reduce 29) (("{") reduce 29) (("|") reduce 29)) 18070 ((("%") reduce 59) (("(") reduce 59) (("*") reduce 59) (("+") reduce 59) (("-") reduce 59) ((".") reduce 59) (("/") reduce 59) (("<") reduce 59) ((">") reduce 59) (("?") reduce 59) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_AS) reduce 59) ((T_BOOLEAN_AND) reduce 59) ((T_BOOLEAN_OR) reduce 59) ((T_COALESCE) reduce 59) ((T_INSTANCEOF) reduce 59) ((T_IS_EQUAL) reduce 59) ((T_IS_GREATER_OR_EQUAL) reduce 59) ((T_IS_IDENTICAL) reduce 59) ((T_IS_NOT_EQUAL) reduce 59) ((T_IS_NOT_IDENTICAL) reduce 59) ((T_IS_SMALLER_OR_EQUAL) reduce 59) ((T_LOGICAL_AND) reduce 59) ((T_LOGICAL_OR) reduce 59) ((T_LOGICAL_XOR) reduce 59) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 59) ((T_OBJECT_OPERATOR) reduce 59) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 59) ((T_POW) reduce 59) ((T_SL) reduce 59) ((T_SPACESHIP) reduce 59) ((T_SR) reduce 59) (("[") reduce 59) (("^") reduce 59) (("{") reduce 59) (("|") reduce 59)) 18071 ((("%") reduce 60) (("(") reduce 60) (("*") reduce 60) (("+") reduce 60) (("-") reduce 60) ((".") reduce 60) (("/") reduce 60) (("<") reduce 60) ((">") reduce 60) (("?") reduce 60) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_AS) reduce 60) ((T_BOOLEAN_AND) reduce 60) ((T_BOOLEAN_OR) reduce 60) ((T_COALESCE) reduce 60) ((T_INSTANCEOF) reduce 60) ((T_IS_EQUAL) reduce 60) ((T_IS_GREATER_OR_EQUAL) reduce 60) ((T_IS_IDENTICAL) reduce 60) ((T_IS_NOT_EQUAL) reduce 60) ((T_IS_NOT_IDENTICAL) reduce 60) ((T_IS_SMALLER_OR_EQUAL) reduce 60) ((T_LOGICAL_AND) reduce 60) ((T_LOGICAL_OR) reduce 60) ((T_LOGICAL_XOR) reduce 60) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 60) ((T_OBJECT_OPERATOR) reduce 60) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 60) ((T_POW) reduce 60) ((T_SL) reduce 60) ((T_SPACESHIP) reduce 60) ((T_SR) reduce 60) (("[") reduce 60) (("^") reduce 60) (("{") reduce 60) (("|") reduce 60)) 18072 ((("%") reduce 11) (("(") reduce 11) (("*") reduce 11) (("+") reduce 11) (("-") reduce 11) ((".") reduce 11) (("/") reduce 11) (("<") reduce 11) ((">") reduce 11) (("?") reduce 11) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_AS) reduce 11) ((T_BOOLEAN_AND) reduce 11) ((T_BOOLEAN_OR) reduce 11) ((T_COALESCE) reduce 11) ((T_INSTANCEOF) reduce 11) ((T_IS_EQUAL) reduce 11) ((T_IS_GREATER_OR_EQUAL) reduce 11) ((T_IS_IDENTICAL) reduce 11) ((T_IS_NOT_EQUAL) reduce 11) ((T_IS_NOT_IDENTICAL) reduce 11) ((T_IS_SMALLER_OR_EQUAL) reduce 11) ((T_LOGICAL_AND) reduce 11) ((T_LOGICAL_OR) reduce 11) ((T_LOGICAL_XOR) reduce 11) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 11) ((T_OBJECT_OPERATOR) reduce 11) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 11) ((T_POW) reduce 11) ((T_SL) reduce 11) ((T_SPACESHIP) reduce 11) ((T_SR) reduce 11) (("[") reduce 11) (("^") reduce 11) (("{") reduce 11) (("|") reduce 11)) 18073 ((("%") reduce 42) (("(") reduce 42) (("*") reduce 42) (("+") reduce 42) (("-") reduce 42) ((".") reduce 42) (("/") reduce 42) (("<") reduce 42) ((">") reduce 42) (("?") reduce 42) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_AS) reduce 42) ((T_BOOLEAN_AND) reduce 42) ((T_BOOLEAN_OR) reduce 42) ((T_COALESCE) reduce 42) ((T_INSTANCEOF) reduce 42) ((T_IS_EQUAL) reduce 42) ((T_IS_GREATER_OR_EQUAL) reduce 42) ((T_IS_IDENTICAL) reduce 42) ((T_IS_NOT_EQUAL) reduce 42) ((T_IS_NOT_IDENTICAL) reduce 42) ((T_IS_SMALLER_OR_EQUAL) reduce 42) ((T_LOGICAL_AND) reduce 42) ((T_LOGICAL_OR) reduce 42) ((T_LOGICAL_XOR) reduce 42) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 42) ((T_OBJECT_OPERATOR) reduce 42) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 42) ((T_POW) reduce 42) ((T_SL) reduce 42) ((T_SPACESHIP) reduce 42) ((T_SR) reduce 42) (("[") reduce 42) (("^") reduce 42) (("{") reduce 42) (("|") reduce 42)) 18074 ((("%") reduce 39) (("(") reduce 39) (("*") reduce 39) (("+") reduce 39) (("-") reduce 39) ((".") reduce 39) (("/") reduce 39) (("<") reduce 39) ((">") reduce 39) (("?") reduce 39) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_AS) reduce 39) ((T_BOOLEAN_AND) reduce 39) ((T_BOOLEAN_OR) reduce 39) ((T_COALESCE) reduce 39) ((T_INSTANCEOF) reduce 39) ((T_IS_EQUAL) reduce 39) ((T_IS_GREATER_OR_EQUAL) reduce 39) ((T_IS_IDENTICAL) reduce 39) ((T_IS_NOT_EQUAL) reduce 39) ((T_IS_NOT_IDENTICAL) reduce 39) ((T_IS_SMALLER_OR_EQUAL) reduce 39) ((T_LOGICAL_AND) reduce 39) ((T_LOGICAL_OR) reduce 39) ((T_LOGICAL_XOR) reduce 39) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 39) ((T_OBJECT_OPERATOR) reduce 39) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 39) ((T_POW) reduce 39) ((T_SL) reduce 39) ((T_SPACESHIP) reduce 39) ((T_SR) reduce 39) (("[") reduce 39) (("^") reduce 39) (("{") reduce 39) (("|") reduce 39)) 18075 ((("%") reduce 25) (("(") reduce 25) (("*") reduce 25) (("+") reduce 25) (("-") reduce 25) ((".") reduce 25) (("/") reduce 25) (("<") reduce 25) ((">") reduce 25) (("?") reduce 25) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_AS) reduce 25) ((T_BOOLEAN_AND) reduce 25) ((T_BOOLEAN_OR) reduce 25) ((T_COALESCE) reduce 25) ((T_INSTANCEOF) reduce 25) ((T_IS_EQUAL) reduce 25) ((T_IS_GREATER_OR_EQUAL) reduce 25) ((T_IS_IDENTICAL) reduce 25) ((T_IS_NOT_EQUAL) reduce 25) ((T_IS_NOT_IDENTICAL) reduce 25) ((T_IS_SMALLER_OR_EQUAL) reduce 25) ((T_LOGICAL_AND) reduce 25) ((T_LOGICAL_OR) reduce 25) ((T_LOGICAL_XOR) reduce 25) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 25) ((T_OBJECT_OPERATOR) reduce 25) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 25) ((T_POW) reduce 25) ((T_SL) reduce 25) ((T_SPACESHIP) reduce 25) ((T_SR) reduce 25) (("[") reduce 25) (("^") reduce 25) (("{") reduce 25) (("|") reduce 25)) 18076 ((("%") reduce 50) (("(") reduce 50) (("*") reduce 50) (("+") reduce 50) (("-") reduce 50) ((".") reduce 50) (("/") reduce 50) (("<") reduce 50) ((">") reduce 50) (("?") reduce 50) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_AS) reduce 50) ((T_BOOLEAN_AND) reduce 50) ((T_BOOLEAN_OR) reduce 50) ((T_COALESCE) reduce 50) ((T_INSTANCEOF) reduce 50) ((T_IS_EQUAL) reduce 50) ((T_IS_GREATER_OR_EQUAL) reduce 50) ((T_IS_IDENTICAL) reduce 50) ((T_IS_NOT_EQUAL) reduce 50) ((T_IS_NOT_IDENTICAL) reduce 50) ((T_IS_SMALLER_OR_EQUAL) reduce 50) ((T_LOGICAL_AND) reduce 50) ((T_LOGICAL_OR) reduce 50) ((T_LOGICAL_XOR) reduce 50) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 50) ((T_OBJECT_OPERATOR) reduce 50) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 50) ((T_POW) reduce 50) ((T_SL) reduce 50) ((T_SPACESHIP) reduce 50) ((T_SR) reduce 50) (("[") reduce 50) (("^") reduce 50) (("{") reduce 50) (("|") reduce 50)) 18077 ((("%") reduce 66) (("(") reduce 66) (("*") reduce 66) (("+") reduce 66) (("-") reduce 66) ((".") reduce 66) (("/") reduce 66) (("<") reduce 66) ((">") reduce 66) (("?") reduce 66) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_AS) reduce 66) ((T_BOOLEAN_AND) reduce 66) ((T_BOOLEAN_OR) reduce 66) ((T_COALESCE) reduce 66) ((T_INSTANCEOF) reduce 66) ((T_IS_EQUAL) reduce 66) ((T_IS_GREATER_OR_EQUAL) reduce 66) ((T_IS_IDENTICAL) reduce 66) ((T_IS_NOT_EQUAL) reduce 66) ((T_IS_NOT_IDENTICAL) reduce 66) ((T_IS_SMALLER_OR_EQUAL) reduce 66) ((T_LOGICAL_AND) reduce 66) ((T_LOGICAL_OR) reduce 66) ((T_LOGICAL_XOR) reduce 66) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 66) ((T_OBJECT_OPERATOR) reduce 66) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 66) ((T_POW) reduce 66) ((T_SL) reduce 66) ((T_SPACESHIP) reduce 66) ((T_SR) reduce 66) (("[") reduce 66) (("^") reduce 66) (("{") reduce 66) (("|") reduce 66)) 18078 ((("%") reduce 18) (("(") reduce 18) (("*") reduce 18) (("+") reduce 18) (("-") reduce 18) ((".") reduce 18) (("/") reduce 18) (("<") reduce 18) ((">") reduce 18) (("?") reduce 18) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_AS) reduce 18) ((T_BOOLEAN_AND) reduce 18) ((T_BOOLEAN_OR) reduce 18) ((T_COALESCE) reduce 18) ((T_INSTANCEOF) reduce 18) ((T_IS_EQUAL) reduce 18) ((T_IS_GREATER_OR_EQUAL) reduce 18) ((T_IS_IDENTICAL) reduce 18) ((T_IS_NOT_EQUAL) reduce 18) ((T_IS_NOT_IDENTICAL) reduce 18) ((T_IS_SMALLER_OR_EQUAL) reduce 18) ((T_LOGICAL_AND) reduce 18) ((T_LOGICAL_OR) reduce 18) ((T_LOGICAL_XOR) reduce 18) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 18) ((T_OBJECT_OPERATOR) reduce 18) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 18) ((T_POW) reduce 18) ((T_SL) reduce 18) ((T_SPACESHIP) reduce 18) ((T_SR) reduce 18) (("[") reduce 18) (("^") reduce 18) (("{") reduce 18) (("|") reduce 18)) 18079 ((("%") reduce 17) (("(") reduce 17) (("*") reduce 17) (("+") reduce 17) (("-") reduce 17) ((".") reduce 17) (("/") reduce 17) (("<") reduce 17) ((">") reduce 17) (("?") reduce 17) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_AS) reduce 17) ((T_BOOLEAN_AND) reduce 17) ((T_BOOLEAN_OR) reduce 17) ((T_COALESCE) reduce 17) ((T_INSTANCEOF) reduce 17) ((T_IS_EQUAL) reduce 17) ((T_IS_GREATER_OR_EQUAL) reduce 17) ((T_IS_IDENTICAL) reduce 17) ((T_IS_NOT_EQUAL) reduce 17) ((T_IS_NOT_IDENTICAL) reduce 17) ((T_IS_SMALLER_OR_EQUAL) reduce 17) ((T_LOGICAL_AND) reduce 17) ((T_LOGICAL_OR) reduce 17) ((T_LOGICAL_XOR) reduce 17) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 17) ((T_OBJECT_OPERATOR) reduce 17) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 17) ((T_POW) reduce 17) ((T_SL) reduce 17) ((T_SPACESHIP) reduce 17) ((T_SR) reduce 17) (("[") reduce 17) (("^") reduce 17) (("{") reduce 17) (("|") reduce 17)) 18080 ((("%") reduce 15) (("(") reduce 15) (("*") reduce 15) (("+") reduce 15) (("-") reduce 15) ((".") reduce 15) (("/") reduce 15) (("<") reduce 15) ((">") reduce 15) (("?") reduce 15) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_AS) reduce 15) ((T_BOOLEAN_AND) reduce 15) ((T_BOOLEAN_OR) reduce 15) ((T_COALESCE) reduce 15) ((T_INSTANCEOF) reduce 15) ((T_IS_EQUAL) reduce 15) ((T_IS_GREATER_OR_EQUAL) reduce 15) ((T_IS_IDENTICAL) reduce 15) ((T_IS_NOT_EQUAL) reduce 15) ((T_IS_NOT_IDENTICAL) reduce 15) ((T_IS_SMALLER_OR_EQUAL) reduce 15) ((T_LOGICAL_AND) reduce 15) ((T_LOGICAL_OR) reduce 15) ((T_LOGICAL_XOR) reduce 15) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 15) ((T_OBJECT_OPERATOR) reduce 15) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 15) ((T_POW) reduce 15) ((T_SL) reduce 15) ((T_SPACESHIP) reduce 15) ((T_SR) reduce 15) (("[") reduce 15) (("^") reduce 15) (("{") reduce 15) (("|") reduce 15)) 18081 ((("%") reduce 14) (("(") reduce 14) (("*") reduce 14) (("+") reduce 14) (("-") reduce 14) ((".") reduce 14) (("/") reduce 14) (("<") reduce 14) ((">") reduce 14) (("?") reduce 14) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_AS) reduce 14) ((T_BOOLEAN_AND) reduce 14) ((T_BOOLEAN_OR) reduce 14) ((T_COALESCE) reduce 14) ((T_INSTANCEOF) reduce 14) ((T_IS_EQUAL) reduce 14) ((T_IS_GREATER_OR_EQUAL) reduce 14) ((T_IS_IDENTICAL) reduce 14) ((T_IS_NOT_EQUAL) reduce 14) ((T_IS_NOT_IDENTICAL) reduce 14) ((T_IS_SMALLER_OR_EQUAL) reduce 14) ((T_LOGICAL_AND) reduce 14) ((T_LOGICAL_OR) reduce 14) ((T_LOGICAL_XOR) reduce 14) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 14) ((T_OBJECT_OPERATOR) reduce 14) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 14) ((T_POW) reduce 14) ((T_SL) reduce 14) ((T_SPACESHIP) reduce 14) ((T_SR) reduce 14) (("[") reduce 14) (("^") reduce 14) (("{") reduce 14) (("|") reduce 14)) 18082 ((("%") reduce 38) (("(") reduce 38) (("*") reduce 38) (("+") reduce 38) (("-") reduce 38) ((".") reduce 38) (("/") reduce 38) (("<") reduce 38) ((">") reduce 38) (("?") reduce 38) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_AS) reduce 38) ((T_BOOLEAN_AND) reduce 38) ((T_BOOLEAN_OR) reduce 38) ((T_COALESCE) reduce 38) ((T_INSTANCEOF) reduce 38) ((T_IS_EQUAL) reduce 38) ((T_IS_GREATER_OR_EQUAL) reduce 38) ((T_IS_IDENTICAL) reduce 38) ((T_IS_NOT_EQUAL) reduce 38) ((T_IS_NOT_IDENTICAL) reduce 38) ((T_IS_SMALLER_OR_EQUAL) reduce 38) ((T_LOGICAL_AND) reduce 38) ((T_LOGICAL_OR) reduce 38) ((T_LOGICAL_XOR) reduce 38) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 38) ((T_OBJECT_OPERATOR) reduce 38) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 38) ((T_POW) reduce 38) ((T_SL) reduce 38) ((T_SPACESHIP) reduce 38) ((T_SR) reduce 38) (("[") reduce 38) (("^") reduce 38) (("{") reduce 38) (("|") reduce 38)) 18083 ((("%") reduce 26) (("(") reduce 26) (("*") reduce 26) (("+") reduce 26) (("-") reduce 26) ((".") reduce 26) (("/") reduce 26) (("<") reduce 26) ((">") reduce 26) (("?") reduce 26) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_AS) reduce 26) ((T_BOOLEAN_AND) reduce 26) ((T_BOOLEAN_OR) reduce 26) ((T_COALESCE) reduce 26) ((T_INSTANCEOF) reduce 26) ((T_IS_EQUAL) reduce 26) ((T_IS_GREATER_OR_EQUAL) reduce 26) ((T_IS_IDENTICAL) reduce 26) ((T_IS_NOT_EQUAL) reduce 26) ((T_IS_NOT_IDENTICAL) reduce 26) ((T_IS_SMALLER_OR_EQUAL) reduce 26) ((T_LOGICAL_AND) reduce 26) ((T_LOGICAL_OR) reduce 26) ((T_LOGICAL_XOR) reduce 26) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 26) ((T_OBJECT_OPERATOR) reduce 26) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 26) ((T_POW) reduce 26) ((T_SL) reduce 26) ((T_SPACESHIP) reduce 26) ((T_SR) reduce 26) (("[") reduce 26) (("^") reduce 26) (("{") reduce 26) (("|") reduce 26)) 18084 ((("%") reduce 22) (("(") reduce 22) (("*") reduce 22) (("+") reduce 22) (("-") reduce 22) ((".") reduce 22) (("/") reduce 22) (("<") reduce 22) ((">") reduce 22) (("?") reduce 22) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_AS) reduce 22) ((T_BOOLEAN_AND) reduce 22) ((T_BOOLEAN_OR) reduce 22) ((T_COALESCE) reduce 22) ((T_INSTANCEOF) reduce 22) ((T_IS_EQUAL) reduce 22) ((T_IS_GREATER_OR_EQUAL) reduce 22) ((T_IS_IDENTICAL) reduce 22) ((T_IS_NOT_EQUAL) reduce 22) ((T_IS_NOT_IDENTICAL) reduce 22) ((T_IS_SMALLER_OR_EQUAL) reduce 22) ((T_LOGICAL_AND) reduce 22) ((T_LOGICAL_OR) reduce 22) ((T_LOGICAL_XOR) reduce 22) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 22) ((T_OBJECT_OPERATOR) reduce 22) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 22) ((T_POW) reduce 22) ((T_SL) reduce 22) ((T_SPACESHIP) reduce 22) ((T_SR) reduce 22) (("[") reduce 22) (("^") reduce 22) (("{") reduce 22) (("|") reduce 22)) 18085 ((("%") reduce 24) (("(") reduce 24) (("*") reduce 24) (("+") reduce 24) (("-") reduce 24) ((".") reduce 24) (("/") reduce 24) (("<") reduce 24) ((">") reduce 24) (("?") reduce 24) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_AS) reduce 24) ((T_BOOLEAN_AND) reduce 24) ((T_BOOLEAN_OR) reduce 24) ((T_COALESCE) reduce 24) ((T_INSTANCEOF) reduce 24) ((T_IS_EQUAL) reduce 24) ((T_IS_GREATER_OR_EQUAL) reduce 24) ((T_IS_IDENTICAL) reduce 24) ((T_IS_NOT_EQUAL) reduce 24) ((T_IS_NOT_IDENTICAL) reduce 24) ((T_IS_SMALLER_OR_EQUAL) reduce 24) ((T_LOGICAL_AND) reduce 24) ((T_LOGICAL_OR) reduce 24) ((T_LOGICAL_XOR) reduce 24) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 24) ((T_OBJECT_OPERATOR) reduce 24) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 24) ((T_POW) reduce 24) ((T_SL) reduce 24) ((T_SPACESHIP) reduce 24) ((T_SR) reduce 24) (("[") reduce 24) (("^") reduce 24) (("{") reduce 24) (("|") reduce 24)) 18086 ((("%") reduce 16) (("(") reduce 16) (("*") reduce 16) (("+") reduce 16) (("-") reduce 16) ((".") reduce 16) (("/") reduce 16) (("<") reduce 16) ((">") reduce 16) (("?") reduce 16) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_AS) reduce 16) ((T_BOOLEAN_AND) reduce 16) ((T_BOOLEAN_OR) reduce 16) ((T_COALESCE) reduce 16) ((T_INSTANCEOF) reduce 16) ((T_IS_EQUAL) reduce 16) ((T_IS_GREATER_OR_EQUAL) reduce 16) ((T_IS_IDENTICAL) reduce 16) ((T_IS_NOT_EQUAL) reduce 16) ((T_IS_NOT_IDENTICAL) reduce 16) ((T_IS_SMALLER_OR_EQUAL) reduce 16) ((T_LOGICAL_AND) reduce 16) ((T_LOGICAL_OR) reduce 16) ((T_LOGICAL_XOR) reduce 16) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 16) ((T_OBJECT_OPERATOR) reduce 16) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 16) ((T_POW) reduce 16) ((T_SL) reduce 16) ((T_SPACESHIP) reduce 16) ((T_SR) reduce 16) (("[") reduce 16) (("^") reduce 16) (("{") reduce 16) (("|") reduce 16)) 18087 ((("%") reduce 48) (("(") reduce 48) (("*") reduce 48) (("+") reduce 48) (("-") reduce 48) ((".") reduce 48) (("/") reduce 48) (("<") reduce 48) ((">") reduce 48) (("?") reduce 48) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_AS) reduce 48) ((T_BOOLEAN_AND) reduce 48) ((T_BOOLEAN_OR) reduce 48) ((T_COALESCE) reduce 48) ((T_INSTANCEOF) reduce 48) ((T_IS_EQUAL) reduce 48) ((T_IS_GREATER_OR_EQUAL) reduce 48) ((T_IS_IDENTICAL) reduce 48) ((T_IS_NOT_EQUAL) reduce 48) ((T_IS_NOT_IDENTICAL) reduce 48) ((T_IS_SMALLER_OR_EQUAL) reduce 48) ((T_LOGICAL_AND) reduce 48) ((T_LOGICAL_OR) reduce 48) ((T_LOGICAL_XOR) reduce 48) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 48) ((T_OBJECT_OPERATOR) reduce 48) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 48) ((T_POW) reduce 48) ((T_SL) reduce 48) ((T_SPACESHIP) reduce 48) ((T_SR) reduce 48) (("[") reduce 48) (("^") reduce 48) (("{") reduce 48) (("|") reduce 48)) 18088 ((("%") reduce 20) (("(") reduce 20) (("*") reduce 20) (("+") reduce 20) (("-") reduce 20) ((".") reduce 20) (("/") reduce 20) (("<") reduce 20) ((">") reduce 20) (("?") reduce 20) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_AS) reduce 20) ((T_BOOLEAN_AND) reduce 20) ((T_BOOLEAN_OR) reduce 20) ((T_COALESCE) reduce 20) ((T_INSTANCEOF) reduce 20) ((T_IS_EQUAL) reduce 20) ((T_IS_GREATER_OR_EQUAL) reduce 20) ((T_IS_IDENTICAL) reduce 20) ((T_IS_NOT_EQUAL) reduce 20) ((T_IS_NOT_IDENTICAL) reduce 20) ((T_IS_SMALLER_OR_EQUAL) reduce 20) ((T_LOGICAL_AND) reduce 20) ((T_LOGICAL_OR) reduce 20) ((T_LOGICAL_XOR) reduce 20) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 20) ((T_OBJECT_OPERATOR) reduce 20) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 20) ((T_POW) reduce 20) ((T_SL) reduce 20) ((T_SPACESHIP) reduce 20) ((T_SR) reduce 20) (("[") reduce 20) (("^") reduce 20) (("{") reduce 20) (("|") reduce 20)) 18089 ((("%") reduce 70) (("(") reduce 70) (("*") reduce 70) (("+") reduce 70) (("-") reduce 70) ((".") reduce 70) (("/") reduce 70) (("<") reduce 70) ((">") reduce 70) (("?") reduce 70) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_AS) reduce 70) ((T_BOOLEAN_AND) reduce 70) ((T_BOOLEAN_OR) reduce 70) ((T_COALESCE) reduce 70) ((T_INSTANCEOF) reduce 70) ((T_IS_EQUAL) reduce 70) ((T_IS_GREATER_OR_EQUAL) reduce 70) ((T_IS_IDENTICAL) reduce 70) ((T_IS_NOT_EQUAL) reduce 70) ((T_IS_NOT_IDENTICAL) reduce 70) ((T_IS_SMALLER_OR_EQUAL) reduce 70) ((T_LOGICAL_AND) reduce 70) ((T_LOGICAL_OR) reduce 70) ((T_LOGICAL_XOR) reduce 70) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 70) ((T_OBJECT_OPERATOR) reduce 70) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 70) ((T_POW) reduce 70) ((T_SL) reduce 70) ((T_SPACESHIP) reduce 70) ((T_SR) reduce 70) (("[") reduce 70) (("^") reduce 70) (("{") reduce 70) (("|") reduce 70)) 18090 ((("%") reduce 3) (("(") reduce 3) (("*") reduce 3) (("+") reduce 3) (("-") reduce 3) ((".") reduce 3) (("/") reduce 3) (("<") reduce 3) ((">") reduce 3) (("?") reduce 3) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_AS) reduce 3) ((T_BOOLEAN_AND) reduce 3) ((T_BOOLEAN_OR) reduce 3) ((T_COALESCE) reduce 3) ((T_INSTANCEOF) reduce 3) ((T_IS_EQUAL) reduce 3) ((T_IS_GREATER_OR_EQUAL) reduce 3) ((T_IS_IDENTICAL) reduce 3) ((T_IS_NOT_EQUAL) reduce 3) ((T_IS_NOT_IDENTICAL) reduce 3) ((T_IS_SMALLER_OR_EQUAL) reduce 3) ((T_LOGICAL_AND) reduce 3) ((T_LOGICAL_OR) reduce 3) ((T_LOGICAL_XOR) reduce 3) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 3) ((T_OBJECT_OPERATOR) reduce 3) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 3) ((T_POW) reduce 3) ((T_SL) reduce 3) ((T_SPACESHIP) reduce 3) ((T_SR) reduce 3) (("[") reduce 3) (("^") reduce 3) (("{") reduce 3) (("|") reduce 3)) 18091 ((("%") reduce 12) (("(") reduce 12) (("*") reduce 12) (("+") reduce 12) (("-") reduce 12) ((".") reduce 12) (("/") reduce 12) (("<") reduce 12) ((">") reduce 12) (("?") reduce 12) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_AS) reduce 12) ((T_BOOLEAN_AND) reduce 12) ((T_BOOLEAN_OR) reduce 12) ((T_COALESCE) reduce 12) ((T_INSTANCEOF) reduce 12) ((T_IS_EQUAL) reduce 12) ((T_IS_GREATER_OR_EQUAL) reduce 12) ((T_IS_IDENTICAL) reduce 12) ((T_IS_NOT_EQUAL) reduce 12) ((T_IS_NOT_IDENTICAL) reduce 12) ((T_IS_SMALLER_OR_EQUAL) reduce 12) ((T_LOGICAL_AND) reduce 12) ((T_LOGICAL_OR) reduce 12) ((T_LOGICAL_XOR) reduce 12) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 12) ((T_OBJECT_OPERATOR) reduce 12) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 12) ((T_POW) reduce 12) ((T_SL) reduce 12) ((T_SPACESHIP) reduce 12) ((T_SR) reduce 12) (("[") reduce 12) (("^") reduce 12) (("{") reduce 12) (("|") reduce 12)) 18092 ((("%") reduce 54) (("(") reduce 54) (("*") reduce 54) (("+") reduce 54) (("-") reduce 54) ((".") reduce 54) (("/") reduce 54) (("<") reduce 54) ((">") reduce 54) (("?") reduce 54) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_AS) reduce 54) ((T_BOOLEAN_AND) reduce 54) ((T_BOOLEAN_OR) reduce 54) ((T_COALESCE) reduce 54) ((T_INSTANCEOF) reduce 54) ((T_IS_EQUAL) reduce 54) ((T_IS_GREATER_OR_EQUAL) reduce 54) ((T_IS_IDENTICAL) reduce 54) ((T_IS_NOT_EQUAL) reduce 54) ((T_IS_NOT_IDENTICAL) reduce 54) ((T_IS_SMALLER_OR_EQUAL) reduce 54) ((T_LOGICAL_AND) reduce 54) ((T_LOGICAL_OR) reduce 54) ((T_LOGICAL_XOR) reduce 54) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 54) ((T_OBJECT_OPERATOR) reduce 54) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 54) ((T_POW) reduce 54) ((T_SL) reduce 54) ((T_SPACESHIP) reduce 54) ((T_SR) reduce 54) (("[") reduce 54) (("^") reduce 54) (("{") reduce 54) (("|") reduce 54)) 18093 ((("%") reduce 65) (("(") reduce 65) (("*") reduce 65) (("+") reduce 65) (("-") reduce 65) ((".") reduce 65) (("/") reduce 65) (("<") reduce 65) ((">") reduce 65) (("?") reduce 65) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_AS) reduce 65) ((T_BOOLEAN_AND) reduce 65) ((T_BOOLEAN_OR) reduce 65) ((T_COALESCE) reduce 65) ((T_INSTANCEOF) reduce 65) ((T_IS_EQUAL) reduce 65) ((T_IS_GREATER_OR_EQUAL) reduce 65) ((T_IS_IDENTICAL) reduce 65) ((T_IS_NOT_EQUAL) reduce 65) ((T_IS_NOT_IDENTICAL) reduce 65) ((T_IS_SMALLER_OR_EQUAL) reduce 65) ((T_LOGICAL_AND) reduce 65) ((T_LOGICAL_OR) reduce 65) ((T_LOGICAL_XOR) reduce 65) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 65) ((T_OBJECT_OPERATOR) reduce 65) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 65) ((T_POW) reduce 65) ((T_SL) reduce 65) ((T_SPACESHIP) reduce 65) ((T_SR) reduce 65) (("[") reduce 65) (("^") reduce 65) (("{") reduce 65) (("|") reduce 65)) 18094 ((("%") reduce 74) (("(") reduce 74) (("*") reduce 74) (("+") reduce 74) (("-") reduce 74) ((".") reduce 74) (("/") reduce 74) (("<") reduce 74) ((">") reduce 74) (("?") reduce 74) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_AS) reduce 74) ((T_BOOLEAN_AND) reduce 74) ((T_BOOLEAN_OR) reduce 74) ((T_COALESCE) reduce 74) ((T_INSTANCEOF) reduce 74) ((T_IS_EQUAL) reduce 74) ((T_IS_GREATER_OR_EQUAL) reduce 74) ((T_IS_IDENTICAL) reduce 74) ((T_IS_NOT_EQUAL) reduce 74) ((T_IS_NOT_IDENTICAL) reduce 74) ((T_IS_SMALLER_OR_EQUAL) reduce 74) ((T_LOGICAL_AND) reduce 74) ((T_LOGICAL_OR) reduce 74) ((T_LOGICAL_XOR) reduce 74) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 74) ((T_OBJECT_OPERATOR) reduce 74) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 74) ((T_POW) reduce 74) ((T_SL) reduce 74) ((T_SPACESHIP) reduce 74) ((T_SR) reduce 74) (("[") reduce 74) (("^") reduce 74) (("{") reduce 74) (("|") reduce 74)) 18095 ((("%") reduce 30) (("(") reduce 30) (("*") reduce 30) (("+") reduce 30) (("-") reduce 30) ((".") reduce 30) (("/") reduce 30) (("<") reduce 30) ((">") reduce 30) (("?") reduce 30) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_AS) reduce 30) ((T_BOOLEAN_AND) reduce 30) ((T_BOOLEAN_OR) reduce 30) ((T_COALESCE) reduce 30) ((T_INSTANCEOF) reduce 30) ((T_IS_EQUAL) reduce 30) ((T_IS_GREATER_OR_EQUAL) reduce 30) ((T_IS_IDENTICAL) reduce 30) ((T_IS_NOT_EQUAL) reduce 30) ((T_IS_NOT_IDENTICAL) reduce 30) ((T_IS_SMALLER_OR_EQUAL) reduce 30) ((T_LOGICAL_AND) reduce 30) ((T_LOGICAL_OR) reduce 30) ((T_LOGICAL_XOR) reduce 30) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 30) ((T_OBJECT_OPERATOR) reduce 30) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 30) ((T_POW) reduce 30) ((T_SL) reduce 30) ((T_SPACESHIP) reduce 30) ((T_SR) reduce 30) (("[") reduce 30) (("^") reduce 30) (("{") reduce 30) (("|") reduce 30)) 18096 ((("%") reduce 68) (("(") reduce 68) (("*") reduce 68) (("+") reduce 68) (("-") reduce 68) ((".") reduce 68) (("/") reduce 68) (("<") reduce 68) ((">") reduce 68) (("?") reduce 68) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_AS) reduce 68) ((T_BOOLEAN_AND) reduce 68) ((T_BOOLEAN_OR) reduce 68) ((T_COALESCE) reduce 68) ((T_INSTANCEOF) reduce 68) ((T_IS_EQUAL) reduce 68) ((T_IS_GREATER_OR_EQUAL) reduce 68) ((T_IS_IDENTICAL) reduce 68) ((T_IS_NOT_EQUAL) reduce 68) ((T_IS_NOT_IDENTICAL) reduce 68) ((T_IS_SMALLER_OR_EQUAL) reduce 68) ((T_LOGICAL_AND) reduce 68) ((T_LOGICAL_OR) reduce 68) ((T_LOGICAL_XOR) reduce 68) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 68) ((T_OBJECT_OPERATOR) reduce 68) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 68) ((T_POW) reduce 68) ((T_SL) reduce 68) ((T_SPACESHIP) reduce 68) ((T_SR) reduce 68) (("[") reduce 68) (("^") reduce 68) (("{") reduce 68) (("|") reduce 68)) 18097 ((("%") reduce 21) (("(") reduce 21) (("*") reduce 21) (("+") reduce 21) (("-") reduce 21) ((".") reduce 21) (("/") reduce 21) (("<") reduce 21) ((">") reduce 21) (("?") reduce 21) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_AS) reduce 21) ((T_BOOLEAN_AND) reduce 21) ((T_BOOLEAN_OR) reduce 21) ((T_COALESCE) reduce 21) ((T_INSTANCEOF) reduce 21) ((T_IS_EQUAL) reduce 21) ((T_IS_GREATER_OR_EQUAL) reduce 21) ((T_IS_IDENTICAL) reduce 21) ((T_IS_NOT_EQUAL) reduce 21) ((T_IS_NOT_IDENTICAL) reduce 21) ((T_IS_SMALLER_OR_EQUAL) reduce 21) ((T_LOGICAL_AND) reduce 21) ((T_LOGICAL_OR) reduce 21) ((T_LOGICAL_XOR) reduce 21) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 21) ((T_OBJECT_OPERATOR) reduce 21) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 21) ((T_POW) reduce 21) ((T_SL) reduce 21) ((T_SPACESHIP) reduce 21) ((T_SR) reduce 21) (("[") reduce 21) (("^") reduce 21) (("{") reduce 21) (("|") reduce 21)) 18098 ((("%") reduce 23) (("(") reduce 23) (("*") reduce 23) (("+") reduce 23) (("-") reduce 23) ((".") reduce 23) (("/") reduce 23) (("<") reduce 23) ((">") reduce 23) (("?") reduce 23) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_AS) reduce 23) ((T_BOOLEAN_AND) reduce 23) ((T_BOOLEAN_OR) reduce 23) ((T_COALESCE) reduce 23) ((T_INSTANCEOF) reduce 23) ((T_IS_EQUAL) reduce 23) ((T_IS_GREATER_OR_EQUAL) reduce 23) ((T_IS_IDENTICAL) reduce 23) ((T_IS_NOT_EQUAL) reduce 23) ((T_IS_NOT_IDENTICAL) reduce 23) ((T_IS_SMALLER_OR_EQUAL) reduce 23) ((T_LOGICAL_AND) reduce 23) ((T_LOGICAL_OR) reduce 23) ((T_LOGICAL_XOR) reduce 23) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 23) ((T_OBJECT_OPERATOR) reduce 23) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 23) ((T_POW) reduce 23) ((T_SL) reduce 23) ((T_SPACESHIP) reduce 23) ((T_SR) reduce 23) (("[") reduce 23) (("^") reduce 23) (("{") reduce 23) (("|") reduce 23)) 18099 ((("%") reduce 41) (("(") reduce 41) (("*") reduce 41) (("+") reduce 41) (("-") reduce 41) ((".") reduce 41) (("/") reduce 41) (("<") reduce 41) ((">") reduce 41) (("?") reduce 41) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_AS) reduce 41) ((T_BOOLEAN_AND) reduce 41) ((T_BOOLEAN_OR) reduce 41) ((T_COALESCE) reduce 41) ((T_INSTANCEOF) reduce 41) ((T_IS_EQUAL) reduce 41) ((T_IS_GREATER_OR_EQUAL) reduce 41) ((T_IS_IDENTICAL) reduce 41) ((T_IS_NOT_EQUAL) reduce 41) ((T_IS_NOT_IDENTICAL) reduce 41) ((T_IS_SMALLER_OR_EQUAL) reduce 41) ((T_LOGICAL_AND) reduce 41) ((T_LOGICAL_OR) reduce 41) ((T_LOGICAL_XOR) reduce 41) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 41) ((T_OBJECT_OPERATOR) reduce 41) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 41) ((T_POW) reduce 41) ((T_SL) reduce 41) ((T_SPACESHIP) reduce 41) ((T_SR) reduce 41) (("[") reduce 41) (("^") reduce 41) (("{") reduce 41) (("|") reduce 41)) 18100 ((("%") reduce 62) (("(") reduce 62) (("*") reduce 62) (("+") reduce 62) (("-") reduce 62) ((".") reduce 62) (("/") reduce 62) (("<") reduce 62) ((">") reduce 62) (("?") reduce 62) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_AS) reduce 62) ((T_BOOLEAN_AND) reduce 62) ((T_BOOLEAN_OR) reduce 62) ((T_COALESCE) reduce 62) ((T_INSTANCEOF) reduce 62) ((T_IS_EQUAL) reduce 62) ((T_IS_GREATER_OR_EQUAL) reduce 62) ((T_IS_IDENTICAL) reduce 62) ((T_IS_NOT_EQUAL) reduce 62) ((T_IS_NOT_IDENTICAL) reduce 62) ((T_IS_SMALLER_OR_EQUAL) reduce 62) ((T_LOGICAL_AND) reduce 62) ((T_LOGICAL_OR) reduce 62) ((T_LOGICAL_XOR) reduce 62) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 62) ((T_OBJECT_OPERATOR) reduce 62) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 62) ((T_POW) reduce 62) ((T_SL) reduce 62) ((T_SPACESHIP) reduce 62) ((T_SR) reduce 62) (("[") reduce 62) (("^") reduce 62) (("{") reduce 62) (("|") reduce 62)) 18101 ((("%") reduce 34) (("(") reduce 34) (("*") reduce 34) (("+") reduce 34) (("-") reduce 34) ((".") reduce 34) (("/") reduce 34) (("<") reduce 34) ((">") reduce 34) (("?") reduce 34) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_AS) reduce 34) ((T_BOOLEAN_AND) reduce 34) ((T_BOOLEAN_OR) reduce 34) ((T_COALESCE) reduce 34) ((T_INSTANCEOF) reduce 34) ((T_IS_EQUAL) reduce 34) ((T_IS_GREATER_OR_EQUAL) reduce 34) ((T_IS_IDENTICAL) reduce 34) ((T_IS_NOT_EQUAL) reduce 34) ((T_IS_NOT_IDENTICAL) reduce 34) ((T_IS_SMALLER_OR_EQUAL) reduce 34) ((T_LOGICAL_AND) reduce 34) ((T_LOGICAL_OR) reduce 34) ((T_LOGICAL_XOR) reduce 34) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 34) ((T_OBJECT_OPERATOR) reduce 34) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 34) ((T_POW) reduce 34) ((T_SL) reduce 34) ((T_SPACESHIP) reduce 34) ((T_SR) reduce 34) (("[") reduce 34) (("^") reduce 34) (("{") reduce 34) (("|") reduce 34)) 18102 ((("%") reduce 40) (("(") reduce 40) (("*") reduce 40) (("+") reduce 40) (("-") reduce 40) ((".") reduce 40) (("/") reduce 40) (("<") reduce 40) ((">") reduce 40) (("?") reduce 40) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_AS) reduce 40) ((T_BOOLEAN_AND) reduce 40) ((T_BOOLEAN_OR) reduce 40) ((T_COALESCE) reduce 40) ((T_INSTANCEOF) reduce 40) ((T_IS_EQUAL) reduce 40) ((T_IS_GREATER_OR_EQUAL) reduce 40) ((T_IS_IDENTICAL) reduce 40) ((T_IS_NOT_EQUAL) reduce 40) ((T_IS_NOT_IDENTICAL) reduce 40) ((T_IS_SMALLER_OR_EQUAL) reduce 40) ((T_LOGICAL_AND) reduce 40) ((T_LOGICAL_OR) reduce 40) ((T_LOGICAL_XOR) reduce 40) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 40) ((T_OBJECT_OPERATOR) reduce 40) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 40) ((T_POW) reduce 40) ((T_SL) reduce 40) ((T_SPACESHIP) reduce 40) ((T_SR) reduce 40) (("[") reduce 40) (("^") reduce 40) (("{") reduce 40) (("|") reduce 40)) 18103 ((("%") reduce 13) (("(") reduce 13) (("*") reduce 13) (("+") reduce 13) (("-") reduce 13) ((".") reduce 13) (("/") reduce 13) (("<") reduce 13) ((">") reduce 13) (("?") reduce 13) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_AS) reduce 13) ((T_BOOLEAN_AND) reduce 13) ((T_BOOLEAN_OR) reduce 13) ((T_COALESCE) reduce 13) ((T_INSTANCEOF) reduce 13) ((T_IS_EQUAL) reduce 13) ((T_IS_GREATER_OR_EQUAL) reduce 13) ((T_IS_IDENTICAL) reduce 13) ((T_IS_NOT_EQUAL) reduce 13) ((T_IS_NOT_IDENTICAL) reduce 13) ((T_IS_SMALLER_OR_EQUAL) reduce 13) ((T_LOGICAL_AND) reduce 13) ((T_LOGICAL_OR) reduce 13) ((T_LOGICAL_XOR) reduce 13) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 13) ((T_OBJECT_OPERATOR) reduce 13) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 13) ((T_POW) reduce 13) ((T_SL) reduce 13) ((T_SPACESHIP) reduce 13) ((T_SR) reduce 13) (("[") reduce 13) (("^") reduce 13) (("{") reduce 13) (("|") reduce 13)) 18104 ((("%") reduce 55) (("(") reduce 55) (("*") reduce 55) (("+") reduce 55) (("-") reduce 55) ((".") reduce 55) (("/") reduce 55) (("<") reduce 55) ((">") reduce 55) (("?") reduce 55) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_AS) reduce 55) ((T_BOOLEAN_AND) reduce 55) ((T_BOOLEAN_OR) reduce 55) ((T_COALESCE) reduce 55) ((T_INSTANCEOF) reduce 55) ((T_IS_EQUAL) reduce 55) ((T_IS_GREATER_OR_EQUAL) reduce 55) ((T_IS_IDENTICAL) reduce 55) ((T_IS_NOT_EQUAL) reduce 55) ((T_IS_NOT_IDENTICAL) reduce 55) ((T_IS_SMALLER_OR_EQUAL) reduce 55) ((T_LOGICAL_AND) reduce 55) ((T_LOGICAL_OR) reduce 55) ((T_LOGICAL_XOR) reduce 55) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 55) ((T_OBJECT_OPERATOR) reduce 55) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 55) ((T_POW) reduce 55) ((T_SL) reduce 55) ((T_SPACESHIP) reduce 55) ((T_SR) reduce 55) (("[") reduce 55) (("^") reduce 55) (("{") reduce 55) (("|") reduce 55)) 18105 ((("%") reduce 1) (("(") reduce 1) (("*") reduce 1) (("+") reduce 1) (("-") reduce 1) ((".") reduce 1) (("/") reduce 1) (("<") reduce 1) ((">") reduce 1) (("?") reduce 1) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_AS) reduce 1) ((T_BOOLEAN_AND) reduce 1) ((T_BOOLEAN_OR) reduce 1) ((T_COALESCE) reduce 1) ((T_INSTANCEOF) reduce 1) ((T_IS_EQUAL) reduce 1) ((T_IS_GREATER_OR_EQUAL) reduce 1) ((T_IS_IDENTICAL) reduce 1) ((T_IS_NOT_EQUAL) reduce 1) ((T_IS_NOT_IDENTICAL) reduce 1) ((T_IS_SMALLER_OR_EQUAL) reduce 1) ((T_LOGICAL_AND) reduce 1) ((T_LOGICAL_OR) reduce 1) ((T_LOGICAL_XOR) reduce 1) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 1) ((T_OBJECT_OPERATOR) reduce 1) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 1) ((T_POW) reduce 1) ((T_SL) reduce 1) ((T_SPACESHIP) reduce 1) ((T_SR) reduce 1) (("[") reduce 1) (("^") reduce 1) (("{") reduce 1) (("|") reduce 1)) 18106 ((("%") reduce 2) (("(") reduce 2) (("*") reduce 2) (("+") reduce 2) (("-") reduce 2) ((".") reduce 2) (("/") reduce 2) (("<") reduce 2) ((">") reduce 2) (("?") reduce 2) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_AS) reduce 2) ((T_BOOLEAN_AND) reduce 2) ((T_BOOLEAN_OR) reduce 2) ((T_COALESCE) reduce 2) ((T_INSTANCEOF) reduce 2) ((T_IS_EQUAL) reduce 2) ((T_IS_GREATER_OR_EQUAL) reduce 2) ((T_IS_IDENTICAL) reduce 2) ((T_IS_NOT_EQUAL) reduce 2) ((T_IS_NOT_IDENTICAL) reduce 2) ((T_IS_SMALLER_OR_EQUAL) reduce 2) ((T_LOGICAL_AND) reduce 2) ((T_LOGICAL_OR) reduce 2) ((T_LOGICAL_XOR) reduce 2) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 2) ((T_OBJECT_OPERATOR) reduce 2) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 2) ((T_POW) reduce 2) ((T_SL) reduce 2) ((T_SPACESHIP) reduce 2) ((T_SR) reduce 2) (("[") reduce 2) (("^") reduce 2) (("{") reduce 2) (("|") reduce 2)) 18107 ((("%") reduce 9) (("(") reduce 9) (("*") reduce 9) (("+") reduce 9) (("-") reduce 9) ((".") reduce 9) (("/") reduce 9) (("<") reduce 9) ((">") reduce 9) (("?") reduce 9) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_AS) reduce 9) ((T_BOOLEAN_AND) reduce 9) ((T_BOOLEAN_OR) reduce 9) ((T_COALESCE) reduce 9) ((T_INSTANCEOF) reduce 9) ((T_IS_EQUAL) reduce 9) ((T_IS_GREATER_OR_EQUAL) reduce 9) ((T_IS_IDENTICAL) reduce 9) ((T_IS_NOT_EQUAL) reduce 9) ((T_IS_NOT_IDENTICAL) reduce 9) ((T_IS_SMALLER_OR_EQUAL) reduce 9) ((T_LOGICAL_AND) reduce 9) ((T_LOGICAL_OR) reduce 9) ((T_LOGICAL_XOR) reduce 9) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 9) ((T_OBJECT_OPERATOR) reduce 9) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 9) ((T_POW) reduce 9) ((T_SL) reduce 9) ((T_SPACESHIP) reduce 9) ((T_SR) reduce 9) (("[") reduce 9) (("^") reduce 9) (("{") reduce 9) (("|") reduce 9)) 18108 ((("%") reduce 33) (("(") reduce 33) (("*") reduce 33) (("+") reduce 33) (("-") reduce 33) ((".") reduce 33) (("/") reduce 33) (("<") reduce 33) ((">") reduce 33) (("?") reduce 33) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_AS) reduce 33) ((T_BOOLEAN_AND) reduce 33) ((T_BOOLEAN_OR) reduce 33) ((T_COALESCE) reduce 33) ((T_INSTANCEOF) reduce 33) ((T_IS_EQUAL) reduce 33) ((T_IS_GREATER_OR_EQUAL) reduce 33) ((T_IS_IDENTICAL) reduce 33) ((T_IS_NOT_EQUAL) reduce 33) ((T_IS_NOT_IDENTICAL) reduce 33) ((T_IS_SMALLER_OR_EQUAL) reduce 33) ((T_LOGICAL_AND) reduce 33) ((T_LOGICAL_OR) reduce 33) ((T_LOGICAL_XOR) reduce 33) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 33) ((T_OBJECT_OPERATOR) reduce 33) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 33) ((T_POW) reduce 33) ((T_SL) reduce 33) ((T_SPACESHIP) reduce 33) ((T_SR) reduce 33) (("[") reduce 33) (("^") reduce 33) (("{") reduce 33) (("|") reduce 33)) 18109 ((("%") reduce 58) (("(") reduce 58) (("*") reduce 58) (("+") reduce 58) (("-") reduce 58) ((".") reduce 58) (("/") reduce 58) (("<") reduce 58) ((">") reduce 58) (("?") reduce 58) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_AS) reduce 58) ((T_BOOLEAN_AND) reduce 58) ((T_BOOLEAN_OR) reduce 58) ((T_COALESCE) reduce 58) ((T_INSTANCEOF) reduce 58) ((T_IS_EQUAL) reduce 58) ((T_IS_GREATER_OR_EQUAL) reduce 58) ((T_IS_IDENTICAL) reduce 58) ((T_IS_NOT_EQUAL) reduce 58) ((T_IS_NOT_IDENTICAL) reduce 58) ((T_IS_SMALLER_OR_EQUAL) reduce 58) ((T_LOGICAL_AND) reduce 58) ((T_LOGICAL_OR) reduce 58) ((T_LOGICAL_XOR) reduce 58) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 58) ((T_OBJECT_OPERATOR) reduce 58) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 58) ((T_POW) reduce 58) ((T_SL) reduce 58) ((T_SPACESHIP) reduce 58) ((T_SR) reduce 58) (("[") reduce 58) (("^") reduce 58) (("{") reduce 58) (("|") reduce 58)) 18110 ((("%") reduce 37) (("(") reduce 37) (("*") reduce 37) (("+") reduce 37) (("-") reduce 37) ((".") reduce 37) (("/") reduce 37) (("<") reduce 37) ((">") reduce 37) (("?") reduce 37) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_AS) reduce 37) ((T_BOOLEAN_AND) reduce 37) ((T_BOOLEAN_OR) reduce 37) ((T_COALESCE) reduce 37) ((T_INSTANCEOF) reduce 37) ((T_IS_EQUAL) reduce 37) ((T_IS_GREATER_OR_EQUAL) reduce 37) ((T_IS_IDENTICAL) reduce 37) ((T_IS_NOT_EQUAL) reduce 37) ((T_IS_NOT_IDENTICAL) reduce 37) ((T_IS_SMALLER_OR_EQUAL) reduce 37) ((T_LOGICAL_AND) reduce 37) ((T_LOGICAL_OR) reduce 37) ((T_LOGICAL_XOR) reduce 37) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 37) ((T_OBJECT_OPERATOR) reduce 37) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 37) ((T_POW) reduce 37) ((T_SL) reduce 37) ((T_SPACESHIP) reduce 37) ((T_SR) reduce 37) (("[") reduce 37) (("^") reduce 37) (("{") reduce 37) (("|") reduce 37)) 18111 ((("%") reduce 64) (("(") reduce 64) (("*") reduce 64) (("+") reduce 64) (("-") reduce 64) ((".") reduce 64) (("/") reduce 64) (("<") reduce 64) ((">") reduce 64) (("?") reduce 64) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_AS) reduce 64) ((T_BOOLEAN_AND) reduce 64) ((T_BOOLEAN_OR) reduce 64) ((T_COALESCE) reduce 64) ((T_INSTANCEOF) reduce 64) ((T_IS_EQUAL) reduce 64) ((T_IS_GREATER_OR_EQUAL) reduce 64) ((T_IS_IDENTICAL) reduce 64) ((T_IS_NOT_EQUAL) reduce 64) ((T_IS_NOT_IDENTICAL) reduce 64) ((T_IS_SMALLER_OR_EQUAL) reduce 64) ((T_LOGICAL_AND) reduce 64) ((T_LOGICAL_OR) reduce 64) ((T_LOGICAL_XOR) reduce 64) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 64) ((T_OBJECT_OPERATOR) reduce 64) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 64) ((T_POW) reduce 64) ((T_SL) reduce 64) ((T_SPACESHIP) reduce 64) ((T_SR) reduce 64) (("[") reduce 64) (("^") reduce 64) (("{") reduce 64) (("|") reduce 64)) 18112 ((("%") reduce 46) (("(") reduce 46) (("*") reduce 46) (("+") reduce 46) (("-") reduce 46) ((".") reduce 46) (("/") reduce 46) (("<") reduce 46) ((">") reduce 46) (("?") reduce 46) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_AS) reduce 46) ((T_BOOLEAN_AND) reduce 46) ((T_BOOLEAN_OR) reduce 46) ((T_COALESCE) reduce 46) ((T_INSTANCEOF) reduce 46) ((T_IS_EQUAL) reduce 46) ((T_IS_GREATER_OR_EQUAL) reduce 46) ((T_IS_IDENTICAL) reduce 46) ((T_IS_NOT_EQUAL) reduce 46) ((T_IS_NOT_IDENTICAL) reduce 46) ((T_IS_SMALLER_OR_EQUAL) reduce 46) ((T_LOGICAL_AND) reduce 46) ((T_LOGICAL_OR) reduce 46) ((T_LOGICAL_XOR) reduce 46) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 46) ((T_OBJECT_OPERATOR) reduce 46) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 46) ((T_POW) reduce 46) ((T_SL) reduce 46) ((T_SPACESHIP) reduce 46) ((T_SR) reduce 46) (("[") reduce 46) (("^") reduce 46) (("{") reduce 46) (("|") reduce 46)) 18113 ((("%") reduce 8) (("(") reduce 8) (("*") reduce 8) (("+") reduce 8) (("-") reduce 8) ((".") reduce 8) (("/") reduce 8) (("<") reduce 8) ((">") reduce 8) (("?") reduce 8) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_AS) reduce 8) ((T_BOOLEAN_AND) reduce 8) ((T_BOOLEAN_OR) reduce 8) ((T_COALESCE) reduce 8) ((T_INSTANCEOF) reduce 8) ((T_IS_EQUAL) reduce 8) ((T_IS_GREATER_OR_EQUAL) reduce 8) ((T_IS_IDENTICAL) reduce 8) ((T_IS_NOT_EQUAL) reduce 8) ((T_IS_NOT_IDENTICAL) reduce 8) ((T_IS_SMALLER_OR_EQUAL) reduce 8) ((T_LOGICAL_AND) reduce 8) ((T_LOGICAL_OR) reduce 8) ((T_LOGICAL_XOR) reduce 8) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 8) ((T_OBJECT_OPERATOR) reduce 8) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 8) ((T_POW) reduce 8) ((T_SL) reduce 8) ((T_SPACESHIP) reduce 8) ((T_SR) reduce 8) (("[") reduce 8) (("^") reduce 8) (("{") reduce 8) (("|") reduce 8)) 18114 ((("%") reduce 6) (("(") reduce 6) (("*") reduce 6) (("+") reduce 6) (("-") reduce 6) ((".") reduce 6) (("/") reduce 6) (("<") reduce 6) ((">") reduce 6) (("?") reduce 6) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_AS) reduce 6) ((T_BOOLEAN_AND) reduce 6) ((T_BOOLEAN_OR) reduce 6) ((T_COALESCE) reduce 6) ((T_INSTANCEOF) reduce 6) ((T_IS_EQUAL) reduce 6) ((T_IS_GREATER_OR_EQUAL) reduce 6) ((T_IS_IDENTICAL) reduce 6) ((T_IS_NOT_EQUAL) reduce 6) ((T_IS_NOT_IDENTICAL) reduce 6) ((T_IS_SMALLER_OR_EQUAL) reduce 6) ((T_LOGICAL_AND) reduce 6) ((T_LOGICAL_OR) reduce 6) ((T_LOGICAL_XOR) reduce 6) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 6) ((T_OBJECT_OPERATOR) reduce 6) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 6) ((T_POW) reduce 6) ((T_SL) reduce 6) ((T_SPACESHIP) reduce 6) ((T_SR) reduce 6) (("[") reduce 6) (("^") reduce 6) (("{") reduce 6) (("|") reduce 6)) 18115 ((("%") reduce 7) (("(") reduce 7) (("*") reduce 7) (("+") reduce 7) (("-") reduce 7) ((".") reduce 7) (("/") reduce 7) (("<") reduce 7) ((">") reduce 7) (("?") reduce 7) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_AS) reduce 7) ((T_BOOLEAN_AND) reduce 7) ((T_BOOLEAN_OR) reduce 7) ((T_COALESCE) reduce 7) ((T_INSTANCEOF) reduce 7) ((T_IS_EQUAL) reduce 7) ((T_IS_GREATER_OR_EQUAL) reduce 7) ((T_IS_IDENTICAL) reduce 7) ((T_IS_NOT_EQUAL) reduce 7) ((T_IS_NOT_IDENTICAL) reduce 7) ((T_IS_SMALLER_OR_EQUAL) reduce 7) ((T_LOGICAL_AND) reduce 7) ((T_LOGICAL_OR) reduce 7) ((T_LOGICAL_XOR) reduce 7) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 7) ((T_OBJECT_OPERATOR) reduce 7) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 7) ((T_POW) reduce 7) ((T_SL) reduce 7) ((T_SPACESHIP) reduce 7) ((T_SR) reduce 7) (("[") reduce 7) (("^") reduce 7) (("{") reduce 7) (("|") reduce 7)) 18116 ((("%") reduce 69) (("(") reduce 69) (("*") reduce 69) (("+") reduce 69) (("-") reduce 69) ((".") reduce 69) (("/") reduce 69) (("<") reduce 69) ((">") reduce 69) (("?") reduce 69) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_AS) reduce 69) ((T_BOOLEAN_AND) reduce 69) ((T_BOOLEAN_OR) reduce 69) ((T_COALESCE) reduce 69) ((T_INSTANCEOF) reduce 69) ((T_IS_EQUAL) reduce 69) ((T_IS_GREATER_OR_EQUAL) reduce 69) ((T_IS_IDENTICAL) reduce 69) ((T_IS_NOT_EQUAL) reduce 69) ((T_IS_NOT_IDENTICAL) reduce 69) ((T_IS_SMALLER_OR_EQUAL) reduce 69) ((T_LOGICAL_AND) reduce 69) ((T_LOGICAL_OR) reduce 69) ((T_LOGICAL_XOR) reduce 69) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 69) ((T_OBJECT_OPERATOR) reduce 69) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 69) ((T_POW) reduce 69) ((T_SL) reduce 69) ((T_SPACESHIP) reduce 69) ((T_SR) reduce 69) (("[") reduce 69) (("^") reduce 69) (("{") reduce 69) (("|") reduce 69)) 18117 ((("%") reduce 63) (("(") reduce 63) (("*") reduce 63) (("+") reduce 63) (("-") reduce 63) ((".") reduce 63) (("/") reduce 63) (("<") reduce 63) ((">") reduce 63) (("?") reduce 63) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_AS) reduce 63) ((T_BOOLEAN_AND) reduce 63) ((T_BOOLEAN_OR) reduce 63) ((T_COALESCE) reduce 63) ((T_INSTANCEOF) reduce 63) ((T_IS_EQUAL) reduce 63) ((T_IS_GREATER_OR_EQUAL) reduce 63) ((T_IS_IDENTICAL) reduce 63) ((T_IS_NOT_EQUAL) reduce 63) ((T_IS_NOT_IDENTICAL) reduce 63) ((T_IS_SMALLER_OR_EQUAL) reduce 63) ((T_LOGICAL_AND) reduce 63) ((T_LOGICAL_OR) reduce 63) ((T_LOGICAL_XOR) reduce 63) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 63) ((T_OBJECT_OPERATOR) reduce 63) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 63) ((T_POW) reduce 63) ((T_SL) reduce 63) ((T_SPACESHIP) reduce 63) ((T_SR) reduce 63) (("[") reduce 63) (("^") reduce 63) (("{") reduce 63) (("|") reduce 63)) 18118 ((("%") reduce 56) (("(") reduce 56) (("*") reduce 56) (("+") reduce 56) (("-") reduce 56) ((".") reduce 56) (("/") reduce 56) (("<") reduce 56) ((">") reduce 56) (("?") reduce 56) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_AS) reduce 56) ((T_BOOLEAN_AND) reduce 56) ((T_BOOLEAN_OR) reduce 56) ((T_COALESCE) reduce 56) ((T_INSTANCEOF) reduce 56) ((T_IS_EQUAL) reduce 56) ((T_IS_GREATER_OR_EQUAL) reduce 56) ((T_IS_IDENTICAL) reduce 56) ((T_IS_NOT_EQUAL) reduce 56) ((T_IS_NOT_IDENTICAL) reduce 56) ((T_IS_SMALLER_OR_EQUAL) reduce 56) ((T_LOGICAL_AND) reduce 56) ((T_LOGICAL_OR) reduce 56) ((T_LOGICAL_XOR) reduce 56) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 56) ((T_OBJECT_OPERATOR) reduce 56) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 56) ((T_POW) reduce 56) ((T_SL) reduce 56) ((T_SPACESHIP) reduce 56) ((T_SR) reduce 56) (("[") reduce 56) (("^") reduce 56) (("{") reduce 56) (("|") reduce 56)) 18119 ((("%") reduce 10) (("(") reduce 10) (("*") reduce 10) (("+") reduce 10) (("-") reduce 10) ((".") reduce 10) (("/") reduce 10) (("<") reduce 10) ((">") reduce 10) (("?") reduce 10) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_AS) reduce 10) ((T_BOOLEAN_AND) reduce 10) ((T_BOOLEAN_OR) reduce 10) ((T_COALESCE) reduce 10) ((T_INSTANCEOF) reduce 10) ((T_IS_EQUAL) reduce 10) ((T_IS_GREATER_OR_EQUAL) reduce 10) ((T_IS_IDENTICAL) reduce 10) ((T_IS_NOT_EQUAL) reduce 10) ((T_IS_NOT_IDENTICAL) reduce 10) ((T_IS_SMALLER_OR_EQUAL) reduce 10) ((T_LOGICAL_AND) reduce 10) ((T_LOGICAL_OR) reduce 10) ((T_LOGICAL_XOR) reduce 10) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 10) ((T_OBJECT_OPERATOR) reduce 10) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 10) ((T_POW) reduce 10) ((T_SL) reduce 10) ((T_SPACESHIP) reduce 10) ((T_SR) reduce 10) (("[") reduce 10) (("^") reduce 10) (("{") reduce 10) (("|") reduce 10)) 18120 ((("%") reduce 67) (("(") reduce 67) (("*") reduce 67) (("+") reduce 67) (("-") reduce 67) ((".") reduce 67) (("/") reduce 67) (("<") reduce 67) ((">") reduce 67) (("?") reduce 67) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_AS) reduce 67) ((T_BOOLEAN_AND) reduce 67) ((T_BOOLEAN_OR) reduce 67) ((T_COALESCE) reduce 67) ((T_INSTANCEOF) reduce 67) ((T_IS_EQUAL) reduce 67) ((T_IS_GREATER_OR_EQUAL) reduce 67) ((T_IS_IDENTICAL) reduce 67) ((T_IS_NOT_EQUAL) reduce 67) ((T_IS_NOT_IDENTICAL) reduce 67) ((T_IS_SMALLER_OR_EQUAL) reduce 67) ((T_LOGICAL_AND) reduce 67) ((T_LOGICAL_OR) reduce 67) ((T_LOGICAL_XOR) reduce 67) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 67) ((T_OBJECT_OPERATOR) reduce 67) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 67) ((T_POW) reduce 67) ((T_SL) reduce 67) ((T_SPACESHIP) reduce 67) ((T_SR) reduce 67) (("[") reduce 67) (("^") reduce 67) (("{") reduce 67) (("|") reduce 67)) 18121 ((("%") reduce 44) (("(") reduce 44) (("*") reduce 44) (("+") reduce 44) (("-") reduce 44) ((".") reduce 44) (("/") reduce 44) (("<") reduce 44) ((">") reduce 44) (("?") reduce 44) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_AS) reduce 44) ((T_BOOLEAN_AND) reduce 44) ((T_BOOLEAN_OR) reduce 44) ((T_COALESCE) reduce 44) ((T_INSTANCEOF) reduce 44) ((T_IS_EQUAL) reduce 44) ((T_IS_GREATER_OR_EQUAL) reduce 44) ((T_IS_IDENTICAL) reduce 44) ((T_IS_NOT_EQUAL) reduce 44) ((T_IS_NOT_IDENTICAL) reduce 44) ((T_IS_SMALLER_OR_EQUAL) reduce 44) ((T_LOGICAL_AND) reduce 44) ((T_LOGICAL_OR) reduce 44) ((T_LOGICAL_XOR) reduce 44) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 44) ((T_OBJECT_OPERATOR) reduce 44) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 44) ((T_POW) reduce 44) ((T_SL) reduce 44) ((T_SPACESHIP) reduce 44) ((T_SR) reduce 44) (("[") reduce 44) (("^") reduce 44) (("{") reduce 44) (("|") reduce 44)) 18122 ((("%") reduce 75) (("(") reduce 75) (("*") reduce 75) (("+") reduce 75) (("-") reduce 75) ((".") reduce 75) (("/") reduce 75) (("<") reduce 75) ((">") reduce 75) (("?") reduce 75) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_AS) reduce 75) ((T_BOOLEAN_AND) reduce 75) ((T_BOOLEAN_OR) reduce 75) ((T_COALESCE) reduce 75) ((T_INSTANCEOF) reduce 75) ((T_IS_EQUAL) reduce 75) ((T_IS_GREATER_OR_EQUAL) reduce 75) ((T_IS_IDENTICAL) reduce 75) ((T_IS_NOT_EQUAL) reduce 75) ((T_IS_NOT_IDENTICAL) reduce 75) ((T_IS_SMALLER_OR_EQUAL) reduce 75) ((T_LOGICAL_AND) reduce 75) ((T_LOGICAL_OR) reduce 75) ((T_LOGICAL_XOR) reduce 75) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 75) ((T_OBJECT_OPERATOR) reduce 75) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 75) ((T_POW) reduce 75) ((T_SL) reduce 75) ((T_SPACESHIP) reduce 75) ((T_SR) reduce 75) (("[") reduce 75) (("^") reduce 75) (("{") reduce 75) (("|") reduce 75)) 18123 ((("%") reduce 76) (("(") reduce 76) (("*") reduce 76) (("+") reduce 76) (("-") reduce 76) ((".") reduce 76) (("/") reduce 76) (("<") reduce 76) ((">") reduce 76) (("?") reduce 76) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_AS) reduce 76) ((T_BOOLEAN_AND) reduce 76) ((T_BOOLEAN_OR) reduce 76) ((T_COALESCE) reduce 76) ((T_INSTANCEOF) reduce 76) ((T_IS_EQUAL) reduce 76) ((T_IS_GREATER_OR_EQUAL) reduce 76) ((T_IS_IDENTICAL) reduce 76) ((T_IS_NOT_EQUAL) reduce 76) ((T_IS_NOT_IDENTICAL) reduce 76) ((T_IS_SMALLER_OR_EQUAL) reduce 76) ((T_LOGICAL_AND) reduce 76) ((T_LOGICAL_OR) reduce 76) ((T_LOGICAL_XOR) reduce 76) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 76) ((T_OBJECT_OPERATOR) reduce 76) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 76) ((T_POW) reduce 76) ((T_SL) reduce 76) ((T_SPACESHIP) reduce 76) ((T_SR) reduce 76) (("[") reduce 76) (("^") reduce 76) (("{") reduce 76) (("|") reduce 76)) 18124 ((("%") reduce 77) (("(") reduce 77) (("*") reduce 77) (("+") reduce 77) (("-") reduce 77) ((".") reduce 77) (("/") reduce 77) (("<") reduce 77) ((">") reduce 77) (("?") reduce 77) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_AS) reduce 77) ((T_BOOLEAN_AND) reduce 77) ((T_BOOLEAN_OR) reduce 77) ((T_COALESCE) reduce 77) ((T_INSTANCEOF) reduce 77) ((T_IS_EQUAL) reduce 77) ((T_IS_GREATER_OR_EQUAL) reduce 77) ((T_IS_IDENTICAL) reduce 77) ((T_IS_NOT_EQUAL) reduce 77) ((T_IS_NOT_IDENTICAL) reduce 77) ((T_IS_SMALLER_OR_EQUAL) reduce 77) ((T_LOGICAL_AND) reduce 77) ((T_LOGICAL_OR) reduce 77) ((T_LOGICAL_XOR) reduce 77) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 77) ((T_OBJECT_OPERATOR) reduce 77) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 77) ((T_POW) reduce 77) ((T_SL) reduce 77) ((T_SPACESHIP) reduce 77) ((T_SR) reduce 77) (("[") reduce 77) (("^") reduce 77) (("{") reduce 77) (("|") reduce 77)) 18125 ((("%") reduce 78) (("(") reduce 78) (("*") reduce 78) (("+") reduce 78) (("-") reduce 78) ((".") reduce 78) (("/") reduce 78) (("<") reduce 78) ((">") reduce 78) (("?") reduce 78) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_AS) reduce 78) ((T_BOOLEAN_AND) reduce 78) ((T_BOOLEAN_OR) reduce 78) ((T_COALESCE) reduce 78) ((T_INSTANCEOF) reduce 78) ((T_IS_EQUAL) reduce 78) ((T_IS_GREATER_OR_EQUAL) reduce 78) ((T_IS_IDENTICAL) reduce 78) ((T_IS_NOT_EQUAL) reduce 78) ((T_IS_NOT_IDENTICAL) reduce 78) ((T_IS_SMALLER_OR_EQUAL) reduce 78) ((T_LOGICAL_AND) reduce 78) ((T_LOGICAL_OR) reduce 78) ((T_LOGICAL_XOR) reduce 78) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 78) ((T_OBJECT_OPERATOR) reduce 78) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 78) ((T_POW) reduce 78) ((T_SL) reduce 78) ((T_SPACESHIP) reduce 78) ((T_SR) reduce 78) (("[") reduce 78) (("^") reduce 78) (("{") reduce 78) (("|") reduce 78)) 18126 ((("%") reduce 4) (("(") reduce 4) (("*") reduce 4) (("+") reduce 4) (("-") reduce 4) ((".") reduce 4) (("/") reduce 4) (("<") reduce 4) ((">") reduce 4) (("?") reduce 4) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_AS) reduce 4) ((T_BOOLEAN_AND) reduce 4) ((T_BOOLEAN_OR) reduce 4) ((T_COALESCE) reduce 4) ((T_INSTANCEOF) reduce 4) ((T_IS_EQUAL) reduce 4) ((T_IS_GREATER_OR_EQUAL) reduce 4) ((T_IS_IDENTICAL) reduce 4) ((T_IS_NOT_EQUAL) reduce 4) ((T_IS_NOT_IDENTICAL) reduce 4) ((T_IS_SMALLER_OR_EQUAL) reduce 4) ((T_LOGICAL_AND) reduce 4) ((T_LOGICAL_OR) reduce 4) ((T_LOGICAL_XOR) reduce 4) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 4) ((T_OBJECT_OPERATOR) reduce 4) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 4) ((T_POW) reduce 4) ((T_SL) reduce 4) ((T_SPACESHIP) reduce 4) ((T_SR) reduce 4) (("[") reduce 4) (("^") reduce 4) (("{") reduce 4) (("|") reduce 4)) 18127 ((("%") reduce 5) (("(") reduce 5) (("*") reduce 5) (("+") reduce 5) (("-") reduce 5) ((".") reduce 5) (("/") reduce 5) (("<") reduce 5) ((">") reduce 5) (("?") reduce 5) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_AS) reduce 5) ((T_BOOLEAN_AND) reduce 5) ((T_BOOLEAN_OR) reduce 5) ((T_COALESCE) reduce 5) ((T_INSTANCEOF) reduce 5) ((T_IS_EQUAL) reduce 5) ((T_IS_GREATER_OR_EQUAL) reduce 5) ((T_IS_IDENTICAL) reduce 5) ((T_IS_NOT_EQUAL) reduce 5) ((T_IS_NOT_IDENTICAL) reduce 5) ((T_IS_SMALLER_OR_EQUAL) reduce 5) ((T_LOGICAL_AND) reduce 5) ((T_LOGICAL_OR) reduce 5) ((T_LOGICAL_XOR) reduce 5) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 5) ((T_OBJECT_OPERATOR) reduce 5) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 5) ((T_POW) reduce 5) ((T_SL) reduce 5) ((T_SPACESHIP) reduce 5) ((T_SR) reduce 5) (("[") reduce 5) (("^") reduce 5) (("{") reduce 5) (("|") reduce 5)) 18128 ((("%") reduce 43) (("(") reduce 43) (("*") reduce 43) (("+") reduce 43) (("-") reduce 43) ((".") reduce 43) (("/") reduce 43) (("<") reduce 43) ((">") reduce 43) (("?") reduce 43) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_AS) reduce 43) ((T_BOOLEAN_AND) reduce 43) ((T_BOOLEAN_OR) reduce 43) ((T_COALESCE) reduce 43) ((T_INSTANCEOF) reduce 43) ((T_IS_EQUAL) reduce 43) ((T_IS_GREATER_OR_EQUAL) reduce 43) ((T_IS_IDENTICAL) reduce 43) ((T_IS_NOT_EQUAL) reduce 43) ((T_IS_NOT_IDENTICAL) reduce 43) ((T_IS_SMALLER_OR_EQUAL) reduce 43) ((T_LOGICAL_AND) reduce 43) ((T_LOGICAL_OR) reduce 43) ((T_LOGICAL_XOR) reduce 43) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 43) ((T_OBJECT_OPERATOR) reduce 43) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 43) ((T_POW) reduce 43) ((T_SL) reduce 43) ((T_SPACESHIP) reduce 43) ((T_SR) reduce 43) (("[") reduce 43) (("^") reduce 43) (("{") reduce 43) (("|") reduce 43)) 18129 ((("%") reduce 72) (("(") reduce 72) (("*") reduce 72) (("+") reduce 72) (("-") reduce 72) ((".") reduce 72) (("/") reduce 72) (("<") reduce 72) ((">") reduce 72) (("?") reduce 72) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_AS) reduce 72) ((T_BOOLEAN_AND) reduce 72) ((T_BOOLEAN_OR) reduce 72) ((T_COALESCE) reduce 72) ((T_INSTANCEOF) reduce 72) ((T_IS_EQUAL) reduce 72) ((T_IS_GREATER_OR_EQUAL) reduce 72) ((T_IS_IDENTICAL) reduce 72) ((T_IS_NOT_EQUAL) reduce 72) ((T_IS_NOT_IDENTICAL) reduce 72) ((T_IS_SMALLER_OR_EQUAL) reduce 72) ((T_LOGICAL_AND) reduce 72) ((T_LOGICAL_OR) reduce 72) ((T_LOGICAL_XOR) reduce 72) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 72) ((T_OBJECT_OPERATOR) reduce 72) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 72) ((T_POW) reduce 72) ((T_SL) reduce 72) ((T_SPACESHIP) reduce 72) ((T_SR) reduce 72) (("[") reduce 72) (("^") reduce 72) (("{") reduce 72) (("|") reduce 72)) 18130 ((("%") reduce 81) (("(") reduce 81) (("*") reduce 81) (("+") reduce 81) (("-") reduce 81) ((".") reduce 81) (("/") reduce 81) (("<") reduce 81) ((">") reduce 81) (("?") reduce 81) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_AS) reduce 81) ((T_BOOLEAN_AND) reduce 81) ((T_BOOLEAN_OR) reduce 81) ((T_COALESCE) reduce 81) ((T_INSTANCEOF) reduce 81) ((T_IS_EQUAL) reduce 81) ((T_IS_GREATER_OR_EQUAL) reduce 81) ((T_IS_IDENTICAL) reduce 81) ((T_IS_NOT_EQUAL) reduce 81) ((T_IS_NOT_IDENTICAL) reduce 81) ((T_IS_SMALLER_OR_EQUAL) reduce 81) ((T_LOGICAL_AND) reduce 81) ((T_LOGICAL_OR) reduce 81) ((T_LOGICAL_XOR) reduce 81) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 81) ((T_OBJECT_OPERATOR) reduce 81) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 81) ((T_POW) reduce 81) ((T_SL) reduce 81) ((T_SPACESHIP) reduce 81) ((T_SR) reduce 81) (("[") reduce 81) (("^") reduce 81) (("{") reduce 81) (("|") reduce 81)) 18131 ((("%") reduce 47) (("(") reduce 47) (("*") reduce 47) (("+") reduce 47) (("-") reduce 47) ((".") reduce 47) (("/") reduce 47) (("<") reduce 47) ((">") reduce 47) (("?") reduce 47) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_AS) reduce 47) ((T_BOOLEAN_AND) reduce 47) ((T_BOOLEAN_OR) reduce 47) ((T_COALESCE) reduce 47) ((T_INSTANCEOF) reduce 47) ((T_IS_EQUAL) reduce 47) ((T_IS_GREATER_OR_EQUAL) reduce 47) ((T_IS_IDENTICAL) reduce 47) ((T_IS_NOT_EQUAL) reduce 47) ((T_IS_NOT_IDENTICAL) reduce 47) ((T_IS_SMALLER_OR_EQUAL) reduce 47) ((T_LOGICAL_AND) reduce 47) ((T_LOGICAL_OR) reduce 47) ((T_LOGICAL_XOR) reduce 47) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 47) ((T_OBJECT_OPERATOR) reduce 47) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 47) ((T_POW) reduce 47) ((T_SL) reduce 47) ((T_SPACESHIP) reduce 47) ((T_SR) reduce 47) (("[") reduce 47) (("^") reduce 47) (("{") reduce 47) (("|") reduce 47)) 18132 ((("%") reduce 31) (("(") reduce 31) (("*") reduce 31) (("+") reduce 31) (("-") reduce 31) ((".") reduce 31) (("/") reduce 31) (("<") reduce 31) ((">") reduce 31) (("?") reduce 31) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_AS) reduce 31) ((T_BOOLEAN_AND) reduce 31) ((T_BOOLEAN_OR) reduce 31) ((T_COALESCE) reduce 31) ((T_INSTANCEOF) reduce 31) ((T_IS_EQUAL) reduce 31) ((T_IS_GREATER_OR_EQUAL) reduce 31) ((T_IS_IDENTICAL) reduce 31) ((T_IS_NOT_EQUAL) reduce 31) ((T_IS_NOT_IDENTICAL) reduce 31) ((T_IS_SMALLER_OR_EQUAL) reduce 31) ((T_LOGICAL_AND) reduce 31) ((T_LOGICAL_OR) reduce 31) ((T_LOGICAL_XOR) reduce 31) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 31) ((T_OBJECT_OPERATOR) reduce 31) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 31) ((T_POW) reduce 31) ((T_SL) reduce 31) ((T_SPACESHIP) reduce 31) ((T_SR) reduce 31) (("[") reduce 31) (("^") reduce 31) (("{") reduce 31) (("|") reduce 31)) 18133 ((("%") reduce 57) (("(") reduce 57) (("*") reduce 57) (("+") reduce 57) (("-") reduce 57) ((".") reduce 57) (("/") reduce 57) (("<") reduce 57) ((">") reduce 57) (("?") reduce 57) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_AS) reduce 57) ((T_BOOLEAN_AND) reduce 57) ((T_BOOLEAN_OR) reduce 57) ((T_COALESCE) reduce 57) ((T_INSTANCEOF) reduce 57) ((T_IS_EQUAL) reduce 57) ((T_IS_GREATER_OR_EQUAL) reduce 57) ((T_IS_IDENTICAL) reduce 57) ((T_IS_NOT_EQUAL) reduce 57) ((T_IS_NOT_IDENTICAL) reduce 57) ((T_IS_SMALLER_OR_EQUAL) reduce 57) ((T_LOGICAL_AND) reduce 57) ((T_LOGICAL_OR) reduce 57) ((T_LOGICAL_XOR) reduce 57) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 57) ((T_OBJECT_OPERATOR) reduce 57) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 57) ((T_POW) reduce 57) ((T_SL) reduce 57) ((T_SPACESHIP) reduce 57) ((T_SR) reduce 57) (("[") reduce 57) (("^") reduce 57) (("{") reduce 57) (("|") reduce 57)) 18134 ((("%") reduce 61) (("(") reduce 61) (("*") reduce 61) (("+") reduce 61) (("-") reduce 61) ((".") reduce 61) (("/") reduce 61) (("<") reduce 61) ((">") reduce 61) (("?") reduce 61) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_AS) reduce 61) ((T_BOOLEAN_AND) reduce 61) ((T_BOOLEAN_OR) reduce 61) ((T_COALESCE) reduce 61) ((T_INSTANCEOF) reduce 61) ((T_IS_EQUAL) reduce 61) ((T_IS_GREATER_OR_EQUAL) reduce 61) ((T_IS_IDENTICAL) reduce 61) ((T_IS_NOT_EQUAL) reduce 61) ((T_IS_NOT_IDENTICAL) reduce 61) ((T_IS_SMALLER_OR_EQUAL) reduce 61) ((T_LOGICAL_AND) reduce 61) ((T_LOGICAL_OR) reduce 61) ((T_LOGICAL_XOR) reduce 61) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 61) ((T_OBJECT_OPERATOR) reduce 61) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 61) ((T_POW) reduce 61) ((T_SL) reduce 61) ((T_SPACESHIP) reduce 61) ((T_SR) reduce 61) (("[") reduce 61) (("^") reduce 61) (("{") reduce 61) (("|") reduce 61)) 18135 ((("%") reduce 28) (("(") reduce 28) (("*") reduce 28) (("+") reduce 28) (("-") reduce 28) ((".") reduce 28) (("/") reduce 28) (("<") reduce 28) ((">") reduce 28) (("?") reduce 28) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_AS) reduce 28) ((T_BOOLEAN_AND) reduce 28) ((T_BOOLEAN_OR) reduce 28) ((T_COALESCE) reduce 28) ((T_INSTANCEOF) reduce 28) ((T_IS_EQUAL) reduce 28) ((T_IS_GREATER_OR_EQUAL) reduce 28) ((T_IS_IDENTICAL) reduce 28) ((T_IS_NOT_EQUAL) reduce 28) ((T_IS_NOT_IDENTICAL) reduce 28) ((T_IS_SMALLER_OR_EQUAL) reduce 28) ((T_LOGICAL_AND) reduce 28) ((T_LOGICAL_OR) reduce 28) ((T_LOGICAL_XOR) reduce 28) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 28) ((T_OBJECT_OPERATOR) reduce 28) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 28) ((T_POW) reduce 28) ((T_SL) reduce 28) ((T_SPACESHIP) reduce 28) ((T_SR) reduce 28) (("[") reduce 28) (("^") reduce 28) (("{") reduce 28) (("|") reduce 28)) 18136 ((("%") reduce 36) (("(") reduce 36) (("*") reduce 36) (("+") reduce 36) (("-") reduce 36) ((".") reduce 36) (("/") reduce 36) (("<") reduce 36) ((">") reduce 36) (("?") reduce 36) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_AS) reduce 36) ((T_BOOLEAN_AND) reduce 36) ((T_BOOLEAN_OR) reduce 36) ((T_COALESCE) reduce 36) ((T_INSTANCEOF) reduce 36) ((T_IS_EQUAL) reduce 36) ((T_IS_GREATER_OR_EQUAL) reduce 36) ((T_IS_IDENTICAL) reduce 36) ((T_IS_NOT_EQUAL) reduce 36) ((T_IS_NOT_IDENTICAL) reduce 36) ((T_IS_SMALLER_OR_EQUAL) reduce 36) ((T_LOGICAL_AND) reduce 36) ((T_LOGICAL_OR) reduce 36) ((T_LOGICAL_XOR) reduce 36) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 36) ((T_OBJECT_OPERATOR) reduce 36) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 36) ((T_POW) reduce 36) ((T_SL) reduce 36) ((T_SPACESHIP) reduce 36) ((T_SR) reduce 36) (("[") reduce 36) (("^") reduce 36) (("{") reduce 36) (("|") reduce 36)) 18137 ((("%") reduce 32) (("(") reduce 32) (("*") reduce 32) (("+") reduce 32) (("-") reduce 32) ((".") reduce 32) (("/") reduce 32) (("<") reduce 32) ((">") reduce 32) (("?") reduce 32) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_AS) reduce 32) ((T_BOOLEAN_AND) reduce 32) ((T_BOOLEAN_OR) reduce 32) ((T_COALESCE) reduce 32) ((T_INSTANCEOF) reduce 32) ((T_IS_EQUAL) reduce 32) ((T_IS_GREATER_OR_EQUAL) reduce 32) ((T_IS_IDENTICAL) reduce 32) ((T_IS_NOT_EQUAL) reduce 32) ((T_IS_NOT_IDENTICAL) reduce 32) ((T_IS_SMALLER_OR_EQUAL) reduce 32) ((T_LOGICAL_AND) reduce 32) ((T_LOGICAL_OR) reduce 32) ((T_LOGICAL_XOR) reduce 32) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 32) ((T_OBJECT_OPERATOR) reduce 32) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 32) ((T_POW) reduce 32) ((T_SL) reduce 32) ((T_SPACESHIP) reduce 32) ((T_SR) reduce 32) (("[") reduce 32) (("^") reduce 32) (("{") reduce 32) (("|") reduce 32)) 18138 ((("%") reduce 35) (("(") reduce 35) (("*") reduce 35) (("+") reduce 35) (("-") reduce 35) ((".") reduce 35) (("/") reduce 35) (("<") reduce 35) ((">") reduce 35) (("?") reduce 35) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_AS) reduce 35) ((T_BOOLEAN_AND) reduce 35) ((T_BOOLEAN_OR) reduce 35) ((T_COALESCE) reduce 35) ((T_INSTANCEOF) reduce 35) ((T_IS_EQUAL) reduce 35) ((T_IS_GREATER_OR_EQUAL) reduce 35) ((T_IS_IDENTICAL) reduce 35) ((T_IS_NOT_EQUAL) reduce 35) ((T_IS_NOT_IDENTICAL) reduce 35) ((T_IS_SMALLER_OR_EQUAL) reduce 35) ((T_LOGICAL_AND) reduce 35) ((T_LOGICAL_OR) reduce 35) ((T_LOGICAL_XOR) reduce 35) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 35) ((T_OBJECT_OPERATOR) reduce 35) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 35) ((T_POW) reduce 35) ((T_SL) reduce 35) ((T_SPACESHIP) reduce 35) ((T_SR) reduce 35) (("[") reduce 35) (("^") reduce 35) (("{") reduce 35) (("|") reduce 35)) 18139 ((("%") reduce 19) (("(") reduce 19) (("*") reduce 19) (("+") reduce 19) (("-") reduce 19) ((".") reduce 19) (("/") reduce 19) (("<") reduce 19) ((">") reduce 19) (("?") reduce 19) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_AS) reduce 19) ((T_BOOLEAN_AND) reduce 19) ((T_BOOLEAN_OR) reduce 19) ((T_COALESCE) reduce 19) ((T_INSTANCEOF) reduce 19) ((T_IS_EQUAL) reduce 19) ((T_IS_GREATER_OR_EQUAL) reduce 19) ((T_IS_IDENTICAL) reduce 19) ((T_IS_NOT_EQUAL) reduce 19) ((T_IS_NOT_IDENTICAL) reduce 19) ((T_IS_SMALLER_OR_EQUAL) reduce 19) ((T_LOGICAL_AND) reduce 19) ((T_LOGICAL_OR) reduce 19) ((T_LOGICAL_XOR) reduce 19) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 19) ((T_OBJECT_OPERATOR) reduce 19) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 19) ((T_POW) reduce 19) ((T_SL) reduce 19) ((T_SPACESHIP) reduce 19) ((T_SR) reduce 19) (("[") reduce 19) (("^") reduce 19) (("{") reduce 19) (("|") reduce 19)) 18140 ((("%") reduce 45) (("(") reduce 45) (("*") reduce 45) (("+") reduce 45) (("-") reduce 45) ((".") reduce 45) (("/") reduce 45) (("<") reduce 45) ((">") reduce 45) (("?") reduce 45) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_AS) reduce 45) ((T_BOOLEAN_AND) reduce 45) ((T_BOOLEAN_OR) reduce 45) ((T_COALESCE) reduce 45) ((T_INSTANCEOF) reduce 45) ((T_IS_EQUAL) reduce 45) ((T_IS_GREATER_OR_EQUAL) reduce 45) ((T_IS_IDENTICAL) reduce 45) ((T_IS_NOT_EQUAL) reduce 45) ((T_IS_NOT_IDENTICAL) reduce 45) ((T_IS_SMALLER_OR_EQUAL) reduce 45) ((T_LOGICAL_AND) reduce 45) ((T_LOGICAL_OR) reduce 45) ((T_LOGICAL_XOR) reduce 45) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 45) ((T_OBJECT_OPERATOR) reduce 45) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 45) ((T_POW) reduce 45) ((T_SL) reduce 45) ((T_SPACESHIP) reduce 45) ((T_SR) reduce 45) (("[") reduce 45) (("^") reduce 45) (("{") reduce 45) (("|") reduce 45)) 18141 ((("%") reduce 504) (("(") reduce 541) (("*") reduce 504) (("+") reduce 504) (("-") reduce 504) ((".") reduce 504) (("/") reduce 504) (("<") reduce 504) ((">") reduce 504) (("?") reduce 504) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_AS) reduce 504) ((T_BOOLEAN_AND) reduce 504) ((T_BOOLEAN_OR) reduce 504) ((T_COALESCE) reduce 504) ((T_INSTANCEOF) reduce 504) ((T_IS_EQUAL) reduce 504) ((T_IS_GREATER_OR_EQUAL) reduce 504) ((T_IS_IDENTICAL) reduce 504) ((T_IS_NOT_EQUAL) reduce 504) ((T_IS_NOT_IDENTICAL) reduce 504) ((T_IS_SMALLER_OR_EQUAL) reduce 504) ((T_LOGICAL_AND) reduce 504) ((T_LOGICAL_OR) reduce 504) ((T_LOGICAL_XOR) reduce 504) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 504) ((T_OBJECT_OPERATOR) reduce 504) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 504) ((T_POW) reduce 504) ((T_SL) reduce 504) ((T_SPACESHIP) reduce 504) ((T_SR) reduce 504) (("[") reduce 504) (("^") reduce 504) (("{") reduce 504) (("|") reduce 504)) 18143 ((("%") reduce 71) (("(") reduce 71) (("*") reduce 71) (("+") reduce 71) (("-") reduce 71) ((".") reduce 71) (("/") reduce 71) (("<") reduce 71) ((">") reduce 71) (("?") reduce 71) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_AS) reduce 71) ((T_BOOLEAN_AND) reduce 71) ((T_BOOLEAN_OR) reduce 71) ((T_COALESCE) reduce 71) ((T_INSTANCEOF) reduce 71) ((T_IS_EQUAL) reduce 71) ((T_IS_GREATER_OR_EQUAL) reduce 71) ((T_IS_IDENTICAL) reduce 71) ((T_IS_NOT_EQUAL) reduce 71) ((T_IS_NOT_IDENTICAL) reduce 71) ((T_IS_SMALLER_OR_EQUAL) reduce 71) ((T_LOGICAL_AND) reduce 71) ((T_LOGICAL_OR) reduce 71) ((T_LOGICAL_XOR) reduce 71) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 71) ((T_OBJECT_OPERATOR) reduce 71) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 71) ((T_POW) reduce 71) ((T_SL) reduce 71) ((T_SPACESHIP) reduce 71) ((T_SR) reduce 71) (("[") reduce 71) (("^") reduce 71) (("{") reduce 71) (("|") reduce 71)) 18144 ((("%") reduce 82) (("(") reduce 82) (("*") reduce 82) (("+") reduce 82) (("-") reduce 82) ((".") reduce 82) (("/") reduce 82) (("<") reduce 82) ((">") reduce 82) (("?") reduce 82) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_AS) reduce 82) ((T_BOOLEAN_AND) reduce 82) ((T_BOOLEAN_OR) reduce 82) ((T_COALESCE) reduce 82) ((T_INSTANCEOF) reduce 82) ((T_IS_EQUAL) reduce 82) ((T_IS_GREATER_OR_EQUAL) reduce 82) ((T_IS_IDENTICAL) reduce 82) ((T_IS_NOT_EQUAL) reduce 82) ((T_IS_NOT_IDENTICAL) reduce 82) ((T_IS_SMALLER_OR_EQUAL) reduce 82) ((T_LOGICAL_AND) reduce 82) ((T_LOGICAL_OR) reduce 82) ((T_LOGICAL_XOR) reduce 82) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 82) ((T_OBJECT_OPERATOR) reduce 82) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 82) ((T_POW) reduce 82) ((T_SL) reduce 82) ((T_SPACESHIP) reduce 82) ((T_SR) reduce 82) (("[") reduce 82) (("^") reduce 82) (("{") reduce 82) (("|") reduce 82)) 18145 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) (("<") reduce 533) (("=") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AND_EQUAL) reduce 533) ((T_AS) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_COALESCE_EQUAL) reduce 533) ((T_CONCAT_EQUAL) reduce 533) ((T_DEC) reduce 533) ((T_DIV_EQUAL) reduce 533) ((T_INC) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_MINUS_EQUAL) reduce 533) ((T_MOD_EQUAL) reduce 533) ((T_MUL_EQUAL) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_OR_EQUAL) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_PLUS_EQUAL) reduce 533) ((T_POW) reduce 533) ((T_POW_EQUAL) reduce 533) ((T_SL) reduce 533) ((T_SL_EQUAL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) ((T_SR_EQUAL) reduce 533) ((T_XOR_EQUAL) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 18148 ((("%") reduce 506) (("(") reduce 542) (("*") reduce 506) (("+") reduce 506) (("-") reduce 506) ((".") reduce 506) (("/") reduce 506) (("<") reduce 506) ((">") reduce 506) (("?") reduce 506) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_AS) reduce 506) ((T_BOOLEAN_AND) reduce 506) ((T_BOOLEAN_OR) reduce 506) ((T_COALESCE) reduce 506) ((T_INSTANCEOF) reduce 506) ((T_IS_EQUAL) reduce 506) ((T_IS_GREATER_OR_EQUAL) reduce 506) ((T_IS_IDENTICAL) reduce 506) ((T_IS_NOT_EQUAL) reduce 506) ((T_IS_NOT_IDENTICAL) reduce 506) ((T_IS_SMALLER_OR_EQUAL) reduce 506) ((T_LOGICAL_AND) reduce 506) ((T_LOGICAL_OR) reduce 506) ((T_LOGICAL_XOR) reduce 506) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 506) ((T_OBJECT_OPERATOR) reduce 506) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 506) ((T_POW) reduce 506) ((T_SL) reduce 506) ((T_SPACESHIP) reduce 506) ((T_SR) reduce 506) (("[") reduce 506) (("^") reduce 506) (("{") reduce 506) (("|") reduce 506)) 18150 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) (("<") reduce 468) (("=") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AND_EQUAL) reduce 468) ((T_AS) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_COALESCE_EQUAL) reduce 468) ((T_CONCAT_EQUAL) reduce 468) ((T_DEC) reduce 468) ((T_DIV_EQUAL) reduce 468) ((T_INC) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_MINUS_EQUAL) reduce 468) ((T_MOD_EQUAL) reduce 468) ((T_MUL_EQUAL) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_OR_EQUAL) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_PLUS_EQUAL) reduce 468) ((T_POW) reduce 468) ((T_POW_EQUAL) reduce 468) ((T_SL) reduce 468) ((T_SL_EQUAL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) ((T_SR_EQUAL) reduce 468) ((T_XOR_EQUAL) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 18151 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) (("=") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AND_EQUAL) reduce 288) ((T_AS) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_COALESCE_EQUAL) reduce 288) ((T_CONCAT_EQUAL) reduce 288) ((T_DEC) reduce 288) ((T_DIV_EQUAL) reduce 288) ((T_INC) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_MINUS_EQUAL) reduce 288) ((T_MOD_EQUAL) reduce 288) ((T_MUL_EQUAL) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_OR_EQUAL) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_PLUS_EQUAL) reduce 288) ((T_POW) reduce 288) ((T_POW_EQUAL) reduce 288) ((T_SL) reduce 288) ((T_SL_EQUAL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) ((T_SR_EQUAL) reduce 288) ((T_XOR_EQUAL) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 18155 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) (("=") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AND_EQUAL) reduce 289) ((T_AS) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_COALESCE_EQUAL) reduce 289) ((T_CONCAT_EQUAL) reduce 289) ((T_DEC) reduce 289) ((T_DIV_EQUAL) reduce 289) ((T_INC) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_MINUS_EQUAL) reduce 289) ((T_MOD_EQUAL) reduce 289) ((T_MUL_EQUAL) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_OR_EQUAL) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_PLUS_EQUAL) reduce 289) ((T_POW) reduce 289) ((T_POW_EQUAL) reduce 289) ((T_SL) reduce 289) ((T_SL_EQUAL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) ((T_SR_EQUAL) reduce 289) ((T_XOR_EQUAL) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 18156 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) (("=") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AND_EQUAL) reduce 290) ((T_AS) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_COALESCE_EQUAL) reduce 290) ((T_CONCAT_EQUAL) reduce 290) ((T_DEC) reduce 290) ((T_DIV_EQUAL) reduce 290) ((T_INC) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_MINUS_EQUAL) reduce 290) ((T_MOD_EQUAL) reduce 290) ((T_MUL_EQUAL) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_OR_EQUAL) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_PLUS_EQUAL) reduce 290) ((T_POW) reduce 290) ((T_POW_EQUAL) reduce 290) ((T_SL) reduce 290) ((T_SL_EQUAL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) ((T_SR_EQUAL) reduce 290) ((T_XOR_EQUAL) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 18161 ((("%") reduce 388) (("*") reduce 388) (("+") reduce 388) (("-") reduce 388) ((".") reduce 388) (("/") reduce 388) (("<") reduce 388) ((">") reduce 388) (("?") reduce 388) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_AS) reduce 388) ((T_BOOLEAN_AND) reduce 388) ((T_BOOLEAN_OR) reduce 388) ((T_COALESCE) reduce 388) ((T_INSTANCEOF) reduce 388) ((T_IS_EQUAL) reduce 388) ((T_IS_GREATER_OR_EQUAL) reduce 388) ((T_IS_IDENTICAL) reduce 388) ((T_IS_NOT_EQUAL) reduce 388) ((T_IS_NOT_IDENTICAL) reduce 388) ((T_IS_SMALLER_OR_EQUAL) reduce 388) ((T_LOGICAL_AND) reduce 388) ((T_LOGICAL_OR) reduce 388) ((T_LOGICAL_XOR) reduce 388) ((T_POW) reduce 388) ((T_SL) reduce 388) ((T_SPACESHIP) reduce 388) ((T_SR) reduce 388) (("^") reduce 388) (("|") reduce 388)) 18163 ((("%") reduce 386) (("*") reduce 386) (("+") reduce 386) (("-") reduce 386) ((".") reduce 386) (("/") reduce 386) (("<") reduce 386) ((">") reduce 386) (("?") reduce 386) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_AS) reduce 386) ((T_BOOLEAN_AND) reduce 386) ((T_BOOLEAN_OR) reduce 386) ((T_COALESCE) reduce 386) ((T_INSTANCEOF) reduce 386) ((T_IS_EQUAL) reduce 386) ((T_IS_GREATER_OR_EQUAL) reduce 386) ((T_IS_IDENTICAL) reduce 386) ((T_IS_NOT_EQUAL) reduce 386) ((T_IS_NOT_IDENTICAL) reduce 386) ((T_IS_SMALLER_OR_EQUAL) reduce 386) ((T_LOGICAL_AND) reduce 386) ((T_LOGICAL_OR) reduce 386) ((T_LOGICAL_XOR) reduce 386) ((T_POW) reduce 386) ((T_SL) reduce 386) ((T_SPACESHIP) reduce 386) ((T_SR) reduce 386) (("^") reduce 386) (("|") reduce 386)) 18173 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 382) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 382) ((T_LOGICAL_OR) reduce 382) ((T_LOGICAL_XOR) reduce 382) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18174 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 384) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 384) ((T_LOGICAL_OR) reduce 384) ((T_LOGICAL_XOR) reduce 384) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18175 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 383) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 383) ((T_LOGICAL_OR) reduce 383) ((T_LOGICAL_XOR) reduce 383) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18176 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 376) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 376) ((T_LOGICAL_OR) reduce 376) ((T_LOGICAL_XOR) reduce 376) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18177 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 373) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 373) ((T_LOGICAL_OR) reduce 373) ((T_LOGICAL_XOR) reduce 373) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18178 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 381) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 381) ((T_LOGICAL_OR) reduce 381) ((T_LOGICAL_XOR) reduce 381) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18179 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 375) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 375) ((T_LOGICAL_OR) reduce 375) ((T_LOGICAL_XOR) reduce 375) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18180 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 379) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 379) ((T_LOGICAL_OR) reduce 379) ((T_LOGICAL_XOR) reduce 379) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18181 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 374) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 374) ((T_LOGICAL_OR) reduce 374) ((T_LOGICAL_XOR) reduce 374) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18182 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 377) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 377) ((T_LOGICAL_OR) reduce 377) ((T_LOGICAL_XOR) reduce 377) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18183 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 378) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 378) ((T_LOGICAL_OR) reduce 378) ((T_LOGICAL_XOR) reduce 378) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18184 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 385) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 385) ((T_LOGICAL_OR) reduce 385) ((T_LOGICAL_XOR) reduce 385) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18185 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 380) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 380) ((T_LOGICAL_OR) reduce 380) ((T_LOGICAL_XOR) reduce 380) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18187 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 370) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 370) ((T_LOGICAL_OR) reduce 370) ((T_LOGICAL_XOR) reduce 370) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18190 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AS) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 18193 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) (("<") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AS) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_POW) reduce 525) ((T_SL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 18195 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) (("<") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AS) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_POW) reduce 524) ((T_SL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 18197 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) (("<") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AS) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_POW) reduce 519) ((T_SL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 18198 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) (("<") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AS) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_POW) reduce 526) ((T_SL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 18199 ((("%") reduce 371) (("*") reduce 371) (("+") reduce 371) (("-") reduce 371) ((".") reduce 371) (("/") reduce 371) (("<") reduce 371) ((">") reduce 371) (("?") reduce 371) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_AS) reduce 371) ((T_BOOLEAN_AND) reduce 371) ((T_BOOLEAN_OR) reduce 371) ((T_COALESCE) reduce 371) ((T_INSTANCEOF) reduce 371) ((T_IS_EQUAL) reduce 371) ((T_IS_GREATER_OR_EQUAL) reduce 371) ((T_IS_IDENTICAL) reduce 371) ((T_IS_NOT_EQUAL) reduce 371) ((T_IS_NOT_IDENTICAL) reduce 371) ((T_IS_SMALLER_OR_EQUAL) reduce 371) ((T_LOGICAL_AND) reduce 371) ((T_LOGICAL_OR) reduce 371) ((T_LOGICAL_XOR) reduce 371) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 371) ((T_SL) reduce 371) ((T_SPACESHIP) reduce 371) ((T_SR) reduce 371) (("[") reduce 510) (("^") reduce 371) (("{") reduce 510) (("|") reduce 371)) 18203 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) (("<") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AS) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_POW) reduce 533) ((T_SL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 18205 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) (("<") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AS) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_POW) reduce 468) ((T_SL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 18206 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AS) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 18210 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AS) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 18211 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AS) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 18212 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) (("<") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AS) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_POW) reduce 465) ((T_SL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 18215 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) (("<") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AS) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_POW) reduce 532) ((T_SL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 18216 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) (("<") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AS) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_POW) reduce 467) ((T_SL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 18217 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) (("<") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AS) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_POW) reduce 469) ((T_SL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 18223 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) (("<") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AS) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_POW) reduce 521) ((T_SL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 18225 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) (("<") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AS) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_POW) reduce 520) ((T_SL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 18226 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AS) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 18227 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) (("<") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AS) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_POW) reduce 527) ((T_SL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 18228 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AS) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 18231 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AS) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 18232 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) (("<") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AS) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_POW) reduce 522) ((T_SL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 18233 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) (("<") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AS) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_POW) reduce 528) ((T_SL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 18234 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) (("<") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AS) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_POW) reduce 523) ((T_SL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 18235 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) (("<") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AS) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_POW) reduce 466) ((T_SL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 18236 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AS) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 18239 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AS) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 18240 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) (("<") reduce 465) (("=") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AND_EQUAL) reduce 465) ((T_AS) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_COALESCE_EQUAL) reduce 465) ((T_CONCAT_EQUAL) reduce 465) ((T_DEC) reduce 465) ((T_DIV_EQUAL) reduce 465) ((T_INC) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_MINUS_EQUAL) reduce 465) ((T_MOD_EQUAL) reduce 465) ((T_MUL_EQUAL) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_OR_EQUAL) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_PLUS_EQUAL) reduce 465) ((T_POW) reduce 465) ((T_POW_EQUAL) reduce 465) ((T_SL) reduce 465) ((T_SL_EQUAL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) ((T_SR_EQUAL) reduce 465) ((T_XOR_EQUAL) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 18251 ((("%") reduce 455) (("*") reduce 455) (("+") reduce 455) (("-") reduce 455) ((".") reduce 455) (("/") reduce 455) (("<") reduce 455) ((">") reduce 455) (("?") reduce 455) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_AS) reduce 455) ((T_BOOLEAN_AND) reduce 455) ((T_BOOLEAN_OR) reduce 455) ((T_COALESCE) reduce 455) ((T_INSTANCEOF) reduce 455) ((T_IS_EQUAL) reduce 455) ((T_IS_GREATER_OR_EQUAL) reduce 455) ((T_IS_IDENTICAL) reduce 455) ((T_IS_NOT_EQUAL) reduce 455) ((T_IS_NOT_IDENTICAL) reduce 455) ((T_IS_SMALLER_OR_EQUAL) reduce 455) ((T_LOGICAL_AND) reduce 455) ((T_LOGICAL_OR) reduce 455) ((T_LOGICAL_XOR) reduce 455) ((T_POW) reduce 455) ((T_SL) reduce 455) ((T_SPACESHIP) reduce 455) ((T_SR) reduce 455) (("^") reduce 455) (("|") reduce 455)) 18252 ((("%") reduce 450) (("*") reduce 450) (("+") reduce 450) (("-") reduce 450) ((".") reduce 450) (("/") reduce 450) (("<") reduce 450) ((">") reduce 450) (("?") reduce 450) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_AS) reduce 450) ((T_BOOLEAN_AND) reduce 450) ((T_BOOLEAN_OR) reduce 450) ((T_COALESCE) reduce 450) ((T_INSTANCEOF) reduce 450) ((T_IS_EQUAL) reduce 450) ((T_IS_GREATER_OR_EQUAL) reduce 450) ((T_IS_IDENTICAL) reduce 450) ((T_IS_NOT_EQUAL) reduce 450) ((T_IS_NOT_IDENTICAL) reduce 450) ((T_IS_SMALLER_OR_EQUAL) reduce 450) ((T_LOGICAL_AND) reduce 450) ((T_LOGICAL_OR) reduce 450) ((T_LOGICAL_XOR) reduce 450) ((T_POW) reduce 450) ((T_SL) reduce 450) ((T_SPACESHIP) reduce 450) ((T_SR) reduce 450) (("^") reduce 450) (("|") reduce 450)) 18324 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 455) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18642 ((("%") reduce 451) (("*") reduce 451) (("+") reduce 451) (("-") reduce 451) ((".") reduce 451) (("/") reduce 451) (("<") reduce 451) ((">") reduce 451) (("?") reduce 451) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_AS) reduce 451) ((T_BOOLEAN_AND) reduce 451) ((T_BOOLEAN_OR) reduce 451) ((T_COALESCE) reduce 451) ((T_INSTANCEOF) reduce 451) ((T_IS_EQUAL) reduce 451) ((T_IS_GREATER_OR_EQUAL) reduce 451) ((T_IS_IDENTICAL) reduce 451) ((T_IS_NOT_EQUAL) reduce 451) ((T_IS_NOT_IDENTICAL) reduce 451) ((T_IS_SMALLER_OR_EQUAL) reduce 451) ((T_LOGICAL_AND) reduce 451) ((T_LOGICAL_OR) reduce 451) ((T_LOGICAL_XOR) reduce 451) ((T_POW) reduce 451) ((T_SL) reduce 451) ((T_SPACESHIP) reduce 451) ((T_SR) reduce 451) (("^") reduce 451) (("|") reduce 451)) 18645 ((("%") reduce 503) (("(") reduce 541) (("*") reduce 503) (("+") reduce 503) (("-") reduce 503) ((".") reduce 503) (("/") reduce 503) (("<") reduce 503) ((">") reduce 503) (("?") reduce 503) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_AS) reduce 503) ((T_BOOLEAN_AND) reduce 503) ((T_BOOLEAN_OR) reduce 503) ((T_COALESCE) reduce 503) ((T_INSTANCEOF) reduce 503) ((T_IS_EQUAL) reduce 503) ((T_IS_GREATER_OR_EQUAL) reduce 503) ((T_IS_IDENTICAL) reduce 503) ((T_IS_NOT_EQUAL) reduce 503) ((T_IS_NOT_IDENTICAL) reduce 503) ((T_IS_SMALLER_OR_EQUAL) reduce 503) ((T_LOGICAL_AND) reduce 503) ((T_LOGICAL_OR) reduce 503) ((T_LOGICAL_XOR) reduce 503) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 503) ((T_OBJECT_OPERATOR) reduce 503) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 503) ((T_POW) reduce 503) ((T_SL) reduce 503) ((T_SPACESHIP) reduce 503) ((T_SR) reduce 503) (("[") reduce 503) (("^") reduce 503) (("{") reduce 503) (("|") reduce 503)) 18647 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) (("<") reduce 532) (("=") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AND_EQUAL) reduce 532) ((T_AS) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_COALESCE_EQUAL) reduce 532) ((T_CONCAT_EQUAL) reduce 532) ((T_DEC) reduce 532) ((T_DIV_EQUAL) reduce 532) ((T_INC) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_MINUS_EQUAL) reduce 532) ((T_MOD_EQUAL) reduce 532) ((T_MUL_EQUAL) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_OR_EQUAL) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_PLUS_EQUAL) reduce 532) ((T_POW) reduce 532) ((T_POW_EQUAL) reduce 532) ((T_SL) reduce 532) ((T_SL_EQUAL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) ((T_SR_EQUAL) reduce 532) ((T_XOR_EQUAL) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 18650 ((("%") reduce 505) (("(") reduce 542) (("*") reduce 505) (("+") reduce 505) (("-") reduce 505) ((".") reduce 505) (("/") reduce 505) (("<") reduce 505) ((">") reduce 505) (("?") reduce 505) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_AS) reduce 505) ((T_BOOLEAN_AND) reduce 505) ((T_BOOLEAN_OR) reduce 505) ((T_COALESCE) reduce 505) ((T_INSTANCEOF) reduce 505) ((T_IS_EQUAL) reduce 505) ((T_IS_GREATER_OR_EQUAL) reduce 505) ((T_IS_IDENTICAL) reduce 505) ((T_IS_NOT_EQUAL) reduce 505) ((T_IS_NOT_IDENTICAL) reduce 505) ((T_IS_SMALLER_OR_EQUAL) reduce 505) ((T_LOGICAL_AND) reduce 505) ((T_LOGICAL_OR) reduce 505) ((T_LOGICAL_XOR) reduce 505) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 505) ((T_OBJECT_OPERATOR) reduce 505) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 505) ((T_POW) reduce 505) ((T_SL) reduce 505) ((T_SPACESHIP) reduce 505) ((T_SR) reduce 505) (("[") reduce 505) (("^") reduce 505) (("{") reduce 505) (("|") reduce 505)) 18651 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) (("<") reduce 467) (("=") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AND_EQUAL) reduce 467) ((T_AS) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_COALESCE_EQUAL) reduce 467) ((T_CONCAT_EQUAL) reduce 467) ((T_DEC) reduce 467) ((T_DIV_EQUAL) reduce 467) ((T_INC) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_MINUS_EQUAL) reduce 467) ((T_MOD_EQUAL) reduce 467) ((T_MUL_EQUAL) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_OR_EQUAL) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_PLUS_EQUAL) reduce 467) ((T_POW) reduce 467) ((T_POW_EQUAL) reduce 467) ((T_SL) reduce 467) ((T_SL_EQUAL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) ((T_SR_EQUAL) reduce 467) ((T_XOR_EQUAL) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 18652 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) (("<") reduce 469) (("=") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AND_EQUAL) reduce 469) ((T_AS) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_COALESCE_EQUAL) reduce 469) ((T_CONCAT_EQUAL) reduce 469) ((T_DEC) reduce 469) ((T_DIV_EQUAL) reduce 469) ((T_INC) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_MINUS_EQUAL) reduce 469) ((T_MOD_EQUAL) reduce 469) ((T_MUL_EQUAL) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_OR_EQUAL) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_PLUS_EQUAL) reduce 469) ((T_POW) reduce 469) ((T_POW_EQUAL) reduce 469) ((T_SL) reduce 469) ((T_SL_EQUAL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) ((T_SR_EQUAL) reduce 469) ((T_XOR_EQUAL) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 18654 ((("%") reduce 446) (("*") reduce 446) (("+") reduce 446) (("-") reduce 446) ((".") reduce 446) (("/") reduce 446) (("<") reduce 446) ((">") reduce 446) (("?") reduce 446) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_AS) reduce 446) ((T_BOOLEAN_AND) reduce 446) ((T_BOOLEAN_OR) reduce 446) ((T_COALESCE) reduce 446) ((T_INSTANCEOF) reduce 446) ((T_IS_EQUAL) reduce 446) ((T_IS_GREATER_OR_EQUAL) reduce 446) ((T_IS_IDENTICAL) reduce 446) ((T_IS_NOT_EQUAL) reduce 446) ((T_IS_NOT_IDENTICAL) reduce 446) ((T_IS_SMALLER_OR_EQUAL) reduce 446) ((T_LOGICAL_AND) reduce 446) ((T_LOGICAL_OR) reduce 446) ((T_LOGICAL_XOR) reduce 446) ((T_POW) reduce 446) ((T_SL) reduce 446) ((T_SPACESHIP) reduce 446) ((T_SR) reduce 446) (("^") reduce 446) (("|") reduce 446)) 18655 ((("%") reduce 448) (("*") reduce 448) (("+") reduce 448) (("-") reduce 448) ((".") reduce 448) (("/") reduce 448) (("<") reduce 448) ((">") reduce 448) (("?") reduce 448) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_AS) reduce 448) ((T_BOOLEAN_AND) reduce 448) ((T_BOOLEAN_OR) reduce 448) ((T_COALESCE) reduce 448) ((T_INSTANCEOF) reduce 448) ((T_IS_EQUAL) reduce 448) ((T_IS_GREATER_OR_EQUAL) reduce 448) ((T_IS_IDENTICAL) reduce 448) ((T_IS_NOT_EQUAL) reduce 448) ((T_IS_NOT_IDENTICAL) reduce 448) ((T_IS_SMALLER_OR_EQUAL) reduce 448) ((T_LOGICAL_AND) reduce 448) ((T_LOGICAL_OR) reduce 448) ((T_LOGICAL_XOR) reduce 448) ((T_POW) reduce 448) ((T_SL) reduce 448) ((T_SPACESHIP) reduce 448) ((T_SR) reduce 448) (("^") reduce 448) (("|") reduce 448)) 18661 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) (("<") reduce 521) (("=") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AND_EQUAL) reduce 521) ((T_AS) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_COALESCE_EQUAL) reduce 521) ((T_CONCAT_EQUAL) reduce 521) ((T_DEC) reduce 521) ((T_DIV_EQUAL) reduce 521) ((T_INC) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_MINUS_EQUAL) reduce 521) ((T_MOD_EQUAL) reduce 521) ((T_MUL_EQUAL) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_OR_EQUAL) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_PLUS_EQUAL) reduce 521) ((T_POW) reduce 521) ((T_POW_EQUAL) reduce 521) ((T_SL) reduce 521) ((T_SL_EQUAL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) ((T_SR_EQUAL) reduce 521) ((T_XOR_EQUAL) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 18663 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) (("<") reduce 520) (("=") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AND_EQUAL) reduce 520) ((T_AS) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_COALESCE_EQUAL) reduce 520) ((T_CONCAT_EQUAL) reduce 520) ((T_DEC) reduce 520) ((T_DIV_EQUAL) reduce 520) ((T_INC) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_MINUS_EQUAL) reduce 520) ((T_MOD_EQUAL) reduce 520) ((T_MUL_EQUAL) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_OR_EQUAL) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_PLUS_EQUAL) reduce 520) ((T_POW) reduce 520) ((T_POW_EQUAL) reduce 520) ((T_SL) reduce 520) ((T_SL_EQUAL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) ((T_SR_EQUAL) reduce 520) ((T_XOR_EQUAL) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 18664 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) (("=") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AND_EQUAL) reduce 544) ((T_AS) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_COALESCE_EQUAL) reduce 544) ((T_CONCAT_EQUAL) reduce 544) ((T_DEC) reduce 544) ((T_DIV_EQUAL) reduce 544) ((T_INC) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_MINUS_EQUAL) reduce 544) ((T_MOD_EQUAL) reduce 544) ((T_MUL_EQUAL) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_OR_EQUAL) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_PLUS_EQUAL) reduce 544) ((T_POW) reduce 544) ((T_POW_EQUAL) reduce 544) ((T_SL) reduce 544) ((T_SL_EQUAL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) ((T_SR_EQUAL) reduce 544) ((T_XOR_EQUAL) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 18665 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) (("<") reduce 527) (("=") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AND_EQUAL) reduce 527) ((T_AS) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_COALESCE_EQUAL) reduce 527) ((T_CONCAT_EQUAL) reduce 527) ((T_DEC) reduce 527) ((T_DIV_EQUAL) reduce 527) ((T_INC) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_MINUS_EQUAL) reduce 527) ((T_MOD_EQUAL) reduce 527) ((T_MUL_EQUAL) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_OR_EQUAL) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_PLUS_EQUAL) reduce 527) ((T_POW) reduce 527) ((T_POW_EQUAL) reduce 527) ((T_SL) reduce 527) ((T_SL_EQUAL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) ((T_SR_EQUAL) reduce 527) ((T_XOR_EQUAL) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 18666 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) (("=") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AND_EQUAL) reduce 546) ((T_AS) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_COALESCE_EQUAL) reduce 546) ((T_CONCAT_EQUAL) reduce 546) ((T_DEC) reduce 546) ((T_DIV_EQUAL) reduce 546) ((T_INC) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_MINUS_EQUAL) reduce 546) ((T_MOD_EQUAL) reduce 546) ((T_MUL_EQUAL) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_OR_EQUAL) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_PLUS_EQUAL) reduce 546) ((T_POW) reduce 546) ((T_POW_EQUAL) reduce 546) ((T_SL) reduce 546) ((T_SL_EQUAL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) ((T_SR_EQUAL) reduce 546) ((T_XOR_EQUAL) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 18669 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) (("=") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AND_EQUAL) reduce 545) ((T_AS) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_COALESCE_EQUAL) reduce 545) ((T_CONCAT_EQUAL) reduce 545) ((T_DEC) reduce 545) ((T_DIV_EQUAL) reduce 545) ((T_INC) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_MINUS_EQUAL) reduce 545) ((T_MOD_EQUAL) reduce 545) ((T_MUL_EQUAL) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_OR_EQUAL) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_PLUS_EQUAL) reduce 545) ((T_POW) reduce 545) ((T_POW_EQUAL) reduce 545) ((T_SL) reduce 545) ((T_SL_EQUAL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) ((T_SR_EQUAL) reduce 545) ((T_XOR_EQUAL) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 18670 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) (("<") reduce 522) (("=") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AND_EQUAL) reduce 522) ((T_AS) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_COALESCE_EQUAL) reduce 522) ((T_CONCAT_EQUAL) reduce 522) ((T_DEC) reduce 522) ((T_DIV_EQUAL) reduce 522) ((T_INC) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_MINUS_EQUAL) reduce 522) ((T_MOD_EQUAL) reduce 522) ((T_MUL_EQUAL) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_OR_EQUAL) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_PLUS_EQUAL) reduce 522) ((T_POW) reduce 522) ((T_POW_EQUAL) reduce 522) ((T_SL) reduce 522) ((T_SL_EQUAL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) ((T_SR_EQUAL) reduce 522) ((T_XOR_EQUAL) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 18671 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) (("<") reduce 528) (("=") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AND_EQUAL) reduce 528) ((T_AS) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_COALESCE_EQUAL) reduce 528) ((T_CONCAT_EQUAL) reduce 528) ((T_DEC) reduce 528) ((T_DIV_EQUAL) reduce 528) ((T_INC) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_MINUS_EQUAL) reduce 528) ((T_MOD_EQUAL) reduce 528) ((T_MUL_EQUAL) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_OR_EQUAL) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_PLUS_EQUAL) reduce 528) ((T_POW) reduce 528) ((T_POW_EQUAL) reduce 528) ((T_SL) reduce 528) ((T_SL_EQUAL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) ((T_SR_EQUAL) reduce 528) ((T_XOR_EQUAL) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 18672 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) (("<") reduce 523) (("=") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AND_EQUAL) reduce 523) ((T_AS) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_COALESCE_EQUAL) reduce 523) ((T_CONCAT_EQUAL) reduce 523) ((T_DEC) reduce 523) ((T_DIV_EQUAL) reduce 523) ((T_INC) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_MINUS_EQUAL) reduce 523) ((T_MOD_EQUAL) reduce 523) ((T_MUL_EQUAL) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_OR_EQUAL) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_PLUS_EQUAL) reduce 523) ((T_POW) reduce 523) ((T_POW_EQUAL) reduce 523) ((T_SL) reduce 523) ((T_SL_EQUAL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) ((T_SR_EQUAL) reduce 523) ((T_XOR_EQUAL) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 18674 ((("%") reduce 438) (("*") reduce 438) (("+") reduce 438) (("-") reduce 438) ((".") reduce 438) (("/") reduce 438) (("<") reduce 438) ((">") reduce 438) (("?") reduce 438) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_AS) reduce 438) ((T_BOOLEAN_AND) reduce 438) ((T_BOOLEAN_OR) reduce 438) ((T_COALESCE) reduce 438) ((T_INSTANCEOF) reduce 438) ((T_IS_EQUAL) reduce 438) ((T_IS_GREATER_OR_EQUAL) reduce 438) ((T_IS_IDENTICAL) reduce 438) ((T_IS_NOT_EQUAL) reduce 438) ((T_IS_NOT_IDENTICAL) reduce 438) ((T_IS_SMALLER_OR_EQUAL) reduce 438) ((T_LOGICAL_AND) reduce 438) ((T_LOGICAL_OR) reduce 438) ((T_LOGICAL_XOR) reduce 438) ((T_POW) reduce 438) ((T_SL) reduce 438) ((T_SPACESHIP) reduce 438) ((T_SR) reduce 438) (("^") reduce 438) (("|") reduce 438)) 18676 ((("%") reduce 483) (("(") reduce 483) (("*") reduce 483) (("+") reduce 483) (("-") reduce 483) ((".") reduce 483) (("/") reduce 483) (("<") reduce 483) (("=") shift) ((">") reduce 483) (("?") reduce 483) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_AS) reduce 483) ((T_BOOLEAN_AND) reduce 483) ((T_BOOLEAN_OR) reduce 483) ((T_COALESCE) reduce 483) ((T_INSTANCEOF) reduce 483) ((T_IS_EQUAL) reduce 483) ((T_IS_GREATER_OR_EQUAL) reduce 483) ((T_IS_IDENTICAL) reduce 483) ((T_IS_NOT_EQUAL) reduce 483) ((T_IS_NOT_IDENTICAL) reduce 483) ((T_IS_SMALLER_OR_EQUAL) reduce 483) ((T_LOGICAL_AND) reduce 483) ((T_LOGICAL_OR) reduce 483) ((T_LOGICAL_XOR) reduce 483) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 483) ((T_OBJECT_OPERATOR) reduce 483) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 483) ((T_POW) reduce 483) ((T_SL) reduce 483) ((T_SPACESHIP) reduce 483) ((T_SR) reduce 483) (("[") reduce 483) (("^") reduce 483) (("{") reduce 483) (("|") reduce 483)) 18678 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 369) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 369) ((T_LOGICAL_OR) reduce 369) ((T_LOGICAL_XOR) reduce 369) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18679 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 443) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 443) ((T_LOGICAL_OR) reduce 443) ((T_LOGICAL_XOR) reduce 443) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18690 ((("%") reduce 502) (("*") reduce 502) (("+") reduce 502) (("-") reduce 502) ((".") reduce 502) (("/") reduce 502) (("<") reduce 502) ((">") reduce 502) (("?") reduce 502) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_AS) reduce 502) ((T_BOOLEAN_AND) reduce 502) ((T_BOOLEAN_OR) reduce 502) ((T_COALESCE) reduce 502) ((T_DOUBLE_ARROW) reduce 502) ((T_INSTANCEOF) reduce 502) ((T_IS_EQUAL) reduce 502) ((T_IS_GREATER_OR_EQUAL) reduce 502) ((T_IS_IDENTICAL) reduce 502) ((T_IS_NOT_EQUAL) reduce 502) ((T_IS_NOT_IDENTICAL) reduce 502) ((T_IS_SMALLER_OR_EQUAL) reduce 502) ((T_LOGICAL_AND) reduce 502) ((T_LOGICAL_OR) reduce 502) ((T_LOGICAL_XOR) reduce 502) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 502) ((T_OBJECT_OPERATOR) reduce 502) ((T_POW) reduce 502) ((T_SL) reduce 502) ((T_SPACESHIP) reduce 502) ((T_SR) reduce 502) (("[") reduce 502) (("^") reduce 502) (("{") reduce 502) (("|") reduce 502)) 18692 ((("%") reduce 484) (("(") reduce 484) (("*") reduce 484) (("+") reduce 484) (("-") reduce 484) ((".") reduce 484) (("/") reduce 484) (("<") reduce 484) ((">") reduce 484) (("?") reduce 484) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_AS) reduce 484) ((T_BOOLEAN_AND) reduce 484) ((T_BOOLEAN_OR) reduce 484) ((T_COALESCE) reduce 484) ((T_DOUBLE_ARROW) reduce 484) ((T_INSTANCEOF) reduce 484) ((T_IS_EQUAL) reduce 484) ((T_IS_GREATER_OR_EQUAL) reduce 484) ((T_IS_IDENTICAL) reduce 484) ((T_IS_NOT_EQUAL) reduce 484) ((T_IS_NOT_IDENTICAL) reduce 484) ((T_IS_SMALLER_OR_EQUAL) reduce 484) ((T_LOGICAL_AND) reduce 484) ((T_LOGICAL_OR) reduce 484) ((T_LOGICAL_XOR) reduce 484) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 484) ((T_OBJECT_OPERATOR) reduce 484) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 484) ((T_POW) reduce 484) ((T_SL) reduce 484) ((T_SPACESHIP) reduce 484) ((T_SR) reduce 484) (("[") reduce 484) (("^") reduce 484) (("{") reduce 484) (("|") reduce 484)) 18694 ((("%") reduce 497) (("*") reduce 497) (("+") reduce 497) (("-") reduce 497) ((".") reduce 497) (("/") reduce 497) (("<") reduce 497) ((">") reduce 497) (("?") reduce 497) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_AS) reduce 497) ((T_BOOLEAN_AND) reduce 497) ((T_BOOLEAN_OR) reduce 497) ((T_COALESCE) reduce 497) ((T_DOUBLE_ARROW) reduce 497) ((T_INSTANCEOF) reduce 497) ((T_IS_EQUAL) reduce 497) ((T_IS_GREATER_OR_EQUAL) reduce 497) ((T_IS_IDENTICAL) reduce 497) ((T_IS_NOT_EQUAL) reduce 497) ((T_IS_NOT_IDENTICAL) reduce 497) ((T_IS_SMALLER_OR_EQUAL) reduce 497) ((T_LOGICAL_AND) reduce 497) ((T_LOGICAL_OR) reduce 497) ((T_LOGICAL_XOR) reduce 497) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 497) ((T_OBJECT_OPERATOR) reduce 497) ((T_POW) reduce 497) ((T_SL) reduce 497) ((T_SPACESHIP) reduce 497) ((T_SR) reduce 497) (("[") reduce 497) (("^") reduce 497) (("{") reduce 497) (("|") reduce 497)) 18695 ((("%") reduce 487) (("*") reduce 487) (("+") reduce 487) (("-") reduce 487) ((".") reduce 487) (("/") reduce 487) (("<") reduce 487) ((">") reduce 487) (("?") reduce 487) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_AS) reduce 487) ((T_BOOLEAN_AND) reduce 487) ((T_BOOLEAN_OR) reduce 487) ((T_COALESCE) reduce 487) ((T_DOUBLE_ARROW) reduce 487) ((T_INSTANCEOF) reduce 487) ((T_IS_EQUAL) reduce 487) ((T_IS_GREATER_OR_EQUAL) reduce 487) ((T_IS_IDENTICAL) reduce 487) ((T_IS_NOT_EQUAL) reduce 487) ((T_IS_NOT_IDENTICAL) reduce 487) ((T_IS_SMALLER_OR_EQUAL) reduce 487) ((T_LOGICAL_AND) reduce 487) ((T_LOGICAL_OR) reduce 487) ((T_LOGICAL_XOR) reduce 487) ((T_POW) reduce 487) ((T_SL) reduce 487) ((T_SPACESHIP) reduce 487) ((T_SR) reduce 487) (("^") reduce 487) (("|") reduce 487)) 18699 ((("%") reduce 475) (("(") shift) (("*") reduce 475) (("+") reduce 475) (("-") reduce 475) ((".") reduce 475) (("/") reduce 475) (("<") reduce 475) ((">") reduce 475) (("?") reduce 475) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_AS) reduce 475) ((T_BOOLEAN_AND) reduce 475) ((T_BOOLEAN_OR) reduce 475) ((T_COALESCE) reduce 475) ((T_DOUBLE_ARROW) reduce 475) ((T_INSTANCEOF) reduce 475) ((T_IS_EQUAL) reduce 475) ((T_IS_GREATER_OR_EQUAL) reduce 475) ((T_IS_IDENTICAL) reduce 475) ((T_IS_NOT_EQUAL) reduce 475) ((T_IS_NOT_IDENTICAL) reduce 475) ((T_IS_SMALLER_OR_EQUAL) reduce 475) ((T_LOGICAL_AND) reduce 475) ((T_LOGICAL_OR) reduce 475) ((T_LOGICAL_XOR) reduce 475) ((T_POW) reduce 475) ((T_SL) reduce 475) ((T_SPACESHIP) reduce 475) ((T_SR) reduce 475) (("^") reduce 475) (("|") reduce 475)) 18700 ((("%") reduce 496) (("*") reduce 496) (("+") reduce 496) (("-") reduce 496) ((".") reduce 496) (("/") reduce 496) (("<") reduce 496) ((">") reduce 496) (("?") reduce 496) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_AS) reduce 496) ((T_BOOLEAN_AND) reduce 496) ((T_BOOLEAN_OR) reduce 496) ((T_COALESCE) reduce 496) ((T_DOUBLE_ARROW) reduce 496) ((T_INSTANCEOF) reduce 496) ((T_IS_EQUAL) reduce 496) ((T_IS_GREATER_OR_EQUAL) reduce 496) ((T_IS_IDENTICAL) reduce 496) ((T_IS_NOT_EQUAL) reduce 496) ((T_IS_NOT_IDENTICAL) reduce 496) ((T_IS_SMALLER_OR_EQUAL) reduce 496) ((T_LOGICAL_AND) reduce 496) ((T_LOGICAL_OR) reduce 496) ((T_LOGICAL_XOR) reduce 496) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 496) ((T_OBJECT_OPERATOR) reduce 496) ((T_POW) reduce 496) ((T_SL) reduce 496) ((T_SPACESHIP) reduce 496) ((T_SR) reduce 496) (("[") reduce 496) (("^") reduce 496) (("{") reduce 496) (("|") reduce 496)) 18701 ((("%") reduce 500) (("*") reduce 500) (("+") reduce 500) (("-") reduce 500) ((".") reduce 500) (("/") reduce 500) (("<") reduce 500) ((">") reduce 500) (("?") reduce 500) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_AS) reduce 500) ((T_BOOLEAN_AND) reduce 500) ((T_BOOLEAN_OR) reduce 500) ((T_COALESCE) reduce 500) ((T_DOUBLE_ARROW) reduce 500) ((T_INSTANCEOF) reduce 500) ((T_IS_EQUAL) reduce 500) ((T_IS_GREATER_OR_EQUAL) reduce 500) ((T_IS_IDENTICAL) reduce 500) ((T_IS_NOT_EQUAL) reduce 500) ((T_IS_NOT_IDENTICAL) reduce 500) ((T_IS_SMALLER_OR_EQUAL) reduce 500) ((T_LOGICAL_AND) reduce 500) ((T_LOGICAL_OR) reduce 500) ((T_LOGICAL_XOR) reduce 500) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 500) ((T_OBJECT_OPERATOR) reduce 500) ((T_POW) reduce 500) ((T_SL) reduce 500) ((T_SPACESHIP) reduce 500) ((T_SR) reduce 500) (("[") reduce 500) (("^") reduce 500) (("{") reduce 500) (("|") reduce 500)) 18707 ((("%") reduce 495) (("*") reduce 495) (("+") reduce 495) (("-") reduce 495) ((".") reduce 495) (("/") reduce 495) (("<") reduce 495) ((">") reduce 495) (("?") reduce 495) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_AS) reduce 495) ((T_BOOLEAN_AND) reduce 495) ((T_BOOLEAN_OR) reduce 495) ((T_COALESCE) reduce 495) ((T_DOUBLE_ARROW) reduce 495) ((T_INSTANCEOF) reduce 495) ((T_IS_EQUAL) reduce 495) ((T_IS_GREATER_OR_EQUAL) reduce 495) ((T_IS_IDENTICAL) reduce 495) ((T_IS_NOT_EQUAL) reduce 495) ((T_IS_NOT_IDENTICAL) reduce 495) ((T_IS_SMALLER_OR_EQUAL) reduce 495) ((T_LOGICAL_AND) reduce 495) ((T_LOGICAL_OR) reduce 495) ((T_LOGICAL_XOR) reduce 495) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 495) ((T_OBJECT_OPERATOR) reduce 495) ((T_POW) reduce 495) ((T_SL) reduce 495) ((T_SPACESHIP) reduce 495) ((T_SR) reduce 495) (("[") reduce 495) (("^") reduce 495) (("{") reduce 495) (("|") reduce 495)) 18709 ((("%") reduce 486) (("*") reduce 486) (("+") reduce 486) (("-") reduce 486) ((".") reduce 486) (("/") reduce 486) (("<") reduce 486) ((">") reduce 486) (("?") reduce 486) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_AS) reduce 486) ((T_BOOLEAN_AND) reduce 486) ((T_BOOLEAN_OR) reduce 486) ((T_COALESCE) reduce 486) ((T_DOUBLE_ARROW) reduce 486) ((T_INSTANCEOF) reduce 486) ((T_IS_EQUAL) reduce 486) ((T_IS_GREATER_OR_EQUAL) reduce 486) ((T_IS_IDENTICAL) reduce 486) ((T_IS_NOT_EQUAL) reduce 486) ((T_IS_NOT_IDENTICAL) reduce 486) ((T_IS_SMALLER_OR_EQUAL) reduce 486) ((T_LOGICAL_AND) reduce 486) ((T_LOGICAL_OR) reduce 486) ((T_LOGICAL_XOR) reduce 486) ((T_POW) reduce 486) ((T_SL) reduce 486) ((T_SPACESHIP) reduce 486) ((T_SR) reduce 486) (("^") reduce 486) (("|") reduce 486)) 18711 ((("%") reduce 499) (("*") reduce 499) (("+") reduce 499) (("-") reduce 499) ((".") reduce 499) (("/") reduce 499) (("<") reduce 499) ((">") reduce 499) (("?") reduce 499) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_AS) reduce 499) ((T_BOOLEAN_AND) reduce 499) ((T_BOOLEAN_OR) reduce 499) ((T_COALESCE) reduce 499) ((T_DOUBLE_ARROW) reduce 499) ((T_INSTANCEOF) reduce 499) ((T_IS_EQUAL) reduce 499) ((T_IS_GREATER_OR_EQUAL) reduce 499) ((T_IS_IDENTICAL) reduce 499) ((T_IS_NOT_EQUAL) reduce 499) ((T_IS_NOT_IDENTICAL) reduce 499) ((T_IS_SMALLER_OR_EQUAL) reduce 499) ((T_LOGICAL_AND) reduce 499) ((T_LOGICAL_OR) reduce 499) ((T_LOGICAL_XOR) reduce 499) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 499) ((T_OBJECT_OPERATOR) reduce 499) ((T_POW) reduce 499) ((T_SL) reduce 499) ((T_SPACESHIP) reduce 499) ((T_SR) reduce 499) (("[") reduce 499) (("^") reduce 499) (("{") reduce 499) (("|") reduce 499)) 18712 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AS) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 93) ((T_OBJECT_OPERATOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("[") reduce 93) (("^") reduce 93) (("{") reduce 93) (("|") reduce 93)) 18713 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AS) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 92) ((T_OBJECT_OPERATOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("[") reduce 92) (("^") reduce 92) (("{") reduce 92) (("|") reduce 92)) 18714 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AS) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 94) ((T_OBJECT_OPERATOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("[") reduce 94) (("^") reduce 94) (("{") reduce 94) (("|") reduce 94)) 18716 ((("%") reduce 501) (("*") reduce 501) (("+") reduce 501) (("-") reduce 501) ((".") reduce 501) (("/") reduce 501) (("<") reduce 501) ((">") reduce 501) (("?") reduce 501) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_AS) reduce 501) ((T_BOOLEAN_AND) reduce 501) ((T_BOOLEAN_OR) reduce 501) ((T_COALESCE) reduce 501) ((T_DOUBLE_ARROW) reduce 501) ((T_INSTANCEOF) reduce 501) ((T_IS_EQUAL) reduce 501) ((T_IS_GREATER_OR_EQUAL) reduce 501) ((T_IS_IDENTICAL) reduce 501) ((T_IS_NOT_EQUAL) reduce 501) ((T_IS_NOT_IDENTICAL) reduce 501) ((T_IS_SMALLER_OR_EQUAL) reduce 501) ((T_LOGICAL_AND) reduce 501) ((T_LOGICAL_OR) reduce 501) ((T_LOGICAL_XOR) reduce 501) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 501) ((T_OBJECT_OPERATOR) reduce 501) ((T_POW) reduce 501) ((T_SL) reduce 501) ((T_SPACESHIP) reduce 501) ((T_SR) reduce 501) (("[") reduce 501) (("^") reduce 501) (("{") reduce 501) (("|") reduce 501)) 18724 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AS) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 91) ((T_OBJECT_OPERATOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("[") reduce 91) (("^") reduce 91) (("{") reduce 91) (("|") reduce 91)) 18727 ((("%") reduce 498) (("*") reduce 498) (("+") reduce 498) (("-") reduce 498) ((".") reduce 498) (("/") reduce 498) (("<") reduce 498) ((">") reduce 498) (("?") reduce 498) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_AS) reduce 498) ((T_BOOLEAN_AND) reduce 498) ((T_BOOLEAN_OR) reduce 498) ((T_COALESCE) reduce 498) ((T_DOUBLE_ARROW) reduce 498) ((T_INSTANCEOF) reduce 498) ((T_IS_EQUAL) reduce 498) ((T_IS_GREATER_OR_EQUAL) reduce 498) ((T_IS_IDENTICAL) reduce 498) ((T_IS_NOT_EQUAL) reduce 498) ((T_IS_NOT_IDENTICAL) reduce 498) ((T_IS_SMALLER_OR_EQUAL) reduce 498) ((T_LOGICAL_AND) reduce 498) ((T_LOGICAL_OR) reduce 498) ((T_LOGICAL_XOR) reduce 498) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 498) ((T_OBJECT_OPERATOR) reduce 498) ((T_POW) reduce 498) ((T_SL) reduce 498) ((T_SPACESHIP) reduce 498) ((T_SR) reduce 498) (("[") reduce 498) (("^") reduce 498) (("{") reduce 498) (("|") reduce 498)) 18729 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) (("=") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AND_EQUAL) reduce 529) ((T_AS) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_COALESCE_EQUAL) reduce 529) ((T_CONCAT_EQUAL) reduce 529) ((T_DEC) reduce 529) ((T_DIV_EQUAL) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INC) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_MINUS_EQUAL) reduce 529) ((T_MOD_EQUAL) reduce 529) ((T_MUL_EQUAL) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_OR_EQUAL) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_PLUS_EQUAL) reduce 529) ((T_POW) reduce 529) ((T_POW_EQUAL) reduce 529) ((T_SL) reduce 529) ((T_SL_EQUAL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) ((T_SR_EQUAL) reduce 529) ((T_XOR_EQUAL) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 18730 ((("!") shift) (("\"") shift) (("$") shift) (("%") reduce 440) (("(") shift) (("*") reduce 440) (("+") shift) (("-") shift) ((".") reduce 440) (("/") reduce 440) (("<") reduce 440) ((">") reduce 440) (("?") reduce 440) (("@") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_AS) reduce 440) ((T_ATTRIBUTE) shift) ((T_BOOLEAN_AND) reduce 440) ((T_BOOLEAN_OR) reduce 440) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_COALESCE) reduce 440) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_ARROW) reduce 440) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INSTANCEOF) reduce 440) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_IS_EQUAL) reduce 440) ((T_IS_GREATER_OR_EQUAL) reduce 440) ((T_IS_IDENTICAL) reduce 440) ((T_IS_NOT_EQUAL) reduce 440) ((T_IS_NOT_IDENTICAL) reduce 440) ((T_IS_SMALLER_OR_EQUAL) reduce 440) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_LOGICAL_AND) reduce 440) ((T_LOGICAL_OR) reduce 440) ((T_LOGICAL_XOR) reduce 440) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_POW) reduce 440) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_SL) reduce 440) ((T_SPACESHIP) reduce 440) ((T_SR) reduce 440) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("^") reduce 440) (("`") shift) (("|") reduce 440) (("~") shift)) 18737 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) (("<") reduce 525) (("=") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AND_EQUAL) reduce 525) ((T_AS) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_COALESCE_EQUAL) reduce 525) ((T_CONCAT_EQUAL) reduce 525) ((T_DEC) reduce 525) ((T_DIV_EQUAL) reduce 525) ((T_DOUBLE_ARROW) reduce 525) ((T_INC) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_MINUS_EQUAL) reduce 525) ((T_MOD_EQUAL) reduce 525) ((T_MUL_EQUAL) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_OR_EQUAL) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_PLUS_EQUAL) reduce 525) ((T_POW) reduce 525) ((T_POW_EQUAL) reduce 525) ((T_SL) reduce 525) ((T_SL_EQUAL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) ((T_SR_EQUAL) reduce 525) ((T_XOR_EQUAL) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 18738 ((("%") reduce 493) (("*") reduce 493) (("+") reduce 493) (("-") reduce 493) ((".") reduce 493) (("/") reduce 493) (("<") reduce 493) ((">") reduce 493) (("?") reduce 493) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_AS) reduce 493) ((T_BOOLEAN_AND) reduce 493) ((T_BOOLEAN_OR) reduce 493) ((T_COALESCE) reduce 493) ((T_DOUBLE_ARROW) reduce 493) ((T_INSTANCEOF) reduce 493) ((T_IS_EQUAL) reduce 493) ((T_IS_GREATER_OR_EQUAL) reduce 493) ((T_IS_IDENTICAL) reduce 493) ((T_IS_NOT_EQUAL) reduce 493) ((T_IS_NOT_IDENTICAL) reduce 493) ((T_IS_SMALLER_OR_EQUAL) reduce 493) ((T_LOGICAL_AND) reduce 493) ((T_LOGICAL_OR) reduce 493) ((T_LOGICAL_XOR) reduce 493) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 513) ((T_OBJECT_OPERATOR) reduce 513) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 513) ((T_POW) reduce 493) ((T_SL) reduce 493) ((T_SPACESHIP) reduce 493) ((T_SR) reduce 493) (("[") reduce 513) (("^") reduce 493) (("{") reduce 513) (("|") reduce 493)) 18740 ((("%") reduce 492) (("*") reduce 492) (("+") reduce 492) (("-") reduce 492) ((".") reduce 492) (("/") reduce 492) (("<") reduce 492) ((">") reduce 492) (("?") reduce 492) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_AS) reduce 492) ((T_BOOLEAN_AND) reduce 492) ((T_BOOLEAN_OR) reduce 492) ((T_COALESCE) reduce 492) ((T_DOUBLE_ARROW) reduce 492) ((T_INSTANCEOF) reduce 492) ((T_IS_EQUAL) reduce 492) ((T_IS_GREATER_OR_EQUAL) reduce 492) ((T_IS_IDENTICAL) reduce 492) ((T_IS_NOT_EQUAL) reduce 492) ((T_IS_NOT_IDENTICAL) reduce 492) ((T_IS_SMALLER_OR_EQUAL) reduce 492) ((T_LOGICAL_AND) reduce 492) ((T_LOGICAL_OR) reduce 492) ((T_LOGICAL_XOR) reduce 492) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 515) ((T_OBJECT_OPERATOR) reduce 515) ((T_POW) reduce 492) ((T_SL) reduce 492) ((T_SPACESHIP) reduce 492) ((T_SR) reduce 492) (("[") reduce 515) (("^") reduce 492) (("{") reduce 515) (("|") reduce 492)) 18741 ((("%") reduce 491) (("(") reduce 518) (("*") reduce 491) (("+") reduce 491) (("-") reduce 491) ((".") reduce 491) (("/") reduce 491) (("<") reduce 491) ((">") reduce 491) (("?") reduce 491) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_AS) reduce 491) ((T_BOOLEAN_AND) reduce 491) ((T_BOOLEAN_OR) reduce 491) ((T_COALESCE) reduce 491) ((T_DOUBLE_ARROW) reduce 491) ((T_INSTANCEOF) reduce 491) ((T_IS_EQUAL) reduce 491) ((T_IS_GREATER_OR_EQUAL) reduce 491) ((T_IS_IDENTICAL) reduce 491) ((T_IS_NOT_EQUAL) reduce 491) ((T_IS_NOT_IDENTICAL) reduce 491) ((T_IS_SMALLER_OR_EQUAL) reduce 491) ((T_LOGICAL_AND) reduce 491) ((T_LOGICAL_OR) reduce 491) ((T_LOGICAL_XOR) reduce 491) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 512) ((T_OBJECT_OPERATOR) reduce 512) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 512) ((T_POW) reduce 491) ((T_SL) reduce 491) ((T_SPACESHIP) reduce 491) ((T_SR) reduce 491) (("[") reduce 512) (("^") reduce 491) (("{") reduce 512) (("|") reduce 491)) 18742 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 441) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 441) ((T_LOGICAL_OR) reduce 441) ((T_LOGICAL_XOR) reduce 441) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18745 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) (("<") reduce 524) (("=") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AND_EQUAL) reduce 524) ((T_AS) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_COALESCE_EQUAL) reduce 524) ((T_CONCAT_EQUAL) reduce 524) ((T_DEC) reduce 524) ((T_DIV_EQUAL) reduce 524) ((T_DOUBLE_ARROW) reduce 524) ((T_INC) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_MINUS_EQUAL) reduce 524) ((T_MOD_EQUAL) reduce 524) ((T_MUL_EQUAL) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_OR_EQUAL) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_PLUS_EQUAL) reduce 524) ((T_POW) reduce 524) ((T_POW_EQUAL) reduce 524) ((T_SL) reduce 524) ((T_SL_EQUAL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) ((T_SR_EQUAL) reduce 524) ((T_XOR_EQUAL) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 18746 ((("%") reduce 445) (("*") reduce 445) (("+") reduce 445) (("-") reduce 445) ((".") reduce 445) (("/") reduce 445) (("<") reduce 445) ((">") reduce 445) (("?") reduce 445) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_AS) reduce 445) ((T_BOOLEAN_AND) reduce 445) ((T_BOOLEAN_OR) reduce 445) ((T_COALESCE) reduce 445) ((T_DOUBLE_ARROW) reduce 445) ((T_INSTANCEOF) reduce 445) ((T_IS_EQUAL) reduce 445) ((T_IS_GREATER_OR_EQUAL) reduce 445) ((T_IS_IDENTICAL) reduce 445) ((T_IS_NOT_EQUAL) reduce 445) ((T_IS_NOT_IDENTICAL) reduce 445) ((T_IS_SMALLER_OR_EQUAL) reduce 445) ((T_LOGICAL_AND) reduce 445) ((T_LOGICAL_OR) reduce 445) ((T_LOGICAL_XOR) reduce 445) ((T_POW) reduce 445) ((T_SL) reduce 445) ((T_SPACESHIP) reduce 445) ((T_SR) reduce 445) (("^") reduce 445) (("|") reduce 445)) 18747 ((("%") reduce 427) (("*") reduce 427) (("+") reduce 427) (("-") reduce 427) ((".") reduce 427) (("/") reduce 427) (("<") reduce 427) ((">") reduce 427) (("?") reduce 427) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_AS) reduce 427) ((T_BOOLEAN_AND) reduce 427) ((T_BOOLEAN_OR) reduce 427) ((T_COALESCE) reduce 427) ((T_DOUBLE_ARROW) reduce 427) ((T_INSTANCEOF) reduce 427) ((T_IS_EQUAL) reduce 427) ((T_IS_GREATER_OR_EQUAL) reduce 427) ((T_IS_IDENTICAL) reduce 427) ((T_IS_NOT_EQUAL) reduce 427) ((T_IS_NOT_IDENTICAL) reduce 427) ((T_IS_SMALLER_OR_EQUAL) reduce 427) ((T_LOGICAL_AND) reduce 427) ((T_LOGICAL_OR) reduce 427) ((T_LOGICAL_XOR) reduce 427) ((T_POW) reduce 427) ((T_SL) reduce 427) ((T_SPACESHIP) reduce 427) ((T_SR) reduce 427) (("^") reduce 427) (("|") reduce 427)) 18748 ((("%") reduce 449) (("*") reduce 449) (("+") reduce 449) (("-") reduce 449) ((".") reduce 449) (("/") reduce 449) (("<") reduce 449) ((">") reduce 449) (("?") reduce 449) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_AS) reduce 449) ((T_BOOLEAN_AND) reduce 449) ((T_BOOLEAN_OR) reduce 449) ((T_COALESCE) reduce 449) ((T_DOUBLE_ARROW) reduce 449) ((T_INSTANCEOF) reduce 449) ((T_IS_EQUAL) reduce 449) ((T_IS_GREATER_OR_EQUAL) reduce 449) ((T_IS_IDENTICAL) reduce 449) ((T_IS_NOT_EQUAL) reduce 449) ((T_IS_NOT_IDENTICAL) reduce 449) ((T_IS_SMALLER_OR_EQUAL) reduce 449) ((T_LOGICAL_AND) reduce 449) ((T_LOGICAL_OR) reduce 449) ((T_LOGICAL_XOR) reduce 449) ((T_POW) reduce 449) ((T_SL) reduce 449) ((T_SPACESHIP) reduce 449) ((T_SR) reduce 449) (("^") reduce 449) (("|") reduce 449)) 18749 ((("%") reduce 494) (("(") shift) (("*") reduce 494) (("+") reduce 494) (("-") reduce 494) ((".") reduce 494) (("/") reduce 494) (("<") reduce 494) ((">") reduce 494) (("?") reduce 494) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_AS) reduce 494) ((T_BOOLEAN_AND) reduce 494) ((T_BOOLEAN_OR) reduce 494) ((T_COALESCE) reduce 494) ((T_DOUBLE_ARROW) reduce 494) ((T_INSTANCEOF) reduce 494) ((T_IS_EQUAL) reduce 494) ((T_IS_GREATER_OR_EQUAL) reduce 494) ((T_IS_IDENTICAL) reduce 494) ((T_IS_NOT_EQUAL) reduce 494) ((T_IS_NOT_IDENTICAL) reduce 494) ((T_IS_SMALLER_OR_EQUAL) reduce 494) ((T_LOGICAL_AND) reduce 494) ((T_LOGICAL_OR) reduce 494) ((T_LOGICAL_XOR) reduce 494) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 494) ((T_OBJECT_OPERATOR) reduce 494) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 494) ((T_SL) reduce 494) ((T_SPACESHIP) reduce 494) ((T_SR) reduce 494) (("[") reduce 494) (("^") reduce 494) (("{") reduce 494) (("|") reduce 494)) 18750 ((("%") reduce 423) (("*") reduce 423) (("+") reduce 423) (("-") reduce 423) ((".") reduce 423) (("/") reduce 423) (("<") reduce 423) ((">") reduce 423) (("?") reduce 423) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_AS) reduce 423) ((T_BOOLEAN_AND) reduce 423) ((T_BOOLEAN_OR) reduce 423) ((T_COALESCE) reduce 423) ((T_DOUBLE_ARROW) reduce 423) ((T_INSTANCEOF) reduce 423) ((T_IS_EQUAL) reduce 423) ((T_IS_GREATER_OR_EQUAL) reduce 423) ((T_IS_IDENTICAL) reduce 423) ((T_IS_NOT_EQUAL) reduce 423) ((T_IS_NOT_IDENTICAL) reduce 423) ((T_IS_SMALLER_OR_EQUAL) reduce 423) ((T_LOGICAL_AND) reduce 423) ((T_LOGICAL_OR) reduce 423) ((T_LOGICAL_XOR) reduce 423) ((T_POW) reduce 423) ((T_SL) reduce 423) ((T_SPACESHIP) reduce 423) ((T_SR) reduce 423) (("^") reduce 423) (("|") reduce 423)) 18751 ((("%") reduce 437) (("*") reduce 437) (("+") reduce 437) (("-") reduce 437) ((".") reduce 437) (("/") reduce 437) (("<") reduce 437) ((">") reduce 437) (("?") reduce 437) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_AS) reduce 437) ((T_BOOLEAN_AND) reduce 437) ((T_BOOLEAN_OR) reduce 437) ((T_COALESCE) reduce 437) ((T_DOUBLE_ARROW) reduce 437) ((T_INSTANCEOF) reduce 437) ((T_IS_EQUAL) reduce 437) ((T_IS_GREATER_OR_EQUAL) reduce 437) ((T_IS_IDENTICAL) reduce 437) ((T_IS_NOT_EQUAL) reduce 437) ((T_IS_NOT_IDENTICAL) reduce 437) ((T_IS_SMALLER_OR_EQUAL) reduce 437) ((T_LOGICAL_AND) reduce 437) ((T_LOGICAL_OR) reduce 437) ((T_LOGICAL_XOR) reduce 437) ((T_POW) reduce 437) ((T_SL) reduce 437) ((T_SPACESHIP) reduce 437) ((T_SR) reduce 437) (("^") reduce 437) (("|") reduce 437)) 18752 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) (("<") reduce 519) (("=") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AND_EQUAL) reduce 519) ((T_AS) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_COALESCE_EQUAL) reduce 519) ((T_CONCAT_EQUAL) reduce 519) ((T_DEC) reduce 519) ((T_DIV_EQUAL) reduce 519) ((T_DOUBLE_ARROW) reduce 519) ((T_INC) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_MINUS_EQUAL) reduce 519) ((T_MOD_EQUAL) reduce 519) ((T_MUL_EQUAL) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_OR_EQUAL) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_PLUS_EQUAL) reduce 519) ((T_POW) reduce 519) ((T_POW_EQUAL) reduce 519) ((T_SL) reduce 519) ((T_SL_EQUAL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) ((T_SR_EQUAL) reduce 519) ((T_XOR_EQUAL) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 18753 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) (("<") reduce 526) (("=") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AND_EQUAL) reduce 526) ((T_AS) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_COALESCE_EQUAL) reduce 526) ((T_CONCAT_EQUAL) reduce 526) ((T_DEC) reduce 526) ((T_DIV_EQUAL) reduce 526) ((T_DOUBLE_ARROW) reduce 526) ((T_INC) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_MINUS_EQUAL) reduce 526) ((T_MOD_EQUAL) reduce 526) ((T_MUL_EQUAL) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_OR_EQUAL) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_PLUS_EQUAL) reduce 526) ((T_POW) reduce 526) ((T_POW_EQUAL) reduce 526) ((T_SL) reduce 526) ((T_SL_EQUAL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) ((T_SR_EQUAL) reduce 526) ((T_XOR_EQUAL) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 18754 ((("%") reduce 367) (("*") reduce 367) (("+") reduce 367) (("-") reduce 367) ((".") reduce 367) (("/") reduce 367) (("<") reduce 367) (("=") shift) ((">") reduce 367) (("?") reduce 367) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AND_EQUAL) shift) ((T_AS) reduce 367) ((T_BOOLEAN_AND) reduce 367) ((T_BOOLEAN_OR) reduce 367) ((T_COALESCE) reduce 367) ((T_COALESCE_EQUAL) shift) ((T_CONCAT_EQUAL) shift) ((T_DEC) shift) ((T_DIV_EQUAL) shift) ((T_DOUBLE_ARROW) reduce 367) ((T_INC) shift) ((T_INSTANCEOF) reduce 367) ((T_IS_EQUAL) reduce 367) ((T_IS_GREATER_OR_EQUAL) reduce 367) ((T_IS_IDENTICAL) reduce 367) ((T_IS_NOT_EQUAL) reduce 367) ((T_IS_NOT_IDENTICAL) reduce 367) ((T_IS_SMALLER_OR_EQUAL) reduce 367) ((T_LOGICAL_AND) reduce 367) ((T_LOGICAL_OR) reduce 367) ((T_LOGICAL_XOR) reduce 367) ((T_MINUS_EQUAL) shift) ((T_MOD_EQUAL) shift) ((T_MUL_EQUAL) shift) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_OR_EQUAL) shift) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_PLUS_EQUAL) shift) ((T_POW) reduce 367) ((T_POW_EQUAL) shift) ((T_SL) reduce 367) ((T_SL_EQUAL) shift) ((T_SPACESHIP) reduce 367) ((T_SR) reduce 367) ((T_SR_EQUAL) shift) ((T_XOR_EQUAL) shift) (("[") reduce 510) (("^") reduce 367) (("{") reduce 510) (("|") reduce 367)) 18757 ((("%") reduce 411) (("*") reduce 411) (("+") reduce 411) (("-") reduce 411) ((".") reduce 411) (("/") reduce 411) (("<") reduce 411) ((">") reduce 411) (("?") reduce 411) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_AS) reduce 411) ((T_BOOLEAN_AND) reduce 411) ((T_BOOLEAN_OR) reduce 411) ((T_COALESCE) reduce 411) ((T_DOUBLE_ARROW) reduce 411) ((T_INSTANCEOF) reduce 411) ((T_IS_EQUAL) reduce 411) ((T_IS_GREATER_OR_EQUAL) reduce 411) ((T_IS_IDENTICAL) reduce 411) ((T_IS_NOT_EQUAL) reduce 411) ((T_IS_NOT_IDENTICAL) reduce 411) ((T_IS_SMALLER_OR_EQUAL) reduce 411) ((T_LOGICAL_AND) reduce 411) ((T_LOGICAL_OR) reduce 411) ((T_LOGICAL_XOR) reduce 411) ((T_POW) shift) ((T_SL) reduce 411) ((T_SPACESHIP) reduce 411) ((T_SR) reduce 411) (("^") reduce 411) (("|") reduce 411)) 18788 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 395) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 395) ((T_BOOLEAN_AND) reduce 395) ((T_BOOLEAN_OR) reduce 395) ((T_COALESCE) reduce 395) ((T_DOUBLE_ARROW) reduce 395) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 395) ((T_LOGICAL_OR) reduce 395) ((T_LOGICAL_XOR) reduce 395) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") reduce 395)) 18789 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 398) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 398) ((T_BOOLEAN_AND) reduce 398) ((T_BOOLEAN_OR) reduce 398) ((T_COALESCE) reduce 398) ((T_DOUBLE_ARROW) reduce 398) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 398) ((T_LOGICAL_OR) reduce 398) ((T_LOGICAL_XOR) reduce 398) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 398) (("|") reduce 398)) 18790 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 407) (("/") shift) (("<") reduce 407) ((">") reduce 407) (("?") reduce 407) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_AS) reduce 407) ((T_BOOLEAN_AND) reduce 407) ((T_BOOLEAN_OR) reduce 407) ((T_COALESCE) reduce 407) ((T_DOUBLE_ARROW) reduce 407) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 407) ((T_IS_GREATER_OR_EQUAL) reduce 407) ((T_IS_IDENTICAL) reduce 407) ((T_IS_NOT_EQUAL) reduce 407) ((T_IS_NOT_IDENTICAL) reduce 407) ((T_IS_SMALLER_OR_EQUAL) reduce 407) ((T_LOGICAL_AND) reduce 407) ((T_LOGICAL_OR) reduce 407) ((T_LOGICAL_XOR) reduce 407) ((T_POW) shift) ((T_SL) reduce 407) ((T_SPACESHIP) reduce 407) ((T_SR) reduce 407) (("^") reduce 407) (("|") reduce 407)) 18791 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 420) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_AS) reduce 420) ((T_BOOLEAN_AND) reduce 420) ((T_BOOLEAN_OR) reduce 420) ((T_COALESCE) reduce 420) ((T_DOUBLE_ARROW) reduce 420) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 420) ((T_LOGICAL_OR) reduce 420) ((T_LOGICAL_XOR) reduce 420) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 420) (("|") reduce 420)) 18792 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 406) (("/") shift) (("<") reduce 406) ((">") reduce 406) (("?") reduce 406) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_AS) reduce 406) ((T_BOOLEAN_AND) reduce 406) ((T_BOOLEAN_OR) reduce 406) ((T_COALESCE) reduce 406) ((T_DOUBLE_ARROW) reduce 406) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 406) ((T_IS_GREATER_OR_EQUAL) reduce 406) ((T_IS_IDENTICAL) reduce 406) ((T_IS_NOT_EQUAL) reduce 406) ((T_IS_NOT_IDENTICAL) reduce 406) ((T_IS_SMALLER_OR_EQUAL) reduce 406) ((T_LOGICAL_AND) reduce 406) ((T_LOGICAL_OR) reduce 406) ((T_LOGICAL_XOR) reduce 406) ((T_POW) shift) ((T_SL) reduce 406) ((T_SPACESHIP) reduce 406) ((T_SR) reduce 406) (("^") reduce 406) (("|") reduce 406)) 18793 ((("%") reduce 403) (("*") reduce 403) (("+") reduce 403) (("-") reduce 403) ((".") reduce 403) (("/") reduce 403) (("<") reduce 403) ((">") reduce 403) (("?") reduce 403) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_AS) reduce 403) ((T_BOOLEAN_AND) reduce 403) ((T_BOOLEAN_OR) reduce 403) ((T_COALESCE) reduce 403) ((T_DOUBLE_ARROW) reduce 403) ((T_INSTANCEOF) reduce 403) ((T_IS_EQUAL) reduce 403) ((T_IS_GREATER_OR_EQUAL) reduce 403) ((T_IS_IDENTICAL) reduce 403) ((T_IS_NOT_EQUAL) reduce 403) ((T_IS_NOT_IDENTICAL) reduce 403) ((T_IS_SMALLER_OR_EQUAL) reduce 403) ((T_LOGICAL_AND) reduce 403) ((T_LOGICAL_OR) reduce 403) ((T_LOGICAL_XOR) reduce 403) ((T_POW) shift) ((T_SL) reduce 403) ((T_SPACESHIP) reduce 403) ((T_SR) reduce 403) (("^") reduce 403) (("|") reduce 403)) 18794 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 394) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 394) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 394) ((T_LOGICAL_XOR) reduce 394) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18795 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 392) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 392) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 392) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18796 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 393) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 393) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 393) ((T_LOGICAL_OR) reduce 393) ((T_LOGICAL_XOR) reduce 393) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18797 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 417) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_AS) reduce 417) ((T_BOOLEAN_AND) reduce 417) ((T_BOOLEAN_OR) reduce 417) ((T_COALESCE) reduce 417) ((T_DOUBLE_ARROW) reduce 417) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 417) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 417) ((T_IS_NOT_EQUAL) reduce 417) ((T_IS_NOT_IDENTICAL) reduce 417) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 417) ((T_LOGICAL_OR) reduce 417) ((T_LOGICAL_XOR) reduce 417) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 417) ((T_SR) shift) (("^") reduce 417) (("|") reduce 417)) 18798 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 413) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_AS) reduce 413) ((T_BOOLEAN_AND) reduce 413) ((T_BOOLEAN_OR) reduce 413) ((T_COALESCE) reduce 413) ((T_DOUBLE_ARROW) reduce 413) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 413) ((T_LOGICAL_OR) reduce 413) ((T_LOGICAL_XOR) reduce 413) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 413) (("|") reduce 413)) 18799 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 415) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_AS) reduce 415) ((T_BOOLEAN_AND) reduce 415) ((T_BOOLEAN_OR) reduce 415) ((T_COALESCE) reduce 415) ((T_DOUBLE_ARROW) reduce 415) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 415) ((T_LOGICAL_OR) reduce 415) ((T_LOGICAL_XOR) reduce 415) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 415) (("|") reduce 415)) 18800 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 412) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_AS) reduce 412) ((T_BOOLEAN_AND) reduce 412) ((T_BOOLEAN_OR) reduce 412) ((T_COALESCE) reduce 412) ((T_DOUBLE_ARROW) reduce 412) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 412) ((T_LOGICAL_OR) reduce 412) ((T_LOGICAL_XOR) reduce 412) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 412) (("|") reduce 412)) 18801 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 419) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_AS) reduce 419) ((T_BOOLEAN_AND) reduce 419) ((T_BOOLEAN_OR) reduce 419) ((T_COALESCE) reduce 419) ((T_DOUBLE_ARROW) reduce 419) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 419) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 419) ((T_IS_NOT_EQUAL) reduce 419) ((T_IS_NOT_IDENTICAL) reduce 419) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 419) ((T_LOGICAL_OR) reduce 419) ((T_LOGICAL_XOR) reduce 419) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 419) ((T_SR) shift) (("^") reduce 419) (("|") reduce 419)) 18802 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 414) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_AS) reduce 414) ((T_BOOLEAN_AND) reduce 414) ((T_BOOLEAN_OR) reduce 414) ((T_COALESCE) reduce 414) ((T_DOUBLE_ARROW) reduce 414) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 414) ((T_LOGICAL_OR) reduce 414) ((T_LOGICAL_XOR) reduce 414) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 414) (("|") reduce 414)) 18805 ((("%") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AS) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93)) 18806 ((("%") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AS) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92)) 18807 ((("%") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AS) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94)) 18808 ((("%") reduce 470) (("*") reduce 470) (("+") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AS) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_DOUBLE_ARROW) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470)) 18809 ((("%") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AS) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91)) 18810 ((("%") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AS) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 18811 ((("%") reduce 472) (("*") reduce 472) (("+") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AS) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_DOUBLE_ARROW) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472)) 18812 ((("%") reduce 421) (("*") reduce 421) (("+") reduce 421) (("-") reduce 421) ((".") reduce 421) (("/") reduce 421) (("<") reduce 421) ((">") reduce 421) (("?") reduce 421) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_AS) reduce 421) ((T_BOOLEAN_AND) reduce 421) ((T_BOOLEAN_OR) reduce 421) ((T_COALESCE) reduce 421) ((T_DOUBLE_ARROW) reduce 421) ((T_INSTANCEOF) reduce 421) ((T_IS_EQUAL) reduce 421) ((T_IS_GREATER_OR_EQUAL) reduce 421) ((T_IS_IDENTICAL) reduce 421) ((T_IS_NOT_EQUAL) reduce 421) ((T_IS_NOT_IDENTICAL) reduce 421) ((T_IS_SMALLER_OR_EQUAL) reduce 421) ((T_LOGICAL_AND) reduce 421) ((T_LOGICAL_OR) reduce 421) ((T_LOGICAL_XOR) reduce 421) ((T_POW) reduce 421) ((T_SL) reduce 421) ((T_SPACESHIP) reduce 421) ((T_SR) reduce 421) (("^") reduce 421) (("|") reduce 421)) 18813 ((("%") reduce 471) (("*") reduce 471) (("+") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AS) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_DOUBLE_ARROW) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471)) 18814 ((("%") reduce 473) (("*") reduce 473) (("+") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AS) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_DOUBLE_ARROW) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 18815 ((("%") reduce 534) (("*") reduce 534) (("+") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AS) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_DOUBLE_ARROW) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 18822 ((("%") reduce 536) (("*") reduce 536) (("+") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AS) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_DOUBLE_ARROW) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 18824 ((("%") reduce 535) (("*") reduce 535) (("+") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AS) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_DOUBLE_ARROW) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 18825 ((("%") reduce 540) (("*") reduce 540) (("+") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AS) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_DOUBLE_ARROW) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 18826 ((("%") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AS) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 18827 ((("%") reduce 537) (("*") reduce 537) (("+") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AS) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_DOUBLE_ARROW) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 18828 ((("%") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AS) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 18831 ((("%") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AS) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 18832 ((("%") reduce 538) (("*") reduce 538) (("+") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AS) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_DOUBLE_ARROW) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 18834 ((("%") reduce 539) (("*") reduce 539) (("+") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AS) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_DOUBLE_ARROW) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 18836 ((("%") reduce 474) (("*") reduce 474) (("+") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AS) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_DOUBLE_ARROW) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474)) 18837 ((("%") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AS) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 18840 ((("%") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AS) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 18841 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 426) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 426) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 426) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 426) ((T_LOGICAL_OR) reduce 426) ((T_LOGICAL_XOR) reduce 426) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18842 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 390) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 390) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) reduce 390) ((T_COALESCE) reduce 390) ((T_DOUBLE_ARROW) reduce 390) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 390) ((T_LOGICAL_OR) reduce 390) ((T_LOGICAL_XOR) reduce 390) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18843 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 391) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 391) ((T_BOOLEAN_AND) reduce 391) ((T_BOOLEAN_OR) reduce 391) ((T_COALESCE) reduce 391) ((T_DOUBLE_ARROW) reduce 391) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 391) ((T_LOGICAL_OR) reduce 391) ((T_LOGICAL_XOR) reduce 391) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18844 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 396) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_AS) reduce 396) ((T_BOOLEAN_AND) reduce 396) ((T_BOOLEAN_OR) reduce 396) ((T_COALESCE) reduce 396) ((T_DOUBLE_ARROW) reduce 396) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 396) ((T_LOGICAL_OR) reduce 396) ((T_LOGICAL_XOR) reduce 396) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 396) (("|") reduce 396)) 18845 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 397) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_AS) reduce 397) ((T_BOOLEAN_AND) reduce 397) ((T_BOOLEAN_OR) reduce 397) ((T_COALESCE) reduce 397) ((T_DOUBLE_ARROW) reduce 397) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 397) ((T_LOGICAL_OR) reduce 397) ((T_LOGICAL_XOR) reduce 397) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 397) (("|") reduce 397)) 18849 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 424) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 424) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 424) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 424) ((T_LOGICAL_OR) reduce 424) ((T_LOGICAL_XOR) reduce 424) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18850 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 425) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 425) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 425) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 425) ((T_LOGICAL_OR) reduce 425) ((T_LOGICAL_XOR) reduce 425) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18851 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 418) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_AS) reduce 418) ((T_BOOLEAN_AND) reduce 418) ((T_BOOLEAN_OR) reduce 418) ((T_COALESCE) reduce 418) ((T_DOUBLE_ARROW) reduce 418) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 418) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 418) ((T_IS_NOT_EQUAL) reduce 418) ((T_IS_NOT_IDENTICAL) reduce 418) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 418) ((T_LOGICAL_OR) reduce 418) ((T_LOGICAL_XOR) reduce 418) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 418) ((T_SR) shift) (("^") reduce 418) (("|") reduce 418)) 18852 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") reduce 416) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_AS) reduce 416) ((T_BOOLEAN_AND) reduce 416) ((T_BOOLEAN_OR) reduce 416) ((T_COALESCE) reduce 416) ((T_DOUBLE_ARROW) reduce 416) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 416) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 416) ((T_IS_NOT_EQUAL) reduce 416) ((T_IS_NOT_IDENTICAL) reduce 416) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 416) ((T_LOGICAL_OR) reduce 416) ((T_LOGICAL_XOR) reduce 416) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 416) ((T_SR) shift) (("^") reduce 416) (("|") reduce 416)) 18853 ((("%") reduce 404) (("*") reduce 404) (("+") reduce 404) (("-") reduce 404) ((".") reduce 404) (("/") reduce 404) (("<") reduce 404) ((">") reduce 404) (("?") reduce 404) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_AS) reduce 404) ((T_BOOLEAN_AND) reduce 404) ((T_BOOLEAN_OR) reduce 404) ((T_COALESCE) reduce 404) ((T_DOUBLE_ARROW) reduce 404) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 404) ((T_IS_GREATER_OR_EQUAL) reduce 404) ((T_IS_IDENTICAL) reduce 404) ((T_IS_NOT_EQUAL) reduce 404) ((T_IS_NOT_IDENTICAL) reduce 404) ((T_IS_SMALLER_OR_EQUAL) reduce 404) ((T_LOGICAL_AND) reduce 404) ((T_LOGICAL_OR) reduce 404) ((T_LOGICAL_XOR) reduce 404) ((T_POW) shift) ((T_SL) reduce 404) ((T_SPACESHIP) reduce 404) ((T_SR) reduce 404) (("^") reduce 404) (("|") reduce 404)) 18854 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 399) (("/") shift) (("<") reduce 399) ((">") reduce 399) (("?") reduce 399) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_AS) reduce 399) ((T_BOOLEAN_AND) reduce 399) ((T_BOOLEAN_OR) reduce 399) ((T_COALESCE) reduce 399) ((T_DOUBLE_ARROW) reduce 399) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 399) ((T_IS_GREATER_OR_EQUAL) reduce 399) ((T_IS_IDENTICAL) reduce 399) ((T_IS_NOT_EQUAL) reduce 399) ((T_IS_NOT_IDENTICAL) reduce 399) ((T_IS_SMALLER_OR_EQUAL) reduce 399) ((T_LOGICAL_AND) reduce 399) ((T_LOGICAL_OR) reduce 399) ((T_LOGICAL_XOR) reduce 399) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 399) ((T_SR) shift) (("^") reduce 399) (("|") reduce 399)) 18855 ((("%") shift) (("*") shift) (("+") reduce 401) (("-") reduce 401) ((".") reduce 401) (("/") shift) (("<") reduce 401) ((">") reduce 401) (("?") reduce 401) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_AS) reduce 401) ((T_BOOLEAN_AND) reduce 401) ((T_BOOLEAN_OR) reduce 401) ((T_COALESCE) reduce 401) ((T_DOUBLE_ARROW) reduce 401) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 401) ((T_IS_GREATER_OR_EQUAL) reduce 401) ((T_IS_IDENTICAL) reduce 401) ((T_IS_NOT_EQUAL) reduce 401) ((T_IS_NOT_IDENTICAL) reduce 401) ((T_IS_SMALLER_OR_EQUAL) reduce 401) ((T_LOGICAL_AND) reduce 401) ((T_LOGICAL_OR) reduce 401) ((T_LOGICAL_XOR) reduce 401) ((T_POW) shift) ((T_SL) reduce 401) ((T_SPACESHIP) reduce 401) ((T_SR) reduce 401) (("^") reduce 401) (("|") reduce 401)) 18856 ((("%") shift) (("*") shift) (("+") reduce 400) (("-") reduce 400) ((".") reduce 400) (("/") shift) (("<") reduce 400) ((">") reduce 400) (("?") reduce 400) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_AS) reduce 400) ((T_BOOLEAN_AND) reduce 400) ((T_BOOLEAN_OR) reduce 400) ((T_COALESCE) reduce 400) ((T_DOUBLE_ARROW) reduce 400) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 400) ((T_IS_GREATER_OR_EQUAL) reduce 400) ((T_IS_IDENTICAL) reduce 400) ((T_IS_NOT_EQUAL) reduce 400) ((T_IS_NOT_IDENTICAL) reduce 400) ((T_IS_SMALLER_OR_EQUAL) reduce 400) ((T_LOGICAL_AND) reduce 400) ((T_LOGICAL_OR) reduce 400) ((T_LOGICAL_XOR) reduce 400) ((T_POW) shift) ((T_SL) reduce 400) ((T_SPACESHIP) reduce 400) ((T_SR) reduce 400) (("^") reduce 400) (("|") reduce 400)) 18857 ((("%") reduce 402) (("*") reduce 402) (("+") reduce 402) (("-") reduce 402) ((".") reduce 402) (("/") reduce 402) (("<") reduce 402) ((">") reduce 402) (("?") reduce 402) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_AS) reduce 402) ((T_BOOLEAN_AND) reduce 402) ((T_BOOLEAN_OR) reduce 402) ((T_COALESCE) reduce 402) ((T_DOUBLE_ARROW) reduce 402) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 402) ((T_IS_GREATER_OR_EQUAL) reduce 402) ((T_IS_IDENTICAL) reduce 402) ((T_IS_NOT_EQUAL) reduce 402) ((T_IS_NOT_IDENTICAL) reduce 402) ((T_IS_SMALLER_OR_EQUAL) reduce 402) ((T_LOGICAL_AND) reduce 402) ((T_LOGICAL_OR) reduce 402) ((T_LOGICAL_XOR) reduce 402) ((T_POW) shift) ((T_SL) reduce 402) ((T_SPACESHIP) reduce 402) ((T_SR) reduce 402) (("^") reduce 402) (("|") reduce 402)) 18858 ((("%") reduce 405) (("*") reduce 405) (("+") reduce 405) (("-") reduce 405) ((".") reduce 405) (("/") reduce 405) (("<") reduce 405) ((">") reduce 405) (("?") reduce 405) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_AS) reduce 405) ((T_BOOLEAN_AND) reduce 405) ((T_BOOLEAN_OR) reduce 405) ((T_COALESCE) reduce 405) ((T_DOUBLE_ARROW) reduce 405) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 405) ((T_IS_GREATER_OR_EQUAL) reduce 405) ((T_IS_IDENTICAL) reduce 405) ((T_IS_NOT_EQUAL) reduce 405) ((T_IS_NOT_IDENTICAL) reduce 405) ((T_IS_SMALLER_OR_EQUAL) reduce 405) ((T_LOGICAL_AND) reduce 405) ((T_LOGICAL_OR) reduce 405) ((T_LOGICAL_XOR) reduce 405) ((T_POW) shift) ((T_SL) reduce 405) ((T_SPACESHIP) reduce 405) ((T_SR) reduce 405) (("^") reduce 405) (("|") reduce 405)) 18860 ((("%") reduce 73) (("(") reduce 73) (("*") reduce 73) (("+") reduce 73) (("-") reduce 73) ((".") reduce 73) (("/") reduce 73) (("<") reduce 73) ((">") reduce 73) (("?") reduce 73) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_AS) reduce 73) ((T_BOOLEAN_AND) reduce 73) ((T_BOOLEAN_OR) reduce 73) ((T_COALESCE) reduce 73) ((T_DOUBLE_ARROW) reduce 73) ((T_INSTANCEOF) reduce 73) ((T_IS_EQUAL) reduce 73) ((T_IS_GREATER_OR_EQUAL) reduce 73) ((T_IS_IDENTICAL) reduce 73) ((T_IS_NOT_EQUAL) reduce 73) ((T_IS_NOT_IDENTICAL) reduce 73) ((T_IS_SMALLER_OR_EQUAL) reduce 73) ((T_LOGICAL_AND) reduce 73) ((T_LOGICAL_OR) reduce 73) ((T_LOGICAL_XOR) reduce 73) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 73) ((T_OBJECT_OPERATOR) reduce 73) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 73) ((T_POW) reduce 73) ((T_SL) reduce 73) ((T_SPACESHIP) reduce 73) ((T_SR) reduce 73) (("[") reduce 73) (("^") reduce 73) (("{") reduce 73) (("|") reduce 73)) 18861 ((("%") reduce 52) (("(") reduce 52) (("*") reduce 52) (("+") reduce 52) (("-") reduce 52) ((".") reduce 52) (("/") reduce 52) (("<") reduce 52) ((">") reduce 52) (("?") reduce 52) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_AS) reduce 52) ((T_BOOLEAN_AND) reduce 52) ((T_BOOLEAN_OR) reduce 52) ((T_COALESCE) reduce 52) ((T_DOUBLE_ARROW) reduce 52) ((T_INSTANCEOF) reduce 52) ((T_IS_EQUAL) reduce 52) ((T_IS_GREATER_OR_EQUAL) reduce 52) ((T_IS_IDENTICAL) reduce 52) ((T_IS_NOT_EQUAL) reduce 52) ((T_IS_NOT_IDENTICAL) reduce 52) ((T_IS_SMALLER_OR_EQUAL) reduce 52) ((T_LOGICAL_AND) reduce 52) ((T_LOGICAL_OR) reduce 52) ((T_LOGICAL_XOR) reduce 52) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 52) ((T_OBJECT_OPERATOR) reduce 52) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 52) ((T_POW) reduce 52) ((T_SL) reduce 52) ((T_SPACESHIP) reduce 52) ((T_SR) reduce 52) (("[") reduce 52) (("^") reduce 52) (("{") reduce 52) (("|") reduce 52)) 18862 ((("%") reduce 27) (("(") reduce 27) (("*") reduce 27) (("+") reduce 27) (("-") reduce 27) ((".") reduce 27) (("/") reduce 27) (("<") reduce 27) ((">") reduce 27) (("?") reduce 27) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_AS) reduce 27) ((T_BOOLEAN_AND) reduce 27) ((T_BOOLEAN_OR) reduce 27) ((T_COALESCE) reduce 27) ((T_DOUBLE_ARROW) reduce 27) ((T_INSTANCEOF) reduce 27) ((T_IS_EQUAL) reduce 27) ((T_IS_GREATER_OR_EQUAL) reduce 27) ((T_IS_IDENTICAL) reduce 27) ((T_IS_NOT_EQUAL) reduce 27) ((T_IS_NOT_IDENTICAL) reduce 27) ((T_IS_SMALLER_OR_EQUAL) reduce 27) ((T_LOGICAL_AND) reduce 27) ((T_LOGICAL_OR) reduce 27) ((T_LOGICAL_XOR) reduce 27) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 27) ((T_OBJECT_OPERATOR) reduce 27) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 27) ((T_POW) reduce 27) ((T_SL) reduce 27) ((T_SPACESHIP) reduce 27) ((T_SR) reduce 27) (("[") reduce 27) (("^") reduce 27) (("{") reduce 27) (("|") reduce 27)) 18863 ((("%") reduce 51) (("(") reduce 51) (("*") reduce 51) (("+") reduce 51) (("-") reduce 51) ((".") reduce 51) (("/") reduce 51) (("<") reduce 51) ((">") reduce 51) (("?") reduce 51) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_AS) reduce 51) ((T_BOOLEAN_AND) reduce 51) ((T_BOOLEAN_OR) reduce 51) ((T_COALESCE) reduce 51) ((T_DOUBLE_ARROW) reduce 51) ((T_INSTANCEOF) reduce 51) ((T_IS_EQUAL) reduce 51) ((T_IS_GREATER_OR_EQUAL) reduce 51) ((T_IS_IDENTICAL) reduce 51) ((T_IS_NOT_EQUAL) reduce 51) ((T_IS_NOT_IDENTICAL) reduce 51) ((T_IS_SMALLER_OR_EQUAL) reduce 51) ((T_LOGICAL_AND) reduce 51) ((T_LOGICAL_OR) reduce 51) ((T_LOGICAL_XOR) reduce 51) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 51) ((T_OBJECT_OPERATOR) reduce 51) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 51) ((T_POW) reduce 51) ((T_SL) reduce 51) ((T_SPACESHIP) reduce 51) ((T_SR) reduce 51) (("[") reduce 51) (("^") reduce 51) (("{") reduce 51) (("|") reduce 51)) 18864 ((("%") reduce 53) (("(") reduce 53) (("*") reduce 53) (("+") reduce 53) (("-") reduce 53) ((".") reduce 53) (("/") reduce 53) (("<") reduce 53) ((">") reduce 53) (("?") reduce 53) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_AS) reduce 53) ((T_BOOLEAN_AND) reduce 53) ((T_BOOLEAN_OR) reduce 53) ((T_COALESCE) reduce 53) ((T_DOUBLE_ARROW) reduce 53) ((T_INSTANCEOF) reduce 53) ((T_IS_EQUAL) reduce 53) ((T_IS_GREATER_OR_EQUAL) reduce 53) ((T_IS_IDENTICAL) reduce 53) ((T_IS_NOT_EQUAL) reduce 53) ((T_IS_NOT_IDENTICAL) reduce 53) ((T_IS_SMALLER_OR_EQUAL) reduce 53) ((T_LOGICAL_AND) reduce 53) ((T_LOGICAL_OR) reduce 53) ((T_LOGICAL_XOR) reduce 53) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 53) ((T_OBJECT_OPERATOR) reduce 53) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 53) ((T_POW) reduce 53) ((T_SL) reduce 53) ((T_SPACESHIP) reduce 53) ((T_SR) reduce 53) (("[") reduce 53) (("^") reduce 53) (("{") reduce 53) (("|") reduce 53)) 18865 ((("%") reduce 49) (("(") reduce 49) (("*") reduce 49) (("+") reduce 49) (("-") reduce 49) ((".") reduce 49) (("/") reduce 49) (("<") reduce 49) ((">") reduce 49) (("?") reduce 49) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_AS) reduce 49) ((T_BOOLEAN_AND) reduce 49) ((T_BOOLEAN_OR) reduce 49) ((T_COALESCE) reduce 49) ((T_DOUBLE_ARROW) reduce 49) ((T_INSTANCEOF) reduce 49) ((T_IS_EQUAL) reduce 49) ((T_IS_GREATER_OR_EQUAL) reduce 49) ((T_IS_IDENTICAL) reduce 49) ((T_IS_NOT_EQUAL) reduce 49) ((T_IS_NOT_IDENTICAL) reduce 49) ((T_IS_SMALLER_OR_EQUAL) reduce 49) ((T_LOGICAL_AND) reduce 49) ((T_LOGICAL_OR) reduce 49) ((T_LOGICAL_XOR) reduce 49) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 49) ((T_OBJECT_OPERATOR) reduce 49) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 49) ((T_POW) reduce 49) ((T_SL) reduce 49) ((T_SPACESHIP) reduce 49) ((T_SR) reduce 49) (("[") reduce 49) (("^") reduce 49) (("{") reduce 49) (("|") reduce 49)) 18866 ((("%") reduce 29) (("(") reduce 29) (("*") reduce 29) (("+") reduce 29) (("-") reduce 29) ((".") reduce 29) (("/") reduce 29) (("<") reduce 29) ((">") reduce 29) (("?") reduce 29) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_AS) reduce 29) ((T_BOOLEAN_AND) reduce 29) ((T_BOOLEAN_OR) reduce 29) ((T_COALESCE) reduce 29) ((T_DOUBLE_ARROW) reduce 29) ((T_INSTANCEOF) reduce 29) ((T_IS_EQUAL) reduce 29) ((T_IS_GREATER_OR_EQUAL) reduce 29) ((T_IS_IDENTICAL) reduce 29) ((T_IS_NOT_EQUAL) reduce 29) ((T_IS_NOT_IDENTICAL) reduce 29) ((T_IS_SMALLER_OR_EQUAL) reduce 29) ((T_LOGICAL_AND) reduce 29) ((T_LOGICAL_OR) reduce 29) ((T_LOGICAL_XOR) reduce 29) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 29) ((T_OBJECT_OPERATOR) reduce 29) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 29) ((T_POW) reduce 29) ((T_SL) reduce 29) ((T_SPACESHIP) reduce 29) ((T_SR) reduce 29) (("[") reduce 29) (("^") reduce 29) (("{") reduce 29) (("|") reduce 29)) 18867 ((("%") reduce 59) (("(") reduce 59) (("*") reduce 59) (("+") reduce 59) (("-") reduce 59) ((".") reduce 59) (("/") reduce 59) (("<") reduce 59) ((">") reduce 59) (("?") reduce 59) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_AS) reduce 59) ((T_BOOLEAN_AND) reduce 59) ((T_BOOLEAN_OR) reduce 59) ((T_COALESCE) reduce 59) ((T_DOUBLE_ARROW) reduce 59) ((T_INSTANCEOF) reduce 59) ((T_IS_EQUAL) reduce 59) ((T_IS_GREATER_OR_EQUAL) reduce 59) ((T_IS_IDENTICAL) reduce 59) ((T_IS_NOT_EQUAL) reduce 59) ((T_IS_NOT_IDENTICAL) reduce 59) ((T_IS_SMALLER_OR_EQUAL) reduce 59) ((T_LOGICAL_AND) reduce 59) ((T_LOGICAL_OR) reduce 59) ((T_LOGICAL_XOR) reduce 59) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 59) ((T_OBJECT_OPERATOR) reduce 59) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 59) ((T_POW) reduce 59) ((T_SL) reduce 59) ((T_SPACESHIP) reduce 59) ((T_SR) reduce 59) (("[") reduce 59) (("^") reduce 59) (("{") reduce 59) (("|") reduce 59)) 18868 ((("%") reduce 60) (("(") reduce 60) (("*") reduce 60) (("+") reduce 60) (("-") reduce 60) ((".") reduce 60) (("/") reduce 60) (("<") reduce 60) ((">") reduce 60) (("?") reduce 60) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_AS) reduce 60) ((T_BOOLEAN_AND) reduce 60) ((T_BOOLEAN_OR) reduce 60) ((T_COALESCE) reduce 60) ((T_DOUBLE_ARROW) reduce 60) ((T_INSTANCEOF) reduce 60) ((T_IS_EQUAL) reduce 60) ((T_IS_GREATER_OR_EQUAL) reduce 60) ((T_IS_IDENTICAL) reduce 60) ((T_IS_NOT_EQUAL) reduce 60) ((T_IS_NOT_IDENTICAL) reduce 60) ((T_IS_SMALLER_OR_EQUAL) reduce 60) ((T_LOGICAL_AND) reduce 60) ((T_LOGICAL_OR) reduce 60) ((T_LOGICAL_XOR) reduce 60) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 60) ((T_OBJECT_OPERATOR) reduce 60) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 60) ((T_POW) reduce 60) ((T_SL) reduce 60) ((T_SPACESHIP) reduce 60) ((T_SR) reduce 60) (("[") reduce 60) (("^") reduce 60) (("{") reduce 60) (("|") reduce 60)) 18869 ((("%") reduce 11) (("(") reduce 11) (("*") reduce 11) (("+") reduce 11) (("-") reduce 11) ((".") reduce 11) (("/") reduce 11) (("<") reduce 11) ((">") reduce 11) (("?") reduce 11) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_AS) reduce 11) ((T_BOOLEAN_AND) reduce 11) ((T_BOOLEAN_OR) reduce 11) ((T_COALESCE) reduce 11) ((T_DOUBLE_ARROW) reduce 11) ((T_INSTANCEOF) reduce 11) ((T_IS_EQUAL) reduce 11) ((T_IS_GREATER_OR_EQUAL) reduce 11) ((T_IS_IDENTICAL) reduce 11) ((T_IS_NOT_EQUAL) reduce 11) ((T_IS_NOT_IDENTICAL) reduce 11) ((T_IS_SMALLER_OR_EQUAL) reduce 11) ((T_LOGICAL_AND) reduce 11) ((T_LOGICAL_OR) reduce 11) ((T_LOGICAL_XOR) reduce 11) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 11) ((T_OBJECT_OPERATOR) reduce 11) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 11) ((T_POW) reduce 11) ((T_SL) reduce 11) ((T_SPACESHIP) reduce 11) ((T_SR) reduce 11) (("[") reduce 11) (("^") reduce 11) (("{") reduce 11) (("|") reduce 11)) 18870 ((("%") reduce 42) (("(") reduce 42) (("*") reduce 42) (("+") reduce 42) (("-") reduce 42) ((".") reduce 42) (("/") reduce 42) (("<") reduce 42) ((">") reduce 42) (("?") reduce 42) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_AS) reduce 42) ((T_BOOLEAN_AND) reduce 42) ((T_BOOLEAN_OR) reduce 42) ((T_COALESCE) reduce 42) ((T_DOUBLE_ARROW) reduce 42) ((T_INSTANCEOF) reduce 42) ((T_IS_EQUAL) reduce 42) ((T_IS_GREATER_OR_EQUAL) reduce 42) ((T_IS_IDENTICAL) reduce 42) ((T_IS_NOT_EQUAL) reduce 42) ((T_IS_NOT_IDENTICAL) reduce 42) ((T_IS_SMALLER_OR_EQUAL) reduce 42) ((T_LOGICAL_AND) reduce 42) ((T_LOGICAL_OR) reduce 42) ((T_LOGICAL_XOR) reduce 42) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 42) ((T_OBJECT_OPERATOR) reduce 42) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 42) ((T_POW) reduce 42) ((T_SL) reduce 42) ((T_SPACESHIP) reduce 42) ((T_SR) reduce 42) (("[") reduce 42) (("^") reduce 42) (("{") reduce 42) (("|") reduce 42)) 18871 ((("%") reduce 39) (("(") reduce 39) (("*") reduce 39) (("+") reduce 39) (("-") reduce 39) ((".") reduce 39) (("/") reduce 39) (("<") reduce 39) ((">") reduce 39) (("?") reduce 39) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_AS) reduce 39) ((T_BOOLEAN_AND) reduce 39) ((T_BOOLEAN_OR) reduce 39) ((T_COALESCE) reduce 39) ((T_DOUBLE_ARROW) reduce 39) ((T_INSTANCEOF) reduce 39) ((T_IS_EQUAL) reduce 39) ((T_IS_GREATER_OR_EQUAL) reduce 39) ((T_IS_IDENTICAL) reduce 39) ((T_IS_NOT_EQUAL) reduce 39) ((T_IS_NOT_IDENTICAL) reduce 39) ((T_IS_SMALLER_OR_EQUAL) reduce 39) ((T_LOGICAL_AND) reduce 39) ((T_LOGICAL_OR) reduce 39) ((T_LOGICAL_XOR) reduce 39) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 39) ((T_OBJECT_OPERATOR) reduce 39) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 39) ((T_POW) reduce 39) ((T_SL) reduce 39) ((T_SPACESHIP) reduce 39) ((T_SR) reduce 39) (("[") reduce 39) (("^") reduce 39) (("{") reduce 39) (("|") reduce 39)) 18872 ((("%") reduce 25) (("(") reduce 25) (("*") reduce 25) (("+") reduce 25) (("-") reduce 25) ((".") reduce 25) (("/") reduce 25) (("<") reduce 25) ((">") reduce 25) (("?") reduce 25) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_AS) reduce 25) ((T_BOOLEAN_AND) reduce 25) ((T_BOOLEAN_OR) reduce 25) ((T_COALESCE) reduce 25) ((T_DOUBLE_ARROW) reduce 25) ((T_INSTANCEOF) reduce 25) ((T_IS_EQUAL) reduce 25) ((T_IS_GREATER_OR_EQUAL) reduce 25) ((T_IS_IDENTICAL) reduce 25) ((T_IS_NOT_EQUAL) reduce 25) ((T_IS_NOT_IDENTICAL) reduce 25) ((T_IS_SMALLER_OR_EQUAL) reduce 25) ((T_LOGICAL_AND) reduce 25) ((T_LOGICAL_OR) reduce 25) ((T_LOGICAL_XOR) reduce 25) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 25) ((T_OBJECT_OPERATOR) reduce 25) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 25) ((T_POW) reduce 25) ((T_SL) reduce 25) ((T_SPACESHIP) reduce 25) ((T_SR) reduce 25) (("[") reduce 25) (("^") reduce 25) (("{") reduce 25) (("|") reduce 25)) 18873 ((("%") reduce 50) (("(") reduce 50) (("*") reduce 50) (("+") reduce 50) (("-") reduce 50) ((".") reduce 50) (("/") reduce 50) (("<") reduce 50) ((">") reduce 50) (("?") reduce 50) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_AS) reduce 50) ((T_BOOLEAN_AND) reduce 50) ((T_BOOLEAN_OR) reduce 50) ((T_COALESCE) reduce 50) ((T_DOUBLE_ARROW) reduce 50) ((T_INSTANCEOF) reduce 50) ((T_IS_EQUAL) reduce 50) ((T_IS_GREATER_OR_EQUAL) reduce 50) ((T_IS_IDENTICAL) reduce 50) ((T_IS_NOT_EQUAL) reduce 50) ((T_IS_NOT_IDENTICAL) reduce 50) ((T_IS_SMALLER_OR_EQUAL) reduce 50) ((T_LOGICAL_AND) reduce 50) ((T_LOGICAL_OR) reduce 50) ((T_LOGICAL_XOR) reduce 50) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 50) ((T_OBJECT_OPERATOR) reduce 50) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 50) ((T_POW) reduce 50) ((T_SL) reduce 50) ((T_SPACESHIP) reduce 50) ((T_SR) reduce 50) (("[") reduce 50) (("^") reduce 50) (("{") reduce 50) (("|") reduce 50)) 18874 ((("%") reduce 66) (("(") reduce 66) (("*") reduce 66) (("+") reduce 66) (("-") reduce 66) ((".") reduce 66) (("/") reduce 66) (("<") reduce 66) ((">") reduce 66) (("?") reduce 66) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_AS) reduce 66) ((T_BOOLEAN_AND) reduce 66) ((T_BOOLEAN_OR) reduce 66) ((T_COALESCE) reduce 66) ((T_DOUBLE_ARROW) reduce 66) ((T_INSTANCEOF) reduce 66) ((T_IS_EQUAL) reduce 66) ((T_IS_GREATER_OR_EQUAL) reduce 66) ((T_IS_IDENTICAL) reduce 66) ((T_IS_NOT_EQUAL) reduce 66) ((T_IS_NOT_IDENTICAL) reduce 66) ((T_IS_SMALLER_OR_EQUAL) reduce 66) ((T_LOGICAL_AND) reduce 66) ((T_LOGICAL_OR) reduce 66) ((T_LOGICAL_XOR) reduce 66) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 66) ((T_OBJECT_OPERATOR) reduce 66) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 66) ((T_POW) reduce 66) ((T_SL) reduce 66) ((T_SPACESHIP) reduce 66) ((T_SR) reduce 66) (("[") reduce 66) (("^") reduce 66) (("{") reduce 66) (("|") reduce 66)) 18875 ((("%") reduce 18) (("(") reduce 18) (("*") reduce 18) (("+") reduce 18) (("-") reduce 18) ((".") reduce 18) (("/") reduce 18) (("<") reduce 18) ((">") reduce 18) (("?") reduce 18) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_AS) reduce 18) ((T_BOOLEAN_AND) reduce 18) ((T_BOOLEAN_OR) reduce 18) ((T_COALESCE) reduce 18) ((T_DOUBLE_ARROW) reduce 18) ((T_INSTANCEOF) reduce 18) ((T_IS_EQUAL) reduce 18) ((T_IS_GREATER_OR_EQUAL) reduce 18) ((T_IS_IDENTICAL) reduce 18) ((T_IS_NOT_EQUAL) reduce 18) ((T_IS_NOT_IDENTICAL) reduce 18) ((T_IS_SMALLER_OR_EQUAL) reduce 18) ((T_LOGICAL_AND) reduce 18) ((T_LOGICAL_OR) reduce 18) ((T_LOGICAL_XOR) reduce 18) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 18) ((T_OBJECT_OPERATOR) reduce 18) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 18) ((T_POW) reduce 18) ((T_SL) reduce 18) ((T_SPACESHIP) reduce 18) ((T_SR) reduce 18) (("[") reduce 18) (("^") reduce 18) (("{") reduce 18) (("|") reduce 18)) 18876 ((("%") reduce 17) (("(") reduce 17) (("*") reduce 17) (("+") reduce 17) (("-") reduce 17) ((".") reduce 17) (("/") reduce 17) (("<") reduce 17) ((">") reduce 17) (("?") reduce 17) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_AS) reduce 17) ((T_BOOLEAN_AND) reduce 17) ((T_BOOLEAN_OR) reduce 17) ((T_COALESCE) reduce 17) ((T_DOUBLE_ARROW) reduce 17) ((T_INSTANCEOF) reduce 17) ((T_IS_EQUAL) reduce 17) ((T_IS_GREATER_OR_EQUAL) reduce 17) ((T_IS_IDENTICAL) reduce 17) ((T_IS_NOT_EQUAL) reduce 17) ((T_IS_NOT_IDENTICAL) reduce 17) ((T_IS_SMALLER_OR_EQUAL) reduce 17) ((T_LOGICAL_AND) reduce 17) ((T_LOGICAL_OR) reduce 17) ((T_LOGICAL_XOR) reduce 17) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 17) ((T_OBJECT_OPERATOR) reduce 17) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 17) ((T_POW) reduce 17) ((T_SL) reduce 17) ((T_SPACESHIP) reduce 17) ((T_SR) reduce 17) (("[") reduce 17) (("^") reduce 17) (("{") reduce 17) (("|") reduce 17)) 18877 ((("%") reduce 15) (("(") reduce 15) (("*") reduce 15) (("+") reduce 15) (("-") reduce 15) ((".") reduce 15) (("/") reduce 15) (("<") reduce 15) ((">") reduce 15) (("?") reduce 15) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_AS) reduce 15) ((T_BOOLEAN_AND) reduce 15) ((T_BOOLEAN_OR) reduce 15) ((T_COALESCE) reduce 15) ((T_DOUBLE_ARROW) reduce 15) ((T_INSTANCEOF) reduce 15) ((T_IS_EQUAL) reduce 15) ((T_IS_GREATER_OR_EQUAL) reduce 15) ((T_IS_IDENTICAL) reduce 15) ((T_IS_NOT_EQUAL) reduce 15) ((T_IS_NOT_IDENTICAL) reduce 15) ((T_IS_SMALLER_OR_EQUAL) reduce 15) ((T_LOGICAL_AND) reduce 15) ((T_LOGICAL_OR) reduce 15) ((T_LOGICAL_XOR) reduce 15) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 15) ((T_OBJECT_OPERATOR) reduce 15) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 15) ((T_POW) reduce 15) ((T_SL) reduce 15) ((T_SPACESHIP) reduce 15) ((T_SR) reduce 15) (("[") reduce 15) (("^") reduce 15) (("{") reduce 15) (("|") reduce 15)) 18878 ((("%") reduce 14) (("(") reduce 14) (("*") reduce 14) (("+") reduce 14) (("-") reduce 14) ((".") reduce 14) (("/") reduce 14) (("<") reduce 14) ((">") reduce 14) (("?") reduce 14) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_AS) reduce 14) ((T_BOOLEAN_AND) reduce 14) ((T_BOOLEAN_OR) reduce 14) ((T_COALESCE) reduce 14) ((T_DOUBLE_ARROW) reduce 14) ((T_INSTANCEOF) reduce 14) ((T_IS_EQUAL) reduce 14) ((T_IS_GREATER_OR_EQUAL) reduce 14) ((T_IS_IDENTICAL) reduce 14) ((T_IS_NOT_EQUAL) reduce 14) ((T_IS_NOT_IDENTICAL) reduce 14) ((T_IS_SMALLER_OR_EQUAL) reduce 14) ((T_LOGICAL_AND) reduce 14) ((T_LOGICAL_OR) reduce 14) ((T_LOGICAL_XOR) reduce 14) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 14) ((T_OBJECT_OPERATOR) reduce 14) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 14) ((T_POW) reduce 14) ((T_SL) reduce 14) ((T_SPACESHIP) reduce 14) ((T_SR) reduce 14) (("[") reduce 14) (("^") reduce 14) (("{") reduce 14) (("|") reduce 14)) 18879 ((("%") reduce 38) (("(") reduce 38) (("*") reduce 38) (("+") reduce 38) (("-") reduce 38) ((".") reduce 38) (("/") reduce 38) (("<") reduce 38) ((">") reduce 38) (("?") reduce 38) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_AS) reduce 38) ((T_BOOLEAN_AND) reduce 38) ((T_BOOLEAN_OR) reduce 38) ((T_COALESCE) reduce 38) ((T_DOUBLE_ARROW) reduce 38) ((T_INSTANCEOF) reduce 38) ((T_IS_EQUAL) reduce 38) ((T_IS_GREATER_OR_EQUAL) reduce 38) ((T_IS_IDENTICAL) reduce 38) ((T_IS_NOT_EQUAL) reduce 38) ((T_IS_NOT_IDENTICAL) reduce 38) ((T_IS_SMALLER_OR_EQUAL) reduce 38) ((T_LOGICAL_AND) reduce 38) ((T_LOGICAL_OR) reduce 38) ((T_LOGICAL_XOR) reduce 38) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 38) ((T_OBJECT_OPERATOR) reduce 38) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 38) ((T_POW) reduce 38) ((T_SL) reduce 38) ((T_SPACESHIP) reduce 38) ((T_SR) reduce 38) (("[") reduce 38) (("^") reduce 38) (("{") reduce 38) (("|") reduce 38)) 18880 ((("%") reduce 26) (("(") reduce 26) (("*") reduce 26) (("+") reduce 26) (("-") reduce 26) ((".") reduce 26) (("/") reduce 26) (("<") reduce 26) ((">") reduce 26) (("?") reduce 26) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_AS) reduce 26) ((T_BOOLEAN_AND) reduce 26) ((T_BOOLEAN_OR) reduce 26) ((T_COALESCE) reduce 26) ((T_DOUBLE_ARROW) reduce 26) ((T_INSTANCEOF) reduce 26) ((T_IS_EQUAL) reduce 26) ((T_IS_GREATER_OR_EQUAL) reduce 26) ((T_IS_IDENTICAL) reduce 26) ((T_IS_NOT_EQUAL) reduce 26) ((T_IS_NOT_IDENTICAL) reduce 26) ((T_IS_SMALLER_OR_EQUAL) reduce 26) ((T_LOGICAL_AND) reduce 26) ((T_LOGICAL_OR) reduce 26) ((T_LOGICAL_XOR) reduce 26) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 26) ((T_OBJECT_OPERATOR) reduce 26) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 26) ((T_POW) reduce 26) ((T_SL) reduce 26) ((T_SPACESHIP) reduce 26) ((T_SR) reduce 26) (("[") reduce 26) (("^") reduce 26) (("{") reduce 26) (("|") reduce 26)) 18881 ((("%") reduce 22) (("(") reduce 22) (("*") reduce 22) (("+") reduce 22) (("-") reduce 22) ((".") reduce 22) (("/") reduce 22) (("<") reduce 22) ((">") reduce 22) (("?") reduce 22) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_AS) reduce 22) ((T_BOOLEAN_AND) reduce 22) ((T_BOOLEAN_OR) reduce 22) ((T_COALESCE) reduce 22) ((T_DOUBLE_ARROW) reduce 22) ((T_INSTANCEOF) reduce 22) ((T_IS_EQUAL) reduce 22) ((T_IS_GREATER_OR_EQUAL) reduce 22) ((T_IS_IDENTICAL) reduce 22) ((T_IS_NOT_EQUAL) reduce 22) ((T_IS_NOT_IDENTICAL) reduce 22) ((T_IS_SMALLER_OR_EQUAL) reduce 22) ((T_LOGICAL_AND) reduce 22) ((T_LOGICAL_OR) reduce 22) ((T_LOGICAL_XOR) reduce 22) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 22) ((T_OBJECT_OPERATOR) reduce 22) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 22) ((T_POW) reduce 22) ((T_SL) reduce 22) ((T_SPACESHIP) reduce 22) ((T_SR) reduce 22) (("[") reduce 22) (("^") reduce 22) (("{") reduce 22) (("|") reduce 22)) 18882 ((("%") reduce 24) (("(") reduce 24) (("*") reduce 24) (("+") reduce 24) (("-") reduce 24) ((".") reduce 24) (("/") reduce 24) (("<") reduce 24) ((">") reduce 24) (("?") reduce 24) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_AS) reduce 24) ((T_BOOLEAN_AND) reduce 24) ((T_BOOLEAN_OR) reduce 24) ((T_COALESCE) reduce 24) ((T_DOUBLE_ARROW) reduce 24) ((T_INSTANCEOF) reduce 24) ((T_IS_EQUAL) reduce 24) ((T_IS_GREATER_OR_EQUAL) reduce 24) ((T_IS_IDENTICAL) reduce 24) ((T_IS_NOT_EQUAL) reduce 24) ((T_IS_NOT_IDENTICAL) reduce 24) ((T_IS_SMALLER_OR_EQUAL) reduce 24) ((T_LOGICAL_AND) reduce 24) ((T_LOGICAL_OR) reduce 24) ((T_LOGICAL_XOR) reduce 24) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 24) ((T_OBJECT_OPERATOR) reduce 24) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 24) ((T_POW) reduce 24) ((T_SL) reduce 24) ((T_SPACESHIP) reduce 24) ((T_SR) reduce 24) (("[") reduce 24) (("^") reduce 24) (("{") reduce 24) (("|") reduce 24)) 18883 ((("%") reduce 16) (("(") reduce 16) (("*") reduce 16) (("+") reduce 16) (("-") reduce 16) ((".") reduce 16) (("/") reduce 16) (("<") reduce 16) ((">") reduce 16) (("?") reduce 16) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_AS) reduce 16) ((T_BOOLEAN_AND) reduce 16) ((T_BOOLEAN_OR) reduce 16) ((T_COALESCE) reduce 16) ((T_DOUBLE_ARROW) reduce 16) ((T_INSTANCEOF) reduce 16) ((T_IS_EQUAL) reduce 16) ((T_IS_GREATER_OR_EQUAL) reduce 16) ((T_IS_IDENTICAL) reduce 16) ((T_IS_NOT_EQUAL) reduce 16) ((T_IS_NOT_IDENTICAL) reduce 16) ((T_IS_SMALLER_OR_EQUAL) reduce 16) ((T_LOGICAL_AND) reduce 16) ((T_LOGICAL_OR) reduce 16) ((T_LOGICAL_XOR) reduce 16) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 16) ((T_OBJECT_OPERATOR) reduce 16) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 16) ((T_POW) reduce 16) ((T_SL) reduce 16) ((T_SPACESHIP) reduce 16) ((T_SR) reduce 16) (("[") reduce 16) (("^") reduce 16) (("{") reduce 16) (("|") reduce 16)) 18884 ((("%") reduce 48) (("(") reduce 48) (("*") reduce 48) (("+") reduce 48) (("-") reduce 48) ((".") reduce 48) (("/") reduce 48) (("<") reduce 48) ((">") reduce 48) (("?") reduce 48) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_AS) reduce 48) ((T_BOOLEAN_AND) reduce 48) ((T_BOOLEAN_OR) reduce 48) ((T_COALESCE) reduce 48) ((T_DOUBLE_ARROW) reduce 48) ((T_INSTANCEOF) reduce 48) ((T_IS_EQUAL) reduce 48) ((T_IS_GREATER_OR_EQUAL) reduce 48) ((T_IS_IDENTICAL) reduce 48) ((T_IS_NOT_EQUAL) reduce 48) ((T_IS_NOT_IDENTICAL) reduce 48) ((T_IS_SMALLER_OR_EQUAL) reduce 48) ((T_LOGICAL_AND) reduce 48) ((T_LOGICAL_OR) reduce 48) ((T_LOGICAL_XOR) reduce 48) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 48) ((T_OBJECT_OPERATOR) reduce 48) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 48) ((T_POW) reduce 48) ((T_SL) reduce 48) ((T_SPACESHIP) reduce 48) ((T_SR) reduce 48) (("[") reduce 48) (("^") reduce 48) (("{") reduce 48) (("|") reduce 48)) 18885 ((("%") reduce 20) (("(") reduce 20) (("*") reduce 20) (("+") reduce 20) (("-") reduce 20) ((".") reduce 20) (("/") reduce 20) (("<") reduce 20) ((">") reduce 20) (("?") reduce 20) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_AS) reduce 20) ((T_BOOLEAN_AND) reduce 20) ((T_BOOLEAN_OR) reduce 20) ((T_COALESCE) reduce 20) ((T_DOUBLE_ARROW) reduce 20) ((T_INSTANCEOF) reduce 20) ((T_IS_EQUAL) reduce 20) ((T_IS_GREATER_OR_EQUAL) reduce 20) ((T_IS_IDENTICAL) reduce 20) ((T_IS_NOT_EQUAL) reduce 20) ((T_IS_NOT_IDENTICAL) reduce 20) ((T_IS_SMALLER_OR_EQUAL) reduce 20) ((T_LOGICAL_AND) reduce 20) ((T_LOGICAL_OR) reduce 20) ((T_LOGICAL_XOR) reduce 20) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 20) ((T_OBJECT_OPERATOR) reduce 20) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 20) ((T_POW) reduce 20) ((T_SL) reduce 20) ((T_SPACESHIP) reduce 20) ((T_SR) reduce 20) (("[") reduce 20) (("^") reduce 20) (("{") reduce 20) (("|") reduce 20)) 18886 ((("%") reduce 70) (("(") reduce 70) (("*") reduce 70) (("+") reduce 70) (("-") reduce 70) ((".") reduce 70) (("/") reduce 70) (("<") reduce 70) ((">") reduce 70) (("?") reduce 70) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_AS) reduce 70) ((T_BOOLEAN_AND) reduce 70) ((T_BOOLEAN_OR) reduce 70) ((T_COALESCE) reduce 70) ((T_DOUBLE_ARROW) reduce 70) ((T_INSTANCEOF) reduce 70) ((T_IS_EQUAL) reduce 70) ((T_IS_GREATER_OR_EQUAL) reduce 70) ((T_IS_IDENTICAL) reduce 70) ((T_IS_NOT_EQUAL) reduce 70) ((T_IS_NOT_IDENTICAL) reduce 70) ((T_IS_SMALLER_OR_EQUAL) reduce 70) ((T_LOGICAL_AND) reduce 70) ((T_LOGICAL_OR) reduce 70) ((T_LOGICAL_XOR) reduce 70) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 70) ((T_OBJECT_OPERATOR) reduce 70) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 70) ((T_POW) reduce 70) ((T_SL) reduce 70) ((T_SPACESHIP) reduce 70) ((T_SR) reduce 70) (("[") reduce 70) (("^") reduce 70) (("{") reduce 70) (("|") reduce 70)) 18887 ((("%") reduce 3) (("(") reduce 3) (("*") reduce 3) (("+") reduce 3) (("-") reduce 3) ((".") reduce 3) (("/") reduce 3) (("<") reduce 3) ((">") reduce 3) (("?") reduce 3) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_AS) reduce 3) ((T_BOOLEAN_AND) reduce 3) ((T_BOOLEAN_OR) reduce 3) ((T_COALESCE) reduce 3) ((T_DOUBLE_ARROW) reduce 3) ((T_INSTANCEOF) reduce 3) ((T_IS_EQUAL) reduce 3) ((T_IS_GREATER_OR_EQUAL) reduce 3) ((T_IS_IDENTICAL) reduce 3) ((T_IS_NOT_EQUAL) reduce 3) ((T_IS_NOT_IDENTICAL) reduce 3) ((T_IS_SMALLER_OR_EQUAL) reduce 3) ((T_LOGICAL_AND) reduce 3) ((T_LOGICAL_OR) reduce 3) ((T_LOGICAL_XOR) reduce 3) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 3) ((T_OBJECT_OPERATOR) reduce 3) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 3) ((T_POW) reduce 3) ((T_SL) reduce 3) ((T_SPACESHIP) reduce 3) ((T_SR) reduce 3) (("[") reduce 3) (("^") reduce 3) (("{") reduce 3) (("|") reduce 3)) 18888 ((("%") reduce 12) (("(") reduce 12) (("*") reduce 12) (("+") reduce 12) (("-") reduce 12) ((".") reduce 12) (("/") reduce 12) (("<") reduce 12) ((">") reduce 12) (("?") reduce 12) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_AS) reduce 12) ((T_BOOLEAN_AND) reduce 12) ((T_BOOLEAN_OR) reduce 12) ((T_COALESCE) reduce 12) ((T_DOUBLE_ARROW) reduce 12) ((T_INSTANCEOF) reduce 12) ((T_IS_EQUAL) reduce 12) ((T_IS_GREATER_OR_EQUAL) reduce 12) ((T_IS_IDENTICAL) reduce 12) ((T_IS_NOT_EQUAL) reduce 12) ((T_IS_NOT_IDENTICAL) reduce 12) ((T_IS_SMALLER_OR_EQUAL) reduce 12) ((T_LOGICAL_AND) reduce 12) ((T_LOGICAL_OR) reduce 12) ((T_LOGICAL_XOR) reduce 12) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 12) ((T_OBJECT_OPERATOR) reduce 12) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 12) ((T_POW) reduce 12) ((T_SL) reduce 12) ((T_SPACESHIP) reduce 12) ((T_SR) reduce 12) (("[") reduce 12) (("^") reduce 12) (("{") reduce 12) (("|") reduce 12)) 18889 ((("%") reduce 54) (("(") reduce 54) (("*") reduce 54) (("+") reduce 54) (("-") reduce 54) ((".") reduce 54) (("/") reduce 54) (("<") reduce 54) ((">") reduce 54) (("?") reduce 54) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_AS) reduce 54) ((T_BOOLEAN_AND) reduce 54) ((T_BOOLEAN_OR) reduce 54) ((T_COALESCE) reduce 54) ((T_DOUBLE_ARROW) reduce 54) ((T_INSTANCEOF) reduce 54) ((T_IS_EQUAL) reduce 54) ((T_IS_GREATER_OR_EQUAL) reduce 54) ((T_IS_IDENTICAL) reduce 54) ((T_IS_NOT_EQUAL) reduce 54) ((T_IS_NOT_IDENTICAL) reduce 54) ((T_IS_SMALLER_OR_EQUAL) reduce 54) ((T_LOGICAL_AND) reduce 54) ((T_LOGICAL_OR) reduce 54) ((T_LOGICAL_XOR) reduce 54) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 54) ((T_OBJECT_OPERATOR) reduce 54) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 54) ((T_POW) reduce 54) ((T_SL) reduce 54) ((T_SPACESHIP) reduce 54) ((T_SR) reduce 54) (("[") reduce 54) (("^") reduce 54) (("{") reduce 54) (("|") reduce 54)) 18890 ((("%") reduce 65) (("(") reduce 65) (("*") reduce 65) (("+") reduce 65) (("-") reduce 65) ((".") reduce 65) (("/") reduce 65) (("<") reduce 65) ((">") reduce 65) (("?") reduce 65) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_AS) reduce 65) ((T_BOOLEAN_AND) reduce 65) ((T_BOOLEAN_OR) reduce 65) ((T_COALESCE) reduce 65) ((T_DOUBLE_ARROW) reduce 65) ((T_INSTANCEOF) reduce 65) ((T_IS_EQUAL) reduce 65) ((T_IS_GREATER_OR_EQUAL) reduce 65) ((T_IS_IDENTICAL) reduce 65) ((T_IS_NOT_EQUAL) reduce 65) ((T_IS_NOT_IDENTICAL) reduce 65) ((T_IS_SMALLER_OR_EQUAL) reduce 65) ((T_LOGICAL_AND) reduce 65) ((T_LOGICAL_OR) reduce 65) ((T_LOGICAL_XOR) reduce 65) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 65) ((T_OBJECT_OPERATOR) reduce 65) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 65) ((T_POW) reduce 65) ((T_SL) reduce 65) ((T_SPACESHIP) reduce 65) ((T_SR) reduce 65) (("[") reduce 65) (("^") reduce 65) (("{") reduce 65) (("|") reduce 65)) 18891 ((("%") reduce 74) (("(") reduce 74) (("*") reduce 74) (("+") reduce 74) (("-") reduce 74) ((".") reduce 74) (("/") reduce 74) (("<") reduce 74) ((">") reduce 74) (("?") reduce 74) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_AS) reduce 74) ((T_BOOLEAN_AND) reduce 74) ((T_BOOLEAN_OR) reduce 74) ((T_COALESCE) reduce 74) ((T_DOUBLE_ARROW) reduce 74) ((T_INSTANCEOF) reduce 74) ((T_IS_EQUAL) reduce 74) ((T_IS_GREATER_OR_EQUAL) reduce 74) ((T_IS_IDENTICAL) reduce 74) ((T_IS_NOT_EQUAL) reduce 74) ((T_IS_NOT_IDENTICAL) reduce 74) ((T_IS_SMALLER_OR_EQUAL) reduce 74) ((T_LOGICAL_AND) reduce 74) ((T_LOGICAL_OR) reduce 74) ((T_LOGICAL_XOR) reduce 74) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 74) ((T_OBJECT_OPERATOR) reduce 74) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 74) ((T_POW) reduce 74) ((T_SL) reduce 74) ((T_SPACESHIP) reduce 74) ((T_SR) reduce 74) (("[") reduce 74) (("^") reduce 74) (("{") reduce 74) (("|") reduce 74)) 18892 ((("%") reduce 30) (("(") reduce 30) (("*") reduce 30) (("+") reduce 30) (("-") reduce 30) ((".") reduce 30) (("/") reduce 30) (("<") reduce 30) ((">") reduce 30) (("?") reduce 30) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_AS) reduce 30) ((T_BOOLEAN_AND) reduce 30) ((T_BOOLEAN_OR) reduce 30) ((T_COALESCE) reduce 30) ((T_DOUBLE_ARROW) reduce 30) ((T_INSTANCEOF) reduce 30) ((T_IS_EQUAL) reduce 30) ((T_IS_GREATER_OR_EQUAL) reduce 30) ((T_IS_IDENTICAL) reduce 30) ((T_IS_NOT_EQUAL) reduce 30) ((T_IS_NOT_IDENTICAL) reduce 30) ((T_IS_SMALLER_OR_EQUAL) reduce 30) ((T_LOGICAL_AND) reduce 30) ((T_LOGICAL_OR) reduce 30) ((T_LOGICAL_XOR) reduce 30) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 30) ((T_OBJECT_OPERATOR) reduce 30) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 30) ((T_POW) reduce 30) ((T_SL) reduce 30) ((T_SPACESHIP) reduce 30) ((T_SR) reduce 30) (("[") reduce 30) (("^") reduce 30) (("{") reduce 30) (("|") reduce 30)) 18893 ((("%") reduce 68) (("(") reduce 68) (("*") reduce 68) (("+") reduce 68) (("-") reduce 68) ((".") reduce 68) (("/") reduce 68) (("<") reduce 68) ((">") reduce 68) (("?") reduce 68) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_AS) reduce 68) ((T_BOOLEAN_AND) reduce 68) ((T_BOOLEAN_OR) reduce 68) ((T_COALESCE) reduce 68) ((T_DOUBLE_ARROW) reduce 68) ((T_INSTANCEOF) reduce 68) ((T_IS_EQUAL) reduce 68) ((T_IS_GREATER_OR_EQUAL) reduce 68) ((T_IS_IDENTICAL) reduce 68) ((T_IS_NOT_EQUAL) reduce 68) ((T_IS_NOT_IDENTICAL) reduce 68) ((T_IS_SMALLER_OR_EQUAL) reduce 68) ((T_LOGICAL_AND) reduce 68) ((T_LOGICAL_OR) reduce 68) ((T_LOGICAL_XOR) reduce 68) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 68) ((T_OBJECT_OPERATOR) reduce 68) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 68) ((T_POW) reduce 68) ((T_SL) reduce 68) ((T_SPACESHIP) reduce 68) ((T_SR) reduce 68) (("[") reduce 68) (("^") reduce 68) (("{") reduce 68) (("|") reduce 68)) 18894 ((("%") reduce 21) (("(") reduce 21) (("*") reduce 21) (("+") reduce 21) (("-") reduce 21) ((".") reduce 21) (("/") reduce 21) (("<") reduce 21) ((">") reduce 21) (("?") reduce 21) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_AS) reduce 21) ((T_BOOLEAN_AND) reduce 21) ((T_BOOLEAN_OR) reduce 21) ((T_COALESCE) reduce 21) ((T_DOUBLE_ARROW) reduce 21) ((T_INSTANCEOF) reduce 21) ((T_IS_EQUAL) reduce 21) ((T_IS_GREATER_OR_EQUAL) reduce 21) ((T_IS_IDENTICAL) reduce 21) ((T_IS_NOT_EQUAL) reduce 21) ((T_IS_NOT_IDENTICAL) reduce 21) ((T_IS_SMALLER_OR_EQUAL) reduce 21) ((T_LOGICAL_AND) reduce 21) ((T_LOGICAL_OR) reduce 21) ((T_LOGICAL_XOR) reduce 21) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 21) ((T_OBJECT_OPERATOR) reduce 21) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 21) ((T_POW) reduce 21) ((T_SL) reduce 21) ((T_SPACESHIP) reduce 21) ((T_SR) reduce 21) (("[") reduce 21) (("^") reduce 21) (("{") reduce 21) (("|") reduce 21)) 18895 ((("%") reduce 23) (("(") reduce 23) (("*") reduce 23) (("+") reduce 23) (("-") reduce 23) ((".") reduce 23) (("/") reduce 23) (("<") reduce 23) ((">") reduce 23) (("?") reduce 23) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_AS) reduce 23) ((T_BOOLEAN_AND) reduce 23) ((T_BOOLEAN_OR) reduce 23) ((T_COALESCE) reduce 23) ((T_DOUBLE_ARROW) reduce 23) ((T_INSTANCEOF) reduce 23) ((T_IS_EQUAL) reduce 23) ((T_IS_GREATER_OR_EQUAL) reduce 23) ((T_IS_IDENTICAL) reduce 23) ((T_IS_NOT_EQUAL) reduce 23) ((T_IS_NOT_IDENTICAL) reduce 23) ((T_IS_SMALLER_OR_EQUAL) reduce 23) ((T_LOGICAL_AND) reduce 23) ((T_LOGICAL_OR) reduce 23) ((T_LOGICAL_XOR) reduce 23) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 23) ((T_OBJECT_OPERATOR) reduce 23) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 23) ((T_POW) reduce 23) ((T_SL) reduce 23) ((T_SPACESHIP) reduce 23) ((T_SR) reduce 23) (("[") reduce 23) (("^") reduce 23) (("{") reduce 23) (("|") reduce 23)) 18896 ((("%") reduce 41) (("(") reduce 41) (("*") reduce 41) (("+") reduce 41) (("-") reduce 41) ((".") reduce 41) (("/") reduce 41) (("<") reduce 41) ((">") reduce 41) (("?") reduce 41) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_AS) reduce 41) ((T_BOOLEAN_AND) reduce 41) ((T_BOOLEAN_OR) reduce 41) ((T_COALESCE) reduce 41) ((T_DOUBLE_ARROW) reduce 41) ((T_INSTANCEOF) reduce 41) ((T_IS_EQUAL) reduce 41) ((T_IS_GREATER_OR_EQUAL) reduce 41) ((T_IS_IDENTICAL) reduce 41) ((T_IS_NOT_EQUAL) reduce 41) ((T_IS_NOT_IDENTICAL) reduce 41) ((T_IS_SMALLER_OR_EQUAL) reduce 41) ((T_LOGICAL_AND) reduce 41) ((T_LOGICAL_OR) reduce 41) ((T_LOGICAL_XOR) reduce 41) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 41) ((T_OBJECT_OPERATOR) reduce 41) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 41) ((T_POW) reduce 41) ((T_SL) reduce 41) ((T_SPACESHIP) reduce 41) ((T_SR) reduce 41) (("[") reduce 41) (("^") reduce 41) (("{") reduce 41) (("|") reduce 41)) 18897 ((("%") reduce 62) (("(") reduce 62) (("*") reduce 62) (("+") reduce 62) (("-") reduce 62) ((".") reduce 62) (("/") reduce 62) (("<") reduce 62) ((">") reduce 62) (("?") reduce 62) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_AS) reduce 62) ((T_BOOLEAN_AND) reduce 62) ((T_BOOLEAN_OR) reduce 62) ((T_COALESCE) reduce 62) ((T_DOUBLE_ARROW) reduce 62) ((T_INSTANCEOF) reduce 62) ((T_IS_EQUAL) reduce 62) ((T_IS_GREATER_OR_EQUAL) reduce 62) ((T_IS_IDENTICAL) reduce 62) ((T_IS_NOT_EQUAL) reduce 62) ((T_IS_NOT_IDENTICAL) reduce 62) ((T_IS_SMALLER_OR_EQUAL) reduce 62) ((T_LOGICAL_AND) reduce 62) ((T_LOGICAL_OR) reduce 62) ((T_LOGICAL_XOR) reduce 62) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 62) ((T_OBJECT_OPERATOR) reduce 62) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 62) ((T_POW) reduce 62) ((T_SL) reduce 62) ((T_SPACESHIP) reduce 62) ((T_SR) reduce 62) (("[") reduce 62) (("^") reduce 62) (("{") reduce 62) (("|") reduce 62)) 18898 ((("%") reduce 34) (("(") reduce 34) (("*") reduce 34) (("+") reduce 34) (("-") reduce 34) ((".") reduce 34) (("/") reduce 34) (("<") reduce 34) ((">") reduce 34) (("?") reduce 34) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_AS) reduce 34) ((T_BOOLEAN_AND) reduce 34) ((T_BOOLEAN_OR) reduce 34) ((T_COALESCE) reduce 34) ((T_DOUBLE_ARROW) reduce 34) ((T_INSTANCEOF) reduce 34) ((T_IS_EQUAL) reduce 34) ((T_IS_GREATER_OR_EQUAL) reduce 34) ((T_IS_IDENTICAL) reduce 34) ((T_IS_NOT_EQUAL) reduce 34) ((T_IS_NOT_IDENTICAL) reduce 34) ((T_IS_SMALLER_OR_EQUAL) reduce 34) ((T_LOGICAL_AND) reduce 34) ((T_LOGICAL_OR) reduce 34) ((T_LOGICAL_XOR) reduce 34) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 34) ((T_OBJECT_OPERATOR) reduce 34) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 34) ((T_POW) reduce 34) ((T_SL) reduce 34) ((T_SPACESHIP) reduce 34) ((T_SR) reduce 34) (("[") reduce 34) (("^") reduce 34) (("{") reduce 34) (("|") reduce 34)) 18899 ((("%") reduce 40) (("(") reduce 40) (("*") reduce 40) (("+") reduce 40) (("-") reduce 40) ((".") reduce 40) (("/") reduce 40) (("<") reduce 40) ((">") reduce 40) (("?") reduce 40) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_AS) reduce 40) ((T_BOOLEAN_AND) reduce 40) ((T_BOOLEAN_OR) reduce 40) ((T_COALESCE) reduce 40) ((T_DOUBLE_ARROW) reduce 40) ((T_INSTANCEOF) reduce 40) ((T_IS_EQUAL) reduce 40) ((T_IS_GREATER_OR_EQUAL) reduce 40) ((T_IS_IDENTICAL) reduce 40) ((T_IS_NOT_EQUAL) reduce 40) ((T_IS_NOT_IDENTICAL) reduce 40) ((T_IS_SMALLER_OR_EQUAL) reduce 40) ((T_LOGICAL_AND) reduce 40) ((T_LOGICAL_OR) reduce 40) ((T_LOGICAL_XOR) reduce 40) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 40) ((T_OBJECT_OPERATOR) reduce 40) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 40) ((T_POW) reduce 40) ((T_SL) reduce 40) ((T_SPACESHIP) reduce 40) ((T_SR) reduce 40) (("[") reduce 40) (("^") reduce 40) (("{") reduce 40) (("|") reduce 40)) 18900 ((("%") reduce 13) (("(") reduce 13) (("*") reduce 13) (("+") reduce 13) (("-") reduce 13) ((".") reduce 13) (("/") reduce 13) (("<") reduce 13) ((">") reduce 13) (("?") reduce 13) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_AS) reduce 13) ((T_BOOLEAN_AND) reduce 13) ((T_BOOLEAN_OR) reduce 13) ((T_COALESCE) reduce 13) ((T_DOUBLE_ARROW) reduce 13) ((T_INSTANCEOF) reduce 13) ((T_IS_EQUAL) reduce 13) ((T_IS_GREATER_OR_EQUAL) reduce 13) ((T_IS_IDENTICAL) reduce 13) ((T_IS_NOT_EQUAL) reduce 13) ((T_IS_NOT_IDENTICAL) reduce 13) ((T_IS_SMALLER_OR_EQUAL) reduce 13) ((T_LOGICAL_AND) reduce 13) ((T_LOGICAL_OR) reduce 13) ((T_LOGICAL_XOR) reduce 13) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 13) ((T_OBJECT_OPERATOR) reduce 13) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 13) ((T_POW) reduce 13) ((T_SL) reduce 13) ((T_SPACESHIP) reduce 13) ((T_SR) reduce 13) (("[") reduce 13) (("^") reduce 13) (("{") reduce 13) (("|") reduce 13)) 18901 ((("%") reduce 55) (("(") reduce 55) (("*") reduce 55) (("+") reduce 55) (("-") reduce 55) ((".") reduce 55) (("/") reduce 55) (("<") reduce 55) ((">") reduce 55) (("?") reduce 55) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_AS) reduce 55) ((T_BOOLEAN_AND) reduce 55) ((T_BOOLEAN_OR) reduce 55) ((T_COALESCE) reduce 55) ((T_DOUBLE_ARROW) reduce 55) ((T_INSTANCEOF) reduce 55) ((T_IS_EQUAL) reduce 55) ((T_IS_GREATER_OR_EQUAL) reduce 55) ((T_IS_IDENTICAL) reduce 55) ((T_IS_NOT_EQUAL) reduce 55) ((T_IS_NOT_IDENTICAL) reduce 55) ((T_IS_SMALLER_OR_EQUAL) reduce 55) ((T_LOGICAL_AND) reduce 55) ((T_LOGICAL_OR) reduce 55) ((T_LOGICAL_XOR) reduce 55) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 55) ((T_OBJECT_OPERATOR) reduce 55) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 55) ((T_POW) reduce 55) ((T_SL) reduce 55) ((T_SPACESHIP) reduce 55) ((T_SR) reduce 55) (("[") reduce 55) (("^") reduce 55) (("{") reduce 55) (("|") reduce 55)) 18902 ((("%") reduce 1) (("(") reduce 1) (("*") reduce 1) (("+") reduce 1) (("-") reduce 1) ((".") reduce 1) (("/") reduce 1) (("<") reduce 1) ((">") reduce 1) (("?") reduce 1) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_AS) reduce 1) ((T_BOOLEAN_AND) reduce 1) ((T_BOOLEAN_OR) reduce 1) ((T_COALESCE) reduce 1) ((T_DOUBLE_ARROW) reduce 1) ((T_INSTANCEOF) reduce 1) ((T_IS_EQUAL) reduce 1) ((T_IS_GREATER_OR_EQUAL) reduce 1) ((T_IS_IDENTICAL) reduce 1) ((T_IS_NOT_EQUAL) reduce 1) ((T_IS_NOT_IDENTICAL) reduce 1) ((T_IS_SMALLER_OR_EQUAL) reduce 1) ((T_LOGICAL_AND) reduce 1) ((T_LOGICAL_OR) reduce 1) ((T_LOGICAL_XOR) reduce 1) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 1) ((T_OBJECT_OPERATOR) reduce 1) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 1) ((T_POW) reduce 1) ((T_SL) reduce 1) ((T_SPACESHIP) reduce 1) ((T_SR) reduce 1) (("[") reduce 1) (("^") reduce 1) (("{") reduce 1) (("|") reduce 1)) 18903 ((("%") reduce 2) (("(") reduce 2) (("*") reduce 2) (("+") reduce 2) (("-") reduce 2) ((".") reduce 2) (("/") reduce 2) (("<") reduce 2) ((">") reduce 2) (("?") reduce 2) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_AS) reduce 2) ((T_BOOLEAN_AND) reduce 2) ((T_BOOLEAN_OR) reduce 2) ((T_COALESCE) reduce 2) ((T_DOUBLE_ARROW) reduce 2) ((T_INSTANCEOF) reduce 2) ((T_IS_EQUAL) reduce 2) ((T_IS_GREATER_OR_EQUAL) reduce 2) ((T_IS_IDENTICAL) reduce 2) ((T_IS_NOT_EQUAL) reduce 2) ((T_IS_NOT_IDENTICAL) reduce 2) ((T_IS_SMALLER_OR_EQUAL) reduce 2) ((T_LOGICAL_AND) reduce 2) ((T_LOGICAL_OR) reduce 2) ((T_LOGICAL_XOR) reduce 2) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 2) ((T_OBJECT_OPERATOR) reduce 2) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 2) ((T_POW) reduce 2) ((T_SL) reduce 2) ((T_SPACESHIP) reduce 2) ((T_SR) reduce 2) (("[") reduce 2) (("^") reduce 2) (("{") reduce 2) (("|") reduce 2)) 18904 ((("%") reduce 9) (("(") reduce 9) (("*") reduce 9) (("+") reduce 9) (("-") reduce 9) ((".") reduce 9) (("/") reduce 9) (("<") reduce 9) ((">") reduce 9) (("?") reduce 9) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_AS) reduce 9) ((T_BOOLEAN_AND) reduce 9) ((T_BOOLEAN_OR) reduce 9) ((T_COALESCE) reduce 9) ((T_DOUBLE_ARROW) reduce 9) ((T_INSTANCEOF) reduce 9) ((T_IS_EQUAL) reduce 9) ((T_IS_GREATER_OR_EQUAL) reduce 9) ((T_IS_IDENTICAL) reduce 9) ((T_IS_NOT_EQUAL) reduce 9) ((T_IS_NOT_IDENTICAL) reduce 9) ((T_IS_SMALLER_OR_EQUAL) reduce 9) ((T_LOGICAL_AND) reduce 9) ((T_LOGICAL_OR) reduce 9) ((T_LOGICAL_XOR) reduce 9) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 9) ((T_OBJECT_OPERATOR) reduce 9) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 9) ((T_POW) reduce 9) ((T_SL) reduce 9) ((T_SPACESHIP) reduce 9) ((T_SR) reduce 9) (("[") reduce 9) (("^") reduce 9) (("{") reduce 9) (("|") reduce 9)) 18905 ((("%") reduce 33) (("(") reduce 33) (("*") reduce 33) (("+") reduce 33) (("-") reduce 33) ((".") reduce 33) (("/") reduce 33) (("<") reduce 33) ((">") reduce 33) (("?") reduce 33) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_AS) reduce 33) ((T_BOOLEAN_AND) reduce 33) ((T_BOOLEAN_OR) reduce 33) ((T_COALESCE) reduce 33) ((T_DOUBLE_ARROW) reduce 33) ((T_INSTANCEOF) reduce 33) ((T_IS_EQUAL) reduce 33) ((T_IS_GREATER_OR_EQUAL) reduce 33) ((T_IS_IDENTICAL) reduce 33) ((T_IS_NOT_EQUAL) reduce 33) ((T_IS_NOT_IDENTICAL) reduce 33) ((T_IS_SMALLER_OR_EQUAL) reduce 33) ((T_LOGICAL_AND) reduce 33) ((T_LOGICAL_OR) reduce 33) ((T_LOGICAL_XOR) reduce 33) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 33) ((T_OBJECT_OPERATOR) reduce 33) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 33) ((T_POW) reduce 33) ((T_SL) reduce 33) ((T_SPACESHIP) reduce 33) ((T_SR) reduce 33) (("[") reduce 33) (("^") reduce 33) (("{") reduce 33) (("|") reduce 33)) 18906 ((("%") reduce 58) (("(") reduce 58) (("*") reduce 58) (("+") reduce 58) (("-") reduce 58) ((".") reduce 58) (("/") reduce 58) (("<") reduce 58) ((">") reduce 58) (("?") reduce 58) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_AS) reduce 58) ((T_BOOLEAN_AND) reduce 58) ((T_BOOLEAN_OR) reduce 58) ((T_COALESCE) reduce 58) ((T_DOUBLE_ARROW) reduce 58) ((T_INSTANCEOF) reduce 58) ((T_IS_EQUAL) reduce 58) ((T_IS_GREATER_OR_EQUAL) reduce 58) ((T_IS_IDENTICAL) reduce 58) ((T_IS_NOT_EQUAL) reduce 58) ((T_IS_NOT_IDENTICAL) reduce 58) ((T_IS_SMALLER_OR_EQUAL) reduce 58) ((T_LOGICAL_AND) reduce 58) ((T_LOGICAL_OR) reduce 58) ((T_LOGICAL_XOR) reduce 58) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 58) ((T_OBJECT_OPERATOR) reduce 58) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 58) ((T_POW) reduce 58) ((T_SL) reduce 58) ((T_SPACESHIP) reduce 58) ((T_SR) reduce 58) (("[") reduce 58) (("^") reduce 58) (("{") reduce 58) (("|") reduce 58)) 18907 ((("%") reduce 37) (("(") reduce 37) (("*") reduce 37) (("+") reduce 37) (("-") reduce 37) ((".") reduce 37) (("/") reduce 37) (("<") reduce 37) ((">") reduce 37) (("?") reduce 37) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_AS) reduce 37) ((T_BOOLEAN_AND) reduce 37) ((T_BOOLEAN_OR) reduce 37) ((T_COALESCE) reduce 37) ((T_DOUBLE_ARROW) reduce 37) ((T_INSTANCEOF) reduce 37) ((T_IS_EQUAL) reduce 37) ((T_IS_GREATER_OR_EQUAL) reduce 37) ((T_IS_IDENTICAL) reduce 37) ((T_IS_NOT_EQUAL) reduce 37) ((T_IS_NOT_IDENTICAL) reduce 37) ((T_IS_SMALLER_OR_EQUAL) reduce 37) ((T_LOGICAL_AND) reduce 37) ((T_LOGICAL_OR) reduce 37) ((T_LOGICAL_XOR) reduce 37) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 37) ((T_OBJECT_OPERATOR) reduce 37) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 37) ((T_POW) reduce 37) ((T_SL) reduce 37) ((T_SPACESHIP) reduce 37) ((T_SR) reduce 37) (("[") reduce 37) (("^") reduce 37) (("{") reduce 37) (("|") reduce 37)) 18908 ((("%") reduce 64) (("(") reduce 64) (("*") reduce 64) (("+") reduce 64) (("-") reduce 64) ((".") reduce 64) (("/") reduce 64) (("<") reduce 64) ((">") reduce 64) (("?") reduce 64) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_AS) reduce 64) ((T_BOOLEAN_AND) reduce 64) ((T_BOOLEAN_OR) reduce 64) ((T_COALESCE) reduce 64) ((T_DOUBLE_ARROW) reduce 64) ((T_INSTANCEOF) reduce 64) ((T_IS_EQUAL) reduce 64) ((T_IS_GREATER_OR_EQUAL) reduce 64) ((T_IS_IDENTICAL) reduce 64) ((T_IS_NOT_EQUAL) reduce 64) ((T_IS_NOT_IDENTICAL) reduce 64) ((T_IS_SMALLER_OR_EQUAL) reduce 64) ((T_LOGICAL_AND) reduce 64) ((T_LOGICAL_OR) reduce 64) ((T_LOGICAL_XOR) reduce 64) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 64) ((T_OBJECT_OPERATOR) reduce 64) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 64) ((T_POW) reduce 64) ((T_SL) reduce 64) ((T_SPACESHIP) reduce 64) ((T_SR) reduce 64) (("[") reduce 64) (("^") reduce 64) (("{") reduce 64) (("|") reduce 64)) 18909 ((("%") reduce 46) (("(") reduce 46) (("*") reduce 46) (("+") reduce 46) (("-") reduce 46) ((".") reduce 46) (("/") reduce 46) (("<") reduce 46) ((">") reduce 46) (("?") reduce 46) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_AS) reduce 46) ((T_BOOLEAN_AND) reduce 46) ((T_BOOLEAN_OR) reduce 46) ((T_COALESCE) reduce 46) ((T_DOUBLE_ARROW) reduce 46) ((T_INSTANCEOF) reduce 46) ((T_IS_EQUAL) reduce 46) ((T_IS_GREATER_OR_EQUAL) reduce 46) ((T_IS_IDENTICAL) reduce 46) ((T_IS_NOT_EQUAL) reduce 46) ((T_IS_NOT_IDENTICAL) reduce 46) ((T_IS_SMALLER_OR_EQUAL) reduce 46) ((T_LOGICAL_AND) reduce 46) ((T_LOGICAL_OR) reduce 46) ((T_LOGICAL_XOR) reduce 46) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 46) ((T_OBJECT_OPERATOR) reduce 46) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 46) ((T_POW) reduce 46) ((T_SL) reduce 46) ((T_SPACESHIP) reduce 46) ((T_SR) reduce 46) (("[") reduce 46) (("^") reduce 46) (("{") reduce 46) (("|") reduce 46)) 18910 ((("%") reduce 8) (("(") reduce 8) (("*") reduce 8) (("+") reduce 8) (("-") reduce 8) ((".") reduce 8) (("/") reduce 8) (("<") reduce 8) ((">") reduce 8) (("?") reduce 8) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_AS) reduce 8) ((T_BOOLEAN_AND) reduce 8) ((T_BOOLEAN_OR) reduce 8) ((T_COALESCE) reduce 8) ((T_DOUBLE_ARROW) reduce 8) ((T_INSTANCEOF) reduce 8) ((T_IS_EQUAL) reduce 8) ((T_IS_GREATER_OR_EQUAL) reduce 8) ((T_IS_IDENTICAL) reduce 8) ((T_IS_NOT_EQUAL) reduce 8) ((T_IS_NOT_IDENTICAL) reduce 8) ((T_IS_SMALLER_OR_EQUAL) reduce 8) ((T_LOGICAL_AND) reduce 8) ((T_LOGICAL_OR) reduce 8) ((T_LOGICAL_XOR) reduce 8) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 8) ((T_OBJECT_OPERATOR) reduce 8) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 8) ((T_POW) reduce 8) ((T_SL) reduce 8) ((T_SPACESHIP) reduce 8) ((T_SR) reduce 8) (("[") reduce 8) (("^") reduce 8) (("{") reduce 8) (("|") reduce 8)) 18911 ((("%") reduce 6) (("(") reduce 6) (("*") reduce 6) (("+") reduce 6) (("-") reduce 6) ((".") reduce 6) (("/") reduce 6) (("<") reduce 6) ((">") reduce 6) (("?") reduce 6) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_AS) reduce 6) ((T_BOOLEAN_AND) reduce 6) ((T_BOOLEAN_OR) reduce 6) ((T_COALESCE) reduce 6) ((T_DOUBLE_ARROW) reduce 6) ((T_INSTANCEOF) reduce 6) ((T_IS_EQUAL) reduce 6) ((T_IS_GREATER_OR_EQUAL) reduce 6) ((T_IS_IDENTICAL) reduce 6) ((T_IS_NOT_EQUAL) reduce 6) ((T_IS_NOT_IDENTICAL) reduce 6) ((T_IS_SMALLER_OR_EQUAL) reduce 6) ((T_LOGICAL_AND) reduce 6) ((T_LOGICAL_OR) reduce 6) ((T_LOGICAL_XOR) reduce 6) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 6) ((T_OBJECT_OPERATOR) reduce 6) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 6) ((T_POW) reduce 6) ((T_SL) reduce 6) ((T_SPACESHIP) reduce 6) ((T_SR) reduce 6) (("[") reduce 6) (("^") reduce 6) (("{") reduce 6) (("|") reduce 6)) 18912 ((("%") reduce 7) (("(") reduce 7) (("*") reduce 7) (("+") reduce 7) (("-") reduce 7) ((".") reduce 7) (("/") reduce 7) (("<") reduce 7) ((">") reduce 7) (("?") reduce 7) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_AS) reduce 7) ((T_BOOLEAN_AND) reduce 7) ((T_BOOLEAN_OR) reduce 7) ((T_COALESCE) reduce 7) ((T_DOUBLE_ARROW) reduce 7) ((T_INSTANCEOF) reduce 7) ((T_IS_EQUAL) reduce 7) ((T_IS_GREATER_OR_EQUAL) reduce 7) ((T_IS_IDENTICAL) reduce 7) ((T_IS_NOT_EQUAL) reduce 7) ((T_IS_NOT_IDENTICAL) reduce 7) ((T_IS_SMALLER_OR_EQUAL) reduce 7) ((T_LOGICAL_AND) reduce 7) ((T_LOGICAL_OR) reduce 7) ((T_LOGICAL_XOR) reduce 7) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 7) ((T_OBJECT_OPERATOR) reduce 7) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 7) ((T_POW) reduce 7) ((T_SL) reduce 7) ((T_SPACESHIP) reduce 7) ((T_SR) reduce 7) (("[") reduce 7) (("^") reduce 7) (("{") reduce 7) (("|") reduce 7)) 18913 ((("%") reduce 69) (("(") reduce 69) (("*") reduce 69) (("+") reduce 69) (("-") reduce 69) ((".") reduce 69) (("/") reduce 69) (("<") reduce 69) ((">") reduce 69) (("?") reduce 69) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_AS) reduce 69) ((T_BOOLEAN_AND) reduce 69) ((T_BOOLEAN_OR) reduce 69) ((T_COALESCE) reduce 69) ((T_DOUBLE_ARROW) reduce 69) ((T_INSTANCEOF) reduce 69) ((T_IS_EQUAL) reduce 69) ((T_IS_GREATER_OR_EQUAL) reduce 69) ((T_IS_IDENTICAL) reduce 69) ((T_IS_NOT_EQUAL) reduce 69) ((T_IS_NOT_IDENTICAL) reduce 69) ((T_IS_SMALLER_OR_EQUAL) reduce 69) ((T_LOGICAL_AND) reduce 69) ((T_LOGICAL_OR) reduce 69) ((T_LOGICAL_XOR) reduce 69) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 69) ((T_OBJECT_OPERATOR) reduce 69) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 69) ((T_POW) reduce 69) ((T_SL) reduce 69) ((T_SPACESHIP) reduce 69) ((T_SR) reduce 69) (("[") reduce 69) (("^") reduce 69) (("{") reduce 69) (("|") reduce 69)) 18914 ((("%") reduce 63) (("(") reduce 63) (("*") reduce 63) (("+") reduce 63) (("-") reduce 63) ((".") reduce 63) (("/") reduce 63) (("<") reduce 63) ((">") reduce 63) (("?") reduce 63) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_AS) reduce 63) ((T_BOOLEAN_AND) reduce 63) ((T_BOOLEAN_OR) reduce 63) ((T_COALESCE) reduce 63) ((T_DOUBLE_ARROW) reduce 63) ((T_INSTANCEOF) reduce 63) ((T_IS_EQUAL) reduce 63) ((T_IS_GREATER_OR_EQUAL) reduce 63) ((T_IS_IDENTICAL) reduce 63) ((T_IS_NOT_EQUAL) reduce 63) ((T_IS_NOT_IDENTICAL) reduce 63) ((T_IS_SMALLER_OR_EQUAL) reduce 63) ((T_LOGICAL_AND) reduce 63) ((T_LOGICAL_OR) reduce 63) ((T_LOGICAL_XOR) reduce 63) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 63) ((T_OBJECT_OPERATOR) reduce 63) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 63) ((T_POW) reduce 63) ((T_SL) reduce 63) ((T_SPACESHIP) reduce 63) ((T_SR) reduce 63) (("[") reduce 63) (("^") reduce 63) (("{") reduce 63) (("|") reduce 63)) 18915 ((("%") reduce 56) (("(") reduce 56) (("*") reduce 56) (("+") reduce 56) (("-") reduce 56) ((".") reduce 56) (("/") reduce 56) (("<") reduce 56) ((">") reduce 56) (("?") reduce 56) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_AS) reduce 56) ((T_BOOLEAN_AND) reduce 56) ((T_BOOLEAN_OR) reduce 56) ((T_COALESCE) reduce 56) ((T_DOUBLE_ARROW) reduce 56) ((T_INSTANCEOF) reduce 56) ((T_IS_EQUAL) reduce 56) ((T_IS_GREATER_OR_EQUAL) reduce 56) ((T_IS_IDENTICAL) reduce 56) ((T_IS_NOT_EQUAL) reduce 56) ((T_IS_NOT_IDENTICAL) reduce 56) ((T_IS_SMALLER_OR_EQUAL) reduce 56) ((T_LOGICAL_AND) reduce 56) ((T_LOGICAL_OR) reduce 56) ((T_LOGICAL_XOR) reduce 56) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 56) ((T_OBJECT_OPERATOR) reduce 56) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 56) ((T_POW) reduce 56) ((T_SL) reduce 56) ((T_SPACESHIP) reduce 56) ((T_SR) reduce 56) (("[") reduce 56) (("^") reduce 56) (("{") reduce 56) (("|") reduce 56)) 18916 ((("%") reduce 10) (("(") reduce 10) (("*") reduce 10) (("+") reduce 10) (("-") reduce 10) ((".") reduce 10) (("/") reduce 10) (("<") reduce 10) ((">") reduce 10) (("?") reduce 10) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_AS) reduce 10) ((T_BOOLEAN_AND) reduce 10) ((T_BOOLEAN_OR) reduce 10) ((T_COALESCE) reduce 10) ((T_DOUBLE_ARROW) reduce 10) ((T_INSTANCEOF) reduce 10) ((T_IS_EQUAL) reduce 10) ((T_IS_GREATER_OR_EQUAL) reduce 10) ((T_IS_IDENTICAL) reduce 10) ((T_IS_NOT_EQUAL) reduce 10) ((T_IS_NOT_IDENTICAL) reduce 10) ((T_IS_SMALLER_OR_EQUAL) reduce 10) ((T_LOGICAL_AND) reduce 10) ((T_LOGICAL_OR) reduce 10) ((T_LOGICAL_XOR) reduce 10) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 10) ((T_OBJECT_OPERATOR) reduce 10) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 10) ((T_POW) reduce 10) ((T_SL) reduce 10) ((T_SPACESHIP) reduce 10) ((T_SR) reduce 10) (("[") reduce 10) (("^") reduce 10) (("{") reduce 10) (("|") reduce 10)) 18917 ((("%") reduce 67) (("(") reduce 67) (("*") reduce 67) (("+") reduce 67) (("-") reduce 67) ((".") reduce 67) (("/") reduce 67) (("<") reduce 67) ((">") reduce 67) (("?") reduce 67) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_AS) reduce 67) ((T_BOOLEAN_AND) reduce 67) ((T_BOOLEAN_OR) reduce 67) ((T_COALESCE) reduce 67) ((T_DOUBLE_ARROW) reduce 67) ((T_INSTANCEOF) reduce 67) ((T_IS_EQUAL) reduce 67) ((T_IS_GREATER_OR_EQUAL) reduce 67) ((T_IS_IDENTICAL) reduce 67) ((T_IS_NOT_EQUAL) reduce 67) ((T_IS_NOT_IDENTICAL) reduce 67) ((T_IS_SMALLER_OR_EQUAL) reduce 67) ((T_LOGICAL_AND) reduce 67) ((T_LOGICAL_OR) reduce 67) ((T_LOGICAL_XOR) reduce 67) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 67) ((T_OBJECT_OPERATOR) reduce 67) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 67) ((T_POW) reduce 67) ((T_SL) reduce 67) ((T_SPACESHIP) reduce 67) ((T_SR) reduce 67) (("[") reduce 67) (("^") reduce 67) (("{") reduce 67) (("|") reduce 67)) 18918 ((("%") reduce 44) (("(") reduce 44) (("*") reduce 44) (("+") reduce 44) (("-") reduce 44) ((".") reduce 44) (("/") reduce 44) (("<") reduce 44) ((">") reduce 44) (("?") reduce 44) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_AS) reduce 44) ((T_BOOLEAN_AND) reduce 44) ((T_BOOLEAN_OR) reduce 44) ((T_COALESCE) reduce 44) ((T_DOUBLE_ARROW) reduce 44) ((T_INSTANCEOF) reduce 44) ((T_IS_EQUAL) reduce 44) ((T_IS_GREATER_OR_EQUAL) reduce 44) ((T_IS_IDENTICAL) reduce 44) ((T_IS_NOT_EQUAL) reduce 44) ((T_IS_NOT_IDENTICAL) reduce 44) ((T_IS_SMALLER_OR_EQUAL) reduce 44) ((T_LOGICAL_AND) reduce 44) ((T_LOGICAL_OR) reduce 44) ((T_LOGICAL_XOR) reduce 44) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 44) ((T_OBJECT_OPERATOR) reduce 44) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 44) ((T_POW) reduce 44) ((T_SL) reduce 44) ((T_SPACESHIP) reduce 44) ((T_SR) reduce 44) (("[") reduce 44) (("^") reduce 44) (("{") reduce 44) (("|") reduce 44)) 18919 ((("%") reduce 75) (("(") reduce 75) (("*") reduce 75) (("+") reduce 75) (("-") reduce 75) ((".") reduce 75) (("/") reduce 75) (("<") reduce 75) ((">") reduce 75) (("?") reduce 75) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_AS) reduce 75) ((T_BOOLEAN_AND) reduce 75) ((T_BOOLEAN_OR) reduce 75) ((T_COALESCE) reduce 75) ((T_DOUBLE_ARROW) reduce 75) ((T_INSTANCEOF) reduce 75) ((T_IS_EQUAL) reduce 75) ((T_IS_GREATER_OR_EQUAL) reduce 75) ((T_IS_IDENTICAL) reduce 75) ((T_IS_NOT_EQUAL) reduce 75) ((T_IS_NOT_IDENTICAL) reduce 75) ((T_IS_SMALLER_OR_EQUAL) reduce 75) ((T_LOGICAL_AND) reduce 75) ((T_LOGICAL_OR) reduce 75) ((T_LOGICAL_XOR) reduce 75) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 75) ((T_OBJECT_OPERATOR) reduce 75) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 75) ((T_POW) reduce 75) ((T_SL) reduce 75) ((T_SPACESHIP) reduce 75) ((T_SR) reduce 75) (("[") reduce 75) (("^") reduce 75) (("{") reduce 75) (("|") reduce 75)) 18920 ((("%") reduce 76) (("(") reduce 76) (("*") reduce 76) (("+") reduce 76) (("-") reduce 76) ((".") reduce 76) (("/") reduce 76) (("<") reduce 76) ((">") reduce 76) (("?") reduce 76) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_AS) reduce 76) ((T_BOOLEAN_AND) reduce 76) ((T_BOOLEAN_OR) reduce 76) ((T_COALESCE) reduce 76) ((T_DOUBLE_ARROW) reduce 76) ((T_INSTANCEOF) reduce 76) ((T_IS_EQUAL) reduce 76) ((T_IS_GREATER_OR_EQUAL) reduce 76) ((T_IS_IDENTICAL) reduce 76) ((T_IS_NOT_EQUAL) reduce 76) ((T_IS_NOT_IDENTICAL) reduce 76) ((T_IS_SMALLER_OR_EQUAL) reduce 76) ((T_LOGICAL_AND) reduce 76) ((T_LOGICAL_OR) reduce 76) ((T_LOGICAL_XOR) reduce 76) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 76) ((T_OBJECT_OPERATOR) reduce 76) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 76) ((T_POW) reduce 76) ((T_SL) reduce 76) ((T_SPACESHIP) reduce 76) ((T_SR) reduce 76) (("[") reduce 76) (("^") reduce 76) (("{") reduce 76) (("|") reduce 76)) 18921 ((("%") reduce 77) (("(") reduce 77) (("*") reduce 77) (("+") reduce 77) (("-") reduce 77) ((".") reduce 77) (("/") reduce 77) (("<") reduce 77) ((">") reduce 77) (("?") reduce 77) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_AS) reduce 77) ((T_BOOLEAN_AND) reduce 77) ((T_BOOLEAN_OR) reduce 77) ((T_COALESCE) reduce 77) ((T_DOUBLE_ARROW) reduce 77) ((T_INSTANCEOF) reduce 77) ((T_IS_EQUAL) reduce 77) ((T_IS_GREATER_OR_EQUAL) reduce 77) ((T_IS_IDENTICAL) reduce 77) ((T_IS_NOT_EQUAL) reduce 77) ((T_IS_NOT_IDENTICAL) reduce 77) ((T_IS_SMALLER_OR_EQUAL) reduce 77) ((T_LOGICAL_AND) reduce 77) ((T_LOGICAL_OR) reduce 77) ((T_LOGICAL_XOR) reduce 77) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 77) ((T_OBJECT_OPERATOR) reduce 77) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 77) ((T_POW) reduce 77) ((T_SL) reduce 77) ((T_SPACESHIP) reduce 77) ((T_SR) reduce 77) (("[") reduce 77) (("^") reduce 77) (("{") reduce 77) (("|") reduce 77)) 18922 ((("%") reduce 78) (("(") reduce 78) (("*") reduce 78) (("+") reduce 78) (("-") reduce 78) ((".") reduce 78) (("/") reduce 78) (("<") reduce 78) ((">") reduce 78) (("?") reduce 78) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_AS) reduce 78) ((T_BOOLEAN_AND) reduce 78) ((T_BOOLEAN_OR) reduce 78) ((T_COALESCE) reduce 78) ((T_DOUBLE_ARROW) reduce 78) ((T_INSTANCEOF) reduce 78) ((T_IS_EQUAL) reduce 78) ((T_IS_GREATER_OR_EQUAL) reduce 78) ((T_IS_IDENTICAL) reduce 78) ((T_IS_NOT_EQUAL) reduce 78) ((T_IS_NOT_IDENTICAL) reduce 78) ((T_IS_SMALLER_OR_EQUAL) reduce 78) ((T_LOGICAL_AND) reduce 78) ((T_LOGICAL_OR) reduce 78) ((T_LOGICAL_XOR) reduce 78) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 78) ((T_OBJECT_OPERATOR) reduce 78) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 78) ((T_POW) reduce 78) ((T_SL) reduce 78) ((T_SPACESHIP) reduce 78) ((T_SR) reduce 78) (("[") reduce 78) (("^") reduce 78) (("{") reduce 78) (("|") reduce 78)) 18923 ((("%") reduce 4) (("(") reduce 4) (("*") reduce 4) (("+") reduce 4) (("-") reduce 4) ((".") reduce 4) (("/") reduce 4) (("<") reduce 4) ((">") reduce 4) (("?") reduce 4) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_AS) reduce 4) ((T_BOOLEAN_AND) reduce 4) ((T_BOOLEAN_OR) reduce 4) ((T_COALESCE) reduce 4) ((T_DOUBLE_ARROW) reduce 4) ((T_INSTANCEOF) reduce 4) ((T_IS_EQUAL) reduce 4) ((T_IS_GREATER_OR_EQUAL) reduce 4) ((T_IS_IDENTICAL) reduce 4) ((T_IS_NOT_EQUAL) reduce 4) ((T_IS_NOT_IDENTICAL) reduce 4) ((T_IS_SMALLER_OR_EQUAL) reduce 4) ((T_LOGICAL_AND) reduce 4) ((T_LOGICAL_OR) reduce 4) ((T_LOGICAL_XOR) reduce 4) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 4) ((T_OBJECT_OPERATOR) reduce 4) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 4) ((T_POW) reduce 4) ((T_SL) reduce 4) ((T_SPACESHIP) reduce 4) ((T_SR) reduce 4) (("[") reduce 4) (("^") reduce 4) (("{") reduce 4) (("|") reduce 4)) 18924 ((("%") reduce 5) (("(") reduce 5) (("*") reduce 5) (("+") reduce 5) (("-") reduce 5) ((".") reduce 5) (("/") reduce 5) (("<") reduce 5) ((">") reduce 5) (("?") reduce 5) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_AS) reduce 5) ((T_BOOLEAN_AND) reduce 5) ((T_BOOLEAN_OR) reduce 5) ((T_COALESCE) reduce 5) ((T_DOUBLE_ARROW) reduce 5) ((T_INSTANCEOF) reduce 5) ((T_IS_EQUAL) reduce 5) ((T_IS_GREATER_OR_EQUAL) reduce 5) ((T_IS_IDENTICAL) reduce 5) ((T_IS_NOT_EQUAL) reduce 5) ((T_IS_NOT_IDENTICAL) reduce 5) ((T_IS_SMALLER_OR_EQUAL) reduce 5) ((T_LOGICAL_AND) reduce 5) ((T_LOGICAL_OR) reduce 5) ((T_LOGICAL_XOR) reduce 5) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 5) ((T_OBJECT_OPERATOR) reduce 5) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 5) ((T_POW) reduce 5) ((T_SL) reduce 5) ((T_SPACESHIP) reduce 5) ((T_SR) reduce 5) (("[") reduce 5) (("^") reduce 5) (("{") reduce 5) (("|") reduce 5)) 18925 ((("%") reduce 43) (("(") reduce 43) (("*") reduce 43) (("+") reduce 43) (("-") reduce 43) ((".") reduce 43) (("/") reduce 43) (("<") reduce 43) ((">") reduce 43) (("?") reduce 43) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_AS) reduce 43) ((T_BOOLEAN_AND) reduce 43) ((T_BOOLEAN_OR) reduce 43) ((T_COALESCE) reduce 43) ((T_DOUBLE_ARROW) reduce 43) ((T_INSTANCEOF) reduce 43) ((T_IS_EQUAL) reduce 43) ((T_IS_GREATER_OR_EQUAL) reduce 43) ((T_IS_IDENTICAL) reduce 43) ((T_IS_NOT_EQUAL) reduce 43) ((T_IS_NOT_IDENTICAL) reduce 43) ((T_IS_SMALLER_OR_EQUAL) reduce 43) ((T_LOGICAL_AND) reduce 43) ((T_LOGICAL_OR) reduce 43) ((T_LOGICAL_XOR) reduce 43) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 43) ((T_OBJECT_OPERATOR) reduce 43) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 43) ((T_POW) reduce 43) ((T_SL) reduce 43) ((T_SPACESHIP) reduce 43) ((T_SR) reduce 43) (("[") reduce 43) (("^") reduce 43) (("{") reduce 43) (("|") reduce 43)) 18926 ((("%") reduce 72) (("(") reduce 72) (("*") reduce 72) (("+") reduce 72) (("-") reduce 72) ((".") reduce 72) (("/") reduce 72) (("<") reduce 72) ((">") reduce 72) (("?") reduce 72) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_AS) reduce 72) ((T_BOOLEAN_AND) reduce 72) ((T_BOOLEAN_OR) reduce 72) ((T_COALESCE) reduce 72) ((T_DOUBLE_ARROW) reduce 72) ((T_INSTANCEOF) reduce 72) ((T_IS_EQUAL) reduce 72) ((T_IS_GREATER_OR_EQUAL) reduce 72) ((T_IS_IDENTICAL) reduce 72) ((T_IS_NOT_EQUAL) reduce 72) ((T_IS_NOT_IDENTICAL) reduce 72) ((T_IS_SMALLER_OR_EQUAL) reduce 72) ((T_LOGICAL_AND) reduce 72) ((T_LOGICAL_OR) reduce 72) ((T_LOGICAL_XOR) reduce 72) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 72) ((T_OBJECT_OPERATOR) reduce 72) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 72) ((T_POW) reduce 72) ((T_SL) reduce 72) ((T_SPACESHIP) reduce 72) ((T_SR) reduce 72) (("[") reduce 72) (("^") reduce 72) (("{") reduce 72) (("|") reduce 72)) 18927 ((("%") reduce 81) (("(") reduce 81) (("*") reduce 81) (("+") reduce 81) (("-") reduce 81) ((".") reduce 81) (("/") reduce 81) (("<") reduce 81) ((">") reduce 81) (("?") reduce 81) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_AS) reduce 81) ((T_BOOLEAN_AND) reduce 81) ((T_BOOLEAN_OR) reduce 81) ((T_COALESCE) reduce 81) ((T_DOUBLE_ARROW) reduce 81) ((T_INSTANCEOF) reduce 81) ((T_IS_EQUAL) reduce 81) ((T_IS_GREATER_OR_EQUAL) reduce 81) ((T_IS_IDENTICAL) reduce 81) ((T_IS_NOT_EQUAL) reduce 81) ((T_IS_NOT_IDENTICAL) reduce 81) ((T_IS_SMALLER_OR_EQUAL) reduce 81) ((T_LOGICAL_AND) reduce 81) ((T_LOGICAL_OR) reduce 81) ((T_LOGICAL_XOR) reduce 81) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 81) ((T_OBJECT_OPERATOR) reduce 81) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 81) ((T_POW) reduce 81) ((T_SL) reduce 81) ((T_SPACESHIP) reduce 81) ((T_SR) reduce 81) (("[") reduce 81) (("^") reduce 81) (("{") reduce 81) (("|") reduce 81)) 18928 ((("%") reduce 47) (("(") reduce 47) (("*") reduce 47) (("+") reduce 47) (("-") reduce 47) ((".") reduce 47) (("/") reduce 47) (("<") reduce 47) ((">") reduce 47) (("?") reduce 47) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_AS) reduce 47) ((T_BOOLEAN_AND) reduce 47) ((T_BOOLEAN_OR) reduce 47) ((T_COALESCE) reduce 47) ((T_DOUBLE_ARROW) reduce 47) ((T_INSTANCEOF) reduce 47) ((T_IS_EQUAL) reduce 47) ((T_IS_GREATER_OR_EQUAL) reduce 47) ((T_IS_IDENTICAL) reduce 47) ((T_IS_NOT_EQUAL) reduce 47) ((T_IS_NOT_IDENTICAL) reduce 47) ((T_IS_SMALLER_OR_EQUAL) reduce 47) ((T_LOGICAL_AND) reduce 47) ((T_LOGICAL_OR) reduce 47) ((T_LOGICAL_XOR) reduce 47) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 47) ((T_OBJECT_OPERATOR) reduce 47) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 47) ((T_POW) reduce 47) ((T_SL) reduce 47) ((T_SPACESHIP) reduce 47) ((T_SR) reduce 47) (("[") reduce 47) (("^") reduce 47) (("{") reduce 47) (("|") reduce 47)) 18929 ((("%") reduce 31) (("(") reduce 31) (("*") reduce 31) (("+") reduce 31) (("-") reduce 31) ((".") reduce 31) (("/") reduce 31) (("<") reduce 31) ((">") reduce 31) (("?") reduce 31) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_AS) reduce 31) ((T_BOOLEAN_AND) reduce 31) ((T_BOOLEAN_OR) reduce 31) ((T_COALESCE) reduce 31) ((T_DOUBLE_ARROW) reduce 31) ((T_INSTANCEOF) reduce 31) ((T_IS_EQUAL) reduce 31) ((T_IS_GREATER_OR_EQUAL) reduce 31) ((T_IS_IDENTICAL) reduce 31) ((T_IS_NOT_EQUAL) reduce 31) ((T_IS_NOT_IDENTICAL) reduce 31) ((T_IS_SMALLER_OR_EQUAL) reduce 31) ((T_LOGICAL_AND) reduce 31) ((T_LOGICAL_OR) reduce 31) ((T_LOGICAL_XOR) reduce 31) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 31) ((T_OBJECT_OPERATOR) reduce 31) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 31) ((T_POW) reduce 31) ((T_SL) reduce 31) ((T_SPACESHIP) reduce 31) ((T_SR) reduce 31) (("[") reduce 31) (("^") reduce 31) (("{") reduce 31) (("|") reduce 31)) 18930 ((("%") reduce 57) (("(") reduce 57) (("*") reduce 57) (("+") reduce 57) (("-") reduce 57) ((".") reduce 57) (("/") reduce 57) (("<") reduce 57) ((">") reduce 57) (("?") reduce 57) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_AS) reduce 57) ((T_BOOLEAN_AND) reduce 57) ((T_BOOLEAN_OR) reduce 57) ((T_COALESCE) reduce 57) ((T_DOUBLE_ARROW) reduce 57) ((T_INSTANCEOF) reduce 57) ((T_IS_EQUAL) reduce 57) ((T_IS_GREATER_OR_EQUAL) reduce 57) ((T_IS_IDENTICAL) reduce 57) ((T_IS_NOT_EQUAL) reduce 57) ((T_IS_NOT_IDENTICAL) reduce 57) ((T_IS_SMALLER_OR_EQUAL) reduce 57) ((T_LOGICAL_AND) reduce 57) ((T_LOGICAL_OR) reduce 57) ((T_LOGICAL_XOR) reduce 57) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 57) ((T_OBJECT_OPERATOR) reduce 57) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 57) ((T_POW) reduce 57) ((T_SL) reduce 57) ((T_SPACESHIP) reduce 57) ((T_SR) reduce 57) (("[") reduce 57) (("^") reduce 57) (("{") reduce 57) (("|") reduce 57)) 18931 ((("%") reduce 61) (("(") reduce 61) (("*") reduce 61) (("+") reduce 61) (("-") reduce 61) ((".") reduce 61) (("/") reduce 61) (("<") reduce 61) ((">") reduce 61) (("?") reduce 61) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_AS) reduce 61) ((T_BOOLEAN_AND) reduce 61) ((T_BOOLEAN_OR) reduce 61) ((T_COALESCE) reduce 61) ((T_DOUBLE_ARROW) reduce 61) ((T_INSTANCEOF) reduce 61) ((T_IS_EQUAL) reduce 61) ((T_IS_GREATER_OR_EQUAL) reduce 61) ((T_IS_IDENTICAL) reduce 61) ((T_IS_NOT_EQUAL) reduce 61) ((T_IS_NOT_IDENTICAL) reduce 61) ((T_IS_SMALLER_OR_EQUAL) reduce 61) ((T_LOGICAL_AND) reduce 61) ((T_LOGICAL_OR) reduce 61) ((T_LOGICAL_XOR) reduce 61) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 61) ((T_OBJECT_OPERATOR) reduce 61) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 61) ((T_POW) reduce 61) ((T_SL) reduce 61) ((T_SPACESHIP) reduce 61) ((T_SR) reduce 61) (("[") reduce 61) (("^") reduce 61) (("{") reduce 61) (("|") reduce 61)) 18932 ((("%") reduce 28) (("(") reduce 28) (("*") reduce 28) (("+") reduce 28) (("-") reduce 28) ((".") reduce 28) (("/") reduce 28) (("<") reduce 28) ((">") reduce 28) (("?") reduce 28) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_AS) reduce 28) ((T_BOOLEAN_AND) reduce 28) ((T_BOOLEAN_OR) reduce 28) ((T_COALESCE) reduce 28) ((T_DOUBLE_ARROW) reduce 28) ((T_INSTANCEOF) reduce 28) ((T_IS_EQUAL) reduce 28) ((T_IS_GREATER_OR_EQUAL) reduce 28) ((T_IS_IDENTICAL) reduce 28) ((T_IS_NOT_EQUAL) reduce 28) ((T_IS_NOT_IDENTICAL) reduce 28) ((T_IS_SMALLER_OR_EQUAL) reduce 28) ((T_LOGICAL_AND) reduce 28) ((T_LOGICAL_OR) reduce 28) ((T_LOGICAL_XOR) reduce 28) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 28) ((T_OBJECT_OPERATOR) reduce 28) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 28) ((T_POW) reduce 28) ((T_SL) reduce 28) ((T_SPACESHIP) reduce 28) ((T_SR) reduce 28) (("[") reduce 28) (("^") reduce 28) (("{") reduce 28) (("|") reduce 28)) 18933 ((("%") reduce 36) (("(") reduce 36) (("*") reduce 36) (("+") reduce 36) (("-") reduce 36) ((".") reduce 36) (("/") reduce 36) (("<") reduce 36) ((">") reduce 36) (("?") reduce 36) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_AS) reduce 36) ((T_BOOLEAN_AND) reduce 36) ((T_BOOLEAN_OR) reduce 36) ((T_COALESCE) reduce 36) ((T_DOUBLE_ARROW) reduce 36) ((T_INSTANCEOF) reduce 36) ((T_IS_EQUAL) reduce 36) ((T_IS_GREATER_OR_EQUAL) reduce 36) ((T_IS_IDENTICAL) reduce 36) ((T_IS_NOT_EQUAL) reduce 36) ((T_IS_NOT_IDENTICAL) reduce 36) ((T_IS_SMALLER_OR_EQUAL) reduce 36) ((T_LOGICAL_AND) reduce 36) ((T_LOGICAL_OR) reduce 36) ((T_LOGICAL_XOR) reduce 36) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 36) ((T_OBJECT_OPERATOR) reduce 36) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 36) ((T_POW) reduce 36) ((T_SL) reduce 36) ((T_SPACESHIP) reduce 36) ((T_SR) reduce 36) (("[") reduce 36) (("^") reduce 36) (("{") reduce 36) (("|") reduce 36)) 18934 ((("%") reduce 32) (("(") reduce 32) (("*") reduce 32) (("+") reduce 32) (("-") reduce 32) ((".") reduce 32) (("/") reduce 32) (("<") reduce 32) ((">") reduce 32) (("?") reduce 32) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_AS) reduce 32) ((T_BOOLEAN_AND) reduce 32) ((T_BOOLEAN_OR) reduce 32) ((T_COALESCE) reduce 32) ((T_DOUBLE_ARROW) reduce 32) ((T_INSTANCEOF) reduce 32) ((T_IS_EQUAL) reduce 32) ((T_IS_GREATER_OR_EQUAL) reduce 32) ((T_IS_IDENTICAL) reduce 32) ((T_IS_NOT_EQUAL) reduce 32) ((T_IS_NOT_IDENTICAL) reduce 32) ((T_IS_SMALLER_OR_EQUAL) reduce 32) ((T_LOGICAL_AND) reduce 32) ((T_LOGICAL_OR) reduce 32) ((T_LOGICAL_XOR) reduce 32) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 32) ((T_OBJECT_OPERATOR) reduce 32) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 32) ((T_POW) reduce 32) ((T_SL) reduce 32) ((T_SPACESHIP) reduce 32) ((T_SR) reduce 32) (("[") reduce 32) (("^") reduce 32) (("{") reduce 32) (("|") reduce 32)) 18935 ((("%") reduce 35) (("(") reduce 35) (("*") reduce 35) (("+") reduce 35) (("-") reduce 35) ((".") reduce 35) (("/") reduce 35) (("<") reduce 35) ((">") reduce 35) (("?") reduce 35) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_AS) reduce 35) ((T_BOOLEAN_AND) reduce 35) ((T_BOOLEAN_OR) reduce 35) ((T_COALESCE) reduce 35) ((T_DOUBLE_ARROW) reduce 35) ((T_INSTANCEOF) reduce 35) ((T_IS_EQUAL) reduce 35) ((T_IS_GREATER_OR_EQUAL) reduce 35) ((T_IS_IDENTICAL) reduce 35) ((T_IS_NOT_EQUAL) reduce 35) ((T_IS_NOT_IDENTICAL) reduce 35) ((T_IS_SMALLER_OR_EQUAL) reduce 35) ((T_LOGICAL_AND) reduce 35) ((T_LOGICAL_OR) reduce 35) ((T_LOGICAL_XOR) reduce 35) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 35) ((T_OBJECT_OPERATOR) reduce 35) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 35) ((T_POW) reduce 35) ((T_SL) reduce 35) ((T_SPACESHIP) reduce 35) ((T_SR) reduce 35) (("[") reduce 35) (("^") reduce 35) (("{") reduce 35) (("|") reduce 35)) 18936 ((("%") reduce 19) (("(") reduce 19) (("*") reduce 19) (("+") reduce 19) (("-") reduce 19) ((".") reduce 19) (("/") reduce 19) (("<") reduce 19) ((">") reduce 19) (("?") reduce 19) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_AS) reduce 19) ((T_BOOLEAN_AND) reduce 19) ((T_BOOLEAN_OR) reduce 19) ((T_COALESCE) reduce 19) ((T_DOUBLE_ARROW) reduce 19) ((T_INSTANCEOF) reduce 19) ((T_IS_EQUAL) reduce 19) ((T_IS_GREATER_OR_EQUAL) reduce 19) ((T_IS_IDENTICAL) reduce 19) ((T_IS_NOT_EQUAL) reduce 19) ((T_IS_NOT_IDENTICAL) reduce 19) ((T_IS_SMALLER_OR_EQUAL) reduce 19) ((T_LOGICAL_AND) reduce 19) ((T_LOGICAL_OR) reduce 19) ((T_LOGICAL_XOR) reduce 19) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 19) ((T_OBJECT_OPERATOR) reduce 19) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 19) ((T_POW) reduce 19) ((T_SL) reduce 19) ((T_SPACESHIP) reduce 19) ((T_SR) reduce 19) (("[") reduce 19) (("^") reduce 19) (("{") reduce 19) (("|") reduce 19)) 18937 ((("%") reduce 45) (("(") reduce 45) (("*") reduce 45) (("+") reduce 45) (("-") reduce 45) ((".") reduce 45) (("/") reduce 45) (("<") reduce 45) ((">") reduce 45) (("?") reduce 45) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_AS) reduce 45) ((T_BOOLEAN_AND) reduce 45) ((T_BOOLEAN_OR) reduce 45) ((T_COALESCE) reduce 45) ((T_DOUBLE_ARROW) reduce 45) ((T_INSTANCEOF) reduce 45) ((T_IS_EQUAL) reduce 45) ((T_IS_GREATER_OR_EQUAL) reduce 45) ((T_IS_IDENTICAL) reduce 45) ((T_IS_NOT_EQUAL) reduce 45) ((T_IS_NOT_IDENTICAL) reduce 45) ((T_IS_SMALLER_OR_EQUAL) reduce 45) ((T_LOGICAL_AND) reduce 45) ((T_LOGICAL_OR) reduce 45) ((T_LOGICAL_XOR) reduce 45) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 45) ((T_OBJECT_OPERATOR) reduce 45) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 45) ((T_POW) reduce 45) ((T_SL) reduce 45) ((T_SPACESHIP) reduce 45) ((T_SR) reduce 45) (("[") reduce 45) (("^") reduce 45) (("{") reduce 45) (("|") reduce 45)) 18938 ((("%") reduce 504) (("(") reduce 541) (("*") reduce 504) (("+") reduce 504) (("-") reduce 504) ((".") reduce 504) (("/") reduce 504) (("<") reduce 504) ((">") reduce 504) (("?") reduce 504) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_AS) reduce 504) ((T_BOOLEAN_AND) reduce 504) ((T_BOOLEAN_OR) reduce 504) ((T_COALESCE) reduce 504) ((T_DOUBLE_ARROW) reduce 504) ((T_INSTANCEOF) reduce 504) ((T_IS_EQUAL) reduce 504) ((T_IS_GREATER_OR_EQUAL) reduce 504) ((T_IS_IDENTICAL) reduce 504) ((T_IS_NOT_EQUAL) reduce 504) ((T_IS_NOT_IDENTICAL) reduce 504) ((T_IS_SMALLER_OR_EQUAL) reduce 504) ((T_LOGICAL_AND) reduce 504) ((T_LOGICAL_OR) reduce 504) ((T_LOGICAL_XOR) reduce 504) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 504) ((T_OBJECT_OPERATOR) reduce 504) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 504) ((T_POW) reduce 504) ((T_SL) reduce 504) ((T_SPACESHIP) reduce 504) ((T_SR) reduce 504) (("[") reduce 504) (("^") reduce 504) (("{") reduce 504) (("|") reduce 504)) 18940 ((("%") reduce 71) (("(") reduce 71) (("*") reduce 71) (("+") reduce 71) (("-") reduce 71) ((".") reduce 71) (("/") reduce 71) (("<") reduce 71) ((">") reduce 71) (("?") reduce 71) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_AS) reduce 71) ((T_BOOLEAN_AND) reduce 71) ((T_BOOLEAN_OR) reduce 71) ((T_COALESCE) reduce 71) ((T_DOUBLE_ARROW) reduce 71) ((T_INSTANCEOF) reduce 71) ((T_IS_EQUAL) reduce 71) ((T_IS_GREATER_OR_EQUAL) reduce 71) ((T_IS_IDENTICAL) reduce 71) ((T_IS_NOT_EQUAL) reduce 71) ((T_IS_NOT_IDENTICAL) reduce 71) ((T_IS_SMALLER_OR_EQUAL) reduce 71) ((T_LOGICAL_AND) reduce 71) ((T_LOGICAL_OR) reduce 71) ((T_LOGICAL_XOR) reduce 71) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 71) ((T_OBJECT_OPERATOR) reduce 71) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 71) ((T_POW) reduce 71) ((T_SL) reduce 71) ((T_SPACESHIP) reduce 71) ((T_SR) reduce 71) (("[") reduce 71) (("^") reduce 71) (("{") reduce 71) (("|") reduce 71)) 18941 ((("%") reduce 82) (("(") reduce 82) (("*") reduce 82) (("+") reduce 82) (("-") reduce 82) ((".") reduce 82) (("/") reduce 82) (("<") reduce 82) ((">") reduce 82) (("?") reduce 82) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_AS) reduce 82) ((T_BOOLEAN_AND) reduce 82) ((T_BOOLEAN_OR) reduce 82) ((T_COALESCE) reduce 82) ((T_DOUBLE_ARROW) reduce 82) ((T_INSTANCEOF) reduce 82) ((T_IS_EQUAL) reduce 82) ((T_IS_GREATER_OR_EQUAL) reduce 82) ((T_IS_IDENTICAL) reduce 82) ((T_IS_NOT_EQUAL) reduce 82) ((T_IS_NOT_IDENTICAL) reduce 82) ((T_IS_SMALLER_OR_EQUAL) reduce 82) ((T_LOGICAL_AND) reduce 82) ((T_LOGICAL_OR) reduce 82) ((T_LOGICAL_XOR) reduce 82) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 82) ((T_OBJECT_OPERATOR) reduce 82) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 82) ((T_POW) reduce 82) ((T_SL) reduce 82) ((T_SPACESHIP) reduce 82) ((T_SR) reduce 82) (("[") reduce 82) (("^") reduce 82) (("{") reduce 82) (("|") reduce 82)) 18942 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) (("<") reduce 533) (("=") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AND_EQUAL) reduce 533) ((T_AS) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_COALESCE_EQUAL) reduce 533) ((T_CONCAT_EQUAL) reduce 533) ((T_DEC) reduce 533) ((T_DIV_EQUAL) reduce 533) ((T_DOUBLE_ARROW) reduce 533) ((T_INC) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_MINUS_EQUAL) reduce 533) ((T_MOD_EQUAL) reduce 533) ((T_MUL_EQUAL) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_OR_EQUAL) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_PLUS_EQUAL) reduce 533) ((T_POW) reduce 533) ((T_POW_EQUAL) reduce 533) ((T_SL) reduce 533) ((T_SL_EQUAL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) ((T_SR_EQUAL) reduce 533) ((T_XOR_EQUAL) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 18945 ((("%") reduce 506) (("(") reduce 542) (("*") reduce 506) (("+") reduce 506) (("-") reduce 506) ((".") reduce 506) (("/") reduce 506) (("<") reduce 506) ((">") reduce 506) (("?") reduce 506) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_AS) reduce 506) ((T_BOOLEAN_AND) reduce 506) ((T_BOOLEAN_OR) reduce 506) ((T_COALESCE) reduce 506) ((T_DOUBLE_ARROW) reduce 506) ((T_INSTANCEOF) reduce 506) ((T_IS_EQUAL) reduce 506) ((T_IS_GREATER_OR_EQUAL) reduce 506) ((T_IS_IDENTICAL) reduce 506) ((T_IS_NOT_EQUAL) reduce 506) ((T_IS_NOT_IDENTICAL) reduce 506) ((T_IS_SMALLER_OR_EQUAL) reduce 506) ((T_LOGICAL_AND) reduce 506) ((T_LOGICAL_OR) reduce 506) ((T_LOGICAL_XOR) reduce 506) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 506) ((T_OBJECT_OPERATOR) reduce 506) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 506) ((T_POW) reduce 506) ((T_SL) reduce 506) ((T_SPACESHIP) reduce 506) ((T_SR) reduce 506) (("[") reduce 506) (("^") reduce 506) (("{") reduce 506) (("|") reduce 506)) 18947 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) (("<") reduce 468) (("=") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AND_EQUAL) reduce 468) ((T_AS) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_COALESCE_EQUAL) reduce 468) ((T_CONCAT_EQUAL) reduce 468) ((T_DEC) reduce 468) ((T_DIV_EQUAL) reduce 468) ((T_DOUBLE_ARROW) reduce 468) ((T_INC) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_MINUS_EQUAL) reduce 468) ((T_MOD_EQUAL) reduce 468) ((T_MUL_EQUAL) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_OR_EQUAL) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_PLUS_EQUAL) reduce 468) ((T_POW) reduce 468) ((T_POW_EQUAL) reduce 468) ((T_SL) reduce 468) ((T_SL_EQUAL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) ((T_SR_EQUAL) reduce 468) ((T_XOR_EQUAL) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 18948 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) (("=") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AND_EQUAL) reduce 288) ((T_AS) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_COALESCE_EQUAL) reduce 288) ((T_CONCAT_EQUAL) reduce 288) ((T_DEC) reduce 288) ((T_DIV_EQUAL) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INC) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_MINUS_EQUAL) reduce 288) ((T_MOD_EQUAL) reduce 288) ((T_MUL_EQUAL) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_OR_EQUAL) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_PLUS_EQUAL) reduce 288) ((T_POW) reduce 288) ((T_POW_EQUAL) reduce 288) ((T_SL) reduce 288) ((T_SL_EQUAL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) ((T_SR_EQUAL) reduce 288) ((T_XOR_EQUAL) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 18952 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) (("=") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AND_EQUAL) reduce 289) ((T_AS) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_COALESCE_EQUAL) reduce 289) ((T_CONCAT_EQUAL) reduce 289) ((T_DEC) reduce 289) ((T_DIV_EQUAL) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INC) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_MINUS_EQUAL) reduce 289) ((T_MOD_EQUAL) reduce 289) ((T_MUL_EQUAL) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_OR_EQUAL) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_PLUS_EQUAL) reduce 289) ((T_POW) reduce 289) ((T_POW_EQUAL) reduce 289) ((T_SL) reduce 289) ((T_SL_EQUAL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) ((T_SR_EQUAL) reduce 289) ((T_XOR_EQUAL) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 18953 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) (("=") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AND_EQUAL) reduce 290) ((T_AS) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_COALESCE_EQUAL) reduce 290) ((T_CONCAT_EQUAL) reduce 290) ((T_DEC) reduce 290) ((T_DIV_EQUAL) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INC) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_MINUS_EQUAL) reduce 290) ((T_MOD_EQUAL) reduce 290) ((T_MUL_EQUAL) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_OR_EQUAL) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_PLUS_EQUAL) reduce 290) ((T_POW) reduce 290) ((T_POW_EQUAL) reduce 290) ((T_SL) reduce 290) ((T_SL_EQUAL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) ((T_SR_EQUAL) reduce 290) ((T_XOR_EQUAL) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 18958 ((("%") reduce 388) (("*") reduce 388) (("+") reduce 388) (("-") reduce 388) ((".") reduce 388) (("/") reduce 388) (("<") reduce 388) ((">") reduce 388) (("?") reduce 388) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_AS) reduce 388) ((T_BOOLEAN_AND) reduce 388) ((T_BOOLEAN_OR) reduce 388) ((T_COALESCE) reduce 388) ((T_DOUBLE_ARROW) reduce 388) ((T_INSTANCEOF) reduce 388) ((T_IS_EQUAL) reduce 388) ((T_IS_GREATER_OR_EQUAL) reduce 388) ((T_IS_IDENTICAL) reduce 388) ((T_IS_NOT_EQUAL) reduce 388) ((T_IS_NOT_IDENTICAL) reduce 388) ((T_IS_SMALLER_OR_EQUAL) reduce 388) ((T_LOGICAL_AND) reduce 388) ((T_LOGICAL_OR) reduce 388) ((T_LOGICAL_XOR) reduce 388) ((T_POW) reduce 388) ((T_SL) reduce 388) ((T_SPACESHIP) reduce 388) ((T_SR) reduce 388) (("^") reduce 388) (("|") reduce 388)) 18960 ((("%") reduce 386) (("*") reduce 386) (("+") reduce 386) (("-") reduce 386) ((".") reduce 386) (("/") reduce 386) (("<") reduce 386) ((">") reduce 386) (("?") reduce 386) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_AS) reduce 386) ((T_BOOLEAN_AND) reduce 386) ((T_BOOLEAN_OR) reduce 386) ((T_COALESCE) reduce 386) ((T_DOUBLE_ARROW) reduce 386) ((T_INSTANCEOF) reduce 386) ((T_IS_EQUAL) reduce 386) ((T_IS_GREATER_OR_EQUAL) reduce 386) ((T_IS_IDENTICAL) reduce 386) ((T_IS_NOT_EQUAL) reduce 386) ((T_IS_NOT_IDENTICAL) reduce 386) ((T_IS_SMALLER_OR_EQUAL) reduce 386) ((T_LOGICAL_AND) reduce 386) ((T_LOGICAL_OR) reduce 386) ((T_LOGICAL_XOR) reduce 386) ((T_POW) reduce 386) ((T_SL) reduce 386) ((T_SPACESHIP) reduce 386) ((T_SR) reduce 386) (("^") reduce 386) (("|") reduce 386)) 18970 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 382) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 382) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 382) ((T_LOGICAL_OR) reduce 382) ((T_LOGICAL_XOR) reduce 382) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18971 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 384) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 384) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 384) ((T_LOGICAL_OR) reduce 384) ((T_LOGICAL_XOR) reduce 384) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18972 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 383) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 383) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 383) ((T_LOGICAL_OR) reduce 383) ((T_LOGICAL_XOR) reduce 383) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18973 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 376) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 376) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 376) ((T_LOGICAL_OR) reduce 376) ((T_LOGICAL_XOR) reduce 376) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18974 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 373) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 373) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 373) ((T_LOGICAL_OR) reduce 373) ((T_LOGICAL_XOR) reduce 373) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18975 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 381) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 381) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 381) ((T_LOGICAL_OR) reduce 381) ((T_LOGICAL_XOR) reduce 381) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18976 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 375) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 375) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 375) ((T_LOGICAL_OR) reduce 375) ((T_LOGICAL_XOR) reduce 375) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18977 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 379) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 379) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 379) ((T_LOGICAL_OR) reduce 379) ((T_LOGICAL_XOR) reduce 379) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18978 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 374) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 374) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 374) ((T_LOGICAL_OR) reduce 374) ((T_LOGICAL_XOR) reduce 374) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18979 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 377) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 377) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 377) ((T_LOGICAL_OR) reduce 377) ((T_LOGICAL_XOR) reduce 377) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18980 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 378) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 378) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 378) ((T_LOGICAL_OR) reduce 378) ((T_LOGICAL_XOR) reduce 378) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18981 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 385) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 385) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 385) ((T_LOGICAL_OR) reduce 385) ((T_LOGICAL_XOR) reduce 385) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18982 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 380) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 380) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 380) ((T_LOGICAL_OR) reduce 380) ((T_LOGICAL_XOR) reduce 380) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18984 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 370) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 370) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 370) ((T_LOGICAL_OR) reduce 370) ((T_LOGICAL_XOR) reduce 370) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 18987 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AS) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 18990 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) (("<") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AS) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_DOUBLE_ARROW) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_POW) reduce 525) ((T_SL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 18992 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) (("<") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AS) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_DOUBLE_ARROW) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_POW) reduce 524) ((T_SL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 18994 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) (("<") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AS) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_DOUBLE_ARROW) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_POW) reduce 519) ((T_SL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 18995 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) (("<") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AS) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_DOUBLE_ARROW) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_POW) reduce 526) ((T_SL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 18996 ((("%") reduce 371) (("*") reduce 371) (("+") reduce 371) (("-") reduce 371) ((".") reduce 371) (("/") reduce 371) (("<") reduce 371) ((">") reduce 371) (("?") reduce 371) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_AS) reduce 371) ((T_BOOLEAN_AND) reduce 371) ((T_BOOLEAN_OR) reduce 371) ((T_COALESCE) reduce 371) ((T_DOUBLE_ARROW) reduce 371) ((T_INSTANCEOF) reduce 371) ((T_IS_EQUAL) reduce 371) ((T_IS_GREATER_OR_EQUAL) reduce 371) ((T_IS_IDENTICAL) reduce 371) ((T_IS_NOT_EQUAL) reduce 371) ((T_IS_NOT_IDENTICAL) reduce 371) ((T_IS_SMALLER_OR_EQUAL) reduce 371) ((T_LOGICAL_AND) reduce 371) ((T_LOGICAL_OR) reduce 371) ((T_LOGICAL_XOR) reduce 371) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 371) ((T_SL) reduce 371) ((T_SPACESHIP) reduce 371) ((T_SR) reduce 371) (("[") reduce 510) (("^") reduce 371) (("{") reduce 510) (("|") reduce 371)) 19000 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) (("<") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AS) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_DOUBLE_ARROW) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_POW) reduce 533) ((T_SL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 19002 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) (("<") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AS) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_DOUBLE_ARROW) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_POW) reduce 468) ((T_SL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 19003 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AS) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 19007 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AS) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 19008 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AS) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 19009 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) (("<") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AS) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_DOUBLE_ARROW) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_POW) reduce 465) ((T_SL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 19012 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) (("<") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AS) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_DOUBLE_ARROW) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_POW) reduce 532) ((T_SL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 19013 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) (("<") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AS) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_DOUBLE_ARROW) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_POW) reduce 467) ((T_SL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 19014 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) (("<") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AS) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_DOUBLE_ARROW) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_POW) reduce 469) ((T_SL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 19020 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) (("<") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AS) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_DOUBLE_ARROW) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_POW) reduce 521) ((T_SL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 19022 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) (("<") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AS) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_DOUBLE_ARROW) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_POW) reduce 520) ((T_SL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 19023 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AS) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 19024 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) (("<") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AS) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_DOUBLE_ARROW) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_POW) reduce 527) ((T_SL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 19025 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AS) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 19028 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AS) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 19029 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) (("<") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AS) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_DOUBLE_ARROW) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_POW) reduce 522) ((T_SL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 19030 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) (("<") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AS) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_DOUBLE_ARROW) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_POW) reduce 528) ((T_SL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 19031 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) (("<") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AS) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_DOUBLE_ARROW) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_POW) reduce 523) ((T_SL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 19032 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) (("<") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AS) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_DOUBLE_ARROW) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_POW) reduce 466) ((T_SL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 19033 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AS) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 19036 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AS) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 19037 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) (("<") reduce 465) (("=") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AND_EQUAL) reduce 465) ((T_AS) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_COALESCE_EQUAL) reduce 465) ((T_CONCAT_EQUAL) reduce 465) ((T_DEC) reduce 465) ((T_DIV_EQUAL) reduce 465) ((T_DOUBLE_ARROW) reduce 465) ((T_INC) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_MINUS_EQUAL) reduce 465) ((T_MOD_EQUAL) reduce 465) ((T_MUL_EQUAL) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_OR_EQUAL) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_PLUS_EQUAL) reduce 465) ((T_POW) reduce 465) ((T_POW_EQUAL) reduce 465) ((T_SL) reduce 465) ((T_SL_EQUAL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) ((T_SR_EQUAL) reduce 465) ((T_XOR_EQUAL) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 19048 ((("%") reduce 455) (("*") reduce 455) (("+") reduce 455) (("-") reduce 455) ((".") reduce 455) (("/") reduce 455) (("<") reduce 455) ((">") reduce 455) (("?") reduce 455) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_AS) reduce 455) ((T_BOOLEAN_AND) reduce 455) ((T_BOOLEAN_OR) reduce 455) ((T_COALESCE) reduce 455) ((T_DOUBLE_ARROW) reduce 455) ((T_INSTANCEOF) reduce 455) ((T_IS_EQUAL) reduce 455) ((T_IS_GREATER_OR_EQUAL) reduce 455) ((T_IS_IDENTICAL) reduce 455) ((T_IS_NOT_EQUAL) reduce 455) ((T_IS_NOT_IDENTICAL) reduce 455) ((T_IS_SMALLER_OR_EQUAL) reduce 455) ((T_LOGICAL_AND) reduce 455) ((T_LOGICAL_OR) reduce 455) ((T_LOGICAL_XOR) reduce 455) ((T_POW) reduce 455) ((T_SL) reduce 455) ((T_SPACESHIP) reduce 455) ((T_SR) reduce 455) (("^") reduce 455) (("|") reduce 455)) 19049 ((("%") reduce 450) (("*") reduce 450) (("+") reduce 450) (("-") reduce 450) ((".") reduce 450) (("/") reduce 450) (("<") reduce 450) ((">") reduce 450) (("?") reduce 450) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_AS) reduce 450) ((T_BOOLEAN_AND) reduce 450) ((T_BOOLEAN_OR) reduce 450) ((T_COALESCE) reduce 450) ((T_DOUBLE_ARROW) reduce 450) ((T_INSTANCEOF) reduce 450) ((T_IS_EQUAL) reduce 450) ((T_IS_GREATER_OR_EQUAL) reduce 450) ((T_IS_IDENTICAL) reduce 450) ((T_IS_NOT_EQUAL) reduce 450) ((T_IS_NOT_IDENTICAL) reduce 450) ((T_IS_SMALLER_OR_EQUAL) reduce 450) ((T_LOGICAL_AND) reduce 450) ((T_LOGICAL_OR) reduce 450) ((T_LOGICAL_XOR) reduce 450) ((T_POW) reduce 450) ((T_SL) reduce 450) ((T_SPACESHIP) reduce 450) ((T_SR) reduce 450) (("^") reduce 450) (("|") reduce 450)) 19059 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 455) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 455) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 19060 ((("%") reduce 451) (("*") reduce 451) (("+") reduce 451) (("-") reduce 451) ((".") reduce 451) (("/") reduce 451) (("<") reduce 451) ((">") reduce 451) (("?") reduce 451) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_AS) reduce 451) ((T_BOOLEAN_AND) reduce 451) ((T_BOOLEAN_OR) reduce 451) ((T_COALESCE) reduce 451) ((T_DOUBLE_ARROW) reduce 451) ((T_INSTANCEOF) reduce 451) ((T_IS_EQUAL) reduce 451) ((T_IS_GREATER_OR_EQUAL) reduce 451) ((T_IS_IDENTICAL) reduce 451) ((T_IS_NOT_EQUAL) reduce 451) ((T_IS_NOT_IDENTICAL) reduce 451) ((T_IS_SMALLER_OR_EQUAL) reduce 451) ((T_LOGICAL_AND) reduce 451) ((T_LOGICAL_OR) reduce 451) ((T_LOGICAL_XOR) reduce 451) ((T_POW) reduce 451) ((T_SL) reduce 451) ((T_SPACESHIP) reduce 451) ((T_SR) reduce 451) (("^") reduce 451) (("|") reduce 451)) 19062 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 442) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 442) ((T_LOGICAL_OR) reduce 442) ((T_LOGICAL_XOR) reduce 442) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 19064 ((("%") reduce 503) (("(") reduce 541) (("*") reduce 503) (("+") reduce 503) (("-") reduce 503) ((".") reduce 503) (("/") reduce 503) (("<") reduce 503) ((">") reduce 503) (("?") reduce 503) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_AS) reduce 503) ((T_BOOLEAN_AND) reduce 503) ((T_BOOLEAN_OR) reduce 503) ((T_COALESCE) reduce 503) ((T_DOUBLE_ARROW) reduce 503) ((T_INSTANCEOF) reduce 503) ((T_IS_EQUAL) reduce 503) ((T_IS_GREATER_OR_EQUAL) reduce 503) ((T_IS_IDENTICAL) reduce 503) ((T_IS_NOT_EQUAL) reduce 503) ((T_IS_NOT_IDENTICAL) reduce 503) ((T_IS_SMALLER_OR_EQUAL) reduce 503) ((T_LOGICAL_AND) reduce 503) ((T_LOGICAL_OR) reduce 503) ((T_LOGICAL_XOR) reduce 503) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 503) ((T_OBJECT_OPERATOR) reduce 503) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 503) ((T_POW) reduce 503) ((T_SL) reduce 503) ((T_SPACESHIP) reduce 503) ((T_SR) reduce 503) (("[") reduce 503) (("^") reduce 503) (("{") reduce 503) (("|") reduce 503)) 19066 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) (("<") reduce 532) (("=") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AND_EQUAL) reduce 532) ((T_AS) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_COALESCE_EQUAL) reduce 532) ((T_CONCAT_EQUAL) reduce 532) ((T_DEC) reduce 532) ((T_DIV_EQUAL) reduce 532) ((T_DOUBLE_ARROW) reduce 532) ((T_INC) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_MINUS_EQUAL) reduce 532) ((T_MOD_EQUAL) reduce 532) ((T_MUL_EQUAL) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_OR_EQUAL) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_PLUS_EQUAL) reduce 532) ((T_POW) reduce 532) ((T_POW_EQUAL) reduce 532) ((T_SL) reduce 532) ((T_SL_EQUAL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) ((T_SR_EQUAL) reduce 532) ((T_XOR_EQUAL) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 19069 ((("%") reduce 505) (("(") reduce 542) (("*") reduce 505) (("+") reduce 505) (("-") reduce 505) ((".") reduce 505) (("/") reduce 505) (("<") reduce 505) ((">") reduce 505) (("?") reduce 505) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_AS) reduce 505) ((T_BOOLEAN_AND) reduce 505) ((T_BOOLEAN_OR) reduce 505) ((T_COALESCE) reduce 505) ((T_DOUBLE_ARROW) reduce 505) ((T_INSTANCEOF) reduce 505) ((T_IS_EQUAL) reduce 505) ((T_IS_GREATER_OR_EQUAL) reduce 505) ((T_IS_IDENTICAL) reduce 505) ((T_IS_NOT_EQUAL) reduce 505) ((T_IS_NOT_IDENTICAL) reduce 505) ((T_IS_SMALLER_OR_EQUAL) reduce 505) ((T_LOGICAL_AND) reduce 505) ((T_LOGICAL_OR) reduce 505) ((T_LOGICAL_XOR) reduce 505) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 505) ((T_OBJECT_OPERATOR) reduce 505) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 505) ((T_POW) reduce 505) ((T_SL) reduce 505) ((T_SPACESHIP) reduce 505) ((T_SR) reduce 505) (("[") reduce 505) (("^") reduce 505) (("{") reduce 505) (("|") reduce 505)) 19070 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) (("<") reduce 467) (("=") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AND_EQUAL) reduce 467) ((T_AS) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_COALESCE_EQUAL) reduce 467) ((T_CONCAT_EQUAL) reduce 467) ((T_DEC) reduce 467) ((T_DIV_EQUAL) reduce 467) ((T_DOUBLE_ARROW) reduce 467) ((T_INC) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_MINUS_EQUAL) reduce 467) ((T_MOD_EQUAL) reduce 467) ((T_MUL_EQUAL) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_OR_EQUAL) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_PLUS_EQUAL) reduce 467) ((T_POW) reduce 467) ((T_POW_EQUAL) reduce 467) ((T_SL) reduce 467) ((T_SL_EQUAL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) ((T_SR_EQUAL) reduce 467) ((T_XOR_EQUAL) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 19071 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) (("<") reduce 469) (("=") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AND_EQUAL) reduce 469) ((T_AS) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_COALESCE_EQUAL) reduce 469) ((T_CONCAT_EQUAL) reduce 469) ((T_DEC) reduce 469) ((T_DIV_EQUAL) reduce 469) ((T_DOUBLE_ARROW) reduce 469) ((T_INC) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_MINUS_EQUAL) reduce 469) ((T_MOD_EQUAL) reduce 469) ((T_MUL_EQUAL) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_OR_EQUAL) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_PLUS_EQUAL) reduce 469) ((T_POW) reduce 469) ((T_POW_EQUAL) reduce 469) ((T_SL) reduce 469) ((T_SL_EQUAL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) ((T_SR_EQUAL) reduce 469) ((T_XOR_EQUAL) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 19073 ((("%") reduce 446) (("*") reduce 446) (("+") reduce 446) (("-") reduce 446) ((".") reduce 446) (("/") reduce 446) (("<") reduce 446) ((">") reduce 446) (("?") reduce 446) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_AS) reduce 446) ((T_BOOLEAN_AND) reduce 446) ((T_BOOLEAN_OR) reduce 446) ((T_COALESCE) reduce 446) ((T_DOUBLE_ARROW) reduce 446) ((T_INSTANCEOF) reduce 446) ((T_IS_EQUAL) reduce 446) ((T_IS_GREATER_OR_EQUAL) reduce 446) ((T_IS_IDENTICAL) reduce 446) ((T_IS_NOT_EQUAL) reduce 446) ((T_IS_NOT_IDENTICAL) reduce 446) ((T_IS_SMALLER_OR_EQUAL) reduce 446) ((T_LOGICAL_AND) reduce 446) ((T_LOGICAL_OR) reduce 446) ((T_LOGICAL_XOR) reduce 446) ((T_POW) reduce 446) ((T_SL) reduce 446) ((T_SPACESHIP) reduce 446) ((T_SR) reduce 446) (("^") reduce 446) (("|") reduce 446)) 19074 ((("%") reduce 448) (("*") reduce 448) (("+") reduce 448) (("-") reduce 448) ((".") reduce 448) (("/") reduce 448) (("<") reduce 448) ((">") reduce 448) (("?") reduce 448) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_AS) reduce 448) ((T_BOOLEAN_AND) reduce 448) ((T_BOOLEAN_OR) reduce 448) ((T_COALESCE) reduce 448) ((T_DOUBLE_ARROW) reduce 448) ((T_INSTANCEOF) reduce 448) ((T_IS_EQUAL) reduce 448) ((T_IS_GREATER_OR_EQUAL) reduce 448) ((T_IS_IDENTICAL) reduce 448) ((T_IS_NOT_EQUAL) reduce 448) ((T_IS_NOT_IDENTICAL) reduce 448) ((T_IS_SMALLER_OR_EQUAL) reduce 448) ((T_LOGICAL_AND) reduce 448) ((T_LOGICAL_OR) reduce 448) ((T_LOGICAL_XOR) reduce 448) ((T_POW) reduce 448) ((T_SL) reduce 448) ((T_SPACESHIP) reduce 448) ((T_SR) reduce 448) (("^") reduce 448) (("|") reduce 448)) 19080 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) (("<") reduce 521) (("=") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AND_EQUAL) reduce 521) ((T_AS) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_COALESCE_EQUAL) reduce 521) ((T_CONCAT_EQUAL) reduce 521) ((T_DEC) reduce 521) ((T_DIV_EQUAL) reduce 521) ((T_DOUBLE_ARROW) reduce 521) ((T_INC) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_MINUS_EQUAL) reduce 521) ((T_MOD_EQUAL) reduce 521) ((T_MUL_EQUAL) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_OR_EQUAL) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_PLUS_EQUAL) reduce 521) ((T_POW) reduce 521) ((T_POW_EQUAL) reduce 521) ((T_SL) reduce 521) ((T_SL_EQUAL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) ((T_SR_EQUAL) reduce 521) ((T_XOR_EQUAL) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 19082 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) (("<") reduce 520) (("=") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AND_EQUAL) reduce 520) ((T_AS) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_COALESCE_EQUAL) reduce 520) ((T_CONCAT_EQUAL) reduce 520) ((T_DEC) reduce 520) ((T_DIV_EQUAL) reduce 520) ((T_DOUBLE_ARROW) reduce 520) ((T_INC) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_MINUS_EQUAL) reduce 520) ((T_MOD_EQUAL) reduce 520) ((T_MUL_EQUAL) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_OR_EQUAL) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_PLUS_EQUAL) reduce 520) ((T_POW) reduce 520) ((T_POW_EQUAL) reduce 520) ((T_SL) reduce 520) ((T_SL_EQUAL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) ((T_SR_EQUAL) reduce 520) ((T_XOR_EQUAL) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 19083 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) (("<") reduce 544) (("=") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AND_EQUAL) reduce 544) ((T_AS) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_COALESCE_EQUAL) reduce 544) ((T_CONCAT_EQUAL) reduce 544) ((T_DEC) reduce 544) ((T_DIV_EQUAL) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INC) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_MINUS_EQUAL) reduce 544) ((T_MOD_EQUAL) reduce 544) ((T_MUL_EQUAL) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_OR_EQUAL) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_PLUS_EQUAL) reduce 544) ((T_POW) reduce 544) ((T_POW_EQUAL) reduce 544) ((T_SL) reduce 544) ((T_SL_EQUAL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) ((T_SR_EQUAL) reduce 544) ((T_XOR_EQUAL) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 19084 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) (("<") reduce 527) (("=") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AND_EQUAL) reduce 527) ((T_AS) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_COALESCE_EQUAL) reduce 527) ((T_CONCAT_EQUAL) reduce 527) ((T_DEC) reduce 527) ((T_DIV_EQUAL) reduce 527) ((T_DOUBLE_ARROW) reduce 527) ((T_INC) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_MINUS_EQUAL) reduce 527) ((T_MOD_EQUAL) reduce 527) ((T_MUL_EQUAL) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_OR_EQUAL) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_PLUS_EQUAL) reduce 527) ((T_POW) reduce 527) ((T_POW_EQUAL) reduce 527) ((T_SL) reduce 527) ((T_SL_EQUAL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) ((T_SR_EQUAL) reduce 527) ((T_XOR_EQUAL) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 19085 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) (("<") reduce 546) (("=") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AND_EQUAL) reduce 546) ((T_AS) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_COALESCE_EQUAL) reduce 546) ((T_CONCAT_EQUAL) reduce 546) ((T_DEC) reduce 546) ((T_DIV_EQUAL) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INC) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_MINUS_EQUAL) reduce 546) ((T_MOD_EQUAL) reduce 546) ((T_MUL_EQUAL) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_OR_EQUAL) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_PLUS_EQUAL) reduce 546) ((T_POW) reduce 546) ((T_POW_EQUAL) reduce 546) ((T_SL) reduce 546) ((T_SL_EQUAL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) ((T_SR_EQUAL) reduce 546) ((T_XOR_EQUAL) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 19088 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) (("<") reduce 545) (("=") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AND_EQUAL) reduce 545) ((T_AS) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_COALESCE_EQUAL) reduce 545) ((T_CONCAT_EQUAL) reduce 545) ((T_DEC) reduce 545) ((T_DIV_EQUAL) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INC) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_MINUS_EQUAL) reduce 545) ((T_MOD_EQUAL) reduce 545) ((T_MUL_EQUAL) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_OR_EQUAL) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_PLUS_EQUAL) reduce 545) ((T_POW) reduce 545) ((T_POW_EQUAL) reduce 545) ((T_SL) reduce 545) ((T_SL_EQUAL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) ((T_SR_EQUAL) reduce 545) ((T_XOR_EQUAL) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 19089 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) (("<") reduce 522) (("=") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AND_EQUAL) reduce 522) ((T_AS) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_COALESCE_EQUAL) reduce 522) ((T_CONCAT_EQUAL) reduce 522) ((T_DEC) reduce 522) ((T_DIV_EQUAL) reduce 522) ((T_DOUBLE_ARROW) reduce 522) ((T_INC) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_MINUS_EQUAL) reduce 522) ((T_MOD_EQUAL) reduce 522) ((T_MUL_EQUAL) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_OR_EQUAL) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_PLUS_EQUAL) reduce 522) ((T_POW) reduce 522) ((T_POW_EQUAL) reduce 522) ((T_SL) reduce 522) ((T_SL_EQUAL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) ((T_SR_EQUAL) reduce 522) ((T_XOR_EQUAL) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 19090 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) (("<") reduce 528) (("=") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AND_EQUAL) reduce 528) ((T_AS) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_COALESCE_EQUAL) reduce 528) ((T_CONCAT_EQUAL) reduce 528) ((T_DEC) reduce 528) ((T_DIV_EQUAL) reduce 528) ((T_DOUBLE_ARROW) reduce 528) ((T_INC) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_MINUS_EQUAL) reduce 528) ((T_MOD_EQUAL) reduce 528) ((T_MUL_EQUAL) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_OR_EQUAL) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_PLUS_EQUAL) reduce 528) ((T_POW) reduce 528) ((T_POW_EQUAL) reduce 528) ((T_SL) reduce 528) ((T_SL_EQUAL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) ((T_SR_EQUAL) reduce 528) ((T_XOR_EQUAL) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 19091 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) (("<") reduce 523) (("=") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AND_EQUAL) reduce 523) ((T_AS) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_COALESCE_EQUAL) reduce 523) ((T_CONCAT_EQUAL) reduce 523) ((T_DEC) reduce 523) ((T_DIV_EQUAL) reduce 523) ((T_DOUBLE_ARROW) reduce 523) ((T_INC) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_MINUS_EQUAL) reduce 523) ((T_MOD_EQUAL) reduce 523) ((T_MUL_EQUAL) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_OR_EQUAL) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_PLUS_EQUAL) reduce 523) ((T_POW) reduce 523) ((T_POW_EQUAL) reduce 523) ((T_SL) reduce 523) ((T_SL_EQUAL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) ((T_SR_EQUAL) reduce 523) ((T_XOR_EQUAL) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 19093 ((("%") reduce 438) (("*") reduce 438) (("+") reduce 438) (("-") reduce 438) ((".") reduce 438) (("/") reduce 438) (("<") reduce 438) ((">") reduce 438) (("?") reduce 438) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_AS) reduce 438) ((T_BOOLEAN_AND) reduce 438) ((T_BOOLEAN_OR) reduce 438) ((T_COALESCE) reduce 438) ((T_DOUBLE_ARROW) reduce 438) ((T_INSTANCEOF) reduce 438) ((T_IS_EQUAL) reduce 438) ((T_IS_GREATER_OR_EQUAL) reduce 438) ((T_IS_IDENTICAL) reduce 438) ((T_IS_NOT_EQUAL) reduce 438) ((T_IS_NOT_IDENTICAL) reduce 438) ((T_IS_SMALLER_OR_EQUAL) reduce 438) ((T_LOGICAL_AND) reduce 438) ((T_LOGICAL_OR) reduce 438) ((T_LOGICAL_XOR) reduce 438) ((T_POW) reduce 438) ((T_SL) reduce 438) ((T_SPACESHIP) reduce 438) ((T_SR) reduce 438) (("^") reduce 438) (("|") reduce 438)) 19095 ((("%") reduce 483) (("(") reduce 483) (("*") reduce 483) (("+") reduce 483) (("-") reduce 483) ((".") reduce 483) (("/") reduce 483) (("<") reduce 483) (("=") shift) ((">") reduce 483) (("?") reduce 483) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_AS) reduce 483) ((T_BOOLEAN_AND) reduce 483) ((T_BOOLEAN_OR) reduce 483) ((T_COALESCE) reduce 483) ((T_DOUBLE_ARROW) reduce 483) ((T_INSTANCEOF) reduce 483) ((T_IS_EQUAL) reduce 483) ((T_IS_GREATER_OR_EQUAL) reduce 483) ((T_IS_IDENTICAL) reduce 483) ((T_IS_NOT_EQUAL) reduce 483) ((T_IS_NOT_IDENTICAL) reduce 483) ((T_IS_SMALLER_OR_EQUAL) reduce 483) ((T_LOGICAL_AND) reduce 483) ((T_LOGICAL_OR) reduce 483) ((T_LOGICAL_XOR) reduce 483) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 483) ((T_OBJECT_OPERATOR) reduce 483) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 483) ((T_POW) reduce 483) ((T_SL) reduce 483) ((T_SPACESHIP) reduce 483) ((T_SR) reduce 483) (("[") reduce 483) (("^") reduce 483) (("{") reduce 483) (("|") reduce 483)) 19097 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 369) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 369) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 369) ((T_LOGICAL_OR) reduce 369) ((T_LOGICAL_XOR) reduce 369) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 19098 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 443) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 443) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 443) ((T_LOGICAL_OR) reduce 443) ((T_LOGICAL_XOR) reduce 443) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 19101 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 442) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 442) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 442) ((T_LOGICAL_OR) reduce 442) ((T_LOGICAL_XOR) reduce 442) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 19102 ((("%") reduce 434) (("*") reduce 434) (("+") reduce 434) (("-") reduce 434) ((".") reduce 434) (("/") reduce 434) (("<") reduce 434) ((">") reduce 434) (("?") reduce 434) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_AS) reduce 434) ((T_BOOLEAN_AND) reduce 434) ((T_BOOLEAN_OR) reduce 434) ((T_COALESCE) reduce 434) ((T_DOUBLE_ARROW) reduce 434) ((T_INSTANCEOF) reduce 434) ((T_IS_EQUAL) reduce 434) ((T_IS_GREATER_OR_EQUAL) reduce 434) ((T_IS_IDENTICAL) reduce 434) ((T_IS_NOT_EQUAL) reduce 434) ((T_IS_NOT_IDENTICAL) reduce 434) ((T_IS_SMALLER_OR_EQUAL) reduce 434) ((T_LOGICAL_AND) reduce 434) ((T_LOGICAL_OR) reduce 434) ((T_LOGICAL_XOR) reduce 434) ((T_POW) shift) ((T_SL) reduce 434) ((T_SPACESHIP) reduce 434) ((T_SR) reduce 434) (("^") reduce 434) (("|") reduce 434)) 19103 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 444) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 444) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 19104 ((("%") reduce 430) (("*") reduce 430) (("+") reduce 430) (("-") reduce 430) ((".") reduce 430) (("/") reduce 430) (("<") reduce 430) ((">") reduce 430) (("?") reduce 430) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_AS) reduce 430) ((T_BOOLEAN_AND) reduce 430) ((T_BOOLEAN_OR) reduce 430) ((T_COALESCE) reduce 430) ((T_DOUBLE_ARROW) reduce 430) ((T_INSTANCEOF) reduce 430) ((T_IS_EQUAL) reduce 430) ((T_IS_GREATER_OR_EQUAL) reduce 430) ((T_IS_IDENTICAL) reduce 430) ((T_IS_NOT_EQUAL) reduce 430) ((T_IS_NOT_IDENTICAL) reduce 430) ((T_IS_SMALLER_OR_EQUAL) reduce 430) ((T_LOGICAL_AND) reduce 430) ((T_LOGICAL_OR) reduce 430) ((T_LOGICAL_XOR) reduce 430) ((T_POW) shift) ((T_SL) reduce 430) ((T_SPACESHIP) reduce 430) ((T_SR) reduce 430) (("^") reduce 430) (("|") reduce 430)) 19105 ((("%") reduce 447) (("*") reduce 447) (("+") reduce 447) (("-") reduce 447) ((".") reduce 447) (("/") reduce 447) (("<") reduce 447) ((">") reduce 447) (("?") reduce 447) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_AS) reduce 447) ((T_BOOLEAN_AND) reduce 447) ((T_BOOLEAN_OR) reduce 447) ((T_COALESCE) reduce 447) ((T_DOUBLE_ARROW) reduce 447) ((T_INSTANCEOF) reduce 447) ((T_IS_EQUAL) reduce 447) ((T_IS_GREATER_OR_EQUAL) reduce 447) ((T_IS_IDENTICAL) reduce 447) ((T_IS_NOT_EQUAL) reduce 447) ((T_IS_NOT_IDENTICAL) reduce 447) ((T_IS_SMALLER_OR_EQUAL) reduce 447) ((T_LOGICAL_AND) reduce 447) ((T_LOGICAL_OR) reduce 447) ((T_LOGICAL_XOR) reduce 447) ((T_POW) reduce 447) ((T_SL) reduce 447) ((T_SPACESHIP) reduce 447) ((T_SR) reduce 447) (("^") reduce 447) (("|") reduce 447)) 19107 ((("%") reduce 489) (("*") reduce 489) (("+") reduce 489) (("-") reduce 489) ((".") reduce 489) (("/") reduce 489) (("<") reduce 489) ((">") reduce 489) (("?") reduce 489) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_AS) reduce 489) ((T_BOOLEAN_AND) reduce 489) ((T_BOOLEAN_OR) reduce 489) ((T_COALESCE) reduce 489) ((T_DOUBLE_ARROW) reduce 489) ((T_INSTANCEOF) reduce 489) ((T_IS_EQUAL) reduce 489) ((T_IS_GREATER_OR_EQUAL) reduce 489) ((T_IS_IDENTICAL) reduce 489) ((T_IS_NOT_EQUAL) reduce 489) ((T_IS_NOT_IDENTICAL) reduce 489) ((T_IS_SMALLER_OR_EQUAL) reduce 489) ((T_LOGICAL_AND) reduce 489) ((T_LOGICAL_OR) reduce 489) ((T_LOGICAL_XOR) reduce 489) ((T_POW) reduce 489) ((T_SL) reduce 489) ((T_SPACESHIP) reduce 489) ((T_SR) reduce 489) (("^") reduce 489) (("|") reduce 489)) 19109 ((("%") reduce 490) (("*") reduce 490) (("+") reduce 490) (("-") reduce 490) ((".") reduce 490) (("/") reduce 490) (("<") reduce 490) ((">") reduce 490) (("?") reduce 490) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_AS) reduce 490) ((T_BOOLEAN_AND) reduce 490) ((T_BOOLEAN_OR) reduce 490) ((T_COALESCE) reduce 490) ((T_DOUBLE_ARROW) reduce 490) ((T_INSTANCEOF) reduce 490) ((T_IS_EQUAL) reduce 490) ((T_IS_GREATER_OR_EQUAL) reduce 490) ((T_IS_IDENTICAL) reduce 490) ((T_IS_NOT_EQUAL) reduce 490) ((T_IS_NOT_IDENTICAL) reduce 490) ((T_IS_SMALLER_OR_EQUAL) reduce 490) ((T_LOGICAL_AND) reduce 490) ((T_LOGICAL_OR) reduce 490) ((T_LOGICAL_XOR) reduce 490) ((T_POW) reduce 490) ((T_SL) reduce 490) ((T_SPACESHIP) reduce 490) ((T_SR) reduce 490) (("^") reduce 490) (("|") reduce 490)) 19110 ((("%") reduce 488) (("*") reduce 488) (("+") reduce 488) (("-") reduce 488) ((".") reduce 488) (("/") reduce 488) (("<") reduce 488) ((">") reduce 488) (("?") reduce 488) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_AS) reduce 488) ((T_BOOLEAN_AND) reduce 488) ((T_BOOLEAN_OR) reduce 488) ((T_COALESCE) reduce 488) ((T_DOUBLE_ARROW) reduce 488) ((T_INSTANCEOF) reduce 488) ((T_IS_EQUAL) reduce 488) ((T_IS_GREATER_OR_EQUAL) reduce 488) ((T_IS_IDENTICAL) reduce 488) ((T_IS_NOT_EQUAL) reduce 488) ((T_IS_NOT_IDENTICAL) reduce 488) ((T_IS_SMALLER_OR_EQUAL) reduce 488) ((T_LOGICAL_AND) reduce 488) ((T_LOGICAL_OR) reduce 488) ((T_LOGICAL_XOR) reduce 488) ((T_POW) reduce 488) ((T_SL) reduce 488) ((T_SPACESHIP) reduce 488) ((T_SR) reduce 488) (("^") reduce 488) (("|") reduce 488)) 19111 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 581) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 581) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 19112 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 580) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 580) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 19113 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) (("<") reduce 466) (("=") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AND_EQUAL) reduce 466) ((T_AS) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_COALESCE_EQUAL) reduce 466) ((T_CONCAT_EQUAL) reduce 466) ((T_DEC) reduce 466) ((T_DIV_EQUAL) reduce 466) ((T_DOUBLE_ARROW) reduce 466) ((T_INC) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_MINUS_EQUAL) reduce 466) ((T_MOD_EQUAL) reduce 466) ((T_MUL_EQUAL) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_OR_EQUAL) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_PLUS_EQUAL) reduce 466) ((T_POW) reduce 466) ((T_POW_EQUAL) reduce 466) ((T_SL) reduce 466) ((T_SL_EQUAL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) ((T_SR_EQUAL) reduce 466) ((T_XOR_EQUAL) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 19114 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 439) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 439) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 439) ((T_LOGICAL_OR) reduce 439) ((T_LOGICAL_XOR) reduce 439) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 19115 ((("%") reduce 432) (("*") reduce 432) (("+") reduce 432) (("-") reduce 432) ((".") reduce 432) (("/") reduce 432) (("<") reduce 432) ((">") reduce 432) (("?") reduce 432) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_AS) reduce 432) ((T_BOOLEAN_AND) reduce 432) ((T_BOOLEAN_OR) reduce 432) ((T_COALESCE) reduce 432) ((T_DOUBLE_ARROW) reduce 432) ((T_INSTANCEOF) reduce 432) ((T_IS_EQUAL) reduce 432) ((T_IS_GREATER_OR_EQUAL) reduce 432) ((T_IS_IDENTICAL) reduce 432) ((T_IS_NOT_EQUAL) reduce 432) ((T_IS_NOT_IDENTICAL) reduce 432) ((T_IS_SMALLER_OR_EQUAL) reduce 432) ((T_LOGICAL_AND) reduce 432) ((T_LOGICAL_OR) reduce 432) ((T_LOGICAL_XOR) reduce 432) ((T_POW) shift) ((T_SL) reduce 432) ((T_SPACESHIP) reduce 432) ((T_SR) reduce 432) (("^") reduce 432) (("|") reduce 432)) 19117 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AS) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93)) 19118 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AS) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92)) 19119 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AS) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94)) 19120 ((("%") reduce 470) (("(") reduce 470) (("*") reduce 470) (("+") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AS) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_DOUBLE_ARROW) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470)) 19121 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AS) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91)) 19122 ((("%") reduce 365) (("*") reduce 365) (("+") reduce 365) (("-") reduce 365) ((".") reduce 365) (("/") reduce 365) (("<") reduce 365) ((">") reduce 365) (("?") reduce 365) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_AS) reduce 365) ((T_BOOLEAN_AND) reduce 365) ((T_BOOLEAN_OR) reduce 365) ((T_COALESCE) reduce 365) ((T_DOUBLE_ARROW) reduce 365) ((T_INSTANCEOF) reduce 365) ((T_IS_EQUAL) reduce 365) ((T_IS_GREATER_OR_EQUAL) reduce 365) ((T_IS_IDENTICAL) reduce 365) ((T_IS_NOT_EQUAL) reduce 365) ((T_IS_NOT_IDENTICAL) reduce 365) ((T_IS_SMALLER_OR_EQUAL) reduce 365) ((T_LOGICAL_AND) reduce 365) ((T_LOGICAL_OR) reduce 365) ((T_LOGICAL_XOR) reduce 365) ((T_POW) reduce 365) ((T_SL) reduce 365) ((T_SPACESHIP) reduce 365) ((T_SR) reduce 365) (("^") reduce 365) (("|") reduce 365)) 19125 ((("%") reduce 472) (("(") reduce 472) (("*") reduce 472) (("+") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AS) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_DOUBLE_ARROW) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472)) 19126 ((("%") reduce 480) (("(") shift) (("*") reduce 480) (("+") reduce 480) (("-") reduce 480) ((".") reduce 480) (("/") reduce 480) (("<") reduce 480) ((">") reduce 480) (("?") reduce 480) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_AS) reduce 480) ((T_BOOLEAN_AND) reduce 480) ((T_BOOLEAN_OR) reduce 480) ((T_COALESCE) reduce 480) ((T_DOUBLE_ARROW) reduce 480) ((T_INSTANCEOF) reduce 480) ((T_IS_EQUAL) reduce 480) ((T_IS_GREATER_OR_EQUAL) reduce 480) ((T_IS_IDENTICAL) reduce 480) ((T_IS_NOT_EQUAL) reduce 480) ((T_IS_NOT_IDENTICAL) reduce 480) ((T_IS_SMALLER_OR_EQUAL) reduce 480) ((T_LOGICAL_AND) reduce 480) ((T_LOGICAL_OR) reduce 480) ((T_LOGICAL_XOR) reduce 480) ((T_POW) reduce 480) ((T_SL) reduce 480) ((T_SPACESHIP) reduce 480) ((T_SR) reduce 480) (("^") reduce 480) (("|") reduce 480)) 19127 ((("%") reduce 471) (("(") reduce 471) (("*") reduce 471) (("+") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AS) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_DOUBLE_ARROW) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471)) 19128 ((("%") reduce 473) (("(") reduce 473) (("*") reduce 473) (("+") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AS) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_DOUBLE_ARROW) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 19129 ((("%") reduce 534) (("(") reduce 534) (("*") reduce 534) (("+") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AS) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_DOUBLE_ARROW) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 19136 ((("%") reduce 536) (("(") reduce 536) (("*") reduce 536) (("+") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AS) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_DOUBLE_ARROW) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 19138 ((("%") reduce 535) (("(") reduce 535) (("*") reduce 535) (("+") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AS) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_DOUBLE_ARROW) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 19139 ((("%") reduce 540) (("(") reduce 540) (("*") reduce 540) (("+") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AS) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_DOUBLE_ARROW) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 19140 ((("%") reduce 537) (("(") reduce 537) (("*") reduce 537) (("+") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AS) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_DOUBLE_ARROW) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 19141 ((("%") reduce 538) (("(") reduce 538) (("*") reduce 538) (("+") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AS) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_DOUBLE_ARROW) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 19143 ((("%") reduce 481) (("*") reduce 481) (("+") reduce 481) (("-") reduce 481) ((".") reduce 481) (("/") reduce 481) (("<") reduce 481) ((">") reduce 481) (("?") reduce 481) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_AS) reduce 481) ((T_BOOLEAN_AND) reduce 481) ((T_BOOLEAN_OR) reduce 481) ((T_COALESCE) reduce 481) ((T_DOUBLE_ARROW) reduce 481) ((T_INSTANCEOF) reduce 481) ((T_IS_EQUAL) reduce 481) ((T_IS_GREATER_OR_EQUAL) reduce 481) ((T_IS_IDENTICAL) reduce 481) ((T_IS_NOT_EQUAL) reduce 481) ((T_IS_NOT_IDENTICAL) reduce 481) ((T_IS_SMALLER_OR_EQUAL) reduce 481) ((T_LOGICAL_AND) reduce 481) ((T_LOGICAL_OR) reduce 481) ((T_LOGICAL_XOR) reduce 481) ((T_POW) reduce 481) ((T_SL) reduce 481) ((T_SPACESHIP) reduce 481) ((T_SR) reduce 481) (("^") reduce 481) (("|") reduce 481)) 19144 ((("%") reduce 364) (("*") reduce 364) (("+") reduce 364) (("-") reduce 364) ((".") reduce 364) (("/") reduce 364) (("<") reduce 364) ((">") reduce 364) (("?") reduce 364) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_AS) reduce 364) ((T_BOOLEAN_AND) reduce 364) ((T_BOOLEAN_OR) reduce 364) ((T_COALESCE) reduce 364) ((T_DOUBLE_ARROW) reduce 364) ((T_INSTANCEOF) reduce 364) ((T_IS_EQUAL) reduce 364) ((T_IS_GREATER_OR_EQUAL) reduce 364) ((T_IS_IDENTICAL) reduce 364) ((T_IS_NOT_EQUAL) reduce 364) ((T_IS_NOT_IDENTICAL) reduce 364) ((T_IS_SMALLER_OR_EQUAL) reduce 364) ((T_LOGICAL_AND) reduce 364) ((T_LOGICAL_OR) reduce 364) ((T_LOGICAL_XOR) reduce 364) ((T_POW) reduce 364) ((T_SL) reduce 364) ((T_SPACESHIP) reduce 364) ((T_SR) reduce 364) (("^") reduce 364) (("|") reduce 364)) 19145 ((("%") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AS) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("^") reduce 288) (("|") reduce 288)) 19149 ((("%") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AS) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("^") reduce 289) (("|") reduce 289)) 19150 ((("%") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AS) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("^") reduce 290) (("|") reduce 290)) 19152 ((("%") reduce 539) (("(") reduce 539) (("*") reduce 539) (("+") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AS) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_DOUBLE_ARROW) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 19153 ((("%") reduce 366) (("*") reduce 366) (("+") reduce 366) (("-") reduce 366) ((".") reduce 366) (("/") reduce 366) (("<") reduce 366) ((">") reduce 366) (("?") reduce 366) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_AS) reduce 366) ((T_BOOLEAN_AND) reduce 366) ((T_BOOLEAN_OR) reduce 366) ((T_COALESCE) reduce 366) ((T_DOUBLE_ARROW) reduce 366) ((T_INSTANCEOF) reduce 366) ((T_IS_EQUAL) reduce 366) ((T_IS_GREATER_OR_EQUAL) reduce 366) ((T_IS_IDENTICAL) reduce 366) ((T_IS_NOT_EQUAL) reduce 366) ((T_IS_NOT_IDENTICAL) reduce 366) ((T_IS_SMALLER_OR_EQUAL) reduce 366) ((T_LOGICAL_AND) reduce 366) ((T_LOGICAL_OR) reduce 366) ((T_LOGICAL_XOR) reduce 366) ((T_POW) reduce 366) ((T_SL) reduce 366) ((T_SPACESHIP) reduce 366) ((T_SR) reduce 366) (("^") reduce 366) (("|") reduce 366)) 19161 ((("%") reduce 363) (("*") reduce 363) (("+") reduce 363) (("-") reduce 363) ((".") reduce 363) (("/") reduce 363) (("<") reduce 363) ((">") reduce 363) (("?") reduce 363) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_AS) reduce 363) ((T_BOOLEAN_AND) reduce 363) ((T_BOOLEAN_OR) reduce 363) ((T_COALESCE) reduce 363) ((T_DOUBLE_ARROW) reduce 363) ((T_INSTANCEOF) reduce 363) ((T_IS_EQUAL) reduce 363) ((T_IS_GREATER_OR_EQUAL) reduce 363) ((T_IS_IDENTICAL) reduce 363) ((T_IS_NOT_EQUAL) reduce 363) ((T_IS_NOT_IDENTICAL) reduce 363) ((T_IS_SMALLER_OR_EQUAL) reduce 363) ((T_LOGICAL_AND) reduce 363) ((T_LOGICAL_OR) reduce 363) ((T_LOGICAL_XOR) reduce 363) ((T_POW) reduce 363) ((T_SL) reduce 363) ((T_SPACESHIP) reduce 363) ((T_SR) reduce 363) (("^") reduce 363) (("|") reduce 363)) 19163 ((("%") reduce 474) (("(") reduce 474) (("*") reduce 474) (("+") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AS) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_DOUBLE_ARROW) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474)) 19169 ((("%") reduce 230) (("*") reduce 230) (("+") reduce 230) (("-") reduce 230) ((".") reduce 230) (("/") reduce 230) (("<") reduce 230) ((">") reduce 230) (("?") reduce 230) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_AS) reduce 230) ((T_BOOLEAN_AND) reduce 230) ((T_BOOLEAN_OR) reduce 230) ((T_COALESCE) reduce 230) ((T_DOUBLE_ARROW) reduce 230) ((T_INSTANCEOF) reduce 230) ((T_IS_EQUAL) reduce 230) ((T_IS_GREATER_OR_EQUAL) reduce 230) ((T_IS_IDENTICAL) reduce 230) ((T_IS_NOT_EQUAL) reduce 230) ((T_IS_NOT_IDENTICAL) reduce 230) ((T_IS_SMALLER_OR_EQUAL) reduce 230) ((T_LOGICAL_AND) reduce 230) ((T_LOGICAL_OR) reduce 230) ((T_LOGICAL_XOR) reduce 230) ((T_POW) reduce 230) ((T_SL) reduce 230) ((T_SPACESHIP) reduce 230) ((T_SR) reduce 230) (("^") reduce 230) (("|") reduce 230)) 19174 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 368) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 368) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 368) ((T_LOGICAL_OR) reduce 368) ((T_LOGICAL_XOR) reduce 368) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 19178 ((("%") reduce 575) (("*") reduce 575) (("+") reduce 575) (("-") reduce 575) ((".") reduce 575) (("/") reduce 575) (("<") reduce 575) ((">") reduce 575) (("?") reduce 575) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_AS) reduce 575) ((T_BOOLEAN_AND) reduce 575) ((T_BOOLEAN_OR) reduce 575) ((T_COALESCE) reduce 575) ((T_DOUBLE_ARROW) reduce 575) ((T_INSTANCEOF) reduce 575) ((T_IS_EQUAL) reduce 575) ((T_IS_GREATER_OR_EQUAL) reduce 575) ((T_IS_IDENTICAL) reduce 575) ((T_IS_NOT_EQUAL) reduce 575) ((T_IS_NOT_IDENTICAL) reduce 575) ((T_IS_SMALLER_OR_EQUAL) reduce 575) ((T_LOGICAL_AND) reduce 575) ((T_LOGICAL_OR) reduce 575) ((T_LOGICAL_XOR) reduce 575) ((T_POW) reduce 575) ((T_SL) reduce 575) ((T_SPACESHIP) reduce 575) ((T_SR) reduce 575) (("^") reduce 575) (("|") reduce 575)) 19179 ((("%") reduce 428) (("*") reduce 428) (("+") reduce 428) (("-") reduce 428) ((".") reduce 428) (("/") reduce 428) (("<") reduce 428) ((">") reduce 428) (("?") reduce 428) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_AS) reduce 428) ((T_BOOLEAN_AND) reduce 428) ((T_BOOLEAN_OR) reduce 428) ((T_COALESCE) reduce 428) ((T_DOUBLE_ARROW) reduce 428) ((T_INSTANCEOF) reduce 428) ((T_IS_EQUAL) reduce 428) ((T_IS_GREATER_OR_EQUAL) reduce 428) ((T_IS_IDENTICAL) reduce 428) ((T_IS_NOT_EQUAL) reduce 428) ((T_IS_NOT_IDENTICAL) reduce 428) ((T_IS_SMALLER_OR_EQUAL) reduce 428) ((T_LOGICAL_AND) reduce 428) ((T_LOGICAL_OR) reduce 428) ((T_LOGICAL_XOR) reduce 428) ((T_POW) shift) ((T_SL) reduce 428) ((T_SPACESHIP) reduce 428) ((T_SR) reduce 428) (("^") reduce 428) (("|") reduce 428)) 19180 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 578) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 578) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 19181 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 577) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 577) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 19182 ((("%") reduce 387) (("*") reduce 387) (("+") reduce 387) (("-") reduce 387) ((".") reduce 387) (("/") reduce 387) (("<") reduce 387) ((">") reduce 387) (("?") reduce 387) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_AS) reduce 387) ((T_BOOLEAN_AND) reduce 387) ((T_BOOLEAN_OR) reduce 387) ((T_COALESCE) reduce 387) ((T_DOUBLE_ARROW) reduce 387) ((T_INSTANCEOF) reduce 387) ((T_IS_EQUAL) reduce 387) ((T_IS_GREATER_OR_EQUAL) reduce 387) ((T_IS_IDENTICAL) reduce 387) ((T_IS_NOT_EQUAL) reduce 387) ((T_IS_NOT_IDENTICAL) reduce 387) ((T_IS_SMALLER_OR_EQUAL) reduce 387) ((T_LOGICAL_AND) reduce 387) ((T_LOGICAL_OR) reduce 387) ((T_LOGICAL_XOR) reduce 387) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 387) ((T_SL) reduce 387) ((T_SPACESHIP) reduce 387) ((T_SR) reduce 387) (("[") reduce 510) (("^") reduce 387) (("{") reduce 510) (("|") reduce 387)) 19184 ((("%") reduce 435) (("*") reduce 435) (("+") reduce 435) (("-") reduce 435) ((".") reduce 435) (("/") reduce 435) (("<") reduce 435) ((">") reduce 435) (("?") reduce 435) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_AS) reduce 435) ((T_BOOLEAN_AND) reduce 435) ((T_BOOLEAN_OR) reduce 435) ((T_COALESCE) reduce 435) ((T_DOUBLE_ARROW) reduce 435) ((T_INSTANCEOF) reduce 435) ((T_IS_EQUAL) reduce 435) ((T_IS_GREATER_OR_EQUAL) reduce 435) ((T_IS_IDENTICAL) reduce 435) ((T_IS_NOT_EQUAL) reduce 435) ((T_IS_NOT_IDENTICAL) reduce 435) ((T_IS_SMALLER_OR_EQUAL) reduce 435) ((T_LOGICAL_AND) reduce 435) ((T_LOGICAL_OR) reduce 435) ((T_LOGICAL_XOR) reduce 435) ((T_POW) reduce 435) ((T_SL) reduce 435) ((T_SPACESHIP) reduce 435) ((T_SR) reduce 435) (("^") reduce 435) (("|") reduce 435)) 19186 ((("%") reduce 476) (("*") reduce 476) (("+") reduce 476) (("-") reduce 476) ((".") reduce 476) (("/") reduce 476) (("<") reduce 476) ((">") reduce 476) (("?") reduce 476) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_AS) reduce 476) ((T_BOOLEAN_AND) reduce 476) ((T_BOOLEAN_OR) reduce 476) ((T_COALESCE) reduce 476) ((T_DOUBLE_ARROW) reduce 476) ((T_INSTANCEOF) reduce 476) ((T_IS_EQUAL) reduce 476) ((T_IS_GREATER_OR_EQUAL) reduce 476) ((T_IS_IDENTICAL) reduce 476) ((T_IS_NOT_EQUAL) reduce 476) ((T_IS_NOT_IDENTICAL) reduce 476) ((T_IS_SMALLER_OR_EQUAL) reduce 476) ((T_LOGICAL_AND) reduce 476) ((T_LOGICAL_OR) reduce 476) ((T_LOGICAL_XOR) reduce 476) ((T_POW) reduce 476) ((T_SL) reduce 476) ((T_SPACESHIP) reduce 476) ((T_SR) reduce 476) (("^") reduce 476) (("|") reduce 476)) 19189 ((("%") reduce 579) (("*") reduce 579) (("+") reduce 579) (("-") reduce 579) ((".") reduce 579) (("/") reduce 579) (("<") reduce 579) ((">") reduce 579) (("?") reduce 579) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_AS) reduce 579) ((T_BOOLEAN_AND) reduce 579) ((T_BOOLEAN_OR) reduce 579) ((T_COALESCE) reduce 579) ((T_DOUBLE_ARROW) reduce 579) ((T_INSTANCEOF) reduce 579) ((T_IS_EQUAL) reduce 579) ((T_IS_GREATER_OR_EQUAL) reduce 579) ((T_IS_IDENTICAL) reduce 579) ((T_IS_NOT_EQUAL) reduce 579) ((T_IS_NOT_IDENTICAL) reduce 579) ((T_IS_SMALLER_OR_EQUAL) reduce 579) ((T_LOGICAL_AND) reduce 579) ((T_LOGICAL_OR) reduce 579) ((T_LOGICAL_XOR) reduce 579) ((T_POW) reduce 579) ((T_SL) reduce 579) ((T_SPACESHIP) reduce 579) ((T_SR) reduce 579) (("^") reduce 579) (("|") reduce 579)) 19192 ((("%") reduce 576) (("*") reduce 576) (("+") reduce 576) (("-") reduce 576) ((".") reduce 576) (("/") reduce 576) (("<") reduce 576) ((">") reduce 576) (("?") reduce 576) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_AS) reduce 576) ((T_BOOLEAN_AND) reduce 576) ((T_BOOLEAN_OR) reduce 576) ((T_COALESCE) reduce 576) ((T_DOUBLE_ARROW) reduce 576) ((T_INSTANCEOF) reduce 576) ((T_IS_EQUAL) reduce 576) ((T_IS_GREATER_OR_EQUAL) reduce 576) ((T_IS_IDENTICAL) reduce 576) ((T_IS_NOT_EQUAL) reduce 576) ((T_IS_NOT_IDENTICAL) reduce 576) ((T_IS_SMALLER_OR_EQUAL) reduce 576) ((T_LOGICAL_AND) reduce 576) ((T_LOGICAL_OR) reduce 576) ((T_LOGICAL_XOR) reduce 576) ((T_POW) reduce 576) ((T_SL) reduce 576) ((T_SPACESHIP) reduce 576) ((T_SR) reduce 576) (("^") reduce 576) (("|") reduce 576)) 19193 ((("%") reduce 429) (("*") reduce 429) (("+") reduce 429) (("-") reduce 429) ((".") reduce 429) (("/") reduce 429) (("<") reduce 429) ((">") reduce 429) (("?") reduce 429) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_AS) reduce 429) ((T_BOOLEAN_AND) reduce 429) ((T_BOOLEAN_OR) reduce 429) ((T_COALESCE) reduce 429) ((T_DOUBLE_ARROW) reduce 429) ((T_INSTANCEOF) reduce 429) ((T_IS_EQUAL) reduce 429) ((T_IS_GREATER_OR_EQUAL) reduce 429) ((T_IS_IDENTICAL) reduce 429) ((T_IS_NOT_EQUAL) reduce 429) ((T_IS_NOT_IDENTICAL) reduce 429) ((T_IS_SMALLER_OR_EQUAL) reduce 429) ((T_LOGICAL_AND) reduce 429) ((T_LOGICAL_OR) reduce 429) ((T_LOGICAL_XOR) reduce 429) ((T_POW) shift) ((T_SL) reduce 429) ((T_SPACESHIP) reduce 429) ((T_SR) reduce 429) (("^") reduce 429) (("|") reduce 429)) 19194 ((("%") reduce 389) (("*") reduce 389) (("+") reduce 389) (("-") reduce 389) ((".") reduce 389) (("/") reduce 389) (("<") reduce 389) ((">") reduce 389) (("?") reduce 389) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_AS) reduce 389) ((T_BOOLEAN_AND) reduce 389) ((T_BOOLEAN_OR) reduce 389) ((T_COALESCE) reduce 389) ((T_DOUBLE_ARROW) reduce 389) ((T_INSTANCEOF) reduce 389) ((T_IS_EQUAL) reduce 389) ((T_IS_GREATER_OR_EQUAL) reduce 389) ((T_IS_IDENTICAL) reduce 389) ((T_IS_NOT_EQUAL) reduce 389) ((T_IS_NOT_IDENTICAL) reduce 389) ((T_IS_SMALLER_OR_EQUAL) reduce 389) ((T_LOGICAL_AND) reduce 389) ((T_LOGICAL_OR) reduce 389) ((T_LOGICAL_XOR) reduce 389) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 389) ((T_SL) reduce 389) ((T_SPACESHIP) reduce 389) ((T_SR) reduce 389) (("[") reduce 510) (("^") reduce 389) (("{") reduce 510) (("|") reduce 389)) 19195 ((("%") reduce 372) (("*") reduce 372) (("+") reduce 372) (("-") reduce 372) ((".") reduce 372) (("/") reduce 372) (("<") reduce 372) ((">") reduce 372) (("?") reduce 372) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_AS) reduce 372) ((T_BOOLEAN_AND) reduce 372) ((T_BOOLEAN_OR) reduce 372) ((T_COALESCE) reduce 372) ((T_DOUBLE_ARROW) reduce 372) ((T_INSTANCEOF) reduce 372) ((T_IS_EQUAL) reduce 372) ((T_IS_GREATER_OR_EQUAL) reduce 372) ((T_IS_IDENTICAL) reduce 372) ((T_IS_NOT_EQUAL) reduce 372) ((T_IS_NOT_IDENTICAL) reduce 372) ((T_IS_SMALLER_OR_EQUAL) reduce 372) ((T_LOGICAL_AND) reduce 372) ((T_LOGICAL_OR) reduce 372) ((T_LOGICAL_XOR) reduce 372) ((T_POW) reduce 372) ((T_SL) reduce 372) ((T_SPACESHIP) reduce 372) ((T_SR) reduce 372) (("^") reduce 372) (("|") reduce 372)) 19196 ((("%") reduce 433) (("*") reduce 433) (("+") reduce 433) (("-") reduce 433) ((".") reduce 433) (("/") reduce 433) (("<") reduce 433) ((">") reduce 433) (("?") reduce 433) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_AS) reduce 433) ((T_BOOLEAN_AND) reduce 433) ((T_BOOLEAN_OR) reduce 433) ((T_COALESCE) reduce 433) ((T_DOUBLE_ARROW) reduce 433) ((T_INSTANCEOF) reduce 433) ((T_IS_EQUAL) reduce 433) ((T_IS_GREATER_OR_EQUAL) reduce 433) ((T_IS_IDENTICAL) reduce 433) ((T_IS_NOT_EQUAL) reduce 433) ((T_IS_NOT_IDENTICAL) reduce 433) ((T_IS_SMALLER_OR_EQUAL) reduce 433) ((T_LOGICAL_AND) reduce 433) ((T_LOGICAL_OR) reduce 433) ((T_LOGICAL_XOR) reduce 433) ((T_POW) shift) ((T_SL) reduce 433) ((T_SPACESHIP) reduce 433) ((T_SR) reduce 433) (("^") reduce 433) (("|") reduce 433)) 19197 ((("%") reduce 431) (("*") reduce 431) (("+") reduce 431) (("-") reduce 431) ((".") reduce 431) (("/") reduce 431) (("<") reduce 431) ((">") reduce 431) (("?") reduce 431) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_AS) reduce 431) ((T_BOOLEAN_AND) reduce 431) ((T_BOOLEAN_OR) reduce 431) ((T_COALESCE) reduce 431) ((T_DOUBLE_ARROW) reduce 431) ((T_INSTANCEOF) reduce 431) ((T_IS_EQUAL) reduce 431) ((T_IS_GREATER_OR_EQUAL) reduce 431) ((T_IS_IDENTICAL) reduce 431) ((T_IS_NOT_EQUAL) reduce 431) ((T_IS_NOT_IDENTICAL) reduce 431) ((T_IS_SMALLER_OR_EQUAL) reduce 431) ((T_LOGICAL_AND) reduce 431) ((T_LOGICAL_OR) reduce 431) ((T_LOGICAL_XOR) reduce 431) ((T_POW) shift) ((T_SL) reduce 431) ((T_SPACESHIP) reduce 431) ((T_SR) reduce 431) (("^") reduce 431) (("|") reduce 431)) 19200 ((("%") reduce 482) (("(") reduce 482) (("*") reduce 482) (("+") reduce 482) (("-") reduce 482) ((".") reduce 482) (("/") reduce 482) (("<") reduce 482) ((">") reduce 482) (("?") reduce 482) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_AS) reduce 482) ((T_BOOLEAN_AND) reduce 482) ((T_BOOLEAN_OR) reduce 482) ((T_COALESCE) reduce 482) ((T_DOUBLE_ARROW) reduce 482) ((T_INSTANCEOF) reduce 482) ((T_IS_EQUAL) reduce 482) ((T_IS_GREATER_OR_EQUAL) reduce 482) ((T_IS_IDENTICAL) reduce 482) ((T_IS_NOT_EQUAL) reduce 482) ((T_IS_NOT_IDENTICAL) reduce 482) ((T_IS_SMALLER_OR_EQUAL) reduce 482) ((T_LOGICAL_AND) reduce 482) ((T_LOGICAL_OR) reduce 482) ((T_LOGICAL_XOR) reduce 482) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 482) ((T_OBJECT_OPERATOR) reduce 482) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 482) ((T_POW) reduce 482) ((T_SL) reduce 482) ((T_SPACESHIP) reduce 482) ((T_SR) reduce 482) (("[") reduce 482) (("^") reduce 482) (("{") reduce 482) (("|") reduce 482)) 19201 ((("%") reduce 436) (("*") reduce 436) (("+") reduce 436) (("-") reduce 436) ((".") reduce 436) (("/") reduce 436) (("<") reduce 436) ((">") reduce 436) (("?") reduce 436) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_AS) reduce 436) ((T_BOOLEAN_AND) reduce 436) ((T_BOOLEAN_OR) reduce 436) ((T_COALESCE) reduce 436) ((T_DOUBLE_ARROW) reduce 436) ((T_INSTANCEOF) reduce 436) ((T_IS_EQUAL) reduce 436) ((T_IS_GREATER_OR_EQUAL) reduce 436) ((T_IS_IDENTICAL) reduce 436) ((T_IS_NOT_EQUAL) reduce 436) ((T_IS_NOT_IDENTICAL) reduce 436) ((T_IS_SMALLER_OR_EQUAL) reduce 436) ((T_LOGICAL_AND) reduce 436) ((T_LOGICAL_OR) reduce 436) ((T_LOGICAL_XOR) reduce 436) ((T_POW) shift) ((T_SL) reduce 436) ((T_SPACESHIP) reduce 436) ((T_SR) reduce 436) (("^") reduce 436) (("|") reduce 436)) 19202 ((("%") reduce 409) (("*") reduce 409) (("+") reduce 409) (("-") reduce 409) ((".") reduce 409) (("/") reduce 409) (("<") reduce 409) ((">") reduce 409) (("?") reduce 409) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_AS) reduce 409) ((T_BOOLEAN_AND) reduce 409) ((T_BOOLEAN_OR) reduce 409) ((T_COALESCE) reduce 409) ((T_DOUBLE_ARROW) reduce 409) ((T_INSTANCEOF) reduce 409) ((T_IS_EQUAL) reduce 409) ((T_IS_GREATER_OR_EQUAL) reduce 409) ((T_IS_IDENTICAL) reduce 409) ((T_IS_NOT_EQUAL) reduce 409) ((T_IS_NOT_IDENTICAL) reduce 409) ((T_IS_SMALLER_OR_EQUAL) reduce 409) ((T_LOGICAL_AND) reduce 409) ((T_LOGICAL_OR) reduce 409) ((T_LOGICAL_XOR) reduce 409) ((T_POW) shift) ((T_SL) reduce 409) ((T_SPACESHIP) reduce 409) ((T_SR) reduce 409) (("^") reduce 409) (("|") reduce 409)) 19203 ((("%") reduce 408) (("*") reduce 408) (("+") reduce 408) (("-") reduce 408) ((".") reduce 408) (("/") reduce 408) (("<") reduce 408) ((">") reduce 408) (("?") reduce 408) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_AS) reduce 408) ((T_BOOLEAN_AND) reduce 408) ((T_BOOLEAN_OR) reduce 408) ((T_COALESCE) reduce 408) ((T_DOUBLE_ARROW) reduce 408) ((T_INSTANCEOF) reduce 408) ((T_IS_EQUAL) reduce 408) ((T_IS_GREATER_OR_EQUAL) reduce 408) ((T_IS_IDENTICAL) reduce 408) ((T_IS_NOT_EQUAL) reduce 408) ((T_IS_NOT_IDENTICAL) reduce 408) ((T_IS_SMALLER_OR_EQUAL) reduce 408) ((T_LOGICAL_AND) reduce 408) ((T_LOGICAL_OR) reduce 408) ((T_LOGICAL_XOR) reduce 408) ((T_POW) shift) ((T_SL) reduce 408) ((T_SPACESHIP) reduce 408) ((T_SR) reduce 408) (("^") reduce 408) (("|") reduce 408)) 19205 ((("%") reduce 422) (("(") reduce 517) (("*") reduce 422) (("+") reduce 422) (("-") reduce 422) ((".") reduce 422) (("/") reduce 422) (("<") reduce 422) ((">") reduce 422) (("?") reduce 422) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_AS) reduce 422) ((T_BOOLEAN_AND) reduce 422) ((T_BOOLEAN_OR) reduce 422) ((T_COALESCE) reduce 422) ((T_DOUBLE_ARROW) reduce 422) ((T_INSTANCEOF) reduce 422) ((T_IS_EQUAL) reduce 422) ((T_IS_GREATER_OR_EQUAL) reduce 422) ((T_IS_IDENTICAL) reduce 422) ((T_IS_NOT_EQUAL) reduce 422) ((T_IS_NOT_IDENTICAL) reduce 422) ((T_IS_SMALLER_OR_EQUAL) reduce 422) ((T_LOGICAL_AND) reduce 422) ((T_LOGICAL_OR) reduce 422) ((T_LOGICAL_XOR) reduce 422) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 511) ((T_OBJECT_OPERATOR) reduce 511) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 511) ((T_POW) reduce 422) ((T_SL) reduce 422) ((T_SPACESHIP) reduce 422) ((T_SR) reduce 422) (("[") reduce 511) (("^") reduce 422) (("{") reduce 511) (("|") reduce 422)) 19206 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) (("=") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AND_EQUAL) reduce 531) ((T_AS) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_COALESCE_EQUAL) reduce 531) ((T_CONCAT_EQUAL) reduce 531) ((T_DEC) reduce 531) ((T_DIV_EQUAL) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INC) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_MINUS_EQUAL) reduce 531) ((T_MOD_EQUAL) reduce 531) ((T_MUL_EQUAL) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_OR_EQUAL) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_PLUS_EQUAL) reduce 531) ((T_POW) reduce 531) ((T_POW_EQUAL) reduce 531) ((T_SL) reduce 531) ((T_SL_EQUAL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) ((T_SR_EQUAL) reduce 531) ((T_XOR_EQUAL) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 19209 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) (("=") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AND_EQUAL) reduce 530) ((T_AS) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_COALESCE_EQUAL) reduce 530) ((T_CONCAT_EQUAL) reduce 530) ((T_DEC) reduce 530) ((T_DIV_EQUAL) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INC) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_MINUS_EQUAL) reduce 530) ((T_MOD_EQUAL) reduce 530) ((T_MUL_EQUAL) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_OR_EQUAL) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_PLUS_EQUAL) reduce 530) ((T_POW) reduce 530) ((T_POW_EQUAL) reduce 530) ((T_SL) reduce 530) ((T_SL_EQUAL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) ((T_SR_EQUAL) reduce 530) ((T_XOR_EQUAL) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 19211 ((("%") reduce 485) (("(") reduce 485) (("*") reduce 485) (("+") reduce 485) (("-") reduce 485) ((".") reduce 485) (("/") reduce 485) (("<") reduce 485) ((">") reduce 485) (("?") reduce 485) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_AS) reduce 485) ((T_BOOLEAN_AND) reduce 485) ((T_BOOLEAN_OR) reduce 485) ((T_COALESCE) reduce 485) ((T_DOUBLE_ARROW) reduce 485) ((T_INSTANCEOF) reduce 485) ((T_IS_EQUAL) reduce 485) ((T_IS_GREATER_OR_EQUAL) reduce 485) ((T_IS_IDENTICAL) reduce 485) ((T_IS_NOT_EQUAL) reduce 485) ((T_IS_NOT_IDENTICAL) reduce 485) ((T_IS_SMALLER_OR_EQUAL) reduce 485) ((T_LOGICAL_AND) reduce 485) ((T_LOGICAL_OR) reduce 485) ((T_LOGICAL_XOR) reduce 485) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 485) ((T_OBJECT_OPERATOR) reduce 485) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 485) ((T_POW) reduce 485) ((T_SL) reduce 485) ((T_SPACESHIP) reduce 485) ((T_SR) reduce 485) (("[") reduce 485) (("^") reduce 485) (("{") reduce 485) (("|") reduce 485)) 19212 ((("%") reduce 410) (("*") reduce 410) (("+") reduce 410) (("-") reduce 410) ((".") reduce 410) (("/") reduce 410) (("<") reduce 410) ((">") reduce 410) (("?") reduce 410) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_AS) reduce 410) ((T_BOOLEAN_AND) reduce 410) ((T_BOOLEAN_OR) reduce 410) ((T_COALESCE) reduce 410) ((T_DOUBLE_ARROW) reduce 410) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 410) ((T_IS_GREATER_OR_EQUAL) reduce 410) ((T_IS_IDENTICAL) reduce 410) ((T_IS_NOT_EQUAL) reduce 410) ((T_IS_NOT_IDENTICAL) reduce 410) ((T_IS_SMALLER_OR_EQUAL) reduce 410) ((T_LOGICAL_AND) reduce 410) ((T_LOGICAL_OR) reduce 410) ((T_LOGICAL_XOR) reduce 410) ((T_POW) shift) ((T_SL) reduce 410) ((T_SPACESHIP) reduce 410) ((T_SR) reduce 410) (("^") reduce 410) (("|") reduce 410)) 19213 ((("%") reduce 434) (("*") reduce 434) (("+") reduce 434) (("-") reduce 434) ((".") reduce 434) (("/") reduce 434) (("<") reduce 434) ((">") reduce 434) (("?") reduce 434) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_AS) reduce 434) ((T_BOOLEAN_AND) reduce 434) ((T_BOOLEAN_OR) reduce 434) ((T_COALESCE) reduce 434) ((T_INSTANCEOF) reduce 434) ((T_IS_EQUAL) reduce 434) ((T_IS_GREATER_OR_EQUAL) reduce 434) ((T_IS_IDENTICAL) reduce 434) ((T_IS_NOT_EQUAL) reduce 434) ((T_IS_NOT_IDENTICAL) reduce 434) ((T_IS_SMALLER_OR_EQUAL) reduce 434) ((T_LOGICAL_AND) reduce 434) ((T_LOGICAL_OR) reduce 434) ((T_LOGICAL_XOR) reduce 434) ((T_POW) shift) ((T_SL) reduce 434) ((T_SPACESHIP) reduce 434) ((T_SR) reduce 434) (("^") reduce 434) (("|") reduce 434)) 19214 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 444) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 19215 ((("%") reduce 430) (("*") reduce 430) (("+") reduce 430) (("-") reduce 430) ((".") reduce 430) (("/") reduce 430) (("<") reduce 430) ((">") reduce 430) (("?") reduce 430) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_AS) reduce 430) ((T_BOOLEAN_AND) reduce 430) ((T_BOOLEAN_OR) reduce 430) ((T_COALESCE) reduce 430) ((T_INSTANCEOF) reduce 430) ((T_IS_EQUAL) reduce 430) ((T_IS_GREATER_OR_EQUAL) reduce 430) ((T_IS_IDENTICAL) reduce 430) ((T_IS_NOT_EQUAL) reduce 430) ((T_IS_NOT_IDENTICAL) reduce 430) ((T_IS_SMALLER_OR_EQUAL) reduce 430) ((T_LOGICAL_AND) reduce 430) ((T_LOGICAL_OR) reduce 430) ((T_LOGICAL_XOR) reduce 430) ((T_POW) shift) ((T_SL) reduce 430) ((T_SPACESHIP) reduce 430) ((T_SR) reduce 430) (("^") reduce 430) (("|") reduce 430)) 19216 ((("%") reduce 447) (("*") reduce 447) (("+") reduce 447) (("-") reduce 447) ((".") reduce 447) (("/") reduce 447) (("<") reduce 447) ((">") reduce 447) (("?") reduce 447) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_AS) reduce 447) ((T_BOOLEAN_AND) reduce 447) ((T_BOOLEAN_OR) reduce 447) ((T_COALESCE) reduce 447) ((T_INSTANCEOF) reduce 447) ((T_IS_EQUAL) reduce 447) ((T_IS_GREATER_OR_EQUAL) reduce 447) ((T_IS_IDENTICAL) reduce 447) ((T_IS_NOT_EQUAL) reduce 447) ((T_IS_NOT_IDENTICAL) reduce 447) ((T_IS_SMALLER_OR_EQUAL) reduce 447) ((T_LOGICAL_AND) reduce 447) ((T_LOGICAL_OR) reduce 447) ((T_LOGICAL_XOR) reduce 447) ((T_POW) reduce 447) ((T_SL) reduce 447) ((T_SPACESHIP) reduce 447) ((T_SR) reduce 447) (("^") reduce 447) (("|") reduce 447)) 19218 ((("%") reduce 489) (("*") reduce 489) (("+") reduce 489) (("-") reduce 489) ((".") reduce 489) (("/") reduce 489) (("<") reduce 489) ((">") reduce 489) (("?") reduce 489) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_AS) reduce 489) ((T_BOOLEAN_AND) reduce 489) ((T_BOOLEAN_OR) reduce 489) ((T_COALESCE) reduce 489) ((T_INSTANCEOF) reduce 489) ((T_IS_EQUAL) reduce 489) ((T_IS_GREATER_OR_EQUAL) reduce 489) ((T_IS_IDENTICAL) reduce 489) ((T_IS_NOT_EQUAL) reduce 489) ((T_IS_NOT_IDENTICAL) reduce 489) ((T_IS_SMALLER_OR_EQUAL) reduce 489) ((T_LOGICAL_AND) reduce 489) ((T_LOGICAL_OR) reduce 489) ((T_LOGICAL_XOR) reduce 489) ((T_POW) reduce 489) ((T_SL) reduce 489) ((T_SPACESHIP) reduce 489) ((T_SR) reduce 489) (("^") reduce 489) (("|") reduce 489)) 19220 ((("%") reduce 490) (("*") reduce 490) (("+") reduce 490) (("-") reduce 490) ((".") reduce 490) (("/") reduce 490) (("<") reduce 490) ((">") reduce 490) (("?") reduce 490) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_AS) reduce 490) ((T_BOOLEAN_AND) reduce 490) ((T_BOOLEAN_OR) reduce 490) ((T_COALESCE) reduce 490) ((T_INSTANCEOF) reduce 490) ((T_IS_EQUAL) reduce 490) ((T_IS_GREATER_OR_EQUAL) reduce 490) ((T_IS_IDENTICAL) reduce 490) ((T_IS_NOT_EQUAL) reduce 490) ((T_IS_NOT_IDENTICAL) reduce 490) ((T_IS_SMALLER_OR_EQUAL) reduce 490) ((T_LOGICAL_AND) reduce 490) ((T_LOGICAL_OR) reduce 490) ((T_LOGICAL_XOR) reduce 490) ((T_POW) reduce 490) ((T_SL) reduce 490) ((T_SPACESHIP) reduce 490) ((T_SR) reduce 490) (("^") reduce 490) (("|") reduce 490)) 19221 ((("%") reduce 488) (("*") reduce 488) (("+") reduce 488) (("-") reduce 488) ((".") reduce 488) (("/") reduce 488) (("<") reduce 488) ((">") reduce 488) (("?") reduce 488) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_AS) reduce 488) ((T_BOOLEAN_AND) reduce 488) ((T_BOOLEAN_OR) reduce 488) ((T_COALESCE) reduce 488) ((T_INSTANCEOF) reduce 488) ((T_IS_EQUAL) reduce 488) ((T_IS_GREATER_OR_EQUAL) reduce 488) ((T_IS_IDENTICAL) reduce 488) ((T_IS_NOT_EQUAL) reduce 488) ((T_IS_NOT_IDENTICAL) reduce 488) ((T_IS_SMALLER_OR_EQUAL) reduce 488) ((T_LOGICAL_AND) reduce 488) ((T_LOGICAL_OR) reduce 488) ((T_LOGICAL_XOR) reduce 488) ((T_POW) reduce 488) ((T_SL) reduce 488) ((T_SPACESHIP) reduce 488) ((T_SR) reduce 488) (("^") reduce 488) (("|") reduce 488)) 19222 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 581) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 19223 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 580) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 19224 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) (("<") reduce 466) (("=") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AND_EQUAL) reduce 466) ((T_AS) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_COALESCE_EQUAL) reduce 466) ((T_CONCAT_EQUAL) reduce 466) ((T_DEC) reduce 466) ((T_DIV_EQUAL) reduce 466) ((T_INC) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_MINUS_EQUAL) reduce 466) ((T_MOD_EQUAL) reduce 466) ((T_MUL_EQUAL) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_OR_EQUAL) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_PLUS_EQUAL) reduce 466) ((T_POW) reduce 466) ((T_POW_EQUAL) reduce 466) ((T_SL) reduce 466) ((T_SL_EQUAL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) ((T_SR_EQUAL) reduce 466) ((T_XOR_EQUAL) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 19225 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 439) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 439) ((T_LOGICAL_OR) reduce 439) ((T_LOGICAL_XOR) reduce 439) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 19226 ((("%") reduce 432) (("*") reduce 432) (("+") reduce 432) (("-") reduce 432) ((".") reduce 432) (("/") reduce 432) (("<") reduce 432) ((">") reduce 432) (("?") reduce 432) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_AS) reduce 432) ((T_BOOLEAN_AND) reduce 432) ((T_BOOLEAN_OR) reduce 432) ((T_COALESCE) reduce 432) ((T_INSTANCEOF) reduce 432) ((T_IS_EQUAL) reduce 432) ((T_IS_GREATER_OR_EQUAL) reduce 432) ((T_IS_IDENTICAL) reduce 432) ((T_IS_NOT_EQUAL) reduce 432) ((T_IS_NOT_IDENTICAL) reduce 432) ((T_IS_SMALLER_OR_EQUAL) reduce 432) ((T_LOGICAL_AND) reduce 432) ((T_LOGICAL_OR) reduce 432) ((T_LOGICAL_XOR) reduce 432) ((T_POW) shift) ((T_SL) reduce 432) ((T_SPACESHIP) reduce 432) ((T_SR) reduce 432) (("^") reduce 432) (("|") reduce 432)) 19228 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AS) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93)) 19229 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AS) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92)) 19230 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AS) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94)) 19231 ((("%") reduce 470) (("(") reduce 470) (("*") reduce 470) (("+") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AS) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470)) 19232 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AS) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91)) 19233 ((("%") reduce 365) (("*") reduce 365) (("+") reduce 365) (("-") reduce 365) ((".") reduce 365) (("/") reduce 365) (("<") reduce 365) ((">") reduce 365) (("?") reduce 365) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_AS) reduce 365) ((T_BOOLEAN_AND) reduce 365) ((T_BOOLEAN_OR) reduce 365) ((T_COALESCE) reduce 365) ((T_INSTANCEOF) reduce 365) ((T_IS_EQUAL) reduce 365) ((T_IS_GREATER_OR_EQUAL) reduce 365) ((T_IS_IDENTICAL) reduce 365) ((T_IS_NOT_EQUAL) reduce 365) ((T_IS_NOT_IDENTICAL) reduce 365) ((T_IS_SMALLER_OR_EQUAL) reduce 365) ((T_LOGICAL_AND) reduce 365) ((T_LOGICAL_OR) reduce 365) ((T_LOGICAL_XOR) reduce 365) ((T_POW) reduce 365) ((T_SL) reduce 365) ((T_SPACESHIP) reduce 365) ((T_SR) reduce 365) (("^") reduce 365) (("|") reduce 365)) 19236 ((("%") reduce 472) (("(") reduce 472) (("*") reduce 472) (("+") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AS) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472)) 19237 ((("%") reduce 480) (("(") shift) (("*") reduce 480) (("+") reduce 480) (("-") reduce 480) ((".") reduce 480) (("/") reduce 480) (("<") reduce 480) ((">") reduce 480) (("?") reduce 480) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_AS) reduce 480) ((T_BOOLEAN_AND) reduce 480) ((T_BOOLEAN_OR) reduce 480) ((T_COALESCE) reduce 480) ((T_INSTANCEOF) reduce 480) ((T_IS_EQUAL) reduce 480) ((T_IS_GREATER_OR_EQUAL) reduce 480) ((T_IS_IDENTICAL) reduce 480) ((T_IS_NOT_EQUAL) reduce 480) ((T_IS_NOT_IDENTICAL) reduce 480) ((T_IS_SMALLER_OR_EQUAL) reduce 480) ((T_LOGICAL_AND) reduce 480) ((T_LOGICAL_OR) reduce 480) ((T_LOGICAL_XOR) reduce 480) ((T_POW) reduce 480) ((T_SL) reduce 480) ((T_SPACESHIP) reduce 480) ((T_SR) reduce 480) (("^") reduce 480) (("|") reduce 480)) 19238 ((("%") reduce 471) (("(") reduce 471) (("*") reduce 471) (("+") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AS) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471)) 19239 ((("%") reduce 473) (("(") reduce 473) (("*") reduce 473) (("+") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AS) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 19240 ((("%") reduce 534) (("(") reduce 534) (("*") reduce 534) (("+") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AS) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 19247 ((("%") reduce 536) (("(") reduce 536) (("*") reduce 536) (("+") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AS) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 19249 ((("%") reduce 535) (("(") reduce 535) (("*") reduce 535) (("+") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AS) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 19250 ((("%") reduce 540) (("(") reduce 540) (("*") reduce 540) (("+") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AS) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 19251 ((("%") reduce 537) (("(") reduce 537) (("*") reduce 537) (("+") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AS) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 19252 ((("%") reduce 538) (("(") reduce 538) (("*") reduce 538) (("+") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AS) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 19254 ((("%") reduce 481) (("*") reduce 481) (("+") reduce 481) (("-") reduce 481) ((".") reduce 481) (("/") reduce 481) (("<") reduce 481) ((">") reduce 481) (("?") reduce 481) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_AS) reduce 481) ((T_BOOLEAN_AND) reduce 481) ((T_BOOLEAN_OR) reduce 481) ((T_COALESCE) reduce 481) ((T_INSTANCEOF) reduce 481) ((T_IS_EQUAL) reduce 481) ((T_IS_GREATER_OR_EQUAL) reduce 481) ((T_IS_IDENTICAL) reduce 481) ((T_IS_NOT_EQUAL) reduce 481) ((T_IS_NOT_IDENTICAL) reduce 481) ((T_IS_SMALLER_OR_EQUAL) reduce 481) ((T_LOGICAL_AND) reduce 481) ((T_LOGICAL_OR) reduce 481) ((T_LOGICAL_XOR) reduce 481) ((T_POW) reduce 481) ((T_SL) reduce 481) ((T_SPACESHIP) reduce 481) ((T_SR) reduce 481) (("^") reduce 481) (("|") reduce 481)) 19255 ((("%") reduce 364) (("*") reduce 364) (("+") reduce 364) (("-") reduce 364) ((".") reduce 364) (("/") reduce 364) (("<") reduce 364) ((">") reduce 364) (("?") reduce 364) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_AS) reduce 364) ((T_BOOLEAN_AND) reduce 364) ((T_BOOLEAN_OR) reduce 364) ((T_COALESCE) reduce 364) ((T_INSTANCEOF) reduce 364) ((T_IS_EQUAL) reduce 364) ((T_IS_GREATER_OR_EQUAL) reduce 364) ((T_IS_IDENTICAL) reduce 364) ((T_IS_NOT_EQUAL) reduce 364) ((T_IS_NOT_IDENTICAL) reduce 364) ((T_IS_SMALLER_OR_EQUAL) reduce 364) ((T_LOGICAL_AND) reduce 364) ((T_LOGICAL_OR) reduce 364) ((T_LOGICAL_XOR) reduce 364) ((T_POW) reduce 364) ((T_SL) reduce 364) ((T_SPACESHIP) reduce 364) ((T_SR) reduce 364) (("^") reduce 364) (("|") reduce 364)) 19256 ((("%") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AS) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("^") reduce 288) (("|") reduce 288)) 19260 ((("%") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AS) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("^") reduce 289) (("|") reduce 289)) 19261 ((("%") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AS) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("^") reduce 290) (("|") reduce 290)) 19263 ((("%") reduce 539) (("(") reduce 539) (("*") reduce 539) (("+") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AS) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 19264 ((("%") reduce 366) (("*") reduce 366) (("+") reduce 366) (("-") reduce 366) ((".") reduce 366) (("/") reduce 366) (("<") reduce 366) ((">") reduce 366) (("?") reduce 366) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_AS) reduce 366) ((T_BOOLEAN_AND) reduce 366) ((T_BOOLEAN_OR) reduce 366) ((T_COALESCE) reduce 366) ((T_INSTANCEOF) reduce 366) ((T_IS_EQUAL) reduce 366) ((T_IS_GREATER_OR_EQUAL) reduce 366) ((T_IS_IDENTICAL) reduce 366) ((T_IS_NOT_EQUAL) reduce 366) ((T_IS_NOT_IDENTICAL) reduce 366) ((T_IS_SMALLER_OR_EQUAL) reduce 366) ((T_LOGICAL_AND) reduce 366) ((T_LOGICAL_OR) reduce 366) ((T_LOGICAL_XOR) reduce 366) ((T_POW) reduce 366) ((T_SL) reduce 366) ((T_SPACESHIP) reduce 366) ((T_SR) reduce 366) (("^") reduce 366) (("|") reduce 366)) 19272 ((("%") reduce 363) (("*") reduce 363) (("+") reduce 363) (("-") reduce 363) ((".") reduce 363) (("/") reduce 363) (("<") reduce 363) ((">") reduce 363) (("?") reduce 363) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_AS) reduce 363) ((T_BOOLEAN_AND) reduce 363) ((T_BOOLEAN_OR) reduce 363) ((T_COALESCE) reduce 363) ((T_INSTANCEOF) reduce 363) ((T_IS_EQUAL) reduce 363) ((T_IS_GREATER_OR_EQUAL) reduce 363) ((T_IS_IDENTICAL) reduce 363) ((T_IS_NOT_EQUAL) reduce 363) ((T_IS_NOT_IDENTICAL) reduce 363) ((T_IS_SMALLER_OR_EQUAL) reduce 363) ((T_LOGICAL_AND) reduce 363) ((T_LOGICAL_OR) reduce 363) ((T_LOGICAL_XOR) reduce 363) ((T_POW) reduce 363) ((T_SL) reduce 363) ((T_SPACESHIP) reduce 363) ((T_SR) reduce 363) (("^") reduce 363) (("|") reduce 363)) 19274 ((("%") reduce 474) (("(") reduce 474) (("*") reduce 474) (("+") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AS) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474)) 19280 ((("%") reduce 230) (("*") reduce 230) (("+") reduce 230) (("-") reduce 230) ((".") reduce 230) (("/") reduce 230) (("<") reduce 230) ((">") reduce 230) (("?") reduce 230) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_AS) reduce 230) ((T_BOOLEAN_AND) reduce 230) ((T_BOOLEAN_OR) reduce 230) ((T_COALESCE) reduce 230) ((T_INSTANCEOF) reduce 230) ((T_IS_EQUAL) reduce 230) ((T_IS_GREATER_OR_EQUAL) reduce 230) ((T_IS_IDENTICAL) reduce 230) ((T_IS_NOT_EQUAL) reduce 230) ((T_IS_NOT_IDENTICAL) reduce 230) ((T_IS_SMALLER_OR_EQUAL) reduce 230) ((T_LOGICAL_AND) reduce 230) ((T_LOGICAL_OR) reduce 230) ((T_LOGICAL_XOR) reduce 230) ((T_POW) reduce 230) ((T_SL) reduce 230) ((T_SPACESHIP) reduce 230) ((T_SR) reduce 230) (("^") reduce 230) (("|") reduce 230)) 19285 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 368) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 368) ((T_LOGICAL_OR) reduce 368) ((T_LOGICAL_XOR) reduce 368) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 19289 ((("%") reduce 575) (("*") reduce 575) (("+") reduce 575) (("-") reduce 575) ((".") reduce 575) (("/") reduce 575) (("<") reduce 575) ((">") reduce 575) (("?") reduce 575) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_AS) reduce 575) ((T_BOOLEAN_AND) reduce 575) ((T_BOOLEAN_OR) reduce 575) ((T_COALESCE) reduce 575) ((T_INSTANCEOF) reduce 575) ((T_IS_EQUAL) reduce 575) ((T_IS_GREATER_OR_EQUAL) reduce 575) ((T_IS_IDENTICAL) reduce 575) ((T_IS_NOT_EQUAL) reduce 575) ((T_IS_NOT_IDENTICAL) reduce 575) ((T_IS_SMALLER_OR_EQUAL) reduce 575) ((T_LOGICAL_AND) reduce 575) ((T_LOGICAL_OR) reduce 575) ((T_LOGICAL_XOR) reduce 575) ((T_POW) reduce 575) ((T_SL) reduce 575) ((T_SPACESHIP) reduce 575) ((T_SR) reduce 575) (("^") reduce 575) (("|") reduce 575)) 19290 ((("%") reduce 428) (("*") reduce 428) (("+") reduce 428) (("-") reduce 428) ((".") reduce 428) (("/") reduce 428) (("<") reduce 428) ((">") reduce 428) (("?") reduce 428) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_AS) reduce 428) ((T_BOOLEAN_AND) reduce 428) ((T_BOOLEAN_OR) reduce 428) ((T_COALESCE) reduce 428) ((T_INSTANCEOF) reduce 428) ((T_IS_EQUAL) reduce 428) ((T_IS_GREATER_OR_EQUAL) reduce 428) ((T_IS_IDENTICAL) reduce 428) ((T_IS_NOT_EQUAL) reduce 428) ((T_IS_NOT_IDENTICAL) reduce 428) ((T_IS_SMALLER_OR_EQUAL) reduce 428) ((T_LOGICAL_AND) reduce 428) ((T_LOGICAL_OR) reduce 428) ((T_LOGICAL_XOR) reduce 428) ((T_POW) shift) ((T_SL) reduce 428) ((T_SPACESHIP) reduce 428) ((T_SR) reduce 428) (("^") reduce 428) (("|") reduce 428)) 19291 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 578) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 19292 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AS) reduce 577) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 19293 ((("%") reduce 387) (("*") reduce 387) (("+") reduce 387) (("-") reduce 387) ((".") reduce 387) (("/") reduce 387) (("<") reduce 387) ((">") reduce 387) (("?") reduce 387) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_AS) reduce 387) ((T_BOOLEAN_AND) reduce 387) ((T_BOOLEAN_OR) reduce 387) ((T_COALESCE) reduce 387) ((T_INSTANCEOF) reduce 387) ((T_IS_EQUAL) reduce 387) ((T_IS_GREATER_OR_EQUAL) reduce 387) ((T_IS_IDENTICAL) reduce 387) ((T_IS_NOT_EQUAL) reduce 387) ((T_IS_NOT_IDENTICAL) reduce 387) ((T_IS_SMALLER_OR_EQUAL) reduce 387) ((T_LOGICAL_AND) reduce 387) ((T_LOGICAL_OR) reduce 387) ((T_LOGICAL_XOR) reduce 387) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 387) ((T_SL) reduce 387) ((T_SPACESHIP) reduce 387) ((T_SR) reduce 387) (("[") reduce 510) (("^") reduce 387) (("{") reduce 510) (("|") reduce 387)) 19295 ((("%") reduce 435) (("*") reduce 435) (("+") reduce 435) (("-") reduce 435) ((".") reduce 435) (("/") reduce 435) (("<") reduce 435) ((">") reduce 435) (("?") reduce 435) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_AS) reduce 435) ((T_BOOLEAN_AND) reduce 435) ((T_BOOLEAN_OR) reduce 435) ((T_COALESCE) reduce 435) ((T_INSTANCEOF) reduce 435) ((T_IS_EQUAL) reduce 435) ((T_IS_GREATER_OR_EQUAL) reduce 435) ((T_IS_IDENTICAL) reduce 435) ((T_IS_NOT_EQUAL) reduce 435) ((T_IS_NOT_IDENTICAL) reduce 435) ((T_IS_SMALLER_OR_EQUAL) reduce 435) ((T_LOGICAL_AND) reduce 435) ((T_LOGICAL_OR) reduce 435) ((T_LOGICAL_XOR) reduce 435) ((T_POW) reduce 435) ((T_SL) reduce 435) ((T_SPACESHIP) reduce 435) ((T_SR) reduce 435) (("^") reduce 435) (("|") reduce 435)) 19297 ((("%") reduce 476) (("*") reduce 476) (("+") reduce 476) (("-") reduce 476) ((".") reduce 476) (("/") reduce 476) (("<") reduce 476) ((">") reduce 476) (("?") reduce 476) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_AS) reduce 476) ((T_BOOLEAN_AND) reduce 476) ((T_BOOLEAN_OR) reduce 476) ((T_COALESCE) reduce 476) ((T_INSTANCEOF) reduce 476) ((T_IS_EQUAL) reduce 476) ((T_IS_GREATER_OR_EQUAL) reduce 476) ((T_IS_IDENTICAL) reduce 476) ((T_IS_NOT_EQUAL) reduce 476) ((T_IS_NOT_IDENTICAL) reduce 476) ((T_IS_SMALLER_OR_EQUAL) reduce 476) ((T_LOGICAL_AND) reduce 476) ((T_LOGICAL_OR) reduce 476) ((T_LOGICAL_XOR) reduce 476) ((T_POW) reduce 476) ((T_SL) reduce 476) ((T_SPACESHIP) reduce 476) ((T_SR) reduce 476) (("^") reduce 476) (("|") reduce 476)) 19300 ((("%") reduce 579) (("*") reduce 579) (("+") reduce 579) (("-") reduce 579) ((".") reduce 579) (("/") reduce 579) (("<") reduce 579) ((">") reduce 579) (("?") reduce 579) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_AS) reduce 579) ((T_BOOLEAN_AND) reduce 579) ((T_BOOLEAN_OR) reduce 579) ((T_COALESCE) reduce 579) ((T_INSTANCEOF) reduce 579) ((T_IS_EQUAL) reduce 579) ((T_IS_GREATER_OR_EQUAL) reduce 579) ((T_IS_IDENTICAL) reduce 579) ((T_IS_NOT_EQUAL) reduce 579) ((T_IS_NOT_IDENTICAL) reduce 579) ((T_IS_SMALLER_OR_EQUAL) reduce 579) ((T_LOGICAL_AND) reduce 579) ((T_LOGICAL_OR) reduce 579) ((T_LOGICAL_XOR) reduce 579) ((T_POW) reduce 579) ((T_SL) reduce 579) ((T_SPACESHIP) reduce 579) ((T_SR) reduce 579) (("^") reduce 579) (("|") reduce 579)) 19303 ((("%") reduce 576) (("*") reduce 576) (("+") reduce 576) (("-") reduce 576) ((".") reduce 576) (("/") reduce 576) (("<") reduce 576) ((">") reduce 576) (("?") reduce 576) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_AS) reduce 576) ((T_BOOLEAN_AND) reduce 576) ((T_BOOLEAN_OR) reduce 576) ((T_COALESCE) reduce 576) ((T_INSTANCEOF) reduce 576) ((T_IS_EQUAL) reduce 576) ((T_IS_GREATER_OR_EQUAL) reduce 576) ((T_IS_IDENTICAL) reduce 576) ((T_IS_NOT_EQUAL) reduce 576) ((T_IS_NOT_IDENTICAL) reduce 576) ((T_IS_SMALLER_OR_EQUAL) reduce 576) ((T_LOGICAL_AND) reduce 576) ((T_LOGICAL_OR) reduce 576) ((T_LOGICAL_XOR) reduce 576) ((T_POW) reduce 576) ((T_SL) reduce 576) ((T_SPACESHIP) reduce 576) ((T_SR) reduce 576) (("^") reduce 576) (("|") reduce 576)) 19304 ((("%") reduce 429) (("*") reduce 429) (("+") reduce 429) (("-") reduce 429) ((".") reduce 429) (("/") reduce 429) (("<") reduce 429) ((">") reduce 429) (("?") reduce 429) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_AS) reduce 429) ((T_BOOLEAN_AND) reduce 429) ((T_BOOLEAN_OR) reduce 429) ((T_COALESCE) reduce 429) ((T_INSTANCEOF) reduce 429) ((T_IS_EQUAL) reduce 429) ((T_IS_GREATER_OR_EQUAL) reduce 429) ((T_IS_IDENTICAL) reduce 429) ((T_IS_NOT_EQUAL) reduce 429) ((T_IS_NOT_IDENTICAL) reduce 429) ((T_IS_SMALLER_OR_EQUAL) reduce 429) ((T_LOGICAL_AND) reduce 429) ((T_LOGICAL_OR) reduce 429) ((T_LOGICAL_XOR) reduce 429) ((T_POW) shift) ((T_SL) reduce 429) ((T_SPACESHIP) reduce 429) ((T_SR) reduce 429) (("^") reduce 429) (("|") reduce 429)) 19305 ((("%") reduce 389) (("*") reduce 389) (("+") reduce 389) (("-") reduce 389) ((".") reduce 389) (("/") reduce 389) (("<") reduce 389) ((">") reduce 389) (("?") reduce 389) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_AS) reduce 389) ((T_BOOLEAN_AND) reduce 389) ((T_BOOLEAN_OR) reduce 389) ((T_COALESCE) reduce 389) ((T_INSTANCEOF) reduce 389) ((T_IS_EQUAL) reduce 389) ((T_IS_GREATER_OR_EQUAL) reduce 389) ((T_IS_IDENTICAL) reduce 389) ((T_IS_NOT_EQUAL) reduce 389) ((T_IS_NOT_IDENTICAL) reduce 389) ((T_IS_SMALLER_OR_EQUAL) reduce 389) ((T_LOGICAL_AND) reduce 389) ((T_LOGICAL_OR) reduce 389) ((T_LOGICAL_XOR) reduce 389) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 389) ((T_SL) reduce 389) ((T_SPACESHIP) reduce 389) ((T_SR) reduce 389) (("[") reduce 510) (("^") reduce 389) (("{") reduce 510) (("|") reduce 389)) 19306 ((("%") reduce 372) (("*") reduce 372) (("+") reduce 372) (("-") reduce 372) ((".") reduce 372) (("/") reduce 372) (("<") reduce 372) ((">") reduce 372) (("?") reduce 372) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_AS) reduce 372) ((T_BOOLEAN_AND) reduce 372) ((T_BOOLEAN_OR) reduce 372) ((T_COALESCE) reduce 372) ((T_INSTANCEOF) reduce 372) ((T_IS_EQUAL) reduce 372) ((T_IS_GREATER_OR_EQUAL) reduce 372) ((T_IS_IDENTICAL) reduce 372) ((T_IS_NOT_EQUAL) reduce 372) ((T_IS_NOT_IDENTICAL) reduce 372) ((T_IS_SMALLER_OR_EQUAL) reduce 372) ((T_LOGICAL_AND) reduce 372) ((T_LOGICAL_OR) reduce 372) ((T_LOGICAL_XOR) reduce 372) ((T_POW) reduce 372) ((T_SL) reduce 372) ((T_SPACESHIP) reduce 372) ((T_SR) reduce 372) (("^") reduce 372) (("|") reduce 372)) 19307 ((("%") reduce 433) (("*") reduce 433) (("+") reduce 433) (("-") reduce 433) ((".") reduce 433) (("/") reduce 433) (("<") reduce 433) ((">") reduce 433) (("?") reduce 433) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_AS) reduce 433) ((T_BOOLEAN_AND) reduce 433) ((T_BOOLEAN_OR) reduce 433) ((T_COALESCE) reduce 433) ((T_INSTANCEOF) reduce 433) ((T_IS_EQUAL) reduce 433) ((T_IS_GREATER_OR_EQUAL) reduce 433) ((T_IS_IDENTICAL) reduce 433) ((T_IS_NOT_EQUAL) reduce 433) ((T_IS_NOT_IDENTICAL) reduce 433) ((T_IS_SMALLER_OR_EQUAL) reduce 433) ((T_LOGICAL_AND) reduce 433) ((T_LOGICAL_OR) reduce 433) ((T_LOGICAL_XOR) reduce 433) ((T_POW) shift) ((T_SL) reduce 433) ((T_SPACESHIP) reduce 433) ((T_SR) reduce 433) (("^") reduce 433) (("|") reduce 433)) 19308 ((("%") reduce 431) (("*") reduce 431) (("+") reduce 431) (("-") reduce 431) ((".") reduce 431) (("/") reduce 431) (("<") reduce 431) ((">") reduce 431) (("?") reduce 431) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_AS) reduce 431) ((T_BOOLEAN_AND) reduce 431) ((T_BOOLEAN_OR) reduce 431) ((T_COALESCE) reduce 431) ((T_INSTANCEOF) reduce 431) ((T_IS_EQUAL) reduce 431) ((T_IS_GREATER_OR_EQUAL) reduce 431) ((T_IS_IDENTICAL) reduce 431) ((T_IS_NOT_EQUAL) reduce 431) ((T_IS_NOT_IDENTICAL) reduce 431) ((T_IS_SMALLER_OR_EQUAL) reduce 431) ((T_LOGICAL_AND) reduce 431) ((T_LOGICAL_OR) reduce 431) ((T_LOGICAL_XOR) reduce 431) ((T_POW) shift) ((T_SL) reduce 431) ((T_SPACESHIP) reduce 431) ((T_SR) reduce 431) (("^") reduce 431) (("|") reduce 431)) 19311 ((("%") reduce 482) (("(") reduce 482) (("*") reduce 482) (("+") reduce 482) (("-") reduce 482) ((".") reduce 482) (("/") reduce 482) (("<") reduce 482) ((">") reduce 482) (("?") reduce 482) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_AS) reduce 482) ((T_BOOLEAN_AND) reduce 482) ((T_BOOLEAN_OR) reduce 482) ((T_COALESCE) reduce 482) ((T_INSTANCEOF) reduce 482) ((T_IS_EQUAL) reduce 482) ((T_IS_GREATER_OR_EQUAL) reduce 482) ((T_IS_IDENTICAL) reduce 482) ((T_IS_NOT_EQUAL) reduce 482) ((T_IS_NOT_IDENTICAL) reduce 482) ((T_IS_SMALLER_OR_EQUAL) reduce 482) ((T_LOGICAL_AND) reduce 482) ((T_LOGICAL_OR) reduce 482) ((T_LOGICAL_XOR) reduce 482) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 482) ((T_OBJECT_OPERATOR) reduce 482) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 482) ((T_POW) reduce 482) ((T_SL) reduce 482) ((T_SPACESHIP) reduce 482) ((T_SR) reduce 482) (("[") reduce 482) (("^") reduce 482) (("{") reduce 482) (("|") reduce 482)) 19312 ((("%") reduce 436) (("*") reduce 436) (("+") reduce 436) (("-") reduce 436) ((".") reduce 436) (("/") reduce 436) (("<") reduce 436) ((">") reduce 436) (("?") reduce 436) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_AS) reduce 436) ((T_BOOLEAN_AND) reduce 436) ((T_BOOLEAN_OR) reduce 436) ((T_COALESCE) reduce 436) ((T_INSTANCEOF) reduce 436) ((T_IS_EQUAL) reduce 436) ((T_IS_GREATER_OR_EQUAL) reduce 436) ((T_IS_IDENTICAL) reduce 436) ((T_IS_NOT_EQUAL) reduce 436) ((T_IS_NOT_IDENTICAL) reduce 436) ((T_IS_SMALLER_OR_EQUAL) reduce 436) ((T_LOGICAL_AND) reduce 436) ((T_LOGICAL_OR) reduce 436) ((T_LOGICAL_XOR) reduce 436) ((T_POW) shift) ((T_SL) reduce 436) ((T_SPACESHIP) reduce 436) ((T_SR) reduce 436) (("^") reduce 436) (("|") reduce 436)) 19313 ((("%") reduce 409) (("*") reduce 409) (("+") reduce 409) (("-") reduce 409) ((".") reduce 409) (("/") reduce 409) (("<") reduce 409) ((">") reduce 409) (("?") reduce 409) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_AS) reduce 409) ((T_BOOLEAN_AND) reduce 409) ((T_BOOLEAN_OR) reduce 409) ((T_COALESCE) reduce 409) ((T_INSTANCEOF) reduce 409) ((T_IS_EQUAL) reduce 409) ((T_IS_GREATER_OR_EQUAL) reduce 409) ((T_IS_IDENTICAL) reduce 409) ((T_IS_NOT_EQUAL) reduce 409) ((T_IS_NOT_IDENTICAL) reduce 409) ((T_IS_SMALLER_OR_EQUAL) reduce 409) ((T_LOGICAL_AND) reduce 409) ((T_LOGICAL_OR) reduce 409) ((T_LOGICAL_XOR) reduce 409) ((T_POW) shift) ((T_SL) reduce 409) ((T_SPACESHIP) reduce 409) ((T_SR) reduce 409) (("^") reduce 409) (("|") reduce 409)) 19314 ((("%") reduce 408) (("*") reduce 408) (("+") reduce 408) (("-") reduce 408) ((".") reduce 408) (("/") reduce 408) (("<") reduce 408) ((">") reduce 408) (("?") reduce 408) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_AS) reduce 408) ((T_BOOLEAN_AND) reduce 408) ((T_BOOLEAN_OR) reduce 408) ((T_COALESCE) reduce 408) ((T_INSTANCEOF) reduce 408) ((T_IS_EQUAL) reduce 408) ((T_IS_GREATER_OR_EQUAL) reduce 408) ((T_IS_IDENTICAL) reduce 408) ((T_IS_NOT_EQUAL) reduce 408) ((T_IS_NOT_IDENTICAL) reduce 408) ((T_IS_SMALLER_OR_EQUAL) reduce 408) ((T_LOGICAL_AND) reduce 408) ((T_LOGICAL_OR) reduce 408) ((T_LOGICAL_XOR) reduce 408) ((T_POW) shift) ((T_SL) reduce 408) ((T_SPACESHIP) reduce 408) ((T_SR) reduce 408) (("^") reduce 408) (("|") reduce 408)) 19316 ((("%") reduce 422) (("(") reduce 517) (("*") reduce 422) (("+") reduce 422) (("-") reduce 422) ((".") reduce 422) (("/") reduce 422) (("<") reduce 422) ((">") reduce 422) (("?") reduce 422) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_AS) reduce 422) ((T_BOOLEAN_AND) reduce 422) ((T_BOOLEAN_OR) reduce 422) ((T_COALESCE) reduce 422) ((T_INSTANCEOF) reduce 422) ((T_IS_EQUAL) reduce 422) ((T_IS_GREATER_OR_EQUAL) reduce 422) ((T_IS_IDENTICAL) reduce 422) ((T_IS_NOT_EQUAL) reduce 422) ((T_IS_NOT_IDENTICAL) reduce 422) ((T_IS_SMALLER_OR_EQUAL) reduce 422) ((T_LOGICAL_AND) reduce 422) ((T_LOGICAL_OR) reduce 422) ((T_LOGICAL_XOR) reduce 422) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 511) ((T_OBJECT_OPERATOR) reduce 511) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 511) ((T_POW) reduce 422) ((T_SL) reduce 422) ((T_SPACESHIP) reduce 422) ((T_SR) reduce 422) (("[") reduce 511) (("^") reduce 422) (("{") reduce 511) (("|") reduce 422)) 19317 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) (("<") reduce 531) (("=") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AND_EQUAL) reduce 531) ((T_AS) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_COALESCE_EQUAL) reduce 531) ((T_CONCAT_EQUAL) reduce 531) ((T_DEC) reduce 531) ((T_DIV_EQUAL) reduce 531) ((T_INC) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_MINUS_EQUAL) reduce 531) ((T_MOD_EQUAL) reduce 531) ((T_MUL_EQUAL) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_OR_EQUAL) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_PLUS_EQUAL) reduce 531) ((T_POW) reduce 531) ((T_POW_EQUAL) reduce 531) ((T_SL) reduce 531) ((T_SL_EQUAL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) ((T_SR_EQUAL) reduce 531) ((T_XOR_EQUAL) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 19320 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) (("<") reduce 530) (("=") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AND_EQUAL) reduce 530) ((T_AS) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_COALESCE_EQUAL) reduce 530) ((T_CONCAT_EQUAL) reduce 530) ((T_DEC) reduce 530) ((T_DIV_EQUAL) reduce 530) ((T_INC) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_MINUS_EQUAL) reduce 530) ((T_MOD_EQUAL) reduce 530) ((T_MUL_EQUAL) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_OR_EQUAL) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_PLUS_EQUAL) reduce 530) ((T_POW) reduce 530) ((T_POW_EQUAL) reduce 530) ((T_SL) reduce 530) ((T_SL_EQUAL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) ((T_SR_EQUAL) reduce 530) ((T_XOR_EQUAL) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 19322 ((("%") reduce 485) (("(") reduce 485) (("*") reduce 485) (("+") reduce 485) (("-") reduce 485) ((".") reduce 485) (("/") reduce 485) (("<") reduce 485) ((">") reduce 485) (("?") reduce 485) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_AS) reduce 485) ((T_BOOLEAN_AND) reduce 485) ((T_BOOLEAN_OR) reduce 485) ((T_COALESCE) reduce 485) ((T_INSTANCEOF) reduce 485) ((T_IS_EQUAL) reduce 485) ((T_IS_GREATER_OR_EQUAL) reduce 485) ((T_IS_IDENTICAL) reduce 485) ((T_IS_NOT_EQUAL) reduce 485) ((T_IS_NOT_IDENTICAL) reduce 485) ((T_IS_SMALLER_OR_EQUAL) reduce 485) ((T_LOGICAL_AND) reduce 485) ((T_LOGICAL_OR) reduce 485) ((T_LOGICAL_XOR) reduce 485) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 485) ((T_OBJECT_OPERATOR) reduce 485) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 485) ((T_POW) reduce 485) ((T_SL) reduce 485) ((T_SPACESHIP) reduce 485) ((T_SR) reduce 485) (("[") reduce 485) (("^") reduce 485) (("{") reduce 485) (("|") reduce 485)) 19323 ((("%") reduce 410) (("*") reduce 410) (("+") reduce 410) (("-") reduce 410) ((".") reduce 410) (("/") reduce 410) (("<") reduce 410) ((">") reduce 410) (("?") reduce 410) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_AS) reduce 410) ((T_BOOLEAN_AND) reduce 410) ((T_BOOLEAN_OR) reduce 410) ((T_COALESCE) reduce 410) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 410) ((T_IS_GREATER_OR_EQUAL) reduce 410) ((T_IS_IDENTICAL) reduce 410) ((T_IS_NOT_EQUAL) reduce 410) ((T_IS_NOT_IDENTICAL) reduce 410) ((T_IS_SMALLER_OR_EQUAL) reduce 410) ((T_LOGICAL_AND) reduce 410) ((T_LOGICAL_OR) reduce 410) ((T_LOGICAL_XOR) reduce 410) ((T_POW) shift) ((T_SL) reduce 410) ((T_SPACESHIP) reduce 410) ((T_SR) reduce 410) (("^") reduce 410) (("|") reduce 410)) 19324 ((("\"") shift) (("$") shift) (("(") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_ARRAY) shift) ((T_CLASS_C) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DIR) shift) ((T_FILE) shift) ((T_FUNC_C) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NS_C) shift) ((T_READONLY) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_TRAIT_C) shift) ((T_VARIABLE) shift) (("[") shift)) 19328 ((("(") reduce 529) ((")") reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) (("[") reduce 529) (("{") reduce 529)) 19333 ((("(") reduce 516) ((")") reduce 525) ((T_DOUBLE_ARROW) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) (("[") reduce 525) (("{") reduce 525)) 19335 (((")") shift) ((T_DOUBLE_ARROW) shift)) 19336 ((("(") reduce 524) ((")") reduce 524) ((T_DOUBLE_ARROW) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) (("[") reduce 524) (("{") reduce 524)) 19338 ((("(") reduce 519) ((")") reduce 519) ((T_DOUBLE_ARROW) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) (("[") reduce 519) (("{") reduce 519)) 19339 (((")") reduce 526) ((T_DOUBLE_ARROW) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) (("[") reduce 526) (("{") reduce 526)) 19340 (((")") reduce 211) ((T_DOUBLE_ARROW) reduce 211) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) (("[") reduce 510) (("{") reduce 510)) 19344 ((("(") reduce 543) ((")") reduce 533) ((T_DOUBLE_ARROW) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) (("[") reduce 533) (("{") reduce 533)) 19346 ((("(") reduce 468) ((")") reduce 468) ((T_DOUBLE_ARROW) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) (("[") reduce 468) (("{") reduce 468)) 19347 ((("(") reduce 288) ((")") reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) (("[") reduce 288) (("{") reduce 288)) 19351 ((("(") reduce 289) ((")") reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) (("[") reduce 289) (("{") reduce 289)) 19352 ((("(") reduce 290) ((")") reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) (("[") reduce 290) (("{") reduce 290)) 19353 ((("(") reduce 465) ((")") reduce 465) ((T_DOUBLE_ARROW) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) (("[") reduce 465) (("{") reduce 465)) 19359 ((("(") reduce 529) ((")") reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) (("[") reduce 529) (("{") reduce 529)) 19364 ((("(") reduce 516) ((")") reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) (("[") reduce 525) (("{") reduce 525)) 19367 ((("(") reduce 524) ((")") reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) (("[") reduce 524) (("{") reduce 524)) 19369 ((("(") reduce 519) ((")") reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) (("[") reduce 519) (("{") reduce 519)) 19370 (((")") reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) (("[") reduce 526) (("{") reduce 526)) 19371 (((")") reduce 211) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) (("[") reduce 510) (("{") reduce 510)) 19375 ((("(") reduce 543) ((")") reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) (("[") reduce 533) (("{") reduce 533)) 19377 ((("(") reduce 468) ((")") reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) (("[") reduce 468) (("{") reduce 468)) 19378 ((("(") reduce 288) ((")") reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) (("[") reduce 288) (("{") reduce 288)) 19382 ((("(") reduce 289) ((")") reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) (("[") reduce 289) (("{") reduce 289)) 19383 ((("(") reduce 290) ((")") reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) (("[") reduce 290) (("{") reduce 290)) 19384 ((("(") reduce 465) ((")") reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) (("[") reduce 465) (("{") reduce 465)) 19386 ((("!") reduce 140) (("\"") reduce 140) (("$") reduce 140) (("(") reduce 140) (("+") reduce 140) (("-") reduce 140) ((";") reduce 140) (("@") reduce 140) ((T_ABSTRACT) reduce 140) ((T_ARRAY) reduce 140) ((T_ARRAY_CAST) reduce 140) ((T_ATTRIBUTE) reduce 140) ((T_BOOL_CAST) reduce 140) ((T_BREAK) reduce 140) ((T_CLASS) reduce 140) ((T_CLASS_C) reduce 140) ((T_CLONE) reduce 140) ((T_CONSTANT_ENCAPSED_STRING) reduce 140) ((T_CONTINUE) reduce 140) ((T_DEC) reduce 140) ((T_DECLARE) reduce 140) ((T_DIR) reduce 140) ((T_DNUMBER) reduce 140) ((T_DO) reduce 140) ((T_DOUBLE_CAST) reduce 140) ((T_ECHO) reduce 140) ((T_EMPTY) reduce 140) ((T_ENDFOREACH) reduce 140) ((T_ENUM) reduce 140) ((T_EVAL) reduce 140) ((T_EXIT) reduce 140) ((T_FILE) reduce 140) ((T_FINAL) reduce 140) ((T_FN) reduce 140) ((T_FOR) reduce 140) ((T_FOREACH) reduce 140) ((T_FUNCTION) reduce 140) ((T_FUNC_C) reduce 140) ((T_GLOBAL) reduce 140) ((T_GOTO) reduce 140) ((T_HALT_COMPILER) reduce 140) ((T_IF) reduce 140) ((T_INC) reduce 140) ((T_INCLUDE) reduce 140) ((T_INCLUDE_ONCE) reduce 140) ((T_INLINE_HTML) reduce 140) ((T_INTERFACE) reduce 140) ((T_INT_CAST) reduce 140) ((T_ISSET) reduce 140) ((T_LINE) reduce 140) ((T_LIST) reduce 140) ((T_LNUMBER) reduce 140) ((T_MATCH) reduce 140) ((T_METHOD_C) reduce 140) ((T_NAME_FULLY_QUALIFIED) reduce 140) ((T_NAME_QUALIFIED) reduce 140) ((T_NAME_RELATIVE) reduce 140) ((T_NEW) reduce 140) ((T_NS_C) reduce 140) ((T_OBJECT_CAST) reduce 140) ((T_PRINT) reduce 140) ((T_READONLY) reduce 140) ((T_REQUIRE) reduce 140) ((T_REQUIRE_ONCE) reduce 140) ((T_RETURN) reduce 140) ((T_START_HEREDOC) reduce 140) ((T_STATIC) reduce 140) ((T_STRING) reduce 140) ((T_STRING_CAST) reduce 140) ((T_SWITCH) reduce 140) ((T_THROW) reduce 140) ((T_TRAIT) reduce 140) ((T_TRAIT_C) reduce 140) ((T_TRY) reduce 140) ((T_UNSET) reduce 140) ((T_UNSET_CAST) reduce 140) ((T_VARIABLE) reduce 140) ((T_WHILE) reduce 140) ((T_YIELD) reduce 140) ((T_YIELD_FROM) reduce 140) (("[") reduce 140) (("`") reduce 140) (("{") reduce 140) (("~") reduce 140)) 19387 ((("!") reduce 162) (("\"") reduce 162) (("$") reduce 162) (("(") reduce 162) (("+") reduce 162) (("-") reduce 162) ((";") reduce 162) (("@") reduce 162) ((T_ABSTRACT) reduce 162) ((T_ARRAY) reduce 162) ((T_ARRAY_CAST) reduce 162) ((T_ATTRIBUTE) reduce 162) ((T_BOOL_CAST) reduce 162) ((T_BREAK) reduce 162) ((T_CASE) reduce 162) ((T_CLASS) reduce 162) ((T_CLASS_C) reduce 162) ((T_CLONE) reduce 162) ((T_CONSTANT_ENCAPSED_STRING) reduce 162) ((T_CONTINUE) reduce 162) ((T_DEC) reduce 162) ((T_DECLARE) reduce 162) ((T_DEFAULT) reduce 162) ((T_DIR) reduce 162) ((T_DNUMBER) reduce 162) ((T_DO) reduce 162) ((T_DOUBLE_CAST) reduce 162) ((T_ECHO) reduce 162) ((T_ELSE) reduce 162) ((T_ELSEIF) reduce 162) ((T_EMPTY) reduce 162) ((T_ENDSWITCH) reduce 162) ((T_ENUM) reduce 162) ((T_EVAL) reduce 162) ((T_EXIT) reduce 162) ((T_FILE) reduce 162) ((T_FINAL) reduce 162) ((T_FN) reduce 162) ((T_FOR) reduce 162) ((T_FOREACH) reduce 162) ((T_FUNCTION) reduce 162) ((T_FUNC_C) reduce 162) ((T_GLOBAL) reduce 162) ((T_GOTO) reduce 162) ((T_HALT_COMPILER) reduce 162) ((T_IF) reduce 162) ((T_INC) reduce 162) ((T_INCLUDE) reduce 162) ((T_INCLUDE_ONCE) reduce 162) ((T_INLINE_HTML) reduce 162) ((T_INTERFACE) reduce 162) ((T_INT_CAST) reduce 162) ((T_ISSET) reduce 162) ((T_LINE) reduce 162) ((T_LIST) reduce 162) ((T_LNUMBER) reduce 162) ((T_MATCH) reduce 162) ((T_METHOD_C) reduce 162) ((T_NAME_FULLY_QUALIFIED) reduce 162) ((T_NAME_QUALIFIED) reduce 162) ((T_NAME_RELATIVE) reduce 162) ((T_NEW) reduce 162) ((T_NS_C) reduce 162) ((T_OBJECT_CAST) reduce 162) ((T_PRINT) reduce 162) ((T_READONLY) reduce 162) ((T_REQUIRE) reduce 162) ((T_REQUIRE_ONCE) reduce 162) ((T_RETURN) reduce 162) ((T_START_HEREDOC) reduce 162) ((T_STATIC) reduce 162) ((T_STRING) reduce 162) ((T_STRING_CAST) reduce 162) ((T_SWITCH) reduce 162) ((T_THROW) reduce 162) ((T_TRAIT) reduce 162) ((T_TRAIT_C) reduce 162) ((T_TRY) reduce 162) ((T_UNSET) reduce 162) ((T_UNSET_CAST) reduce 162) ((T_VARIABLE) reduce 162) ((T_WHILE) reduce 162) ((T_YIELD) reduce 162) ((T_YIELD_FROM) reduce 162) (("[") reduce 162) (("`") reduce 162) (("{") reduce 162) (("~") reduce 162)) 19388 ((("!") reduce 217) (("\"") reduce 217) (("$") reduce 217) (("(") reduce 217) (("+") reduce 217) (("-") reduce 217) ((";") reduce 217) (("@") reduce 217) ((T_ABSTRACT) reduce 217) ((T_ARRAY) reduce 217) ((T_ARRAY_CAST) reduce 217) ((T_ATTRIBUTE) reduce 217) ((T_BOOL_CAST) reduce 217) ((T_BREAK) reduce 217) ((T_CASE) reduce 217) ((T_CLASS) reduce 217) ((T_CLASS_C) reduce 217) ((T_CLONE) reduce 217) ((T_CONSTANT_ENCAPSED_STRING) reduce 217) ((T_CONTINUE) reduce 217) ((T_DEC) reduce 217) ((T_DECLARE) reduce 217) ((T_DEFAULT) reduce 217) ((T_DIR) reduce 217) ((T_DNUMBER) reduce 217) ((T_DO) reduce 217) ((T_DOUBLE_CAST) reduce 217) ((T_ECHO) reduce 217) ((T_ELSE) reduce 217) ((T_ELSEIF) reduce 217) ((T_EMPTY) reduce 217) ((T_ENDSWITCH) reduce 217) ((T_ENUM) reduce 217) ((T_EVAL) reduce 217) ((T_EXIT) reduce 217) ((T_FILE) reduce 217) ((T_FINAL) reduce 217) ((T_FN) reduce 217) ((T_FOR) reduce 217) ((T_FOREACH) reduce 217) ((T_FUNCTION) reduce 217) ((T_FUNC_C) reduce 217) ((T_GLOBAL) reduce 217) ((T_GOTO) reduce 217) ((T_HALT_COMPILER) reduce 217) ((T_IF) reduce 217) ((T_INC) reduce 217) ((T_INCLUDE) reduce 217) ((T_INCLUDE_ONCE) reduce 217) ((T_INLINE_HTML) reduce 217) ((T_INTERFACE) reduce 217) ((T_INT_CAST) reduce 217) ((T_ISSET) reduce 217) ((T_LINE) reduce 217) ((T_LIST) reduce 217) ((T_LNUMBER) reduce 217) ((T_MATCH) reduce 217) ((T_METHOD_C) reduce 217) ((T_NAME_FULLY_QUALIFIED) reduce 217) ((T_NAME_QUALIFIED) reduce 217) ((T_NAME_RELATIVE) reduce 217) ((T_NEW) reduce 217) ((T_NS_C) reduce 217) ((T_OBJECT_CAST) reduce 217) ((T_PRINT) reduce 217) ((T_READONLY) reduce 217) ((T_REQUIRE) reduce 217) ((T_REQUIRE_ONCE) reduce 217) ((T_RETURN) reduce 217) ((T_START_HEREDOC) reduce 217) ((T_STATIC) reduce 217) ((T_STRING) reduce 217) ((T_STRING_CAST) reduce 217) ((T_SWITCH) reduce 217) ((T_THROW) reduce 217) ((T_TRAIT) reduce 217) ((T_TRAIT_C) reduce 217) ((T_TRY) reduce 217) ((T_UNSET) reduce 217) ((T_UNSET_CAST) reduce 217) ((T_VARIABLE) reduce 217) ((T_WHILE) reduce 217) ((T_YIELD) reduce 217) ((T_YIELD_FROM) reduce 217) (("[") reduce 217) (("`") reduce 217) (("{") reduce 217) (("~") reduce 217)) 19389 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) (("+") shift) (("-") shift) ((";") shift) (("@") shift) ((T_ABSTRACT) shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_BREAK) shift) ((T_CLASS) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_CONTINUE) shift) ((T_DEC) shift) ((T_DECLARE) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DO) shift) ((T_DOUBLE_CAST) shift) ((T_ECHO) shift) ((T_EMPTY) shift) ((T_ENDFOREACH) shift) ((T_ENUM) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FINAL) shift) ((T_FN) shift) ((T_FOR) shift) ((T_FOREACH) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_GLOBAL) shift) ((T_GOTO) shift) ((T_HALT_COMPILER) shift) ((T_IF) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INLINE_HTML) shift) ((T_INTERFACE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_RETURN) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_SWITCH) shift) ((T_THROW) shift) ((T_TRAIT) shift) ((T_TRAIT_C) shift) ((T_TRY) shift) ((T_UNSET) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_WHILE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("{") shift) (("~") shift)) 19390 ((("!") reduce 164) (("\"") reduce 164) (("$") reduce 164) (("(") reduce 164) (("+") reduce 164) (("-") reduce 164) ((";") reduce 164) (("@") reduce 164) ((T_ABSTRACT) reduce 164) ((T_ARRAY) reduce 164) ((T_ARRAY_CAST) reduce 164) ((T_ATTRIBUTE) reduce 164) ((T_BOOL_CAST) reduce 164) ((T_BREAK) reduce 164) ((T_CLASS) reduce 164) ((T_CLASS_C) reduce 164) ((T_CLONE) reduce 164) ((T_CONSTANT_ENCAPSED_STRING) reduce 164) ((T_CONTINUE) reduce 164) ((T_DEC) reduce 164) ((T_DECLARE) reduce 164) ((T_DIR) reduce 164) ((T_DNUMBER) reduce 164) ((T_DO) reduce 164) ((T_DOUBLE_CAST) reduce 164) ((T_ECHO) reduce 164) ((T_EMPTY) reduce 164) ((T_ENDFOREACH) reduce 164) ((T_ENUM) reduce 164) ((T_EVAL) reduce 164) ((T_EXIT) reduce 164) ((T_FILE) reduce 164) ((T_FINAL) reduce 164) ((T_FN) reduce 164) ((T_FOR) reduce 164) ((T_FOREACH) reduce 164) ((T_FUNCTION) reduce 164) ((T_FUNC_C) reduce 164) ((T_GLOBAL) reduce 164) ((T_GOTO) reduce 164) ((T_HALT_COMPILER) reduce 164) ((T_IF) reduce 164) ((T_INC) reduce 164) ((T_INCLUDE) reduce 164) ((T_INCLUDE_ONCE) reduce 164) ((T_INLINE_HTML) reduce 164) ((T_INTERFACE) reduce 164) ((T_INT_CAST) reduce 164) ((T_ISSET) reduce 164) ((T_LINE) reduce 164) ((T_LIST) reduce 164) ((T_LNUMBER) reduce 164) ((T_MATCH) reduce 164) ((T_METHOD_C) reduce 164) ((T_NAME_FULLY_QUALIFIED) reduce 164) ((T_NAME_QUALIFIED) reduce 164) ((T_NAME_RELATIVE) reduce 164) ((T_NEW) reduce 164) ((T_NS_C) reduce 164) ((T_OBJECT_CAST) reduce 164) ((T_PRINT) reduce 164) ((T_READONLY) reduce 164) ((T_REQUIRE) reduce 164) ((T_REQUIRE_ONCE) reduce 164) ((T_RETURN) reduce 164) ((T_START_HEREDOC) reduce 164) ((T_STATIC) reduce 164) ((T_STRING) reduce 164) ((T_STRING_CAST) reduce 164) ((T_SWITCH) reduce 164) ((T_THROW) reduce 164) ((T_TRAIT) reduce 164) ((T_TRAIT_C) reduce 164) ((T_TRY) reduce 164) ((T_UNSET) reduce 164) ((T_UNSET_CAST) reduce 164) ((T_VARIABLE) reduce 164) ((T_WHILE) reduce 164) ((T_YIELD) reduce 164) ((T_YIELD_FROM) reduce 164) (("[") reduce 164) (("`") reduce 164) (("{") reduce 164) (("~") reduce 164)) 19405 ((("!") reduce 158) (("\"") reduce 158) (("$") reduce 158) (("(") reduce 158) (("+") reduce 158) (("-") reduce 158) ((";") reduce 158) (("@") reduce 158) ((T_ABSTRACT) reduce 158) ((T_ARRAY) reduce 158) ((T_ARRAY_CAST) reduce 158) ((T_ATTRIBUTE) reduce 158) ((T_BOOL_CAST) reduce 158) ((T_BREAK) reduce 158) ((T_CLASS) reduce 158) ((T_CLASS_C) reduce 158) ((T_CLONE) reduce 158) ((T_CONSTANT_ENCAPSED_STRING) reduce 158) ((T_CONTINUE) reduce 158) ((T_DEC) reduce 158) ((T_DECLARE) reduce 158) ((T_DIR) reduce 158) ((T_DNUMBER) reduce 158) ((T_DO) reduce 158) ((T_DOUBLE_CAST) reduce 158) ((T_ECHO) reduce 158) ((T_EMPTY) reduce 158) ((T_ENDFOREACH) reduce 158) ((T_ENUM) reduce 158) ((T_EVAL) reduce 158) ((T_EXIT) reduce 158) ((T_FILE) reduce 158) ((T_FINAL) reduce 158) ((T_FN) reduce 158) ((T_FOR) reduce 158) ((T_FOREACH) reduce 158) ((T_FUNCTION) reduce 158) ((T_FUNC_C) reduce 158) ((T_GLOBAL) reduce 158) ((T_GOTO) reduce 158) ((T_HALT_COMPILER) reduce 158) ((T_IF) reduce 158) ((T_INC) reduce 158) ((T_INCLUDE) reduce 158) ((T_INCLUDE_ONCE) reduce 158) ((T_INLINE_HTML) reduce 158) ((T_INTERFACE) reduce 158) ((T_INT_CAST) reduce 158) ((T_ISSET) reduce 158) ((T_LINE) reduce 158) ((T_LIST) reduce 158) ((T_LNUMBER) reduce 158) ((T_MATCH) reduce 158) ((T_METHOD_C) reduce 158) ((T_NAME_FULLY_QUALIFIED) reduce 158) ((T_NAME_QUALIFIED) reduce 158) ((T_NAME_RELATIVE) reduce 158) ((T_NEW) reduce 158) ((T_NS_C) reduce 158) ((T_OBJECT_CAST) reduce 158) ((T_PRINT) reduce 158) ((T_READONLY) reduce 158) ((T_REQUIRE) reduce 158) ((T_REQUIRE_ONCE) reduce 158) ((T_RETURN) reduce 158) ((T_START_HEREDOC) reduce 158) ((T_STATIC) reduce 158) ((T_STRING) reduce 158) ((T_STRING_CAST) reduce 158) ((T_SWITCH) reduce 158) ((T_THROW) reduce 158) ((T_TRAIT) reduce 158) ((T_TRAIT_C) reduce 158) ((T_TRY) reduce 158) ((T_UNSET) reduce 158) ((T_UNSET_CAST) reduce 158) ((T_VARIABLE) reduce 158) ((T_WHILE) reduce 158) ((T_YIELD) reduce 158) ((T_YIELD_FROM) reduce 158) (("[") reduce 158) (("`") reduce 158) (("{") reduce 158) (("~") reduce 158)) 19415 ((("!") reduce 147) (("\"") reduce 147) (("$") reduce 147) (("(") reduce 147) (("+") reduce 147) (("-") reduce 147) ((";") reduce 147) (("@") reduce 147) ((T_ABSTRACT) reduce 147) ((T_ARRAY) reduce 147) ((T_ARRAY_CAST) reduce 147) ((T_ATTRIBUTE) reduce 147) ((T_BOOL_CAST) reduce 147) ((T_BREAK) reduce 147) ((T_CLASS) reduce 147) ((T_CLASS_C) reduce 147) ((T_CLONE) reduce 147) ((T_CONSTANT_ENCAPSED_STRING) reduce 147) ((T_CONTINUE) reduce 147) ((T_DEC) reduce 147) ((T_DECLARE) reduce 147) ((T_DIR) reduce 147) ((T_DNUMBER) reduce 147) ((T_DO) reduce 147) ((T_DOUBLE_CAST) reduce 147) ((T_ECHO) reduce 147) ((T_EMPTY) reduce 147) ((T_ENDFOREACH) reduce 147) ((T_ENUM) reduce 147) ((T_EVAL) reduce 147) ((T_EXIT) reduce 147) ((T_FILE) reduce 147) ((T_FINAL) reduce 147) ((T_FN) reduce 147) ((T_FOR) reduce 147) ((T_FOREACH) reduce 147) ((T_FUNCTION) reduce 147) ((T_FUNC_C) reduce 147) ((T_GLOBAL) reduce 147) ((T_GOTO) reduce 147) ((T_HALT_COMPILER) reduce 147) ((T_IF) reduce 147) ((T_INC) reduce 147) ((T_INCLUDE) reduce 147) ((T_INCLUDE_ONCE) reduce 147) ((T_INLINE_HTML) reduce 147) ((T_INTERFACE) reduce 147) ((T_INT_CAST) reduce 147) ((T_ISSET) reduce 147) ((T_LINE) reduce 147) ((T_LIST) reduce 147) ((T_LNUMBER) reduce 147) ((T_MATCH) reduce 147) ((T_METHOD_C) reduce 147) ((T_NAME_FULLY_QUALIFIED) reduce 147) ((T_NAME_QUALIFIED) reduce 147) ((T_NAME_RELATIVE) reduce 147) ((T_NEW) reduce 147) ((T_NS_C) reduce 147) ((T_OBJECT_CAST) reduce 147) ((T_PRINT) reduce 147) ((T_READONLY) reduce 147) ((T_REQUIRE) reduce 147) ((T_REQUIRE_ONCE) reduce 147) ((T_RETURN) reduce 147) ((T_START_HEREDOC) reduce 147) ((T_STATIC) reduce 147) ((T_STRING) reduce 147) ((T_STRING_CAST) reduce 147) ((T_SWITCH) reduce 147) ((T_THROW) reduce 147) ((T_TRAIT) reduce 147) ((T_TRAIT_C) reduce 147) ((T_TRY) reduce 147) ((T_UNSET) reduce 147) ((T_UNSET_CAST) reduce 147) ((T_VARIABLE) reduce 147) ((T_WHILE) reduce 147) ((T_YIELD) reduce 147) ((T_YIELD_FROM) reduce 147) (("[") reduce 147) (("`") reduce 147) (("{") reduce 147) (("~") reduce 147)) 19417 ((("!") reduce 142) (("\"") reduce 142) (("$") reduce 142) (("(") reduce 142) (("+") reduce 142) (("-") reduce 142) ((";") reduce 142) (("@") reduce 142) ((T_ABSTRACT) reduce 142) ((T_ARRAY) reduce 142) ((T_ARRAY_CAST) reduce 142) ((T_ATTRIBUTE) reduce 142) ((T_BOOL_CAST) reduce 142) ((T_BREAK) reduce 142) ((T_CLASS) reduce 142) ((T_CLASS_C) reduce 142) ((T_CLONE) reduce 142) ((T_CONSTANT_ENCAPSED_STRING) reduce 142) ((T_CONTINUE) reduce 142) ((T_DEC) reduce 142) ((T_DECLARE) reduce 142) ((T_DIR) reduce 142) ((T_DNUMBER) reduce 142) ((T_DO) reduce 142) ((T_DOUBLE_CAST) reduce 142) ((T_ECHO) reduce 142) ((T_EMPTY) reduce 142) ((T_ENDFOREACH) reduce 142) ((T_ENUM) reduce 142) ((T_EVAL) reduce 142) ((T_EXIT) reduce 142) ((T_FILE) reduce 142) ((T_FINAL) reduce 142) ((T_FN) reduce 142) ((T_FOR) reduce 142) ((T_FOREACH) reduce 142) ((T_FUNCTION) reduce 142) ((T_FUNC_C) reduce 142) ((T_GLOBAL) reduce 142) ((T_GOTO) reduce 142) ((T_HALT_COMPILER) reduce 142) ((T_IF) reduce 142) ((T_INC) reduce 142) ((T_INCLUDE) reduce 142) ((T_INCLUDE_ONCE) reduce 142) ((T_INLINE_HTML) reduce 142) ((T_INTERFACE) reduce 142) ((T_INT_CAST) reduce 142) ((T_ISSET) reduce 142) ((T_LINE) reduce 142) ((T_LIST) reduce 142) ((T_LNUMBER) reduce 142) ((T_MATCH) reduce 142) ((T_METHOD_C) reduce 142) ((T_NAME_FULLY_QUALIFIED) reduce 142) ((T_NAME_QUALIFIED) reduce 142) ((T_NAME_RELATIVE) reduce 142) ((T_NEW) reduce 142) ((T_NS_C) reduce 142) ((T_OBJECT_CAST) reduce 142) ((T_PRINT) reduce 142) ((T_READONLY) reduce 142) ((T_REQUIRE) reduce 142) ((T_REQUIRE_ONCE) reduce 142) ((T_RETURN) reduce 142) ((T_START_HEREDOC) reduce 142) ((T_STATIC) reduce 142) ((T_STRING) reduce 142) ((T_STRING_CAST) reduce 142) ((T_SWITCH) reduce 142) ((T_THROW) reduce 142) ((T_TRAIT) reduce 142) ((T_TRAIT_C) reduce 142) ((T_TRY) reduce 142) ((T_UNSET) reduce 142) ((T_UNSET_CAST) reduce 142) ((T_VARIABLE) reduce 142) ((T_WHILE) reduce 142) ((T_YIELD) reduce 142) ((T_YIELD_FROM) reduce 142) (("[") reduce 142) (("`") reduce 142) (("{") reduce 142) (("~") reduce 142)) 19419 ((("!") reduce 103) (("\"") reduce 103) (("$") reduce 103) (("(") reduce 103) (("+") reduce 103) (("-") reduce 103) ((";") reduce 103) (("@") reduce 103) ((T_ABSTRACT) reduce 103) ((T_ARRAY) reduce 103) ((T_ARRAY_CAST) reduce 103) ((T_ATTRIBUTE) reduce 103) ((T_BOOL_CAST) reduce 103) ((T_BREAK) reduce 103) ((T_CLASS) reduce 103) ((T_CLASS_C) reduce 103) ((T_CLONE) reduce 103) ((T_CONSTANT_ENCAPSED_STRING) reduce 103) ((T_CONTINUE) reduce 103) ((T_DEC) reduce 103) ((T_DECLARE) reduce 103) ((T_DIR) reduce 103) ((T_DNUMBER) reduce 103) ((T_DO) reduce 103) ((T_DOUBLE_CAST) reduce 103) ((T_ECHO) reduce 103) ((T_EMPTY) reduce 103) ((T_ENDFOREACH) reduce 103) ((T_ENUM) reduce 103) ((T_EVAL) reduce 103) ((T_EXIT) reduce 103) ((T_FILE) reduce 103) ((T_FINAL) reduce 103) ((T_FN) reduce 103) ((T_FOR) reduce 103) ((T_FOREACH) reduce 103) ((T_FUNCTION) reduce 103) ((T_FUNC_C) reduce 103) ((T_GLOBAL) reduce 103) ((T_GOTO) reduce 103) ((T_HALT_COMPILER) reduce 103) ((T_IF) reduce 103) ((T_INC) reduce 103) ((T_INCLUDE) reduce 103) ((T_INCLUDE_ONCE) reduce 103) ((T_INLINE_HTML) reduce 103) ((T_INTERFACE) reduce 103) ((T_INT_CAST) reduce 103) ((T_ISSET) reduce 103) ((T_LINE) reduce 103) ((T_LIST) reduce 103) ((T_LNUMBER) reduce 103) ((T_MATCH) reduce 103) ((T_METHOD_C) reduce 103) ((T_NAME_FULLY_QUALIFIED) reduce 103) ((T_NAME_QUALIFIED) reduce 103) ((T_NAME_RELATIVE) reduce 103) ((T_NEW) reduce 103) ((T_NS_C) reduce 103) ((T_OBJECT_CAST) reduce 103) ((T_PRINT) reduce 103) ((T_READONLY) reduce 103) ((T_REQUIRE) reduce 103) ((T_REQUIRE_ONCE) reduce 103) ((T_RETURN) reduce 103) ((T_START_HEREDOC) reduce 103) ((T_STATIC) reduce 103) ((T_STRING) reduce 103) ((T_STRING_CAST) reduce 103) ((T_SWITCH) reduce 103) ((T_THROW) reduce 103) ((T_TRAIT) reduce 103) ((T_TRAIT_C) reduce 103) ((T_TRY) reduce 103) ((T_UNSET) reduce 103) ((T_UNSET_CAST) reduce 103) ((T_VARIABLE) reduce 103) ((T_WHILE) reduce 103) ((T_YIELD) reduce 103) ((T_YIELD_FROM) reduce 103) (("[") reduce 103) (("`") reduce 103) (("{") reduce 103) (("~") reduce 103)) 19421 ((("!") reduce 106) (("\"") reduce 106) (("$") reduce 106) (("(") reduce 106) (("+") reduce 106) (("-") reduce 106) ((";") reduce 106) (("@") reduce 106) ((T_ABSTRACT) reduce 106) ((T_ARRAY) reduce 106) ((T_ARRAY_CAST) reduce 106) ((T_ATTRIBUTE) reduce 106) ((T_BOOL_CAST) reduce 106) ((T_BREAK) reduce 106) ((T_CLASS) reduce 106) ((T_CLASS_C) reduce 106) ((T_CLONE) reduce 106) ((T_CONSTANT_ENCAPSED_STRING) reduce 106) ((T_CONTINUE) reduce 106) ((T_DEC) reduce 106) ((T_DECLARE) reduce 106) ((T_DIR) reduce 106) ((T_DNUMBER) reduce 106) ((T_DO) reduce 106) ((T_DOUBLE_CAST) reduce 106) ((T_ECHO) reduce 106) ((T_EMPTY) reduce 106) ((T_ENDFOREACH) reduce 106) ((T_ENUM) reduce 106) ((T_EVAL) reduce 106) ((T_EXIT) reduce 106) ((T_FILE) reduce 106) ((T_FINAL) reduce 106) ((T_FN) reduce 106) ((T_FOR) reduce 106) ((T_FOREACH) reduce 106) ((T_FUNCTION) reduce 106) ((T_FUNC_C) reduce 106) ((T_GLOBAL) reduce 106) ((T_GOTO) reduce 106) ((T_HALT_COMPILER) reduce 106) ((T_IF) reduce 106) ((T_INC) reduce 106) ((T_INCLUDE) reduce 106) ((T_INCLUDE_ONCE) reduce 106) ((T_INLINE_HTML) reduce 106) ((T_INTERFACE) reduce 106) ((T_INT_CAST) reduce 106) ((T_ISSET) reduce 106) ((T_LINE) reduce 106) ((T_LIST) reduce 106) ((T_LNUMBER) reduce 106) ((T_MATCH) reduce 106) ((T_METHOD_C) reduce 106) ((T_NAME_FULLY_QUALIFIED) reduce 106) ((T_NAME_QUALIFIED) reduce 106) ((T_NAME_RELATIVE) reduce 106) ((T_NEW) reduce 106) ((T_NS_C) reduce 106) ((T_OBJECT_CAST) reduce 106) ((T_PRINT) reduce 106) ((T_READONLY) reduce 106) ((T_REQUIRE) reduce 106) ((T_REQUIRE_ONCE) reduce 106) ((T_RETURN) reduce 106) ((T_START_HEREDOC) reduce 106) ((T_STATIC) reduce 106) ((T_STRING) reduce 106) ((T_STRING_CAST) reduce 106) ((T_SWITCH) reduce 106) ((T_THROW) reduce 106) ((T_TRAIT) reduce 106) ((T_TRAIT_C) reduce 106) ((T_TRY) reduce 106) ((T_UNSET) reduce 106) ((T_UNSET_CAST) reduce 106) ((T_VARIABLE) reduce 106) ((T_WHILE) reduce 106) ((T_YIELD) reduce 106) ((T_YIELD_FROM) reduce 106) (("[") reduce 106) (("`") reduce 106) (("{") reduce 106) (("~") reduce 106)) 19424 ((("!") reduce 102) (("\"") reduce 102) (("$") reduce 102) (("(") reduce 102) (("+") reduce 102) (("-") reduce 102) ((";") reduce 102) (("@") reduce 102) ((T_ABSTRACT) reduce 102) ((T_ARRAY) reduce 102) ((T_ARRAY_CAST) reduce 102) ((T_ATTRIBUTE) reduce 102) ((T_BOOL_CAST) reduce 102) ((T_BREAK) reduce 102) ((T_CLASS) reduce 102) ((T_CLASS_C) reduce 102) ((T_CLONE) reduce 102) ((T_CONSTANT_ENCAPSED_STRING) reduce 102) ((T_CONTINUE) reduce 102) ((T_DEC) reduce 102) ((T_DECLARE) reduce 102) ((T_DIR) reduce 102) ((T_DNUMBER) reduce 102) ((T_DO) reduce 102) ((T_DOUBLE_CAST) reduce 102) ((T_ECHO) reduce 102) ((T_EMPTY) reduce 102) ((T_ENDFOREACH) reduce 102) ((T_ENUM) reduce 102) ((T_EVAL) reduce 102) ((T_EXIT) reduce 102) ((T_FILE) reduce 102) ((T_FINAL) reduce 102) ((T_FN) reduce 102) ((T_FOR) reduce 102) ((T_FOREACH) reduce 102) ((T_FUNCTION) reduce 102) ((T_FUNC_C) reduce 102) ((T_GLOBAL) reduce 102) ((T_GOTO) reduce 102) ((T_HALT_COMPILER) reduce 102) ((T_IF) reduce 102) ((T_INC) reduce 102) ((T_INCLUDE) reduce 102) ((T_INCLUDE_ONCE) reduce 102) ((T_INLINE_HTML) reduce 102) ((T_INTERFACE) reduce 102) ((T_INT_CAST) reduce 102) ((T_ISSET) reduce 102) ((T_LINE) reduce 102) ((T_LIST) reduce 102) ((T_LNUMBER) reduce 102) ((T_MATCH) reduce 102) ((T_METHOD_C) reduce 102) ((T_NAME_FULLY_QUALIFIED) reduce 102) ((T_NAME_QUALIFIED) reduce 102) ((T_NAME_RELATIVE) reduce 102) ((T_NEW) reduce 102) ((T_NS_C) reduce 102) ((T_OBJECT_CAST) reduce 102) ((T_PRINT) reduce 102) ((T_READONLY) reduce 102) ((T_REQUIRE) reduce 102) ((T_REQUIRE_ONCE) reduce 102) ((T_RETURN) reduce 102) ((T_START_HEREDOC) reduce 102) ((T_STATIC) reduce 102) ((T_STRING) reduce 102) ((T_STRING_CAST) reduce 102) ((T_SWITCH) reduce 102) ((T_THROW) reduce 102) ((T_TRAIT) reduce 102) ((T_TRAIT_C) reduce 102) ((T_TRY) reduce 102) ((T_UNSET) reduce 102) ((T_UNSET_CAST) reduce 102) ((T_VARIABLE) reduce 102) ((T_WHILE) reduce 102) ((T_YIELD) reduce 102) ((T_YIELD_FROM) reduce 102) (("[") reduce 102) (("`") reduce 102) (("{") reduce 102) (("~") reduce 102)) 19425 ((("!") reduce 146) (("\"") reduce 146) (("$") reduce 146) (("(") reduce 146) (("+") reduce 146) (("-") reduce 146) ((";") reduce 146) (("@") reduce 146) ((T_ABSTRACT) reduce 146) ((T_ARRAY) reduce 146) ((T_ARRAY_CAST) reduce 146) ((T_ATTRIBUTE) reduce 146) ((T_BOOL_CAST) reduce 146) ((T_BREAK) reduce 146) ((T_CLASS) reduce 146) ((T_CLASS_C) reduce 146) ((T_CLONE) reduce 146) ((T_CONSTANT_ENCAPSED_STRING) reduce 146) ((T_CONTINUE) reduce 146) ((T_DEC) reduce 146) ((T_DECLARE) reduce 146) ((T_DIR) reduce 146) ((T_DNUMBER) reduce 146) ((T_DO) reduce 146) ((T_DOUBLE_CAST) reduce 146) ((T_ECHO) reduce 146) ((T_EMPTY) reduce 146) ((T_ENDFOREACH) reduce 146) ((T_ENUM) reduce 146) ((T_EVAL) reduce 146) ((T_EXIT) reduce 146) ((T_FILE) reduce 146) ((T_FINAL) reduce 146) ((T_FN) reduce 146) ((T_FOR) reduce 146) ((T_FOREACH) reduce 146) ((T_FUNCTION) reduce 146) ((T_FUNC_C) reduce 146) ((T_GLOBAL) reduce 146) ((T_GOTO) reduce 146) ((T_HALT_COMPILER) reduce 146) ((T_IF) reduce 146) ((T_INC) reduce 146) ((T_INCLUDE) reduce 146) ((T_INCLUDE_ONCE) reduce 146) ((T_INLINE_HTML) reduce 146) ((T_INTERFACE) reduce 146) ((T_INT_CAST) reduce 146) ((T_ISSET) reduce 146) ((T_LINE) reduce 146) ((T_LIST) reduce 146) ((T_LNUMBER) reduce 146) ((T_MATCH) reduce 146) ((T_METHOD_C) reduce 146) ((T_NAME_FULLY_QUALIFIED) reduce 146) ((T_NAME_QUALIFIED) reduce 146) ((T_NAME_RELATIVE) reduce 146) ((T_NEW) reduce 146) ((T_NS_C) reduce 146) ((T_OBJECT_CAST) reduce 146) ((T_PRINT) reduce 146) ((T_READONLY) reduce 146) ((T_REQUIRE) reduce 146) ((T_REQUIRE_ONCE) reduce 146) ((T_RETURN) reduce 146) ((T_START_HEREDOC) reduce 146) ((T_STATIC) reduce 146) ((T_STRING) reduce 146) ((T_STRING_CAST) reduce 146) ((T_SWITCH) reduce 146) ((T_THROW) reduce 146) ((T_TRAIT) reduce 146) ((T_TRAIT_C) reduce 146) ((T_TRY) reduce 146) ((T_UNSET) reduce 146) ((T_UNSET_CAST) reduce 146) ((T_VARIABLE) reduce 146) ((T_WHILE) reduce 146) ((T_YIELD) reduce 146) ((T_YIELD_FROM) reduce 146) (("[") reduce 146) (("`") reduce 146) (("{") reduce 146) (("~") reduce 146)) 19426 ((("!") reduce 243) (("\"") reduce 243) (("$") reduce 243) (("(") reduce 243) (("+") reduce 243) (("-") reduce 243) ((";") reduce 243) (("@") reduce 243) ((T_ABSTRACT) reduce 243) ((T_ARRAY) reduce 243) ((T_ARRAY_CAST) reduce 243) ((T_ATTRIBUTE) reduce 243) ((T_BOOL_CAST) reduce 243) ((T_BREAK) reduce 243) ((T_CLASS) reduce 243) ((T_CLASS_C) reduce 243) ((T_CLONE) reduce 243) ((T_CONSTANT_ENCAPSED_STRING) reduce 243) ((T_CONTINUE) reduce 243) ((T_DEC) reduce 243) ((T_DECLARE) reduce 243) ((T_DIR) reduce 243) ((T_DNUMBER) reduce 243) ((T_DO) reduce 243) ((T_DOUBLE_CAST) reduce 243) ((T_ECHO) reduce 243) ((T_ELSE) shift) ((T_ELSEIF) shift) ((T_EMPTY) reduce 243) ((T_ENDFOREACH) reduce 243) ((T_ENUM) reduce 243) ((T_EVAL) reduce 243) ((T_EXIT) reduce 243) ((T_FILE) reduce 243) ((T_FINAL) reduce 243) ((T_FN) reduce 243) ((T_FOR) reduce 243) ((T_FOREACH) reduce 243) ((T_FUNCTION) reduce 243) ((T_FUNC_C) reduce 243) ((T_GLOBAL) reduce 243) ((T_GOTO) reduce 243) ((T_HALT_COMPILER) reduce 243) ((T_IF) reduce 243) ((T_INC) reduce 243) ((T_INCLUDE) reduce 243) ((T_INCLUDE_ONCE) reduce 243) ((T_INLINE_HTML) reduce 243) ((T_INTERFACE) reduce 243) ((T_INT_CAST) reduce 243) ((T_ISSET) reduce 243) ((T_LINE) reduce 243) ((T_LIST) reduce 243) ((T_LNUMBER) reduce 243) ((T_MATCH) reduce 243) ((T_METHOD_C) reduce 243) ((T_NAME_FULLY_QUALIFIED) reduce 243) ((T_NAME_QUALIFIED) reduce 243) ((T_NAME_RELATIVE) reduce 243) ((T_NEW) reduce 243) ((T_NS_C) reduce 243) ((T_OBJECT_CAST) reduce 243) ((T_PRINT) reduce 243) ((T_READONLY) reduce 243) ((T_REQUIRE) reduce 243) ((T_REQUIRE_ONCE) reduce 243) ((T_RETURN) reduce 243) ((T_START_HEREDOC) reduce 243) ((T_STATIC) reduce 243) ((T_STRING) reduce 243) ((T_STRING_CAST) reduce 243) ((T_SWITCH) reduce 243) ((T_THROW) reduce 243) ((T_TRAIT) reduce 243) ((T_TRAIT_C) reduce 243) ((T_TRY) reduce 243) ((T_UNSET) reduce 243) ((T_UNSET_CAST) reduce 243) ((T_VARIABLE) reduce 243) ((T_WHILE) reduce 243) ((T_YIELD) reduce 243) ((T_YIELD_FROM) reduce 243) (("[") reduce 243) (("`") reduce 243) (("{") reduce 243) (("~") reduce 243)) 19427 ((("!") reduce 139) (("\"") reduce 139) (("$") reduce 139) (("(") reduce 139) (("+") reduce 139) (("-") reduce 139) ((";") reduce 139) (("@") reduce 139) ((T_ABSTRACT) reduce 139) ((T_ARRAY) reduce 139) ((T_ARRAY_CAST) reduce 139) ((T_ATTRIBUTE) reduce 139) ((T_BOOL_CAST) reduce 139) ((T_BREAK) reduce 139) ((T_CLASS) reduce 139) ((T_CLASS_C) reduce 139) ((T_CLONE) reduce 139) ((T_CONSTANT_ENCAPSED_STRING) reduce 139) ((T_CONTINUE) reduce 139) ((T_DEC) reduce 139) ((T_DECLARE) reduce 139) ((T_DIR) reduce 139) ((T_DNUMBER) reduce 139) ((T_DO) reduce 139) ((T_DOUBLE_CAST) reduce 139) ((T_ECHO) reduce 139) ((T_EMPTY) reduce 139) ((T_ENDFOREACH) reduce 139) ((T_ENUM) reduce 139) ((T_EVAL) reduce 139) ((T_EXIT) reduce 139) ((T_FILE) reduce 139) ((T_FINAL) reduce 139) ((T_FN) reduce 139) ((T_FOR) reduce 139) ((T_FOREACH) reduce 139) ((T_FUNCTION) reduce 139) ((T_FUNC_C) reduce 139) ((T_GLOBAL) reduce 139) ((T_GOTO) reduce 139) ((T_HALT_COMPILER) reduce 139) ((T_IF) reduce 139) ((T_INC) reduce 139) ((T_INCLUDE) reduce 139) ((T_INCLUDE_ONCE) reduce 139) ((T_INLINE_HTML) reduce 139) ((T_INTERFACE) reduce 139) ((T_INT_CAST) reduce 139) ((T_ISSET) reduce 139) ((T_LINE) reduce 139) ((T_LIST) reduce 139) ((T_LNUMBER) reduce 139) ((T_MATCH) reduce 139) ((T_METHOD_C) reduce 139) ((T_NAME_FULLY_QUALIFIED) reduce 139) ((T_NAME_QUALIFIED) reduce 139) ((T_NAME_RELATIVE) reduce 139) ((T_NEW) reduce 139) ((T_NS_C) reduce 139) ((T_OBJECT_CAST) reduce 139) ((T_PRINT) reduce 139) ((T_READONLY) reduce 139) ((T_REQUIRE) reduce 139) ((T_REQUIRE_ONCE) reduce 139) ((T_RETURN) reduce 139) ((T_START_HEREDOC) reduce 139) ((T_STATIC) reduce 139) ((T_STRING) reduce 139) ((T_STRING_CAST) reduce 139) ((T_SWITCH) reduce 139) ((T_THROW) reduce 139) ((T_TRAIT) reduce 139) ((T_TRAIT_C) reduce 139) ((T_TRY) reduce 139) ((T_UNSET) reduce 139) ((T_UNSET_CAST) reduce 139) ((T_VARIABLE) reduce 139) ((T_WHILE) reduce 139) ((T_YIELD) reduce 139) ((T_YIELD_FROM) reduce 139) (("[") reduce 139) (("`") reduce 139) (("{") reduce 139) (("~") reduce 139)) 19428 ((("!") reduce 105) (("\"") reduce 105) (("$") reduce 105) (("(") reduce 105) (("+") reduce 105) (("-") reduce 105) ((";") reduce 105) (("@") reduce 105) ((T_ABSTRACT) reduce 105) ((T_ARRAY) reduce 105) ((T_ARRAY_CAST) reduce 105) ((T_ATTRIBUTE) reduce 105) ((T_BOOL_CAST) reduce 105) ((T_BREAK) reduce 105) ((T_CLASS) reduce 105) ((T_CLASS_C) reduce 105) ((T_CLONE) reduce 105) ((T_CONSTANT_ENCAPSED_STRING) reduce 105) ((T_CONTINUE) reduce 105) ((T_DEC) reduce 105) ((T_DECLARE) reduce 105) ((T_DIR) reduce 105) ((T_DNUMBER) reduce 105) ((T_DO) reduce 105) ((T_DOUBLE_CAST) reduce 105) ((T_ECHO) reduce 105) ((T_EMPTY) reduce 105) ((T_ENDFOREACH) reduce 105) ((T_ENUM) reduce 105) ((T_EVAL) reduce 105) ((T_EXIT) reduce 105) ((T_FILE) reduce 105) ((T_FINAL) reduce 105) ((T_FN) reduce 105) ((T_FOR) reduce 105) ((T_FOREACH) reduce 105) ((T_FUNCTION) reduce 105) ((T_FUNC_C) reduce 105) ((T_GLOBAL) reduce 105) ((T_GOTO) reduce 105) ((T_HALT_COMPILER) reduce 105) ((T_IF) reduce 105) ((T_INC) reduce 105) ((T_INCLUDE) reduce 105) ((T_INCLUDE_ONCE) reduce 105) ((T_INLINE_HTML) reduce 105) ((T_INTERFACE) reduce 105) ((T_INT_CAST) reduce 105) ((T_ISSET) reduce 105) ((T_LINE) reduce 105) ((T_LIST) reduce 105) ((T_LNUMBER) reduce 105) ((T_MATCH) reduce 105) ((T_METHOD_C) reduce 105) ((T_NAME_FULLY_QUALIFIED) reduce 105) ((T_NAME_QUALIFIED) reduce 105) ((T_NAME_RELATIVE) reduce 105) ((T_NEW) reduce 105) ((T_NS_C) reduce 105) ((T_OBJECT_CAST) reduce 105) ((T_PRINT) reduce 105) ((T_READONLY) reduce 105) ((T_REQUIRE) reduce 105) ((T_REQUIRE_ONCE) reduce 105) ((T_RETURN) reduce 105) ((T_START_HEREDOC) reduce 105) ((T_STATIC) reduce 105) ((T_STRING) reduce 105) ((T_STRING_CAST) reduce 105) ((T_SWITCH) reduce 105) ((T_THROW) reduce 105) ((T_TRAIT) reduce 105) ((T_TRAIT_C) reduce 105) ((T_TRY) reduce 105) ((T_UNSET) reduce 105) ((T_UNSET_CAST) reduce 105) ((T_VARIABLE) reduce 105) ((T_WHILE) reduce 105) ((T_YIELD) reduce 105) ((T_YIELD_FROM) reduce 105) (("[") reduce 105) (("`") reduce 105) (("{") reduce 105) (("~") reduce 105)) 19429 ((("!") reduce 141) (("\"") reduce 141) (("$") reduce 141) (("(") reduce 141) (("+") reduce 141) (("-") reduce 141) ((";") reduce 141) (("@") reduce 141) ((T_ABSTRACT) reduce 141) ((T_ARRAY) reduce 141) ((T_ARRAY_CAST) reduce 141) ((T_ATTRIBUTE) reduce 141) ((T_BOOL_CAST) reduce 141) ((T_BREAK) reduce 141) ((T_CLASS) reduce 141) ((T_CLASS_C) reduce 141) ((T_CLONE) reduce 141) ((T_CONSTANT_ENCAPSED_STRING) reduce 141) ((T_CONTINUE) reduce 141) ((T_DEC) reduce 141) ((T_DECLARE) reduce 141) ((T_DIR) reduce 141) ((T_DNUMBER) reduce 141) ((T_DO) reduce 141) ((T_DOUBLE_CAST) reduce 141) ((T_ECHO) reduce 141) ((T_EMPTY) reduce 141) ((T_ENDFOREACH) reduce 141) ((T_ENUM) reduce 141) ((T_EVAL) reduce 141) ((T_EXIT) reduce 141) ((T_FILE) reduce 141) ((T_FINAL) reduce 141) ((T_FN) reduce 141) ((T_FOR) reduce 141) ((T_FOREACH) reduce 141) ((T_FUNCTION) reduce 141) ((T_FUNC_C) reduce 141) ((T_GLOBAL) reduce 141) ((T_GOTO) reduce 141) ((T_HALT_COMPILER) reduce 141) ((T_IF) reduce 141) ((T_INC) reduce 141) ((T_INCLUDE) reduce 141) ((T_INCLUDE_ONCE) reduce 141) ((T_INLINE_HTML) reduce 141) ((T_INTERFACE) reduce 141) ((T_INT_CAST) reduce 141) ((T_ISSET) reduce 141) ((T_LINE) reduce 141) ((T_LIST) reduce 141) ((T_LNUMBER) reduce 141) ((T_MATCH) reduce 141) ((T_METHOD_C) reduce 141) ((T_NAME_FULLY_QUALIFIED) reduce 141) ((T_NAME_QUALIFIED) reduce 141) ((T_NAME_RELATIVE) reduce 141) ((T_NEW) reduce 141) ((T_NS_C) reduce 141) ((T_OBJECT_CAST) reduce 141) ((T_PRINT) reduce 141) ((T_READONLY) reduce 141) ((T_REQUIRE) reduce 141) ((T_REQUIRE_ONCE) reduce 141) ((T_RETURN) reduce 141) ((T_START_HEREDOC) reduce 141) ((T_STATIC) reduce 141) ((T_STRING) reduce 141) ((T_STRING_CAST) reduce 141) ((T_SWITCH) reduce 141) ((T_THROW) reduce 141) ((T_TRAIT) reduce 141) ((T_TRAIT_C) reduce 141) ((T_TRY) reduce 141) ((T_UNSET) reduce 141) ((T_UNSET_CAST) reduce 141) ((T_VARIABLE) reduce 141) ((T_WHILE) reduce 141) ((T_YIELD) reduce 141) ((T_YIELD_FROM) reduce 141) (("[") reduce 141) (("`") reduce 141) (("{") reduce 141) (("~") reduce 141)) 19430 ((("!") reduce 104) (("\"") reduce 104) (("$") reduce 104) (("(") reduce 104) (("+") reduce 104) (("-") reduce 104) ((";") reduce 104) (("@") reduce 104) ((T_ABSTRACT) reduce 104) ((T_ARRAY) reduce 104) ((T_ARRAY_CAST) reduce 104) ((T_ATTRIBUTE) reduce 104) ((T_BOOL_CAST) reduce 104) ((T_BREAK) reduce 104) ((T_CLASS) reduce 104) ((T_CLASS_C) reduce 104) ((T_CLONE) reduce 104) ((T_CONSTANT_ENCAPSED_STRING) reduce 104) ((T_CONTINUE) reduce 104) ((T_DEC) reduce 104) ((T_DECLARE) reduce 104) ((T_DIR) reduce 104) ((T_DNUMBER) reduce 104) ((T_DO) reduce 104) ((T_DOUBLE_CAST) reduce 104) ((T_ECHO) reduce 104) ((T_EMPTY) reduce 104) ((T_ENDFOREACH) reduce 104) ((T_ENUM) reduce 104) ((T_EVAL) reduce 104) ((T_EXIT) reduce 104) ((T_FILE) reduce 104) ((T_FINAL) reduce 104) ((T_FN) reduce 104) ((T_FOR) reduce 104) ((T_FOREACH) reduce 104) ((T_FUNCTION) reduce 104) ((T_FUNC_C) reduce 104) ((T_GLOBAL) reduce 104) ((T_GOTO) reduce 104) ((T_HALT_COMPILER) reduce 104) ((T_IF) reduce 104) ((T_INC) reduce 104) ((T_INCLUDE) reduce 104) ((T_INCLUDE_ONCE) reduce 104) ((T_INLINE_HTML) reduce 104) ((T_INTERFACE) reduce 104) ((T_INT_CAST) reduce 104) ((T_ISSET) reduce 104) ((T_LINE) reduce 104) ((T_LIST) reduce 104) ((T_LNUMBER) reduce 104) ((T_MATCH) reduce 104) ((T_METHOD_C) reduce 104) ((T_NAME_FULLY_QUALIFIED) reduce 104) ((T_NAME_QUALIFIED) reduce 104) ((T_NAME_RELATIVE) reduce 104) ((T_NEW) reduce 104) ((T_NS_C) reduce 104) ((T_OBJECT_CAST) reduce 104) ((T_PRINT) reduce 104) ((T_READONLY) reduce 104) ((T_REQUIRE) reduce 104) ((T_REQUIRE_ONCE) reduce 104) ((T_RETURN) reduce 104) ((T_START_HEREDOC) reduce 104) ((T_STATIC) reduce 104) ((T_STRING) reduce 104) ((T_STRING_CAST) reduce 104) ((T_SWITCH) reduce 104) ((T_THROW) reduce 104) ((T_TRAIT) reduce 104) ((T_TRAIT_C) reduce 104) ((T_TRY) reduce 104) ((T_UNSET) reduce 104) ((T_UNSET_CAST) reduce 104) ((T_VARIABLE) reduce 104) ((T_WHILE) reduce 104) ((T_YIELD) reduce 104) ((T_YIELD_FROM) reduce 104) (("[") reduce 104) (("`") reduce 104) (("{") reduce 104) (("~") reduce 104)) 19433 ((("!") reduce 145) (("\"") reduce 145) (("$") reduce 145) (("(") reduce 145) (("+") reduce 145) (("-") reduce 145) ((";") reduce 145) (("@") reduce 145) ((T_ABSTRACT) reduce 145) ((T_ARRAY) reduce 145) ((T_ARRAY_CAST) reduce 145) ((T_ATTRIBUTE) reduce 145) ((T_BOOL_CAST) reduce 145) ((T_BREAK) reduce 145) ((T_CLASS) reduce 145) ((T_CLASS_C) reduce 145) ((T_CLONE) reduce 145) ((T_CONSTANT_ENCAPSED_STRING) reduce 145) ((T_CONTINUE) reduce 145) ((T_DEC) reduce 145) ((T_DECLARE) reduce 145) ((T_DIR) reduce 145) ((T_DNUMBER) reduce 145) ((T_DO) reduce 145) ((T_DOUBLE_CAST) reduce 145) ((T_ECHO) reduce 145) ((T_EMPTY) reduce 145) ((T_ENDFOREACH) reduce 145) ((T_ENUM) reduce 145) ((T_EVAL) reduce 145) ((T_EXIT) reduce 145) ((T_FILE) reduce 145) ((T_FINAL) reduce 145) ((T_FN) reduce 145) ((T_FOR) reduce 145) ((T_FOREACH) reduce 145) ((T_FUNCTION) reduce 145) ((T_FUNC_C) reduce 145) ((T_GLOBAL) reduce 145) ((T_GOTO) reduce 145) ((T_HALT_COMPILER) reduce 145) ((T_IF) reduce 145) ((T_INC) reduce 145) ((T_INCLUDE) reduce 145) ((T_INCLUDE_ONCE) reduce 145) ((T_INLINE_HTML) reduce 145) ((T_INTERFACE) reduce 145) ((T_INT_CAST) reduce 145) ((T_ISSET) reduce 145) ((T_LINE) reduce 145) ((T_LIST) reduce 145) ((T_LNUMBER) reduce 145) ((T_MATCH) reduce 145) ((T_METHOD_C) reduce 145) ((T_NAME_FULLY_QUALIFIED) reduce 145) ((T_NAME_QUALIFIED) reduce 145) ((T_NAME_RELATIVE) reduce 145) ((T_NEW) reduce 145) ((T_NS_C) reduce 145) ((T_OBJECT_CAST) reduce 145) ((T_PRINT) reduce 145) ((T_READONLY) reduce 145) ((T_REQUIRE) reduce 145) ((T_REQUIRE_ONCE) reduce 145) ((T_RETURN) reduce 145) ((T_START_HEREDOC) reduce 145) ((T_STATIC) reduce 145) ((T_STRING) reduce 145) ((T_STRING_CAST) reduce 145) ((T_SWITCH) reduce 145) ((T_THROW) reduce 145) ((T_TRAIT) reduce 145) ((T_TRAIT_C) reduce 145) ((T_TRY) reduce 145) ((T_UNSET) reduce 145) ((T_UNSET_CAST) reduce 145) ((T_VARIABLE) reduce 145) ((T_WHILE) reduce 145) ((T_YIELD) reduce 145) ((T_YIELD_FROM) reduce 145) (("[") reduce 145) (("`") reduce 145) (("{") reduce 145) (("~") reduce 145)) 19439 ((("!") reduce 164) (("\"") reduce 164) (("$") reduce 164) (("(") reduce 164) (("+") reduce 164) (("-") reduce 164) ((";") reduce 164) (("@") reduce 164) ((T_ABSTRACT) reduce 164) ((T_ARRAY) reduce 164) ((T_ARRAY_CAST) reduce 164) ((T_ATTRIBUTE) reduce 164) ((T_BOOL_CAST) reduce 164) ((T_BREAK) reduce 164) ((T_CLASS) reduce 164) ((T_CLASS_C) reduce 164) ((T_CLONE) reduce 164) ((T_CONSTANT_ENCAPSED_STRING) reduce 164) ((T_CONTINUE) reduce 164) ((T_DEC) reduce 164) ((T_DECLARE) reduce 164) ((T_DIR) reduce 164) ((T_DNUMBER) reduce 164) ((T_DO) reduce 164) ((T_DOUBLE_CAST) reduce 164) ((T_ECHO) reduce 164) ((T_ELSE) reduce 164) ((T_ELSEIF) reduce 164) ((T_EMPTY) reduce 164) ((T_ENDFOREACH) reduce 164) ((T_ENUM) reduce 164) ((T_EVAL) reduce 164) ((T_EXIT) reduce 164) ((T_FILE) reduce 164) ((T_FINAL) reduce 164) ((T_FN) reduce 164) ((T_FOR) reduce 164) ((T_FOREACH) reduce 164) ((T_FUNCTION) reduce 164) ((T_FUNC_C) reduce 164) ((T_GLOBAL) reduce 164) ((T_GOTO) reduce 164) ((T_HALT_COMPILER) reduce 164) ((T_IF) reduce 164) ((T_INC) reduce 164) ((T_INCLUDE) reduce 164) ((T_INCLUDE_ONCE) reduce 164) ((T_INLINE_HTML) reduce 164) ((T_INTERFACE) reduce 164) ((T_INT_CAST) reduce 164) ((T_ISSET) reduce 164) ((T_LINE) reduce 164) ((T_LIST) reduce 164) ((T_LNUMBER) reduce 164) ((T_MATCH) reduce 164) ((T_METHOD_C) reduce 164) ((T_NAME_FULLY_QUALIFIED) reduce 164) ((T_NAME_QUALIFIED) reduce 164) ((T_NAME_RELATIVE) reduce 164) ((T_NEW) reduce 164) ((T_NS_C) reduce 164) ((T_OBJECT_CAST) reduce 164) ((T_PRINT) reduce 164) ((T_READONLY) reduce 164) ((T_REQUIRE) reduce 164) ((T_REQUIRE_ONCE) reduce 164) ((T_RETURN) reduce 164) ((T_START_HEREDOC) reduce 164) ((T_STATIC) reduce 164) ((T_STRING) reduce 164) ((T_STRING_CAST) reduce 164) ((T_SWITCH) reduce 164) ((T_THROW) reduce 164) ((T_TRAIT) reduce 164) ((T_TRAIT_C) reduce 164) ((T_TRY) reduce 164) ((T_UNSET) reduce 164) ((T_UNSET_CAST) reduce 164) ((T_VARIABLE) reduce 164) ((T_WHILE) reduce 164) ((T_YIELD) reduce 164) ((T_YIELD_FROM) reduce 164) (("[") reduce 164) (("`") reduce 164) (("{") reduce 164) (("~") reduce 164)) 19449 ((("!") reduce 158) (("\"") reduce 158) (("$") reduce 158) (("(") reduce 158) (("+") reduce 158) (("-") reduce 158) ((";") reduce 158) (("@") reduce 158) ((T_ABSTRACT) reduce 158) ((T_ARRAY) reduce 158) ((T_ARRAY_CAST) reduce 158) ((T_ATTRIBUTE) reduce 158) ((T_BOOL_CAST) reduce 158) ((T_BREAK) reduce 158) ((T_CLASS) reduce 158) ((T_CLASS_C) reduce 158) ((T_CLONE) reduce 158) ((T_CONSTANT_ENCAPSED_STRING) reduce 158) ((T_CONTINUE) reduce 158) ((T_DEC) reduce 158) ((T_DECLARE) reduce 158) ((T_DIR) reduce 158) ((T_DNUMBER) reduce 158) ((T_DO) reduce 158) ((T_DOUBLE_CAST) reduce 158) ((T_ECHO) reduce 158) ((T_ELSE) reduce 158) ((T_ELSEIF) reduce 158) ((T_EMPTY) reduce 158) ((T_ENDFOREACH) reduce 158) ((T_ENUM) reduce 158) ((T_EVAL) reduce 158) ((T_EXIT) reduce 158) ((T_FILE) reduce 158) ((T_FINAL) reduce 158) ((T_FN) reduce 158) ((T_FOR) reduce 158) ((T_FOREACH) reduce 158) ((T_FUNCTION) reduce 158) ((T_FUNC_C) reduce 158) ((T_GLOBAL) reduce 158) ((T_GOTO) reduce 158) ((T_HALT_COMPILER) reduce 158) ((T_IF) reduce 158) ((T_INC) reduce 158) ((T_INCLUDE) reduce 158) ((T_INCLUDE_ONCE) reduce 158) ((T_INLINE_HTML) reduce 158) ((T_INTERFACE) reduce 158) ((T_INT_CAST) reduce 158) ((T_ISSET) reduce 158) ((T_LINE) reduce 158) ((T_LIST) reduce 158) ((T_LNUMBER) reduce 158) ((T_MATCH) reduce 158) ((T_METHOD_C) reduce 158) ((T_NAME_FULLY_QUALIFIED) reduce 158) ((T_NAME_QUALIFIED) reduce 158) ((T_NAME_RELATIVE) reduce 158) ((T_NEW) reduce 158) ((T_NS_C) reduce 158) ((T_OBJECT_CAST) reduce 158) ((T_PRINT) reduce 158) ((T_READONLY) reduce 158) ((T_REQUIRE) reduce 158) ((T_REQUIRE_ONCE) reduce 158) ((T_RETURN) reduce 158) ((T_START_HEREDOC) reduce 158) ((T_STATIC) reduce 158) ((T_STRING) reduce 158) ((T_STRING_CAST) reduce 158) ((T_SWITCH) reduce 158) ((T_THROW) reduce 158) ((T_TRAIT) reduce 158) ((T_TRAIT_C) reduce 158) ((T_TRY) reduce 158) ((T_UNSET) reduce 158) ((T_UNSET_CAST) reduce 158) ((T_VARIABLE) reduce 158) ((T_WHILE) reduce 158) ((T_YIELD) reduce 158) ((T_YIELD_FROM) reduce 158) (("[") reduce 158) (("`") reduce 158) (("{") reduce 158) (("~") reduce 158)) 19457 ((("!") reduce 147) (("\"") reduce 147) (("$") reduce 147) (("(") reduce 147) (("+") reduce 147) (("-") reduce 147) ((";") reduce 147) (("@") reduce 147) ((T_ABSTRACT) reduce 147) ((T_ARRAY) reduce 147) ((T_ARRAY_CAST) reduce 147) ((T_ATTRIBUTE) reduce 147) ((T_BOOL_CAST) reduce 147) ((T_BREAK) reduce 147) ((T_CLASS) reduce 147) ((T_CLASS_C) reduce 147) ((T_CLONE) reduce 147) ((T_CONSTANT_ENCAPSED_STRING) reduce 147) ((T_CONTINUE) reduce 147) ((T_DEC) reduce 147) ((T_DECLARE) reduce 147) ((T_DIR) reduce 147) ((T_DNUMBER) reduce 147) ((T_DO) reduce 147) ((T_DOUBLE_CAST) reduce 147) ((T_ECHO) reduce 147) ((T_ELSE) reduce 147) ((T_ELSEIF) reduce 147) ((T_EMPTY) reduce 147) ((T_ENDFOREACH) reduce 147) ((T_ENUM) reduce 147) ((T_EVAL) reduce 147) ((T_EXIT) reduce 147) ((T_FILE) reduce 147) ((T_FINAL) reduce 147) ((T_FN) reduce 147) ((T_FOR) reduce 147) ((T_FOREACH) reduce 147) ((T_FUNCTION) reduce 147) ((T_FUNC_C) reduce 147) ((T_GLOBAL) reduce 147) ((T_GOTO) reduce 147) ((T_HALT_COMPILER) reduce 147) ((T_IF) reduce 147) ((T_INC) reduce 147) ((T_INCLUDE) reduce 147) ((T_INCLUDE_ONCE) reduce 147) ((T_INLINE_HTML) reduce 147) ((T_INTERFACE) reduce 147) ((T_INT_CAST) reduce 147) ((T_ISSET) reduce 147) ((T_LINE) reduce 147) ((T_LIST) reduce 147) ((T_LNUMBER) reduce 147) ((T_MATCH) reduce 147) ((T_METHOD_C) reduce 147) ((T_NAME_FULLY_QUALIFIED) reduce 147) ((T_NAME_QUALIFIED) reduce 147) ((T_NAME_RELATIVE) reduce 147) ((T_NEW) reduce 147) ((T_NS_C) reduce 147) ((T_OBJECT_CAST) reduce 147) ((T_PRINT) reduce 147) ((T_READONLY) reduce 147) ((T_REQUIRE) reduce 147) ((T_REQUIRE_ONCE) reduce 147) ((T_RETURN) reduce 147) ((T_START_HEREDOC) reduce 147) ((T_STATIC) reduce 147) ((T_STRING) reduce 147) ((T_STRING_CAST) reduce 147) ((T_SWITCH) reduce 147) ((T_THROW) reduce 147) ((T_TRAIT) reduce 147) ((T_TRAIT_C) reduce 147) ((T_TRY) reduce 147) ((T_UNSET) reduce 147) ((T_UNSET_CAST) reduce 147) ((T_VARIABLE) reduce 147) ((T_WHILE) reduce 147) ((T_YIELD) reduce 147) ((T_YIELD_FROM) reduce 147) (("[") reduce 147) (("`") reduce 147) (("{") reduce 147) (("~") reduce 147)) 19460 ((("!") reduce 146) (("\"") reduce 146) (("$") reduce 146) (("(") reduce 146) (("+") reduce 146) (("-") reduce 146) ((";") reduce 146) (("@") reduce 146) ((T_ABSTRACT) reduce 146) ((T_ARRAY) reduce 146) ((T_ARRAY_CAST) reduce 146) ((T_ATTRIBUTE) reduce 146) ((T_BOOL_CAST) reduce 146) ((T_BREAK) reduce 146) ((T_CLASS) reduce 146) ((T_CLASS_C) reduce 146) ((T_CLONE) reduce 146) ((T_CONSTANT_ENCAPSED_STRING) reduce 146) ((T_CONTINUE) reduce 146) ((T_DEC) reduce 146) ((T_DECLARE) reduce 146) ((T_DIR) reduce 146) ((T_DNUMBER) reduce 146) ((T_DO) reduce 146) ((T_DOUBLE_CAST) reduce 146) ((T_ECHO) reduce 146) ((T_ELSE) reduce 146) ((T_ELSEIF) reduce 146) ((T_EMPTY) reduce 146) ((T_ENDFOREACH) reduce 146) ((T_ENUM) reduce 146) ((T_EVAL) reduce 146) ((T_EXIT) reduce 146) ((T_FILE) reduce 146) ((T_FINAL) reduce 146) ((T_FN) reduce 146) ((T_FOR) reduce 146) ((T_FOREACH) reduce 146) ((T_FUNCTION) reduce 146) ((T_FUNC_C) reduce 146) ((T_GLOBAL) reduce 146) ((T_GOTO) reduce 146) ((T_HALT_COMPILER) reduce 146) ((T_IF) reduce 146) ((T_INC) reduce 146) ((T_INCLUDE) reduce 146) ((T_INCLUDE_ONCE) reduce 146) ((T_INLINE_HTML) reduce 146) ((T_INTERFACE) reduce 146) ((T_INT_CAST) reduce 146) ((T_ISSET) reduce 146) ((T_LINE) reduce 146) ((T_LIST) reduce 146) ((T_LNUMBER) reduce 146) ((T_MATCH) reduce 146) ((T_METHOD_C) reduce 146) ((T_NAME_FULLY_QUALIFIED) reduce 146) ((T_NAME_QUALIFIED) reduce 146) ((T_NAME_RELATIVE) reduce 146) ((T_NEW) reduce 146) ((T_NS_C) reduce 146) ((T_OBJECT_CAST) reduce 146) ((T_PRINT) reduce 146) ((T_READONLY) reduce 146) ((T_REQUIRE) reduce 146) ((T_REQUIRE_ONCE) reduce 146) ((T_RETURN) reduce 146) ((T_START_HEREDOC) reduce 146) ((T_STATIC) reduce 146) ((T_STRING) reduce 146) ((T_STRING_CAST) reduce 146) ((T_SWITCH) reduce 146) ((T_THROW) reduce 146) ((T_TRAIT) reduce 146) ((T_TRAIT_C) reduce 146) ((T_TRY) reduce 146) ((T_UNSET) reduce 146) ((T_UNSET_CAST) reduce 146) ((T_VARIABLE) reduce 146) ((T_WHILE) reduce 146) ((T_YIELD) reduce 146) ((T_YIELD_FROM) reduce 146) (("[") reduce 146) (("`") reduce 146) (("{") reduce 146) (("~") reduce 146)) 19462 ((("!") reduce 242) (("\"") reduce 242) (("$") reduce 242) (("(") reduce 242) (("+") reduce 242) (("-") reduce 242) ((";") reduce 242) (("@") reduce 242) ((T_ABSTRACT) reduce 242) ((T_ARRAY) reduce 242) ((T_ARRAY_CAST) reduce 242) ((T_ATTRIBUTE) reduce 242) ((T_BOOL_CAST) reduce 242) ((T_BREAK) reduce 242) ((T_CLASS) reduce 242) ((T_CLASS_C) reduce 242) ((T_CLONE) reduce 242) ((T_CONSTANT_ENCAPSED_STRING) reduce 242) ((T_CONTINUE) reduce 242) ((T_DEC) reduce 242) ((T_DECLARE) reduce 242) ((T_DIR) reduce 242) ((T_DNUMBER) reduce 242) ((T_DO) reduce 242) ((T_DOUBLE_CAST) reduce 242) ((T_ECHO) reduce 242) ((T_ELSE) reduce 242) ((T_ELSEIF) reduce 242) ((T_EMPTY) reduce 242) ((T_ENDFOREACH) reduce 242) ((T_ENUM) reduce 242) ((T_EVAL) reduce 242) ((T_EXIT) reduce 242) ((T_FILE) reduce 242) ((T_FINAL) reduce 242) ((T_FN) reduce 242) ((T_FOR) reduce 242) ((T_FOREACH) reduce 242) ((T_FUNCTION) reduce 242) ((T_FUNC_C) reduce 242) ((T_GLOBAL) reduce 242) ((T_GOTO) reduce 242) ((T_HALT_COMPILER) reduce 242) ((T_IF) reduce 242) ((T_INC) reduce 242) ((T_INCLUDE) reduce 242) ((T_INCLUDE_ONCE) reduce 242) ((T_INLINE_HTML) reduce 242) ((T_INTERFACE) reduce 242) ((T_INT_CAST) reduce 242) ((T_ISSET) reduce 242) ((T_LINE) reduce 242) ((T_LIST) reduce 242) ((T_LNUMBER) reduce 242) ((T_MATCH) reduce 242) ((T_METHOD_C) reduce 242) ((T_NAME_FULLY_QUALIFIED) reduce 242) ((T_NAME_QUALIFIED) reduce 242) ((T_NAME_RELATIVE) reduce 242) ((T_NEW) reduce 242) ((T_NS_C) reduce 242) ((T_OBJECT_CAST) reduce 242) ((T_PRINT) reduce 242) ((T_READONLY) reduce 242) ((T_REQUIRE) reduce 242) ((T_REQUIRE_ONCE) reduce 242) ((T_RETURN) reduce 242) ((T_START_HEREDOC) reduce 242) ((T_STATIC) reduce 242) ((T_STRING) reduce 242) ((T_STRING_CAST) reduce 242) ((T_SWITCH) reduce 242) ((T_THROW) reduce 242) ((T_TRAIT) reduce 242) ((T_TRAIT_C) reduce 242) ((T_TRY) reduce 242) ((T_UNSET) reduce 242) ((T_UNSET_CAST) reduce 242) ((T_VARIABLE) reduce 242) ((T_WHILE) reduce 242) ((T_YIELD) reduce 242) ((T_YIELD_FROM) reduce 242) (("[") reduce 242) (("`") reduce 242) (("{") reduce 242) (("~") reduce 242)) 19465 ((("!") reduce 145) (("\"") reduce 145) (("$") reduce 145) (("(") reduce 145) (("+") reduce 145) (("-") reduce 145) ((";") reduce 145) (("@") reduce 145) ((T_ABSTRACT) reduce 145) ((T_ARRAY) reduce 145) ((T_ARRAY_CAST) reduce 145) ((T_ATTRIBUTE) reduce 145) ((T_BOOL_CAST) reduce 145) ((T_BREAK) reduce 145) ((T_CLASS) reduce 145) ((T_CLASS_C) reduce 145) ((T_CLONE) reduce 145) ((T_CONSTANT_ENCAPSED_STRING) reduce 145) ((T_CONTINUE) reduce 145) ((T_DEC) reduce 145) ((T_DECLARE) reduce 145) ((T_DIR) reduce 145) ((T_DNUMBER) reduce 145) ((T_DO) reduce 145) ((T_DOUBLE_CAST) reduce 145) ((T_ECHO) reduce 145) ((T_ELSE) reduce 145) ((T_ELSEIF) reduce 145) ((T_EMPTY) reduce 145) ((T_ENDFOREACH) reduce 145) ((T_ENUM) reduce 145) ((T_EVAL) reduce 145) ((T_EXIT) reduce 145) ((T_FILE) reduce 145) ((T_FINAL) reduce 145) ((T_FN) reduce 145) ((T_FOR) reduce 145) ((T_FOREACH) reduce 145) ((T_FUNCTION) reduce 145) ((T_FUNC_C) reduce 145) ((T_GLOBAL) reduce 145) ((T_GOTO) reduce 145) ((T_HALT_COMPILER) reduce 145) ((T_IF) reduce 145) ((T_INC) reduce 145) ((T_INCLUDE) reduce 145) ((T_INCLUDE_ONCE) reduce 145) ((T_INLINE_HTML) reduce 145) ((T_INTERFACE) reduce 145) ((T_INT_CAST) reduce 145) ((T_ISSET) reduce 145) ((T_LINE) reduce 145) ((T_LIST) reduce 145) ((T_LNUMBER) reduce 145) ((T_MATCH) reduce 145) ((T_METHOD_C) reduce 145) ((T_NAME_FULLY_QUALIFIED) reduce 145) ((T_NAME_QUALIFIED) reduce 145) ((T_NAME_RELATIVE) reduce 145) ((T_NEW) reduce 145) ((T_NS_C) reduce 145) ((T_OBJECT_CAST) reduce 145) ((T_PRINT) reduce 145) ((T_READONLY) reduce 145) ((T_REQUIRE) reduce 145) ((T_REQUIRE_ONCE) reduce 145) ((T_RETURN) reduce 145) ((T_START_HEREDOC) reduce 145) ((T_STATIC) reduce 145) ((T_STRING) reduce 145) ((T_STRING_CAST) reduce 145) ((T_SWITCH) reduce 145) ((T_THROW) reduce 145) ((T_TRAIT) reduce 145) ((T_TRAIT_C) reduce 145) ((T_TRY) reduce 145) ((T_UNSET) reduce 145) ((T_UNSET_CAST) reduce 145) ((T_VARIABLE) reduce 145) ((T_WHILE) reduce 145) ((T_YIELD) reduce 145) ((T_YIELD_FROM) reduce 145) (("[") reduce 145) (("`") reduce 145) (("{") reduce 145) (("~") reduce 145)) 19467 ((("!") reduce 244) (("\"") reduce 244) (("$") reduce 244) (("(") reduce 244) (("+") reduce 244) (("-") reduce 244) ((";") reduce 244) (("@") reduce 244) ((T_ABSTRACT) reduce 244) ((T_ARRAY) reduce 244) ((T_ARRAY_CAST) reduce 244) ((T_ATTRIBUTE) reduce 244) ((T_BOOL_CAST) reduce 244) ((T_BREAK) reduce 244) ((T_CLASS) reduce 244) ((T_CLASS_C) reduce 244) ((T_CLONE) reduce 244) ((T_CONSTANT_ENCAPSED_STRING) reduce 244) ((T_CONTINUE) reduce 244) ((T_DEC) reduce 244) ((T_DECLARE) reduce 244) ((T_DIR) reduce 244) ((T_DNUMBER) reduce 244) ((T_DO) reduce 244) ((T_DOUBLE_CAST) reduce 244) ((T_ECHO) reduce 244) ((T_ELSE) reduce 244) ((T_ELSEIF) reduce 244) ((T_EMPTY) reduce 244) ((T_ENDFOREACH) reduce 244) ((T_ENUM) reduce 244) ((T_EVAL) reduce 244) ((T_EXIT) reduce 244) ((T_FILE) reduce 244) ((T_FINAL) reduce 244) ((T_FN) reduce 244) ((T_FOR) reduce 244) ((T_FOREACH) reduce 244) ((T_FUNCTION) reduce 244) ((T_FUNC_C) reduce 244) ((T_GLOBAL) reduce 244) ((T_GOTO) reduce 244) ((T_HALT_COMPILER) reduce 244) ((T_IF) reduce 244) ((T_INC) reduce 244) ((T_INCLUDE) reduce 244) ((T_INCLUDE_ONCE) reduce 244) ((T_INLINE_HTML) reduce 244) ((T_INTERFACE) reduce 244) ((T_INT_CAST) reduce 244) ((T_ISSET) reduce 244) ((T_LINE) reduce 244) ((T_LIST) reduce 244) ((T_LNUMBER) reduce 244) ((T_MATCH) reduce 244) ((T_METHOD_C) reduce 244) ((T_NAME_FULLY_QUALIFIED) reduce 244) ((T_NAME_QUALIFIED) reduce 244) ((T_NAME_RELATIVE) reduce 244) ((T_NEW) reduce 244) ((T_NS_C) reduce 244) ((T_OBJECT_CAST) reduce 244) ((T_PRINT) reduce 244) ((T_READONLY) reduce 244) ((T_REQUIRE) reduce 244) ((T_REQUIRE_ONCE) reduce 244) ((T_RETURN) reduce 244) ((T_START_HEREDOC) reduce 244) ((T_STATIC) reduce 244) ((T_STRING) reduce 244) ((T_STRING_CAST) reduce 244) ((T_SWITCH) reduce 244) ((T_THROW) reduce 244) ((T_TRAIT) reduce 244) ((T_TRAIT_C) reduce 244) ((T_TRY) reduce 244) ((T_UNSET) reduce 244) ((T_UNSET_CAST) reduce 244) ((T_VARIABLE) reduce 244) ((T_WHILE) reduce 244) ((T_YIELD) reduce 244) ((T_YIELD_FROM) reduce 244) (("[") reduce 244) (("`") reduce 244) (("{") reduce 244) (("~") reduce 244)) 19468 ((("!") reduce 159) (("\"") reduce 159) (("$") reduce 159) (("(") reduce 159) (("+") reduce 159) (("-") reduce 159) ((";") reduce 159) (("@") reduce 159) ((T_ABSTRACT) reduce 159) ((T_ARRAY) reduce 159) ((T_ARRAY_CAST) reduce 159) ((T_ATTRIBUTE) reduce 159) ((T_BOOL_CAST) reduce 159) ((T_BREAK) reduce 159) ((T_CLASS) reduce 159) ((T_CLASS_C) reduce 159) ((T_CLONE) reduce 159) ((T_CONSTANT_ENCAPSED_STRING) reduce 159) ((T_CONTINUE) reduce 159) ((T_DEC) reduce 159) ((T_DECLARE) reduce 159) ((T_DIR) reduce 159) ((T_DNUMBER) reduce 159) ((T_DO) reduce 159) ((T_DOUBLE_CAST) reduce 159) ((T_ECHO) reduce 159) ((T_ELSE) reduce 159) ((T_ELSEIF) reduce 159) ((T_EMPTY) reduce 159) ((T_ENDFOREACH) reduce 159) ((T_ENUM) reduce 159) ((T_EVAL) reduce 159) ((T_EXIT) reduce 159) ((T_FILE) reduce 159) ((T_FINAL) reduce 159) ((T_FN) reduce 159) ((T_FOR) reduce 159) ((T_FOREACH) reduce 159) ((T_FUNCTION) reduce 159) ((T_FUNC_C) reduce 159) ((T_GLOBAL) reduce 159) ((T_GOTO) reduce 159) ((T_HALT_COMPILER) reduce 159) ((T_IF) reduce 159) ((T_INC) reduce 159) ((T_INCLUDE) reduce 159) ((T_INCLUDE_ONCE) reduce 159) ((T_INLINE_HTML) reduce 159) ((T_INTERFACE) reduce 159) ((T_INT_CAST) reduce 159) ((T_ISSET) reduce 159) ((T_LINE) reduce 159) ((T_LIST) reduce 159) ((T_LNUMBER) reduce 159) ((T_MATCH) reduce 159) ((T_METHOD_C) reduce 159) ((T_NAME_FULLY_QUALIFIED) reduce 159) ((T_NAME_QUALIFIED) reduce 159) ((T_NAME_RELATIVE) reduce 159) ((T_NEW) reduce 159) ((T_NS_C) reduce 159) ((T_OBJECT_CAST) reduce 159) ((T_PRINT) reduce 159) ((T_READONLY) reduce 159) ((T_REQUIRE) reduce 159) ((T_REQUIRE_ONCE) reduce 159) ((T_RETURN) reduce 159) ((T_START_HEREDOC) reduce 159) ((T_STATIC) reduce 159) ((T_STRING) reduce 159) ((T_STRING_CAST) reduce 159) ((T_SWITCH) reduce 159) ((T_THROW) reduce 159) ((T_TRAIT) reduce 159) ((T_TRAIT_C) reduce 159) ((T_TRY) reduce 159) ((T_UNSET) reduce 159) ((T_UNSET_CAST) reduce 159) ((T_VARIABLE) reduce 159) ((T_WHILE) reduce 159) ((T_YIELD) reduce 159) ((T_YIELD_FROM) reduce 159) (("[") reduce 159) (("`") reduce 159) (("{") reduce 159) (("~") reduce 159)) 19471 ((("!") reduce 247) (("\"") reduce 247) (("$") reduce 247) (("(") reduce 247) (("+") reduce 247) (("-") reduce 247) ((";") reduce 247) (("@") reduce 247) ((T_ABSTRACT) reduce 247) ((T_ARRAY) reduce 247) ((T_ARRAY_CAST) reduce 247) ((T_ATTRIBUTE) reduce 247) ((T_BOOL_CAST) reduce 247) ((T_BREAK) reduce 247) ((T_CLASS) reduce 247) ((T_CLASS_C) reduce 247) ((T_CLONE) reduce 247) ((T_CONSTANT_ENCAPSED_STRING) reduce 247) ((T_CONTINUE) reduce 247) ((T_DEC) reduce 247) ((T_DECLARE) reduce 247) ((T_DIR) reduce 247) ((T_DNUMBER) reduce 247) ((T_DO) reduce 247) ((T_DOUBLE_CAST) reduce 247) ((T_ECHO) reduce 247) ((T_ELSE) reduce 247) ((T_ELSEIF) reduce 247) ((T_EMPTY) reduce 247) ((T_ENDFOREACH) reduce 247) ((T_ENUM) reduce 247) ((T_EVAL) reduce 247) ((T_EXIT) reduce 247) ((T_FILE) reduce 247) ((T_FINAL) reduce 247) ((T_FN) reduce 247) ((T_FOR) reduce 247) ((T_FOREACH) reduce 247) ((T_FUNCTION) reduce 247) ((T_FUNC_C) reduce 247) ((T_GLOBAL) reduce 247) ((T_GOTO) reduce 247) ((T_HALT_COMPILER) reduce 247) ((T_IF) reduce 247) ((T_INC) reduce 247) ((T_INCLUDE) reduce 247) ((T_INCLUDE_ONCE) reduce 247) ((T_INLINE_HTML) reduce 247) ((T_INTERFACE) reduce 247) ((T_INT_CAST) reduce 247) ((T_ISSET) reduce 247) ((T_LINE) reduce 247) ((T_LIST) reduce 247) ((T_LNUMBER) reduce 247) ((T_MATCH) reduce 247) ((T_METHOD_C) reduce 247) ((T_NAME_FULLY_QUALIFIED) reduce 247) ((T_NAME_QUALIFIED) reduce 247) ((T_NAME_RELATIVE) reduce 247) ((T_NEW) reduce 247) ((T_NS_C) reduce 247) ((T_OBJECT_CAST) reduce 247) ((T_PRINT) reduce 247) ((T_READONLY) reduce 247) ((T_REQUIRE) reduce 247) ((T_REQUIRE_ONCE) reduce 247) ((T_RETURN) reduce 247) ((T_START_HEREDOC) reduce 247) ((T_STATIC) reduce 247) ((T_STRING) reduce 247) ((T_STRING_CAST) reduce 247) ((T_SWITCH) reduce 247) ((T_THROW) reduce 247) ((T_TRAIT) reduce 247) ((T_TRAIT_C) reduce 247) ((T_TRY) reduce 247) ((T_UNSET) reduce 247) ((T_UNSET_CAST) reduce 247) ((T_VARIABLE) reduce 247) ((T_WHILE) reduce 247) ((T_YIELD) reduce 247) ((T_YIELD_FROM) reduce 247) (("[") reduce 247) (("`") reduce 247) (("{") reduce 247) (("~") reduce 247)) 19475 ((("!") reduce 248) (("\"") reduce 248) (("$") reduce 248) (("(") reduce 248) (("+") reduce 248) (("-") reduce 248) ((";") reduce 248) (("@") reduce 248) ((T_ABSTRACT) reduce 248) ((T_ARRAY) reduce 248) ((T_ARRAY_CAST) reduce 248) ((T_ATTRIBUTE) reduce 248) ((T_BOOL_CAST) reduce 248) ((T_BREAK) reduce 248) ((T_CLASS) reduce 248) ((T_CLASS_C) reduce 248) ((T_CLONE) reduce 248) ((T_CONSTANT_ENCAPSED_STRING) reduce 248) ((T_CONTINUE) reduce 248) ((T_DEC) reduce 248) ((T_DECLARE) reduce 248) ((T_DIR) reduce 248) ((T_DNUMBER) reduce 248) ((T_DO) reduce 248) ((T_DOUBLE_CAST) reduce 248) ((T_ECHO) reduce 248) ((T_ELSE) reduce 248) ((T_ELSEIF) reduce 248) ((T_EMPTY) reduce 248) ((T_ENDFOREACH) reduce 248) ((T_ENUM) reduce 248) ((T_EVAL) reduce 248) ((T_EXIT) reduce 248) ((T_FILE) reduce 248) ((T_FINAL) reduce 248) ((T_FN) reduce 248) ((T_FOR) reduce 248) ((T_FOREACH) reduce 248) ((T_FUNCTION) reduce 248) ((T_FUNC_C) reduce 248) ((T_GLOBAL) reduce 248) ((T_GOTO) reduce 248) ((T_HALT_COMPILER) reduce 248) ((T_IF) reduce 248) ((T_INC) reduce 248) ((T_INCLUDE) reduce 248) ((T_INCLUDE_ONCE) reduce 248) ((T_INLINE_HTML) reduce 248) ((T_INTERFACE) reduce 248) ((T_INT_CAST) reduce 248) ((T_ISSET) reduce 248) ((T_LINE) reduce 248) ((T_LIST) reduce 248) ((T_LNUMBER) reduce 248) ((T_MATCH) reduce 248) ((T_METHOD_C) reduce 248) ((T_NAME_FULLY_QUALIFIED) reduce 248) ((T_NAME_QUALIFIED) reduce 248) ((T_NAME_RELATIVE) reduce 248) ((T_NEW) reduce 248) ((T_NS_C) reduce 248) ((T_OBJECT_CAST) reduce 248) ((T_PRINT) reduce 248) ((T_READONLY) reduce 248) ((T_REQUIRE) reduce 248) ((T_REQUIRE_ONCE) reduce 248) ((T_RETURN) reduce 248) ((T_START_HEREDOC) reduce 248) ((T_STATIC) reduce 248) ((T_STRING) reduce 248) ((T_STRING_CAST) reduce 248) ((T_SWITCH) reduce 248) ((T_THROW) reduce 248) ((T_TRAIT) reduce 248) ((T_TRAIT_C) reduce 248) ((T_TRY) reduce 248) ((T_UNSET) reduce 248) ((T_UNSET_CAST) reduce 248) ((T_VARIABLE) reduce 248) ((T_WHILE) reduce 248) ((T_YIELD) reduce 248) ((T_YIELD_FROM) reduce 248) (("[") reduce 248) (("`") reduce 248) (("{") reduce 248) (("~") reduce 248)) 19480 ((("!") reduce 239) (("\"") reduce 239) (("$") reduce 239) (("(") reduce 239) (("+") reduce 239) (("-") reduce 239) ((";") reduce 239) (("@") reduce 239) ((T_ABSTRACT) reduce 239) ((T_ARRAY) reduce 239) ((T_ARRAY_CAST) reduce 239) ((T_ATTRIBUTE) reduce 239) ((T_BOOL_CAST) reduce 239) ((T_BREAK) reduce 239) ((T_CLASS) reduce 239) ((T_CLASS_C) reduce 239) ((T_CLONE) reduce 239) ((T_CONSTANT_ENCAPSED_STRING) reduce 239) ((T_CONTINUE) reduce 239) ((T_DEC) reduce 239) ((T_DECLARE) reduce 239) ((T_DIR) reduce 239) ((T_DNUMBER) reduce 239) ((T_DO) reduce 239) ((T_DOUBLE_CAST) reduce 239) ((T_ECHO) reduce 239) ((T_ELSE) reduce 239) ((T_ELSEIF) reduce 239) ((T_EMPTY) reduce 239) ((T_ENDFOREACH) reduce 239) ((T_ENUM) reduce 239) ((T_EVAL) reduce 239) ((T_EXIT) reduce 239) ((T_FILE) reduce 239) ((T_FINAL) reduce 239) ((T_FN) reduce 239) ((T_FOR) reduce 239) ((T_FOREACH) reduce 239) ((T_FUNCTION) reduce 239) ((T_FUNC_C) reduce 239) ((T_GLOBAL) reduce 239) ((T_GOTO) reduce 239) ((T_HALT_COMPILER) reduce 239) ((T_IF) reduce 239) ((T_INC) reduce 239) ((T_INCLUDE) reduce 239) ((T_INCLUDE_ONCE) reduce 239) ((T_INLINE_HTML) reduce 239) ((T_INTERFACE) reduce 239) ((T_INT_CAST) reduce 239) ((T_ISSET) reduce 239) ((T_LINE) reduce 239) ((T_LIST) reduce 239) ((T_LNUMBER) reduce 239) ((T_MATCH) reduce 239) ((T_METHOD_C) reduce 239) ((T_NAME_FULLY_QUALIFIED) reduce 239) ((T_NAME_QUALIFIED) reduce 239) ((T_NAME_RELATIVE) reduce 239) ((T_NEW) reduce 239) ((T_NS_C) reduce 239) ((T_OBJECT_CAST) reduce 239) ((T_PRINT) reduce 239) ((T_READONLY) reduce 239) ((T_REQUIRE) reduce 239) ((T_REQUIRE_ONCE) reduce 239) ((T_RETURN) reduce 239) ((T_START_HEREDOC) reduce 239) ((T_STATIC) reduce 239) ((T_STRING) reduce 239) ((T_STRING_CAST) reduce 239) ((T_SWITCH) reduce 239) ((T_THROW) reduce 239) ((T_TRAIT) reduce 239) ((T_TRAIT_C) reduce 239) ((T_TRY) reduce 239) ((T_UNSET) reduce 239) ((T_UNSET_CAST) reduce 239) ((T_VARIABLE) reduce 239) ((T_WHILE) reduce 239) ((T_YIELD) reduce 239) ((T_YIELD_FROM) reduce 239) (("[") reduce 239) (("`") reduce 239) (("{") reduce 239) (("~") reduce 239)) 19481 ((("!") reduce 148) (("\"") reduce 148) (("$") reduce 148) (("(") reduce 148) (("+") reduce 148) (("-") reduce 148) ((";") reduce 148) (("@") reduce 148) ((T_ABSTRACT) reduce 148) ((T_ARRAY) reduce 148) ((T_ARRAY_CAST) reduce 148) ((T_ATTRIBUTE) reduce 148) ((T_BOOL_CAST) reduce 148) ((T_BREAK) reduce 148) ((T_CLASS) reduce 148) ((T_CLASS_C) reduce 148) ((T_CLONE) reduce 148) ((T_CONSTANT_ENCAPSED_STRING) reduce 148) ((T_CONTINUE) reduce 148) ((T_DEC) reduce 148) ((T_DECLARE) reduce 148) ((T_DIR) reduce 148) ((T_DNUMBER) reduce 148) ((T_DO) reduce 148) ((T_DOUBLE_CAST) reduce 148) ((T_ECHO) reduce 148) ((T_ELSE) reduce 148) ((T_ELSEIF) reduce 148) ((T_EMPTY) reduce 148) ((T_ENDFOREACH) reduce 148) ((T_ENUM) reduce 148) ((T_EVAL) reduce 148) ((T_EXIT) reduce 148) ((T_FILE) reduce 148) ((T_FINAL) reduce 148) ((T_FN) reduce 148) ((T_FOR) reduce 148) ((T_FOREACH) reduce 148) ((T_FUNCTION) reduce 148) ((T_FUNC_C) reduce 148) ((T_GLOBAL) reduce 148) ((T_GOTO) reduce 148) ((T_HALT_COMPILER) reduce 148) ((T_IF) reduce 148) ((T_INC) reduce 148) ((T_INCLUDE) reduce 148) ((T_INCLUDE_ONCE) reduce 148) ((T_INLINE_HTML) reduce 148) ((T_INTERFACE) reduce 148) ((T_INT_CAST) reduce 148) ((T_ISSET) reduce 148) ((T_LINE) reduce 148) ((T_LIST) reduce 148) ((T_LNUMBER) reduce 148) ((T_MATCH) reduce 148) ((T_METHOD_C) reduce 148) ((T_NAME_FULLY_QUALIFIED) reduce 148) ((T_NAME_QUALIFIED) reduce 148) ((T_NAME_RELATIVE) reduce 148) ((T_NEW) reduce 148) ((T_NS_C) reduce 148) ((T_OBJECT_CAST) reduce 148) ((T_PRINT) reduce 148) ((T_READONLY) reduce 148) ((T_REQUIRE) reduce 148) ((T_REQUIRE_ONCE) reduce 148) ((T_RETURN) reduce 148) ((T_START_HEREDOC) reduce 148) ((T_STATIC) reduce 148) ((T_STRING) reduce 148) ((T_STRING_CAST) reduce 148) ((T_SWITCH) reduce 148) ((T_THROW) reduce 148) ((T_TRAIT) reduce 148) ((T_TRAIT_C) reduce 148) ((T_TRY) reduce 148) ((T_UNSET) reduce 148) ((T_UNSET_CAST) reduce 148) ((T_VARIABLE) reduce 148) ((T_WHILE) reduce 148) ((T_YIELD) reduce 148) ((T_YIELD_FROM) reduce 148) (("[") reduce 148) (("`") reduce 148) (("{") reduce 148) (("~") reduce 148)) 19484 ((("!") reduce 240) (("\"") reduce 240) (("$") reduce 240) (("(") reduce 240) (("+") reduce 240) (("-") reduce 240) ((";") reduce 240) (("@") reduce 240) ((T_ABSTRACT) reduce 240) ((T_ARRAY) reduce 240) ((T_ARRAY_CAST) reduce 240) ((T_ATTRIBUTE) reduce 240) ((T_BOOL_CAST) reduce 240) ((T_BREAK) reduce 240) ((T_CLASS) reduce 240) ((T_CLASS_C) reduce 240) ((T_CLONE) reduce 240) ((T_CONSTANT_ENCAPSED_STRING) reduce 240) ((T_CONTINUE) reduce 240) ((T_DEC) reduce 240) ((T_DECLARE) reduce 240) ((T_DIR) reduce 240) ((T_DNUMBER) reduce 240) ((T_DO) reduce 240) ((T_DOUBLE_CAST) reduce 240) ((T_ECHO) reduce 240) ((T_ELSE) reduce 240) ((T_ELSEIF) reduce 240) ((T_EMPTY) reduce 240) ((T_ENDFOREACH) reduce 240) ((T_ENUM) reduce 240) ((T_EVAL) reduce 240) ((T_EXIT) reduce 240) ((T_FILE) reduce 240) ((T_FINAL) reduce 240) ((T_FN) reduce 240) ((T_FOR) reduce 240) ((T_FOREACH) reduce 240) ((T_FUNCTION) reduce 240) ((T_FUNC_C) reduce 240) ((T_GLOBAL) reduce 240) ((T_GOTO) reduce 240) ((T_HALT_COMPILER) reduce 240) ((T_IF) reduce 240) ((T_INC) reduce 240) ((T_INCLUDE) reduce 240) ((T_INCLUDE_ONCE) reduce 240) ((T_INLINE_HTML) reduce 240) ((T_INTERFACE) reduce 240) ((T_INT_CAST) reduce 240) ((T_ISSET) reduce 240) ((T_LINE) reduce 240) ((T_LIST) reduce 240) ((T_LNUMBER) reduce 240) ((T_MATCH) reduce 240) ((T_METHOD_C) reduce 240) ((T_NAME_FULLY_QUALIFIED) reduce 240) ((T_NAME_QUALIFIED) reduce 240) ((T_NAME_RELATIVE) reduce 240) ((T_NEW) reduce 240) ((T_NS_C) reduce 240) ((T_OBJECT_CAST) reduce 240) ((T_PRINT) reduce 240) ((T_READONLY) reduce 240) ((T_REQUIRE) reduce 240) ((T_REQUIRE_ONCE) reduce 240) ((T_RETURN) reduce 240) ((T_START_HEREDOC) reduce 240) ((T_STATIC) reduce 240) ((T_STRING) reduce 240) ((T_STRING_CAST) reduce 240) ((T_SWITCH) reduce 240) ((T_THROW) reduce 240) ((T_TRAIT) reduce 240) ((T_TRAIT_C) reduce 240) ((T_TRY) reduce 240) ((T_UNSET) reduce 240) ((T_UNSET_CAST) reduce 240) ((T_VARIABLE) reduce 240) ((T_WHILE) reduce 240) ((T_YIELD) reduce 240) ((T_YIELD_FROM) reduce 240) (("[") reduce 240) (("`") reduce 240) (("{") reduce 240) (("~") reduce 240)) 19489 ((("!") reduce 160) (("\"") reduce 160) (("$") reduce 160) (("(") reduce 160) (("+") reduce 160) (("-") reduce 160) ((";") reduce 160) (("@") reduce 160) ((T_ABSTRACT) reduce 160) ((T_ARRAY) reduce 160) ((T_ARRAY_CAST) reduce 160) ((T_ATTRIBUTE) reduce 160) ((T_BOOL_CAST) reduce 160) ((T_BREAK) reduce 160) ((T_CLASS) reduce 160) ((T_CLASS_C) reduce 160) ((T_CLONE) reduce 160) ((T_CONSTANT_ENCAPSED_STRING) reduce 160) ((T_CONTINUE) reduce 160) ((T_DEC) reduce 160) ((T_DECLARE) reduce 160) ((T_DIR) reduce 160) ((T_DNUMBER) reduce 160) ((T_DO) reduce 160) ((T_DOUBLE_CAST) reduce 160) ((T_ECHO) reduce 160) ((T_ELSE) reduce 160) ((T_ELSEIF) reduce 160) ((T_EMPTY) reduce 160) ((T_ENDFOREACH) reduce 160) ((T_ENUM) reduce 160) ((T_EVAL) reduce 160) ((T_EXIT) reduce 160) ((T_FILE) reduce 160) ((T_FINAL) reduce 160) ((T_FN) reduce 160) ((T_FOR) reduce 160) ((T_FOREACH) reduce 160) ((T_FUNCTION) reduce 160) ((T_FUNC_C) reduce 160) ((T_GLOBAL) reduce 160) ((T_GOTO) reduce 160) ((T_HALT_COMPILER) reduce 160) ((T_IF) reduce 160) ((T_INC) reduce 160) ((T_INCLUDE) reduce 160) ((T_INCLUDE_ONCE) reduce 160) ((T_INLINE_HTML) reduce 160) ((T_INTERFACE) reduce 160) ((T_INT_CAST) reduce 160) ((T_ISSET) reduce 160) ((T_LINE) reduce 160) ((T_LIST) reduce 160) ((T_LNUMBER) reduce 160) ((T_MATCH) reduce 160) ((T_METHOD_C) reduce 160) ((T_NAME_FULLY_QUALIFIED) reduce 160) ((T_NAME_QUALIFIED) reduce 160) ((T_NAME_RELATIVE) reduce 160) ((T_NEW) reduce 160) ((T_NS_C) reduce 160) ((T_OBJECT_CAST) reduce 160) ((T_PRINT) reduce 160) ((T_READONLY) reduce 160) ((T_REQUIRE) reduce 160) ((T_REQUIRE_ONCE) reduce 160) ((T_RETURN) reduce 160) ((T_START_HEREDOC) reduce 160) ((T_STATIC) reduce 160) ((T_STRING) reduce 160) ((T_STRING_CAST) reduce 160) ((T_SWITCH) reduce 160) ((T_THROW) reduce 160) ((T_TRAIT) reduce 160) ((T_TRAIT_C) reduce 160) ((T_TRY) reduce 160) ((T_UNSET) reduce 160) ((T_UNSET_CAST) reduce 160) ((T_VARIABLE) reduce 160) ((T_WHILE) reduce 160) ((T_YIELD) reduce 160) ((T_YIELD_FROM) reduce 160) (("[") reduce 160) (("`") reduce 160) (("{") reduce 160) (("~") reduce 160)) 19492 ((("!") reduce 168) (("\"") reduce 168) (("$") reduce 168) (("(") reduce 168) (("+") reduce 168) (("-") reduce 168) ((";") reduce 168) (("@") reduce 168) ((T_ABSTRACT) reduce 168) ((T_ARRAY) reduce 168) ((T_ARRAY_CAST) reduce 168) ((T_ATTRIBUTE) reduce 168) ((T_BOOL_CAST) reduce 168) ((T_BREAK) reduce 168) ((T_CATCH) reduce 168) ((T_CLASS) reduce 168) ((T_CLASS_C) reduce 168) ((T_CLONE) reduce 168) ((T_CONSTANT_ENCAPSED_STRING) reduce 168) ((T_CONTINUE) reduce 168) ((T_DEC) reduce 168) ((T_DECLARE) reduce 168) ((T_DIR) reduce 168) ((T_DNUMBER) reduce 168) ((T_DO) reduce 168) ((T_DOUBLE_CAST) reduce 168) ((T_ECHO) reduce 168) ((T_ELSE) reduce 168) ((T_ELSEIF) reduce 168) ((T_EMPTY) reduce 168) ((T_ENDFOREACH) reduce 168) ((T_ENUM) reduce 168) ((T_EVAL) reduce 168) ((T_EXIT) reduce 168) ((T_FILE) reduce 168) ((T_FINAL) reduce 168) ((T_FINALLY) reduce 168) ((T_FN) reduce 168) ((T_FOR) reduce 168) ((T_FOREACH) reduce 168) ((T_FUNCTION) reduce 168) ((T_FUNC_C) reduce 168) ((T_GLOBAL) reduce 168) ((T_GOTO) reduce 168) ((T_HALT_COMPILER) reduce 168) ((T_IF) reduce 168) ((T_INC) reduce 168) ((T_INCLUDE) reduce 168) ((T_INCLUDE_ONCE) reduce 168) ((T_INLINE_HTML) reduce 168) ((T_INTERFACE) reduce 168) ((T_INT_CAST) reduce 168) ((T_ISSET) reduce 168) ((T_LINE) reduce 168) ((T_LIST) reduce 168) ((T_LNUMBER) reduce 168) ((T_MATCH) reduce 168) ((T_METHOD_C) reduce 168) ((T_NAME_FULLY_QUALIFIED) reduce 168) ((T_NAME_QUALIFIED) reduce 168) ((T_NAME_RELATIVE) reduce 168) ((T_NEW) reduce 168) ((T_NS_C) reduce 168) ((T_OBJECT_CAST) reduce 168) ((T_PRINT) reduce 168) ((T_READONLY) reduce 168) ((T_REQUIRE) reduce 168) ((T_REQUIRE_ONCE) reduce 168) ((T_RETURN) reduce 168) ((T_START_HEREDOC) reduce 168) ((T_STATIC) reduce 168) ((T_STRING) reduce 168) ((T_STRING_CAST) reduce 168) ((T_SWITCH) reduce 168) ((T_THROW) reduce 168) ((T_TRAIT) reduce 168) ((T_TRAIT_C) reduce 168) ((T_TRY) reduce 168) ((T_UNSET) reduce 168) ((T_UNSET_CAST) reduce 168) ((T_VARIABLE) reduce 168) ((T_WHILE) reduce 168) ((T_YIELD) reduce 168) ((T_YIELD_FROM) reduce 168) (("[") reduce 168) (("`") reduce 168) (("{") reduce 168) (("~") reduce 168)) 19493 ((("!") reduce 174) (("\"") reduce 174) (("$") reduce 174) (("(") reduce 174) (("+") reduce 174) (("-") reduce 174) ((";") reduce 174) (("@") reduce 174) ((T_ABSTRACT) reduce 174) ((T_ARRAY) reduce 174) ((T_ARRAY_CAST) reduce 174) ((T_ATTRIBUTE) reduce 174) ((T_BOOL_CAST) reduce 174) ((T_BREAK) reduce 174) ((T_CATCH) shift) ((T_CLASS) reduce 174) ((T_CLASS_C) reduce 174) ((T_CLONE) reduce 174) ((T_CONSTANT_ENCAPSED_STRING) reduce 174) ((T_CONTINUE) reduce 174) ((T_DEC) reduce 174) ((T_DECLARE) reduce 174) ((T_DIR) reduce 174) ((T_DNUMBER) reduce 174) ((T_DO) reduce 174) ((T_DOUBLE_CAST) reduce 174) ((T_ECHO) reduce 174) ((T_ELSE) reduce 174) ((T_ELSEIF) reduce 174) ((T_EMPTY) reduce 174) ((T_ENDFOREACH) reduce 174) ((T_ENUM) reduce 174) ((T_EVAL) reduce 174) ((T_EXIT) reduce 174) ((T_FILE) reduce 174) ((T_FINAL) reduce 174) ((T_FINALLY) shift) ((T_FN) reduce 174) ((T_FOR) reduce 174) ((T_FOREACH) reduce 174) ((T_FUNCTION) reduce 174) ((T_FUNC_C) reduce 174) ((T_GLOBAL) reduce 174) ((T_GOTO) reduce 174) ((T_HALT_COMPILER) reduce 174) ((T_IF) reduce 174) ((T_INC) reduce 174) ((T_INCLUDE) reduce 174) ((T_INCLUDE_ONCE) reduce 174) ((T_INLINE_HTML) reduce 174) ((T_INTERFACE) reduce 174) ((T_INT_CAST) reduce 174) ((T_ISSET) reduce 174) ((T_LINE) reduce 174) ((T_LIST) reduce 174) ((T_LNUMBER) reduce 174) ((T_MATCH) reduce 174) ((T_METHOD_C) reduce 174) ((T_NAME_FULLY_QUALIFIED) reduce 174) ((T_NAME_QUALIFIED) reduce 174) ((T_NAME_RELATIVE) reduce 174) ((T_NEW) reduce 174) ((T_NS_C) reduce 174) ((T_OBJECT_CAST) reduce 174) ((T_PRINT) reduce 174) ((T_READONLY) reduce 174) ((T_REQUIRE) reduce 174) ((T_REQUIRE_ONCE) reduce 174) ((T_RETURN) reduce 174) ((T_START_HEREDOC) reduce 174) ((T_STATIC) reduce 174) ((T_STRING) reduce 174) ((T_STRING_CAST) reduce 174) ((T_SWITCH) reduce 174) ((T_THROW) reduce 174) ((T_TRAIT) reduce 174) ((T_TRAIT_C) reduce 174) ((T_TRY) reduce 174) ((T_UNSET) reduce 174) ((T_UNSET_CAST) reduce 174) ((T_VARIABLE) reduce 174) ((T_WHILE) reduce 174) ((T_YIELD) reduce 174) ((T_YIELD_FROM) reduce 174) (("[") reduce 174) (("`") reduce 174) (("{") reduce 174) (("~") reduce 174)) 19496 ((("!") reduce 165) (("\"") reduce 165) (("$") reduce 165) (("(") reduce 165) (("+") reduce 165) (("-") reduce 165) ((";") reduce 165) (("@") reduce 165) ((T_ABSTRACT) reduce 165) ((T_ARRAY) reduce 165) ((T_ARRAY_CAST) reduce 165) ((T_ATTRIBUTE) reduce 165) ((T_BOOL_CAST) reduce 165) ((T_BREAK) reduce 165) ((T_CLASS) reduce 165) ((T_CLASS_C) reduce 165) ((T_CLONE) reduce 165) ((T_CONSTANT_ENCAPSED_STRING) reduce 165) ((T_CONTINUE) reduce 165) ((T_DEC) reduce 165) ((T_DECLARE) reduce 165) ((T_DIR) reduce 165) ((T_DNUMBER) reduce 165) ((T_DO) reduce 165) ((T_DOUBLE_CAST) reduce 165) ((T_ECHO) reduce 165) ((T_ELSE) reduce 165) ((T_ELSEIF) reduce 165) ((T_EMPTY) reduce 165) ((T_ENDFOREACH) reduce 165) ((T_ENUM) reduce 165) ((T_EVAL) reduce 165) ((T_EXIT) reduce 165) ((T_FILE) reduce 165) ((T_FINAL) reduce 165) ((T_FN) reduce 165) ((T_FOR) reduce 165) ((T_FOREACH) reduce 165) ((T_FUNCTION) reduce 165) ((T_FUNC_C) reduce 165) ((T_GLOBAL) reduce 165) ((T_GOTO) reduce 165) ((T_HALT_COMPILER) reduce 165) ((T_IF) reduce 165) ((T_INC) reduce 165) ((T_INCLUDE) reduce 165) ((T_INCLUDE_ONCE) reduce 165) ((T_INLINE_HTML) reduce 165) ((T_INTERFACE) reduce 165) ((T_INT_CAST) reduce 165) ((T_ISSET) reduce 165) ((T_LINE) reduce 165) ((T_LIST) reduce 165) ((T_LNUMBER) reduce 165) ((T_MATCH) reduce 165) ((T_METHOD_C) reduce 165) ((T_NAME_FULLY_QUALIFIED) reduce 165) ((T_NAME_QUALIFIED) reduce 165) ((T_NAME_RELATIVE) reduce 165) ((T_NEW) reduce 165) ((T_NS_C) reduce 165) ((T_OBJECT_CAST) reduce 165) ((T_PRINT) reduce 165) ((T_READONLY) reduce 165) ((T_REQUIRE) reduce 165) ((T_REQUIRE_ONCE) reduce 165) ((T_RETURN) reduce 165) ((T_START_HEREDOC) reduce 165) ((T_STATIC) reduce 165) ((T_STRING) reduce 165) ((T_STRING_CAST) reduce 165) ((T_SWITCH) reduce 165) ((T_THROW) reduce 165) ((T_TRAIT) reduce 165) ((T_TRAIT_C) reduce 165) ((T_TRY) reduce 165) ((T_UNSET) reduce 165) ((T_UNSET_CAST) reduce 165) ((T_VARIABLE) reduce 165) ((T_WHILE) reduce 165) ((T_YIELD) reduce 165) ((T_YIELD_FROM) reduce 165) (("[") reduce 165) (("`") reduce 165) (("{") reduce 165) (("~") reduce 165)) 19499 ((("!") reduce 175) (("\"") reduce 175) (("$") reduce 175) (("(") reduce 175) (("+") reduce 175) (("-") reduce 175) ((";") reduce 175) (("@") reduce 175) ((T_ABSTRACT) reduce 175) ((T_ARRAY) reduce 175) ((T_ARRAY_CAST) reduce 175) ((T_ATTRIBUTE) reduce 175) ((T_BOOL_CAST) reduce 175) ((T_BREAK) reduce 175) ((T_CLASS) reduce 175) ((T_CLASS_C) reduce 175) ((T_CLONE) reduce 175) ((T_CONSTANT_ENCAPSED_STRING) reduce 175) ((T_CONTINUE) reduce 175) ((T_DEC) reduce 175) ((T_DECLARE) reduce 175) ((T_DIR) reduce 175) ((T_DNUMBER) reduce 175) ((T_DO) reduce 175) ((T_DOUBLE_CAST) reduce 175) ((T_ECHO) reduce 175) ((T_ELSE) reduce 175) ((T_ELSEIF) reduce 175) ((T_EMPTY) reduce 175) ((T_ENDFOREACH) reduce 175) ((T_ENUM) reduce 175) ((T_EVAL) reduce 175) ((T_EXIT) reduce 175) ((T_FILE) reduce 175) ((T_FINAL) reduce 175) ((T_FN) reduce 175) ((T_FOR) reduce 175) ((T_FOREACH) reduce 175) ((T_FUNCTION) reduce 175) ((T_FUNC_C) reduce 175) ((T_GLOBAL) reduce 175) ((T_GOTO) reduce 175) ((T_HALT_COMPILER) reduce 175) ((T_IF) reduce 175) ((T_INC) reduce 175) ((T_INCLUDE) reduce 175) ((T_INCLUDE_ONCE) reduce 175) ((T_INLINE_HTML) reduce 175) ((T_INTERFACE) reduce 175) ((T_INT_CAST) reduce 175) ((T_ISSET) reduce 175) ((T_LINE) reduce 175) ((T_LIST) reduce 175) ((T_LNUMBER) reduce 175) ((T_MATCH) reduce 175) ((T_METHOD_C) reduce 175) ((T_NAME_FULLY_QUALIFIED) reduce 175) ((T_NAME_QUALIFIED) reduce 175) ((T_NAME_RELATIVE) reduce 175) ((T_NEW) reduce 175) ((T_NS_C) reduce 175) ((T_OBJECT_CAST) reduce 175) ((T_PRINT) reduce 175) ((T_READONLY) reduce 175) ((T_REQUIRE) reduce 175) ((T_REQUIRE_ONCE) reduce 175) ((T_RETURN) reduce 175) ((T_START_HEREDOC) reduce 175) ((T_STATIC) reduce 175) ((T_STRING) reduce 175) ((T_STRING_CAST) reduce 175) ((T_SWITCH) reduce 175) ((T_THROW) reduce 175) ((T_TRAIT) reduce 175) ((T_TRAIT_C) reduce 175) ((T_TRY) reduce 175) ((T_UNSET) reduce 175) ((T_UNSET_CAST) reduce 175) ((T_VARIABLE) reduce 175) ((T_WHILE) reduce 175) ((T_YIELD) reduce 175) ((T_YIELD_FROM) reduce 175) (("[") reduce 175) (("`") reduce 175) (("{") reduce 175) (("~") reduce 175)) 19506 ((("!") reduce 169) (("\"") reduce 169) (("$") reduce 169) (("(") reduce 169) (("+") reduce 169) (("-") reduce 169) ((";") reduce 169) (("@") reduce 169) ((T_ABSTRACT) reduce 169) ((T_ARRAY) reduce 169) ((T_ARRAY_CAST) reduce 169) ((T_ATTRIBUTE) reduce 169) ((T_BOOL_CAST) reduce 169) ((T_BREAK) reduce 169) ((T_CATCH) reduce 169) ((T_CLASS) reduce 169) ((T_CLASS_C) reduce 169) ((T_CLONE) reduce 169) ((T_CONSTANT_ENCAPSED_STRING) reduce 169) ((T_CONTINUE) reduce 169) ((T_DEC) reduce 169) ((T_DECLARE) reduce 169) ((T_DIR) reduce 169) ((T_DNUMBER) reduce 169) ((T_DO) reduce 169) ((T_DOUBLE_CAST) reduce 169) ((T_ECHO) reduce 169) ((T_ELSE) reduce 169) ((T_ELSEIF) reduce 169) ((T_EMPTY) reduce 169) ((T_ENDFOREACH) reduce 169) ((T_ENUM) reduce 169) ((T_EVAL) reduce 169) ((T_EXIT) reduce 169) ((T_FILE) reduce 169) ((T_FINAL) reduce 169) ((T_FINALLY) reduce 169) ((T_FN) reduce 169) ((T_FOR) reduce 169) ((T_FOREACH) reduce 169) ((T_FUNCTION) reduce 169) ((T_FUNC_C) reduce 169) ((T_GLOBAL) reduce 169) ((T_GOTO) reduce 169) ((T_HALT_COMPILER) reduce 169) ((T_IF) reduce 169) ((T_INC) reduce 169) ((T_INCLUDE) reduce 169) ((T_INCLUDE_ONCE) reduce 169) ((T_INLINE_HTML) reduce 169) ((T_INTERFACE) reduce 169) ((T_INT_CAST) reduce 169) ((T_ISSET) reduce 169) ((T_LINE) reduce 169) ((T_LIST) reduce 169) ((T_LNUMBER) reduce 169) ((T_MATCH) reduce 169) ((T_METHOD_C) reduce 169) ((T_NAME_FULLY_QUALIFIED) reduce 169) ((T_NAME_QUALIFIED) reduce 169) ((T_NAME_RELATIVE) reduce 169) ((T_NEW) reduce 169) ((T_NS_C) reduce 169) ((T_OBJECT_CAST) reduce 169) ((T_PRINT) reduce 169) ((T_READONLY) reduce 169) ((T_REQUIRE) reduce 169) ((T_REQUIRE_ONCE) reduce 169) ((T_RETURN) reduce 169) ((T_START_HEREDOC) reduce 169) ((T_STATIC) reduce 169) ((T_STRING) reduce 169) ((T_STRING_CAST) reduce 169) ((T_SWITCH) reduce 169) ((T_THROW) reduce 169) ((T_TRAIT) reduce 169) ((T_TRAIT_C) reduce 169) ((T_TRY) reduce 169) ((T_UNSET) reduce 169) ((T_UNSET_CAST) reduce 169) ((T_VARIABLE) reduce 169) ((T_WHILE) reduce 169) ((T_YIELD) reduce 169) ((T_YIELD_FROM) reduce 169) (("[") reduce 169) (("`") reduce 169) (("{") reduce 169) (("~") reduce 169)) 19511 ((("!") reduce 151) (("\"") reduce 151) (("$") reduce 151) (("(") reduce 151) (("+") reduce 151) (("-") reduce 151) ((";") reduce 151) (("@") reduce 151) ((T_ABSTRACT) reduce 151) ((T_ARRAY) reduce 151) ((T_ARRAY_CAST) reduce 151) ((T_ATTRIBUTE) reduce 151) ((T_BOOL_CAST) reduce 151) ((T_BREAK) reduce 151) ((T_CLASS) reduce 151) ((T_CLASS_C) reduce 151) ((T_CLONE) reduce 151) ((T_CONSTANT_ENCAPSED_STRING) reduce 151) ((T_CONTINUE) reduce 151) ((T_DEC) reduce 151) ((T_DECLARE) reduce 151) ((T_DIR) reduce 151) ((T_DNUMBER) reduce 151) ((T_DO) reduce 151) ((T_DOUBLE_CAST) reduce 151) ((T_ECHO) reduce 151) ((T_ELSE) reduce 151) ((T_ELSEIF) reduce 151) ((T_EMPTY) reduce 151) ((T_ENDFOREACH) reduce 151) ((T_ENUM) reduce 151) ((T_EVAL) reduce 151) ((T_EXIT) reduce 151) ((T_FILE) reduce 151) ((T_FINAL) reduce 151) ((T_FN) reduce 151) ((T_FOR) reduce 151) ((T_FOREACH) reduce 151) ((T_FUNCTION) reduce 151) ((T_FUNC_C) reduce 151) ((T_GLOBAL) reduce 151) ((T_GOTO) reduce 151) ((T_HALT_COMPILER) reduce 151) ((T_IF) reduce 151) ((T_INC) reduce 151) ((T_INCLUDE) reduce 151) ((T_INCLUDE_ONCE) reduce 151) ((T_INLINE_HTML) reduce 151) ((T_INTERFACE) reduce 151) ((T_INT_CAST) reduce 151) ((T_ISSET) reduce 151) ((T_LINE) reduce 151) ((T_LIST) reduce 151) ((T_LNUMBER) reduce 151) ((T_MATCH) reduce 151) ((T_METHOD_C) reduce 151) ((T_NAME_FULLY_QUALIFIED) reduce 151) ((T_NAME_QUALIFIED) reduce 151) ((T_NAME_RELATIVE) reduce 151) ((T_NEW) reduce 151) ((T_NS_C) reduce 151) ((T_OBJECT_CAST) reduce 151) ((T_PRINT) reduce 151) ((T_READONLY) reduce 151) ((T_REQUIRE) reduce 151) ((T_REQUIRE_ONCE) reduce 151) ((T_RETURN) reduce 151) ((T_START_HEREDOC) reduce 151) ((T_STATIC) reduce 151) ((T_STRING) reduce 151) ((T_STRING_CAST) reduce 151) ((T_SWITCH) reduce 151) ((T_THROW) reduce 151) ((T_TRAIT) reduce 151) ((T_TRAIT_C) reduce 151) ((T_TRY) reduce 151) ((T_UNSET) reduce 151) ((T_UNSET_CAST) reduce 151) ((T_VARIABLE) reduce 151) ((T_WHILE) reduce 151) ((T_YIELD) reduce 151) ((T_YIELD_FROM) reduce 151) (("[") reduce 151) (("`") reduce 151) (("{") reduce 151) (("~") reduce 151)) 19515 ((("!") reduce 221) (("\"") reduce 221) (("$") reduce 221) (("(") reduce 221) (("+") reduce 221) (("-") reduce 221) ((";") reduce 221) (("@") reduce 221) ((T_ABSTRACT) reduce 221) ((T_ARRAY) reduce 221) ((T_ARRAY_CAST) reduce 221) ((T_ATTRIBUTE) reduce 221) ((T_BOOL_CAST) reduce 221) ((T_BREAK) reduce 221) ((T_CLASS) reduce 221) ((T_CLASS_C) reduce 221) ((T_CLONE) reduce 221) ((T_CONSTANT_ENCAPSED_STRING) reduce 221) ((T_CONTINUE) reduce 221) ((T_DEC) reduce 221) ((T_DECLARE) reduce 221) ((T_DIR) reduce 221) ((T_DNUMBER) reduce 221) ((T_DO) reduce 221) ((T_DOUBLE_CAST) reduce 221) ((T_ECHO) reduce 221) ((T_ELSE) reduce 221) ((T_ELSEIF) reduce 221) ((T_EMPTY) reduce 221) ((T_ENDFOREACH) reduce 221) ((T_ENUM) reduce 221) ((T_EVAL) reduce 221) ((T_EXIT) reduce 221) ((T_FILE) reduce 221) ((T_FINAL) reduce 221) ((T_FN) reduce 221) ((T_FOR) reduce 221) ((T_FOREACH) reduce 221) ((T_FUNCTION) reduce 221) ((T_FUNC_C) reduce 221) ((T_GLOBAL) reduce 221) ((T_GOTO) reduce 221) ((T_HALT_COMPILER) reduce 221) ((T_IF) reduce 221) ((T_INC) reduce 221) ((T_INCLUDE) reduce 221) ((T_INCLUDE_ONCE) reduce 221) ((T_INLINE_HTML) reduce 221) ((T_INTERFACE) reduce 221) ((T_INT_CAST) reduce 221) ((T_ISSET) reduce 221) ((T_LINE) reduce 221) ((T_LIST) reduce 221) ((T_LNUMBER) reduce 221) ((T_MATCH) reduce 221) ((T_METHOD_C) reduce 221) ((T_NAME_FULLY_QUALIFIED) reduce 221) ((T_NAME_QUALIFIED) reduce 221) ((T_NAME_RELATIVE) reduce 221) ((T_NEW) reduce 221) ((T_NS_C) reduce 221) ((T_OBJECT_CAST) reduce 221) ((T_PRINT) reduce 221) ((T_READONLY) reduce 221) ((T_REQUIRE) reduce 221) ((T_REQUIRE_ONCE) reduce 221) ((T_RETURN) reduce 221) ((T_START_HEREDOC) reduce 221) ((T_STATIC) reduce 221) ((T_STRING) reduce 221) ((T_STRING_CAST) reduce 221) ((T_SWITCH) reduce 221) ((T_THROW) reduce 221) ((T_TRAIT) reduce 221) ((T_TRAIT_C) reduce 221) ((T_TRY) reduce 221) ((T_UNSET) reduce 221) ((T_UNSET_CAST) reduce 221) ((T_VARIABLE) reduce 221) ((T_WHILE) reduce 221) ((T_YIELD) reduce 221) ((T_YIELD_FROM) reduce 221) (("[") reduce 221) (("`") reduce 221) (("{") reduce 221) (("~") reduce 221)) 19517 ((("!") reduce 222) (("\"") reduce 222) (("$") reduce 222) (("(") reduce 222) (("+") reduce 222) (("-") reduce 222) ((";") reduce 222) (("@") reduce 222) ((T_ABSTRACT) reduce 222) ((T_ARRAY) reduce 222) ((T_ARRAY_CAST) reduce 222) ((T_ATTRIBUTE) reduce 222) ((T_BOOL_CAST) reduce 222) ((T_BREAK) reduce 222) ((T_CLASS) reduce 222) ((T_CLASS_C) reduce 222) ((T_CLONE) reduce 222) ((T_CONSTANT_ENCAPSED_STRING) reduce 222) ((T_CONTINUE) reduce 222) ((T_DEC) reduce 222) ((T_DECLARE) reduce 222) ((T_DIR) reduce 222) ((T_DNUMBER) reduce 222) ((T_DO) reduce 222) ((T_DOUBLE_CAST) reduce 222) ((T_ECHO) reduce 222) ((T_ELSE) reduce 222) ((T_ELSEIF) reduce 222) ((T_EMPTY) reduce 222) ((T_ENDFOREACH) reduce 222) ((T_ENUM) reduce 222) ((T_EVAL) reduce 222) ((T_EXIT) reduce 222) ((T_FILE) reduce 222) ((T_FINAL) reduce 222) ((T_FN) reduce 222) ((T_FOR) reduce 222) ((T_FOREACH) reduce 222) ((T_FUNCTION) reduce 222) ((T_FUNC_C) reduce 222) ((T_GLOBAL) reduce 222) ((T_GOTO) reduce 222) ((T_HALT_COMPILER) reduce 222) ((T_IF) reduce 222) ((T_INC) reduce 222) ((T_INCLUDE) reduce 222) ((T_INCLUDE_ONCE) reduce 222) ((T_INLINE_HTML) reduce 222) ((T_INTERFACE) reduce 222) ((T_INT_CAST) reduce 222) ((T_ISSET) reduce 222) ((T_LINE) reduce 222) ((T_LIST) reduce 222) ((T_LNUMBER) reduce 222) ((T_MATCH) reduce 222) ((T_METHOD_C) reduce 222) ((T_NAME_FULLY_QUALIFIED) reduce 222) ((T_NAME_QUALIFIED) reduce 222) ((T_NAME_RELATIVE) reduce 222) ((T_NEW) reduce 222) ((T_NS_C) reduce 222) ((T_OBJECT_CAST) reduce 222) ((T_PRINT) reduce 222) ((T_READONLY) reduce 222) ((T_REQUIRE) reduce 222) ((T_REQUIRE_ONCE) reduce 222) ((T_RETURN) reduce 222) ((T_START_HEREDOC) reduce 222) ((T_STATIC) reduce 222) ((T_STRING) reduce 222) ((T_STRING_CAST) reduce 222) ((T_SWITCH) reduce 222) ((T_THROW) reduce 222) ((T_TRAIT) reduce 222) ((T_TRAIT_C) reduce 222) ((T_TRY) reduce 222) ((T_UNSET) reduce 222) ((T_UNSET_CAST) reduce 222) ((T_VARIABLE) reduce 222) ((T_WHILE) reduce 222) ((T_YIELD) reduce 222) ((T_YIELD_FROM) reduce 222) (("[") reduce 222) (("`") reduce 222) (("{") reduce 222) (("~") reduce 222)) 19521 ((("!") reduce 223) (("\"") reduce 223) (("$") reduce 223) (("(") reduce 223) (("+") reduce 223) (("-") reduce 223) ((";") reduce 223) (("@") reduce 223) ((T_ABSTRACT) reduce 223) ((T_ARRAY) reduce 223) ((T_ARRAY_CAST) reduce 223) ((T_ATTRIBUTE) reduce 223) ((T_BOOL_CAST) reduce 223) ((T_BREAK) reduce 223) ((T_CLASS) reduce 223) ((T_CLASS_C) reduce 223) ((T_CLONE) reduce 223) ((T_CONSTANT_ENCAPSED_STRING) reduce 223) ((T_CONTINUE) reduce 223) ((T_DEC) reduce 223) ((T_DECLARE) reduce 223) ((T_DIR) reduce 223) ((T_DNUMBER) reduce 223) ((T_DO) reduce 223) ((T_DOUBLE_CAST) reduce 223) ((T_ECHO) reduce 223) ((T_ELSE) reduce 223) ((T_ELSEIF) reduce 223) ((T_EMPTY) reduce 223) ((T_ENDFOREACH) reduce 223) ((T_ENUM) reduce 223) ((T_EVAL) reduce 223) ((T_EXIT) reduce 223) ((T_FILE) reduce 223) ((T_FINAL) reduce 223) ((T_FN) reduce 223) ((T_FOR) reduce 223) ((T_FOREACH) reduce 223) ((T_FUNCTION) reduce 223) ((T_FUNC_C) reduce 223) ((T_GLOBAL) reduce 223) ((T_GOTO) reduce 223) ((T_HALT_COMPILER) reduce 223) ((T_IF) reduce 223) ((T_INC) reduce 223) ((T_INCLUDE) reduce 223) ((T_INCLUDE_ONCE) reduce 223) ((T_INLINE_HTML) reduce 223) ((T_INTERFACE) reduce 223) ((T_INT_CAST) reduce 223) ((T_ISSET) reduce 223) ((T_LINE) reduce 223) ((T_LIST) reduce 223) ((T_LNUMBER) reduce 223) ((T_MATCH) reduce 223) ((T_METHOD_C) reduce 223) ((T_NAME_FULLY_QUALIFIED) reduce 223) ((T_NAME_QUALIFIED) reduce 223) ((T_NAME_RELATIVE) reduce 223) ((T_NEW) reduce 223) ((T_NS_C) reduce 223) ((T_OBJECT_CAST) reduce 223) ((T_PRINT) reduce 223) ((T_READONLY) reduce 223) ((T_REQUIRE) reduce 223) ((T_REQUIRE_ONCE) reduce 223) ((T_RETURN) reduce 223) ((T_START_HEREDOC) reduce 223) ((T_STATIC) reduce 223) ((T_STRING) reduce 223) ((T_STRING_CAST) reduce 223) ((T_SWITCH) reduce 223) ((T_THROW) reduce 223) ((T_TRAIT) reduce 223) ((T_TRAIT_C) reduce 223) ((T_TRY) reduce 223) ((T_UNSET) reduce 223) ((T_UNSET_CAST) reduce 223) ((T_VARIABLE) reduce 223) ((T_WHILE) reduce 223) ((T_YIELD) reduce 223) ((T_YIELD_FROM) reduce 223) (("[") reduce 223) (("`") reduce 223) (("{") reduce 223) (("~") reduce 223)) 19524 ((("!") reduce 224) (("\"") reduce 224) (("$") reduce 224) (("(") reduce 224) (("+") reduce 224) (("-") reduce 224) ((";") reduce 224) (("@") reduce 224) ((T_ABSTRACT) reduce 224) ((T_ARRAY) reduce 224) ((T_ARRAY_CAST) reduce 224) ((T_ATTRIBUTE) reduce 224) ((T_BOOL_CAST) reduce 224) ((T_BREAK) reduce 224) ((T_CLASS) reduce 224) ((T_CLASS_C) reduce 224) ((T_CLONE) reduce 224) ((T_CONSTANT_ENCAPSED_STRING) reduce 224) ((T_CONTINUE) reduce 224) ((T_DEC) reduce 224) ((T_DECLARE) reduce 224) ((T_DIR) reduce 224) ((T_DNUMBER) reduce 224) ((T_DO) reduce 224) ((T_DOUBLE_CAST) reduce 224) ((T_ECHO) reduce 224) ((T_ELSE) reduce 224) ((T_ELSEIF) reduce 224) ((T_EMPTY) reduce 224) ((T_ENDFOREACH) reduce 224) ((T_ENUM) reduce 224) ((T_EVAL) reduce 224) ((T_EXIT) reduce 224) ((T_FILE) reduce 224) ((T_FINAL) reduce 224) ((T_FN) reduce 224) ((T_FOR) reduce 224) ((T_FOREACH) reduce 224) ((T_FUNCTION) reduce 224) ((T_FUNC_C) reduce 224) ((T_GLOBAL) reduce 224) ((T_GOTO) reduce 224) ((T_HALT_COMPILER) reduce 224) ((T_IF) reduce 224) ((T_INC) reduce 224) ((T_INCLUDE) reduce 224) ((T_INCLUDE_ONCE) reduce 224) ((T_INLINE_HTML) reduce 224) ((T_INTERFACE) reduce 224) ((T_INT_CAST) reduce 224) ((T_ISSET) reduce 224) ((T_LINE) reduce 224) ((T_LIST) reduce 224) ((T_LNUMBER) reduce 224) ((T_MATCH) reduce 224) ((T_METHOD_C) reduce 224) ((T_NAME_FULLY_QUALIFIED) reduce 224) ((T_NAME_QUALIFIED) reduce 224) ((T_NAME_RELATIVE) reduce 224) ((T_NEW) reduce 224) ((T_NS_C) reduce 224) ((T_OBJECT_CAST) reduce 224) ((T_PRINT) reduce 224) ((T_READONLY) reduce 224) ((T_REQUIRE) reduce 224) ((T_REQUIRE_ONCE) reduce 224) ((T_RETURN) reduce 224) ((T_START_HEREDOC) reduce 224) ((T_STATIC) reduce 224) ((T_STRING) reduce 224) ((T_STRING_CAST) reduce 224) ((T_SWITCH) reduce 224) ((T_THROW) reduce 224) ((T_TRAIT) reduce 224) ((T_TRAIT_C) reduce 224) ((T_TRY) reduce 224) ((T_UNSET) reduce 224) ((T_UNSET_CAST) reduce 224) ((T_VARIABLE) reduce 224) ((T_WHILE) reduce 224) ((T_YIELD) reduce 224) ((T_YIELD_FROM) reduce 224) (("[") reduce 224) (("`") reduce 224) (("{") reduce 224) (("~") reduce 224)) 19525 ((("!") reduce 167) (("\"") reduce 167) (("$") reduce 167) (("(") reduce 167) (("+") reduce 167) (("-") reduce 167) ((";") reduce 167) (("@") reduce 167) ((T_ABSTRACT) reduce 167) ((T_ARRAY) reduce 167) ((T_ARRAY_CAST) reduce 167) ((T_ATTRIBUTE) reduce 167) ((T_BOOL_CAST) reduce 167) ((T_BREAK) reduce 167) ((T_CLASS) reduce 167) ((T_CLASS_C) reduce 167) ((T_CLONE) reduce 167) ((T_CONSTANT_ENCAPSED_STRING) reduce 167) ((T_CONTINUE) reduce 167) ((T_DEC) reduce 167) ((T_DECLARE) reduce 167) ((T_DIR) reduce 167) ((T_DNUMBER) reduce 167) ((T_DO) reduce 167) ((T_DOUBLE_CAST) reduce 167) ((T_ECHO) reduce 167) ((T_ELSE) reduce 167) ((T_ELSEIF) reduce 167) ((T_EMPTY) reduce 167) ((T_ENDFOREACH) reduce 167) ((T_ENUM) reduce 167) ((T_EVAL) reduce 167) ((T_EXIT) reduce 167) ((T_FILE) reduce 167) ((T_FINAL) reduce 167) ((T_FN) reduce 167) ((T_FOR) reduce 167) ((T_FOREACH) reduce 167) ((T_FUNCTION) reduce 167) ((T_FUNC_C) reduce 167) ((T_GLOBAL) reduce 167) ((T_GOTO) reduce 167) ((T_HALT_COMPILER) reduce 167) ((T_IF) reduce 167) ((T_INC) reduce 167) ((T_INCLUDE) reduce 167) ((T_INCLUDE_ONCE) reduce 167) ((T_INLINE_HTML) reduce 167) ((T_INTERFACE) reduce 167) ((T_INT_CAST) reduce 167) ((T_ISSET) reduce 167) ((T_LINE) reduce 167) ((T_LIST) reduce 167) ((T_LNUMBER) reduce 167) ((T_MATCH) reduce 167) ((T_METHOD_C) reduce 167) ((T_NAME_FULLY_QUALIFIED) reduce 167) ((T_NAME_QUALIFIED) reduce 167) ((T_NAME_RELATIVE) reduce 167) ((T_NEW) reduce 167) ((T_NS_C) reduce 167) ((T_OBJECT_CAST) reduce 167) ((T_PRINT) reduce 167) ((T_READONLY) reduce 167) ((T_REQUIRE) reduce 167) ((T_REQUIRE_ONCE) reduce 167) ((T_RETURN) reduce 167) ((T_START_HEREDOC) reduce 167) ((T_STATIC) reduce 167) ((T_STRING) reduce 167) ((T_STRING_CAST) reduce 167) ((T_SWITCH) reduce 167) ((T_THROW) reduce 167) ((T_TRAIT) reduce 167) ((T_TRAIT_C) reduce 167) ((T_TRY) reduce 167) ((T_UNSET) reduce 167) ((T_UNSET_CAST) reduce 167) ((T_VARIABLE) reduce 167) ((T_WHILE) reduce 167) ((T_YIELD) reduce 167) ((T_YIELD_FROM) reduce 167) (("[") reduce 167) (("`") reduce 167) (("{") reduce 167) (("~") reduce 167)) 19527 ((("!") reduce 156) (("\"") reduce 156) (("$") reduce 156) (("(") reduce 156) (("+") reduce 156) (("-") reduce 156) ((";") reduce 156) (("@") reduce 156) ((T_ABSTRACT) reduce 156) ((T_ARRAY) reduce 156) ((T_ARRAY_CAST) reduce 156) ((T_ATTRIBUTE) reduce 156) ((T_BOOL_CAST) reduce 156) ((T_BREAK) reduce 156) ((T_CLASS) reduce 156) ((T_CLASS_C) reduce 156) ((T_CLONE) reduce 156) ((T_CONSTANT_ENCAPSED_STRING) reduce 156) ((T_CONTINUE) reduce 156) ((T_DEC) reduce 156) ((T_DECLARE) reduce 156) ((T_DIR) reduce 156) ((T_DNUMBER) reduce 156) ((T_DO) reduce 156) ((T_DOUBLE_CAST) reduce 156) ((T_ECHO) reduce 156) ((T_ELSE) reduce 156) ((T_ELSEIF) reduce 156) ((T_EMPTY) reduce 156) ((T_ENDFOREACH) reduce 156) ((T_ENUM) reduce 156) ((T_EVAL) reduce 156) ((T_EXIT) reduce 156) ((T_FILE) reduce 156) ((T_FINAL) reduce 156) ((T_FN) reduce 156) ((T_FOR) reduce 156) ((T_FOREACH) reduce 156) ((T_FUNCTION) reduce 156) ((T_FUNC_C) reduce 156) ((T_GLOBAL) reduce 156) ((T_GOTO) reduce 156) ((T_HALT_COMPILER) reduce 156) ((T_IF) reduce 156) ((T_INC) reduce 156) ((T_INCLUDE) reduce 156) ((T_INCLUDE_ONCE) reduce 156) ((T_INLINE_HTML) reduce 156) ((T_INTERFACE) reduce 156) ((T_INT_CAST) reduce 156) ((T_ISSET) reduce 156) ((T_LINE) reduce 156) ((T_LIST) reduce 156) ((T_LNUMBER) reduce 156) ((T_MATCH) reduce 156) ((T_METHOD_C) reduce 156) ((T_NAME_FULLY_QUALIFIED) reduce 156) ((T_NAME_QUALIFIED) reduce 156) ((T_NAME_RELATIVE) reduce 156) ((T_NEW) reduce 156) ((T_NS_C) reduce 156) ((T_OBJECT_CAST) reduce 156) ((T_PRINT) reduce 156) ((T_READONLY) reduce 156) ((T_REQUIRE) reduce 156) ((T_REQUIRE_ONCE) reduce 156) ((T_RETURN) reduce 156) ((T_START_HEREDOC) reduce 156) ((T_STATIC) reduce 156) ((T_STRING) reduce 156) ((T_STRING_CAST) reduce 156) ((T_SWITCH) reduce 156) ((T_THROW) reduce 156) ((T_TRAIT) reduce 156) ((T_TRAIT_C) reduce 156) ((T_TRY) reduce 156) ((T_UNSET) reduce 156) ((T_UNSET_CAST) reduce 156) ((T_VARIABLE) reduce 156) ((T_WHILE) reduce 156) ((T_YIELD) reduce 156) ((T_YIELD_FROM) reduce 156) (("[") reduce 156) (("`") reduce 156) (("{") reduce 156) (("~") reduce 156)) 19529 ((("!") reduce 154) (("\"") reduce 154) (("$") reduce 154) (("(") reduce 154) (("+") reduce 154) (("-") reduce 154) ((";") reduce 154) (("@") reduce 154) ((T_ABSTRACT) reduce 154) ((T_ARRAY) reduce 154) ((T_ARRAY_CAST) reduce 154) ((T_ATTRIBUTE) reduce 154) ((T_BOOL_CAST) reduce 154) ((T_BREAK) reduce 154) ((T_CLASS) reduce 154) ((T_CLASS_C) reduce 154) ((T_CLONE) reduce 154) ((T_CONSTANT_ENCAPSED_STRING) reduce 154) ((T_CONTINUE) reduce 154) ((T_DEC) reduce 154) ((T_DECLARE) reduce 154) ((T_DIR) reduce 154) ((T_DNUMBER) reduce 154) ((T_DO) reduce 154) ((T_DOUBLE_CAST) reduce 154) ((T_ECHO) reduce 154) ((T_ELSE) reduce 154) ((T_ELSEIF) reduce 154) ((T_EMPTY) reduce 154) ((T_ENDFOREACH) reduce 154) ((T_ENUM) reduce 154) ((T_EVAL) reduce 154) ((T_EXIT) reduce 154) ((T_FILE) reduce 154) ((T_FINAL) reduce 154) ((T_FN) reduce 154) ((T_FOR) reduce 154) ((T_FOREACH) reduce 154) ((T_FUNCTION) reduce 154) ((T_FUNC_C) reduce 154) ((T_GLOBAL) reduce 154) ((T_GOTO) reduce 154) ((T_HALT_COMPILER) reduce 154) ((T_IF) reduce 154) ((T_INC) reduce 154) ((T_INCLUDE) reduce 154) ((T_INCLUDE_ONCE) reduce 154) ((T_INLINE_HTML) reduce 154) ((T_INTERFACE) reduce 154) ((T_INT_CAST) reduce 154) ((T_ISSET) reduce 154) ((T_LINE) reduce 154) ((T_LIST) reduce 154) ((T_LNUMBER) reduce 154) ((T_MATCH) reduce 154) ((T_METHOD_C) reduce 154) ((T_NAME_FULLY_QUALIFIED) reduce 154) ((T_NAME_QUALIFIED) reduce 154) ((T_NAME_RELATIVE) reduce 154) ((T_NEW) reduce 154) ((T_NS_C) reduce 154) ((T_OBJECT_CAST) reduce 154) ((T_PRINT) reduce 154) ((T_READONLY) reduce 154) ((T_REQUIRE) reduce 154) ((T_REQUIRE_ONCE) reduce 154) ((T_RETURN) reduce 154) ((T_START_HEREDOC) reduce 154) ((T_STATIC) reduce 154) ((T_STRING) reduce 154) ((T_STRING_CAST) reduce 154) ((T_SWITCH) reduce 154) ((T_THROW) reduce 154) ((T_TRAIT) reduce 154) ((T_TRAIT_C) reduce 154) ((T_TRY) reduce 154) ((T_UNSET) reduce 154) ((T_UNSET_CAST) reduce 154) ((T_VARIABLE) reduce 154) ((T_WHILE) reduce 154) ((T_YIELD) reduce 154) ((T_YIELD_FROM) reduce 154) (("[") reduce 154) (("`") reduce 154) (("{") reduce 154) (("~") reduce 154)) 19531 ((("!") reduce 166) (("\"") reduce 166) (("$") reduce 166) (("(") reduce 166) (("+") reduce 166) (("-") reduce 166) ((";") reduce 166) (("@") reduce 166) ((T_ABSTRACT) reduce 166) ((T_ARRAY) reduce 166) ((T_ARRAY_CAST) reduce 166) ((T_ATTRIBUTE) reduce 166) ((T_BOOL_CAST) reduce 166) ((T_BREAK) reduce 166) ((T_CLASS) reduce 166) ((T_CLASS_C) reduce 166) ((T_CLONE) reduce 166) ((T_CONSTANT_ENCAPSED_STRING) reduce 166) ((T_CONTINUE) reduce 166) ((T_DEC) reduce 166) ((T_DECLARE) reduce 166) ((T_DIR) reduce 166) ((T_DNUMBER) reduce 166) ((T_DO) reduce 166) ((T_DOUBLE_CAST) reduce 166) ((T_ECHO) reduce 166) ((T_ELSE) reduce 166) ((T_ELSEIF) reduce 166) ((T_EMPTY) reduce 166) ((T_ENDFOREACH) reduce 166) ((T_ENUM) reduce 166) ((T_EVAL) reduce 166) ((T_EXIT) reduce 166) ((T_FILE) reduce 166) ((T_FINAL) reduce 166) ((T_FN) reduce 166) ((T_FOR) reduce 166) ((T_FOREACH) reduce 166) ((T_FUNCTION) reduce 166) ((T_FUNC_C) reduce 166) ((T_GLOBAL) reduce 166) ((T_GOTO) reduce 166) ((T_HALT_COMPILER) reduce 166) ((T_IF) reduce 166) ((T_INC) reduce 166) ((T_INCLUDE) reduce 166) ((T_INCLUDE_ONCE) reduce 166) ((T_INLINE_HTML) reduce 166) ((T_INTERFACE) reduce 166) ((T_INT_CAST) reduce 166) ((T_ISSET) reduce 166) ((T_LINE) reduce 166) ((T_LIST) reduce 166) ((T_LNUMBER) reduce 166) ((T_MATCH) reduce 166) ((T_METHOD_C) reduce 166) ((T_NAME_FULLY_QUALIFIED) reduce 166) ((T_NAME_QUALIFIED) reduce 166) ((T_NAME_RELATIVE) reduce 166) ((T_NEW) reduce 166) ((T_NS_C) reduce 166) ((T_OBJECT_CAST) reduce 166) ((T_PRINT) reduce 166) ((T_READONLY) reduce 166) ((T_REQUIRE) reduce 166) ((T_REQUIRE_ONCE) reduce 166) ((T_RETURN) reduce 166) ((T_START_HEREDOC) reduce 166) ((T_STATIC) reduce 166) ((T_STRING) reduce 166) ((T_STRING_CAST) reduce 166) ((T_SWITCH) reduce 166) ((T_THROW) reduce 166) ((T_TRAIT) reduce 166) ((T_TRAIT_C) reduce 166) ((T_TRY) reduce 166) ((T_UNSET) reduce 166) ((T_UNSET_CAST) reduce 166) ((T_VARIABLE) reduce 166) ((T_WHILE) reduce 166) ((T_YIELD) reduce 166) ((T_YIELD_FROM) reduce 166) (("[") reduce 166) (("`") reduce 166) (("{") reduce 166) (("~") reduce 166)) 19533 ((("!") reduce 155) (("\"") reduce 155) (("$") reduce 155) (("(") reduce 155) (("+") reduce 155) (("-") reduce 155) ((";") reduce 155) (("@") reduce 155) ((T_ABSTRACT) reduce 155) ((T_ARRAY) reduce 155) ((T_ARRAY_CAST) reduce 155) ((T_ATTRIBUTE) reduce 155) ((T_BOOL_CAST) reduce 155) ((T_BREAK) reduce 155) ((T_CLASS) reduce 155) ((T_CLASS_C) reduce 155) ((T_CLONE) reduce 155) ((T_CONSTANT_ENCAPSED_STRING) reduce 155) ((T_CONTINUE) reduce 155) ((T_DEC) reduce 155) ((T_DECLARE) reduce 155) ((T_DIR) reduce 155) ((T_DNUMBER) reduce 155) ((T_DO) reduce 155) ((T_DOUBLE_CAST) reduce 155) ((T_ECHO) reduce 155) ((T_ELSE) reduce 155) ((T_ELSEIF) reduce 155) ((T_EMPTY) reduce 155) ((T_ENDFOREACH) reduce 155) ((T_ENUM) reduce 155) ((T_EVAL) reduce 155) ((T_EXIT) reduce 155) ((T_FILE) reduce 155) ((T_FINAL) reduce 155) ((T_FN) reduce 155) ((T_FOR) reduce 155) ((T_FOREACH) reduce 155) ((T_FUNCTION) reduce 155) ((T_FUNC_C) reduce 155) ((T_GLOBAL) reduce 155) ((T_GOTO) reduce 155) ((T_HALT_COMPILER) reduce 155) ((T_IF) reduce 155) ((T_INC) reduce 155) ((T_INCLUDE) reduce 155) ((T_INCLUDE_ONCE) reduce 155) ((T_INLINE_HTML) reduce 155) ((T_INTERFACE) reduce 155) ((T_INT_CAST) reduce 155) ((T_ISSET) reduce 155) ((T_LINE) reduce 155) ((T_LIST) reduce 155) ((T_LNUMBER) reduce 155) ((T_MATCH) reduce 155) ((T_METHOD_C) reduce 155) ((T_NAME_FULLY_QUALIFIED) reduce 155) ((T_NAME_QUALIFIED) reduce 155) ((T_NAME_RELATIVE) reduce 155) ((T_NEW) reduce 155) ((T_NS_C) reduce 155) ((T_OBJECT_CAST) reduce 155) ((T_PRINT) reduce 155) ((T_READONLY) reduce 155) ((T_REQUIRE) reduce 155) ((T_REQUIRE_ONCE) reduce 155) ((T_RETURN) reduce 155) ((T_START_HEREDOC) reduce 155) ((T_STATIC) reduce 155) ((T_STRING) reduce 155) ((T_STRING_CAST) reduce 155) ((T_SWITCH) reduce 155) ((T_THROW) reduce 155) ((T_TRAIT) reduce 155) ((T_TRAIT_C) reduce 155) ((T_TRY) reduce 155) ((T_UNSET) reduce 155) ((T_UNSET_CAST) reduce 155) ((T_VARIABLE) reduce 155) ((T_WHILE) reduce 155) ((T_YIELD) reduce 155) ((T_YIELD_FROM) reduce 155) (("[") reduce 155) (("`") reduce 155) (("{") reduce 155) (("~") reduce 155)) 19543 ((("!") reduce 162) (("\"") reduce 162) (("$") reduce 162) (("(") reduce 162) (("+") reduce 162) (("-") reduce 162) ((";") reduce 162) (("@") reduce 162) ((T_ABSTRACT) reduce 162) ((T_ARRAY) reduce 162) ((T_ARRAY_CAST) reduce 162) ((T_ATTRIBUTE) reduce 162) ((T_BOOL_CAST) reduce 162) ((T_BREAK) reduce 162) ((T_CLASS) reduce 162) ((T_CLASS_C) reduce 162) ((T_CLONE) reduce 162) ((T_CONSTANT_ENCAPSED_STRING) reduce 162) ((T_CONTINUE) reduce 162) ((T_DEC) reduce 162) ((T_DECLARE) reduce 162) ((T_DIR) reduce 162) ((T_DNUMBER) reduce 162) ((T_DO) reduce 162) ((T_DOUBLE_CAST) reduce 162) ((T_ECHO) reduce 162) ((T_ELSE) reduce 162) ((T_ELSEIF) reduce 162) ((T_EMPTY) reduce 162) ((T_ENDFOREACH) reduce 162) ((T_ENUM) reduce 162) ((T_EVAL) reduce 162) ((T_EXIT) reduce 162) ((T_FILE) reduce 162) ((T_FINAL) reduce 162) ((T_FN) reduce 162) ((T_FOR) reduce 162) ((T_FOREACH) reduce 162) ((T_FUNCTION) reduce 162) ((T_FUNC_C) reduce 162) ((T_GLOBAL) reduce 162) ((T_GOTO) reduce 162) ((T_HALT_COMPILER) reduce 162) ((T_IF) reduce 162) ((T_INC) reduce 162) ((T_INCLUDE) reduce 162) ((T_INCLUDE_ONCE) reduce 162) ((T_INLINE_HTML) reduce 162) ((T_INTERFACE) reduce 162) ((T_INT_CAST) reduce 162) ((T_ISSET) reduce 162) ((T_LINE) reduce 162) ((T_LIST) reduce 162) ((T_LNUMBER) reduce 162) ((T_MATCH) reduce 162) ((T_METHOD_C) reduce 162) ((T_NAME_FULLY_QUALIFIED) reduce 162) ((T_NAME_QUALIFIED) reduce 162) ((T_NAME_RELATIVE) reduce 162) ((T_NEW) reduce 162) ((T_NS_C) reduce 162) ((T_OBJECT_CAST) reduce 162) ((T_PRINT) reduce 162) ((T_READONLY) reduce 162) ((T_REQUIRE) reduce 162) ((T_REQUIRE_ONCE) reduce 162) ((T_RETURN) reduce 162) ((T_START_HEREDOC) reduce 162) ((T_STATIC) reduce 162) ((T_STRING) reduce 162) ((T_STRING_CAST) reduce 162) ((T_SWITCH) reduce 162) ((T_THROW) reduce 162) ((T_TRAIT) reduce 162) ((T_TRAIT_C) reduce 162) ((T_TRY) reduce 162) ((T_UNSET) reduce 162) ((T_UNSET_CAST) reduce 162) ((T_VARIABLE) reduce 162) ((T_WHILE) reduce 162) ((T_YIELD) reduce 162) ((T_YIELD_FROM) reduce 162) (("[") reduce 162) (("`") reduce 162) (("{") reduce 162) (("~") reduce 162)) 19544 ((("!") reduce 217) (("\"") reduce 217) (("$") reduce 217) (("(") reduce 217) (("+") reduce 217) (("-") reduce 217) ((";") reduce 217) (("@") reduce 217) ((T_ABSTRACT) reduce 217) ((T_ARRAY) reduce 217) ((T_ARRAY_CAST) reduce 217) ((T_ATTRIBUTE) reduce 217) ((T_BOOL_CAST) reduce 217) ((T_BREAK) reduce 217) ((T_CLASS) reduce 217) ((T_CLASS_C) reduce 217) ((T_CLONE) reduce 217) ((T_CONSTANT_ENCAPSED_STRING) reduce 217) ((T_CONTINUE) reduce 217) ((T_DEC) reduce 217) ((T_DECLARE) reduce 217) ((T_DIR) reduce 217) ((T_DNUMBER) reduce 217) ((T_DO) reduce 217) ((T_DOUBLE_CAST) reduce 217) ((T_ECHO) reduce 217) ((T_ELSE) reduce 217) ((T_ELSEIF) reduce 217) ((T_EMPTY) reduce 217) ((T_ENDFOREACH) reduce 217) ((T_ENUM) reduce 217) ((T_EVAL) reduce 217) ((T_EXIT) reduce 217) ((T_FILE) reduce 217) ((T_FINAL) reduce 217) ((T_FN) reduce 217) ((T_FOR) reduce 217) ((T_FOREACH) reduce 217) ((T_FUNCTION) reduce 217) ((T_FUNC_C) reduce 217) ((T_GLOBAL) reduce 217) ((T_GOTO) reduce 217) ((T_HALT_COMPILER) reduce 217) ((T_IF) reduce 217) ((T_INC) reduce 217) ((T_INCLUDE) reduce 217) ((T_INCLUDE_ONCE) reduce 217) ((T_INLINE_HTML) reduce 217) ((T_INTERFACE) reduce 217) ((T_INT_CAST) reduce 217) ((T_ISSET) reduce 217) ((T_LINE) reduce 217) ((T_LIST) reduce 217) ((T_LNUMBER) reduce 217) ((T_MATCH) reduce 217) ((T_METHOD_C) reduce 217) ((T_NAME_FULLY_QUALIFIED) reduce 217) ((T_NAME_QUALIFIED) reduce 217) ((T_NAME_RELATIVE) reduce 217) ((T_NEW) reduce 217) ((T_NS_C) reduce 217) ((T_OBJECT_CAST) reduce 217) ((T_PRINT) reduce 217) ((T_READONLY) reduce 217) ((T_REQUIRE) reduce 217) ((T_REQUIRE_ONCE) reduce 217) ((T_RETURN) reduce 217) ((T_START_HEREDOC) reduce 217) ((T_STATIC) reduce 217) ((T_STRING) reduce 217) ((T_STRING_CAST) reduce 217) ((T_SWITCH) reduce 217) ((T_THROW) reduce 217) ((T_TRAIT) reduce 217) ((T_TRAIT_C) reduce 217) ((T_TRY) reduce 217) ((T_UNSET) reduce 217) ((T_UNSET_CAST) reduce 217) ((T_VARIABLE) reduce 217) ((T_WHILE) reduce 217) ((T_YIELD) reduce 217) ((T_YIELD_FROM) reduce 217) (("[") reduce 217) (("`") reduce 217) (("{") reduce 217) (("~") reduce 217)) 19547 ((("!") reduce 218) (("\"") reduce 218) (("$") reduce 218) (("(") reduce 218) (("+") reduce 218) (("-") reduce 218) ((";") reduce 218) (("@") reduce 218) ((T_ABSTRACT) reduce 218) ((T_ARRAY) reduce 218) ((T_ARRAY_CAST) reduce 218) ((T_ATTRIBUTE) reduce 218) ((T_BOOL_CAST) reduce 218) ((T_BREAK) reduce 218) ((T_CLASS) reduce 218) ((T_CLASS_C) reduce 218) ((T_CLONE) reduce 218) ((T_CONSTANT_ENCAPSED_STRING) reduce 218) ((T_CONTINUE) reduce 218) ((T_DEC) reduce 218) ((T_DECLARE) reduce 218) ((T_DIR) reduce 218) ((T_DNUMBER) reduce 218) ((T_DO) reduce 218) ((T_DOUBLE_CAST) reduce 218) ((T_ECHO) reduce 218) ((T_ELSE) reduce 218) ((T_ELSEIF) reduce 218) ((T_EMPTY) reduce 218) ((T_ENDFOREACH) reduce 218) ((T_ENUM) reduce 218) ((T_EVAL) reduce 218) ((T_EXIT) reduce 218) ((T_FILE) reduce 218) ((T_FINAL) reduce 218) ((T_FN) reduce 218) ((T_FOR) reduce 218) ((T_FOREACH) reduce 218) ((T_FUNCTION) reduce 218) ((T_FUNC_C) reduce 218) ((T_GLOBAL) reduce 218) ((T_GOTO) reduce 218) ((T_HALT_COMPILER) reduce 218) ((T_IF) reduce 218) ((T_INC) reduce 218) ((T_INCLUDE) reduce 218) ((T_INCLUDE_ONCE) reduce 218) ((T_INLINE_HTML) reduce 218) ((T_INTERFACE) reduce 218) ((T_INT_CAST) reduce 218) ((T_ISSET) reduce 218) ((T_LINE) reduce 218) ((T_LIST) reduce 218) ((T_LNUMBER) reduce 218) ((T_MATCH) reduce 218) ((T_METHOD_C) reduce 218) ((T_NAME_FULLY_QUALIFIED) reduce 218) ((T_NAME_QUALIFIED) reduce 218) ((T_NAME_RELATIVE) reduce 218) ((T_NEW) reduce 218) ((T_NS_C) reduce 218) ((T_OBJECT_CAST) reduce 218) ((T_PRINT) reduce 218) ((T_READONLY) reduce 218) ((T_REQUIRE) reduce 218) ((T_REQUIRE_ONCE) reduce 218) ((T_RETURN) reduce 218) ((T_START_HEREDOC) reduce 218) ((T_STATIC) reduce 218) ((T_STRING) reduce 218) ((T_STRING_CAST) reduce 218) ((T_SWITCH) reduce 218) ((T_THROW) reduce 218) ((T_TRAIT) reduce 218) ((T_TRAIT_C) reduce 218) ((T_TRY) reduce 218) ((T_UNSET) reduce 218) ((T_UNSET_CAST) reduce 218) ((T_VARIABLE) reduce 218) ((T_WHILE) reduce 218) ((T_YIELD) reduce 218) ((T_YIELD_FROM) reduce 218) (("[") reduce 218) (("`") reduce 218) (("{") reduce 218) (("~") reduce 218)) 19548 ((("!") reduce 161) (("\"") reduce 161) (("$") reduce 161) (("(") reduce 161) (("+") reduce 161) (("-") reduce 161) ((";") reduce 161) (("@") reduce 161) ((T_ABSTRACT) reduce 161) ((T_ARRAY) reduce 161) ((T_ARRAY_CAST) reduce 161) ((T_ATTRIBUTE) reduce 161) ((T_BOOL_CAST) reduce 161) ((T_BREAK) reduce 161) ((T_CLASS) reduce 161) ((T_CLASS_C) reduce 161) ((T_CLONE) reduce 161) ((T_CONSTANT_ENCAPSED_STRING) reduce 161) ((T_CONTINUE) reduce 161) ((T_DEC) reduce 161) ((T_DECLARE) reduce 161) ((T_DIR) reduce 161) ((T_DNUMBER) reduce 161) ((T_DO) reduce 161) ((T_DOUBLE_CAST) reduce 161) ((T_ECHO) reduce 161) ((T_ELSE) reduce 161) ((T_ELSEIF) reduce 161) ((T_EMPTY) reduce 161) ((T_ENDFOREACH) reduce 161) ((T_ENUM) reduce 161) ((T_EVAL) reduce 161) ((T_EXIT) reduce 161) ((T_FILE) reduce 161) ((T_FINAL) reduce 161) ((T_FN) reduce 161) ((T_FOR) reduce 161) ((T_FOREACH) reduce 161) ((T_FUNCTION) reduce 161) ((T_FUNC_C) reduce 161) ((T_GLOBAL) reduce 161) ((T_GOTO) reduce 161) ((T_HALT_COMPILER) reduce 161) ((T_IF) reduce 161) ((T_INC) reduce 161) ((T_INCLUDE) reduce 161) ((T_INCLUDE_ONCE) reduce 161) ((T_INLINE_HTML) reduce 161) ((T_INTERFACE) reduce 161) ((T_INT_CAST) reduce 161) ((T_ISSET) reduce 161) ((T_LINE) reduce 161) ((T_LIST) reduce 161) ((T_LNUMBER) reduce 161) ((T_MATCH) reduce 161) ((T_METHOD_C) reduce 161) ((T_NAME_FULLY_QUALIFIED) reduce 161) ((T_NAME_QUALIFIED) reduce 161) ((T_NAME_RELATIVE) reduce 161) ((T_NEW) reduce 161) ((T_NS_C) reduce 161) ((T_OBJECT_CAST) reduce 161) ((T_PRINT) reduce 161) ((T_READONLY) reduce 161) ((T_REQUIRE) reduce 161) ((T_REQUIRE_ONCE) reduce 161) ((T_RETURN) reduce 161) ((T_START_HEREDOC) reduce 161) ((T_STATIC) reduce 161) ((T_STRING) reduce 161) ((T_STRING_CAST) reduce 161) ((T_SWITCH) reduce 161) ((T_THROW) reduce 161) ((T_TRAIT) reduce 161) ((T_TRAIT_C) reduce 161) ((T_TRY) reduce 161) ((T_UNSET) reduce 161) ((T_UNSET_CAST) reduce 161) ((T_VARIABLE) reduce 161) ((T_WHILE) reduce 161) ((T_YIELD) reduce 161) ((T_YIELD_FROM) reduce 161) (("[") reduce 161) (("`") reduce 161) (("{") reduce 161) (("~") reduce 161)) 19549 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) (("+") shift) (("-") shift) ((";") reduce 359) (("@") shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("~") shift)) 19550 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 362) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 362) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 19552 (((",") shift) ((";") reduce 360)) 19554 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 361) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 361) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 19557 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) ((")") reduce 359) (("+") shift) (("-") shift) (("@") shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("~") shift)) 19558 ((("%") shift) ((")") reduce 362) (("*") shift) (("+") shift) ((",") reduce 362) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 19560 (((")") reduce 360) ((",") shift)) 19562 ((("%") shift) ((")") reduce 361) (("*") shift) (("+") shift) ((",") reduce 361) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 19564 ((("!") reduce 140) (("\"") reduce 140) (("$") reduce 140) (("(") reduce 140) (("+") reduce 140) (("-") reduce 140) ((";") reduce 140) (("@") reduce 140) ((T_ABSTRACT) reduce 140) ((T_ARRAY) reduce 140) ((T_ARRAY_CAST) reduce 140) ((T_ATTRIBUTE) reduce 140) ((T_BOOL_CAST) reduce 140) ((T_BREAK) reduce 140) ((T_CLASS) reduce 140) ((T_CLASS_C) reduce 140) ((T_CLONE) reduce 140) ((T_CONSTANT_ENCAPSED_STRING) reduce 140) ((T_CONTINUE) reduce 140) ((T_DEC) reduce 140) ((T_DECLARE) reduce 140) ((T_DIR) reduce 140) ((T_DNUMBER) reduce 140) ((T_DO) reduce 140) ((T_DOUBLE_CAST) reduce 140) ((T_ECHO) reduce 140) ((T_EMPTY) reduce 140) ((T_ENDFOR) reduce 140) ((T_ENUM) reduce 140) ((T_EVAL) reduce 140) ((T_EXIT) reduce 140) ((T_FILE) reduce 140) ((T_FINAL) reduce 140) ((T_FN) reduce 140) ((T_FOR) reduce 140) ((T_FOREACH) reduce 140) ((T_FUNCTION) reduce 140) ((T_FUNC_C) reduce 140) ((T_GLOBAL) reduce 140) ((T_GOTO) reduce 140) ((T_HALT_COMPILER) reduce 140) ((T_IF) reduce 140) ((T_INC) reduce 140) ((T_INCLUDE) reduce 140) ((T_INCLUDE_ONCE) reduce 140) ((T_INLINE_HTML) reduce 140) ((T_INTERFACE) reduce 140) ((T_INT_CAST) reduce 140) ((T_ISSET) reduce 140) ((T_LINE) reduce 140) ((T_LIST) reduce 140) ((T_LNUMBER) reduce 140) ((T_MATCH) reduce 140) ((T_METHOD_C) reduce 140) ((T_NAME_FULLY_QUALIFIED) reduce 140) ((T_NAME_QUALIFIED) reduce 140) ((T_NAME_RELATIVE) reduce 140) ((T_NEW) reduce 140) ((T_NS_C) reduce 140) ((T_OBJECT_CAST) reduce 140) ((T_PRINT) reduce 140) ((T_READONLY) reduce 140) ((T_REQUIRE) reduce 140) ((T_REQUIRE_ONCE) reduce 140) ((T_RETURN) reduce 140) ((T_START_HEREDOC) reduce 140) ((T_STATIC) reduce 140) ((T_STRING) reduce 140) ((T_STRING_CAST) reduce 140) ((T_SWITCH) reduce 140) ((T_THROW) reduce 140) ((T_TRAIT) reduce 140) ((T_TRAIT_C) reduce 140) ((T_TRY) reduce 140) ((T_UNSET) reduce 140) ((T_UNSET_CAST) reduce 140) ((T_VARIABLE) reduce 140) ((T_WHILE) reduce 140) ((T_YIELD) reduce 140) ((T_YIELD_FROM) reduce 140) (("[") reduce 140) (("`") reduce 140) (("{") reduce 140) (("~") reduce 140)) 19565 ((("!") reduce 150) (("\"") reduce 150) (("$") reduce 150) (("(") reduce 150) (("+") reduce 150) (("-") reduce 150) ((";") reduce 150) (("@") reduce 150) ((T_ABSTRACT) reduce 150) ((T_ARRAY) reduce 150) ((T_ARRAY_CAST) reduce 150) ((T_ATTRIBUTE) reduce 150) ((T_BOOL_CAST) reduce 150) ((T_BREAK) reduce 150) ((T_CLASS) reduce 150) ((T_CLASS_C) reduce 150) ((T_CLONE) reduce 150) ((T_CONSTANT_ENCAPSED_STRING) reduce 150) ((T_CONTINUE) reduce 150) ((T_DEC) reduce 150) ((T_DECLARE) reduce 150) ((T_DIR) reduce 150) ((T_DNUMBER) reduce 150) ((T_DO) reduce 150) ((T_DOUBLE_CAST) reduce 150) ((T_ECHO) reduce 150) ((T_ELSE) reduce 150) ((T_ELSEIF) reduce 150) ((T_EMPTY) reduce 150) ((T_ENDFOREACH) reduce 150) ((T_ENUM) reduce 150) ((T_EVAL) reduce 150) ((T_EXIT) reduce 150) ((T_FILE) reduce 150) ((T_FINAL) reduce 150) ((T_FN) reduce 150) ((T_FOR) reduce 150) ((T_FOREACH) reduce 150) ((T_FUNCTION) reduce 150) ((T_FUNC_C) reduce 150) ((T_GLOBAL) reduce 150) ((T_GOTO) reduce 150) ((T_HALT_COMPILER) reduce 150) ((T_IF) reduce 150) ((T_INC) reduce 150) ((T_INCLUDE) reduce 150) ((T_INCLUDE_ONCE) reduce 150) ((T_INLINE_HTML) reduce 150) ((T_INTERFACE) reduce 150) ((T_INT_CAST) reduce 150) ((T_ISSET) reduce 150) ((T_LINE) reduce 150) ((T_LIST) reduce 150) ((T_LNUMBER) reduce 150) ((T_MATCH) reduce 150) ((T_METHOD_C) reduce 150) ((T_NAME_FULLY_QUALIFIED) reduce 150) ((T_NAME_QUALIFIED) reduce 150) ((T_NAME_RELATIVE) reduce 150) ((T_NEW) reduce 150) ((T_NS_C) reduce 150) ((T_OBJECT_CAST) reduce 150) ((T_PRINT) reduce 150) ((T_READONLY) reduce 150) ((T_REQUIRE) reduce 150) ((T_REQUIRE_ONCE) reduce 150) ((T_RETURN) reduce 150) ((T_START_HEREDOC) reduce 150) ((T_STATIC) reduce 150) ((T_STRING) reduce 150) ((T_STRING_CAST) reduce 150) ((T_SWITCH) reduce 150) ((T_THROW) reduce 150) ((T_TRAIT) reduce 150) ((T_TRAIT_C) reduce 150) ((T_TRY) reduce 150) ((T_UNSET) reduce 150) ((T_UNSET_CAST) reduce 150) ((T_VARIABLE) reduce 150) ((T_WHILE) reduce 150) ((T_YIELD) reduce 150) ((T_YIELD_FROM) reduce 150) (("[") reduce 150) (("`") reduce 150) (("{") reduce 150) (("~") reduce 150)) 19566 ((("!") reduce 215) (("\"") reduce 215) (("$") reduce 215) (("(") reduce 215) (("+") reduce 215) (("-") reduce 215) ((";") reduce 215) (("@") reduce 215) ((T_ABSTRACT) reduce 215) ((T_ARRAY) reduce 215) ((T_ARRAY_CAST) reduce 215) ((T_ATTRIBUTE) reduce 215) ((T_BOOL_CAST) reduce 215) ((T_BREAK) reduce 215) ((T_CLASS) reduce 215) ((T_CLASS_C) reduce 215) ((T_CLONE) reduce 215) ((T_CONSTANT_ENCAPSED_STRING) reduce 215) ((T_CONTINUE) reduce 215) ((T_DEC) reduce 215) ((T_DECLARE) reduce 215) ((T_DIR) reduce 215) ((T_DNUMBER) reduce 215) ((T_DO) reduce 215) ((T_DOUBLE_CAST) reduce 215) ((T_ECHO) reduce 215) ((T_ELSE) reduce 215) ((T_ELSEIF) reduce 215) ((T_EMPTY) reduce 215) ((T_ENDFOREACH) reduce 215) ((T_ENUM) reduce 215) ((T_EVAL) reduce 215) ((T_EXIT) reduce 215) ((T_FILE) reduce 215) ((T_FINAL) reduce 215) ((T_FN) reduce 215) ((T_FOR) reduce 215) ((T_FOREACH) reduce 215) ((T_FUNCTION) reduce 215) ((T_FUNC_C) reduce 215) ((T_GLOBAL) reduce 215) ((T_GOTO) reduce 215) ((T_HALT_COMPILER) reduce 215) ((T_IF) reduce 215) ((T_INC) reduce 215) ((T_INCLUDE) reduce 215) ((T_INCLUDE_ONCE) reduce 215) ((T_INLINE_HTML) reduce 215) ((T_INTERFACE) reduce 215) ((T_INT_CAST) reduce 215) ((T_ISSET) reduce 215) ((T_LINE) reduce 215) ((T_LIST) reduce 215) ((T_LNUMBER) reduce 215) ((T_MATCH) reduce 215) ((T_METHOD_C) reduce 215) ((T_NAME_FULLY_QUALIFIED) reduce 215) ((T_NAME_QUALIFIED) reduce 215) ((T_NAME_RELATIVE) reduce 215) ((T_NEW) reduce 215) ((T_NS_C) reduce 215) ((T_OBJECT_CAST) reduce 215) ((T_PRINT) reduce 215) ((T_READONLY) reduce 215) ((T_REQUIRE) reduce 215) ((T_REQUIRE_ONCE) reduce 215) ((T_RETURN) reduce 215) ((T_START_HEREDOC) reduce 215) ((T_STATIC) reduce 215) ((T_STRING) reduce 215) ((T_STRING_CAST) reduce 215) ((T_SWITCH) reduce 215) ((T_THROW) reduce 215) ((T_TRAIT) reduce 215) ((T_TRAIT_C) reduce 215) ((T_TRY) reduce 215) ((T_UNSET) reduce 215) ((T_UNSET_CAST) reduce 215) ((T_VARIABLE) reduce 215) ((T_WHILE) reduce 215) ((T_YIELD) reduce 215) ((T_YIELD_FROM) reduce 215) (("[") reduce 215) (("`") reduce 215) (("{") reduce 215) (("~") reduce 215)) 19567 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) (("+") shift) (("-") shift) ((";") shift) (("@") shift) ((T_ABSTRACT) shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_BREAK) shift) ((T_CLASS) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_CONTINUE) shift) ((T_DEC) shift) ((T_DECLARE) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DO) shift) ((T_DOUBLE_CAST) shift) ((T_ECHO) shift) ((T_EMPTY) shift) ((T_ENDFOR) shift) ((T_ENUM) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FINAL) shift) ((T_FN) shift) ((T_FOR) shift) ((T_FOREACH) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_GLOBAL) shift) ((T_GOTO) shift) ((T_HALT_COMPILER) shift) ((T_IF) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INLINE_HTML) shift) ((T_INTERFACE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_RETURN) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_SWITCH) shift) ((T_THROW) shift) ((T_TRAIT) shift) ((T_TRAIT_C) shift) ((T_TRY) shift) ((T_UNSET) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_WHILE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("{") shift) (("~") shift)) 19568 ((("!") reduce 164) (("\"") reduce 164) (("$") reduce 164) (("(") reduce 164) (("+") reduce 164) (("-") reduce 164) ((";") reduce 164) (("@") reduce 164) ((T_ABSTRACT) reduce 164) ((T_ARRAY) reduce 164) ((T_ARRAY_CAST) reduce 164) ((T_ATTRIBUTE) reduce 164) ((T_BOOL_CAST) reduce 164) ((T_BREAK) reduce 164) ((T_CLASS) reduce 164) ((T_CLASS_C) reduce 164) ((T_CLONE) reduce 164) ((T_CONSTANT_ENCAPSED_STRING) reduce 164) ((T_CONTINUE) reduce 164) ((T_DEC) reduce 164) ((T_DECLARE) reduce 164) ((T_DIR) reduce 164) ((T_DNUMBER) reduce 164) ((T_DO) reduce 164) ((T_DOUBLE_CAST) reduce 164) ((T_ECHO) reduce 164) ((T_EMPTY) reduce 164) ((T_ENDFOR) reduce 164) ((T_ENUM) reduce 164) ((T_EVAL) reduce 164) ((T_EXIT) reduce 164) ((T_FILE) reduce 164) ((T_FINAL) reduce 164) ((T_FN) reduce 164) ((T_FOR) reduce 164) ((T_FOREACH) reduce 164) ((T_FUNCTION) reduce 164) ((T_FUNC_C) reduce 164) ((T_GLOBAL) reduce 164) ((T_GOTO) reduce 164) ((T_HALT_COMPILER) reduce 164) ((T_IF) reduce 164) ((T_INC) reduce 164) ((T_INCLUDE) reduce 164) ((T_INCLUDE_ONCE) reduce 164) ((T_INLINE_HTML) reduce 164) ((T_INTERFACE) reduce 164) ((T_INT_CAST) reduce 164) ((T_ISSET) reduce 164) ((T_LINE) reduce 164) ((T_LIST) reduce 164) ((T_LNUMBER) reduce 164) ((T_MATCH) reduce 164) ((T_METHOD_C) reduce 164) ((T_NAME_FULLY_QUALIFIED) reduce 164) ((T_NAME_QUALIFIED) reduce 164) ((T_NAME_RELATIVE) reduce 164) ((T_NEW) reduce 164) ((T_NS_C) reduce 164) ((T_OBJECT_CAST) reduce 164) ((T_PRINT) reduce 164) ((T_READONLY) reduce 164) ((T_REQUIRE) reduce 164) ((T_REQUIRE_ONCE) reduce 164) ((T_RETURN) reduce 164) ((T_START_HEREDOC) reduce 164) ((T_STATIC) reduce 164) ((T_STRING) reduce 164) ((T_STRING_CAST) reduce 164) ((T_SWITCH) reduce 164) ((T_THROW) reduce 164) ((T_TRAIT) reduce 164) ((T_TRAIT_C) reduce 164) ((T_TRY) reduce 164) ((T_UNSET) reduce 164) ((T_UNSET_CAST) reduce 164) ((T_VARIABLE) reduce 164) ((T_WHILE) reduce 164) ((T_YIELD) reduce 164) ((T_YIELD_FROM) reduce 164) (("[") reduce 164) (("`") reduce 164) (("{") reduce 164) (("~") reduce 164)) 19583 ((("!") reduce 158) (("\"") reduce 158) (("$") reduce 158) (("(") reduce 158) (("+") reduce 158) (("-") reduce 158) ((";") reduce 158) (("@") reduce 158) ((T_ABSTRACT) reduce 158) ((T_ARRAY) reduce 158) ((T_ARRAY_CAST) reduce 158) ((T_ATTRIBUTE) reduce 158) ((T_BOOL_CAST) reduce 158) ((T_BREAK) reduce 158) ((T_CLASS) reduce 158) ((T_CLASS_C) reduce 158) ((T_CLONE) reduce 158) ((T_CONSTANT_ENCAPSED_STRING) reduce 158) ((T_CONTINUE) reduce 158) ((T_DEC) reduce 158) ((T_DECLARE) reduce 158) ((T_DIR) reduce 158) ((T_DNUMBER) reduce 158) ((T_DO) reduce 158) ((T_DOUBLE_CAST) reduce 158) ((T_ECHO) reduce 158) ((T_EMPTY) reduce 158) ((T_ENDFOR) reduce 158) ((T_ENUM) reduce 158) ((T_EVAL) reduce 158) ((T_EXIT) reduce 158) ((T_FILE) reduce 158) ((T_FINAL) reduce 158) ((T_FN) reduce 158) ((T_FOR) reduce 158) ((T_FOREACH) reduce 158) ((T_FUNCTION) reduce 158) ((T_FUNC_C) reduce 158) ((T_GLOBAL) reduce 158) ((T_GOTO) reduce 158) ((T_HALT_COMPILER) reduce 158) ((T_IF) reduce 158) ((T_INC) reduce 158) ((T_INCLUDE) reduce 158) ((T_INCLUDE_ONCE) reduce 158) ((T_INLINE_HTML) reduce 158) ((T_INTERFACE) reduce 158) ((T_INT_CAST) reduce 158) ((T_ISSET) reduce 158) ((T_LINE) reduce 158) ((T_LIST) reduce 158) ((T_LNUMBER) reduce 158) ((T_MATCH) reduce 158) ((T_METHOD_C) reduce 158) ((T_NAME_FULLY_QUALIFIED) reduce 158) ((T_NAME_QUALIFIED) reduce 158) ((T_NAME_RELATIVE) reduce 158) ((T_NEW) reduce 158) ((T_NS_C) reduce 158) ((T_OBJECT_CAST) reduce 158) ((T_PRINT) reduce 158) ((T_READONLY) reduce 158) ((T_REQUIRE) reduce 158) ((T_REQUIRE_ONCE) reduce 158) ((T_RETURN) reduce 158) ((T_START_HEREDOC) reduce 158) ((T_STATIC) reduce 158) ((T_STRING) reduce 158) ((T_STRING_CAST) reduce 158) ((T_SWITCH) reduce 158) ((T_THROW) reduce 158) ((T_TRAIT) reduce 158) ((T_TRAIT_C) reduce 158) ((T_TRY) reduce 158) ((T_UNSET) reduce 158) ((T_UNSET_CAST) reduce 158) ((T_VARIABLE) reduce 158) ((T_WHILE) reduce 158) ((T_YIELD) reduce 158) ((T_YIELD_FROM) reduce 158) (("[") reduce 158) (("`") reduce 158) (("{") reduce 158) (("~") reduce 158)) 19593 ((("!") reduce 147) (("\"") reduce 147) (("$") reduce 147) (("(") reduce 147) (("+") reduce 147) (("-") reduce 147) ((";") reduce 147) (("@") reduce 147) ((T_ABSTRACT) reduce 147) ((T_ARRAY) reduce 147) ((T_ARRAY_CAST) reduce 147) ((T_ATTRIBUTE) reduce 147) ((T_BOOL_CAST) reduce 147) ((T_BREAK) reduce 147) ((T_CLASS) reduce 147) ((T_CLASS_C) reduce 147) ((T_CLONE) reduce 147) ((T_CONSTANT_ENCAPSED_STRING) reduce 147) ((T_CONTINUE) reduce 147) ((T_DEC) reduce 147) ((T_DECLARE) reduce 147) ((T_DIR) reduce 147) ((T_DNUMBER) reduce 147) ((T_DO) reduce 147) ((T_DOUBLE_CAST) reduce 147) ((T_ECHO) reduce 147) ((T_EMPTY) reduce 147) ((T_ENDFOR) reduce 147) ((T_ENUM) reduce 147) ((T_EVAL) reduce 147) ((T_EXIT) reduce 147) ((T_FILE) reduce 147) ((T_FINAL) reduce 147) ((T_FN) reduce 147) ((T_FOR) reduce 147) ((T_FOREACH) reduce 147) ((T_FUNCTION) reduce 147) ((T_FUNC_C) reduce 147) ((T_GLOBAL) reduce 147) ((T_GOTO) reduce 147) ((T_HALT_COMPILER) reduce 147) ((T_IF) reduce 147) ((T_INC) reduce 147) ((T_INCLUDE) reduce 147) ((T_INCLUDE_ONCE) reduce 147) ((T_INLINE_HTML) reduce 147) ((T_INTERFACE) reduce 147) ((T_INT_CAST) reduce 147) ((T_ISSET) reduce 147) ((T_LINE) reduce 147) ((T_LIST) reduce 147) ((T_LNUMBER) reduce 147) ((T_MATCH) reduce 147) ((T_METHOD_C) reduce 147) ((T_NAME_FULLY_QUALIFIED) reduce 147) ((T_NAME_QUALIFIED) reduce 147) ((T_NAME_RELATIVE) reduce 147) ((T_NEW) reduce 147) ((T_NS_C) reduce 147) ((T_OBJECT_CAST) reduce 147) ((T_PRINT) reduce 147) ((T_READONLY) reduce 147) ((T_REQUIRE) reduce 147) ((T_REQUIRE_ONCE) reduce 147) ((T_RETURN) reduce 147) ((T_START_HEREDOC) reduce 147) ((T_STATIC) reduce 147) ((T_STRING) reduce 147) ((T_STRING_CAST) reduce 147) ((T_SWITCH) reduce 147) ((T_THROW) reduce 147) ((T_TRAIT) reduce 147) ((T_TRAIT_C) reduce 147) ((T_TRY) reduce 147) ((T_UNSET) reduce 147) ((T_UNSET_CAST) reduce 147) ((T_VARIABLE) reduce 147) ((T_WHILE) reduce 147) ((T_YIELD) reduce 147) ((T_YIELD_FROM) reduce 147) (("[") reduce 147) (("`") reduce 147) (("{") reduce 147) (("~") reduce 147)) 19595 ((("!") reduce 142) (("\"") reduce 142) (("$") reduce 142) (("(") reduce 142) (("+") reduce 142) (("-") reduce 142) ((";") reduce 142) (("@") reduce 142) ((T_ABSTRACT) reduce 142) ((T_ARRAY) reduce 142) ((T_ARRAY_CAST) reduce 142) ((T_ATTRIBUTE) reduce 142) ((T_BOOL_CAST) reduce 142) ((T_BREAK) reduce 142) ((T_CLASS) reduce 142) ((T_CLASS_C) reduce 142) ((T_CLONE) reduce 142) ((T_CONSTANT_ENCAPSED_STRING) reduce 142) ((T_CONTINUE) reduce 142) ((T_DEC) reduce 142) ((T_DECLARE) reduce 142) ((T_DIR) reduce 142) ((T_DNUMBER) reduce 142) ((T_DO) reduce 142) ((T_DOUBLE_CAST) reduce 142) ((T_ECHO) reduce 142) ((T_EMPTY) reduce 142) ((T_ENDFOR) reduce 142) ((T_ENUM) reduce 142) ((T_EVAL) reduce 142) ((T_EXIT) reduce 142) ((T_FILE) reduce 142) ((T_FINAL) reduce 142) ((T_FN) reduce 142) ((T_FOR) reduce 142) ((T_FOREACH) reduce 142) ((T_FUNCTION) reduce 142) ((T_FUNC_C) reduce 142) ((T_GLOBAL) reduce 142) ((T_GOTO) reduce 142) ((T_HALT_COMPILER) reduce 142) ((T_IF) reduce 142) ((T_INC) reduce 142) ((T_INCLUDE) reduce 142) ((T_INCLUDE_ONCE) reduce 142) ((T_INLINE_HTML) reduce 142) ((T_INTERFACE) reduce 142) ((T_INT_CAST) reduce 142) ((T_ISSET) reduce 142) ((T_LINE) reduce 142) ((T_LIST) reduce 142) ((T_LNUMBER) reduce 142) ((T_MATCH) reduce 142) ((T_METHOD_C) reduce 142) ((T_NAME_FULLY_QUALIFIED) reduce 142) ((T_NAME_QUALIFIED) reduce 142) ((T_NAME_RELATIVE) reduce 142) ((T_NEW) reduce 142) ((T_NS_C) reduce 142) ((T_OBJECT_CAST) reduce 142) ((T_PRINT) reduce 142) ((T_READONLY) reduce 142) ((T_REQUIRE) reduce 142) ((T_REQUIRE_ONCE) reduce 142) ((T_RETURN) reduce 142) ((T_START_HEREDOC) reduce 142) ((T_STATIC) reduce 142) ((T_STRING) reduce 142) ((T_STRING_CAST) reduce 142) ((T_SWITCH) reduce 142) ((T_THROW) reduce 142) ((T_TRAIT) reduce 142) ((T_TRAIT_C) reduce 142) ((T_TRY) reduce 142) ((T_UNSET) reduce 142) ((T_UNSET_CAST) reduce 142) ((T_VARIABLE) reduce 142) ((T_WHILE) reduce 142) ((T_YIELD) reduce 142) ((T_YIELD_FROM) reduce 142) (("[") reduce 142) (("`") reduce 142) (("{") reduce 142) (("~") reduce 142)) 19597 ((("!") reduce 103) (("\"") reduce 103) (("$") reduce 103) (("(") reduce 103) (("+") reduce 103) (("-") reduce 103) ((";") reduce 103) (("@") reduce 103) ((T_ABSTRACT) reduce 103) ((T_ARRAY) reduce 103) ((T_ARRAY_CAST) reduce 103) ((T_ATTRIBUTE) reduce 103) ((T_BOOL_CAST) reduce 103) ((T_BREAK) reduce 103) ((T_CLASS) reduce 103) ((T_CLASS_C) reduce 103) ((T_CLONE) reduce 103) ((T_CONSTANT_ENCAPSED_STRING) reduce 103) ((T_CONTINUE) reduce 103) ((T_DEC) reduce 103) ((T_DECLARE) reduce 103) ((T_DIR) reduce 103) ((T_DNUMBER) reduce 103) ((T_DO) reduce 103) ((T_DOUBLE_CAST) reduce 103) ((T_ECHO) reduce 103) ((T_EMPTY) reduce 103) ((T_ENDFOR) reduce 103) ((T_ENUM) reduce 103) ((T_EVAL) reduce 103) ((T_EXIT) reduce 103) ((T_FILE) reduce 103) ((T_FINAL) reduce 103) ((T_FN) reduce 103) ((T_FOR) reduce 103) ((T_FOREACH) reduce 103) ((T_FUNCTION) reduce 103) ((T_FUNC_C) reduce 103) ((T_GLOBAL) reduce 103) ((T_GOTO) reduce 103) ((T_HALT_COMPILER) reduce 103) ((T_IF) reduce 103) ((T_INC) reduce 103) ((T_INCLUDE) reduce 103) ((T_INCLUDE_ONCE) reduce 103) ((T_INLINE_HTML) reduce 103) ((T_INTERFACE) reduce 103) ((T_INT_CAST) reduce 103) ((T_ISSET) reduce 103) ((T_LINE) reduce 103) ((T_LIST) reduce 103) ((T_LNUMBER) reduce 103) ((T_MATCH) reduce 103) ((T_METHOD_C) reduce 103) ((T_NAME_FULLY_QUALIFIED) reduce 103) ((T_NAME_QUALIFIED) reduce 103) ((T_NAME_RELATIVE) reduce 103) ((T_NEW) reduce 103) ((T_NS_C) reduce 103) ((T_OBJECT_CAST) reduce 103) ((T_PRINT) reduce 103) ((T_READONLY) reduce 103) ((T_REQUIRE) reduce 103) ((T_REQUIRE_ONCE) reduce 103) ((T_RETURN) reduce 103) ((T_START_HEREDOC) reduce 103) ((T_STATIC) reduce 103) ((T_STRING) reduce 103) ((T_STRING_CAST) reduce 103) ((T_SWITCH) reduce 103) ((T_THROW) reduce 103) ((T_TRAIT) reduce 103) ((T_TRAIT_C) reduce 103) ((T_TRY) reduce 103) ((T_UNSET) reduce 103) ((T_UNSET_CAST) reduce 103) ((T_VARIABLE) reduce 103) ((T_WHILE) reduce 103) ((T_YIELD) reduce 103) ((T_YIELD_FROM) reduce 103) (("[") reduce 103) (("`") reduce 103) (("{") reduce 103) (("~") reduce 103)) 19599 ((("!") reduce 106) (("\"") reduce 106) (("$") reduce 106) (("(") reduce 106) (("+") reduce 106) (("-") reduce 106) ((";") reduce 106) (("@") reduce 106) ((T_ABSTRACT) reduce 106) ((T_ARRAY) reduce 106) ((T_ARRAY_CAST) reduce 106) ((T_ATTRIBUTE) reduce 106) ((T_BOOL_CAST) reduce 106) ((T_BREAK) reduce 106) ((T_CLASS) reduce 106) ((T_CLASS_C) reduce 106) ((T_CLONE) reduce 106) ((T_CONSTANT_ENCAPSED_STRING) reduce 106) ((T_CONTINUE) reduce 106) ((T_DEC) reduce 106) ((T_DECLARE) reduce 106) ((T_DIR) reduce 106) ((T_DNUMBER) reduce 106) ((T_DO) reduce 106) ((T_DOUBLE_CAST) reduce 106) ((T_ECHO) reduce 106) ((T_EMPTY) reduce 106) ((T_ENDFOR) reduce 106) ((T_ENUM) reduce 106) ((T_EVAL) reduce 106) ((T_EXIT) reduce 106) ((T_FILE) reduce 106) ((T_FINAL) reduce 106) ((T_FN) reduce 106) ((T_FOR) reduce 106) ((T_FOREACH) reduce 106) ((T_FUNCTION) reduce 106) ((T_FUNC_C) reduce 106) ((T_GLOBAL) reduce 106) ((T_GOTO) reduce 106) ((T_HALT_COMPILER) reduce 106) ((T_IF) reduce 106) ((T_INC) reduce 106) ((T_INCLUDE) reduce 106) ((T_INCLUDE_ONCE) reduce 106) ((T_INLINE_HTML) reduce 106) ((T_INTERFACE) reduce 106) ((T_INT_CAST) reduce 106) ((T_ISSET) reduce 106) ((T_LINE) reduce 106) ((T_LIST) reduce 106) ((T_LNUMBER) reduce 106) ((T_MATCH) reduce 106) ((T_METHOD_C) reduce 106) ((T_NAME_FULLY_QUALIFIED) reduce 106) ((T_NAME_QUALIFIED) reduce 106) ((T_NAME_RELATIVE) reduce 106) ((T_NEW) reduce 106) ((T_NS_C) reduce 106) ((T_OBJECT_CAST) reduce 106) ((T_PRINT) reduce 106) ((T_READONLY) reduce 106) ((T_REQUIRE) reduce 106) ((T_REQUIRE_ONCE) reduce 106) ((T_RETURN) reduce 106) ((T_START_HEREDOC) reduce 106) ((T_STATIC) reduce 106) ((T_STRING) reduce 106) ((T_STRING_CAST) reduce 106) ((T_SWITCH) reduce 106) ((T_THROW) reduce 106) ((T_TRAIT) reduce 106) ((T_TRAIT_C) reduce 106) ((T_TRY) reduce 106) ((T_UNSET) reduce 106) ((T_UNSET_CAST) reduce 106) ((T_VARIABLE) reduce 106) ((T_WHILE) reduce 106) ((T_YIELD) reduce 106) ((T_YIELD_FROM) reduce 106) (("[") reduce 106) (("`") reduce 106) (("{") reduce 106) (("~") reduce 106)) 19602 ((("!") reduce 102) (("\"") reduce 102) (("$") reduce 102) (("(") reduce 102) (("+") reduce 102) (("-") reduce 102) ((";") reduce 102) (("@") reduce 102) ((T_ABSTRACT) reduce 102) ((T_ARRAY) reduce 102) ((T_ARRAY_CAST) reduce 102) ((T_ATTRIBUTE) reduce 102) ((T_BOOL_CAST) reduce 102) ((T_BREAK) reduce 102) ((T_CLASS) reduce 102) ((T_CLASS_C) reduce 102) ((T_CLONE) reduce 102) ((T_CONSTANT_ENCAPSED_STRING) reduce 102) ((T_CONTINUE) reduce 102) ((T_DEC) reduce 102) ((T_DECLARE) reduce 102) ((T_DIR) reduce 102) ((T_DNUMBER) reduce 102) ((T_DO) reduce 102) ((T_DOUBLE_CAST) reduce 102) ((T_ECHO) reduce 102) ((T_EMPTY) reduce 102) ((T_ENDFOR) reduce 102) ((T_ENUM) reduce 102) ((T_EVAL) reduce 102) ((T_EXIT) reduce 102) ((T_FILE) reduce 102) ((T_FINAL) reduce 102) ((T_FN) reduce 102) ((T_FOR) reduce 102) ((T_FOREACH) reduce 102) ((T_FUNCTION) reduce 102) ((T_FUNC_C) reduce 102) ((T_GLOBAL) reduce 102) ((T_GOTO) reduce 102) ((T_HALT_COMPILER) reduce 102) ((T_IF) reduce 102) ((T_INC) reduce 102) ((T_INCLUDE) reduce 102) ((T_INCLUDE_ONCE) reduce 102) ((T_INLINE_HTML) reduce 102) ((T_INTERFACE) reduce 102) ((T_INT_CAST) reduce 102) ((T_ISSET) reduce 102) ((T_LINE) reduce 102) ((T_LIST) reduce 102) ((T_LNUMBER) reduce 102) ((T_MATCH) reduce 102) ((T_METHOD_C) reduce 102) ((T_NAME_FULLY_QUALIFIED) reduce 102) ((T_NAME_QUALIFIED) reduce 102) ((T_NAME_RELATIVE) reduce 102) ((T_NEW) reduce 102) ((T_NS_C) reduce 102) ((T_OBJECT_CAST) reduce 102) ((T_PRINT) reduce 102) ((T_READONLY) reduce 102) ((T_REQUIRE) reduce 102) ((T_REQUIRE_ONCE) reduce 102) ((T_RETURN) reduce 102) ((T_START_HEREDOC) reduce 102) ((T_STATIC) reduce 102) ((T_STRING) reduce 102) ((T_STRING_CAST) reduce 102) ((T_SWITCH) reduce 102) ((T_THROW) reduce 102) ((T_TRAIT) reduce 102) ((T_TRAIT_C) reduce 102) ((T_TRY) reduce 102) ((T_UNSET) reduce 102) ((T_UNSET_CAST) reduce 102) ((T_VARIABLE) reduce 102) ((T_WHILE) reduce 102) ((T_YIELD) reduce 102) ((T_YIELD_FROM) reduce 102) (("[") reduce 102) (("`") reduce 102) (("{") reduce 102) (("~") reduce 102)) 19603 ((("!") reduce 146) (("\"") reduce 146) (("$") reduce 146) (("(") reduce 146) (("+") reduce 146) (("-") reduce 146) ((";") reduce 146) (("@") reduce 146) ((T_ABSTRACT) reduce 146) ((T_ARRAY) reduce 146) ((T_ARRAY_CAST) reduce 146) ((T_ATTRIBUTE) reduce 146) ((T_BOOL_CAST) reduce 146) ((T_BREAK) reduce 146) ((T_CLASS) reduce 146) ((T_CLASS_C) reduce 146) ((T_CLONE) reduce 146) ((T_CONSTANT_ENCAPSED_STRING) reduce 146) ((T_CONTINUE) reduce 146) ((T_DEC) reduce 146) ((T_DECLARE) reduce 146) ((T_DIR) reduce 146) ((T_DNUMBER) reduce 146) ((T_DO) reduce 146) ((T_DOUBLE_CAST) reduce 146) ((T_ECHO) reduce 146) ((T_EMPTY) reduce 146) ((T_ENDFOR) reduce 146) ((T_ENUM) reduce 146) ((T_EVAL) reduce 146) ((T_EXIT) reduce 146) ((T_FILE) reduce 146) ((T_FINAL) reduce 146) ((T_FN) reduce 146) ((T_FOR) reduce 146) ((T_FOREACH) reduce 146) ((T_FUNCTION) reduce 146) ((T_FUNC_C) reduce 146) ((T_GLOBAL) reduce 146) ((T_GOTO) reduce 146) ((T_HALT_COMPILER) reduce 146) ((T_IF) reduce 146) ((T_INC) reduce 146) ((T_INCLUDE) reduce 146) ((T_INCLUDE_ONCE) reduce 146) ((T_INLINE_HTML) reduce 146) ((T_INTERFACE) reduce 146) ((T_INT_CAST) reduce 146) ((T_ISSET) reduce 146) ((T_LINE) reduce 146) ((T_LIST) reduce 146) ((T_LNUMBER) reduce 146) ((T_MATCH) reduce 146) ((T_METHOD_C) reduce 146) ((T_NAME_FULLY_QUALIFIED) reduce 146) ((T_NAME_QUALIFIED) reduce 146) ((T_NAME_RELATIVE) reduce 146) ((T_NEW) reduce 146) ((T_NS_C) reduce 146) ((T_OBJECT_CAST) reduce 146) ((T_PRINT) reduce 146) ((T_READONLY) reduce 146) ((T_REQUIRE) reduce 146) ((T_REQUIRE_ONCE) reduce 146) ((T_RETURN) reduce 146) ((T_START_HEREDOC) reduce 146) ((T_STATIC) reduce 146) ((T_STRING) reduce 146) ((T_STRING_CAST) reduce 146) ((T_SWITCH) reduce 146) ((T_THROW) reduce 146) ((T_TRAIT) reduce 146) ((T_TRAIT_C) reduce 146) ((T_TRY) reduce 146) ((T_UNSET) reduce 146) ((T_UNSET_CAST) reduce 146) ((T_VARIABLE) reduce 146) ((T_WHILE) reduce 146) ((T_YIELD) reduce 146) ((T_YIELD_FROM) reduce 146) (("[") reduce 146) (("`") reduce 146) (("{") reduce 146) (("~") reduce 146)) 19604 ((("!") reduce 243) (("\"") reduce 243) (("$") reduce 243) (("(") reduce 243) (("+") reduce 243) (("-") reduce 243) ((";") reduce 243) (("@") reduce 243) ((T_ABSTRACT) reduce 243) ((T_ARRAY) reduce 243) ((T_ARRAY_CAST) reduce 243) ((T_ATTRIBUTE) reduce 243) ((T_BOOL_CAST) reduce 243) ((T_BREAK) reduce 243) ((T_CLASS) reduce 243) ((T_CLASS_C) reduce 243) ((T_CLONE) reduce 243) ((T_CONSTANT_ENCAPSED_STRING) reduce 243) ((T_CONTINUE) reduce 243) ((T_DEC) reduce 243) ((T_DECLARE) reduce 243) ((T_DIR) reduce 243) ((T_DNUMBER) reduce 243) ((T_DO) reduce 243) ((T_DOUBLE_CAST) reduce 243) ((T_ECHO) reduce 243) ((T_ELSE) shift) ((T_ELSEIF) shift) ((T_EMPTY) reduce 243) ((T_ENDFOR) reduce 243) ((T_ENUM) reduce 243) ((T_EVAL) reduce 243) ((T_EXIT) reduce 243) ((T_FILE) reduce 243) ((T_FINAL) reduce 243) ((T_FN) reduce 243) ((T_FOR) reduce 243) ((T_FOREACH) reduce 243) ((T_FUNCTION) reduce 243) ((T_FUNC_C) reduce 243) ((T_GLOBAL) reduce 243) ((T_GOTO) reduce 243) ((T_HALT_COMPILER) reduce 243) ((T_IF) reduce 243) ((T_INC) reduce 243) ((T_INCLUDE) reduce 243) ((T_INCLUDE_ONCE) reduce 243) ((T_INLINE_HTML) reduce 243) ((T_INTERFACE) reduce 243) ((T_INT_CAST) reduce 243) ((T_ISSET) reduce 243) ((T_LINE) reduce 243) ((T_LIST) reduce 243) ((T_LNUMBER) reduce 243) ((T_MATCH) reduce 243) ((T_METHOD_C) reduce 243) ((T_NAME_FULLY_QUALIFIED) reduce 243) ((T_NAME_QUALIFIED) reduce 243) ((T_NAME_RELATIVE) reduce 243) ((T_NEW) reduce 243) ((T_NS_C) reduce 243) ((T_OBJECT_CAST) reduce 243) ((T_PRINT) reduce 243) ((T_READONLY) reduce 243) ((T_REQUIRE) reduce 243) ((T_REQUIRE_ONCE) reduce 243) ((T_RETURN) reduce 243) ((T_START_HEREDOC) reduce 243) ((T_STATIC) reduce 243) ((T_STRING) reduce 243) ((T_STRING_CAST) reduce 243) ((T_SWITCH) reduce 243) ((T_THROW) reduce 243) ((T_TRAIT) reduce 243) ((T_TRAIT_C) reduce 243) ((T_TRY) reduce 243) ((T_UNSET) reduce 243) ((T_UNSET_CAST) reduce 243) ((T_VARIABLE) reduce 243) ((T_WHILE) reduce 243) ((T_YIELD) reduce 243) ((T_YIELD_FROM) reduce 243) (("[") reduce 243) (("`") reduce 243) (("{") reduce 243) (("~") reduce 243)) 19605 ((("!") reduce 139) (("\"") reduce 139) (("$") reduce 139) (("(") reduce 139) (("+") reduce 139) (("-") reduce 139) ((";") reduce 139) (("@") reduce 139) ((T_ABSTRACT) reduce 139) ((T_ARRAY) reduce 139) ((T_ARRAY_CAST) reduce 139) ((T_ATTRIBUTE) reduce 139) ((T_BOOL_CAST) reduce 139) ((T_BREAK) reduce 139) ((T_CLASS) reduce 139) ((T_CLASS_C) reduce 139) ((T_CLONE) reduce 139) ((T_CONSTANT_ENCAPSED_STRING) reduce 139) ((T_CONTINUE) reduce 139) ((T_DEC) reduce 139) ((T_DECLARE) reduce 139) ((T_DIR) reduce 139) ((T_DNUMBER) reduce 139) ((T_DO) reduce 139) ((T_DOUBLE_CAST) reduce 139) ((T_ECHO) reduce 139) ((T_EMPTY) reduce 139) ((T_ENDFOR) reduce 139) ((T_ENUM) reduce 139) ((T_EVAL) reduce 139) ((T_EXIT) reduce 139) ((T_FILE) reduce 139) ((T_FINAL) reduce 139) ((T_FN) reduce 139) ((T_FOR) reduce 139) ((T_FOREACH) reduce 139) ((T_FUNCTION) reduce 139) ((T_FUNC_C) reduce 139) ((T_GLOBAL) reduce 139) ((T_GOTO) reduce 139) ((T_HALT_COMPILER) reduce 139) ((T_IF) reduce 139) ((T_INC) reduce 139) ((T_INCLUDE) reduce 139) ((T_INCLUDE_ONCE) reduce 139) ((T_INLINE_HTML) reduce 139) ((T_INTERFACE) reduce 139) ((T_INT_CAST) reduce 139) ((T_ISSET) reduce 139) ((T_LINE) reduce 139) ((T_LIST) reduce 139) ((T_LNUMBER) reduce 139) ((T_MATCH) reduce 139) ((T_METHOD_C) reduce 139) ((T_NAME_FULLY_QUALIFIED) reduce 139) ((T_NAME_QUALIFIED) reduce 139) ((T_NAME_RELATIVE) reduce 139) ((T_NEW) reduce 139) ((T_NS_C) reduce 139) ((T_OBJECT_CAST) reduce 139) ((T_PRINT) reduce 139) ((T_READONLY) reduce 139) ((T_REQUIRE) reduce 139) ((T_REQUIRE_ONCE) reduce 139) ((T_RETURN) reduce 139) ((T_START_HEREDOC) reduce 139) ((T_STATIC) reduce 139) ((T_STRING) reduce 139) ((T_STRING_CAST) reduce 139) ((T_SWITCH) reduce 139) ((T_THROW) reduce 139) ((T_TRAIT) reduce 139) ((T_TRAIT_C) reduce 139) ((T_TRY) reduce 139) ((T_UNSET) reduce 139) ((T_UNSET_CAST) reduce 139) ((T_VARIABLE) reduce 139) ((T_WHILE) reduce 139) ((T_YIELD) reduce 139) ((T_YIELD_FROM) reduce 139) (("[") reduce 139) (("`") reduce 139) (("{") reduce 139) (("~") reduce 139)) 19606 ((("!") reduce 105) (("\"") reduce 105) (("$") reduce 105) (("(") reduce 105) (("+") reduce 105) (("-") reduce 105) ((";") reduce 105) (("@") reduce 105) ((T_ABSTRACT) reduce 105) ((T_ARRAY) reduce 105) ((T_ARRAY_CAST) reduce 105) ((T_ATTRIBUTE) reduce 105) ((T_BOOL_CAST) reduce 105) ((T_BREAK) reduce 105) ((T_CLASS) reduce 105) ((T_CLASS_C) reduce 105) ((T_CLONE) reduce 105) ((T_CONSTANT_ENCAPSED_STRING) reduce 105) ((T_CONTINUE) reduce 105) ((T_DEC) reduce 105) ((T_DECLARE) reduce 105) ((T_DIR) reduce 105) ((T_DNUMBER) reduce 105) ((T_DO) reduce 105) ((T_DOUBLE_CAST) reduce 105) ((T_ECHO) reduce 105) ((T_EMPTY) reduce 105) ((T_ENDFOR) reduce 105) ((T_ENUM) reduce 105) ((T_EVAL) reduce 105) ((T_EXIT) reduce 105) ((T_FILE) reduce 105) ((T_FINAL) reduce 105) ((T_FN) reduce 105) ((T_FOR) reduce 105) ((T_FOREACH) reduce 105) ((T_FUNCTION) reduce 105) ((T_FUNC_C) reduce 105) ((T_GLOBAL) reduce 105) ((T_GOTO) reduce 105) ((T_HALT_COMPILER) reduce 105) ((T_IF) reduce 105) ((T_INC) reduce 105) ((T_INCLUDE) reduce 105) ((T_INCLUDE_ONCE) reduce 105) ((T_INLINE_HTML) reduce 105) ((T_INTERFACE) reduce 105) ((T_INT_CAST) reduce 105) ((T_ISSET) reduce 105) ((T_LINE) reduce 105) ((T_LIST) reduce 105) ((T_LNUMBER) reduce 105) ((T_MATCH) reduce 105) ((T_METHOD_C) reduce 105) ((T_NAME_FULLY_QUALIFIED) reduce 105) ((T_NAME_QUALIFIED) reduce 105) ((T_NAME_RELATIVE) reduce 105) ((T_NEW) reduce 105) ((T_NS_C) reduce 105) ((T_OBJECT_CAST) reduce 105) ((T_PRINT) reduce 105) ((T_READONLY) reduce 105) ((T_REQUIRE) reduce 105) ((T_REQUIRE_ONCE) reduce 105) ((T_RETURN) reduce 105) ((T_START_HEREDOC) reduce 105) ((T_STATIC) reduce 105) ((T_STRING) reduce 105) ((T_STRING_CAST) reduce 105) ((T_SWITCH) reduce 105) ((T_THROW) reduce 105) ((T_TRAIT) reduce 105) ((T_TRAIT_C) reduce 105) ((T_TRY) reduce 105) ((T_UNSET) reduce 105) ((T_UNSET_CAST) reduce 105) ((T_VARIABLE) reduce 105) ((T_WHILE) reduce 105) ((T_YIELD) reduce 105) ((T_YIELD_FROM) reduce 105) (("[") reduce 105) (("`") reduce 105) (("{") reduce 105) (("~") reduce 105)) 19607 ((("!") reduce 141) (("\"") reduce 141) (("$") reduce 141) (("(") reduce 141) (("+") reduce 141) (("-") reduce 141) ((";") reduce 141) (("@") reduce 141) ((T_ABSTRACT) reduce 141) ((T_ARRAY) reduce 141) ((T_ARRAY_CAST) reduce 141) ((T_ATTRIBUTE) reduce 141) ((T_BOOL_CAST) reduce 141) ((T_BREAK) reduce 141) ((T_CLASS) reduce 141) ((T_CLASS_C) reduce 141) ((T_CLONE) reduce 141) ((T_CONSTANT_ENCAPSED_STRING) reduce 141) ((T_CONTINUE) reduce 141) ((T_DEC) reduce 141) ((T_DECLARE) reduce 141) ((T_DIR) reduce 141) ((T_DNUMBER) reduce 141) ((T_DO) reduce 141) ((T_DOUBLE_CAST) reduce 141) ((T_ECHO) reduce 141) ((T_EMPTY) reduce 141) ((T_ENDFOR) reduce 141) ((T_ENUM) reduce 141) ((T_EVAL) reduce 141) ((T_EXIT) reduce 141) ((T_FILE) reduce 141) ((T_FINAL) reduce 141) ((T_FN) reduce 141) ((T_FOR) reduce 141) ((T_FOREACH) reduce 141) ((T_FUNCTION) reduce 141) ((T_FUNC_C) reduce 141) ((T_GLOBAL) reduce 141) ((T_GOTO) reduce 141) ((T_HALT_COMPILER) reduce 141) ((T_IF) reduce 141) ((T_INC) reduce 141) ((T_INCLUDE) reduce 141) ((T_INCLUDE_ONCE) reduce 141) ((T_INLINE_HTML) reduce 141) ((T_INTERFACE) reduce 141) ((T_INT_CAST) reduce 141) ((T_ISSET) reduce 141) ((T_LINE) reduce 141) ((T_LIST) reduce 141) ((T_LNUMBER) reduce 141) ((T_MATCH) reduce 141) ((T_METHOD_C) reduce 141) ((T_NAME_FULLY_QUALIFIED) reduce 141) ((T_NAME_QUALIFIED) reduce 141) ((T_NAME_RELATIVE) reduce 141) ((T_NEW) reduce 141) ((T_NS_C) reduce 141) ((T_OBJECT_CAST) reduce 141) ((T_PRINT) reduce 141) ((T_READONLY) reduce 141) ((T_REQUIRE) reduce 141) ((T_REQUIRE_ONCE) reduce 141) ((T_RETURN) reduce 141) ((T_START_HEREDOC) reduce 141) ((T_STATIC) reduce 141) ((T_STRING) reduce 141) ((T_STRING_CAST) reduce 141) ((T_SWITCH) reduce 141) ((T_THROW) reduce 141) ((T_TRAIT) reduce 141) ((T_TRAIT_C) reduce 141) ((T_TRY) reduce 141) ((T_UNSET) reduce 141) ((T_UNSET_CAST) reduce 141) ((T_VARIABLE) reduce 141) ((T_WHILE) reduce 141) ((T_YIELD) reduce 141) ((T_YIELD_FROM) reduce 141) (("[") reduce 141) (("`") reduce 141) (("{") reduce 141) (("~") reduce 141)) 19608 ((("!") reduce 104) (("\"") reduce 104) (("$") reduce 104) (("(") reduce 104) (("+") reduce 104) (("-") reduce 104) ((";") reduce 104) (("@") reduce 104) ((T_ABSTRACT) reduce 104) ((T_ARRAY) reduce 104) ((T_ARRAY_CAST) reduce 104) ((T_ATTRIBUTE) reduce 104) ((T_BOOL_CAST) reduce 104) ((T_BREAK) reduce 104) ((T_CLASS) reduce 104) ((T_CLASS_C) reduce 104) ((T_CLONE) reduce 104) ((T_CONSTANT_ENCAPSED_STRING) reduce 104) ((T_CONTINUE) reduce 104) ((T_DEC) reduce 104) ((T_DECLARE) reduce 104) ((T_DIR) reduce 104) ((T_DNUMBER) reduce 104) ((T_DO) reduce 104) ((T_DOUBLE_CAST) reduce 104) ((T_ECHO) reduce 104) ((T_EMPTY) reduce 104) ((T_ENDFOR) reduce 104) ((T_ENUM) reduce 104) ((T_EVAL) reduce 104) ((T_EXIT) reduce 104) ((T_FILE) reduce 104) ((T_FINAL) reduce 104) ((T_FN) reduce 104) ((T_FOR) reduce 104) ((T_FOREACH) reduce 104) ((T_FUNCTION) reduce 104) ((T_FUNC_C) reduce 104) ((T_GLOBAL) reduce 104) ((T_GOTO) reduce 104) ((T_HALT_COMPILER) reduce 104) ((T_IF) reduce 104) ((T_INC) reduce 104) ((T_INCLUDE) reduce 104) ((T_INCLUDE_ONCE) reduce 104) ((T_INLINE_HTML) reduce 104) ((T_INTERFACE) reduce 104) ((T_INT_CAST) reduce 104) ((T_ISSET) reduce 104) ((T_LINE) reduce 104) ((T_LIST) reduce 104) ((T_LNUMBER) reduce 104) ((T_MATCH) reduce 104) ((T_METHOD_C) reduce 104) ((T_NAME_FULLY_QUALIFIED) reduce 104) ((T_NAME_QUALIFIED) reduce 104) ((T_NAME_RELATIVE) reduce 104) ((T_NEW) reduce 104) ((T_NS_C) reduce 104) ((T_OBJECT_CAST) reduce 104) ((T_PRINT) reduce 104) ((T_READONLY) reduce 104) ((T_REQUIRE) reduce 104) ((T_REQUIRE_ONCE) reduce 104) ((T_RETURN) reduce 104) ((T_START_HEREDOC) reduce 104) ((T_STATIC) reduce 104) ((T_STRING) reduce 104) ((T_STRING_CAST) reduce 104) ((T_SWITCH) reduce 104) ((T_THROW) reduce 104) ((T_TRAIT) reduce 104) ((T_TRAIT_C) reduce 104) ((T_TRY) reduce 104) ((T_UNSET) reduce 104) ((T_UNSET_CAST) reduce 104) ((T_VARIABLE) reduce 104) ((T_WHILE) reduce 104) ((T_YIELD) reduce 104) ((T_YIELD_FROM) reduce 104) (("[") reduce 104) (("`") reduce 104) (("{") reduce 104) (("~") reduce 104)) 19611 ((("!") reduce 145) (("\"") reduce 145) (("$") reduce 145) (("(") reduce 145) (("+") reduce 145) (("-") reduce 145) ((";") reduce 145) (("@") reduce 145) ((T_ABSTRACT) reduce 145) ((T_ARRAY) reduce 145) ((T_ARRAY_CAST) reduce 145) ((T_ATTRIBUTE) reduce 145) ((T_BOOL_CAST) reduce 145) ((T_BREAK) reduce 145) ((T_CLASS) reduce 145) ((T_CLASS_C) reduce 145) ((T_CLONE) reduce 145) ((T_CONSTANT_ENCAPSED_STRING) reduce 145) ((T_CONTINUE) reduce 145) ((T_DEC) reduce 145) ((T_DECLARE) reduce 145) ((T_DIR) reduce 145) ((T_DNUMBER) reduce 145) ((T_DO) reduce 145) ((T_DOUBLE_CAST) reduce 145) ((T_ECHO) reduce 145) ((T_EMPTY) reduce 145) ((T_ENDFOR) reduce 145) ((T_ENUM) reduce 145) ((T_EVAL) reduce 145) ((T_EXIT) reduce 145) ((T_FILE) reduce 145) ((T_FINAL) reduce 145) ((T_FN) reduce 145) ((T_FOR) reduce 145) ((T_FOREACH) reduce 145) ((T_FUNCTION) reduce 145) ((T_FUNC_C) reduce 145) ((T_GLOBAL) reduce 145) ((T_GOTO) reduce 145) ((T_HALT_COMPILER) reduce 145) ((T_IF) reduce 145) ((T_INC) reduce 145) ((T_INCLUDE) reduce 145) ((T_INCLUDE_ONCE) reduce 145) ((T_INLINE_HTML) reduce 145) ((T_INTERFACE) reduce 145) ((T_INT_CAST) reduce 145) ((T_ISSET) reduce 145) ((T_LINE) reduce 145) ((T_LIST) reduce 145) ((T_LNUMBER) reduce 145) ((T_MATCH) reduce 145) ((T_METHOD_C) reduce 145) ((T_NAME_FULLY_QUALIFIED) reduce 145) ((T_NAME_QUALIFIED) reduce 145) ((T_NAME_RELATIVE) reduce 145) ((T_NEW) reduce 145) ((T_NS_C) reduce 145) ((T_OBJECT_CAST) reduce 145) ((T_PRINT) reduce 145) ((T_READONLY) reduce 145) ((T_REQUIRE) reduce 145) ((T_REQUIRE_ONCE) reduce 145) ((T_RETURN) reduce 145) ((T_START_HEREDOC) reduce 145) ((T_STATIC) reduce 145) ((T_STRING) reduce 145) ((T_STRING_CAST) reduce 145) ((T_SWITCH) reduce 145) ((T_THROW) reduce 145) ((T_TRAIT) reduce 145) ((T_TRAIT_C) reduce 145) ((T_TRY) reduce 145) ((T_UNSET) reduce 145) ((T_UNSET_CAST) reduce 145) ((T_VARIABLE) reduce 145) ((T_WHILE) reduce 145) ((T_YIELD) reduce 145) ((T_YIELD_FROM) reduce 145) (("[") reduce 145) (("`") reduce 145) (("{") reduce 145) (("~") reduce 145)) 19617 ((("!") reduce 164) (("\"") reduce 164) (("$") reduce 164) (("(") reduce 164) (("+") reduce 164) (("-") reduce 164) ((";") reduce 164) (("@") reduce 164) ((T_ABSTRACT) reduce 164) ((T_ARRAY) reduce 164) ((T_ARRAY_CAST) reduce 164) ((T_ATTRIBUTE) reduce 164) ((T_BOOL_CAST) reduce 164) ((T_BREAK) reduce 164) ((T_CLASS) reduce 164) ((T_CLASS_C) reduce 164) ((T_CLONE) reduce 164) ((T_CONSTANT_ENCAPSED_STRING) reduce 164) ((T_CONTINUE) reduce 164) ((T_DEC) reduce 164) ((T_DECLARE) reduce 164) ((T_DIR) reduce 164) ((T_DNUMBER) reduce 164) ((T_DO) reduce 164) ((T_DOUBLE_CAST) reduce 164) ((T_ECHO) reduce 164) ((T_ELSE) reduce 164) ((T_ELSEIF) reduce 164) ((T_EMPTY) reduce 164) ((T_ENDFOR) reduce 164) ((T_ENUM) reduce 164) ((T_EVAL) reduce 164) ((T_EXIT) reduce 164) ((T_FILE) reduce 164) ((T_FINAL) reduce 164) ((T_FN) reduce 164) ((T_FOR) reduce 164) ((T_FOREACH) reduce 164) ((T_FUNCTION) reduce 164) ((T_FUNC_C) reduce 164) ((T_GLOBAL) reduce 164) ((T_GOTO) reduce 164) ((T_HALT_COMPILER) reduce 164) ((T_IF) reduce 164) ((T_INC) reduce 164) ((T_INCLUDE) reduce 164) ((T_INCLUDE_ONCE) reduce 164) ((T_INLINE_HTML) reduce 164) ((T_INTERFACE) reduce 164) ((T_INT_CAST) reduce 164) ((T_ISSET) reduce 164) ((T_LINE) reduce 164) ((T_LIST) reduce 164) ((T_LNUMBER) reduce 164) ((T_MATCH) reduce 164) ((T_METHOD_C) reduce 164) ((T_NAME_FULLY_QUALIFIED) reduce 164) ((T_NAME_QUALIFIED) reduce 164) ((T_NAME_RELATIVE) reduce 164) ((T_NEW) reduce 164) ((T_NS_C) reduce 164) ((T_OBJECT_CAST) reduce 164) ((T_PRINT) reduce 164) ((T_READONLY) reduce 164) ((T_REQUIRE) reduce 164) ((T_REQUIRE_ONCE) reduce 164) ((T_RETURN) reduce 164) ((T_START_HEREDOC) reduce 164) ((T_STATIC) reduce 164) ((T_STRING) reduce 164) ((T_STRING_CAST) reduce 164) ((T_SWITCH) reduce 164) ((T_THROW) reduce 164) ((T_TRAIT) reduce 164) ((T_TRAIT_C) reduce 164) ((T_TRY) reduce 164) ((T_UNSET) reduce 164) ((T_UNSET_CAST) reduce 164) ((T_VARIABLE) reduce 164) ((T_WHILE) reduce 164) ((T_YIELD) reduce 164) ((T_YIELD_FROM) reduce 164) (("[") reduce 164) (("`") reduce 164) (("{") reduce 164) (("~") reduce 164)) 19627 ((("!") reduce 158) (("\"") reduce 158) (("$") reduce 158) (("(") reduce 158) (("+") reduce 158) (("-") reduce 158) ((";") reduce 158) (("@") reduce 158) ((T_ABSTRACT) reduce 158) ((T_ARRAY) reduce 158) ((T_ARRAY_CAST) reduce 158) ((T_ATTRIBUTE) reduce 158) ((T_BOOL_CAST) reduce 158) ((T_BREAK) reduce 158) ((T_CLASS) reduce 158) ((T_CLASS_C) reduce 158) ((T_CLONE) reduce 158) ((T_CONSTANT_ENCAPSED_STRING) reduce 158) ((T_CONTINUE) reduce 158) ((T_DEC) reduce 158) ((T_DECLARE) reduce 158) ((T_DIR) reduce 158) ((T_DNUMBER) reduce 158) ((T_DO) reduce 158) ((T_DOUBLE_CAST) reduce 158) ((T_ECHO) reduce 158) ((T_ELSE) reduce 158) ((T_ELSEIF) reduce 158) ((T_EMPTY) reduce 158) ((T_ENDFOR) reduce 158) ((T_ENUM) reduce 158) ((T_EVAL) reduce 158) ((T_EXIT) reduce 158) ((T_FILE) reduce 158) ((T_FINAL) reduce 158) ((T_FN) reduce 158) ((T_FOR) reduce 158) ((T_FOREACH) reduce 158) ((T_FUNCTION) reduce 158) ((T_FUNC_C) reduce 158) ((T_GLOBAL) reduce 158) ((T_GOTO) reduce 158) ((T_HALT_COMPILER) reduce 158) ((T_IF) reduce 158) ((T_INC) reduce 158) ((T_INCLUDE) reduce 158) ((T_INCLUDE_ONCE) reduce 158) ((T_INLINE_HTML) reduce 158) ((T_INTERFACE) reduce 158) ((T_INT_CAST) reduce 158) ((T_ISSET) reduce 158) ((T_LINE) reduce 158) ((T_LIST) reduce 158) ((T_LNUMBER) reduce 158) ((T_MATCH) reduce 158) ((T_METHOD_C) reduce 158) ((T_NAME_FULLY_QUALIFIED) reduce 158) ((T_NAME_QUALIFIED) reduce 158) ((T_NAME_RELATIVE) reduce 158) ((T_NEW) reduce 158) ((T_NS_C) reduce 158) ((T_OBJECT_CAST) reduce 158) ((T_PRINT) reduce 158) ((T_READONLY) reduce 158) ((T_REQUIRE) reduce 158) ((T_REQUIRE_ONCE) reduce 158) ((T_RETURN) reduce 158) ((T_START_HEREDOC) reduce 158) ((T_STATIC) reduce 158) ((T_STRING) reduce 158) ((T_STRING_CAST) reduce 158) ((T_SWITCH) reduce 158) ((T_THROW) reduce 158) ((T_TRAIT) reduce 158) ((T_TRAIT_C) reduce 158) ((T_TRY) reduce 158) ((T_UNSET) reduce 158) ((T_UNSET_CAST) reduce 158) ((T_VARIABLE) reduce 158) ((T_WHILE) reduce 158) ((T_YIELD) reduce 158) ((T_YIELD_FROM) reduce 158) (("[") reduce 158) (("`") reduce 158) (("{") reduce 158) (("~") reduce 158)) 19635 ((("!") reduce 147) (("\"") reduce 147) (("$") reduce 147) (("(") reduce 147) (("+") reduce 147) (("-") reduce 147) ((";") reduce 147) (("@") reduce 147) ((T_ABSTRACT) reduce 147) ((T_ARRAY) reduce 147) ((T_ARRAY_CAST) reduce 147) ((T_ATTRIBUTE) reduce 147) ((T_BOOL_CAST) reduce 147) ((T_BREAK) reduce 147) ((T_CLASS) reduce 147) ((T_CLASS_C) reduce 147) ((T_CLONE) reduce 147) ((T_CONSTANT_ENCAPSED_STRING) reduce 147) ((T_CONTINUE) reduce 147) ((T_DEC) reduce 147) ((T_DECLARE) reduce 147) ((T_DIR) reduce 147) ((T_DNUMBER) reduce 147) ((T_DO) reduce 147) ((T_DOUBLE_CAST) reduce 147) ((T_ECHO) reduce 147) ((T_ELSE) reduce 147) ((T_ELSEIF) reduce 147) ((T_EMPTY) reduce 147) ((T_ENDFOR) reduce 147) ((T_ENUM) reduce 147) ((T_EVAL) reduce 147) ((T_EXIT) reduce 147) ((T_FILE) reduce 147) ((T_FINAL) reduce 147) ((T_FN) reduce 147) ((T_FOR) reduce 147) ((T_FOREACH) reduce 147) ((T_FUNCTION) reduce 147) ((T_FUNC_C) reduce 147) ((T_GLOBAL) reduce 147) ((T_GOTO) reduce 147) ((T_HALT_COMPILER) reduce 147) ((T_IF) reduce 147) ((T_INC) reduce 147) ((T_INCLUDE) reduce 147) ((T_INCLUDE_ONCE) reduce 147) ((T_INLINE_HTML) reduce 147) ((T_INTERFACE) reduce 147) ((T_INT_CAST) reduce 147) ((T_ISSET) reduce 147) ((T_LINE) reduce 147) ((T_LIST) reduce 147) ((T_LNUMBER) reduce 147) ((T_MATCH) reduce 147) ((T_METHOD_C) reduce 147) ((T_NAME_FULLY_QUALIFIED) reduce 147) ((T_NAME_QUALIFIED) reduce 147) ((T_NAME_RELATIVE) reduce 147) ((T_NEW) reduce 147) ((T_NS_C) reduce 147) ((T_OBJECT_CAST) reduce 147) ((T_PRINT) reduce 147) ((T_READONLY) reduce 147) ((T_REQUIRE) reduce 147) ((T_REQUIRE_ONCE) reduce 147) ((T_RETURN) reduce 147) ((T_START_HEREDOC) reduce 147) ((T_STATIC) reduce 147) ((T_STRING) reduce 147) ((T_STRING_CAST) reduce 147) ((T_SWITCH) reduce 147) ((T_THROW) reduce 147) ((T_TRAIT) reduce 147) ((T_TRAIT_C) reduce 147) ((T_TRY) reduce 147) ((T_UNSET) reduce 147) ((T_UNSET_CAST) reduce 147) ((T_VARIABLE) reduce 147) ((T_WHILE) reduce 147) ((T_YIELD) reduce 147) ((T_YIELD_FROM) reduce 147) (("[") reduce 147) (("`") reduce 147) (("{") reduce 147) (("~") reduce 147)) 19638 ((("!") reduce 146) (("\"") reduce 146) (("$") reduce 146) (("(") reduce 146) (("+") reduce 146) (("-") reduce 146) ((";") reduce 146) (("@") reduce 146) ((T_ABSTRACT) reduce 146) ((T_ARRAY) reduce 146) ((T_ARRAY_CAST) reduce 146) ((T_ATTRIBUTE) reduce 146) ((T_BOOL_CAST) reduce 146) ((T_BREAK) reduce 146) ((T_CLASS) reduce 146) ((T_CLASS_C) reduce 146) ((T_CLONE) reduce 146) ((T_CONSTANT_ENCAPSED_STRING) reduce 146) ((T_CONTINUE) reduce 146) ((T_DEC) reduce 146) ((T_DECLARE) reduce 146) ((T_DIR) reduce 146) ((T_DNUMBER) reduce 146) ((T_DO) reduce 146) ((T_DOUBLE_CAST) reduce 146) ((T_ECHO) reduce 146) ((T_ELSE) reduce 146) ((T_ELSEIF) reduce 146) ((T_EMPTY) reduce 146) ((T_ENDFOR) reduce 146) ((T_ENUM) reduce 146) ((T_EVAL) reduce 146) ((T_EXIT) reduce 146) ((T_FILE) reduce 146) ((T_FINAL) reduce 146) ((T_FN) reduce 146) ((T_FOR) reduce 146) ((T_FOREACH) reduce 146) ((T_FUNCTION) reduce 146) ((T_FUNC_C) reduce 146) ((T_GLOBAL) reduce 146) ((T_GOTO) reduce 146) ((T_HALT_COMPILER) reduce 146) ((T_IF) reduce 146) ((T_INC) reduce 146) ((T_INCLUDE) reduce 146) ((T_INCLUDE_ONCE) reduce 146) ((T_INLINE_HTML) reduce 146) ((T_INTERFACE) reduce 146) ((T_INT_CAST) reduce 146) ((T_ISSET) reduce 146) ((T_LINE) reduce 146) ((T_LIST) reduce 146) ((T_LNUMBER) reduce 146) ((T_MATCH) reduce 146) ((T_METHOD_C) reduce 146) ((T_NAME_FULLY_QUALIFIED) reduce 146) ((T_NAME_QUALIFIED) reduce 146) ((T_NAME_RELATIVE) reduce 146) ((T_NEW) reduce 146) ((T_NS_C) reduce 146) ((T_OBJECT_CAST) reduce 146) ((T_PRINT) reduce 146) ((T_READONLY) reduce 146) ((T_REQUIRE) reduce 146) ((T_REQUIRE_ONCE) reduce 146) ((T_RETURN) reduce 146) ((T_START_HEREDOC) reduce 146) ((T_STATIC) reduce 146) ((T_STRING) reduce 146) ((T_STRING_CAST) reduce 146) ((T_SWITCH) reduce 146) ((T_THROW) reduce 146) ((T_TRAIT) reduce 146) ((T_TRAIT_C) reduce 146) ((T_TRY) reduce 146) ((T_UNSET) reduce 146) ((T_UNSET_CAST) reduce 146) ((T_VARIABLE) reduce 146) ((T_WHILE) reduce 146) ((T_YIELD) reduce 146) ((T_YIELD_FROM) reduce 146) (("[") reduce 146) (("`") reduce 146) (("{") reduce 146) (("~") reduce 146)) 19640 ((("!") reduce 242) (("\"") reduce 242) (("$") reduce 242) (("(") reduce 242) (("+") reduce 242) (("-") reduce 242) ((";") reduce 242) (("@") reduce 242) ((T_ABSTRACT) reduce 242) ((T_ARRAY) reduce 242) ((T_ARRAY_CAST) reduce 242) ((T_ATTRIBUTE) reduce 242) ((T_BOOL_CAST) reduce 242) ((T_BREAK) reduce 242) ((T_CLASS) reduce 242) ((T_CLASS_C) reduce 242) ((T_CLONE) reduce 242) ((T_CONSTANT_ENCAPSED_STRING) reduce 242) ((T_CONTINUE) reduce 242) ((T_DEC) reduce 242) ((T_DECLARE) reduce 242) ((T_DIR) reduce 242) ((T_DNUMBER) reduce 242) ((T_DO) reduce 242) ((T_DOUBLE_CAST) reduce 242) ((T_ECHO) reduce 242) ((T_ELSE) reduce 242) ((T_ELSEIF) reduce 242) ((T_EMPTY) reduce 242) ((T_ENDFOR) reduce 242) ((T_ENUM) reduce 242) ((T_EVAL) reduce 242) ((T_EXIT) reduce 242) ((T_FILE) reduce 242) ((T_FINAL) reduce 242) ((T_FN) reduce 242) ((T_FOR) reduce 242) ((T_FOREACH) reduce 242) ((T_FUNCTION) reduce 242) ((T_FUNC_C) reduce 242) ((T_GLOBAL) reduce 242) ((T_GOTO) reduce 242) ((T_HALT_COMPILER) reduce 242) ((T_IF) reduce 242) ((T_INC) reduce 242) ((T_INCLUDE) reduce 242) ((T_INCLUDE_ONCE) reduce 242) ((T_INLINE_HTML) reduce 242) ((T_INTERFACE) reduce 242) ((T_INT_CAST) reduce 242) ((T_ISSET) reduce 242) ((T_LINE) reduce 242) ((T_LIST) reduce 242) ((T_LNUMBER) reduce 242) ((T_MATCH) reduce 242) ((T_METHOD_C) reduce 242) ((T_NAME_FULLY_QUALIFIED) reduce 242) ((T_NAME_QUALIFIED) reduce 242) ((T_NAME_RELATIVE) reduce 242) ((T_NEW) reduce 242) ((T_NS_C) reduce 242) ((T_OBJECT_CAST) reduce 242) ((T_PRINT) reduce 242) ((T_READONLY) reduce 242) ((T_REQUIRE) reduce 242) ((T_REQUIRE_ONCE) reduce 242) ((T_RETURN) reduce 242) ((T_START_HEREDOC) reduce 242) ((T_STATIC) reduce 242) ((T_STRING) reduce 242) ((T_STRING_CAST) reduce 242) ((T_SWITCH) reduce 242) ((T_THROW) reduce 242) ((T_TRAIT) reduce 242) ((T_TRAIT_C) reduce 242) ((T_TRY) reduce 242) ((T_UNSET) reduce 242) ((T_UNSET_CAST) reduce 242) ((T_VARIABLE) reduce 242) ((T_WHILE) reduce 242) ((T_YIELD) reduce 242) ((T_YIELD_FROM) reduce 242) (("[") reduce 242) (("`") reduce 242) (("{") reduce 242) (("~") reduce 242)) 19643 ((("!") reduce 145) (("\"") reduce 145) (("$") reduce 145) (("(") reduce 145) (("+") reduce 145) (("-") reduce 145) ((";") reduce 145) (("@") reduce 145) ((T_ABSTRACT) reduce 145) ((T_ARRAY) reduce 145) ((T_ARRAY_CAST) reduce 145) ((T_ATTRIBUTE) reduce 145) ((T_BOOL_CAST) reduce 145) ((T_BREAK) reduce 145) ((T_CLASS) reduce 145) ((T_CLASS_C) reduce 145) ((T_CLONE) reduce 145) ((T_CONSTANT_ENCAPSED_STRING) reduce 145) ((T_CONTINUE) reduce 145) ((T_DEC) reduce 145) ((T_DECLARE) reduce 145) ((T_DIR) reduce 145) ((T_DNUMBER) reduce 145) ((T_DO) reduce 145) ((T_DOUBLE_CAST) reduce 145) ((T_ECHO) reduce 145) ((T_ELSE) reduce 145) ((T_ELSEIF) reduce 145) ((T_EMPTY) reduce 145) ((T_ENDFOR) reduce 145) ((T_ENUM) reduce 145) ((T_EVAL) reduce 145) ((T_EXIT) reduce 145) ((T_FILE) reduce 145) ((T_FINAL) reduce 145) ((T_FN) reduce 145) ((T_FOR) reduce 145) ((T_FOREACH) reduce 145) ((T_FUNCTION) reduce 145) ((T_FUNC_C) reduce 145) ((T_GLOBAL) reduce 145) ((T_GOTO) reduce 145) ((T_HALT_COMPILER) reduce 145) ((T_IF) reduce 145) ((T_INC) reduce 145) ((T_INCLUDE) reduce 145) ((T_INCLUDE_ONCE) reduce 145) ((T_INLINE_HTML) reduce 145) ((T_INTERFACE) reduce 145) ((T_INT_CAST) reduce 145) ((T_ISSET) reduce 145) ((T_LINE) reduce 145) ((T_LIST) reduce 145) ((T_LNUMBER) reduce 145) ((T_MATCH) reduce 145) ((T_METHOD_C) reduce 145) ((T_NAME_FULLY_QUALIFIED) reduce 145) ((T_NAME_QUALIFIED) reduce 145) ((T_NAME_RELATIVE) reduce 145) ((T_NEW) reduce 145) ((T_NS_C) reduce 145) ((T_OBJECT_CAST) reduce 145) ((T_PRINT) reduce 145) ((T_READONLY) reduce 145) ((T_REQUIRE) reduce 145) ((T_REQUIRE_ONCE) reduce 145) ((T_RETURN) reduce 145) ((T_START_HEREDOC) reduce 145) ((T_STATIC) reduce 145) ((T_STRING) reduce 145) ((T_STRING_CAST) reduce 145) ((T_SWITCH) reduce 145) ((T_THROW) reduce 145) ((T_TRAIT) reduce 145) ((T_TRAIT_C) reduce 145) ((T_TRY) reduce 145) ((T_UNSET) reduce 145) ((T_UNSET_CAST) reduce 145) ((T_VARIABLE) reduce 145) ((T_WHILE) reduce 145) ((T_YIELD) reduce 145) ((T_YIELD_FROM) reduce 145) (("[") reduce 145) (("`") reduce 145) (("{") reduce 145) (("~") reduce 145)) 19645 ((("!") reduce 244) (("\"") reduce 244) (("$") reduce 244) (("(") reduce 244) (("+") reduce 244) (("-") reduce 244) ((";") reduce 244) (("@") reduce 244) ((T_ABSTRACT) reduce 244) ((T_ARRAY) reduce 244) ((T_ARRAY_CAST) reduce 244) ((T_ATTRIBUTE) reduce 244) ((T_BOOL_CAST) reduce 244) ((T_BREAK) reduce 244) ((T_CLASS) reduce 244) ((T_CLASS_C) reduce 244) ((T_CLONE) reduce 244) ((T_CONSTANT_ENCAPSED_STRING) reduce 244) ((T_CONTINUE) reduce 244) ((T_DEC) reduce 244) ((T_DECLARE) reduce 244) ((T_DIR) reduce 244) ((T_DNUMBER) reduce 244) ((T_DO) reduce 244) ((T_DOUBLE_CAST) reduce 244) ((T_ECHO) reduce 244) ((T_ELSE) reduce 244) ((T_ELSEIF) reduce 244) ((T_EMPTY) reduce 244) ((T_ENDFOR) reduce 244) ((T_ENUM) reduce 244) ((T_EVAL) reduce 244) ((T_EXIT) reduce 244) ((T_FILE) reduce 244) ((T_FINAL) reduce 244) ((T_FN) reduce 244) ((T_FOR) reduce 244) ((T_FOREACH) reduce 244) ((T_FUNCTION) reduce 244) ((T_FUNC_C) reduce 244) ((T_GLOBAL) reduce 244) ((T_GOTO) reduce 244) ((T_HALT_COMPILER) reduce 244) ((T_IF) reduce 244) ((T_INC) reduce 244) ((T_INCLUDE) reduce 244) ((T_INCLUDE_ONCE) reduce 244) ((T_INLINE_HTML) reduce 244) ((T_INTERFACE) reduce 244) ((T_INT_CAST) reduce 244) ((T_ISSET) reduce 244) ((T_LINE) reduce 244) ((T_LIST) reduce 244) ((T_LNUMBER) reduce 244) ((T_MATCH) reduce 244) ((T_METHOD_C) reduce 244) ((T_NAME_FULLY_QUALIFIED) reduce 244) ((T_NAME_QUALIFIED) reduce 244) ((T_NAME_RELATIVE) reduce 244) ((T_NEW) reduce 244) ((T_NS_C) reduce 244) ((T_OBJECT_CAST) reduce 244) ((T_PRINT) reduce 244) ((T_READONLY) reduce 244) ((T_REQUIRE) reduce 244) ((T_REQUIRE_ONCE) reduce 244) ((T_RETURN) reduce 244) ((T_START_HEREDOC) reduce 244) ((T_STATIC) reduce 244) ((T_STRING) reduce 244) ((T_STRING_CAST) reduce 244) ((T_SWITCH) reduce 244) ((T_THROW) reduce 244) ((T_TRAIT) reduce 244) ((T_TRAIT_C) reduce 244) ((T_TRY) reduce 244) ((T_UNSET) reduce 244) ((T_UNSET_CAST) reduce 244) ((T_VARIABLE) reduce 244) ((T_WHILE) reduce 244) ((T_YIELD) reduce 244) ((T_YIELD_FROM) reduce 244) (("[") reduce 244) (("`") reduce 244) (("{") reduce 244) (("~") reduce 244)) 19646 ((("!") reduce 159) (("\"") reduce 159) (("$") reduce 159) (("(") reduce 159) (("+") reduce 159) (("-") reduce 159) ((";") reduce 159) (("@") reduce 159) ((T_ABSTRACT) reduce 159) ((T_ARRAY) reduce 159) ((T_ARRAY_CAST) reduce 159) ((T_ATTRIBUTE) reduce 159) ((T_BOOL_CAST) reduce 159) ((T_BREAK) reduce 159) ((T_CLASS) reduce 159) ((T_CLASS_C) reduce 159) ((T_CLONE) reduce 159) ((T_CONSTANT_ENCAPSED_STRING) reduce 159) ((T_CONTINUE) reduce 159) ((T_DEC) reduce 159) ((T_DECLARE) reduce 159) ((T_DIR) reduce 159) ((T_DNUMBER) reduce 159) ((T_DO) reduce 159) ((T_DOUBLE_CAST) reduce 159) ((T_ECHO) reduce 159) ((T_ELSE) reduce 159) ((T_ELSEIF) reduce 159) ((T_EMPTY) reduce 159) ((T_ENDFOR) reduce 159) ((T_ENUM) reduce 159) ((T_EVAL) reduce 159) ((T_EXIT) reduce 159) ((T_FILE) reduce 159) ((T_FINAL) reduce 159) ((T_FN) reduce 159) ((T_FOR) reduce 159) ((T_FOREACH) reduce 159) ((T_FUNCTION) reduce 159) ((T_FUNC_C) reduce 159) ((T_GLOBAL) reduce 159) ((T_GOTO) reduce 159) ((T_HALT_COMPILER) reduce 159) ((T_IF) reduce 159) ((T_INC) reduce 159) ((T_INCLUDE) reduce 159) ((T_INCLUDE_ONCE) reduce 159) ((T_INLINE_HTML) reduce 159) ((T_INTERFACE) reduce 159) ((T_INT_CAST) reduce 159) ((T_ISSET) reduce 159) ((T_LINE) reduce 159) ((T_LIST) reduce 159) ((T_LNUMBER) reduce 159) ((T_MATCH) reduce 159) ((T_METHOD_C) reduce 159) ((T_NAME_FULLY_QUALIFIED) reduce 159) ((T_NAME_QUALIFIED) reduce 159) ((T_NAME_RELATIVE) reduce 159) ((T_NEW) reduce 159) ((T_NS_C) reduce 159) ((T_OBJECT_CAST) reduce 159) ((T_PRINT) reduce 159) ((T_READONLY) reduce 159) ((T_REQUIRE) reduce 159) ((T_REQUIRE_ONCE) reduce 159) ((T_RETURN) reduce 159) ((T_START_HEREDOC) reduce 159) ((T_STATIC) reduce 159) ((T_STRING) reduce 159) ((T_STRING_CAST) reduce 159) ((T_SWITCH) reduce 159) ((T_THROW) reduce 159) ((T_TRAIT) reduce 159) ((T_TRAIT_C) reduce 159) ((T_TRY) reduce 159) ((T_UNSET) reduce 159) ((T_UNSET_CAST) reduce 159) ((T_VARIABLE) reduce 159) ((T_WHILE) reduce 159) ((T_YIELD) reduce 159) ((T_YIELD_FROM) reduce 159) (("[") reduce 159) (("`") reduce 159) (("{") reduce 159) (("~") reduce 159)) 19649 ((("!") reduce 247) (("\"") reduce 247) (("$") reduce 247) (("(") reduce 247) (("+") reduce 247) (("-") reduce 247) ((";") reduce 247) (("@") reduce 247) ((T_ABSTRACT) reduce 247) ((T_ARRAY) reduce 247) ((T_ARRAY_CAST) reduce 247) ((T_ATTRIBUTE) reduce 247) ((T_BOOL_CAST) reduce 247) ((T_BREAK) reduce 247) ((T_CLASS) reduce 247) ((T_CLASS_C) reduce 247) ((T_CLONE) reduce 247) ((T_CONSTANT_ENCAPSED_STRING) reduce 247) ((T_CONTINUE) reduce 247) ((T_DEC) reduce 247) ((T_DECLARE) reduce 247) ((T_DIR) reduce 247) ((T_DNUMBER) reduce 247) ((T_DO) reduce 247) ((T_DOUBLE_CAST) reduce 247) ((T_ECHO) reduce 247) ((T_ELSE) reduce 247) ((T_ELSEIF) reduce 247) ((T_EMPTY) reduce 247) ((T_ENDFOR) reduce 247) ((T_ENUM) reduce 247) ((T_EVAL) reduce 247) ((T_EXIT) reduce 247) ((T_FILE) reduce 247) ((T_FINAL) reduce 247) ((T_FN) reduce 247) ((T_FOR) reduce 247) ((T_FOREACH) reduce 247) ((T_FUNCTION) reduce 247) ((T_FUNC_C) reduce 247) ((T_GLOBAL) reduce 247) ((T_GOTO) reduce 247) ((T_HALT_COMPILER) reduce 247) ((T_IF) reduce 247) ((T_INC) reduce 247) ((T_INCLUDE) reduce 247) ((T_INCLUDE_ONCE) reduce 247) ((T_INLINE_HTML) reduce 247) ((T_INTERFACE) reduce 247) ((T_INT_CAST) reduce 247) ((T_ISSET) reduce 247) ((T_LINE) reduce 247) ((T_LIST) reduce 247) ((T_LNUMBER) reduce 247) ((T_MATCH) reduce 247) ((T_METHOD_C) reduce 247) ((T_NAME_FULLY_QUALIFIED) reduce 247) ((T_NAME_QUALIFIED) reduce 247) ((T_NAME_RELATIVE) reduce 247) ((T_NEW) reduce 247) ((T_NS_C) reduce 247) ((T_OBJECT_CAST) reduce 247) ((T_PRINT) reduce 247) ((T_READONLY) reduce 247) ((T_REQUIRE) reduce 247) ((T_REQUIRE_ONCE) reduce 247) ((T_RETURN) reduce 247) ((T_START_HEREDOC) reduce 247) ((T_STATIC) reduce 247) ((T_STRING) reduce 247) ((T_STRING_CAST) reduce 247) ((T_SWITCH) reduce 247) ((T_THROW) reduce 247) ((T_TRAIT) reduce 247) ((T_TRAIT_C) reduce 247) ((T_TRY) reduce 247) ((T_UNSET) reduce 247) ((T_UNSET_CAST) reduce 247) ((T_VARIABLE) reduce 247) ((T_WHILE) reduce 247) ((T_YIELD) reduce 247) ((T_YIELD_FROM) reduce 247) (("[") reduce 247) (("`") reduce 247) (("{") reduce 247) (("~") reduce 247)) 19653 ((("!") reduce 248) (("\"") reduce 248) (("$") reduce 248) (("(") reduce 248) (("+") reduce 248) (("-") reduce 248) ((";") reduce 248) (("@") reduce 248) ((T_ABSTRACT) reduce 248) ((T_ARRAY) reduce 248) ((T_ARRAY_CAST) reduce 248) ((T_ATTRIBUTE) reduce 248) ((T_BOOL_CAST) reduce 248) ((T_BREAK) reduce 248) ((T_CLASS) reduce 248) ((T_CLASS_C) reduce 248) ((T_CLONE) reduce 248) ((T_CONSTANT_ENCAPSED_STRING) reduce 248) ((T_CONTINUE) reduce 248) ((T_DEC) reduce 248) ((T_DECLARE) reduce 248) ((T_DIR) reduce 248) ((T_DNUMBER) reduce 248) ((T_DO) reduce 248) ((T_DOUBLE_CAST) reduce 248) ((T_ECHO) reduce 248) ((T_ELSE) reduce 248) ((T_ELSEIF) reduce 248) ((T_EMPTY) reduce 248) ((T_ENDFOR) reduce 248) ((T_ENUM) reduce 248) ((T_EVAL) reduce 248) ((T_EXIT) reduce 248) ((T_FILE) reduce 248) ((T_FINAL) reduce 248) ((T_FN) reduce 248) ((T_FOR) reduce 248) ((T_FOREACH) reduce 248) ((T_FUNCTION) reduce 248) ((T_FUNC_C) reduce 248) ((T_GLOBAL) reduce 248) ((T_GOTO) reduce 248) ((T_HALT_COMPILER) reduce 248) ((T_IF) reduce 248) ((T_INC) reduce 248) ((T_INCLUDE) reduce 248) ((T_INCLUDE_ONCE) reduce 248) ((T_INLINE_HTML) reduce 248) ((T_INTERFACE) reduce 248) ((T_INT_CAST) reduce 248) ((T_ISSET) reduce 248) ((T_LINE) reduce 248) ((T_LIST) reduce 248) ((T_LNUMBER) reduce 248) ((T_MATCH) reduce 248) ((T_METHOD_C) reduce 248) ((T_NAME_FULLY_QUALIFIED) reduce 248) ((T_NAME_QUALIFIED) reduce 248) ((T_NAME_RELATIVE) reduce 248) ((T_NEW) reduce 248) ((T_NS_C) reduce 248) ((T_OBJECT_CAST) reduce 248) ((T_PRINT) reduce 248) ((T_READONLY) reduce 248) ((T_REQUIRE) reduce 248) ((T_REQUIRE_ONCE) reduce 248) ((T_RETURN) reduce 248) ((T_START_HEREDOC) reduce 248) ((T_STATIC) reduce 248) ((T_STRING) reduce 248) ((T_STRING_CAST) reduce 248) ((T_SWITCH) reduce 248) ((T_THROW) reduce 248) ((T_TRAIT) reduce 248) ((T_TRAIT_C) reduce 248) ((T_TRY) reduce 248) ((T_UNSET) reduce 248) ((T_UNSET_CAST) reduce 248) ((T_VARIABLE) reduce 248) ((T_WHILE) reduce 248) ((T_YIELD) reduce 248) ((T_YIELD_FROM) reduce 248) (("[") reduce 248) (("`") reduce 248) (("{") reduce 248) (("~") reduce 248)) 19658 ((("!") reduce 239) (("\"") reduce 239) (("$") reduce 239) (("(") reduce 239) (("+") reduce 239) (("-") reduce 239) ((";") reduce 239) (("@") reduce 239) ((T_ABSTRACT) reduce 239) ((T_ARRAY) reduce 239) ((T_ARRAY_CAST) reduce 239) ((T_ATTRIBUTE) reduce 239) ((T_BOOL_CAST) reduce 239) ((T_BREAK) reduce 239) ((T_CLASS) reduce 239) ((T_CLASS_C) reduce 239) ((T_CLONE) reduce 239) ((T_CONSTANT_ENCAPSED_STRING) reduce 239) ((T_CONTINUE) reduce 239) ((T_DEC) reduce 239) ((T_DECLARE) reduce 239) ((T_DIR) reduce 239) ((T_DNUMBER) reduce 239) ((T_DO) reduce 239) ((T_DOUBLE_CAST) reduce 239) ((T_ECHO) reduce 239) ((T_ELSE) reduce 239) ((T_ELSEIF) reduce 239) ((T_EMPTY) reduce 239) ((T_ENDFOR) reduce 239) ((T_ENUM) reduce 239) ((T_EVAL) reduce 239) ((T_EXIT) reduce 239) ((T_FILE) reduce 239) ((T_FINAL) reduce 239) ((T_FN) reduce 239) ((T_FOR) reduce 239) ((T_FOREACH) reduce 239) ((T_FUNCTION) reduce 239) ((T_FUNC_C) reduce 239) ((T_GLOBAL) reduce 239) ((T_GOTO) reduce 239) ((T_HALT_COMPILER) reduce 239) ((T_IF) reduce 239) ((T_INC) reduce 239) ((T_INCLUDE) reduce 239) ((T_INCLUDE_ONCE) reduce 239) ((T_INLINE_HTML) reduce 239) ((T_INTERFACE) reduce 239) ((T_INT_CAST) reduce 239) ((T_ISSET) reduce 239) ((T_LINE) reduce 239) ((T_LIST) reduce 239) ((T_LNUMBER) reduce 239) ((T_MATCH) reduce 239) ((T_METHOD_C) reduce 239) ((T_NAME_FULLY_QUALIFIED) reduce 239) ((T_NAME_QUALIFIED) reduce 239) ((T_NAME_RELATIVE) reduce 239) ((T_NEW) reduce 239) ((T_NS_C) reduce 239) ((T_OBJECT_CAST) reduce 239) ((T_PRINT) reduce 239) ((T_READONLY) reduce 239) ((T_REQUIRE) reduce 239) ((T_REQUIRE_ONCE) reduce 239) ((T_RETURN) reduce 239) ((T_START_HEREDOC) reduce 239) ((T_STATIC) reduce 239) ((T_STRING) reduce 239) ((T_STRING_CAST) reduce 239) ((T_SWITCH) reduce 239) ((T_THROW) reduce 239) ((T_TRAIT) reduce 239) ((T_TRAIT_C) reduce 239) ((T_TRY) reduce 239) ((T_UNSET) reduce 239) ((T_UNSET_CAST) reduce 239) ((T_VARIABLE) reduce 239) ((T_WHILE) reduce 239) ((T_YIELD) reduce 239) ((T_YIELD_FROM) reduce 239) (("[") reduce 239) (("`") reduce 239) (("{") reduce 239) (("~") reduce 239)) 19659 ((("!") reduce 148) (("\"") reduce 148) (("$") reduce 148) (("(") reduce 148) (("+") reduce 148) (("-") reduce 148) ((";") reduce 148) (("@") reduce 148) ((T_ABSTRACT) reduce 148) ((T_ARRAY) reduce 148) ((T_ARRAY_CAST) reduce 148) ((T_ATTRIBUTE) reduce 148) ((T_BOOL_CAST) reduce 148) ((T_BREAK) reduce 148) ((T_CLASS) reduce 148) ((T_CLASS_C) reduce 148) ((T_CLONE) reduce 148) ((T_CONSTANT_ENCAPSED_STRING) reduce 148) ((T_CONTINUE) reduce 148) ((T_DEC) reduce 148) ((T_DECLARE) reduce 148) ((T_DIR) reduce 148) ((T_DNUMBER) reduce 148) ((T_DO) reduce 148) ((T_DOUBLE_CAST) reduce 148) ((T_ECHO) reduce 148) ((T_ELSE) reduce 148) ((T_ELSEIF) reduce 148) ((T_EMPTY) reduce 148) ((T_ENDFOR) reduce 148) ((T_ENUM) reduce 148) ((T_EVAL) reduce 148) ((T_EXIT) reduce 148) ((T_FILE) reduce 148) ((T_FINAL) reduce 148) ((T_FN) reduce 148) ((T_FOR) reduce 148) ((T_FOREACH) reduce 148) ((T_FUNCTION) reduce 148) ((T_FUNC_C) reduce 148) ((T_GLOBAL) reduce 148) ((T_GOTO) reduce 148) ((T_HALT_COMPILER) reduce 148) ((T_IF) reduce 148) ((T_INC) reduce 148) ((T_INCLUDE) reduce 148) ((T_INCLUDE_ONCE) reduce 148) ((T_INLINE_HTML) reduce 148) ((T_INTERFACE) reduce 148) ((T_INT_CAST) reduce 148) ((T_ISSET) reduce 148) ((T_LINE) reduce 148) ((T_LIST) reduce 148) ((T_LNUMBER) reduce 148) ((T_MATCH) reduce 148) ((T_METHOD_C) reduce 148) ((T_NAME_FULLY_QUALIFIED) reduce 148) ((T_NAME_QUALIFIED) reduce 148) ((T_NAME_RELATIVE) reduce 148) ((T_NEW) reduce 148) ((T_NS_C) reduce 148) ((T_OBJECT_CAST) reduce 148) ((T_PRINT) reduce 148) ((T_READONLY) reduce 148) ((T_REQUIRE) reduce 148) ((T_REQUIRE_ONCE) reduce 148) ((T_RETURN) reduce 148) ((T_START_HEREDOC) reduce 148) ((T_STATIC) reduce 148) ((T_STRING) reduce 148) ((T_STRING_CAST) reduce 148) ((T_SWITCH) reduce 148) ((T_THROW) reduce 148) ((T_TRAIT) reduce 148) ((T_TRAIT_C) reduce 148) ((T_TRY) reduce 148) ((T_UNSET) reduce 148) ((T_UNSET_CAST) reduce 148) ((T_VARIABLE) reduce 148) ((T_WHILE) reduce 148) ((T_YIELD) reduce 148) ((T_YIELD_FROM) reduce 148) (("[") reduce 148) (("`") reduce 148) (("{") reduce 148) (("~") reduce 148)) 19662 ((("!") reduce 240) (("\"") reduce 240) (("$") reduce 240) (("(") reduce 240) (("+") reduce 240) (("-") reduce 240) ((";") reduce 240) (("@") reduce 240) ((T_ABSTRACT) reduce 240) ((T_ARRAY) reduce 240) ((T_ARRAY_CAST) reduce 240) ((T_ATTRIBUTE) reduce 240) ((T_BOOL_CAST) reduce 240) ((T_BREAK) reduce 240) ((T_CLASS) reduce 240) ((T_CLASS_C) reduce 240) ((T_CLONE) reduce 240) ((T_CONSTANT_ENCAPSED_STRING) reduce 240) ((T_CONTINUE) reduce 240) ((T_DEC) reduce 240) ((T_DECLARE) reduce 240) ((T_DIR) reduce 240) ((T_DNUMBER) reduce 240) ((T_DO) reduce 240) ((T_DOUBLE_CAST) reduce 240) ((T_ECHO) reduce 240) ((T_ELSE) reduce 240) ((T_ELSEIF) reduce 240) ((T_EMPTY) reduce 240) ((T_ENDFOR) reduce 240) ((T_ENUM) reduce 240) ((T_EVAL) reduce 240) ((T_EXIT) reduce 240) ((T_FILE) reduce 240) ((T_FINAL) reduce 240) ((T_FN) reduce 240) ((T_FOR) reduce 240) ((T_FOREACH) reduce 240) ((T_FUNCTION) reduce 240) ((T_FUNC_C) reduce 240) ((T_GLOBAL) reduce 240) ((T_GOTO) reduce 240) ((T_HALT_COMPILER) reduce 240) ((T_IF) reduce 240) ((T_INC) reduce 240) ((T_INCLUDE) reduce 240) ((T_INCLUDE_ONCE) reduce 240) ((T_INLINE_HTML) reduce 240) ((T_INTERFACE) reduce 240) ((T_INT_CAST) reduce 240) ((T_ISSET) reduce 240) ((T_LINE) reduce 240) ((T_LIST) reduce 240) ((T_LNUMBER) reduce 240) ((T_MATCH) reduce 240) ((T_METHOD_C) reduce 240) ((T_NAME_FULLY_QUALIFIED) reduce 240) ((T_NAME_QUALIFIED) reduce 240) ((T_NAME_RELATIVE) reduce 240) ((T_NEW) reduce 240) ((T_NS_C) reduce 240) ((T_OBJECT_CAST) reduce 240) ((T_PRINT) reduce 240) ((T_READONLY) reduce 240) ((T_REQUIRE) reduce 240) ((T_REQUIRE_ONCE) reduce 240) ((T_RETURN) reduce 240) ((T_START_HEREDOC) reduce 240) ((T_STATIC) reduce 240) ((T_STRING) reduce 240) ((T_STRING_CAST) reduce 240) ((T_SWITCH) reduce 240) ((T_THROW) reduce 240) ((T_TRAIT) reduce 240) ((T_TRAIT_C) reduce 240) ((T_TRY) reduce 240) ((T_UNSET) reduce 240) ((T_UNSET_CAST) reduce 240) ((T_VARIABLE) reduce 240) ((T_WHILE) reduce 240) ((T_YIELD) reduce 240) ((T_YIELD_FROM) reduce 240) (("[") reduce 240) (("`") reduce 240) (("{") reduce 240) (("~") reduce 240)) 19667 ((("!") reduce 160) (("\"") reduce 160) (("$") reduce 160) (("(") reduce 160) (("+") reduce 160) (("-") reduce 160) ((";") reduce 160) (("@") reduce 160) ((T_ABSTRACT) reduce 160) ((T_ARRAY) reduce 160) ((T_ARRAY_CAST) reduce 160) ((T_ATTRIBUTE) reduce 160) ((T_BOOL_CAST) reduce 160) ((T_BREAK) reduce 160) ((T_CLASS) reduce 160) ((T_CLASS_C) reduce 160) ((T_CLONE) reduce 160) ((T_CONSTANT_ENCAPSED_STRING) reduce 160) ((T_CONTINUE) reduce 160) ((T_DEC) reduce 160) ((T_DECLARE) reduce 160) ((T_DIR) reduce 160) ((T_DNUMBER) reduce 160) ((T_DO) reduce 160) ((T_DOUBLE_CAST) reduce 160) ((T_ECHO) reduce 160) ((T_ELSE) reduce 160) ((T_ELSEIF) reduce 160) ((T_EMPTY) reduce 160) ((T_ENDFOR) reduce 160) ((T_ENUM) reduce 160) ((T_EVAL) reduce 160) ((T_EXIT) reduce 160) ((T_FILE) reduce 160) ((T_FINAL) reduce 160) ((T_FN) reduce 160) ((T_FOR) reduce 160) ((T_FOREACH) reduce 160) ((T_FUNCTION) reduce 160) ((T_FUNC_C) reduce 160) ((T_GLOBAL) reduce 160) ((T_GOTO) reduce 160) ((T_HALT_COMPILER) reduce 160) ((T_IF) reduce 160) ((T_INC) reduce 160) ((T_INCLUDE) reduce 160) ((T_INCLUDE_ONCE) reduce 160) ((T_INLINE_HTML) reduce 160) ((T_INTERFACE) reduce 160) ((T_INT_CAST) reduce 160) ((T_ISSET) reduce 160) ((T_LINE) reduce 160) ((T_LIST) reduce 160) ((T_LNUMBER) reduce 160) ((T_MATCH) reduce 160) ((T_METHOD_C) reduce 160) ((T_NAME_FULLY_QUALIFIED) reduce 160) ((T_NAME_QUALIFIED) reduce 160) ((T_NAME_RELATIVE) reduce 160) ((T_NEW) reduce 160) ((T_NS_C) reduce 160) ((T_OBJECT_CAST) reduce 160) ((T_PRINT) reduce 160) ((T_READONLY) reduce 160) ((T_REQUIRE) reduce 160) ((T_REQUIRE_ONCE) reduce 160) ((T_RETURN) reduce 160) ((T_START_HEREDOC) reduce 160) ((T_STATIC) reduce 160) ((T_STRING) reduce 160) ((T_STRING_CAST) reduce 160) ((T_SWITCH) reduce 160) ((T_THROW) reduce 160) ((T_TRAIT) reduce 160) ((T_TRAIT_C) reduce 160) ((T_TRY) reduce 160) ((T_UNSET) reduce 160) ((T_UNSET_CAST) reduce 160) ((T_VARIABLE) reduce 160) ((T_WHILE) reduce 160) ((T_YIELD) reduce 160) ((T_YIELD_FROM) reduce 160) (("[") reduce 160) (("`") reduce 160) (("{") reduce 160) (("~") reduce 160)) 19670 ((("!") reduce 168) (("\"") reduce 168) (("$") reduce 168) (("(") reduce 168) (("+") reduce 168) (("-") reduce 168) ((";") reduce 168) (("@") reduce 168) ((T_ABSTRACT) reduce 168) ((T_ARRAY) reduce 168) ((T_ARRAY_CAST) reduce 168) ((T_ATTRIBUTE) reduce 168) ((T_BOOL_CAST) reduce 168) ((T_BREAK) reduce 168) ((T_CATCH) reduce 168) ((T_CLASS) reduce 168) ((T_CLASS_C) reduce 168) ((T_CLONE) reduce 168) ((T_CONSTANT_ENCAPSED_STRING) reduce 168) ((T_CONTINUE) reduce 168) ((T_DEC) reduce 168) ((T_DECLARE) reduce 168) ((T_DIR) reduce 168) ((T_DNUMBER) reduce 168) ((T_DO) reduce 168) ((T_DOUBLE_CAST) reduce 168) ((T_ECHO) reduce 168) ((T_ELSE) reduce 168) ((T_ELSEIF) reduce 168) ((T_EMPTY) reduce 168) ((T_ENDFOR) reduce 168) ((T_ENUM) reduce 168) ((T_EVAL) reduce 168) ((T_EXIT) reduce 168) ((T_FILE) reduce 168) ((T_FINAL) reduce 168) ((T_FINALLY) reduce 168) ((T_FN) reduce 168) ((T_FOR) reduce 168) ((T_FOREACH) reduce 168) ((T_FUNCTION) reduce 168) ((T_FUNC_C) reduce 168) ((T_GLOBAL) reduce 168) ((T_GOTO) reduce 168) ((T_HALT_COMPILER) reduce 168) ((T_IF) reduce 168) ((T_INC) reduce 168) ((T_INCLUDE) reduce 168) ((T_INCLUDE_ONCE) reduce 168) ((T_INLINE_HTML) reduce 168) ((T_INTERFACE) reduce 168) ((T_INT_CAST) reduce 168) ((T_ISSET) reduce 168) ((T_LINE) reduce 168) ((T_LIST) reduce 168) ((T_LNUMBER) reduce 168) ((T_MATCH) reduce 168) ((T_METHOD_C) reduce 168) ((T_NAME_FULLY_QUALIFIED) reduce 168) ((T_NAME_QUALIFIED) reduce 168) ((T_NAME_RELATIVE) reduce 168) ((T_NEW) reduce 168) ((T_NS_C) reduce 168) ((T_OBJECT_CAST) reduce 168) ((T_PRINT) reduce 168) ((T_READONLY) reduce 168) ((T_REQUIRE) reduce 168) ((T_REQUIRE_ONCE) reduce 168) ((T_RETURN) reduce 168) ((T_START_HEREDOC) reduce 168) ((T_STATIC) reduce 168) ((T_STRING) reduce 168) ((T_STRING_CAST) reduce 168) ((T_SWITCH) reduce 168) ((T_THROW) reduce 168) ((T_TRAIT) reduce 168) ((T_TRAIT_C) reduce 168) ((T_TRY) reduce 168) ((T_UNSET) reduce 168) ((T_UNSET_CAST) reduce 168) ((T_VARIABLE) reduce 168) ((T_WHILE) reduce 168) ((T_YIELD) reduce 168) ((T_YIELD_FROM) reduce 168) (("[") reduce 168) (("`") reduce 168) (("{") reduce 168) (("~") reduce 168)) 19671 ((("!") reduce 174) (("\"") reduce 174) (("$") reduce 174) (("(") reduce 174) (("+") reduce 174) (("-") reduce 174) ((";") reduce 174) (("@") reduce 174) ((T_ABSTRACT) reduce 174) ((T_ARRAY) reduce 174) ((T_ARRAY_CAST) reduce 174) ((T_ATTRIBUTE) reduce 174) ((T_BOOL_CAST) reduce 174) ((T_BREAK) reduce 174) ((T_CATCH) shift) ((T_CLASS) reduce 174) ((T_CLASS_C) reduce 174) ((T_CLONE) reduce 174) ((T_CONSTANT_ENCAPSED_STRING) reduce 174) ((T_CONTINUE) reduce 174) ((T_DEC) reduce 174) ((T_DECLARE) reduce 174) ((T_DIR) reduce 174) ((T_DNUMBER) reduce 174) ((T_DO) reduce 174) ((T_DOUBLE_CAST) reduce 174) ((T_ECHO) reduce 174) ((T_ELSE) reduce 174) ((T_ELSEIF) reduce 174) ((T_EMPTY) reduce 174) ((T_ENDFOR) reduce 174) ((T_ENUM) reduce 174) ((T_EVAL) reduce 174) ((T_EXIT) reduce 174) ((T_FILE) reduce 174) ((T_FINAL) reduce 174) ((T_FINALLY) shift) ((T_FN) reduce 174) ((T_FOR) reduce 174) ((T_FOREACH) reduce 174) ((T_FUNCTION) reduce 174) ((T_FUNC_C) reduce 174) ((T_GLOBAL) reduce 174) ((T_GOTO) reduce 174) ((T_HALT_COMPILER) reduce 174) ((T_IF) reduce 174) ((T_INC) reduce 174) ((T_INCLUDE) reduce 174) ((T_INCLUDE_ONCE) reduce 174) ((T_INLINE_HTML) reduce 174) ((T_INTERFACE) reduce 174) ((T_INT_CAST) reduce 174) ((T_ISSET) reduce 174) ((T_LINE) reduce 174) ((T_LIST) reduce 174) ((T_LNUMBER) reduce 174) ((T_MATCH) reduce 174) ((T_METHOD_C) reduce 174) ((T_NAME_FULLY_QUALIFIED) reduce 174) ((T_NAME_QUALIFIED) reduce 174) ((T_NAME_RELATIVE) reduce 174) ((T_NEW) reduce 174) ((T_NS_C) reduce 174) ((T_OBJECT_CAST) reduce 174) ((T_PRINT) reduce 174) ((T_READONLY) reduce 174) ((T_REQUIRE) reduce 174) ((T_REQUIRE_ONCE) reduce 174) ((T_RETURN) reduce 174) ((T_START_HEREDOC) reduce 174) ((T_STATIC) reduce 174) ((T_STRING) reduce 174) ((T_STRING_CAST) reduce 174) ((T_SWITCH) reduce 174) ((T_THROW) reduce 174) ((T_TRAIT) reduce 174) ((T_TRAIT_C) reduce 174) ((T_TRY) reduce 174) ((T_UNSET) reduce 174) ((T_UNSET_CAST) reduce 174) ((T_VARIABLE) reduce 174) ((T_WHILE) reduce 174) ((T_YIELD) reduce 174) ((T_YIELD_FROM) reduce 174) (("[") reduce 174) (("`") reduce 174) (("{") reduce 174) (("~") reduce 174)) 19674 ((("!") reduce 165) (("\"") reduce 165) (("$") reduce 165) (("(") reduce 165) (("+") reduce 165) (("-") reduce 165) ((";") reduce 165) (("@") reduce 165) ((T_ABSTRACT) reduce 165) ((T_ARRAY) reduce 165) ((T_ARRAY_CAST) reduce 165) ((T_ATTRIBUTE) reduce 165) ((T_BOOL_CAST) reduce 165) ((T_BREAK) reduce 165) ((T_CLASS) reduce 165) ((T_CLASS_C) reduce 165) ((T_CLONE) reduce 165) ((T_CONSTANT_ENCAPSED_STRING) reduce 165) ((T_CONTINUE) reduce 165) ((T_DEC) reduce 165) ((T_DECLARE) reduce 165) ((T_DIR) reduce 165) ((T_DNUMBER) reduce 165) ((T_DO) reduce 165) ((T_DOUBLE_CAST) reduce 165) ((T_ECHO) reduce 165) ((T_ELSE) reduce 165) ((T_ELSEIF) reduce 165) ((T_EMPTY) reduce 165) ((T_ENDFOR) reduce 165) ((T_ENUM) reduce 165) ((T_EVAL) reduce 165) ((T_EXIT) reduce 165) ((T_FILE) reduce 165) ((T_FINAL) reduce 165) ((T_FN) reduce 165) ((T_FOR) reduce 165) ((T_FOREACH) reduce 165) ((T_FUNCTION) reduce 165) ((T_FUNC_C) reduce 165) ((T_GLOBAL) reduce 165) ((T_GOTO) reduce 165) ((T_HALT_COMPILER) reduce 165) ((T_IF) reduce 165) ((T_INC) reduce 165) ((T_INCLUDE) reduce 165) ((T_INCLUDE_ONCE) reduce 165) ((T_INLINE_HTML) reduce 165) ((T_INTERFACE) reduce 165) ((T_INT_CAST) reduce 165) ((T_ISSET) reduce 165) ((T_LINE) reduce 165) ((T_LIST) reduce 165) ((T_LNUMBER) reduce 165) ((T_MATCH) reduce 165) ((T_METHOD_C) reduce 165) ((T_NAME_FULLY_QUALIFIED) reduce 165) ((T_NAME_QUALIFIED) reduce 165) ((T_NAME_RELATIVE) reduce 165) ((T_NEW) reduce 165) ((T_NS_C) reduce 165) ((T_OBJECT_CAST) reduce 165) ((T_PRINT) reduce 165) ((T_READONLY) reduce 165) ((T_REQUIRE) reduce 165) ((T_REQUIRE_ONCE) reduce 165) ((T_RETURN) reduce 165) ((T_START_HEREDOC) reduce 165) ((T_STATIC) reduce 165) ((T_STRING) reduce 165) ((T_STRING_CAST) reduce 165) ((T_SWITCH) reduce 165) ((T_THROW) reduce 165) ((T_TRAIT) reduce 165) ((T_TRAIT_C) reduce 165) ((T_TRY) reduce 165) ((T_UNSET) reduce 165) ((T_UNSET_CAST) reduce 165) ((T_VARIABLE) reduce 165) ((T_WHILE) reduce 165) ((T_YIELD) reduce 165) ((T_YIELD_FROM) reduce 165) (("[") reduce 165) (("`") reduce 165) (("{") reduce 165) (("~") reduce 165)) 19677 ((("!") reduce 175) (("\"") reduce 175) (("$") reduce 175) (("(") reduce 175) (("+") reduce 175) (("-") reduce 175) ((";") reduce 175) (("@") reduce 175) ((T_ABSTRACT) reduce 175) ((T_ARRAY) reduce 175) ((T_ARRAY_CAST) reduce 175) ((T_ATTRIBUTE) reduce 175) ((T_BOOL_CAST) reduce 175) ((T_BREAK) reduce 175) ((T_CLASS) reduce 175) ((T_CLASS_C) reduce 175) ((T_CLONE) reduce 175) ((T_CONSTANT_ENCAPSED_STRING) reduce 175) ((T_CONTINUE) reduce 175) ((T_DEC) reduce 175) ((T_DECLARE) reduce 175) ((T_DIR) reduce 175) ((T_DNUMBER) reduce 175) ((T_DO) reduce 175) ((T_DOUBLE_CAST) reduce 175) ((T_ECHO) reduce 175) ((T_ELSE) reduce 175) ((T_ELSEIF) reduce 175) ((T_EMPTY) reduce 175) ((T_ENDFOR) reduce 175) ((T_ENUM) reduce 175) ((T_EVAL) reduce 175) ((T_EXIT) reduce 175) ((T_FILE) reduce 175) ((T_FINAL) reduce 175) ((T_FN) reduce 175) ((T_FOR) reduce 175) ((T_FOREACH) reduce 175) ((T_FUNCTION) reduce 175) ((T_FUNC_C) reduce 175) ((T_GLOBAL) reduce 175) ((T_GOTO) reduce 175) ((T_HALT_COMPILER) reduce 175) ((T_IF) reduce 175) ((T_INC) reduce 175) ((T_INCLUDE) reduce 175) ((T_INCLUDE_ONCE) reduce 175) ((T_INLINE_HTML) reduce 175) ((T_INTERFACE) reduce 175) ((T_INT_CAST) reduce 175) ((T_ISSET) reduce 175) ((T_LINE) reduce 175) ((T_LIST) reduce 175) ((T_LNUMBER) reduce 175) ((T_MATCH) reduce 175) ((T_METHOD_C) reduce 175) ((T_NAME_FULLY_QUALIFIED) reduce 175) ((T_NAME_QUALIFIED) reduce 175) ((T_NAME_RELATIVE) reduce 175) ((T_NEW) reduce 175) ((T_NS_C) reduce 175) ((T_OBJECT_CAST) reduce 175) ((T_PRINT) reduce 175) ((T_READONLY) reduce 175) ((T_REQUIRE) reduce 175) ((T_REQUIRE_ONCE) reduce 175) ((T_RETURN) reduce 175) ((T_START_HEREDOC) reduce 175) ((T_STATIC) reduce 175) ((T_STRING) reduce 175) ((T_STRING_CAST) reduce 175) ((T_SWITCH) reduce 175) ((T_THROW) reduce 175) ((T_TRAIT) reduce 175) ((T_TRAIT_C) reduce 175) ((T_TRY) reduce 175) ((T_UNSET) reduce 175) ((T_UNSET_CAST) reduce 175) ((T_VARIABLE) reduce 175) ((T_WHILE) reduce 175) ((T_YIELD) reduce 175) ((T_YIELD_FROM) reduce 175) (("[") reduce 175) (("`") reduce 175) (("{") reduce 175) (("~") reduce 175)) 19684 ((("!") reduce 169) (("\"") reduce 169) (("$") reduce 169) (("(") reduce 169) (("+") reduce 169) (("-") reduce 169) ((";") reduce 169) (("@") reduce 169) ((T_ABSTRACT) reduce 169) ((T_ARRAY) reduce 169) ((T_ARRAY_CAST) reduce 169) ((T_ATTRIBUTE) reduce 169) ((T_BOOL_CAST) reduce 169) ((T_BREAK) reduce 169) ((T_CATCH) reduce 169) ((T_CLASS) reduce 169) ((T_CLASS_C) reduce 169) ((T_CLONE) reduce 169) ((T_CONSTANT_ENCAPSED_STRING) reduce 169) ((T_CONTINUE) reduce 169) ((T_DEC) reduce 169) ((T_DECLARE) reduce 169) ((T_DIR) reduce 169) ((T_DNUMBER) reduce 169) ((T_DO) reduce 169) ((T_DOUBLE_CAST) reduce 169) ((T_ECHO) reduce 169) ((T_ELSE) reduce 169) ((T_ELSEIF) reduce 169) ((T_EMPTY) reduce 169) ((T_ENDFOR) reduce 169) ((T_ENUM) reduce 169) ((T_EVAL) reduce 169) ((T_EXIT) reduce 169) ((T_FILE) reduce 169) ((T_FINAL) reduce 169) ((T_FINALLY) reduce 169) ((T_FN) reduce 169) ((T_FOR) reduce 169) ((T_FOREACH) reduce 169) ((T_FUNCTION) reduce 169) ((T_FUNC_C) reduce 169) ((T_GLOBAL) reduce 169) ((T_GOTO) reduce 169) ((T_HALT_COMPILER) reduce 169) ((T_IF) reduce 169) ((T_INC) reduce 169) ((T_INCLUDE) reduce 169) ((T_INCLUDE_ONCE) reduce 169) ((T_INLINE_HTML) reduce 169) ((T_INTERFACE) reduce 169) ((T_INT_CAST) reduce 169) ((T_ISSET) reduce 169) ((T_LINE) reduce 169) ((T_LIST) reduce 169) ((T_LNUMBER) reduce 169) ((T_MATCH) reduce 169) ((T_METHOD_C) reduce 169) ((T_NAME_FULLY_QUALIFIED) reduce 169) ((T_NAME_QUALIFIED) reduce 169) ((T_NAME_RELATIVE) reduce 169) ((T_NEW) reduce 169) ((T_NS_C) reduce 169) ((T_OBJECT_CAST) reduce 169) ((T_PRINT) reduce 169) ((T_READONLY) reduce 169) ((T_REQUIRE) reduce 169) ((T_REQUIRE_ONCE) reduce 169) ((T_RETURN) reduce 169) ((T_START_HEREDOC) reduce 169) ((T_STATIC) reduce 169) ((T_STRING) reduce 169) ((T_STRING_CAST) reduce 169) ((T_SWITCH) reduce 169) ((T_THROW) reduce 169) ((T_TRAIT) reduce 169) ((T_TRAIT_C) reduce 169) ((T_TRY) reduce 169) ((T_UNSET) reduce 169) ((T_UNSET_CAST) reduce 169) ((T_VARIABLE) reduce 169) ((T_WHILE) reduce 169) ((T_YIELD) reduce 169) ((T_YIELD_FROM) reduce 169) (("[") reduce 169) (("`") reduce 169) (("{") reduce 169) (("~") reduce 169)) 19689 ((("!") reduce 151) (("\"") reduce 151) (("$") reduce 151) (("(") reduce 151) (("+") reduce 151) (("-") reduce 151) ((";") reduce 151) (("@") reduce 151) ((T_ABSTRACT) reduce 151) ((T_ARRAY) reduce 151) ((T_ARRAY_CAST) reduce 151) ((T_ATTRIBUTE) reduce 151) ((T_BOOL_CAST) reduce 151) ((T_BREAK) reduce 151) ((T_CLASS) reduce 151) ((T_CLASS_C) reduce 151) ((T_CLONE) reduce 151) ((T_CONSTANT_ENCAPSED_STRING) reduce 151) ((T_CONTINUE) reduce 151) ((T_DEC) reduce 151) ((T_DECLARE) reduce 151) ((T_DIR) reduce 151) ((T_DNUMBER) reduce 151) ((T_DO) reduce 151) ((T_DOUBLE_CAST) reduce 151) ((T_ECHO) reduce 151) ((T_ELSE) reduce 151) ((T_ELSEIF) reduce 151) ((T_EMPTY) reduce 151) ((T_ENDFOR) reduce 151) ((T_ENUM) reduce 151) ((T_EVAL) reduce 151) ((T_EXIT) reduce 151) ((T_FILE) reduce 151) ((T_FINAL) reduce 151) ((T_FN) reduce 151) ((T_FOR) reduce 151) ((T_FOREACH) reduce 151) ((T_FUNCTION) reduce 151) ((T_FUNC_C) reduce 151) ((T_GLOBAL) reduce 151) ((T_GOTO) reduce 151) ((T_HALT_COMPILER) reduce 151) ((T_IF) reduce 151) ((T_INC) reduce 151) ((T_INCLUDE) reduce 151) ((T_INCLUDE_ONCE) reduce 151) ((T_INLINE_HTML) reduce 151) ((T_INTERFACE) reduce 151) ((T_INT_CAST) reduce 151) ((T_ISSET) reduce 151) ((T_LINE) reduce 151) ((T_LIST) reduce 151) ((T_LNUMBER) reduce 151) ((T_MATCH) reduce 151) ((T_METHOD_C) reduce 151) ((T_NAME_FULLY_QUALIFIED) reduce 151) ((T_NAME_QUALIFIED) reduce 151) ((T_NAME_RELATIVE) reduce 151) ((T_NEW) reduce 151) ((T_NS_C) reduce 151) ((T_OBJECT_CAST) reduce 151) ((T_PRINT) reduce 151) ((T_READONLY) reduce 151) ((T_REQUIRE) reduce 151) ((T_REQUIRE_ONCE) reduce 151) ((T_RETURN) reduce 151) ((T_START_HEREDOC) reduce 151) ((T_STATIC) reduce 151) ((T_STRING) reduce 151) ((T_STRING_CAST) reduce 151) ((T_SWITCH) reduce 151) ((T_THROW) reduce 151) ((T_TRAIT) reduce 151) ((T_TRAIT_C) reduce 151) ((T_TRY) reduce 151) ((T_UNSET) reduce 151) ((T_UNSET_CAST) reduce 151) ((T_VARIABLE) reduce 151) ((T_WHILE) reduce 151) ((T_YIELD) reduce 151) ((T_YIELD_FROM) reduce 151) (("[") reduce 151) (("`") reduce 151) (("{") reduce 151) (("~") reduce 151)) 19693 ((("!") reduce 221) (("\"") reduce 221) (("$") reduce 221) (("(") reduce 221) (("+") reduce 221) (("-") reduce 221) ((";") reduce 221) (("@") reduce 221) ((T_ABSTRACT) reduce 221) ((T_ARRAY) reduce 221) ((T_ARRAY_CAST) reduce 221) ((T_ATTRIBUTE) reduce 221) ((T_BOOL_CAST) reduce 221) ((T_BREAK) reduce 221) ((T_CLASS) reduce 221) ((T_CLASS_C) reduce 221) ((T_CLONE) reduce 221) ((T_CONSTANT_ENCAPSED_STRING) reduce 221) ((T_CONTINUE) reduce 221) ((T_DEC) reduce 221) ((T_DECLARE) reduce 221) ((T_DIR) reduce 221) ((T_DNUMBER) reduce 221) ((T_DO) reduce 221) ((T_DOUBLE_CAST) reduce 221) ((T_ECHO) reduce 221) ((T_ELSE) reduce 221) ((T_ELSEIF) reduce 221) ((T_EMPTY) reduce 221) ((T_ENDFOR) reduce 221) ((T_ENUM) reduce 221) ((T_EVAL) reduce 221) ((T_EXIT) reduce 221) ((T_FILE) reduce 221) ((T_FINAL) reduce 221) ((T_FN) reduce 221) ((T_FOR) reduce 221) ((T_FOREACH) reduce 221) ((T_FUNCTION) reduce 221) ((T_FUNC_C) reduce 221) ((T_GLOBAL) reduce 221) ((T_GOTO) reduce 221) ((T_HALT_COMPILER) reduce 221) ((T_IF) reduce 221) ((T_INC) reduce 221) ((T_INCLUDE) reduce 221) ((T_INCLUDE_ONCE) reduce 221) ((T_INLINE_HTML) reduce 221) ((T_INTERFACE) reduce 221) ((T_INT_CAST) reduce 221) ((T_ISSET) reduce 221) ((T_LINE) reduce 221) ((T_LIST) reduce 221) ((T_LNUMBER) reduce 221) ((T_MATCH) reduce 221) ((T_METHOD_C) reduce 221) ((T_NAME_FULLY_QUALIFIED) reduce 221) ((T_NAME_QUALIFIED) reduce 221) ((T_NAME_RELATIVE) reduce 221) ((T_NEW) reduce 221) ((T_NS_C) reduce 221) ((T_OBJECT_CAST) reduce 221) ((T_PRINT) reduce 221) ((T_READONLY) reduce 221) ((T_REQUIRE) reduce 221) ((T_REQUIRE_ONCE) reduce 221) ((T_RETURN) reduce 221) ((T_START_HEREDOC) reduce 221) ((T_STATIC) reduce 221) ((T_STRING) reduce 221) ((T_STRING_CAST) reduce 221) ((T_SWITCH) reduce 221) ((T_THROW) reduce 221) ((T_TRAIT) reduce 221) ((T_TRAIT_C) reduce 221) ((T_TRY) reduce 221) ((T_UNSET) reduce 221) ((T_UNSET_CAST) reduce 221) ((T_VARIABLE) reduce 221) ((T_WHILE) reduce 221) ((T_YIELD) reduce 221) ((T_YIELD_FROM) reduce 221) (("[") reduce 221) (("`") reduce 221) (("{") reduce 221) (("~") reduce 221)) 19695 ((("!") reduce 222) (("\"") reduce 222) (("$") reduce 222) (("(") reduce 222) (("+") reduce 222) (("-") reduce 222) ((";") reduce 222) (("@") reduce 222) ((T_ABSTRACT) reduce 222) ((T_ARRAY) reduce 222) ((T_ARRAY_CAST) reduce 222) ((T_ATTRIBUTE) reduce 222) ((T_BOOL_CAST) reduce 222) ((T_BREAK) reduce 222) ((T_CLASS) reduce 222) ((T_CLASS_C) reduce 222) ((T_CLONE) reduce 222) ((T_CONSTANT_ENCAPSED_STRING) reduce 222) ((T_CONTINUE) reduce 222) ((T_DEC) reduce 222) ((T_DECLARE) reduce 222) ((T_DIR) reduce 222) ((T_DNUMBER) reduce 222) ((T_DO) reduce 222) ((T_DOUBLE_CAST) reduce 222) ((T_ECHO) reduce 222) ((T_ELSE) reduce 222) ((T_ELSEIF) reduce 222) ((T_EMPTY) reduce 222) ((T_ENDFOR) reduce 222) ((T_ENUM) reduce 222) ((T_EVAL) reduce 222) ((T_EXIT) reduce 222) ((T_FILE) reduce 222) ((T_FINAL) reduce 222) ((T_FN) reduce 222) ((T_FOR) reduce 222) ((T_FOREACH) reduce 222) ((T_FUNCTION) reduce 222) ((T_FUNC_C) reduce 222) ((T_GLOBAL) reduce 222) ((T_GOTO) reduce 222) ((T_HALT_COMPILER) reduce 222) ((T_IF) reduce 222) ((T_INC) reduce 222) ((T_INCLUDE) reduce 222) ((T_INCLUDE_ONCE) reduce 222) ((T_INLINE_HTML) reduce 222) ((T_INTERFACE) reduce 222) ((T_INT_CAST) reduce 222) ((T_ISSET) reduce 222) ((T_LINE) reduce 222) ((T_LIST) reduce 222) ((T_LNUMBER) reduce 222) ((T_MATCH) reduce 222) ((T_METHOD_C) reduce 222) ((T_NAME_FULLY_QUALIFIED) reduce 222) ((T_NAME_QUALIFIED) reduce 222) ((T_NAME_RELATIVE) reduce 222) ((T_NEW) reduce 222) ((T_NS_C) reduce 222) ((T_OBJECT_CAST) reduce 222) ((T_PRINT) reduce 222) ((T_READONLY) reduce 222) ((T_REQUIRE) reduce 222) ((T_REQUIRE_ONCE) reduce 222) ((T_RETURN) reduce 222) ((T_START_HEREDOC) reduce 222) ((T_STATIC) reduce 222) ((T_STRING) reduce 222) ((T_STRING_CAST) reduce 222) ((T_SWITCH) reduce 222) ((T_THROW) reduce 222) ((T_TRAIT) reduce 222) ((T_TRAIT_C) reduce 222) ((T_TRY) reduce 222) ((T_UNSET) reduce 222) ((T_UNSET_CAST) reduce 222) ((T_VARIABLE) reduce 222) ((T_WHILE) reduce 222) ((T_YIELD) reduce 222) ((T_YIELD_FROM) reduce 222) (("[") reduce 222) (("`") reduce 222) (("{") reduce 222) (("~") reduce 222)) 19699 ((("!") reduce 223) (("\"") reduce 223) (("$") reduce 223) (("(") reduce 223) (("+") reduce 223) (("-") reduce 223) ((";") reduce 223) (("@") reduce 223) ((T_ABSTRACT) reduce 223) ((T_ARRAY) reduce 223) ((T_ARRAY_CAST) reduce 223) ((T_ATTRIBUTE) reduce 223) ((T_BOOL_CAST) reduce 223) ((T_BREAK) reduce 223) ((T_CLASS) reduce 223) ((T_CLASS_C) reduce 223) ((T_CLONE) reduce 223) ((T_CONSTANT_ENCAPSED_STRING) reduce 223) ((T_CONTINUE) reduce 223) ((T_DEC) reduce 223) ((T_DECLARE) reduce 223) ((T_DIR) reduce 223) ((T_DNUMBER) reduce 223) ((T_DO) reduce 223) ((T_DOUBLE_CAST) reduce 223) ((T_ECHO) reduce 223) ((T_ELSE) reduce 223) ((T_ELSEIF) reduce 223) ((T_EMPTY) reduce 223) ((T_ENDFOR) reduce 223) ((T_ENUM) reduce 223) ((T_EVAL) reduce 223) ((T_EXIT) reduce 223) ((T_FILE) reduce 223) ((T_FINAL) reduce 223) ((T_FN) reduce 223) ((T_FOR) reduce 223) ((T_FOREACH) reduce 223) ((T_FUNCTION) reduce 223) ((T_FUNC_C) reduce 223) ((T_GLOBAL) reduce 223) ((T_GOTO) reduce 223) ((T_HALT_COMPILER) reduce 223) ((T_IF) reduce 223) ((T_INC) reduce 223) ((T_INCLUDE) reduce 223) ((T_INCLUDE_ONCE) reduce 223) ((T_INLINE_HTML) reduce 223) ((T_INTERFACE) reduce 223) ((T_INT_CAST) reduce 223) ((T_ISSET) reduce 223) ((T_LINE) reduce 223) ((T_LIST) reduce 223) ((T_LNUMBER) reduce 223) ((T_MATCH) reduce 223) ((T_METHOD_C) reduce 223) ((T_NAME_FULLY_QUALIFIED) reduce 223) ((T_NAME_QUALIFIED) reduce 223) ((T_NAME_RELATIVE) reduce 223) ((T_NEW) reduce 223) ((T_NS_C) reduce 223) ((T_OBJECT_CAST) reduce 223) ((T_PRINT) reduce 223) ((T_READONLY) reduce 223) ((T_REQUIRE) reduce 223) ((T_REQUIRE_ONCE) reduce 223) ((T_RETURN) reduce 223) ((T_START_HEREDOC) reduce 223) ((T_STATIC) reduce 223) ((T_STRING) reduce 223) ((T_STRING_CAST) reduce 223) ((T_SWITCH) reduce 223) ((T_THROW) reduce 223) ((T_TRAIT) reduce 223) ((T_TRAIT_C) reduce 223) ((T_TRY) reduce 223) ((T_UNSET) reduce 223) ((T_UNSET_CAST) reduce 223) ((T_VARIABLE) reduce 223) ((T_WHILE) reduce 223) ((T_YIELD) reduce 223) ((T_YIELD_FROM) reduce 223) (("[") reduce 223) (("`") reduce 223) (("{") reduce 223) (("~") reduce 223)) 19702 ((("!") reduce 224) (("\"") reduce 224) (("$") reduce 224) (("(") reduce 224) (("+") reduce 224) (("-") reduce 224) ((";") reduce 224) (("@") reduce 224) ((T_ABSTRACT) reduce 224) ((T_ARRAY) reduce 224) ((T_ARRAY_CAST) reduce 224) ((T_ATTRIBUTE) reduce 224) ((T_BOOL_CAST) reduce 224) ((T_BREAK) reduce 224) ((T_CLASS) reduce 224) ((T_CLASS_C) reduce 224) ((T_CLONE) reduce 224) ((T_CONSTANT_ENCAPSED_STRING) reduce 224) ((T_CONTINUE) reduce 224) ((T_DEC) reduce 224) ((T_DECLARE) reduce 224) ((T_DIR) reduce 224) ((T_DNUMBER) reduce 224) ((T_DO) reduce 224) ((T_DOUBLE_CAST) reduce 224) ((T_ECHO) reduce 224) ((T_ELSE) reduce 224) ((T_ELSEIF) reduce 224) ((T_EMPTY) reduce 224) ((T_ENDFOR) reduce 224) ((T_ENUM) reduce 224) ((T_EVAL) reduce 224) ((T_EXIT) reduce 224) ((T_FILE) reduce 224) ((T_FINAL) reduce 224) ((T_FN) reduce 224) ((T_FOR) reduce 224) ((T_FOREACH) reduce 224) ((T_FUNCTION) reduce 224) ((T_FUNC_C) reduce 224) ((T_GLOBAL) reduce 224) ((T_GOTO) reduce 224) ((T_HALT_COMPILER) reduce 224) ((T_IF) reduce 224) ((T_INC) reduce 224) ((T_INCLUDE) reduce 224) ((T_INCLUDE_ONCE) reduce 224) ((T_INLINE_HTML) reduce 224) ((T_INTERFACE) reduce 224) ((T_INT_CAST) reduce 224) ((T_ISSET) reduce 224) ((T_LINE) reduce 224) ((T_LIST) reduce 224) ((T_LNUMBER) reduce 224) ((T_MATCH) reduce 224) ((T_METHOD_C) reduce 224) ((T_NAME_FULLY_QUALIFIED) reduce 224) ((T_NAME_QUALIFIED) reduce 224) ((T_NAME_RELATIVE) reduce 224) ((T_NEW) reduce 224) ((T_NS_C) reduce 224) ((T_OBJECT_CAST) reduce 224) ((T_PRINT) reduce 224) ((T_READONLY) reduce 224) ((T_REQUIRE) reduce 224) ((T_REQUIRE_ONCE) reduce 224) ((T_RETURN) reduce 224) ((T_START_HEREDOC) reduce 224) ((T_STATIC) reduce 224) ((T_STRING) reduce 224) ((T_STRING_CAST) reduce 224) ((T_SWITCH) reduce 224) ((T_THROW) reduce 224) ((T_TRAIT) reduce 224) ((T_TRAIT_C) reduce 224) ((T_TRY) reduce 224) ((T_UNSET) reduce 224) ((T_UNSET_CAST) reduce 224) ((T_VARIABLE) reduce 224) ((T_WHILE) reduce 224) ((T_YIELD) reduce 224) ((T_YIELD_FROM) reduce 224) (("[") reduce 224) (("`") reduce 224) (("{") reduce 224) (("~") reduce 224)) 19703 ((("!") reduce 167) (("\"") reduce 167) (("$") reduce 167) (("(") reduce 167) (("+") reduce 167) (("-") reduce 167) ((";") reduce 167) (("@") reduce 167) ((T_ABSTRACT) reduce 167) ((T_ARRAY) reduce 167) ((T_ARRAY_CAST) reduce 167) ((T_ATTRIBUTE) reduce 167) ((T_BOOL_CAST) reduce 167) ((T_BREAK) reduce 167) ((T_CLASS) reduce 167) ((T_CLASS_C) reduce 167) ((T_CLONE) reduce 167) ((T_CONSTANT_ENCAPSED_STRING) reduce 167) ((T_CONTINUE) reduce 167) ((T_DEC) reduce 167) ((T_DECLARE) reduce 167) ((T_DIR) reduce 167) ((T_DNUMBER) reduce 167) ((T_DO) reduce 167) ((T_DOUBLE_CAST) reduce 167) ((T_ECHO) reduce 167) ((T_ELSE) reduce 167) ((T_ELSEIF) reduce 167) ((T_EMPTY) reduce 167) ((T_ENDFOR) reduce 167) ((T_ENUM) reduce 167) ((T_EVAL) reduce 167) ((T_EXIT) reduce 167) ((T_FILE) reduce 167) ((T_FINAL) reduce 167) ((T_FN) reduce 167) ((T_FOR) reduce 167) ((T_FOREACH) reduce 167) ((T_FUNCTION) reduce 167) ((T_FUNC_C) reduce 167) ((T_GLOBAL) reduce 167) ((T_GOTO) reduce 167) ((T_HALT_COMPILER) reduce 167) ((T_IF) reduce 167) ((T_INC) reduce 167) ((T_INCLUDE) reduce 167) ((T_INCLUDE_ONCE) reduce 167) ((T_INLINE_HTML) reduce 167) ((T_INTERFACE) reduce 167) ((T_INT_CAST) reduce 167) ((T_ISSET) reduce 167) ((T_LINE) reduce 167) ((T_LIST) reduce 167) ((T_LNUMBER) reduce 167) ((T_MATCH) reduce 167) ((T_METHOD_C) reduce 167) ((T_NAME_FULLY_QUALIFIED) reduce 167) ((T_NAME_QUALIFIED) reduce 167) ((T_NAME_RELATIVE) reduce 167) ((T_NEW) reduce 167) ((T_NS_C) reduce 167) ((T_OBJECT_CAST) reduce 167) ((T_PRINT) reduce 167) ((T_READONLY) reduce 167) ((T_REQUIRE) reduce 167) ((T_REQUIRE_ONCE) reduce 167) ((T_RETURN) reduce 167) ((T_START_HEREDOC) reduce 167) ((T_STATIC) reduce 167) ((T_STRING) reduce 167) ((T_STRING_CAST) reduce 167) ((T_SWITCH) reduce 167) ((T_THROW) reduce 167) ((T_TRAIT) reduce 167) ((T_TRAIT_C) reduce 167) ((T_TRY) reduce 167) ((T_UNSET) reduce 167) ((T_UNSET_CAST) reduce 167) ((T_VARIABLE) reduce 167) ((T_WHILE) reduce 167) ((T_YIELD) reduce 167) ((T_YIELD_FROM) reduce 167) (("[") reduce 167) (("`") reduce 167) (("{") reduce 167) (("~") reduce 167)) 19705 ((("!") reduce 156) (("\"") reduce 156) (("$") reduce 156) (("(") reduce 156) (("+") reduce 156) (("-") reduce 156) ((";") reduce 156) (("@") reduce 156) ((T_ABSTRACT) reduce 156) ((T_ARRAY) reduce 156) ((T_ARRAY_CAST) reduce 156) ((T_ATTRIBUTE) reduce 156) ((T_BOOL_CAST) reduce 156) ((T_BREAK) reduce 156) ((T_CLASS) reduce 156) ((T_CLASS_C) reduce 156) ((T_CLONE) reduce 156) ((T_CONSTANT_ENCAPSED_STRING) reduce 156) ((T_CONTINUE) reduce 156) ((T_DEC) reduce 156) ((T_DECLARE) reduce 156) ((T_DIR) reduce 156) ((T_DNUMBER) reduce 156) ((T_DO) reduce 156) ((T_DOUBLE_CAST) reduce 156) ((T_ECHO) reduce 156) ((T_ELSE) reduce 156) ((T_ELSEIF) reduce 156) ((T_EMPTY) reduce 156) ((T_ENDFOR) reduce 156) ((T_ENUM) reduce 156) ((T_EVAL) reduce 156) ((T_EXIT) reduce 156) ((T_FILE) reduce 156) ((T_FINAL) reduce 156) ((T_FN) reduce 156) ((T_FOR) reduce 156) ((T_FOREACH) reduce 156) ((T_FUNCTION) reduce 156) ((T_FUNC_C) reduce 156) ((T_GLOBAL) reduce 156) ((T_GOTO) reduce 156) ((T_HALT_COMPILER) reduce 156) ((T_IF) reduce 156) ((T_INC) reduce 156) ((T_INCLUDE) reduce 156) ((T_INCLUDE_ONCE) reduce 156) ((T_INLINE_HTML) reduce 156) ((T_INTERFACE) reduce 156) ((T_INT_CAST) reduce 156) ((T_ISSET) reduce 156) ((T_LINE) reduce 156) ((T_LIST) reduce 156) ((T_LNUMBER) reduce 156) ((T_MATCH) reduce 156) ((T_METHOD_C) reduce 156) ((T_NAME_FULLY_QUALIFIED) reduce 156) ((T_NAME_QUALIFIED) reduce 156) ((T_NAME_RELATIVE) reduce 156) ((T_NEW) reduce 156) ((T_NS_C) reduce 156) ((T_OBJECT_CAST) reduce 156) ((T_PRINT) reduce 156) ((T_READONLY) reduce 156) ((T_REQUIRE) reduce 156) ((T_REQUIRE_ONCE) reduce 156) ((T_RETURN) reduce 156) ((T_START_HEREDOC) reduce 156) ((T_STATIC) reduce 156) ((T_STRING) reduce 156) ((T_STRING_CAST) reduce 156) ((T_SWITCH) reduce 156) ((T_THROW) reduce 156) ((T_TRAIT) reduce 156) ((T_TRAIT_C) reduce 156) ((T_TRY) reduce 156) ((T_UNSET) reduce 156) ((T_UNSET_CAST) reduce 156) ((T_VARIABLE) reduce 156) ((T_WHILE) reduce 156) ((T_YIELD) reduce 156) ((T_YIELD_FROM) reduce 156) (("[") reduce 156) (("`") reduce 156) (("{") reduce 156) (("~") reduce 156)) 19707 ((("!") reduce 154) (("\"") reduce 154) (("$") reduce 154) (("(") reduce 154) (("+") reduce 154) (("-") reduce 154) ((";") reduce 154) (("@") reduce 154) ((T_ABSTRACT) reduce 154) ((T_ARRAY) reduce 154) ((T_ARRAY_CAST) reduce 154) ((T_ATTRIBUTE) reduce 154) ((T_BOOL_CAST) reduce 154) ((T_BREAK) reduce 154) ((T_CLASS) reduce 154) ((T_CLASS_C) reduce 154) ((T_CLONE) reduce 154) ((T_CONSTANT_ENCAPSED_STRING) reduce 154) ((T_CONTINUE) reduce 154) ((T_DEC) reduce 154) ((T_DECLARE) reduce 154) ((T_DIR) reduce 154) ((T_DNUMBER) reduce 154) ((T_DO) reduce 154) ((T_DOUBLE_CAST) reduce 154) ((T_ECHO) reduce 154) ((T_ELSE) reduce 154) ((T_ELSEIF) reduce 154) ((T_EMPTY) reduce 154) ((T_ENDFOR) reduce 154) ((T_ENUM) reduce 154) ((T_EVAL) reduce 154) ((T_EXIT) reduce 154) ((T_FILE) reduce 154) ((T_FINAL) reduce 154) ((T_FN) reduce 154) ((T_FOR) reduce 154) ((T_FOREACH) reduce 154) ((T_FUNCTION) reduce 154) ((T_FUNC_C) reduce 154) ((T_GLOBAL) reduce 154) ((T_GOTO) reduce 154) ((T_HALT_COMPILER) reduce 154) ((T_IF) reduce 154) ((T_INC) reduce 154) ((T_INCLUDE) reduce 154) ((T_INCLUDE_ONCE) reduce 154) ((T_INLINE_HTML) reduce 154) ((T_INTERFACE) reduce 154) ((T_INT_CAST) reduce 154) ((T_ISSET) reduce 154) ((T_LINE) reduce 154) ((T_LIST) reduce 154) ((T_LNUMBER) reduce 154) ((T_MATCH) reduce 154) ((T_METHOD_C) reduce 154) ((T_NAME_FULLY_QUALIFIED) reduce 154) ((T_NAME_QUALIFIED) reduce 154) ((T_NAME_RELATIVE) reduce 154) ((T_NEW) reduce 154) ((T_NS_C) reduce 154) ((T_OBJECT_CAST) reduce 154) ((T_PRINT) reduce 154) ((T_READONLY) reduce 154) ((T_REQUIRE) reduce 154) ((T_REQUIRE_ONCE) reduce 154) ((T_RETURN) reduce 154) ((T_START_HEREDOC) reduce 154) ((T_STATIC) reduce 154) ((T_STRING) reduce 154) ((T_STRING_CAST) reduce 154) ((T_SWITCH) reduce 154) ((T_THROW) reduce 154) ((T_TRAIT) reduce 154) ((T_TRAIT_C) reduce 154) ((T_TRY) reduce 154) ((T_UNSET) reduce 154) ((T_UNSET_CAST) reduce 154) ((T_VARIABLE) reduce 154) ((T_WHILE) reduce 154) ((T_YIELD) reduce 154) ((T_YIELD_FROM) reduce 154) (("[") reduce 154) (("`") reduce 154) (("{") reduce 154) (("~") reduce 154)) 19709 ((("!") reduce 166) (("\"") reduce 166) (("$") reduce 166) (("(") reduce 166) (("+") reduce 166) (("-") reduce 166) ((";") reduce 166) (("@") reduce 166) ((T_ABSTRACT) reduce 166) ((T_ARRAY) reduce 166) ((T_ARRAY_CAST) reduce 166) ((T_ATTRIBUTE) reduce 166) ((T_BOOL_CAST) reduce 166) ((T_BREAK) reduce 166) ((T_CLASS) reduce 166) ((T_CLASS_C) reduce 166) ((T_CLONE) reduce 166) ((T_CONSTANT_ENCAPSED_STRING) reduce 166) ((T_CONTINUE) reduce 166) ((T_DEC) reduce 166) ((T_DECLARE) reduce 166) ((T_DIR) reduce 166) ((T_DNUMBER) reduce 166) ((T_DO) reduce 166) ((T_DOUBLE_CAST) reduce 166) ((T_ECHO) reduce 166) ((T_ELSE) reduce 166) ((T_ELSEIF) reduce 166) ((T_EMPTY) reduce 166) ((T_ENDFOR) reduce 166) ((T_ENUM) reduce 166) ((T_EVAL) reduce 166) ((T_EXIT) reduce 166) ((T_FILE) reduce 166) ((T_FINAL) reduce 166) ((T_FN) reduce 166) ((T_FOR) reduce 166) ((T_FOREACH) reduce 166) ((T_FUNCTION) reduce 166) ((T_FUNC_C) reduce 166) ((T_GLOBAL) reduce 166) ((T_GOTO) reduce 166) ((T_HALT_COMPILER) reduce 166) ((T_IF) reduce 166) ((T_INC) reduce 166) ((T_INCLUDE) reduce 166) ((T_INCLUDE_ONCE) reduce 166) ((T_INLINE_HTML) reduce 166) ((T_INTERFACE) reduce 166) ((T_INT_CAST) reduce 166) ((T_ISSET) reduce 166) ((T_LINE) reduce 166) ((T_LIST) reduce 166) ((T_LNUMBER) reduce 166) ((T_MATCH) reduce 166) ((T_METHOD_C) reduce 166) ((T_NAME_FULLY_QUALIFIED) reduce 166) ((T_NAME_QUALIFIED) reduce 166) ((T_NAME_RELATIVE) reduce 166) ((T_NEW) reduce 166) ((T_NS_C) reduce 166) ((T_OBJECT_CAST) reduce 166) ((T_PRINT) reduce 166) ((T_READONLY) reduce 166) ((T_REQUIRE) reduce 166) ((T_REQUIRE_ONCE) reduce 166) ((T_RETURN) reduce 166) ((T_START_HEREDOC) reduce 166) ((T_STATIC) reduce 166) ((T_STRING) reduce 166) ((T_STRING_CAST) reduce 166) ((T_SWITCH) reduce 166) ((T_THROW) reduce 166) ((T_TRAIT) reduce 166) ((T_TRAIT_C) reduce 166) ((T_TRY) reduce 166) ((T_UNSET) reduce 166) ((T_UNSET_CAST) reduce 166) ((T_VARIABLE) reduce 166) ((T_WHILE) reduce 166) ((T_YIELD) reduce 166) ((T_YIELD_FROM) reduce 166) (("[") reduce 166) (("`") reduce 166) (("{") reduce 166) (("~") reduce 166)) 19711 ((("!") reduce 155) (("\"") reduce 155) (("$") reduce 155) (("(") reduce 155) (("+") reduce 155) (("-") reduce 155) ((";") reduce 155) (("@") reduce 155) ((T_ABSTRACT) reduce 155) ((T_ARRAY) reduce 155) ((T_ARRAY_CAST) reduce 155) ((T_ATTRIBUTE) reduce 155) ((T_BOOL_CAST) reduce 155) ((T_BREAK) reduce 155) ((T_CLASS) reduce 155) ((T_CLASS_C) reduce 155) ((T_CLONE) reduce 155) ((T_CONSTANT_ENCAPSED_STRING) reduce 155) ((T_CONTINUE) reduce 155) ((T_DEC) reduce 155) ((T_DECLARE) reduce 155) ((T_DIR) reduce 155) ((T_DNUMBER) reduce 155) ((T_DO) reduce 155) ((T_DOUBLE_CAST) reduce 155) ((T_ECHO) reduce 155) ((T_ELSE) reduce 155) ((T_ELSEIF) reduce 155) ((T_EMPTY) reduce 155) ((T_ENDFOR) reduce 155) ((T_ENUM) reduce 155) ((T_EVAL) reduce 155) ((T_EXIT) reduce 155) ((T_FILE) reduce 155) ((T_FINAL) reduce 155) ((T_FN) reduce 155) ((T_FOR) reduce 155) ((T_FOREACH) reduce 155) ((T_FUNCTION) reduce 155) ((T_FUNC_C) reduce 155) ((T_GLOBAL) reduce 155) ((T_GOTO) reduce 155) ((T_HALT_COMPILER) reduce 155) ((T_IF) reduce 155) ((T_INC) reduce 155) ((T_INCLUDE) reduce 155) ((T_INCLUDE_ONCE) reduce 155) ((T_INLINE_HTML) reduce 155) ((T_INTERFACE) reduce 155) ((T_INT_CAST) reduce 155) ((T_ISSET) reduce 155) ((T_LINE) reduce 155) ((T_LIST) reduce 155) ((T_LNUMBER) reduce 155) ((T_MATCH) reduce 155) ((T_METHOD_C) reduce 155) ((T_NAME_FULLY_QUALIFIED) reduce 155) ((T_NAME_QUALIFIED) reduce 155) ((T_NAME_RELATIVE) reduce 155) ((T_NEW) reduce 155) ((T_NS_C) reduce 155) ((T_OBJECT_CAST) reduce 155) ((T_PRINT) reduce 155) ((T_READONLY) reduce 155) ((T_REQUIRE) reduce 155) ((T_REQUIRE_ONCE) reduce 155) ((T_RETURN) reduce 155) ((T_START_HEREDOC) reduce 155) ((T_STATIC) reduce 155) ((T_STRING) reduce 155) ((T_STRING_CAST) reduce 155) ((T_SWITCH) reduce 155) ((T_THROW) reduce 155) ((T_TRAIT) reduce 155) ((T_TRAIT_C) reduce 155) ((T_TRY) reduce 155) ((T_UNSET) reduce 155) ((T_UNSET_CAST) reduce 155) ((T_VARIABLE) reduce 155) ((T_WHILE) reduce 155) ((T_YIELD) reduce 155) ((T_YIELD_FROM) reduce 155) (("[") reduce 155) (("`") reduce 155) (("{") reduce 155) (("~") reduce 155)) 19721 ((("!") reduce 162) (("\"") reduce 162) (("$") reduce 162) (("(") reduce 162) (("+") reduce 162) (("-") reduce 162) ((";") reduce 162) (("@") reduce 162) ((T_ABSTRACT) reduce 162) ((T_ARRAY) reduce 162) ((T_ARRAY_CAST) reduce 162) ((T_ATTRIBUTE) reduce 162) ((T_BOOL_CAST) reduce 162) ((T_BREAK) reduce 162) ((T_CLASS) reduce 162) ((T_CLASS_C) reduce 162) ((T_CLONE) reduce 162) ((T_CONSTANT_ENCAPSED_STRING) reduce 162) ((T_CONTINUE) reduce 162) ((T_DEC) reduce 162) ((T_DECLARE) reduce 162) ((T_DIR) reduce 162) ((T_DNUMBER) reduce 162) ((T_DO) reduce 162) ((T_DOUBLE_CAST) reduce 162) ((T_ECHO) reduce 162) ((T_ELSE) reduce 162) ((T_ELSEIF) reduce 162) ((T_EMPTY) reduce 162) ((T_ENDFOR) reduce 162) ((T_ENUM) reduce 162) ((T_EVAL) reduce 162) ((T_EXIT) reduce 162) ((T_FILE) reduce 162) ((T_FINAL) reduce 162) ((T_FN) reduce 162) ((T_FOR) reduce 162) ((T_FOREACH) reduce 162) ((T_FUNCTION) reduce 162) ((T_FUNC_C) reduce 162) ((T_GLOBAL) reduce 162) ((T_GOTO) reduce 162) ((T_HALT_COMPILER) reduce 162) ((T_IF) reduce 162) ((T_INC) reduce 162) ((T_INCLUDE) reduce 162) ((T_INCLUDE_ONCE) reduce 162) ((T_INLINE_HTML) reduce 162) ((T_INTERFACE) reduce 162) ((T_INT_CAST) reduce 162) ((T_ISSET) reduce 162) ((T_LINE) reduce 162) ((T_LIST) reduce 162) ((T_LNUMBER) reduce 162) ((T_MATCH) reduce 162) ((T_METHOD_C) reduce 162) ((T_NAME_FULLY_QUALIFIED) reduce 162) ((T_NAME_QUALIFIED) reduce 162) ((T_NAME_RELATIVE) reduce 162) ((T_NEW) reduce 162) ((T_NS_C) reduce 162) ((T_OBJECT_CAST) reduce 162) ((T_PRINT) reduce 162) ((T_READONLY) reduce 162) ((T_REQUIRE) reduce 162) ((T_REQUIRE_ONCE) reduce 162) ((T_RETURN) reduce 162) ((T_START_HEREDOC) reduce 162) ((T_STATIC) reduce 162) ((T_STRING) reduce 162) ((T_STRING_CAST) reduce 162) ((T_SWITCH) reduce 162) ((T_THROW) reduce 162) ((T_TRAIT) reduce 162) ((T_TRAIT_C) reduce 162) ((T_TRY) reduce 162) ((T_UNSET) reduce 162) ((T_UNSET_CAST) reduce 162) ((T_VARIABLE) reduce 162) ((T_WHILE) reduce 162) ((T_YIELD) reduce 162) ((T_YIELD_FROM) reduce 162) (("[") reduce 162) (("`") reduce 162) (("{") reduce 162) (("~") reduce 162)) 19722 ((("!") reduce 217) (("\"") reduce 217) (("$") reduce 217) (("(") reduce 217) (("+") reduce 217) (("-") reduce 217) ((";") reduce 217) (("@") reduce 217) ((T_ABSTRACT) reduce 217) ((T_ARRAY) reduce 217) ((T_ARRAY_CAST) reduce 217) ((T_ATTRIBUTE) reduce 217) ((T_BOOL_CAST) reduce 217) ((T_BREAK) reduce 217) ((T_CLASS) reduce 217) ((T_CLASS_C) reduce 217) ((T_CLONE) reduce 217) ((T_CONSTANT_ENCAPSED_STRING) reduce 217) ((T_CONTINUE) reduce 217) ((T_DEC) reduce 217) ((T_DECLARE) reduce 217) ((T_DIR) reduce 217) ((T_DNUMBER) reduce 217) ((T_DO) reduce 217) ((T_DOUBLE_CAST) reduce 217) ((T_ECHO) reduce 217) ((T_ELSE) reduce 217) ((T_ELSEIF) reduce 217) ((T_EMPTY) reduce 217) ((T_ENDFOR) reduce 217) ((T_ENUM) reduce 217) ((T_EVAL) reduce 217) ((T_EXIT) reduce 217) ((T_FILE) reduce 217) ((T_FINAL) reduce 217) ((T_FN) reduce 217) ((T_FOR) reduce 217) ((T_FOREACH) reduce 217) ((T_FUNCTION) reduce 217) ((T_FUNC_C) reduce 217) ((T_GLOBAL) reduce 217) ((T_GOTO) reduce 217) ((T_HALT_COMPILER) reduce 217) ((T_IF) reduce 217) ((T_INC) reduce 217) ((T_INCLUDE) reduce 217) ((T_INCLUDE_ONCE) reduce 217) ((T_INLINE_HTML) reduce 217) ((T_INTERFACE) reduce 217) ((T_INT_CAST) reduce 217) ((T_ISSET) reduce 217) ((T_LINE) reduce 217) ((T_LIST) reduce 217) ((T_LNUMBER) reduce 217) ((T_MATCH) reduce 217) ((T_METHOD_C) reduce 217) ((T_NAME_FULLY_QUALIFIED) reduce 217) ((T_NAME_QUALIFIED) reduce 217) ((T_NAME_RELATIVE) reduce 217) ((T_NEW) reduce 217) ((T_NS_C) reduce 217) ((T_OBJECT_CAST) reduce 217) ((T_PRINT) reduce 217) ((T_READONLY) reduce 217) ((T_REQUIRE) reduce 217) ((T_REQUIRE_ONCE) reduce 217) ((T_RETURN) reduce 217) ((T_START_HEREDOC) reduce 217) ((T_STATIC) reduce 217) ((T_STRING) reduce 217) ((T_STRING_CAST) reduce 217) ((T_SWITCH) reduce 217) ((T_THROW) reduce 217) ((T_TRAIT) reduce 217) ((T_TRAIT_C) reduce 217) ((T_TRY) reduce 217) ((T_UNSET) reduce 217) ((T_UNSET_CAST) reduce 217) ((T_VARIABLE) reduce 217) ((T_WHILE) reduce 217) ((T_YIELD) reduce 217) ((T_YIELD_FROM) reduce 217) (("[") reduce 217) (("`") reduce 217) (("{") reduce 217) (("~") reduce 217)) 19725 ((("!") reduce 218) (("\"") reduce 218) (("$") reduce 218) (("(") reduce 218) (("+") reduce 218) (("-") reduce 218) ((";") reduce 218) (("@") reduce 218) ((T_ABSTRACT) reduce 218) ((T_ARRAY) reduce 218) ((T_ARRAY_CAST) reduce 218) ((T_ATTRIBUTE) reduce 218) ((T_BOOL_CAST) reduce 218) ((T_BREAK) reduce 218) ((T_CLASS) reduce 218) ((T_CLASS_C) reduce 218) ((T_CLONE) reduce 218) ((T_CONSTANT_ENCAPSED_STRING) reduce 218) ((T_CONTINUE) reduce 218) ((T_DEC) reduce 218) ((T_DECLARE) reduce 218) ((T_DIR) reduce 218) ((T_DNUMBER) reduce 218) ((T_DO) reduce 218) ((T_DOUBLE_CAST) reduce 218) ((T_ECHO) reduce 218) ((T_ELSE) reduce 218) ((T_ELSEIF) reduce 218) ((T_EMPTY) reduce 218) ((T_ENDFOR) reduce 218) ((T_ENUM) reduce 218) ((T_EVAL) reduce 218) ((T_EXIT) reduce 218) ((T_FILE) reduce 218) ((T_FINAL) reduce 218) ((T_FN) reduce 218) ((T_FOR) reduce 218) ((T_FOREACH) reduce 218) ((T_FUNCTION) reduce 218) ((T_FUNC_C) reduce 218) ((T_GLOBAL) reduce 218) ((T_GOTO) reduce 218) ((T_HALT_COMPILER) reduce 218) ((T_IF) reduce 218) ((T_INC) reduce 218) ((T_INCLUDE) reduce 218) ((T_INCLUDE_ONCE) reduce 218) ((T_INLINE_HTML) reduce 218) ((T_INTERFACE) reduce 218) ((T_INT_CAST) reduce 218) ((T_ISSET) reduce 218) ((T_LINE) reduce 218) ((T_LIST) reduce 218) ((T_LNUMBER) reduce 218) ((T_MATCH) reduce 218) ((T_METHOD_C) reduce 218) ((T_NAME_FULLY_QUALIFIED) reduce 218) ((T_NAME_QUALIFIED) reduce 218) ((T_NAME_RELATIVE) reduce 218) ((T_NEW) reduce 218) ((T_NS_C) reduce 218) ((T_OBJECT_CAST) reduce 218) ((T_PRINT) reduce 218) ((T_READONLY) reduce 218) ((T_REQUIRE) reduce 218) ((T_REQUIRE_ONCE) reduce 218) ((T_RETURN) reduce 218) ((T_START_HEREDOC) reduce 218) ((T_STATIC) reduce 218) ((T_STRING) reduce 218) ((T_STRING_CAST) reduce 218) ((T_SWITCH) reduce 218) ((T_THROW) reduce 218) ((T_TRAIT) reduce 218) ((T_TRAIT_C) reduce 218) ((T_TRY) reduce 218) ((T_UNSET) reduce 218) ((T_UNSET_CAST) reduce 218) ((T_VARIABLE) reduce 218) ((T_WHILE) reduce 218) ((T_YIELD) reduce 218) ((T_YIELD_FROM) reduce 218) (("[") reduce 218) (("`") reduce 218) (("{") reduce 218) (("~") reduce 218)) 19726 ((("!") reduce 161) (("\"") reduce 161) (("$") reduce 161) (("(") reduce 161) (("+") reduce 161) (("-") reduce 161) ((";") reduce 161) (("@") reduce 161) ((T_ABSTRACT) reduce 161) ((T_ARRAY) reduce 161) ((T_ARRAY_CAST) reduce 161) ((T_ATTRIBUTE) reduce 161) ((T_BOOL_CAST) reduce 161) ((T_BREAK) reduce 161) ((T_CLASS) reduce 161) ((T_CLASS_C) reduce 161) ((T_CLONE) reduce 161) ((T_CONSTANT_ENCAPSED_STRING) reduce 161) ((T_CONTINUE) reduce 161) ((T_DEC) reduce 161) ((T_DECLARE) reduce 161) ((T_DIR) reduce 161) ((T_DNUMBER) reduce 161) ((T_DO) reduce 161) ((T_DOUBLE_CAST) reduce 161) ((T_ECHO) reduce 161) ((T_ELSE) reduce 161) ((T_ELSEIF) reduce 161) ((T_EMPTY) reduce 161) ((T_ENDFOR) reduce 161) ((T_ENUM) reduce 161) ((T_EVAL) reduce 161) ((T_EXIT) reduce 161) ((T_FILE) reduce 161) ((T_FINAL) reduce 161) ((T_FN) reduce 161) ((T_FOR) reduce 161) ((T_FOREACH) reduce 161) ((T_FUNCTION) reduce 161) ((T_FUNC_C) reduce 161) ((T_GLOBAL) reduce 161) ((T_GOTO) reduce 161) ((T_HALT_COMPILER) reduce 161) ((T_IF) reduce 161) ((T_INC) reduce 161) ((T_INCLUDE) reduce 161) ((T_INCLUDE_ONCE) reduce 161) ((T_INLINE_HTML) reduce 161) ((T_INTERFACE) reduce 161) ((T_INT_CAST) reduce 161) ((T_ISSET) reduce 161) ((T_LINE) reduce 161) ((T_LIST) reduce 161) ((T_LNUMBER) reduce 161) ((T_MATCH) reduce 161) ((T_METHOD_C) reduce 161) ((T_NAME_FULLY_QUALIFIED) reduce 161) ((T_NAME_QUALIFIED) reduce 161) ((T_NAME_RELATIVE) reduce 161) ((T_NEW) reduce 161) ((T_NS_C) reduce 161) ((T_OBJECT_CAST) reduce 161) ((T_PRINT) reduce 161) ((T_READONLY) reduce 161) ((T_REQUIRE) reduce 161) ((T_REQUIRE_ONCE) reduce 161) ((T_RETURN) reduce 161) ((T_START_HEREDOC) reduce 161) ((T_STATIC) reduce 161) ((T_STRING) reduce 161) ((T_STRING_CAST) reduce 161) ((T_SWITCH) reduce 161) ((T_THROW) reduce 161) ((T_TRAIT) reduce 161) ((T_TRAIT_C) reduce 161) ((T_TRY) reduce 161) ((T_UNSET) reduce 161) ((T_UNSET_CAST) reduce 161) ((T_VARIABLE) reduce 161) ((T_WHILE) reduce 161) ((T_YIELD) reduce 161) ((T_YIELD_FROM) reduce 161) (("[") reduce 161) (("`") reduce 161) (("{") reduce 161) (("~") reduce 161)) 19735 ((("!") reduce 150) (("\"") reduce 150) (("$") reduce 150) (("(") reduce 150) (("+") reduce 150) (("-") reduce 150) ((";") reduce 150) (("@") reduce 150) ((T_ABSTRACT) reduce 150) ((T_ARRAY) reduce 150) ((T_ARRAY_CAST) reduce 150) ((T_ATTRIBUTE) reduce 150) ((T_BOOL_CAST) reduce 150) ((T_BREAK) reduce 150) ((T_CLASS) reduce 150) ((T_CLASS_C) reduce 150) ((T_CLONE) reduce 150) ((T_CONSTANT_ENCAPSED_STRING) reduce 150) ((T_CONTINUE) reduce 150) ((T_DEC) reduce 150) ((T_DECLARE) reduce 150) ((T_DIR) reduce 150) ((T_DNUMBER) reduce 150) ((T_DO) reduce 150) ((T_DOUBLE_CAST) reduce 150) ((T_ECHO) reduce 150) ((T_ELSE) reduce 150) ((T_ELSEIF) reduce 150) ((T_EMPTY) reduce 150) ((T_ENDFOR) reduce 150) ((T_ENUM) reduce 150) ((T_EVAL) reduce 150) ((T_EXIT) reduce 150) ((T_FILE) reduce 150) ((T_FINAL) reduce 150) ((T_FN) reduce 150) ((T_FOR) reduce 150) ((T_FOREACH) reduce 150) ((T_FUNCTION) reduce 150) ((T_FUNC_C) reduce 150) ((T_GLOBAL) reduce 150) ((T_GOTO) reduce 150) ((T_HALT_COMPILER) reduce 150) ((T_IF) reduce 150) ((T_INC) reduce 150) ((T_INCLUDE) reduce 150) ((T_INCLUDE_ONCE) reduce 150) ((T_INLINE_HTML) reduce 150) ((T_INTERFACE) reduce 150) ((T_INT_CAST) reduce 150) ((T_ISSET) reduce 150) ((T_LINE) reduce 150) ((T_LIST) reduce 150) ((T_LNUMBER) reduce 150) ((T_MATCH) reduce 150) ((T_METHOD_C) reduce 150) ((T_NAME_FULLY_QUALIFIED) reduce 150) ((T_NAME_QUALIFIED) reduce 150) ((T_NAME_RELATIVE) reduce 150) ((T_NEW) reduce 150) ((T_NS_C) reduce 150) ((T_OBJECT_CAST) reduce 150) ((T_PRINT) reduce 150) ((T_READONLY) reduce 150) ((T_REQUIRE) reduce 150) ((T_REQUIRE_ONCE) reduce 150) ((T_RETURN) reduce 150) ((T_START_HEREDOC) reduce 150) ((T_STATIC) reduce 150) ((T_STRING) reduce 150) ((T_STRING_CAST) reduce 150) ((T_SWITCH) reduce 150) ((T_THROW) reduce 150) ((T_TRAIT) reduce 150) ((T_TRAIT_C) reduce 150) ((T_TRY) reduce 150) ((T_UNSET) reduce 150) ((T_UNSET_CAST) reduce 150) ((T_VARIABLE) reduce 150) ((T_WHILE) reduce 150) ((T_YIELD) reduce 150) ((T_YIELD_FROM) reduce 150) (("[") reduce 150) (("`") reduce 150) (("{") reduce 150) (("~") reduce 150)) 19736 ((("!") reduce 215) (("\"") reduce 215) (("$") reduce 215) (("(") reduce 215) (("+") reduce 215) (("-") reduce 215) ((";") reduce 215) (("@") reduce 215) ((T_ABSTRACT) reduce 215) ((T_ARRAY) reduce 215) ((T_ARRAY_CAST) reduce 215) ((T_ATTRIBUTE) reduce 215) ((T_BOOL_CAST) reduce 215) ((T_BREAK) reduce 215) ((T_CLASS) reduce 215) ((T_CLASS_C) reduce 215) ((T_CLONE) reduce 215) ((T_CONSTANT_ENCAPSED_STRING) reduce 215) ((T_CONTINUE) reduce 215) ((T_DEC) reduce 215) ((T_DECLARE) reduce 215) ((T_DIR) reduce 215) ((T_DNUMBER) reduce 215) ((T_DO) reduce 215) ((T_DOUBLE_CAST) reduce 215) ((T_ECHO) reduce 215) ((T_ELSE) reduce 215) ((T_ELSEIF) reduce 215) ((T_EMPTY) reduce 215) ((T_ENDFOR) reduce 215) ((T_ENUM) reduce 215) ((T_EVAL) reduce 215) ((T_EXIT) reduce 215) ((T_FILE) reduce 215) ((T_FINAL) reduce 215) ((T_FN) reduce 215) ((T_FOR) reduce 215) ((T_FOREACH) reduce 215) ((T_FUNCTION) reduce 215) ((T_FUNC_C) reduce 215) ((T_GLOBAL) reduce 215) ((T_GOTO) reduce 215) ((T_HALT_COMPILER) reduce 215) ((T_IF) reduce 215) ((T_INC) reduce 215) ((T_INCLUDE) reduce 215) ((T_INCLUDE_ONCE) reduce 215) ((T_INLINE_HTML) reduce 215) ((T_INTERFACE) reduce 215) ((T_INT_CAST) reduce 215) ((T_ISSET) reduce 215) ((T_LINE) reduce 215) ((T_LIST) reduce 215) ((T_LNUMBER) reduce 215) ((T_MATCH) reduce 215) ((T_METHOD_C) reduce 215) ((T_NAME_FULLY_QUALIFIED) reduce 215) ((T_NAME_QUALIFIED) reduce 215) ((T_NAME_RELATIVE) reduce 215) ((T_NEW) reduce 215) ((T_NS_C) reduce 215) ((T_OBJECT_CAST) reduce 215) ((T_PRINT) reduce 215) ((T_READONLY) reduce 215) ((T_REQUIRE) reduce 215) ((T_REQUIRE_ONCE) reduce 215) ((T_RETURN) reduce 215) ((T_START_HEREDOC) reduce 215) ((T_STATIC) reduce 215) ((T_STRING) reduce 215) ((T_STRING_CAST) reduce 215) ((T_SWITCH) reduce 215) ((T_THROW) reduce 215) ((T_TRAIT) reduce 215) ((T_TRAIT_C) reduce 215) ((T_TRY) reduce 215) ((T_UNSET) reduce 215) ((T_UNSET_CAST) reduce 215) ((T_VARIABLE) reduce 215) ((T_WHILE) reduce 215) ((T_YIELD) reduce 215) ((T_YIELD_FROM) reduce 215) (("[") reduce 215) (("`") reduce 215) (("{") reduce 215) (("~") reduce 215)) 19739 ((("!") reduce 216) (("\"") reduce 216) (("$") reduce 216) (("(") reduce 216) (("+") reduce 216) (("-") reduce 216) ((";") reduce 216) (("@") reduce 216) ((T_ABSTRACT) reduce 216) ((T_ARRAY) reduce 216) ((T_ARRAY_CAST) reduce 216) ((T_ATTRIBUTE) reduce 216) ((T_BOOL_CAST) reduce 216) ((T_BREAK) reduce 216) ((T_CLASS) reduce 216) ((T_CLASS_C) reduce 216) ((T_CLONE) reduce 216) ((T_CONSTANT_ENCAPSED_STRING) reduce 216) ((T_CONTINUE) reduce 216) ((T_DEC) reduce 216) ((T_DECLARE) reduce 216) ((T_DIR) reduce 216) ((T_DNUMBER) reduce 216) ((T_DO) reduce 216) ((T_DOUBLE_CAST) reduce 216) ((T_ECHO) reduce 216) ((T_ELSE) reduce 216) ((T_ELSEIF) reduce 216) ((T_EMPTY) reduce 216) ((T_ENDFOR) reduce 216) ((T_ENUM) reduce 216) ((T_EVAL) reduce 216) ((T_EXIT) reduce 216) ((T_FILE) reduce 216) ((T_FINAL) reduce 216) ((T_FN) reduce 216) ((T_FOR) reduce 216) ((T_FOREACH) reduce 216) ((T_FUNCTION) reduce 216) ((T_FUNC_C) reduce 216) ((T_GLOBAL) reduce 216) ((T_GOTO) reduce 216) ((T_HALT_COMPILER) reduce 216) ((T_IF) reduce 216) ((T_INC) reduce 216) ((T_INCLUDE) reduce 216) ((T_INCLUDE_ONCE) reduce 216) ((T_INLINE_HTML) reduce 216) ((T_INTERFACE) reduce 216) ((T_INT_CAST) reduce 216) ((T_ISSET) reduce 216) ((T_LINE) reduce 216) ((T_LIST) reduce 216) ((T_LNUMBER) reduce 216) ((T_MATCH) reduce 216) ((T_METHOD_C) reduce 216) ((T_NAME_FULLY_QUALIFIED) reduce 216) ((T_NAME_QUALIFIED) reduce 216) ((T_NAME_RELATIVE) reduce 216) ((T_NEW) reduce 216) ((T_NS_C) reduce 216) ((T_OBJECT_CAST) reduce 216) ((T_PRINT) reduce 216) ((T_READONLY) reduce 216) ((T_REQUIRE) reduce 216) ((T_REQUIRE_ONCE) reduce 216) ((T_RETURN) reduce 216) ((T_START_HEREDOC) reduce 216) ((T_STATIC) reduce 216) ((T_STRING) reduce 216) ((T_STRING_CAST) reduce 216) ((T_SWITCH) reduce 216) ((T_THROW) reduce 216) ((T_TRAIT) reduce 216) ((T_TRAIT_C) reduce 216) ((T_TRY) reduce 216) ((T_UNSET) reduce 216) ((T_UNSET_CAST) reduce 216) ((T_VARIABLE) reduce 216) ((T_WHILE) reduce 216) ((T_YIELD) reduce 216) ((T_YIELD_FROM) reduce 216) (("[") reduce 216) (("`") reduce 216) (("{") reduce 216) (("~") reduce 216)) 19740 (((",") reduce 357) ((";") reduce 357)) 19742 ((("%") shift) (("*") shift) (("+") shift) ((",") reduce 358) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 358) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 19744 ((("!") reduce 157) (("\"") reduce 157) (("$") reduce 157) (("(") reduce 157) (("+") reduce 157) (("-") reduce 157) ((";") reduce 157) (("@") reduce 157) ((T_ABSTRACT) reduce 157) ((T_ARRAY) reduce 157) ((T_ARRAY_CAST) reduce 157) ((T_ATTRIBUTE) reduce 157) ((T_BOOL_CAST) reduce 157) ((T_BREAK) reduce 157) ((T_CLASS) reduce 157) ((T_CLASS_C) reduce 157) ((T_CLONE) reduce 157) ((T_CONSTANT_ENCAPSED_STRING) reduce 157) ((T_CONTINUE) reduce 157) ((T_DEC) reduce 157) ((T_DECLARE) reduce 157) ((T_DIR) reduce 157) ((T_DNUMBER) reduce 157) ((T_DO) reduce 157) ((T_DOUBLE_CAST) reduce 157) ((T_ECHO) reduce 157) ((T_ELSE) reduce 157) ((T_ELSEIF) reduce 157) ((T_EMPTY) reduce 157) ((T_ENDFOR) reduce 157) ((T_ENUM) reduce 157) ((T_EVAL) reduce 157) ((T_EXIT) reduce 157) ((T_FILE) reduce 157) ((T_FINAL) reduce 157) ((T_FN) reduce 157) ((T_FOR) reduce 157) ((T_FOREACH) reduce 157) ((T_FUNCTION) reduce 157) ((T_FUNC_C) reduce 157) ((T_GLOBAL) reduce 157) ((T_GOTO) reduce 157) ((T_HALT_COMPILER) reduce 157) ((T_IF) reduce 157) ((T_INC) reduce 157) ((T_INCLUDE) reduce 157) ((T_INCLUDE_ONCE) reduce 157) ((T_INLINE_HTML) reduce 157) ((T_INTERFACE) reduce 157) ((T_INT_CAST) reduce 157) ((T_ISSET) reduce 157) ((T_LINE) reduce 157) ((T_LIST) reduce 157) ((T_LNUMBER) reduce 157) ((T_MATCH) reduce 157) ((T_METHOD_C) reduce 157) ((T_NAME_FULLY_QUALIFIED) reduce 157) ((T_NAME_QUALIFIED) reduce 157) ((T_NAME_RELATIVE) reduce 157) ((T_NEW) reduce 157) ((T_NS_C) reduce 157) ((T_OBJECT_CAST) reduce 157) ((T_PRINT) reduce 157) ((T_READONLY) reduce 157) ((T_REQUIRE) reduce 157) ((T_REQUIRE_ONCE) reduce 157) ((T_RETURN) reduce 157) ((T_START_HEREDOC) reduce 157) ((T_STATIC) reduce 157) ((T_STRING) reduce 157) ((T_STRING_CAST) reduce 157) ((T_SWITCH) reduce 157) ((T_THROW) reduce 157) ((T_TRAIT) reduce 157) ((T_TRAIT_C) reduce 157) ((T_TRY) reduce 157) ((T_UNSET) reduce 157) ((T_UNSET_CAST) reduce 157) ((T_VARIABLE) reduce 157) ((T_WHILE) reduce 157) ((T_YIELD) reduce 157) ((T_YIELD_FROM) reduce 157) (("[") reduce 157) (("`") reduce 157) (("{") reduce 157) (("~") reduce 157)) 19745 (((",") reduce 356) ((";") reduce 356)) 19746 (((T_WHILE) reduce 164)) 19757 (((T_WHILE) reduce 158)) 19765 (((T_WHILE) reduce 147)) 19768 (((T_WHILE) reduce 146)) 19769 (((T_ELSE) shift) ((T_ELSEIF) shift) ((T_WHILE) reduce 243)) 19770 (((T_WHILE) shift)) 19773 (((T_WHILE) reduce 145)) 19778 ((("!") reduce 149) (("\"") reduce 149) (("$") reduce 149) (("(") reduce 149) (("+") reduce 149) (("-") reduce 149) ((";") reduce 149) (("@") reduce 149) ((T_ABSTRACT) reduce 149) ((T_ARRAY) reduce 149) ((T_ARRAY_CAST) reduce 149) ((T_ATTRIBUTE) reduce 149) ((T_BOOL_CAST) reduce 149) ((T_BREAK) reduce 149) ((T_CLASS) reduce 149) ((T_CLASS_C) reduce 149) ((T_CLONE) reduce 149) ((T_CONSTANT_ENCAPSED_STRING) reduce 149) ((T_CONTINUE) reduce 149) ((T_DEC) reduce 149) ((T_DECLARE) reduce 149) ((T_DIR) reduce 149) ((T_DNUMBER) reduce 149) ((T_DO) reduce 149) ((T_DOUBLE_CAST) reduce 149) ((T_ECHO) reduce 149) ((T_ELSE) reduce 149) ((T_ELSEIF) reduce 149) ((T_EMPTY) reduce 149) ((T_ENDFOR) reduce 149) ((T_ENUM) reduce 149) ((T_EVAL) reduce 149) ((T_EXIT) reduce 149) ((T_FILE) reduce 149) ((T_FINAL) reduce 149) ((T_FN) reduce 149) ((T_FOR) reduce 149) ((T_FOREACH) reduce 149) ((T_FUNCTION) reduce 149) ((T_FUNC_C) reduce 149) ((T_GLOBAL) reduce 149) ((T_GOTO) reduce 149) ((T_HALT_COMPILER) reduce 149) ((T_IF) reduce 149) ((T_INC) reduce 149) ((T_INCLUDE) reduce 149) ((T_INCLUDE_ONCE) reduce 149) ((T_INLINE_HTML) reduce 149) ((T_INTERFACE) reduce 149) ((T_INT_CAST) reduce 149) ((T_ISSET) reduce 149) ((T_LINE) reduce 149) ((T_LIST) reduce 149) ((T_LNUMBER) reduce 149) ((T_MATCH) reduce 149) ((T_METHOD_C) reduce 149) ((T_NAME_FULLY_QUALIFIED) reduce 149) ((T_NAME_QUALIFIED) reduce 149) ((T_NAME_RELATIVE) reduce 149) ((T_NEW) reduce 149) ((T_NS_C) reduce 149) ((T_OBJECT_CAST) reduce 149) ((T_PRINT) reduce 149) ((T_READONLY) reduce 149) ((T_REQUIRE) reduce 149) ((T_REQUIRE_ONCE) reduce 149) ((T_RETURN) reduce 149) ((T_START_HEREDOC) reduce 149) ((T_STATIC) reduce 149) ((T_STRING) reduce 149) ((T_STRING_CAST) reduce 149) ((T_SWITCH) reduce 149) ((T_THROW) reduce 149) ((T_TRAIT) reduce 149) ((T_TRAIT_C) reduce 149) ((T_TRY) reduce 149) ((T_UNSET) reduce 149) ((T_UNSET_CAST) reduce 149) ((T_VARIABLE) reduce 149) ((T_WHILE) reduce 149) ((T_YIELD) reduce 149) ((T_YIELD_FROM) reduce 149) (("[") reduce 149) (("`") reduce 149) (("{") reduce 149) (("~") reduce 149)) 19784 (((T_ELSE) reduce 164) ((T_ELSEIF) reduce 164) ((T_WHILE) reduce 164)) 19794 (((T_ELSE) reduce 158) ((T_ELSEIF) reduce 158) ((T_WHILE) reduce 158)) 19802 (((T_ELSE) reduce 147) ((T_ELSEIF) reduce 147) ((T_WHILE) reduce 147)) 19805 (((T_ELSE) reduce 146) ((T_ELSEIF) reduce 146) ((T_WHILE) reduce 146)) 19807 (((T_ELSE) reduce 242) ((T_ELSEIF) reduce 242) ((T_WHILE) reduce 242)) 19810 (((T_ELSE) reduce 145) ((T_ELSEIF) reduce 145) ((T_WHILE) reduce 145)) 19812 (((T_ELSE) reduce 244) ((T_ELSEIF) reduce 244) ((T_WHILE) reduce 244)) 19813 (((T_ELSE) reduce 159) ((T_ELSEIF) reduce 159) ((T_WHILE) reduce 159)) 19816 (((T_ELSE) reduce 247) ((T_ELSEIF) reduce 247) ((T_WHILE) reduce 247)) 19820 (((T_ELSE) reduce 248) ((T_ELSEIF) reduce 248) ((T_WHILE) reduce 248)) 19825 (((T_ELSE) reduce 239) ((T_ELSEIF) reduce 239) ((T_WHILE) reduce 239)) 19826 (((T_ELSE) reduce 148) ((T_ELSEIF) reduce 148) ((T_WHILE) reduce 148)) 19829 (((T_ELSE) reduce 240) ((T_ELSEIF) reduce 240) ((T_WHILE) reduce 240)) 19834 (((T_ELSE) reduce 160) ((T_ELSEIF) reduce 160) ((T_WHILE) reduce 160)) 19837 (((T_CATCH) reduce 168) ((T_ELSE) reduce 168) ((T_ELSEIF) reduce 168) ((T_FINALLY) reduce 168) ((T_WHILE) reduce 168)) 19838 (((T_CATCH) shift) ((T_ELSE) reduce 174) ((T_ELSEIF) reduce 174) ((T_FINALLY) shift) ((T_WHILE) reduce 174)) 19841 (((T_ELSE) reduce 165) ((T_ELSEIF) reduce 165) ((T_WHILE) reduce 165)) 19844 (((T_ELSE) reduce 175) ((T_ELSEIF) reduce 175) ((T_WHILE) reduce 175)) 19851 (((T_CATCH) reduce 169) ((T_ELSE) reduce 169) ((T_ELSEIF) reduce 169) ((T_FINALLY) reduce 169) ((T_WHILE) reduce 169)) 19856 (((T_ELSE) reduce 151) ((T_ELSEIF) reduce 151) ((T_WHILE) reduce 151)) 19860 (((T_ELSE) reduce 221) ((T_ELSEIF) reduce 221) ((T_WHILE) reduce 221)) 19862 (((T_ELSE) reduce 222) ((T_ELSEIF) reduce 222) ((T_WHILE) reduce 222)) 19866 (((T_ELSE) reduce 223) ((T_ELSEIF) reduce 223) ((T_WHILE) reduce 223)) 19869 (((T_ELSE) reduce 224) ((T_ELSEIF) reduce 224) ((T_WHILE) reduce 224)) 19870 (((T_ELSE) reduce 167) ((T_ELSEIF) reduce 167) ((T_WHILE) reduce 167)) 19872 (((T_ELSE) reduce 156) ((T_ELSEIF) reduce 156) ((T_WHILE) reduce 156)) 19874 (((T_ELSE) reduce 154) ((T_ELSEIF) reduce 154) ((T_WHILE) reduce 154)) 19876 (((T_ELSE) reduce 166) ((T_ELSEIF) reduce 166) ((T_WHILE) reduce 166)) 19878 (((T_ELSE) reduce 155) ((T_ELSEIF) reduce 155) ((T_WHILE) reduce 155)) 19888 (((T_ELSE) reduce 162) ((T_ELSEIF) reduce 162) ((T_WHILE) reduce 162)) 19889 (((T_ELSE) reduce 217) ((T_ELSEIF) reduce 217) ((T_WHILE) reduce 217)) 19892 (((T_ELSE) reduce 218) ((T_ELSEIF) reduce 218) ((T_WHILE) reduce 218)) 19893 (((T_ELSE) reduce 161) ((T_ELSEIF) reduce 161) ((T_WHILE) reduce 161)) 19902 (((T_ELSE) reduce 150) ((T_ELSEIF) reduce 150) ((T_WHILE) reduce 150)) 19903 (((T_ELSE) reduce 215) ((T_ELSEIF) reduce 215) ((T_WHILE) reduce 215)) 19906 (((T_ELSE) reduce 216) ((T_ELSEIF) reduce 216) ((T_WHILE) reduce 216)) 19908 (((T_ELSE) reduce 157) ((T_ELSEIF) reduce 157) ((T_WHILE) reduce 157)) 19914 (((T_ELSE) reduce 149) ((T_ELSEIF) reduce 149) ((T_WHILE) reduce 149)) 19917 (((")") reduce 138) ((",") reduce 138)) 19918 (((")") shift) ((",") shift)) 19921 (((")") reduce 137) ((",") reduce 137)) 19922 ((("!") reduce 140) (("\"") reduce 140) (("$") reduce 140) (("(") reduce 140) (("+") reduce 140) (("-") reduce 140) ((";") reduce 140) (("@") reduce 140) ((T_ABSTRACT) reduce 140) ((T_ARRAY) reduce 140) ((T_ARRAY_CAST) reduce 140) ((T_ATTRIBUTE) reduce 140) ((T_BOOL_CAST) reduce 140) ((T_BREAK) reduce 140) ((T_CLASS) reduce 140) ((T_CLASS_C) reduce 140) ((T_CLONE) reduce 140) ((T_CONSTANT_ENCAPSED_STRING) reduce 140) ((T_CONTINUE) reduce 140) ((T_DEC) reduce 140) ((T_DECLARE) reduce 140) ((T_DIR) reduce 140) ((T_DNUMBER) reduce 140) ((T_DO) reduce 140) ((T_DOUBLE_CAST) reduce 140) ((T_ECHO) reduce 140) ((T_EMPTY) reduce 140) ((T_ENDDECLARE) reduce 140) ((T_ENUM) reduce 140) ((T_EVAL) reduce 140) ((T_EXIT) reduce 140) ((T_FILE) reduce 140) ((T_FINAL) reduce 140) ((T_FN) reduce 140) ((T_FOR) reduce 140) ((T_FOREACH) reduce 140) ((T_FUNCTION) reduce 140) ((T_FUNC_C) reduce 140) ((T_GLOBAL) reduce 140) ((T_GOTO) reduce 140) ((T_HALT_COMPILER) reduce 140) ((T_IF) reduce 140) ((T_INC) reduce 140) ((T_INCLUDE) reduce 140) ((T_INCLUDE_ONCE) reduce 140) ((T_INLINE_HTML) reduce 140) ((T_INTERFACE) reduce 140) ((T_INT_CAST) reduce 140) ((T_ISSET) reduce 140) ((T_LINE) reduce 140) ((T_LIST) reduce 140) ((T_LNUMBER) reduce 140) ((T_MATCH) reduce 140) ((T_METHOD_C) reduce 140) ((T_NAME_FULLY_QUALIFIED) reduce 140) ((T_NAME_QUALIFIED) reduce 140) ((T_NAME_RELATIVE) reduce 140) ((T_NEW) reduce 140) ((T_NS_C) reduce 140) ((T_OBJECT_CAST) reduce 140) ((T_PRINT) reduce 140) ((T_READONLY) reduce 140) ((T_REQUIRE) reduce 140) ((T_REQUIRE_ONCE) reduce 140) ((T_RETURN) reduce 140) ((T_START_HEREDOC) reduce 140) ((T_STATIC) reduce 140) ((T_STRING) reduce 140) ((T_STRING_CAST) reduce 140) ((T_SWITCH) reduce 140) ((T_THROW) reduce 140) ((T_TRAIT) reduce 140) ((T_TRAIT_C) reduce 140) ((T_TRY) reduce 140) ((T_UNSET) reduce 140) ((T_UNSET_CAST) reduce 140) ((T_VARIABLE) reduce 140) ((T_WHILE) reduce 140) ((T_YIELD) reduce 140) ((T_YIELD_FROM) reduce 140) (("[") reduce 140) (("`") reduce 140) (("{") reduce 140) (("~") reduce 140)) 19923 (((T_ELSE) reduce 163) ((T_ELSEIF) reduce 163) ((T_WHILE) reduce 163)) 19924 (((T_ELSE) reduce 219) ((T_ELSEIF) reduce 219) ((T_WHILE) reduce 219)) 19925 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) (("+") shift) (("-") shift) ((";") shift) (("@") shift) ((T_ABSTRACT) shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_BREAK) shift) ((T_CLASS) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_CONTINUE) shift) ((T_DEC) shift) ((T_DECLARE) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DO) shift) ((T_DOUBLE_CAST) shift) ((T_ECHO) shift) ((T_EMPTY) shift) ((T_ENDDECLARE) shift) ((T_ENUM) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FINAL) shift) ((T_FN) shift) ((T_FOR) shift) ((T_FOREACH) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_GLOBAL) shift) ((T_GOTO) shift) ((T_HALT_COMPILER) shift) ((T_IF) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INLINE_HTML) shift) ((T_INTERFACE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_RETURN) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_SWITCH) shift) ((T_THROW) shift) ((T_TRAIT) shift) ((T_TRAIT_C) shift) ((T_TRY) shift) ((T_UNSET) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_WHILE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("{") shift) (("~") shift)) 19926 ((("!") reduce 164) (("\"") reduce 164) (("$") reduce 164) (("(") reduce 164) (("+") reduce 164) (("-") reduce 164) ((";") reduce 164) (("@") reduce 164) ((T_ABSTRACT) reduce 164) ((T_ARRAY) reduce 164) ((T_ARRAY_CAST) reduce 164) ((T_ATTRIBUTE) reduce 164) ((T_BOOL_CAST) reduce 164) ((T_BREAK) reduce 164) ((T_CLASS) reduce 164) ((T_CLASS_C) reduce 164) ((T_CLONE) reduce 164) ((T_CONSTANT_ENCAPSED_STRING) reduce 164) ((T_CONTINUE) reduce 164) ((T_DEC) reduce 164) ((T_DECLARE) reduce 164) ((T_DIR) reduce 164) ((T_DNUMBER) reduce 164) ((T_DO) reduce 164) ((T_DOUBLE_CAST) reduce 164) ((T_ECHO) reduce 164) ((T_EMPTY) reduce 164) ((T_ENDDECLARE) reduce 164) ((T_ENUM) reduce 164) ((T_EVAL) reduce 164) ((T_EXIT) reduce 164) ((T_FILE) reduce 164) ((T_FINAL) reduce 164) ((T_FN) reduce 164) ((T_FOR) reduce 164) ((T_FOREACH) reduce 164) ((T_FUNCTION) reduce 164) ((T_FUNC_C) reduce 164) ((T_GLOBAL) reduce 164) ((T_GOTO) reduce 164) ((T_HALT_COMPILER) reduce 164) ((T_IF) reduce 164) ((T_INC) reduce 164) ((T_INCLUDE) reduce 164) ((T_INCLUDE_ONCE) reduce 164) ((T_INLINE_HTML) reduce 164) ((T_INTERFACE) reduce 164) ((T_INT_CAST) reduce 164) ((T_ISSET) reduce 164) ((T_LINE) reduce 164) ((T_LIST) reduce 164) ((T_LNUMBER) reduce 164) ((T_MATCH) reduce 164) ((T_METHOD_C) reduce 164) ((T_NAME_FULLY_QUALIFIED) reduce 164) ((T_NAME_QUALIFIED) reduce 164) ((T_NAME_RELATIVE) reduce 164) ((T_NEW) reduce 164) ((T_NS_C) reduce 164) ((T_OBJECT_CAST) reduce 164) ((T_PRINT) reduce 164) ((T_READONLY) reduce 164) ((T_REQUIRE) reduce 164) ((T_REQUIRE_ONCE) reduce 164) ((T_RETURN) reduce 164) ((T_START_HEREDOC) reduce 164) ((T_STATIC) reduce 164) ((T_STRING) reduce 164) ((T_STRING_CAST) reduce 164) ((T_SWITCH) reduce 164) ((T_THROW) reduce 164) ((T_TRAIT) reduce 164) ((T_TRAIT_C) reduce 164) ((T_TRY) reduce 164) ((T_UNSET) reduce 164) ((T_UNSET_CAST) reduce 164) ((T_VARIABLE) reduce 164) ((T_WHILE) reduce 164) ((T_YIELD) reduce 164) ((T_YIELD_FROM) reduce 164) (("[") reduce 164) (("`") reduce 164) (("{") reduce 164) (("~") reduce 164)) 19941 ((("!") reduce 158) (("\"") reduce 158) (("$") reduce 158) (("(") reduce 158) (("+") reduce 158) (("-") reduce 158) ((";") reduce 158) (("@") reduce 158) ((T_ABSTRACT) reduce 158) ((T_ARRAY) reduce 158) ((T_ARRAY_CAST) reduce 158) ((T_ATTRIBUTE) reduce 158) ((T_BOOL_CAST) reduce 158) ((T_BREAK) reduce 158) ((T_CLASS) reduce 158) ((T_CLASS_C) reduce 158) ((T_CLONE) reduce 158) ((T_CONSTANT_ENCAPSED_STRING) reduce 158) ((T_CONTINUE) reduce 158) ((T_DEC) reduce 158) ((T_DECLARE) reduce 158) ((T_DIR) reduce 158) ((T_DNUMBER) reduce 158) ((T_DO) reduce 158) ((T_DOUBLE_CAST) reduce 158) ((T_ECHO) reduce 158) ((T_EMPTY) reduce 158) ((T_ENDDECLARE) reduce 158) ((T_ENUM) reduce 158) ((T_EVAL) reduce 158) ((T_EXIT) reduce 158) ((T_FILE) reduce 158) ((T_FINAL) reduce 158) ((T_FN) reduce 158) ((T_FOR) reduce 158) ((T_FOREACH) reduce 158) ((T_FUNCTION) reduce 158) ((T_FUNC_C) reduce 158) ((T_GLOBAL) reduce 158) ((T_GOTO) reduce 158) ((T_HALT_COMPILER) reduce 158) ((T_IF) reduce 158) ((T_INC) reduce 158) ((T_INCLUDE) reduce 158) ((T_INCLUDE_ONCE) reduce 158) ((T_INLINE_HTML) reduce 158) ((T_INTERFACE) reduce 158) ((T_INT_CAST) reduce 158) ((T_ISSET) reduce 158) ((T_LINE) reduce 158) ((T_LIST) reduce 158) ((T_LNUMBER) reduce 158) ((T_MATCH) reduce 158) ((T_METHOD_C) reduce 158) ((T_NAME_FULLY_QUALIFIED) reduce 158) ((T_NAME_QUALIFIED) reduce 158) ((T_NAME_RELATIVE) reduce 158) ((T_NEW) reduce 158) ((T_NS_C) reduce 158) ((T_OBJECT_CAST) reduce 158) ((T_PRINT) reduce 158) ((T_READONLY) reduce 158) ((T_REQUIRE) reduce 158) ((T_REQUIRE_ONCE) reduce 158) ((T_RETURN) reduce 158) ((T_START_HEREDOC) reduce 158) ((T_STATIC) reduce 158) ((T_STRING) reduce 158) ((T_STRING_CAST) reduce 158) ((T_SWITCH) reduce 158) ((T_THROW) reduce 158) ((T_TRAIT) reduce 158) ((T_TRAIT_C) reduce 158) ((T_TRY) reduce 158) ((T_UNSET) reduce 158) ((T_UNSET_CAST) reduce 158) ((T_VARIABLE) reduce 158) ((T_WHILE) reduce 158) ((T_YIELD) reduce 158) ((T_YIELD_FROM) reduce 158) (("[") reduce 158) (("`") reduce 158) (("{") reduce 158) (("~") reduce 158)) 19951 ((("!") reduce 147) (("\"") reduce 147) (("$") reduce 147) (("(") reduce 147) (("+") reduce 147) (("-") reduce 147) ((";") reduce 147) (("@") reduce 147) ((T_ABSTRACT) reduce 147) ((T_ARRAY) reduce 147) ((T_ARRAY_CAST) reduce 147) ((T_ATTRIBUTE) reduce 147) ((T_BOOL_CAST) reduce 147) ((T_BREAK) reduce 147) ((T_CLASS) reduce 147) ((T_CLASS_C) reduce 147) ((T_CLONE) reduce 147) ((T_CONSTANT_ENCAPSED_STRING) reduce 147) ((T_CONTINUE) reduce 147) ((T_DEC) reduce 147) ((T_DECLARE) reduce 147) ((T_DIR) reduce 147) ((T_DNUMBER) reduce 147) ((T_DO) reduce 147) ((T_DOUBLE_CAST) reduce 147) ((T_ECHO) reduce 147) ((T_EMPTY) reduce 147) ((T_ENDDECLARE) reduce 147) ((T_ENUM) reduce 147) ((T_EVAL) reduce 147) ((T_EXIT) reduce 147) ((T_FILE) reduce 147) ((T_FINAL) reduce 147) ((T_FN) reduce 147) ((T_FOR) reduce 147) ((T_FOREACH) reduce 147) ((T_FUNCTION) reduce 147) ((T_FUNC_C) reduce 147) ((T_GLOBAL) reduce 147) ((T_GOTO) reduce 147) ((T_HALT_COMPILER) reduce 147) ((T_IF) reduce 147) ((T_INC) reduce 147) ((T_INCLUDE) reduce 147) ((T_INCLUDE_ONCE) reduce 147) ((T_INLINE_HTML) reduce 147) ((T_INTERFACE) reduce 147) ((T_INT_CAST) reduce 147) ((T_ISSET) reduce 147) ((T_LINE) reduce 147) ((T_LIST) reduce 147) ((T_LNUMBER) reduce 147) ((T_MATCH) reduce 147) ((T_METHOD_C) reduce 147) ((T_NAME_FULLY_QUALIFIED) reduce 147) ((T_NAME_QUALIFIED) reduce 147) ((T_NAME_RELATIVE) reduce 147) ((T_NEW) reduce 147) ((T_NS_C) reduce 147) ((T_OBJECT_CAST) reduce 147) ((T_PRINT) reduce 147) ((T_READONLY) reduce 147) ((T_REQUIRE) reduce 147) ((T_REQUIRE_ONCE) reduce 147) ((T_RETURN) reduce 147) ((T_START_HEREDOC) reduce 147) ((T_STATIC) reduce 147) ((T_STRING) reduce 147) ((T_STRING_CAST) reduce 147) ((T_SWITCH) reduce 147) ((T_THROW) reduce 147) ((T_TRAIT) reduce 147) ((T_TRAIT_C) reduce 147) ((T_TRY) reduce 147) ((T_UNSET) reduce 147) ((T_UNSET_CAST) reduce 147) ((T_VARIABLE) reduce 147) ((T_WHILE) reduce 147) ((T_YIELD) reduce 147) ((T_YIELD_FROM) reduce 147) (("[") reduce 147) (("`") reduce 147) (("{") reduce 147) (("~") reduce 147)) 19953 ((("!") reduce 142) (("\"") reduce 142) (("$") reduce 142) (("(") reduce 142) (("+") reduce 142) (("-") reduce 142) ((";") reduce 142) (("@") reduce 142) ((T_ABSTRACT) reduce 142) ((T_ARRAY) reduce 142) ((T_ARRAY_CAST) reduce 142) ((T_ATTRIBUTE) reduce 142) ((T_BOOL_CAST) reduce 142) ((T_BREAK) reduce 142) ((T_CLASS) reduce 142) ((T_CLASS_C) reduce 142) ((T_CLONE) reduce 142) ((T_CONSTANT_ENCAPSED_STRING) reduce 142) ((T_CONTINUE) reduce 142) ((T_DEC) reduce 142) ((T_DECLARE) reduce 142) ((T_DIR) reduce 142) ((T_DNUMBER) reduce 142) ((T_DO) reduce 142) ((T_DOUBLE_CAST) reduce 142) ((T_ECHO) reduce 142) ((T_EMPTY) reduce 142) ((T_ENDDECLARE) reduce 142) ((T_ENUM) reduce 142) ((T_EVAL) reduce 142) ((T_EXIT) reduce 142) ((T_FILE) reduce 142) ((T_FINAL) reduce 142) ((T_FN) reduce 142) ((T_FOR) reduce 142) ((T_FOREACH) reduce 142) ((T_FUNCTION) reduce 142) ((T_FUNC_C) reduce 142) ((T_GLOBAL) reduce 142) ((T_GOTO) reduce 142) ((T_HALT_COMPILER) reduce 142) ((T_IF) reduce 142) ((T_INC) reduce 142) ((T_INCLUDE) reduce 142) ((T_INCLUDE_ONCE) reduce 142) ((T_INLINE_HTML) reduce 142) ((T_INTERFACE) reduce 142) ((T_INT_CAST) reduce 142) ((T_ISSET) reduce 142) ((T_LINE) reduce 142) ((T_LIST) reduce 142) ((T_LNUMBER) reduce 142) ((T_MATCH) reduce 142) ((T_METHOD_C) reduce 142) ((T_NAME_FULLY_QUALIFIED) reduce 142) ((T_NAME_QUALIFIED) reduce 142) ((T_NAME_RELATIVE) reduce 142) ((T_NEW) reduce 142) ((T_NS_C) reduce 142) ((T_OBJECT_CAST) reduce 142) ((T_PRINT) reduce 142) ((T_READONLY) reduce 142) ((T_REQUIRE) reduce 142) ((T_REQUIRE_ONCE) reduce 142) ((T_RETURN) reduce 142) ((T_START_HEREDOC) reduce 142) ((T_STATIC) reduce 142) ((T_STRING) reduce 142) ((T_STRING_CAST) reduce 142) ((T_SWITCH) reduce 142) ((T_THROW) reduce 142) ((T_TRAIT) reduce 142) ((T_TRAIT_C) reduce 142) ((T_TRY) reduce 142) ((T_UNSET) reduce 142) ((T_UNSET_CAST) reduce 142) ((T_VARIABLE) reduce 142) ((T_WHILE) reduce 142) ((T_YIELD) reduce 142) ((T_YIELD_FROM) reduce 142) (("[") reduce 142) (("`") reduce 142) (("{") reduce 142) (("~") reduce 142)) 19955 ((("!") reduce 103) (("\"") reduce 103) (("$") reduce 103) (("(") reduce 103) (("+") reduce 103) (("-") reduce 103) ((";") reduce 103) (("@") reduce 103) ((T_ABSTRACT) reduce 103) ((T_ARRAY) reduce 103) ((T_ARRAY_CAST) reduce 103) ((T_ATTRIBUTE) reduce 103) ((T_BOOL_CAST) reduce 103) ((T_BREAK) reduce 103) ((T_CLASS) reduce 103) ((T_CLASS_C) reduce 103) ((T_CLONE) reduce 103) ((T_CONSTANT_ENCAPSED_STRING) reduce 103) ((T_CONTINUE) reduce 103) ((T_DEC) reduce 103) ((T_DECLARE) reduce 103) ((T_DIR) reduce 103) ((T_DNUMBER) reduce 103) ((T_DO) reduce 103) ((T_DOUBLE_CAST) reduce 103) ((T_ECHO) reduce 103) ((T_EMPTY) reduce 103) ((T_ENDDECLARE) reduce 103) ((T_ENUM) reduce 103) ((T_EVAL) reduce 103) ((T_EXIT) reduce 103) ((T_FILE) reduce 103) ((T_FINAL) reduce 103) ((T_FN) reduce 103) ((T_FOR) reduce 103) ((T_FOREACH) reduce 103) ((T_FUNCTION) reduce 103) ((T_FUNC_C) reduce 103) ((T_GLOBAL) reduce 103) ((T_GOTO) reduce 103) ((T_HALT_COMPILER) reduce 103) ((T_IF) reduce 103) ((T_INC) reduce 103) ((T_INCLUDE) reduce 103) ((T_INCLUDE_ONCE) reduce 103) ((T_INLINE_HTML) reduce 103) ((T_INTERFACE) reduce 103) ((T_INT_CAST) reduce 103) ((T_ISSET) reduce 103) ((T_LINE) reduce 103) ((T_LIST) reduce 103) ((T_LNUMBER) reduce 103) ((T_MATCH) reduce 103) ((T_METHOD_C) reduce 103) ((T_NAME_FULLY_QUALIFIED) reduce 103) ((T_NAME_QUALIFIED) reduce 103) ((T_NAME_RELATIVE) reduce 103) ((T_NEW) reduce 103) ((T_NS_C) reduce 103) ((T_OBJECT_CAST) reduce 103) ((T_PRINT) reduce 103) ((T_READONLY) reduce 103) ((T_REQUIRE) reduce 103) ((T_REQUIRE_ONCE) reduce 103) ((T_RETURN) reduce 103) ((T_START_HEREDOC) reduce 103) ((T_STATIC) reduce 103) ((T_STRING) reduce 103) ((T_STRING_CAST) reduce 103) ((T_SWITCH) reduce 103) ((T_THROW) reduce 103) ((T_TRAIT) reduce 103) ((T_TRAIT_C) reduce 103) ((T_TRY) reduce 103) ((T_UNSET) reduce 103) ((T_UNSET_CAST) reduce 103) ((T_VARIABLE) reduce 103) ((T_WHILE) reduce 103) ((T_YIELD) reduce 103) ((T_YIELD_FROM) reduce 103) (("[") reduce 103) (("`") reduce 103) (("{") reduce 103) (("~") reduce 103)) 19957 ((("!") reduce 106) (("\"") reduce 106) (("$") reduce 106) (("(") reduce 106) (("+") reduce 106) (("-") reduce 106) ((";") reduce 106) (("@") reduce 106) ((T_ABSTRACT) reduce 106) ((T_ARRAY) reduce 106) ((T_ARRAY_CAST) reduce 106) ((T_ATTRIBUTE) reduce 106) ((T_BOOL_CAST) reduce 106) ((T_BREAK) reduce 106) ((T_CLASS) reduce 106) ((T_CLASS_C) reduce 106) ((T_CLONE) reduce 106) ((T_CONSTANT_ENCAPSED_STRING) reduce 106) ((T_CONTINUE) reduce 106) ((T_DEC) reduce 106) ((T_DECLARE) reduce 106) ((T_DIR) reduce 106) ((T_DNUMBER) reduce 106) ((T_DO) reduce 106) ((T_DOUBLE_CAST) reduce 106) ((T_ECHO) reduce 106) ((T_EMPTY) reduce 106) ((T_ENDDECLARE) reduce 106) ((T_ENUM) reduce 106) ((T_EVAL) reduce 106) ((T_EXIT) reduce 106) ((T_FILE) reduce 106) ((T_FINAL) reduce 106) ((T_FN) reduce 106) ((T_FOR) reduce 106) ((T_FOREACH) reduce 106) ((T_FUNCTION) reduce 106) ((T_FUNC_C) reduce 106) ((T_GLOBAL) reduce 106) ((T_GOTO) reduce 106) ((T_HALT_COMPILER) reduce 106) ((T_IF) reduce 106) ((T_INC) reduce 106) ((T_INCLUDE) reduce 106) ((T_INCLUDE_ONCE) reduce 106) ((T_INLINE_HTML) reduce 106) ((T_INTERFACE) reduce 106) ((T_INT_CAST) reduce 106) ((T_ISSET) reduce 106) ((T_LINE) reduce 106) ((T_LIST) reduce 106) ((T_LNUMBER) reduce 106) ((T_MATCH) reduce 106) ((T_METHOD_C) reduce 106) ((T_NAME_FULLY_QUALIFIED) reduce 106) ((T_NAME_QUALIFIED) reduce 106) ((T_NAME_RELATIVE) reduce 106) ((T_NEW) reduce 106) ((T_NS_C) reduce 106) ((T_OBJECT_CAST) reduce 106) ((T_PRINT) reduce 106) ((T_READONLY) reduce 106) ((T_REQUIRE) reduce 106) ((T_REQUIRE_ONCE) reduce 106) ((T_RETURN) reduce 106) ((T_START_HEREDOC) reduce 106) ((T_STATIC) reduce 106) ((T_STRING) reduce 106) ((T_STRING_CAST) reduce 106) ((T_SWITCH) reduce 106) ((T_THROW) reduce 106) ((T_TRAIT) reduce 106) ((T_TRAIT_C) reduce 106) ((T_TRY) reduce 106) ((T_UNSET) reduce 106) ((T_UNSET_CAST) reduce 106) ((T_VARIABLE) reduce 106) ((T_WHILE) reduce 106) ((T_YIELD) reduce 106) ((T_YIELD_FROM) reduce 106) (("[") reduce 106) (("`") reduce 106) (("{") reduce 106) (("~") reduce 106)) 19960 ((("!") reduce 102) (("\"") reduce 102) (("$") reduce 102) (("(") reduce 102) (("+") reduce 102) (("-") reduce 102) ((";") reduce 102) (("@") reduce 102) ((T_ABSTRACT) reduce 102) ((T_ARRAY) reduce 102) ((T_ARRAY_CAST) reduce 102) ((T_ATTRIBUTE) reduce 102) ((T_BOOL_CAST) reduce 102) ((T_BREAK) reduce 102) ((T_CLASS) reduce 102) ((T_CLASS_C) reduce 102) ((T_CLONE) reduce 102) ((T_CONSTANT_ENCAPSED_STRING) reduce 102) ((T_CONTINUE) reduce 102) ((T_DEC) reduce 102) ((T_DECLARE) reduce 102) ((T_DIR) reduce 102) ((T_DNUMBER) reduce 102) ((T_DO) reduce 102) ((T_DOUBLE_CAST) reduce 102) ((T_ECHO) reduce 102) ((T_EMPTY) reduce 102) ((T_ENDDECLARE) reduce 102) ((T_ENUM) reduce 102) ((T_EVAL) reduce 102) ((T_EXIT) reduce 102) ((T_FILE) reduce 102) ((T_FINAL) reduce 102) ((T_FN) reduce 102) ((T_FOR) reduce 102) ((T_FOREACH) reduce 102) ((T_FUNCTION) reduce 102) ((T_FUNC_C) reduce 102) ((T_GLOBAL) reduce 102) ((T_GOTO) reduce 102) ((T_HALT_COMPILER) reduce 102) ((T_IF) reduce 102) ((T_INC) reduce 102) ((T_INCLUDE) reduce 102) ((T_INCLUDE_ONCE) reduce 102) ((T_INLINE_HTML) reduce 102) ((T_INTERFACE) reduce 102) ((T_INT_CAST) reduce 102) ((T_ISSET) reduce 102) ((T_LINE) reduce 102) ((T_LIST) reduce 102) ((T_LNUMBER) reduce 102) ((T_MATCH) reduce 102) ((T_METHOD_C) reduce 102) ((T_NAME_FULLY_QUALIFIED) reduce 102) ((T_NAME_QUALIFIED) reduce 102) ((T_NAME_RELATIVE) reduce 102) ((T_NEW) reduce 102) ((T_NS_C) reduce 102) ((T_OBJECT_CAST) reduce 102) ((T_PRINT) reduce 102) ((T_READONLY) reduce 102) ((T_REQUIRE) reduce 102) ((T_REQUIRE_ONCE) reduce 102) ((T_RETURN) reduce 102) ((T_START_HEREDOC) reduce 102) ((T_STATIC) reduce 102) ((T_STRING) reduce 102) ((T_STRING_CAST) reduce 102) ((T_SWITCH) reduce 102) ((T_THROW) reduce 102) ((T_TRAIT) reduce 102) ((T_TRAIT_C) reduce 102) ((T_TRY) reduce 102) ((T_UNSET) reduce 102) ((T_UNSET_CAST) reduce 102) ((T_VARIABLE) reduce 102) ((T_WHILE) reduce 102) ((T_YIELD) reduce 102) ((T_YIELD_FROM) reduce 102) (("[") reduce 102) (("`") reduce 102) (("{") reduce 102) (("~") reduce 102)) 19961 ((("!") reduce 146) (("\"") reduce 146) (("$") reduce 146) (("(") reduce 146) (("+") reduce 146) (("-") reduce 146) ((";") reduce 146) (("@") reduce 146) ((T_ABSTRACT) reduce 146) ((T_ARRAY) reduce 146) ((T_ARRAY_CAST) reduce 146) ((T_ATTRIBUTE) reduce 146) ((T_BOOL_CAST) reduce 146) ((T_BREAK) reduce 146) ((T_CLASS) reduce 146) ((T_CLASS_C) reduce 146) ((T_CLONE) reduce 146) ((T_CONSTANT_ENCAPSED_STRING) reduce 146) ((T_CONTINUE) reduce 146) ((T_DEC) reduce 146) ((T_DECLARE) reduce 146) ((T_DIR) reduce 146) ((T_DNUMBER) reduce 146) ((T_DO) reduce 146) ((T_DOUBLE_CAST) reduce 146) ((T_ECHO) reduce 146) ((T_EMPTY) reduce 146) ((T_ENDDECLARE) reduce 146) ((T_ENUM) reduce 146) ((T_EVAL) reduce 146) ((T_EXIT) reduce 146) ((T_FILE) reduce 146) ((T_FINAL) reduce 146) ((T_FN) reduce 146) ((T_FOR) reduce 146) ((T_FOREACH) reduce 146) ((T_FUNCTION) reduce 146) ((T_FUNC_C) reduce 146) ((T_GLOBAL) reduce 146) ((T_GOTO) reduce 146) ((T_HALT_COMPILER) reduce 146) ((T_IF) reduce 146) ((T_INC) reduce 146) ((T_INCLUDE) reduce 146) ((T_INCLUDE_ONCE) reduce 146) ((T_INLINE_HTML) reduce 146) ((T_INTERFACE) reduce 146) ((T_INT_CAST) reduce 146) ((T_ISSET) reduce 146) ((T_LINE) reduce 146) ((T_LIST) reduce 146) ((T_LNUMBER) reduce 146) ((T_MATCH) reduce 146) ((T_METHOD_C) reduce 146) ((T_NAME_FULLY_QUALIFIED) reduce 146) ((T_NAME_QUALIFIED) reduce 146) ((T_NAME_RELATIVE) reduce 146) ((T_NEW) reduce 146) ((T_NS_C) reduce 146) ((T_OBJECT_CAST) reduce 146) ((T_PRINT) reduce 146) ((T_READONLY) reduce 146) ((T_REQUIRE) reduce 146) ((T_REQUIRE_ONCE) reduce 146) ((T_RETURN) reduce 146) ((T_START_HEREDOC) reduce 146) ((T_STATIC) reduce 146) ((T_STRING) reduce 146) ((T_STRING_CAST) reduce 146) ((T_SWITCH) reduce 146) ((T_THROW) reduce 146) ((T_TRAIT) reduce 146) ((T_TRAIT_C) reduce 146) ((T_TRY) reduce 146) ((T_UNSET) reduce 146) ((T_UNSET_CAST) reduce 146) ((T_VARIABLE) reduce 146) ((T_WHILE) reduce 146) ((T_YIELD) reduce 146) ((T_YIELD_FROM) reduce 146) (("[") reduce 146) (("`") reduce 146) (("{") reduce 146) (("~") reduce 146)) 19962 ((("!") reduce 243) (("\"") reduce 243) (("$") reduce 243) (("(") reduce 243) (("+") reduce 243) (("-") reduce 243) ((";") reduce 243) (("@") reduce 243) ((T_ABSTRACT) reduce 243) ((T_ARRAY) reduce 243) ((T_ARRAY_CAST) reduce 243) ((T_ATTRIBUTE) reduce 243) ((T_BOOL_CAST) reduce 243) ((T_BREAK) reduce 243) ((T_CLASS) reduce 243) ((T_CLASS_C) reduce 243) ((T_CLONE) reduce 243) ((T_CONSTANT_ENCAPSED_STRING) reduce 243) ((T_CONTINUE) reduce 243) ((T_DEC) reduce 243) ((T_DECLARE) reduce 243) ((T_DIR) reduce 243) ((T_DNUMBER) reduce 243) ((T_DO) reduce 243) ((T_DOUBLE_CAST) reduce 243) ((T_ECHO) reduce 243) ((T_ELSE) shift) ((T_ELSEIF) shift) ((T_EMPTY) reduce 243) ((T_ENDDECLARE) reduce 243) ((T_ENUM) reduce 243) ((T_EVAL) reduce 243) ((T_EXIT) reduce 243) ((T_FILE) reduce 243) ((T_FINAL) reduce 243) ((T_FN) reduce 243) ((T_FOR) reduce 243) ((T_FOREACH) reduce 243) ((T_FUNCTION) reduce 243) ((T_FUNC_C) reduce 243) ((T_GLOBAL) reduce 243) ((T_GOTO) reduce 243) ((T_HALT_COMPILER) reduce 243) ((T_IF) reduce 243) ((T_INC) reduce 243) ((T_INCLUDE) reduce 243) ((T_INCLUDE_ONCE) reduce 243) ((T_INLINE_HTML) reduce 243) ((T_INTERFACE) reduce 243) ((T_INT_CAST) reduce 243) ((T_ISSET) reduce 243) ((T_LINE) reduce 243) ((T_LIST) reduce 243) ((T_LNUMBER) reduce 243) ((T_MATCH) reduce 243) ((T_METHOD_C) reduce 243) ((T_NAME_FULLY_QUALIFIED) reduce 243) ((T_NAME_QUALIFIED) reduce 243) ((T_NAME_RELATIVE) reduce 243) ((T_NEW) reduce 243) ((T_NS_C) reduce 243) ((T_OBJECT_CAST) reduce 243) ((T_PRINT) reduce 243) ((T_READONLY) reduce 243) ((T_REQUIRE) reduce 243) ((T_REQUIRE_ONCE) reduce 243) ((T_RETURN) reduce 243) ((T_START_HEREDOC) reduce 243) ((T_STATIC) reduce 243) ((T_STRING) reduce 243) ((T_STRING_CAST) reduce 243) ((T_SWITCH) reduce 243) ((T_THROW) reduce 243) ((T_TRAIT) reduce 243) ((T_TRAIT_C) reduce 243) ((T_TRY) reduce 243) ((T_UNSET) reduce 243) ((T_UNSET_CAST) reduce 243) ((T_VARIABLE) reduce 243) ((T_WHILE) reduce 243) ((T_YIELD) reduce 243) ((T_YIELD_FROM) reduce 243) (("[") reduce 243) (("`") reduce 243) (("{") reduce 243) (("~") reduce 243)) 19963 ((("!") reduce 139) (("\"") reduce 139) (("$") reduce 139) (("(") reduce 139) (("+") reduce 139) (("-") reduce 139) ((";") reduce 139) (("@") reduce 139) ((T_ABSTRACT) reduce 139) ((T_ARRAY) reduce 139) ((T_ARRAY_CAST) reduce 139) ((T_ATTRIBUTE) reduce 139) ((T_BOOL_CAST) reduce 139) ((T_BREAK) reduce 139) ((T_CLASS) reduce 139) ((T_CLASS_C) reduce 139) ((T_CLONE) reduce 139) ((T_CONSTANT_ENCAPSED_STRING) reduce 139) ((T_CONTINUE) reduce 139) ((T_DEC) reduce 139) ((T_DECLARE) reduce 139) ((T_DIR) reduce 139) ((T_DNUMBER) reduce 139) ((T_DO) reduce 139) ((T_DOUBLE_CAST) reduce 139) ((T_ECHO) reduce 139) ((T_EMPTY) reduce 139) ((T_ENDDECLARE) reduce 139) ((T_ENUM) reduce 139) ((T_EVAL) reduce 139) ((T_EXIT) reduce 139) ((T_FILE) reduce 139) ((T_FINAL) reduce 139) ((T_FN) reduce 139) ((T_FOR) reduce 139) ((T_FOREACH) reduce 139) ((T_FUNCTION) reduce 139) ((T_FUNC_C) reduce 139) ((T_GLOBAL) reduce 139) ((T_GOTO) reduce 139) ((T_HALT_COMPILER) reduce 139) ((T_IF) reduce 139) ((T_INC) reduce 139) ((T_INCLUDE) reduce 139) ((T_INCLUDE_ONCE) reduce 139) ((T_INLINE_HTML) reduce 139) ((T_INTERFACE) reduce 139) ((T_INT_CAST) reduce 139) ((T_ISSET) reduce 139) ((T_LINE) reduce 139) ((T_LIST) reduce 139) ((T_LNUMBER) reduce 139) ((T_MATCH) reduce 139) ((T_METHOD_C) reduce 139) ((T_NAME_FULLY_QUALIFIED) reduce 139) ((T_NAME_QUALIFIED) reduce 139) ((T_NAME_RELATIVE) reduce 139) ((T_NEW) reduce 139) ((T_NS_C) reduce 139) ((T_OBJECT_CAST) reduce 139) ((T_PRINT) reduce 139) ((T_READONLY) reduce 139) ((T_REQUIRE) reduce 139) ((T_REQUIRE_ONCE) reduce 139) ((T_RETURN) reduce 139) ((T_START_HEREDOC) reduce 139) ((T_STATIC) reduce 139) ((T_STRING) reduce 139) ((T_STRING_CAST) reduce 139) ((T_SWITCH) reduce 139) ((T_THROW) reduce 139) ((T_TRAIT) reduce 139) ((T_TRAIT_C) reduce 139) ((T_TRY) reduce 139) ((T_UNSET) reduce 139) ((T_UNSET_CAST) reduce 139) ((T_VARIABLE) reduce 139) ((T_WHILE) reduce 139) ((T_YIELD) reduce 139) ((T_YIELD_FROM) reduce 139) (("[") reduce 139) (("`") reduce 139) (("{") reduce 139) (("~") reduce 139)) 19964 ((("!") reduce 105) (("\"") reduce 105) (("$") reduce 105) (("(") reduce 105) (("+") reduce 105) (("-") reduce 105) ((";") reduce 105) (("@") reduce 105) ((T_ABSTRACT) reduce 105) ((T_ARRAY) reduce 105) ((T_ARRAY_CAST) reduce 105) ((T_ATTRIBUTE) reduce 105) ((T_BOOL_CAST) reduce 105) ((T_BREAK) reduce 105) ((T_CLASS) reduce 105) ((T_CLASS_C) reduce 105) ((T_CLONE) reduce 105) ((T_CONSTANT_ENCAPSED_STRING) reduce 105) ((T_CONTINUE) reduce 105) ((T_DEC) reduce 105) ((T_DECLARE) reduce 105) ((T_DIR) reduce 105) ((T_DNUMBER) reduce 105) ((T_DO) reduce 105) ((T_DOUBLE_CAST) reduce 105) ((T_ECHO) reduce 105) ((T_EMPTY) reduce 105) ((T_ENDDECLARE) reduce 105) ((T_ENUM) reduce 105) ((T_EVAL) reduce 105) ((T_EXIT) reduce 105) ((T_FILE) reduce 105) ((T_FINAL) reduce 105) ((T_FN) reduce 105) ((T_FOR) reduce 105) ((T_FOREACH) reduce 105) ((T_FUNCTION) reduce 105) ((T_FUNC_C) reduce 105) ((T_GLOBAL) reduce 105) ((T_GOTO) reduce 105) ((T_HALT_COMPILER) reduce 105) ((T_IF) reduce 105) ((T_INC) reduce 105) ((T_INCLUDE) reduce 105) ((T_INCLUDE_ONCE) reduce 105) ((T_INLINE_HTML) reduce 105) ((T_INTERFACE) reduce 105) ((T_INT_CAST) reduce 105) ((T_ISSET) reduce 105) ((T_LINE) reduce 105) ((T_LIST) reduce 105) ((T_LNUMBER) reduce 105) ((T_MATCH) reduce 105) ((T_METHOD_C) reduce 105) ((T_NAME_FULLY_QUALIFIED) reduce 105) ((T_NAME_QUALIFIED) reduce 105) ((T_NAME_RELATIVE) reduce 105) ((T_NEW) reduce 105) ((T_NS_C) reduce 105) ((T_OBJECT_CAST) reduce 105) ((T_PRINT) reduce 105) ((T_READONLY) reduce 105) ((T_REQUIRE) reduce 105) ((T_REQUIRE_ONCE) reduce 105) ((T_RETURN) reduce 105) ((T_START_HEREDOC) reduce 105) ((T_STATIC) reduce 105) ((T_STRING) reduce 105) ((T_STRING_CAST) reduce 105) ((T_SWITCH) reduce 105) ((T_THROW) reduce 105) ((T_TRAIT) reduce 105) ((T_TRAIT_C) reduce 105) ((T_TRY) reduce 105) ((T_UNSET) reduce 105) ((T_UNSET_CAST) reduce 105) ((T_VARIABLE) reduce 105) ((T_WHILE) reduce 105) ((T_YIELD) reduce 105) ((T_YIELD_FROM) reduce 105) (("[") reduce 105) (("`") reduce 105) (("{") reduce 105) (("~") reduce 105)) 19965 ((("!") reduce 141) (("\"") reduce 141) (("$") reduce 141) (("(") reduce 141) (("+") reduce 141) (("-") reduce 141) ((";") reduce 141) (("@") reduce 141) ((T_ABSTRACT) reduce 141) ((T_ARRAY) reduce 141) ((T_ARRAY_CAST) reduce 141) ((T_ATTRIBUTE) reduce 141) ((T_BOOL_CAST) reduce 141) ((T_BREAK) reduce 141) ((T_CLASS) reduce 141) ((T_CLASS_C) reduce 141) ((T_CLONE) reduce 141) ((T_CONSTANT_ENCAPSED_STRING) reduce 141) ((T_CONTINUE) reduce 141) ((T_DEC) reduce 141) ((T_DECLARE) reduce 141) ((T_DIR) reduce 141) ((T_DNUMBER) reduce 141) ((T_DO) reduce 141) ((T_DOUBLE_CAST) reduce 141) ((T_ECHO) reduce 141) ((T_EMPTY) reduce 141) ((T_ENDDECLARE) reduce 141) ((T_ENUM) reduce 141) ((T_EVAL) reduce 141) ((T_EXIT) reduce 141) ((T_FILE) reduce 141) ((T_FINAL) reduce 141) ((T_FN) reduce 141) ((T_FOR) reduce 141) ((T_FOREACH) reduce 141) ((T_FUNCTION) reduce 141) ((T_FUNC_C) reduce 141) ((T_GLOBAL) reduce 141) ((T_GOTO) reduce 141) ((T_HALT_COMPILER) reduce 141) ((T_IF) reduce 141) ((T_INC) reduce 141) ((T_INCLUDE) reduce 141) ((T_INCLUDE_ONCE) reduce 141) ((T_INLINE_HTML) reduce 141) ((T_INTERFACE) reduce 141) ((T_INT_CAST) reduce 141) ((T_ISSET) reduce 141) ((T_LINE) reduce 141) ((T_LIST) reduce 141) ((T_LNUMBER) reduce 141) ((T_MATCH) reduce 141) ((T_METHOD_C) reduce 141) ((T_NAME_FULLY_QUALIFIED) reduce 141) ((T_NAME_QUALIFIED) reduce 141) ((T_NAME_RELATIVE) reduce 141) ((T_NEW) reduce 141) ((T_NS_C) reduce 141) ((T_OBJECT_CAST) reduce 141) ((T_PRINT) reduce 141) ((T_READONLY) reduce 141) ((T_REQUIRE) reduce 141) ((T_REQUIRE_ONCE) reduce 141) ((T_RETURN) reduce 141) ((T_START_HEREDOC) reduce 141) ((T_STATIC) reduce 141) ((T_STRING) reduce 141) ((T_STRING_CAST) reduce 141) ((T_SWITCH) reduce 141) ((T_THROW) reduce 141) ((T_TRAIT) reduce 141) ((T_TRAIT_C) reduce 141) ((T_TRY) reduce 141) ((T_UNSET) reduce 141) ((T_UNSET_CAST) reduce 141) ((T_VARIABLE) reduce 141) ((T_WHILE) reduce 141) ((T_YIELD) reduce 141) ((T_YIELD_FROM) reduce 141) (("[") reduce 141) (("`") reduce 141) (("{") reduce 141) (("~") reduce 141)) 19966 ((("!") reduce 104) (("\"") reduce 104) (("$") reduce 104) (("(") reduce 104) (("+") reduce 104) (("-") reduce 104) ((";") reduce 104) (("@") reduce 104) ((T_ABSTRACT) reduce 104) ((T_ARRAY) reduce 104) ((T_ARRAY_CAST) reduce 104) ((T_ATTRIBUTE) reduce 104) ((T_BOOL_CAST) reduce 104) ((T_BREAK) reduce 104) ((T_CLASS) reduce 104) ((T_CLASS_C) reduce 104) ((T_CLONE) reduce 104) ((T_CONSTANT_ENCAPSED_STRING) reduce 104) ((T_CONTINUE) reduce 104) ((T_DEC) reduce 104) ((T_DECLARE) reduce 104) ((T_DIR) reduce 104) ((T_DNUMBER) reduce 104) ((T_DO) reduce 104) ((T_DOUBLE_CAST) reduce 104) ((T_ECHO) reduce 104) ((T_EMPTY) reduce 104) ((T_ENDDECLARE) reduce 104) ((T_ENUM) reduce 104) ((T_EVAL) reduce 104) ((T_EXIT) reduce 104) ((T_FILE) reduce 104) ((T_FINAL) reduce 104) ((T_FN) reduce 104) ((T_FOR) reduce 104) ((T_FOREACH) reduce 104) ((T_FUNCTION) reduce 104) ((T_FUNC_C) reduce 104) ((T_GLOBAL) reduce 104) ((T_GOTO) reduce 104) ((T_HALT_COMPILER) reduce 104) ((T_IF) reduce 104) ((T_INC) reduce 104) ((T_INCLUDE) reduce 104) ((T_INCLUDE_ONCE) reduce 104) ((T_INLINE_HTML) reduce 104) ((T_INTERFACE) reduce 104) ((T_INT_CAST) reduce 104) ((T_ISSET) reduce 104) ((T_LINE) reduce 104) ((T_LIST) reduce 104) ((T_LNUMBER) reduce 104) ((T_MATCH) reduce 104) ((T_METHOD_C) reduce 104) ((T_NAME_FULLY_QUALIFIED) reduce 104) ((T_NAME_QUALIFIED) reduce 104) ((T_NAME_RELATIVE) reduce 104) ((T_NEW) reduce 104) ((T_NS_C) reduce 104) ((T_OBJECT_CAST) reduce 104) ((T_PRINT) reduce 104) ((T_READONLY) reduce 104) ((T_REQUIRE) reduce 104) ((T_REQUIRE_ONCE) reduce 104) ((T_RETURN) reduce 104) ((T_START_HEREDOC) reduce 104) ((T_STATIC) reduce 104) ((T_STRING) reduce 104) ((T_STRING_CAST) reduce 104) ((T_SWITCH) reduce 104) ((T_THROW) reduce 104) ((T_TRAIT) reduce 104) ((T_TRAIT_C) reduce 104) ((T_TRY) reduce 104) ((T_UNSET) reduce 104) ((T_UNSET_CAST) reduce 104) ((T_VARIABLE) reduce 104) ((T_WHILE) reduce 104) ((T_YIELD) reduce 104) ((T_YIELD_FROM) reduce 104) (("[") reduce 104) (("`") reduce 104) (("{") reduce 104) (("~") reduce 104)) 19969 ((("!") reduce 145) (("\"") reduce 145) (("$") reduce 145) (("(") reduce 145) (("+") reduce 145) (("-") reduce 145) ((";") reduce 145) (("@") reduce 145) ((T_ABSTRACT) reduce 145) ((T_ARRAY) reduce 145) ((T_ARRAY_CAST) reduce 145) ((T_ATTRIBUTE) reduce 145) ((T_BOOL_CAST) reduce 145) ((T_BREAK) reduce 145) ((T_CLASS) reduce 145) ((T_CLASS_C) reduce 145) ((T_CLONE) reduce 145) ((T_CONSTANT_ENCAPSED_STRING) reduce 145) ((T_CONTINUE) reduce 145) ((T_DEC) reduce 145) ((T_DECLARE) reduce 145) ((T_DIR) reduce 145) ((T_DNUMBER) reduce 145) ((T_DO) reduce 145) ((T_DOUBLE_CAST) reduce 145) ((T_ECHO) reduce 145) ((T_EMPTY) reduce 145) ((T_ENDDECLARE) reduce 145) ((T_ENUM) reduce 145) ((T_EVAL) reduce 145) ((T_EXIT) reduce 145) ((T_FILE) reduce 145) ((T_FINAL) reduce 145) ((T_FN) reduce 145) ((T_FOR) reduce 145) ((T_FOREACH) reduce 145) ((T_FUNCTION) reduce 145) ((T_FUNC_C) reduce 145) ((T_GLOBAL) reduce 145) ((T_GOTO) reduce 145) ((T_HALT_COMPILER) reduce 145) ((T_IF) reduce 145) ((T_INC) reduce 145) ((T_INCLUDE) reduce 145) ((T_INCLUDE_ONCE) reduce 145) ((T_INLINE_HTML) reduce 145) ((T_INTERFACE) reduce 145) ((T_INT_CAST) reduce 145) ((T_ISSET) reduce 145) ((T_LINE) reduce 145) ((T_LIST) reduce 145) ((T_LNUMBER) reduce 145) ((T_MATCH) reduce 145) ((T_METHOD_C) reduce 145) ((T_NAME_FULLY_QUALIFIED) reduce 145) ((T_NAME_QUALIFIED) reduce 145) ((T_NAME_RELATIVE) reduce 145) ((T_NEW) reduce 145) ((T_NS_C) reduce 145) ((T_OBJECT_CAST) reduce 145) ((T_PRINT) reduce 145) ((T_READONLY) reduce 145) ((T_REQUIRE) reduce 145) ((T_REQUIRE_ONCE) reduce 145) ((T_RETURN) reduce 145) ((T_START_HEREDOC) reduce 145) ((T_STATIC) reduce 145) ((T_STRING) reduce 145) ((T_STRING_CAST) reduce 145) ((T_SWITCH) reduce 145) ((T_THROW) reduce 145) ((T_TRAIT) reduce 145) ((T_TRAIT_C) reduce 145) ((T_TRY) reduce 145) ((T_UNSET) reduce 145) ((T_UNSET_CAST) reduce 145) ((T_VARIABLE) reduce 145) ((T_WHILE) reduce 145) ((T_YIELD) reduce 145) ((T_YIELD_FROM) reduce 145) (("[") reduce 145) (("`") reduce 145) (("{") reduce 145) (("~") reduce 145)) 19975 ((("!") reduce 164) (("\"") reduce 164) (("$") reduce 164) (("(") reduce 164) (("+") reduce 164) (("-") reduce 164) ((";") reduce 164) (("@") reduce 164) ((T_ABSTRACT) reduce 164) ((T_ARRAY) reduce 164) ((T_ARRAY_CAST) reduce 164) ((T_ATTRIBUTE) reduce 164) ((T_BOOL_CAST) reduce 164) ((T_BREAK) reduce 164) ((T_CLASS) reduce 164) ((T_CLASS_C) reduce 164) ((T_CLONE) reduce 164) ((T_CONSTANT_ENCAPSED_STRING) reduce 164) ((T_CONTINUE) reduce 164) ((T_DEC) reduce 164) ((T_DECLARE) reduce 164) ((T_DIR) reduce 164) ((T_DNUMBER) reduce 164) ((T_DO) reduce 164) ((T_DOUBLE_CAST) reduce 164) ((T_ECHO) reduce 164) ((T_ELSE) reduce 164) ((T_ELSEIF) reduce 164) ((T_EMPTY) reduce 164) ((T_ENDDECLARE) reduce 164) ((T_ENUM) reduce 164) ((T_EVAL) reduce 164) ((T_EXIT) reduce 164) ((T_FILE) reduce 164) ((T_FINAL) reduce 164) ((T_FN) reduce 164) ((T_FOR) reduce 164) ((T_FOREACH) reduce 164) ((T_FUNCTION) reduce 164) ((T_FUNC_C) reduce 164) ((T_GLOBAL) reduce 164) ((T_GOTO) reduce 164) ((T_HALT_COMPILER) reduce 164) ((T_IF) reduce 164) ((T_INC) reduce 164) ((T_INCLUDE) reduce 164) ((T_INCLUDE_ONCE) reduce 164) ((T_INLINE_HTML) reduce 164) ((T_INTERFACE) reduce 164) ((T_INT_CAST) reduce 164) ((T_ISSET) reduce 164) ((T_LINE) reduce 164) ((T_LIST) reduce 164) ((T_LNUMBER) reduce 164) ((T_MATCH) reduce 164) ((T_METHOD_C) reduce 164) ((T_NAME_FULLY_QUALIFIED) reduce 164) ((T_NAME_QUALIFIED) reduce 164) ((T_NAME_RELATIVE) reduce 164) ((T_NEW) reduce 164) ((T_NS_C) reduce 164) ((T_OBJECT_CAST) reduce 164) ((T_PRINT) reduce 164) ((T_READONLY) reduce 164) ((T_REQUIRE) reduce 164) ((T_REQUIRE_ONCE) reduce 164) ((T_RETURN) reduce 164) ((T_START_HEREDOC) reduce 164) ((T_STATIC) reduce 164) ((T_STRING) reduce 164) ((T_STRING_CAST) reduce 164) ((T_SWITCH) reduce 164) ((T_THROW) reduce 164) ((T_TRAIT) reduce 164) ((T_TRAIT_C) reduce 164) ((T_TRY) reduce 164) ((T_UNSET) reduce 164) ((T_UNSET_CAST) reduce 164) ((T_VARIABLE) reduce 164) ((T_WHILE) reduce 164) ((T_YIELD) reduce 164) ((T_YIELD_FROM) reduce 164) (("[") reduce 164) (("`") reduce 164) (("{") reduce 164) (("~") reduce 164)) 19985 ((("!") reduce 158) (("\"") reduce 158) (("$") reduce 158) (("(") reduce 158) (("+") reduce 158) (("-") reduce 158) ((";") reduce 158) (("@") reduce 158) ((T_ABSTRACT) reduce 158) ((T_ARRAY) reduce 158) ((T_ARRAY_CAST) reduce 158) ((T_ATTRIBUTE) reduce 158) ((T_BOOL_CAST) reduce 158) ((T_BREAK) reduce 158) ((T_CLASS) reduce 158) ((T_CLASS_C) reduce 158) ((T_CLONE) reduce 158) ((T_CONSTANT_ENCAPSED_STRING) reduce 158) ((T_CONTINUE) reduce 158) ((T_DEC) reduce 158) ((T_DECLARE) reduce 158) ((T_DIR) reduce 158) ((T_DNUMBER) reduce 158) ((T_DO) reduce 158) ((T_DOUBLE_CAST) reduce 158) ((T_ECHO) reduce 158) ((T_ELSE) reduce 158) ((T_ELSEIF) reduce 158) ((T_EMPTY) reduce 158) ((T_ENDDECLARE) reduce 158) ((T_ENUM) reduce 158) ((T_EVAL) reduce 158) ((T_EXIT) reduce 158) ((T_FILE) reduce 158) ((T_FINAL) reduce 158) ((T_FN) reduce 158) ((T_FOR) reduce 158) ((T_FOREACH) reduce 158) ((T_FUNCTION) reduce 158) ((T_FUNC_C) reduce 158) ((T_GLOBAL) reduce 158) ((T_GOTO) reduce 158) ((T_HALT_COMPILER) reduce 158) ((T_IF) reduce 158) ((T_INC) reduce 158) ((T_INCLUDE) reduce 158) ((T_INCLUDE_ONCE) reduce 158) ((T_INLINE_HTML) reduce 158) ((T_INTERFACE) reduce 158) ((T_INT_CAST) reduce 158) ((T_ISSET) reduce 158) ((T_LINE) reduce 158) ((T_LIST) reduce 158) ((T_LNUMBER) reduce 158) ((T_MATCH) reduce 158) ((T_METHOD_C) reduce 158) ((T_NAME_FULLY_QUALIFIED) reduce 158) ((T_NAME_QUALIFIED) reduce 158) ((T_NAME_RELATIVE) reduce 158) ((T_NEW) reduce 158) ((T_NS_C) reduce 158) ((T_OBJECT_CAST) reduce 158) ((T_PRINT) reduce 158) ((T_READONLY) reduce 158) ((T_REQUIRE) reduce 158) ((T_REQUIRE_ONCE) reduce 158) ((T_RETURN) reduce 158) ((T_START_HEREDOC) reduce 158) ((T_STATIC) reduce 158) ((T_STRING) reduce 158) ((T_STRING_CAST) reduce 158) ((T_SWITCH) reduce 158) ((T_THROW) reduce 158) ((T_TRAIT) reduce 158) ((T_TRAIT_C) reduce 158) ((T_TRY) reduce 158) ((T_UNSET) reduce 158) ((T_UNSET_CAST) reduce 158) ((T_VARIABLE) reduce 158) ((T_WHILE) reduce 158) ((T_YIELD) reduce 158) ((T_YIELD_FROM) reduce 158) (("[") reduce 158) (("`") reduce 158) (("{") reduce 158) (("~") reduce 158)) 19993 ((("!") reduce 147) (("\"") reduce 147) (("$") reduce 147) (("(") reduce 147) (("+") reduce 147) (("-") reduce 147) ((";") reduce 147) (("@") reduce 147) ((T_ABSTRACT) reduce 147) ((T_ARRAY) reduce 147) ((T_ARRAY_CAST) reduce 147) ((T_ATTRIBUTE) reduce 147) ((T_BOOL_CAST) reduce 147) ((T_BREAK) reduce 147) ((T_CLASS) reduce 147) ((T_CLASS_C) reduce 147) ((T_CLONE) reduce 147) ((T_CONSTANT_ENCAPSED_STRING) reduce 147) ((T_CONTINUE) reduce 147) ((T_DEC) reduce 147) ((T_DECLARE) reduce 147) ((T_DIR) reduce 147) ((T_DNUMBER) reduce 147) ((T_DO) reduce 147) ((T_DOUBLE_CAST) reduce 147) ((T_ECHO) reduce 147) ((T_ELSE) reduce 147) ((T_ELSEIF) reduce 147) ((T_EMPTY) reduce 147) ((T_ENDDECLARE) reduce 147) ((T_ENUM) reduce 147) ((T_EVAL) reduce 147) ((T_EXIT) reduce 147) ((T_FILE) reduce 147) ((T_FINAL) reduce 147) ((T_FN) reduce 147) ((T_FOR) reduce 147) ((T_FOREACH) reduce 147) ((T_FUNCTION) reduce 147) ((T_FUNC_C) reduce 147) ((T_GLOBAL) reduce 147) ((T_GOTO) reduce 147) ((T_HALT_COMPILER) reduce 147) ((T_IF) reduce 147) ((T_INC) reduce 147) ((T_INCLUDE) reduce 147) ((T_INCLUDE_ONCE) reduce 147) ((T_INLINE_HTML) reduce 147) ((T_INTERFACE) reduce 147) ((T_INT_CAST) reduce 147) ((T_ISSET) reduce 147) ((T_LINE) reduce 147) ((T_LIST) reduce 147) ((T_LNUMBER) reduce 147) ((T_MATCH) reduce 147) ((T_METHOD_C) reduce 147) ((T_NAME_FULLY_QUALIFIED) reduce 147) ((T_NAME_QUALIFIED) reduce 147) ((T_NAME_RELATIVE) reduce 147) ((T_NEW) reduce 147) ((T_NS_C) reduce 147) ((T_OBJECT_CAST) reduce 147) ((T_PRINT) reduce 147) ((T_READONLY) reduce 147) ((T_REQUIRE) reduce 147) ((T_REQUIRE_ONCE) reduce 147) ((T_RETURN) reduce 147) ((T_START_HEREDOC) reduce 147) ((T_STATIC) reduce 147) ((T_STRING) reduce 147) ((T_STRING_CAST) reduce 147) ((T_SWITCH) reduce 147) ((T_THROW) reduce 147) ((T_TRAIT) reduce 147) ((T_TRAIT_C) reduce 147) ((T_TRY) reduce 147) ((T_UNSET) reduce 147) ((T_UNSET_CAST) reduce 147) ((T_VARIABLE) reduce 147) ((T_WHILE) reduce 147) ((T_YIELD) reduce 147) ((T_YIELD_FROM) reduce 147) (("[") reduce 147) (("`") reduce 147) (("{") reduce 147) (("~") reduce 147)) 19996 ((("!") reduce 146) (("\"") reduce 146) (("$") reduce 146) (("(") reduce 146) (("+") reduce 146) (("-") reduce 146) ((";") reduce 146) (("@") reduce 146) ((T_ABSTRACT) reduce 146) ((T_ARRAY) reduce 146) ((T_ARRAY_CAST) reduce 146) ((T_ATTRIBUTE) reduce 146) ((T_BOOL_CAST) reduce 146) ((T_BREAK) reduce 146) ((T_CLASS) reduce 146) ((T_CLASS_C) reduce 146) ((T_CLONE) reduce 146) ((T_CONSTANT_ENCAPSED_STRING) reduce 146) ((T_CONTINUE) reduce 146) ((T_DEC) reduce 146) ((T_DECLARE) reduce 146) ((T_DIR) reduce 146) ((T_DNUMBER) reduce 146) ((T_DO) reduce 146) ((T_DOUBLE_CAST) reduce 146) ((T_ECHO) reduce 146) ((T_ELSE) reduce 146) ((T_ELSEIF) reduce 146) ((T_EMPTY) reduce 146) ((T_ENDDECLARE) reduce 146) ((T_ENUM) reduce 146) ((T_EVAL) reduce 146) ((T_EXIT) reduce 146) ((T_FILE) reduce 146) ((T_FINAL) reduce 146) ((T_FN) reduce 146) ((T_FOR) reduce 146) ((T_FOREACH) reduce 146) ((T_FUNCTION) reduce 146) ((T_FUNC_C) reduce 146) ((T_GLOBAL) reduce 146) ((T_GOTO) reduce 146) ((T_HALT_COMPILER) reduce 146) ((T_IF) reduce 146) ((T_INC) reduce 146) ((T_INCLUDE) reduce 146) ((T_INCLUDE_ONCE) reduce 146) ((T_INLINE_HTML) reduce 146) ((T_INTERFACE) reduce 146) ((T_INT_CAST) reduce 146) ((T_ISSET) reduce 146) ((T_LINE) reduce 146) ((T_LIST) reduce 146) ((T_LNUMBER) reduce 146) ((T_MATCH) reduce 146) ((T_METHOD_C) reduce 146) ((T_NAME_FULLY_QUALIFIED) reduce 146) ((T_NAME_QUALIFIED) reduce 146) ((T_NAME_RELATIVE) reduce 146) ((T_NEW) reduce 146) ((T_NS_C) reduce 146) ((T_OBJECT_CAST) reduce 146) ((T_PRINT) reduce 146) ((T_READONLY) reduce 146) ((T_REQUIRE) reduce 146) ((T_REQUIRE_ONCE) reduce 146) ((T_RETURN) reduce 146) ((T_START_HEREDOC) reduce 146) ((T_STATIC) reduce 146) ((T_STRING) reduce 146) ((T_STRING_CAST) reduce 146) ((T_SWITCH) reduce 146) ((T_THROW) reduce 146) ((T_TRAIT) reduce 146) ((T_TRAIT_C) reduce 146) ((T_TRY) reduce 146) ((T_UNSET) reduce 146) ((T_UNSET_CAST) reduce 146) ((T_VARIABLE) reduce 146) ((T_WHILE) reduce 146) ((T_YIELD) reduce 146) ((T_YIELD_FROM) reduce 146) (("[") reduce 146) (("`") reduce 146) (("{") reduce 146) (("~") reduce 146)) 19998 ((("!") reduce 242) (("\"") reduce 242) (("$") reduce 242) (("(") reduce 242) (("+") reduce 242) (("-") reduce 242) ((";") reduce 242) (("@") reduce 242) ((T_ABSTRACT) reduce 242) ((T_ARRAY) reduce 242) ((T_ARRAY_CAST) reduce 242) ((T_ATTRIBUTE) reduce 242) ((T_BOOL_CAST) reduce 242) ((T_BREAK) reduce 242) ((T_CLASS) reduce 242) ((T_CLASS_C) reduce 242) ((T_CLONE) reduce 242) ((T_CONSTANT_ENCAPSED_STRING) reduce 242) ((T_CONTINUE) reduce 242) ((T_DEC) reduce 242) ((T_DECLARE) reduce 242) ((T_DIR) reduce 242) ((T_DNUMBER) reduce 242) ((T_DO) reduce 242) ((T_DOUBLE_CAST) reduce 242) ((T_ECHO) reduce 242) ((T_ELSE) reduce 242) ((T_ELSEIF) reduce 242) ((T_EMPTY) reduce 242) ((T_ENDDECLARE) reduce 242) ((T_ENUM) reduce 242) ((T_EVAL) reduce 242) ((T_EXIT) reduce 242) ((T_FILE) reduce 242) ((T_FINAL) reduce 242) ((T_FN) reduce 242) ((T_FOR) reduce 242) ((T_FOREACH) reduce 242) ((T_FUNCTION) reduce 242) ((T_FUNC_C) reduce 242) ((T_GLOBAL) reduce 242) ((T_GOTO) reduce 242) ((T_HALT_COMPILER) reduce 242) ((T_IF) reduce 242) ((T_INC) reduce 242) ((T_INCLUDE) reduce 242) ((T_INCLUDE_ONCE) reduce 242) ((T_INLINE_HTML) reduce 242) ((T_INTERFACE) reduce 242) ((T_INT_CAST) reduce 242) ((T_ISSET) reduce 242) ((T_LINE) reduce 242) ((T_LIST) reduce 242) ((T_LNUMBER) reduce 242) ((T_MATCH) reduce 242) ((T_METHOD_C) reduce 242) ((T_NAME_FULLY_QUALIFIED) reduce 242) ((T_NAME_QUALIFIED) reduce 242) ((T_NAME_RELATIVE) reduce 242) ((T_NEW) reduce 242) ((T_NS_C) reduce 242) ((T_OBJECT_CAST) reduce 242) ((T_PRINT) reduce 242) ((T_READONLY) reduce 242) ((T_REQUIRE) reduce 242) ((T_REQUIRE_ONCE) reduce 242) ((T_RETURN) reduce 242) ((T_START_HEREDOC) reduce 242) ((T_STATIC) reduce 242) ((T_STRING) reduce 242) ((T_STRING_CAST) reduce 242) ((T_SWITCH) reduce 242) ((T_THROW) reduce 242) ((T_TRAIT) reduce 242) ((T_TRAIT_C) reduce 242) ((T_TRY) reduce 242) ((T_UNSET) reduce 242) ((T_UNSET_CAST) reduce 242) ((T_VARIABLE) reduce 242) ((T_WHILE) reduce 242) ((T_YIELD) reduce 242) ((T_YIELD_FROM) reduce 242) (("[") reduce 242) (("`") reduce 242) (("{") reduce 242) (("~") reduce 242)) 20001 ((("!") reduce 145) (("\"") reduce 145) (("$") reduce 145) (("(") reduce 145) (("+") reduce 145) (("-") reduce 145) ((";") reduce 145) (("@") reduce 145) ((T_ABSTRACT) reduce 145) ((T_ARRAY) reduce 145) ((T_ARRAY_CAST) reduce 145) ((T_ATTRIBUTE) reduce 145) ((T_BOOL_CAST) reduce 145) ((T_BREAK) reduce 145) ((T_CLASS) reduce 145) ((T_CLASS_C) reduce 145) ((T_CLONE) reduce 145) ((T_CONSTANT_ENCAPSED_STRING) reduce 145) ((T_CONTINUE) reduce 145) ((T_DEC) reduce 145) ((T_DECLARE) reduce 145) ((T_DIR) reduce 145) ((T_DNUMBER) reduce 145) ((T_DO) reduce 145) ((T_DOUBLE_CAST) reduce 145) ((T_ECHO) reduce 145) ((T_ELSE) reduce 145) ((T_ELSEIF) reduce 145) ((T_EMPTY) reduce 145) ((T_ENDDECLARE) reduce 145) ((T_ENUM) reduce 145) ((T_EVAL) reduce 145) ((T_EXIT) reduce 145) ((T_FILE) reduce 145) ((T_FINAL) reduce 145) ((T_FN) reduce 145) ((T_FOR) reduce 145) ((T_FOREACH) reduce 145) ((T_FUNCTION) reduce 145) ((T_FUNC_C) reduce 145) ((T_GLOBAL) reduce 145) ((T_GOTO) reduce 145) ((T_HALT_COMPILER) reduce 145) ((T_IF) reduce 145) ((T_INC) reduce 145) ((T_INCLUDE) reduce 145) ((T_INCLUDE_ONCE) reduce 145) ((T_INLINE_HTML) reduce 145) ((T_INTERFACE) reduce 145) ((T_INT_CAST) reduce 145) ((T_ISSET) reduce 145) ((T_LINE) reduce 145) ((T_LIST) reduce 145) ((T_LNUMBER) reduce 145) ((T_MATCH) reduce 145) ((T_METHOD_C) reduce 145) ((T_NAME_FULLY_QUALIFIED) reduce 145) ((T_NAME_QUALIFIED) reduce 145) ((T_NAME_RELATIVE) reduce 145) ((T_NEW) reduce 145) ((T_NS_C) reduce 145) ((T_OBJECT_CAST) reduce 145) ((T_PRINT) reduce 145) ((T_READONLY) reduce 145) ((T_REQUIRE) reduce 145) ((T_REQUIRE_ONCE) reduce 145) ((T_RETURN) reduce 145) ((T_START_HEREDOC) reduce 145) ((T_STATIC) reduce 145) ((T_STRING) reduce 145) ((T_STRING_CAST) reduce 145) ((T_SWITCH) reduce 145) ((T_THROW) reduce 145) ((T_TRAIT) reduce 145) ((T_TRAIT_C) reduce 145) ((T_TRY) reduce 145) ((T_UNSET) reduce 145) ((T_UNSET_CAST) reduce 145) ((T_VARIABLE) reduce 145) ((T_WHILE) reduce 145) ((T_YIELD) reduce 145) ((T_YIELD_FROM) reduce 145) (("[") reduce 145) (("`") reduce 145) (("{") reduce 145) (("~") reduce 145)) 20003 ((("!") reduce 244) (("\"") reduce 244) (("$") reduce 244) (("(") reduce 244) (("+") reduce 244) (("-") reduce 244) ((";") reduce 244) (("@") reduce 244) ((T_ABSTRACT) reduce 244) ((T_ARRAY) reduce 244) ((T_ARRAY_CAST) reduce 244) ((T_ATTRIBUTE) reduce 244) ((T_BOOL_CAST) reduce 244) ((T_BREAK) reduce 244) ((T_CLASS) reduce 244) ((T_CLASS_C) reduce 244) ((T_CLONE) reduce 244) ((T_CONSTANT_ENCAPSED_STRING) reduce 244) ((T_CONTINUE) reduce 244) ((T_DEC) reduce 244) ((T_DECLARE) reduce 244) ((T_DIR) reduce 244) ((T_DNUMBER) reduce 244) ((T_DO) reduce 244) ((T_DOUBLE_CAST) reduce 244) ((T_ECHO) reduce 244) ((T_ELSE) reduce 244) ((T_ELSEIF) reduce 244) ((T_EMPTY) reduce 244) ((T_ENDDECLARE) reduce 244) ((T_ENUM) reduce 244) ((T_EVAL) reduce 244) ((T_EXIT) reduce 244) ((T_FILE) reduce 244) ((T_FINAL) reduce 244) ((T_FN) reduce 244) ((T_FOR) reduce 244) ((T_FOREACH) reduce 244) ((T_FUNCTION) reduce 244) ((T_FUNC_C) reduce 244) ((T_GLOBAL) reduce 244) ((T_GOTO) reduce 244) ((T_HALT_COMPILER) reduce 244) ((T_IF) reduce 244) ((T_INC) reduce 244) ((T_INCLUDE) reduce 244) ((T_INCLUDE_ONCE) reduce 244) ((T_INLINE_HTML) reduce 244) ((T_INTERFACE) reduce 244) ((T_INT_CAST) reduce 244) ((T_ISSET) reduce 244) ((T_LINE) reduce 244) ((T_LIST) reduce 244) ((T_LNUMBER) reduce 244) ((T_MATCH) reduce 244) ((T_METHOD_C) reduce 244) ((T_NAME_FULLY_QUALIFIED) reduce 244) ((T_NAME_QUALIFIED) reduce 244) ((T_NAME_RELATIVE) reduce 244) ((T_NEW) reduce 244) ((T_NS_C) reduce 244) ((T_OBJECT_CAST) reduce 244) ((T_PRINT) reduce 244) ((T_READONLY) reduce 244) ((T_REQUIRE) reduce 244) ((T_REQUIRE_ONCE) reduce 244) ((T_RETURN) reduce 244) ((T_START_HEREDOC) reduce 244) ((T_STATIC) reduce 244) ((T_STRING) reduce 244) ((T_STRING_CAST) reduce 244) ((T_SWITCH) reduce 244) ((T_THROW) reduce 244) ((T_TRAIT) reduce 244) ((T_TRAIT_C) reduce 244) ((T_TRY) reduce 244) ((T_UNSET) reduce 244) ((T_UNSET_CAST) reduce 244) ((T_VARIABLE) reduce 244) ((T_WHILE) reduce 244) ((T_YIELD) reduce 244) ((T_YIELD_FROM) reduce 244) (("[") reduce 244) (("`") reduce 244) (("{") reduce 244) (("~") reduce 244)) 20004 ((("!") reduce 159) (("\"") reduce 159) (("$") reduce 159) (("(") reduce 159) (("+") reduce 159) (("-") reduce 159) ((";") reduce 159) (("@") reduce 159) ((T_ABSTRACT) reduce 159) ((T_ARRAY) reduce 159) ((T_ARRAY_CAST) reduce 159) ((T_ATTRIBUTE) reduce 159) ((T_BOOL_CAST) reduce 159) ((T_BREAK) reduce 159) ((T_CLASS) reduce 159) ((T_CLASS_C) reduce 159) ((T_CLONE) reduce 159) ((T_CONSTANT_ENCAPSED_STRING) reduce 159) ((T_CONTINUE) reduce 159) ((T_DEC) reduce 159) ((T_DECLARE) reduce 159) ((T_DIR) reduce 159) ((T_DNUMBER) reduce 159) ((T_DO) reduce 159) ((T_DOUBLE_CAST) reduce 159) ((T_ECHO) reduce 159) ((T_ELSE) reduce 159) ((T_ELSEIF) reduce 159) ((T_EMPTY) reduce 159) ((T_ENDDECLARE) reduce 159) ((T_ENUM) reduce 159) ((T_EVAL) reduce 159) ((T_EXIT) reduce 159) ((T_FILE) reduce 159) ((T_FINAL) reduce 159) ((T_FN) reduce 159) ((T_FOR) reduce 159) ((T_FOREACH) reduce 159) ((T_FUNCTION) reduce 159) ((T_FUNC_C) reduce 159) ((T_GLOBAL) reduce 159) ((T_GOTO) reduce 159) ((T_HALT_COMPILER) reduce 159) ((T_IF) reduce 159) ((T_INC) reduce 159) ((T_INCLUDE) reduce 159) ((T_INCLUDE_ONCE) reduce 159) ((T_INLINE_HTML) reduce 159) ((T_INTERFACE) reduce 159) ((T_INT_CAST) reduce 159) ((T_ISSET) reduce 159) ((T_LINE) reduce 159) ((T_LIST) reduce 159) ((T_LNUMBER) reduce 159) ((T_MATCH) reduce 159) ((T_METHOD_C) reduce 159) ((T_NAME_FULLY_QUALIFIED) reduce 159) ((T_NAME_QUALIFIED) reduce 159) ((T_NAME_RELATIVE) reduce 159) ((T_NEW) reduce 159) ((T_NS_C) reduce 159) ((T_OBJECT_CAST) reduce 159) ((T_PRINT) reduce 159) ((T_READONLY) reduce 159) ((T_REQUIRE) reduce 159) ((T_REQUIRE_ONCE) reduce 159) ((T_RETURN) reduce 159) ((T_START_HEREDOC) reduce 159) ((T_STATIC) reduce 159) ((T_STRING) reduce 159) ((T_STRING_CAST) reduce 159) ((T_SWITCH) reduce 159) ((T_THROW) reduce 159) ((T_TRAIT) reduce 159) ((T_TRAIT_C) reduce 159) ((T_TRY) reduce 159) ((T_UNSET) reduce 159) ((T_UNSET_CAST) reduce 159) ((T_VARIABLE) reduce 159) ((T_WHILE) reduce 159) ((T_YIELD) reduce 159) ((T_YIELD_FROM) reduce 159) (("[") reduce 159) (("`") reduce 159) (("{") reduce 159) (("~") reduce 159)) 20007 ((("!") reduce 247) (("\"") reduce 247) (("$") reduce 247) (("(") reduce 247) (("+") reduce 247) (("-") reduce 247) ((";") reduce 247) (("@") reduce 247) ((T_ABSTRACT) reduce 247) ((T_ARRAY) reduce 247) ((T_ARRAY_CAST) reduce 247) ((T_ATTRIBUTE) reduce 247) ((T_BOOL_CAST) reduce 247) ((T_BREAK) reduce 247) ((T_CLASS) reduce 247) ((T_CLASS_C) reduce 247) ((T_CLONE) reduce 247) ((T_CONSTANT_ENCAPSED_STRING) reduce 247) ((T_CONTINUE) reduce 247) ((T_DEC) reduce 247) ((T_DECLARE) reduce 247) ((T_DIR) reduce 247) ((T_DNUMBER) reduce 247) ((T_DO) reduce 247) ((T_DOUBLE_CAST) reduce 247) ((T_ECHO) reduce 247) ((T_ELSE) reduce 247) ((T_ELSEIF) reduce 247) ((T_EMPTY) reduce 247) ((T_ENDDECLARE) reduce 247) ((T_ENUM) reduce 247) ((T_EVAL) reduce 247) ((T_EXIT) reduce 247) ((T_FILE) reduce 247) ((T_FINAL) reduce 247) ((T_FN) reduce 247) ((T_FOR) reduce 247) ((T_FOREACH) reduce 247) ((T_FUNCTION) reduce 247) ((T_FUNC_C) reduce 247) ((T_GLOBAL) reduce 247) ((T_GOTO) reduce 247) ((T_HALT_COMPILER) reduce 247) ((T_IF) reduce 247) ((T_INC) reduce 247) ((T_INCLUDE) reduce 247) ((T_INCLUDE_ONCE) reduce 247) ((T_INLINE_HTML) reduce 247) ((T_INTERFACE) reduce 247) ((T_INT_CAST) reduce 247) ((T_ISSET) reduce 247) ((T_LINE) reduce 247) ((T_LIST) reduce 247) ((T_LNUMBER) reduce 247) ((T_MATCH) reduce 247) ((T_METHOD_C) reduce 247) ((T_NAME_FULLY_QUALIFIED) reduce 247) ((T_NAME_QUALIFIED) reduce 247) ((T_NAME_RELATIVE) reduce 247) ((T_NEW) reduce 247) ((T_NS_C) reduce 247) ((T_OBJECT_CAST) reduce 247) ((T_PRINT) reduce 247) ((T_READONLY) reduce 247) ((T_REQUIRE) reduce 247) ((T_REQUIRE_ONCE) reduce 247) ((T_RETURN) reduce 247) ((T_START_HEREDOC) reduce 247) ((T_STATIC) reduce 247) ((T_STRING) reduce 247) ((T_STRING_CAST) reduce 247) ((T_SWITCH) reduce 247) ((T_THROW) reduce 247) ((T_TRAIT) reduce 247) ((T_TRAIT_C) reduce 247) ((T_TRY) reduce 247) ((T_UNSET) reduce 247) ((T_UNSET_CAST) reduce 247) ((T_VARIABLE) reduce 247) ((T_WHILE) reduce 247) ((T_YIELD) reduce 247) ((T_YIELD_FROM) reduce 247) (("[") reduce 247) (("`") reduce 247) (("{") reduce 247) (("~") reduce 247)) 20011 ((("!") reduce 248) (("\"") reduce 248) (("$") reduce 248) (("(") reduce 248) (("+") reduce 248) (("-") reduce 248) ((";") reduce 248) (("@") reduce 248) ((T_ABSTRACT) reduce 248) ((T_ARRAY) reduce 248) ((T_ARRAY_CAST) reduce 248) ((T_ATTRIBUTE) reduce 248) ((T_BOOL_CAST) reduce 248) ((T_BREAK) reduce 248) ((T_CLASS) reduce 248) ((T_CLASS_C) reduce 248) ((T_CLONE) reduce 248) ((T_CONSTANT_ENCAPSED_STRING) reduce 248) ((T_CONTINUE) reduce 248) ((T_DEC) reduce 248) ((T_DECLARE) reduce 248) ((T_DIR) reduce 248) ((T_DNUMBER) reduce 248) ((T_DO) reduce 248) ((T_DOUBLE_CAST) reduce 248) ((T_ECHO) reduce 248) ((T_ELSE) reduce 248) ((T_ELSEIF) reduce 248) ((T_EMPTY) reduce 248) ((T_ENDDECLARE) reduce 248) ((T_ENUM) reduce 248) ((T_EVAL) reduce 248) ((T_EXIT) reduce 248) ((T_FILE) reduce 248) ((T_FINAL) reduce 248) ((T_FN) reduce 248) ((T_FOR) reduce 248) ((T_FOREACH) reduce 248) ((T_FUNCTION) reduce 248) ((T_FUNC_C) reduce 248) ((T_GLOBAL) reduce 248) ((T_GOTO) reduce 248) ((T_HALT_COMPILER) reduce 248) ((T_IF) reduce 248) ((T_INC) reduce 248) ((T_INCLUDE) reduce 248) ((T_INCLUDE_ONCE) reduce 248) ((T_INLINE_HTML) reduce 248) ((T_INTERFACE) reduce 248) ((T_INT_CAST) reduce 248) ((T_ISSET) reduce 248) ((T_LINE) reduce 248) ((T_LIST) reduce 248) ((T_LNUMBER) reduce 248) ((T_MATCH) reduce 248) ((T_METHOD_C) reduce 248) ((T_NAME_FULLY_QUALIFIED) reduce 248) ((T_NAME_QUALIFIED) reduce 248) ((T_NAME_RELATIVE) reduce 248) ((T_NEW) reduce 248) ((T_NS_C) reduce 248) ((T_OBJECT_CAST) reduce 248) ((T_PRINT) reduce 248) ((T_READONLY) reduce 248) ((T_REQUIRE) reduce 248) ((T_REQUIRE_ONCE) reduce 248) ((T_RETURN) reduce 248) ((T_START_HEREDOC) reduce 248) ((T_STATIC) reduce 248) ((T_STRING) reduce 248) ((T_STRING_CAST) reduce 248) ((T_SWITCH) reduce 248) ((T_THROW) reduce 248) ((T_TRAIT) reduce 248) ((T_TRAIT_C) reduce 248) ((T_TRY) reduce 248) ((T_UNSET) reduce 248) ((T_UNSET_CAST) reduce 248) ((T_VARIABLE) reduce 248) ((T_WHILE) reduce 248) ((T_YIELD) reduce 248) ((T_YIELD_FROM) reduce 248) (("[") reduce 248) (("`") reduce 248) (("{") reduce 248) (("~") reduce 248)) 20016 ((("!") reduce 239) (("\"") reduce 239) (("$") reduce 239) (("(") reduce 239) (("+") reduce 239) (("-") reduce 239) ((";") reduce 239) (("@") reduce 239) ((T_ABSTRACT) reduce 239) ((T_ARRAY) reduce 239) ((T_ARRAY_CAST) reduce 239) ((T_ATTRIBUTE) reduce 239) ((T_BOOL_CAST) reduce 239) ((T_BREAK) reduce 239) ((T_CLASS) reduce 239) ((T_CLASS_C) reduce 239) ((T_CLONE) reduce 239) ((T_CONSTANT_ENCAPSED_STRING) reduce 239) ((T_CONTINUE) reduce 239) ((T_DEC) reduce 239) ((T_DECLARE) reduce 239) ((T_DIR) reduce 239) ((T_DNUMBER) reduce 239) ((T_DO) reduce 239) ((T_DOUBLE_CAST) reduce 239) ((T_ECHO) reduce 239) ((T_ELSE) reduce 239) ((T_ELSEIF) reduce 239) ((T_EMPTY) reduce 239) ((T_ENDDECLARE) reduce 239) ((T_ENUM) reduce 239) ((T_EVAL) reduce 239) ((T_EXIT) reduce 239) ((T_FILE) reduce 239) ((T_FINAL) reduce 239) ((T_FN) reduce 239) ((T_FOR) reduce 239) ((T_FOREACH) reduce 239) ((T_FUNCTION) reduce 239) ((T_FUNC_C) reduce 239) ((T_GLOBAL) reduce 239) ((T_GOTO) reduce 239) ((T_HALT_COMPILER) reduce 239) ((T_IF) reduce 239) ((T_INC) reduce 239) ((T_INCLUDE) reduce 239) ((T_INCLUDE_ONCE) reduce 239) ((T_INLINE_HTML) reduce 239) ((T_INTERFACE) reduce 239) ((T_INT_CAST) reduce 239) ((T_ISSET) reduce 239) ((T_LINE) reduce 239) ((T_LIST) reduce 239) ((T_LNUMBER) reduce 239) ((T_MATCH) reduce 239) ((T_METHOD_C) reduce 239) ((T_NAME_FULLY_QUALIFIED) reduce 239) ((T_NAME_QUALIFIED) reduce 239) ((T_NAME_RELATIVE) reduce 239) ((T_NEW) reduce 239) ((T_NS_C) reduce 239) ((T_OBJECT_CAST) reduce 239) ((T_PRINT) reduce 239) ((T_READONLY) reduce 239) ((T_REQUIRE) reduce 239) ((T_REQUIRE_ONCE) reduce 239) ((T_RETURN) reduce 239) ((T_START_HEREDOC) reduce 239) ((T_STATIC) reduce 239) ((T_STRING) reduce 239) ((T_STRING_CAST) reduce 239) ((T_SWITCH) reduce 239) ((T_THROW) reduce 239) ((T_TRAIT) reduce 239) ((T_TRAIT_C) reduce 239) ((T_TRY) reduce 239) ((T_UNSET) reduce 239) ((T_UNSET_CAST) reduce 239) ((T_VARIABLE) reduce 239) ((T_WHILE) reduce 239) ((T_YIELD) reduce 239) ((T_YIELD_FROM) reduce 239) (("[") reduce 239) (("`") reduce 239) (("{") reduce 239) (("~") reduce 239)) 20017 ((("!") reduce 148) (("\"") reduce 148) (("$") reduce 148) (("(") reduce 148) (("+") reduce 148) (("-") reduce 148) ((";") reduce 148) (("@") reduce 148) ((T_ABSTRACT) reduce 148) ((T_ARRAY) reduce 148) ((T_ARRAY_CAST) reduce 148) ((T_ATTRIBUTE) reduce 148) ((T_BOOL_CAST) reduce 148) ((T_BREAK) reduce 148) ((T_CLASS) reduce 148) ((T_CLASS_C) reduce 148) ((T_CLONE) reduce 148) ((T_CONSTANT_ENCAPSED_STRING) reduce 148) ((T_CONTINUE) reduce 148) ((T_DEC) reduce 148) ((T_DECLARE) reduce 148) ((T_DIR) reduce 148) ((T_DNUMBER) reduce 148) ((T_DO) reduce 148) ((T_DOUBLE_CAST) reduce 148) ((T_ECHO) reduce 148) ((T_ELSE) reduce 148) ((T_ELSEIF) reduce 148) ((T_EMPTY) reduce 148) ((T_ENDDECLARE) reduce 148) ((T_ENUM) reduce 148) ((T_EVAL) reduce 148) ((T_EXIT) reduce 148) ((T_FILE) reduce 148) ((T_FINAL) reduce 148) ((T_FN) reduce 148) ((T_FOR) reduce 148) ((T_FOREACH) reduce 148) ((T_FUNCTION) reduce 148) ((T_FUNC_C) reduce 148) ((T_GLOBAL) reduce 148) ((T_GOTO) reduce 148) ((T_HALT_COMPILER) reduce 148) ((T_IF) reduce 148) ((T_INC) reduce 148) ((T_INCLUDE) reduce 148) ((T_INCLUDE_ONCE) reduce 148) ((T_INLINE_HTML) reduce 148) ((T_INTERFACE) reduce 148) ((T_INT_CAST) reduce 148) ((T_ISSET) reduce 148) ((T_LINE) reduce 148) ((T_LIST) reduce 148) ((T_LNUMBER) reduce 148) ((T_MATCH) reduce 148) ((T_METHOD_C) reduce 148) ((T_NAME_FULLY_QUALIFIED) reduce 148) ((T_NAME_QUALIFIED) reduce 148) ((T_NAME_RELATIVE) reduce 148) ((T_NEW) reduce 148) ((T_NS_C) reduce 148) ((T_OBJECT_CAST) reduce 148) ((T_PRINT) reduce 148) ((T_READONLY) reduce 148) ((T_REQUIRE) reduce 148) ((T_REQUIRE_ONCE) reduce 148) ((T_RETURN) reduce 148) ((T_START_HEREDOC) reduce 148) ((T_STATIC) reduce 148) ((T_STRING) reduce 148) ((T_STRING_CAST) reduce 148) ((T_SWITCH) reduce 148) ((T_THROW) reduce 148) ((T_TRAIT) reduce 148) ((T_TRAIT_C) reduce 148) ((T_TRY) reduce 148) ((T_UNSET) reduce 148) ((T_UNSET_CAST) reduce 148) ((T_VARIABLE) reduce 148) ((T_WHILE) reduce 148) ((T_YIELD) reduce 148) ((T_YIELD_FROM) reduce 148) (("[") reduce 148) (("`") reduce 148) (("{") reduce 148) (("~") reduce 148)) 20020 ((("!") reduce 240) (("\"") reduce 240) (("$") reduce 240) (("(") reduce 240) (("+") reduce 240) (("-") reduce 240) ((";") reduce 240) (("@") reduce 240) ((T_ABSTRACT) reduce 240) ((T_ARRAY) reduce 240) ((T_ARRAY_CAST) reduce 240) ((T_ATTRIBUTE) reduce 240) ((T_BOOL_CAST) reduce 240) ((T_BREAK) reduce 240) ((T_CLASS) reduce 240) ((T_CLASS_C) reduce 240) ((T_CLONE) reduce 240) ((T_CONSTANT_ENCAPSED_STRING) reduce 240) ((T_CONTINUE) reduce 240) ((T_DEC) reduce 240) ((T_DECLARE) reduce 240) ((T_DIR) reduce 240) ((T_DNUMBER) reduce 240) ((T_DO) reduce 240) ((T_DOUBLE_CAST) reduce 240) ((T_ECHO) reduce 240) ((T_ELSE) reduce 240) ((T_ELSEIF) reduce 240) ((T_EMPTY) reduce 240) ((T_ENDDECLARE) reduce 240) ((T_ENUM) reduce 240) ((T_EVAL) reduce 240) ((T_EXIT) reduce 240) ((T_FILE) reduce 240) ((T_FINAL) reduce 240) ((T_FN) reduce 240) ((T_FOR) reduce 240) ((T_FOREACH) reduce 240) ((T_FUNCTION) reduce 240) ((T_FUNC_C) reduce 240) ((T_GLOBAL) reduce 240) ((T_GOTO) reduce 240) ((T_HALT_COMPILER) reduce 240) ((T_IF) reduce 240) ((T_INC) reduce 240) ((T_INCLUDE) reduce 240) ((T_INCLUDE_ONCE) reduce 240) ((T_INLINE_HTML) reduce 240) ((T_INTERFACE) reduce 240) ((T_INT_CAST) reduce 240) ((T_ISSET) reduce 240) ((T_LINE) reduce 240) ((T_LIST) reduce 240) ((T_LNUMBER) reduce 240) ((T_MATCH) reduce 240) ((T_METHOD_C) reduce 240) ((T_NAME_FULLY_QUALIFIED) reduce 240) ((T_NAME_QUALIFIED) reduce 240) ((T_NAME_RELATIVE) reduce 240) ((T_NEW) reduce 240) ((T_NS_C) reduce 240) ((T_OBJECT_CAST) reduce 240) ((T_PRINT) reduce 240) ((T_READONLY) reduce 240) ((T_REQUIRE) reduce 240) ((T_REQUIRE_ONCE) reduce 240) ((T_RETURN) reduce 240) ((T_START_HEREDOC) reduce 240) ((T_STATIC) reduce 240) ((T_STRING) reduce 240) ((T_STRING_CAST) reduce 240) ((T_SWITCH) reduce 240) ((T_THROW) reduce 240) ((T_TRAIT) reduce 240) ((T_TRAIT_C) reduce 240) ((T_TRY) reduce 240) ((T_UNSET) reduce 240) ((T_UNSET_CAST) reduce 240) ((T_VARIABLE) reduce 240) ((T_WHILE) reduce 240) ((T_YIELD) reduce 240) ((T_YIELD_FROM) reduce 240) (("[") reduce 240) (("`") reduce 240) (("{") reduce 240) (("~") reduce 240)) 20025 ((("!") reduce 160) (("\"") reduce 160) (("$") reduce 160) (("(") reduce 160) (("+") reduce 160) (("-") reduce 160) ((";") reduce 160) (("@") reduce 160) ((T_ABSTRACT) reduce 160) ((T_ARRAY) reduce 160) ((T_ARRAY_CAST) reduce 160) ((T_ATTRIBUTE) reduce 160) ((T_BOOL_CAST) reduce 160) ((T_BREAK) reduce 160) ((T_CLASS) reduce 160) ((T_CLASS_C) reduce 160) ((T_CLONE) reduce 160) ((T_CONSTANT_ENCAPSED_STRING) reduce 160) ((T_CONTINUE) reduce 160) ((T_DEC) reduce 160) ((T_DECLARE) reduce 160) ((T_DIR) reduce 160) ((T_DNUMBER) reduce 160) ((T_DO) reduce 160) ((T_DOUBLE_CAST) reduce 160) ((T_ECHO) reduce 160) ((T_ELSE) reduce 160) ((T_ELSEIF) reduce 160) ((T_EMPTY) reduce 160) ((T_ENDDECLARE) reduce 160) ((T_ENUM) reduce 160) ((T_EVAL) reduce 160) ((T_EXIT) reduce 160) ((T_FILE) reduce 160) ((T_FINAL) reduce 160) ((T_FN) reduce 160) ((T_FOR) reduce 160) ((T_FOREACH) reduce 160) ((T_FUNCTION) reduce 160) ((T_FUNC_C) reduce 160) ((T_GLOBAL) reduce 160) ((T_GOTO) reduce 160) ((T_HALT_COMPILER) reduce 160) ((T_IF) reduce 160) ((T_INC) reduce 160) ((T_INCLUDE) reduce 160) ((T_INCLUDE_ONCE) reduce 160) ((T_INLINE_HTML) reduce 160) ((T_INTERFACE) reduce 160) ((T_INT_CAST) reduce 160) ((T_ISSET) reduce 160) ((T_LINE) reduce 160) ((T_LIST) reduce 160) ((T_LNUMBER) reduce 160) ((T_MATCH) reduce 160) ((T_METHOD_C) reduce 160) ((T_NAME_FULLY_QUALIFIED) reduce 160) ((T_NAME_QUALIFIED) reduce 160) ((T_NAME_RELATIVE) reduce 160) ((T_NEW) reduce 160) ((T_NS_C) reduce 160) ((T_OBJECT_CAST) reduce 160) ((T_PRINT) reduce 160) ((T_READONLY) reduce 160) ((T_REQUIRE) reduce 160) ((T_REQUIRE_ONCE) reduce 160) ((T_RETURN) reduce 160) ((T_START_HEREDOC) reduce 160) ((T_STATIC) reduce 160) ((T_STRING) reduce 160) ((T_STRING_CAST) reduce 160) ((T_SWITCH) reduce 160) ((T_THROW) reduce 160) ((T_TRAIT) reduce 160) ((T_TRAIT_C) reduce 160) ((T_TRY) reduce 160) ((T_UNSET) reduce 160) ((T_UNSET_CAST) reduce 160) ((T_VARIABLE) reduce 160) ((T_WHILE) reduce 160) ((T_YIELD) reduce 160) ((T_YIELD_FROM) reduce 160) (("[") reduce 160) (("`") reduce 160) (("{") reduce 160) (("~") reduce 160)) 20028 ((("!") reduce 168) (("\"") reduce 168) (("$") reduce 168) (("(") reduce 168) (("+") reduce 168) (("-") reduce 168) ((";") reduce 168) (("@") reduce 168) ((T_ABSTRACT) reduce 168) ((T_ARRAY) reduce 168) ((T_ARRAY_CAST) reduce 168) ((T_ATTRIBUTE) reduce 168) ((T_BOOL_CAST) reduce 168) ((T_BREAK) reduce 168) ((T_CATCH) reduce 168) ((T_CLASS) reduce 168) ((T_CLASS_C) reduce 168) ((T_CLONE) reduce 168) ((T_CONSTANT_ENCAPSED_STRING) reduce 168) ((T_CONTINUE) reduce 168) ((T_DEC) reduce 168) ((T_DECLARE) reduce 168) ((T_DIR) reduce 168) ((T_DNUMBER) reduce 168) ((T_DO) reduce 168) ((T_DOUBLE_CAST) reduce 168) ((T_ECHO) reduce 168) ((T_ELSE) reduce 168) ((T_ELSEIF) reduce 168) ((T_EMPTY) reduce 168) ((T_ENDDECLARE) reduce 168) ((T_ENUM) reduce 168) ((T_EVAL) reduce 168) ((T_EXIT) reduce 168) ((T_FILE) reduce 168) ((T_FINAL) reduce 168) ((T_FINALLY) reduce 168) ((T_FN) reduce 168) ((T_FOR) reduce 168) ((T_FOREACH) reduce 168) ((T_FUNCTION) reduce 168) ((T_FUNC_C) reduce 168) ((T_GLOBAL) reduce 168) ((T_GOTO) reduce 168) ((T_HALT_COMPILER) reduce 168) ((T_IF) reduce 168) ((T_INC) reduce 168) ((T_INCLUDE) reduce 168) ((T_INCLUDE_ONCE) reduce 168) ((T_INLINE_HTML) reduce 168) ((T_INTERFACE) reduce 168) ((T_INT_CAST) reduce 168) ((T_ISSET) reduce 168) ((T_LINE) reduce 168) ((T_LIST) reduce 168) ((T_LNUMBER) reduce 168) ((T_MATCH) reduce 168) ((T_METHOD_C) reduce 168) ((T_NAME_FULLY_QUALIFIED) reduce 168) ((T_NAME_QUALIFIED) reduce 168) ((T_NAME_RELATIVE) reduce 168) ((T_NEW) reduce 168) ((T_NS_C) reduce 168) ((T_OBJECT_CAST) reduce 168) ((T_PRINT) reduce 168) ((T_READONLY) reduce 168) ((T_REQUIRE) reduce 168) ((T_REQUIRE_ONCE) reduce 168) ((T_RETURN) reduce 168) ((T_START_HEREDOC) reduce 168) ((T_STATIC) reduce 168) ((T_STRING) reduce 168) ((T_STRING_CAST) reduce 168) ((T_SWITCH) reduce 168) ((T_THROW) reduce 168) ((T_TRAIT) reduce 168) ((T_TRAIT_C) reduce 168) ((T_TRY) reduce 168) ((T_UNSET) reduce 168) ((T_UNSET_CAST) reduce 168) ((T_VARIABLE) reduce 168) ((T_WHILE) reduce 168) ((T_YIELD) reduce 168) ((T_YIELD_FROM) reduce 168) (("[") reduce 168) (("`") reduce 168) (("{") reduce 168) (("~") reduce 168)) 20029 ((("!") reduce 174) (("\"") reduce 174) (("$") reduce 174) (("(") reduce 174) (("+") reduce 174) (("-") reduce 174) ((";") reduce 174) (("@") reduce 174) ((T_ABSTRACT) reduce 174) ((T_ARRAY) reduce 174) ((T_ARRAY_CAST) reduce 174) ((T_ATTRIBUTE) reduce 174) ((T_BOOL_CAST) reduce 174) ((T_BREAK) reduce 174) ((T_CATCH) shift) ((T_CLASS) reduce 174) ((T_CLASS_C) reduce 174) ((T_CLONE) reduce 174) ((T_CONSTANT_ENCAPSED_STRING) reduce 174) ((T_CONTINUE) reduce 174) ((T_DEC) reduce 174) ((T_DECLARE) reduce 174) ((T_DIR) reduce 174) ((T_DNUMBER) reduce 174) ((T_DO) reduce 174) ((T_DOUBLE_CAST) reduce 174) ((T_ECHO) reduce 174) ((T_ELSE) reduce 174) ((T_ELSEIF) reduce 174) ((T_EMPTY) reduce 174) ((T_ENDDECLARE) reduce 174) ((T_ENUM) reduce 174) ((T_EVAL) reduce 174) ((T_EXIT) reduce 174) ((T_FILE) reduce 174) ((T_FINAL) reduce 174) ((T_FINALLY) shift) ((T_FN) reduce 174) ((T_FOR) reduce 174) ((T_FOREACH) reduce 174) ((T_FUNCTION) reduce 174) ((T_FUNC_C) reduce 174) ((T_GLOBAL) reduce 174) ((T_GOTO) reduce 174) ((T_HALT_COMPILER) reduce 174) ((T_IF) reduce 174) ((T_INC) reduce 174) ((T_INCLUDE) reduce 174) ((T_INCLUDE_ONCE) reduce 174) ((T_INLINE_HTML) reduce 174) ((T_INTERFACE) reduce 174) ((T_INT_CAST) reduce 174) ((T_ISSET) reduce 174) ((T_LINE) reduce 174) ((T_LIST) reduce 174) ((T_LNUMBER) reduce 174) ((T_MATCH) reduce 174) ((T_METHOD_C) reduce 174) ((T_NAME_FULLY_QUALIFIED) reduce 174) ((T_NAME_QUALIFIED) reduce 174) ((T_NAME_RELATIVE) reduce 174) ((T_NEW) reduce 174) ((T_NS_C) reduce 174) ((T_OBJECT_CAST) reduce 174) ((T_PRINT) reduce 174) ((T_READONLY) reduce 174) ((T_REQUIRE) reduce 174) ((T_REQUIRE_ONCE) reduce 174) ((T_RETURN) reduce 174) ((T_START_HEREDOC) reduce 174) ((T_STATIC) reduce 174) ((T_STRING) reduce 174) ((T_STRING_CAST) reduce 174) ((T_SWITCH) reduce 174) ((T_THROW) reduce 174) ((T_TRAIT) reduce 174) ((T_TRAIT_C) reduce 174) ((T_TRY) reduce 174) ((T_UNSET) reduce 174) ((T_UNSET_CAST) reduce 174) ((T_VARIABLE) reduce 174) ((T_WHILE) reduce 174) ((T_YIELD) reduce 174) ((T_YIELD_FROM) reduce 174) (("[") reduce 174) (("`") reduce 174) (("{") reduce 174) (("~") reduce 174)) 20032 ((("!") reduce 165) (("\"") reduce 165) (("$") reduce 165) (("(") reduce 165) (("+") reduce 165) (("-") reduce 165) ((";") reduce 165) (("@") reduce 165) ((T_ABSTRACT) reduce 165) ((T_ARRAY) reduce 165) ((T_ARRAY_CAST) reduce 165) ((T_ATTRIBUTE) reduce 165) ((T_BOOL_CAST) reduce 165) ((T_BREAK) reduce 165) ((T_CLASS) reduce 165) ((T_CLASS_C) reduce 165) ((T_CLONE) reduce 165) ((T_CONSTANT_ENCAPSED_STRING) reduce 165) ((T_CONTINUE) reduce 165) ((T_DEC) reduce 165) ((T_DECLARE) reduce 165) ((T_DIR) reduce 165) ((T_DNUMBER) reduce 165) ((T_DO) reduce 165) ((T_DOUBLE_CAST) reduce 165) ((T_ECHO) reduce 165) ((T_ELSE) reduce 165) ((T_ELSEIF) reduce 165) ((T_EMPTY) reduce 165) ((T_ENDDECLARE) reduce 165) ((T_ENUM) reduce 165) ((T_EVAL) reduce 165) ((T_EXIT) reduce 165) ((T_FILE) reduce 165) ((T_FINAL) reduce 165) ((T_FN) reduce 165) ((T_FOR) reduce 165) ((T_FOREACH) reduce 165) ((T_FUNCTION) reduce 165) ((T_FUNC_C) reduce 165) ((T_GLOBAL) reduce 165) ((T_GOTO) reduce 165) ((T_HALT_COMPILER) reduce 165) ((T_IF) reduce 165) ((T_INC) reduce 165) ((T_INCLUDE) reduce 165) ((T_INCLUDE_ONCE) reduce 165) ((T_INLINE_HTML) reduce 165) ((T_INTERFACE) reduce 165) ((T_INT_CAST) reduce 165) ((T_ISSET) reduce 165) ((T_LINE) reduce 165) ((T_LIST) reduce 165) ((T_LNUMBER) reduce 165) ((T_MATCH) reduce 165) ((T_METHOD_C) reduce 165) ((T_NAME_FULLY_QUALIFIED) reduce 165) ((T_NAME_QUALIFIED) reduce 165) ((T_NAME_RELATIVE) reduce 165) ((T_NEW) reduce 165) ((T_NS_C) reduce 165) ((T_OBJECT_CAST) reduce 165) ((T_PRINT) reduce 165) ((T_READONLY) reduce 165) ((T_REQUIRE) reduce 165) ((T_REQUIRE_ONCE) reduce 165) ((T_RETURN) reduce 165) ((T_START_HEREDOC) reduce 165) ((T_STATIC) reduce 165) ((T_STRING) reduce 165) ((T_STRING_CAST) reduce 165) ((T_SWITCH) reduce 165) ((T_THROW) reduce 165) ((T_TRAIT) reduce 165) ((T_TRAIT_C) reduce 165) ((T_TRY) reduce 165) ((T_UNSET) reduce 165) ((T_UNSET_CAST) reduce 165) ((T_VARIABLE) reduce 165) ((T_WHILE) reduce 165) ((T_YIELD) reduce 165) ((T_YIELD_FROM) reduce 165) (("[") reduce 165) (("`") reduce 165) (("{") reduce 165) (("~") reduce 165)) 20035 ((("!") reduce 175) (("\"") reduce 175) (("$") reduce 175) (("(") reduce 175) (("+") reduce 175) (("-") reduce 175) ((";") reduce 175) (("@") reduce 175) ((T_ABSTRACT) reduce 175) ((T_ARRAY) reduce 175) ((T_ARRAY_CAST) reduce 175) ((T_ATTRIBUTE) reduce 175) ((T_BOOL_CAST) reduce 175) ((T_BREAK) reduce 175) ((T_CLASS) reduce 175) ((T_CLASS_C) reduce 175) ((T_CLONE) reduce 175) ((T_CONSTANT_ENCAPSED_STRING) reduce 175) ((T_CONTINUE) reduce 175) ((T_DEC) reduce 175) ((T_DECLARE) reduce 175) ((T_DIR) reduce 175) ((T_DNUMBER) reduce 175) ((T_DO) reduce 175) ((T_DOUBLE_CAST) reduce 175) ((T_ECHO) reduce 175) ((T_ELSE) reduce 175) ((T_ELSEIF) reduce 175) ((T_EMPTY) reduce 175) ((T_ENDDECLARE) reduce 175) ((T_ENUM) reduce 175) ((T_EVAL) reduce 175) ((T_EXIT) reduce 175) ((T_FILE) reduce 175) ((T_FINAL) reduce 175) ((T_FN) reduce 175) ((T_FOR) reduce 175) ((T_FOREACH) reduce 175) ((T_FUNCTION) reduce 175) ((T_FUNC_C) reduce 175) ((T_GLOBAL) reduce 175) ((T_GOTO) reduce 175) ((T_HALT_COMPILER) reduce 175) ((T_IF) reduce 175) ((T_INC) reduce 175) ((T_INCLUDE) reduce 175) ((T_INCLUDE_ONCE) reduce 175) ((T_INLINE_HTML) reduce 175) ((T_INTERFACE) reduce 175) ((T_INT_CAST) reduce 175) ((T_ISSET) reduce 175) ((T_LINE) reduce 175) ((T_LIST) reduce 175) ((T_LNUMBER) reduce 175) ((T_MATCH) reduce 175) ((T_METHOD_C) reduce 175) ((T_NAME_FULLY_QUALIFIED) reduce 175) ((T_NAME_QUALIFIED) reduce 175) ((T_NAME_RELATIVE) reduce 175) ((T_NEW) reduce 175) ((T_NS_C) reduce 175) ((T_OBJECT_CAST) reduce 175) ((T_PRINT) reduce 175) ((T_READONLY) reduce 175) ((T_REQUIRE) reduce 175) ((T_REQUIRE_ONCE) reduce 175) ((T_RETURN) reduce 175) ((T_START_HEREDOC) reduce 175) ((T_STATIC) reduce 175) ((T_STRING) reduce 175) ((T_STRING_CAST) reduce 175) ((T_SWITCH) reduce 175) ((T_THROW) reduce 175) ((T_TRAIT) reduce 175) ((T_TRAIT_C) reduce 175) ((T_TRY) reduce 175) ((T_UNSET) reduce 175) ((T_UNSET_CAST) reduce 175) ((T_VARIABLE) reduce 175) ((T_WHILE) reduce 175) ((T_YIELD) reduce 175) ((T_YIELD_FROM) reduce 175) (("[") reduce 175) (("`") reduce 175) (("{") reduce 175) (("~") reduce 175)) 20042 ((("!") reduce 169) (("\"") reduce 169) (("$") reduce 169) (("(") reduce 169) (("+") reduce 169) (("-") reduce 169) ((";") reduce 169) (("@") reduce 169) ((T_ABSTRACT) reduce 169) ((T_ARRAY) reduce 169) ((T_ARRAY_CAST) reduce 169) ((T_ATTRIBUTE) reduce 169) ((T_BOOL_CAST) reduce 169) ((T_BREAK) reduce 169) ((T_CATCH) reduce 169) ((T_CLASS) reduce 169) ((T_CLASS_C) reduce 169) ((T_CLONE) reduce 169) ((T_CONSTANT_ENCAPSED_STRING) reduce 169) ((T_CONTINUE) reduce 169) ((T_DEC) reduce 169) ((T_DECLARE) reduce 169) ((T_DIR) reduce 169) ((T_DNUMBER) reduce 169) ((T_DO) reduce 169) ((T_DOUBLE_CAST) reduce 169) ((T_ECHO) reduce 169) ((T_ELSE) reduce 169) ((T_ELSEIF) reduce 169) ((T_EMPTY) reduce 169) ((T_ENDDECLARE) reduce 169) ((T_ENUM) reduce 169) ((T_EVAL) reduce 169) ((T_EXIT) reduce 169) ((T_FILE) reduce 169) ((T_FINAL) reduce 169) ((T_FINALLY) reduce 169) ((T_FN) reduce 169) ((T_FOR) reduce 169) ((T_FOREACH) reduce 169) ((T_FUNCTION) reduce 169) ((T_FUNC_C) reduce 169) ((T_GLOBAL) reduce 169) ((T_GOTO) reduce 169) ((T_HALT_COMPILER) reduce 169) ((T_IF) reduce 169) ((T_INC) reduce 169) ((T_INCLUDE) reduce 169) ((T_INCLUDE_ONCE) reduce 169) ((T_INLINE_HTML) reduce 169) ((T_INTERFACE) reduce 169) ((T_INT_CAST) reduce 169) ((T_ISSET) reduce 169) ((T_LINE) reduce 169) ((T_LIST) reduce 169) ((T_LNUMBER) reduce 169) ((T_MATCH) reduce 169) ((T_METHOD_C) reduce 169) ((T_NAME_FULLY_QUALIFIED) reduce 169) ((T_NAME_QUALIFIED) reduce 169) ((T_NAME_RELATIVE) reduce 169) ((T_NEW) reduce 169) ((T_NS_C) reduce 169) ((T_OBJECT_CAST) reduce 169) ((T_PRINT) reduce 169) ((T_READONLY) reduce 169) ((T_REQUIRE) reduce 169) ((T_REQUIRE_ONCE) reduce 169) ((T_RETURN) reduce 169) ((T_START_HEREDOC) reduce 169) ((T_STATIC) reduce 169) ((T_STRING) reduce 169) ((T_STRING_CAST) reduce 169) ((T_SWITCH) reduce 169) ((T_THROW) reduce 169) ((T_TRAIT) reduce 169) ((T_TRAIT_C) reduce 169) ((T_TRY) reduce 169) ((T_UNSET) reduce 169) ((T_UNSET_CAST) reduce 169) ((T_VARIABLE) reduce 169) ((T_WHILE) reduce 169) ((T_YIELD) reduce 169) ((T_YIELD_FROM) reduce 169) (("[") reduce 169) (("`") reduce 169) (("{") reduce 169) (("~") reduce 169)) 20047 ((("!") reduce 151) (("\"") reduce 151) (("$") reduce 151) (("(") reduce 151) (("+") reduce 151) (("-") reduce 151) ((";") reduce 151) (("@") reduce 151) ((T_ABSTRACT) reduce 151) ((T_ARRAY) reduce 151) ((T_ARRAY_CAST) reduce 151) ((T_ATTRIBUTE) reduce 151) ((T_BOOL_CAST) reduce 151) ((T_BREAK) reduce 151) ((T_CLASS) reduce 151) ((T_CLASS_C) reduce 151) ((T_CLONE) reduce 151) ((T_CONSTANT_ENCAPSED_STRING) reduce 151) ((T_CONTINUE) reduce 151) ((T_DEC) reduce 151) ((T_DECLARE) reduce 151) ((T_DIR) reduce 151) ((T_DNUMBER) reduce 151) ((T_DO) reduce 151) ((T_DOUBLE_CAST) reduce 151) ((T_ECHO) reduce 151) ((T_ELSE) reduce 151) ((T_ELSEIF) reduce 151) ((T_EMPTY) reduce 151) ((T_ENDDECLARE) reduce 151) ((T_ENUM) reduce 151) ((T_EVAL) reduce 151) ((T_EXIT) reduce 151) ((T_FILE) reduce 151) ((T_FINAL) reduce 151) ((T_FN) reduce 151) ((T_FOR) reduce 151) ((T_FOREACH) reduce 151) ((T_FUNCTION) reduce 151) ((T_FUNC_C) reduce 151) ((T_GLOBAL) reduce 151) ((T_GOTO) reduce 151) ((T_HALT_COMPILER) reduce 151) ((T_IF) reduce 151) ((T_INC) reduce 151) ((T_INCLUDE) reduce 151) ((T_INCLUDE_ONCE) reduce 151) ((T_INLINE_HTML) reduce 151) ((T_INTERFACE) reduce 151) ((T_INT_CAST) reduce 151) ((T_ISSET) reduce 151) ((T_LINE) reduce 151) ((T_LIST) reduce 151) ((T_LNUMBER) reduce 151) ((T_MATCH) reduce 151) ((T_METHOD_C) reduce 151) ((T_NAME_FULLY_QUALIFIED) reduce 151) ((T_NAME_QUALIFIED) reduce 151) ((T_NAME_RELATIVE) reduce 151) ((T_NEW) reduce 151) ((T_NS_C) reduce 151) ((T_OBJECT_CAST) reduce 151) ((T_PRINT) reduce 151) ((T_READONLY) reduce 151) ((T_REQUIRE) reduce 151) ((T_REQUIRE_ONCE) reduce 151) ((T_RETURN) reduce 151) ((T_START_HEREDOC) reduce 151) ((T_STATIC) reduce 151) ((T_STRING) reduce 151) ((T_STRING_CAST) reduce 151) ((T_SWITCH) reduce 151) ((T_THROW) reduce 151) ((T_TRAIT) reduce 151) ((T_TRAIT_C) reduce 151) ((T_TRY) reduce 151) ((T_UNSET) reduce 151) ((T_UNSET_CAST) reduce 151) ((T_VARIABLE) reduce 151) ((T_WHILE) reduce 151) ((T_YIELD) reduce 151) ((T_YIELD_FROM) reduce 151) (("[") reduce 151) (("`") reduce 151) (("{") reduce 151) (("~") reduce 151)) 20051 ((("!") reduce 221) (("\"") reduce 221) (("$") reduce 221) (("(") reduce 221) (("+") reduce 221) (("-") reduce 221) ((";") reduce 221) (("@") reduce 221) ((T_ABSTRACT) reduce 221) ((T_ARRAY) reduce 221) ((T_ARRAY_CAST) reduce 221) ((T_ATTRIBUTE) reduce 221) ((T_BOOL_CAST) reduce 221) ((T_BREAK) reduce 221) ((T_CLASS) reduce 221) ((T_CLASS_C) reduce 221) ((T_CLONE) reduce 221) ((T_CONSTANT_ENCAPSED_STRING) reduce 221) ((T_CONTINUE) reduce 221) ((T_DEC) reduce 221) ((T_DECLARE) reduce 221) ((T_DIR) reduce 221) ((T_DNUMBER) reduce 221) ((T_DO) reduce 221) ((T_DOUBLE_CAST) reduce 221) ((T_ECHO) reduce 221) ((T_ELSE) reduce 221) ((T_ELSEIF) reduce 221) ((T_EMPTY) reduce 221) ((T_ENDDECLARE) reduce 221) ((T_ENUM) reduce 221) ((T_EVAL) reduce 221) ((T_EXIT) reduce 221) ((T_FILE) reduce 221) ((T_FINAL) reduce 221) ((T_FN) reduce 221) ((T_FOR) reduce 221) ((T_FOREACH) reduce 221) ((T_FUNCTION) reduce 221) ((T_FUNC_C) reduce 221) ((T_GLOBAL) reduce 221) ((T_GOTO) reduce 221) ((T_HALT_COMPILER) reduce 221) ((T_IF) reduce 221) ((T_INC) reduce 221) ((T_INCLUDE) reduce 221) ((T_INCLUDE_ONCE) reduce 221) ((T_INLINE_HTML) reduce 221) ((T_INTERFACE) reduce 221) ((T_INT_CAST) reduce 221) ((T_ISSET) reduce 221) ((T_LINE) reduce 221) ((T_LIST) reduce 221) ((T_LNUMBER) reduce 221) ((T_MATCH) reduce 221) ((T_METHOD_C) reduce 221) ((T_NAME_FULLY_QUALIFIED) reduce 221) ((T_NAME_QUALIFIED) reduce 221) ((T_NAME_RELATIVE) reduce 221) ((T_NEW) reduce 221) ((T_NS_C) reduce 221) ((T_OBJECT_CAST) reduce 221) ((T_PRINT) reduce 221) ((T_READONLY) reduce 221) ((T_REQUIRE) reduce 221) ((T_REQUIRE_ONCE) reduce 221) ((T_RETURN) reduce 221) ((T_START_HEREDOC) reduce 221) ((T_STATIC) reduce 221) ((T_STRING) reduce 221) ((T_STRING_CAST) reduce 221) ((T_SWITCH) reduce 221) ((T_THROW) reduce 221) ((T_TRAIT) reduce 221) ((T_TRAIT_C) reduce 221) ((T_TRY) reduce 221) ((T_UNSET) reduce 221) ((T_UNSET_CAST) reduce 221) ((T_VARIABLE) reduce 221) ((T_WHILE) reduce 221) ((T_YIELD) reduce 221) ((T_YIELD_FROM) reduce 221) (("[") reduce 221) (("`") reduce 221) (("{") reduce 221) (("~") reduce 221)) 20053 ((("!") reduce 222) (("\"") reduce 222) (("$") reduce 222) (("(") reduce 222) (("+") reduce 222) (("-") reduce 222) ((";") reduce 222) (("@") reduce 222) ((T_ABSTRACT) reduce 222) ((T_ARRAY) reduce 222) ((T_ARRAY_CAST) reduce 222) ((T_ATTRIBUTE) reduce 222) ((T_BOOL_CAST) reduce 222) ((T_BREAK) reduce 222) ((T_CLASS) reduce 222) ((T_CLASS_C) reduce 222) ((T_CLONE) reduce 222) ((T_CONSTANT_ENCAPSED_STRING) reduce 222) ((T_CONTINUE) reduce 222) ((T_DEC) reduce 222) ((T_DECLARE) reduce 222) ((T_DIR) reduce 222) ((T_DNUMBER) reduce 222) ((T_DO) reduce 222) ((T_DOUBLE_CAST) reduce 222) ((T_ECHO) reduce 222) ((T_ELSE) reduce 222) ((T_ELSEIF) reduce 222) ((T_EMPTY) reduce 222) ((T_ENDDECLARE) reduce 222) ((T_ENUM) reduce 222) ((T_EVAL) reduce 222) ((T_EXIT) reduce 222) ((T_FILE) reduce 222) ((T_FINAL) reduce 222) ((T_FN) reduce 222) ((T_FOR) reduce 222) ((T_FOREACH) reduce 222) ((T_FUNCTION) reduce 222) ((T_FUNC_C) reduce 222) ((T_GLOBAL) reduce 222) ((T_GOTO) reduce 222) ((T_HALT_COMPILER) reduce 222) ((T_IF) reduce 222) ((T_INC) reduce 222) ((T_INCLUDE) reduce 222) ((T_INCLUDE_ONCE) reduce 222) ((T_INLINE_HTML) reduce 222) ((T_INTERFACE) reduce 222) ((T_INT_CAST) reduce 222) ((T_ISSET) reduce 222) ((T_LINE) reduce 222) ((T_LIST) reduce 222) ((T_LNUMBER) reduce 222) ((T_MATCH) reduce 222) ((T_METHOD_C) reduce 222) ((T_NAME_FULLY_QUALIFIED) reduce 222) ((T_NAME_QUALIFIED) reduce 222) ((T_NAME_RELATIVE) reduce 222) ((T_NEW) reduce 222) ((T_NS_C) reduce 222) ((T_OBJECT_CAST) reduce 222) ((T_PRINT) reduce 222) ((T_READONLY) reduce 222) ((T_REQUIRE) reduce 222) ((T_REQUIRE_ONCE) reduce 222) ((T_RETURN) reduce 222) ((T_START_HEREDOC) reduce 222) ((T_STATIC) reduce 222) ((T_STRING) reduce 222) ((T_STRING_CAST) reduce 222) ((T_SWITCH) reduce 222) ((T_THROW) reduce 222) ((T_TRAIT) reduce 222) ((T_TRAIT_C) reduce 222) ((T_TRY) reduce 222) ((T_UNSET) reduce 222) ((T_UNSET_CAST) reduce 222) ((T_VARIABLE) reduce 222) ((T_WHILE) reduce 222) ((T_YIELD) reduce 222) ((T_YIELD_FROM) reduce 222) (("[") reduce 222) (("`") reduce 222) (("{") reduce 222) (("~") reduce 222)) 20057 ((("!") reduce 223) (("\"") reduce 223) (("$") reduce 223) (("(") reduce 223) (("+") reduce 223) (("-") reduce 223) ((";") reduce 223) (("@") reduce 223) ((T_ABSTRACT) reduce 223) ((T_ARRAY) reduce 223) ((T_ARRAY_CAST) reduce 223) ((T_ATTRIBUTE) reduce 223) ((T_BOOL_CAST) reduce 223) ((T_BREAK) reduce 223) ((T_CLASS) reduce 223) ((T_CLASS_C) reduce 223) ((T_CLONE) reduce 223) ((T_CONSTANT_ENCAPSED_STRING) reduce 223) ((T_CONTINUE) reduce 223) ((T_DEC) reduce 223) ((T_DECLARE) reduce 223) ((T_DIR) reduce 223) ((T_DNUMBER) reduce 223) ((T_DO) reduce 223) ((T_DOUBLE_CAST) reduce 223) ((T_ECHO) reduce 223) ((T_ELSE) reduce 223) ((T_ELSEIF) reduce 223) ((T_EMPTY) reduce 223) ((T_ENDDECLARE) reduce 223) ((T_ENUM) reduce 223) ((T_EVAL) reduce 223) ((T_EXIT) reduce 223) ((T_FILE) reduce 223) ((T_FINAL) reduce 223) ((T_FN) reduce 223) ((T_FOR) reduce 223) ((T_FOREACH) reduce 223) ((T_FUNCTION) reduce 223) ((T_FUNC_C) reduce 223) ((T_GLOBAL) reduce 223) ((T_GOTO) reduce 223) ((T_HALT_COMPILER) reduce 223) ((T_IF) reduce 223) ((T_INC) reduce 223) ((T_INCLUDE) reduce 223) ((T_INCLUDE_ONCE) reduce 223) ((T_INLINE_HTML) reduce 223) ((T_INTERFACE) reduce 223) ((T_INT_CAST) reduce 223) ((T_ISSET) reduce 223) ((T_LINE) reduce 223) ((T_LIST) reduce 223) ((T_LNUMBER) reduce 223) ((T_MATCH) reduce 223) ((T_METHOD_C) reduce 223) ((T_NAME_FULLY_QUALIFIED) reduce 223) ((T_NAME_QUALIFIED) reduce 223) ((T_NAME_RELATIVE) reduce 223) ((T_NEW) reduce 223) ((T_NS_C) reduce 223) ((T_OBJECT_CAST) reduce 223) ((T_PRINT) reduce 223) ((T_READONLY) reduce 223) ((T_REQUIRE) reduce 223) ((T_REQUIRE_ONCE) reduce 223) ((T_RETURN) reduce 223) ((T_START_HEREDOC) reduce 223) ((T_STATIC) reduce 223) ((T_STRING) reduce 223) ((T_STRING_CAST) reduce 223) ((T_SWITCH) reduce 223) ((T_THROW) reduce 223) ((T_TRAIT) reduce 223) ((T_TRAIT_C) reduce 223) ((T_TRY) reduce 223) ((T_UNSET) reduce 223) ((T_UNSET_CAST) reduce 223) ((T_VARIABLE) reduce 223) ((T_WHILE) reduce 223) ((T_YIELD) reduce 223) ((T_YIELD_FROM) reduce 223) (("[") reduce 223) (("`") reduce 223) (("{") reduce 223) (("~") reduce 223)) 20060 ((("!") reduce 224) (("\"") reduce 224) (("$") reduce 224) (("(") reduce 224) (("+") reduce 224) (("-") reduce 224) ((";") reduce 224) (("@") reduce 224) ((T_ABSTRACT) reduce 224) ((T_ARRAY) reduce 224) ((T_ARRAY_CAST) reduce 224) ((T_ATTRIBUTE) reduce 224) ((T_BOOL_CAST) reduce 224) ((T_BREAK) reduce 224) ((T_CLASS) reduce 224) ((T_CLASS_C) reduce 224) ((T_CLONE) reduce 224) ((T_CONSTANT_ENCAPSED_STRING) reduce 224) ((T_CONTINUE) reduce 224) ((T_DEC) reduce 224) ((T_DECLARE) reduce 224) ((T_DIR) reduce 224) ((T_DNUMBER) reduce 224) ((T_DO) reduce 224) ((T_DOUBLE_CAST) reduce 224) ((T_ECHO) reduce 224) ((T_ELSE) reduce 224) ((T_ELSEIF) reduce 224) ((T_EMPTY) reduce 224) ((T_ENDDECLARE) reduce 224) ((T_ENUM) reduce 224) ((T_EVAL) reduce 224) ((T_EXIT) reduce 224) ((T_FILE) reduce 224) ((T_FINAL) reduce 224) ((T_FN) reduce 224) ((T_FOR) reduce 224) ((T_FOREACH) reduce 224) ((T_FUNCTION) reduce 224) ((T_FUNC_C) reduce 224) ((T_GLOBAL) reduce 224) ((T_GOTO) reduce 224) ((T_HALT_COMPILER) reduce 224) ((T_IF) reduce 224) ((T_INC) reduce 224) ((T_INCLUDE) reduce 224) ((T_INCLUDE_ONCE) reduce 224) ((T_INLINE_HTML) reduce 224) ((T_INTERFACE) reduce 224) ((T_INT_CAST) reduce 224) ((T_ISSET) reduce 224) ((T_LINE) reduce 224) ((T_LIST) reduce 224) ((T_LNUMBER) reduce 224) ((T_MATCH) reduce 224) ((T_METHOD_C) reduce 224) ((T_NAME_FULLY_QUALIFIED) reduce 224) ((T_NAME_QUALIFIED) reduce 224) ((T_NAME_RELATIVE) reduce 224) ((T_NEW) reduce 224) ((T_NS_C) reduce 224) ((T_OBJECT_CAST) reduce 224) ((T_PRINT) reduce 224) ((T_READONLY) reduce 224) ((T_REQUIRE) reduce 224) ((T_REQUIRE_ONCE) reduce 224) ((T_RETURN) reduce 224) ((T_START_HEREDOC) reduce 224) ((T_STATIC) reduce 224) ((T_STRING) reduce 224) ((T_STRING_CAST) reduce 224) ((T_SWITCH) reduce 224) ((T_THROW) reduce 224) ((T_TRAIT) reduce 224) ((T_TRAIT_C) reduce 224) ((T_TRY) reduce 224) ((T_UNSET) reduce 224) ((T_UNSET_CAST) reduce 224) ((T_VARIABLE) reduce 224) ((T_WHILE) reduce 224) ((T_YIELD) reduce 224) ((T_YIELD_FROM) reduce 224) (("[") reduce 224) (("`") reduce 224) (("{") reduce 224) (("~") reduce 224)) 20061 ((("!") reduce 167) (("\"") reduce 167) (("$") reduce 167) (("(") reduce 167) (("+") reduce 167) (("-") reduce 167) ((";") reduce 167) (("@") reduce 167) ((T_ABSTRACT) reduce 167) ((T_ARRAY) reduce 167) ((T_ARRAY_CAST) reduce 167) ((T_ATTRIBUTE) reduce 167) ((T_BOOL_CAST) reduce 167) ((T_BREAK) reduce 167) ((T_CLASS) reduce 167) ((T_CLASS_C) reduce 167) ((T_CLONE) reduce 167) ((T_CONSTANT_ENCAPSED_STRING) reduce 167) ((T_CONTINUE) reduce 167) ((T_DEC) reduce 167) ((T_DECLARE) reduce 167) ((T_DIR) reduce 167) ((T_DNUMBER) reduce 167) ((T_DO) reduce 167) ((T_DOUBLE_CAST) reduce 167) ((T_ECHO) reduce 167) ((T_ELSE) reduce 167) ((T_ELSEIF) reduce 167) ((T_EMPTY) reduce 167) ((T_ENDDECLARE) reduce 167) ((T_ENUM) reduce 167) ((T_EVAL) reduce 167) ((T_EXIT) reduce 167) ((T_FILE) reduce 167) ((T_FINAL) reduce 167) ((T_FN) reduce 167) ((T_FOR) reduce 167) ((T_FOREACH) reduce 167) ((T_FUNCTION) reduce 167) ((T_FUNC_C) reduce 167) ((T_GLOBAL) reduce 167) ((T_GOTO) reduce 167) ((T_HALT_COMPILER) reduce 167) ((T_IF) reduce 167) ((T_INC) reduce 167) ((T_INCLUDE) reduce 167) ((T_INCLUDE_ONCE) reduce 167) ((T_INLINE_HTML) reduce 167) ((T_INTERFACE) reduce 167) ((T_INT_CAST) reduce 167) ((T_ISSET) reduce 167) ((T_LINE) reduce 167) ((T_LIST) reduce 167) ((T_LNUMBER) reduce 167) ((T_MATCH) reduce 167) ((T_METHOD_C) reduce 167) ((T_NAME_FULLY_QUALIFIED) reduce 167) ((T_NAME_QUALIFIED) reduce 167) ((T_NAME_RELATIVE) reduce 167) ((T_NEW) reduce 167) ((T_NS_C) reduce 167) ((T_OBJECT_CAST) reduce 167) ((T_PRINT) reduce 167) ((T_READONLY) reduce 167) ((T_REQUIRE) reduce 167) ((T_REQUIRE_ONCE) reduce 167) ((T_RETURN) reduce 167) ((T_START_HEREDOC) reduce 167) ((T_STATIC) reduce 167) ((T_STRING) reduce 167) ((T_STRING_CAST) reduce 167) ((T_SWITCH) reduce 167) ((T_THROW) reduce 167) ((T_TRAIT) reduce 167) ((T_TRAIT_C) reduce 167) ((T_TRY) reduce 167) ((T_UNSET) reduce 167) ((T_UNSET_CAST) reduce 167) ((T_VARIABLE) reduce 167) ((T_WHILE) reduce 167) ((T_YIELD) reduce 167) ((T_YIELD_FROM) reduce 167) (("[") reduce 167) (("`") reduce 167) (("{") reduce 167) (("~") reduce 167)) 20063 ((("!") reduce 156) (("\"") reduce 156) (("$") reduce 156) (("(") reduce 156) (("+") reduce 156) (("-") reduce 156) ((";") reduce 156) (("@") reduce 156) ((T_ABSTRACT) reduce 156) ((T_ARRAY) reduce 156) ((T_ARRAY_CAST) reduce 156) ((T_ATTRIBUTE) reduce 156) ((T_BOOL_CAST) reduce 156) ((T_BREAK) reduce 156) ((T_CLASS) reduce 156) ((T_CLASS_C) reduce 156) ((T_CLONE) reduce 156) ((T_CONSTANT_ENCAPSED_STRING) reduce 156) ((T_CONTINUE) reduce 156) ((T_DEC) reduce 156) ((T_DECLARE) reduce 156) ((T_DIR) reduce 156) ((T_DNUMBER) reduce 156) ((T_DO) reduce 156) ((T_DOUBLE_CAST) reduce 156) ((T_ECHO) reduce 156) ((T_ELSE) reduce 156) ((T_ELSEIF) reduce 156) ((T_EMPTY) reduce 156) ((T_ENDDECLARE) reduce 156) ((T_ENUM) reduce 156) ((T_EVAL) reduce 156) ((T_EXIT) reduce 156) ((T_FILE) reduce 156) ((T_FINAL) reduce 156) ((T_FN) reduce 156) ((T_FOR) reduce 156) ((T_FOREACH) reduce 156) ((T_FUNCTION) reduce 156) ((T_FUNC_C) reduce 156) ((T_GLOBAL) reduce 156) ((T_GOTO) reduce 156) ((T_HALT_COMPILER) reduce 156) ((T_IF) reduce 156) ((T_INC) reduce 156) ((T_INCLUDE) reduce 156) ((T_INCLUDE_ONCE) reduce 156) ((T_INLINE_HTML) reduce 156) ((T_INTERFACE) reduce 156) ((T_INT_CAST) reduce 156) ((T_ISSET) reduce 156) ((T_LINE) reduce 156) ((T_LIST) reduce 156) ((T_LNUMBER) reduce 156) ((T_MATCH) reduce 156) ((T_METHOD_C) reduce 156) ((T_NAME_FULLY_QUALIFIED) reduce 156) ((T_NAME_QUALIFIED) reduce 156) ((T_NAME_RELATIVE) reduce 156) ((T_NEW) reduce 156) ((T_NS_C) reduce 156) ((T_OBJECT_CAST) reduce 156) ((T_PRINT) reduce 156) ((T_READONLY) reduce 156) ((T_REQUIRE) reduce 156) ((T_REQUIRE_ONCE) reduce 156) ((T_RETURN) reduce 156) ((T_START_HEREDOC) reduce 156) ((T_STATIC) reduce 156) ((T_STRING) reduce 156) ((T_STRING_CAST) reduce 156) ((T_SWITCH) reduce 156) ((T_THROW) reduce 156) ((T_TRAIT) reduce 156) ((T_TRAIT_C) reduce 156) ((T_TRY) reduce 156) ((T_UNSET) reduce 156) ((T_UNSET_CAST) reduce 156) ((T_VARIABLE) reduce 156) ((T_WHILE) reduce 156) ((T_YIELD) reduce 156) ((T_YIELD_FROM) reduce 156) (("[") reduce 156) (("`") reduce 156) (("{") reduce 156) (("~") reduce 156)) 20065 ((("!") reduce 154) (("\"") reduce 154) (("$") reduce 154) (("(") reduce 154) (("+") reduce 154) (("-") reduce 154) ((";") reduce 154) (("@") reduce 154) ((T_ABSTRACT) reduce 154) ((T_ARRAY) reduce 154) ((T_ARRAY_CAST) reduce 154) ((T_ATTRIBUTE) reduce 154) ((T_BOOL_CAST) reduce 154) ((T_BREAK) reduce 154) ((T_CLASS) reduce 154) ((T_CLASS_C) reduce 154) ((T_CLONE) reduce 154) ((T_CONSTANT_ENCAPSED_STRING) reduce 154) ((T_CONTINUE) reduce 154) ((T_DEC) reduce 154) ((T_DECLARE) reduce 154) ((T_DIR) reduce 154) ((T_DNUMBER) reduce 154) ((T_DO) reduce 154) ((T_DOUBLE_CAST) reduce 154) ((T_ECHO) reduce 154) ((T_ELSE) reduce 154) ((T_ELSEIF) reduce 154) ((T_EMPTY) reduce 154) ((T_ENDDECLARE) reduce 154) ((T_ENUM) reduce 154) ((T_EVAL) reduce 154) ((T_EXIT) reduce 154) ((T_FILE) reduce 154) ((T_FINAL) reduce 154) ((T_FN) reduce 154) ((T_FOR) reduce 154) ((T_FOREACH) reduce 154) ((T_FUNCTION) reduce 154) ((T_FUNC_C) reduce 154) ((T_GLOBAL) reduce 154) ((T_GOTO) reduce 154) ((T_HALT_COMPILER) reduce 154) ((T_IF) reduce 154) ((T_INC) reduce 154) ((T_INCLUDE) reduce 154) ((T_INCLUDE_ONCE) reduce 154) ((T_INLINE_HTML) reduce 154) ((T_INTERFACE) reduce 154) ((T_INT_CAST) reduce 154) ((T_ISSET) reduce 154) ((T_LINE) reduce 154) ((T_LIST) reduce 154) ((T_LNUMBER) reduce 154) ((T_MATCH) reduce 154) ((T_METHOD_C) reduce 154) ((T_NAME_FULLY_QUALIFIED) reduce 154) ((T_NAME_QUALIFIED) reduce 154) ((T_NAME_RELATIVE) reduce 154) ((T_NEW) reduce 154) ((T_NS_C) reduce 154) ((T_OBJECT_CAST) reduce 154) ((T_PRINT) reduce 154) ((T_READONLY) reduce 154) ((T_REQUIRE) reduce 154) ((T_REQUIRE_ONCE) reduce 154) ((T_RETURN) reduce 154) ((T_START_HEREDOC) reduce 154) ((T_STATIC) reduce 154) ((T_STRING) reduce 154) ((T_STRING_CAST) reduce 154) ((T_SWITCH) reduce 154) ((T_THROW) reduce 154) ((T_TRAIT) reduce 154) ((T_TRAIT_C) reduce 154) ((T_TRY) reduce 154) ((T_UNSET) reduce 154) ((T_UNSET_CAST) reduce 154) ((T_VARIABLE) reduce 154) ((T_WHILE) reduce 154) ((T_YIELD) reduce 154) ((T_YIELD_FROM) reduce 154) (("[") reduce 154) (("`") reduce 154) (("{") reduce 154) (("~") reduce 154)) 20067 ((("!") reduce 166) (("\"") reduce 166) (("$") reduce 166) (("(") reduce 166) (("+") reduce 166) (("-") reduce 166) ((";") reduce 166) (("@") reduce 166) ((T_ABSTRACT) reduce 166) ((T_ARRAY) reduce 166) ((T_ARRAY_CAST) reduce 166) ((T_ATTRIBUTE) reduce 166) ((T_BOOL_CAST) reduce 166) ((T_BREAK) reduce 166) ((T_CLASS) reduce 166) ((T_CLASS_C) reduce 166) ((T_CLONE) reduce 166) ((T_CONSTANT_ENCAPSED_STRING) reduce 166) ((T_CONTINUE) reduce 166) ((T_DEC) reduce 166) ((T_DECLARE) reduce 166) ((T_DIR) reduce 166) ((T_DNUMBER) reduce 166) ((T_DO) reduce 166) ((T_DOUBLE_CAST) reduce 166) ((T_ECHO) reduce 166) ((T_ELSE) reduce 166) ((T_ELSEIF) reduce 166) ((T_EMPTY) reduce 166) ((T_ENDDECLARE) reduce 166) ((T_ENUM) reduce 166) ((T_EVAL) reduce 166) ((T_EXIT) reduce 166) ((T_FILE) reduce 166) ((T_FINAL) reduce 166) ((T_FN) reduce 166) ((T_FOR) reduce 166) ((T_FOREACH) reduce 166) ((T_FUNCTION) reduce 166) ((T_FUNC_C) reduce 166) ((T_GLOBAL) reduce 166) ((T_GOTO) reduce 166) ((T_HALT_COMPILER) reduce 166) ((T_IF) reduce 166) ((T_INC) reduce 166) ((T_INCLUDE) reduce 166) ((T_INCLUDE_ONCE) reduce 166) ((T_INLINE_HTML) reduce 166) ((T_INTERFACE) reduce 166) ((T_INT_CAST) reduce 166) ((T_ISSET) reduce 166) ((T_LINE) reduce 166) ((T_LIST) reduce 166) ((T_LNUMBER) reduce 166) ((T_MATCH) reduce 166) ((T_METHOD_C) reduce 166) ((T_NAME_FULLY_QUALIFIED) reduce 166) ((T_NAME_QUALIFIED) reduce 166) ((T_NAME_RELATIVE) reduce 166) ((T_NEW) reduce 166) ((T_NS_C) reduce 166) ((T_OBJECT_CAST) reduce 166) ((T_PRINT) reduce 166) ((T_READONLY) reduce 166) ((T_REQUIRE) reduce 166) ((T_REQUIRE_ONCE) reduce 166) ((T_RETURN) reduce 166) ((T_START_HEREDOC) reduce 166) ((T_STATIC) reduce 166) ((T_STRING) reduce 166) ((T_STRING_CAST) reduce 166) ((T_SWITCH) reduce 166) ((T_THROW) reduce 166) ((T_TRAIT) reduce 166) ((T_TRAIT_C) reduce 166) ((T_TRY) reduce 166) ((T_UNSET) reduce 166) ((T_UNSET_CAST) reduce 166) ((T_VARIABLE) reduce 166) ((T_WHILE) reduce 166) ((T_YIELD) reduce 166) ((T_YIELD_FROM) reduce 166) (("[") reduce 166) (("`") reduce 166) (("{") reduce 166) (("~") reduce 166)) 20069 ((("!") reduce 155) (("\"") reduce 155) (("$") reduce 155) (("(") reduce 155) (("+") reduce 155) (("-") reduce 155) ((";") reduce 155) (("@") reduce 155) ((T_ABSTRACT) reduce 155) ((T_ARRAY) reduce 155) ((T_ARRAY_CAST) reduce 155) ((T_ATTRIBUTE) reduce 155) ((T_BOOL_CAST) reduce 155) ((T_BREAK) reduce 155) ((T_CLASS) reduce 155) ((T_CLASS_C) reduce 155) ((T_CLONE) reduce 155) ((T_CONSTANT_ENCAPSED_STRING) reduce 155) ((T_CONTINUE) reduce 155) ((T_DEC) reduce 155) ((T_DECLARE) reduce 155) ((T_DIR) reduce 155) ((T_DNUMBER) reduce 155) ((T_DO) reduce 155) ((T_DOUBLE_CAST) reduce 155) ((T_ECHO) reduce 155) ((T_ELSE) reduce 155) ((T_ELSEIF) reduce 155) ((T_EMPTY) reduce 155) ((T_ENDDECLARE) reduce 155) ((T_ENUM) reduce 155) ((T_EVAL) reduce 155) ((T_EXIT) reduce 155) ((T_FILE) reduce 155) ((T_FINAL) reduce 155) ((T_FN) reduce 155) ((T_FOR) reduce 155) ((T_FOREACH) reduce 155) ((T_FUNCTION) reduce 155) ((T_FUNC_C) reduce 155) ((T_GLOBAL) reduce 155) ((T_GOTO) reduce 155) ((T_HALT_COMPILER) reduce 155) ((T_IF) reduce 155) ((T_INC) reduce 155) ((T_INCLUDE) reduce 155) ((T_INCLUDE_ONCE) reduce 155) ((T_INLINE_HTML) reduce 155) ((T_INTERFACE) reduce 155) ((T_INT_CAST) reduce 155) ((T_ISSET) reduce 155) ((T_LINE) reduce 155) ((T_LIST) reduce 155) ((T_LNUMBER) reduce 155) ((T_MATCH) reduce 155) ((T_METHOD_C) reduce 155) ((T_NAME_FULLY_QUALIFIED) reduce 155) ((T_NAME_QUALIFIED) reduce 155) ((T_NAME_RELATIVE) reduce 155) ((T_NEW) reduce 155) ((T_NS_C) reduce 155) ((T_OBJECT_CAST) reduce 155) ((T_PRINT) reduce 155) ((T_READONLY) reduce 155) ((T_REQUIRE) reduce 155) ((T_REQUIRE_ONCE) reduce 155) ((T_RETURN) reduce 155) ((T_START_HEREDOC) reduce 155) ((T_STATIC) reduce 155) ((T_STRING) reduce 155) ((T_STRING_CAST) reduce 155) ((T_SWITCH) reduce 155) ((T_THROW) reduce 155) ((T_TRAIT) reduce 155) ((T_TRAIT_C) reduce 155) ((T_TRY) reduce 155) ((T_UNSET) reduce 155) ((T_UNSET_CAST) reduce 155) ((T_VARIABLE) reduce 155) ((T_WHILE) reduce 155) ((T_YIELD) reduce 155) ((T_YIELD_FROM) reduce 155) (("[") reduce 155) (("`") reduce 155) (("{") reduce 155) (("~") reduce 155)) 20079 ((("!") reduce 162) (("\"") reduce 162) (("$") reduce 162) (("(") reduce 162) (("+") reduce 162) (("-") reduce 162) ((";") reduce 162) (("@") reduce 162) ((T_ABSTRACT) reduce 162) ((T_ARRAY) reduce 162) ((T_ARRAY_CAST) reduce 162) ((T_ATTRIBUTE) reduce 162) ((T_BOOL_CAST) reduce 162) ((T_BREAK) reduce 162) ((T_CLASS) reduce 162) ((T_CLASS_C) reduce 162) ((T_CLONE) reduce 162) ((T_CONSTANT_ENCAPSED_STRING) reduce 162) ((T_CONTINUE) reduce 162) ((T_DEC) reduce 162) ((T_DECLARE) reduce 162) ((T_DIR) reduce 162) ((T_DNUMBER) reduce 162) ((T_DO) reduce 162) ((T_DOUBLE_CAST) reduce 162) ((T_ECHO) reduce 162) ((T_ELSE) reduce 162) ((T_ELSEIF) reduce 162) ((T_EMPTY) reduce 162) ((T_ENDDECLARE) reduce 162) ((T_ENUM) reduce 162) ((T_EVAL) reduce 162) ((T_EXIT) reduce 162) ((T_FILE) reduce 162) ((T_FINAL) reduce 162) ((T_FN) reduce 162) ((T_FOR) reduce 162) ((T_FOREACH) reduce 162) ((T_FUNCTION) reduce 162) ((T_FUNC_C) reduce 162) ((T_GLOBAL) reduce 162) ((T_GOTO) reduce 162) ((T_HALT_COMPILER) reduce 162) ((T_IF) reduce 162) ((T_INC) reduce 162) ((T_INCLUDE) reduce 162) ((T_INCLUDE_ONCE) reduce 162) ((T_INLINE_HTML) reduce 162) ((T_INTERFACE) reduce 162) ((T_INT_CAST) reduce 162) ((T_ISSET) reduce 162) ((T_LINE) reduce 162) ((T_LIST) reduce 162) ((T_LNUMBER) reduce 162) ((T_MATCH) reduce 162) ((T_METHOD_C) reduce 162) ((T_NAME_FULLY_QUALIFIED) reduce 162) ((T_NAME_QUALIFIED) reduce 162) ((T_NAME_RELATIVE) reduce 162) ((T_NEW) reduce 162) ((T_NS_C) reduce 162) ((T_OBJECT_CAST) reduce 162) ((T_PRINT) reduce 162) ((T_READONLY) reduce 162) ((T_REQUIRE) reduce 162) ((T_REQUIRE_ONCE) reduce 162) ((T_RETURN) reduce 162) ((T_START_HEREDOC) reduce 162) ((T_STATIC) reduce 162) ((T_STRING) reduce 162) ((T_STRING_CAST) reduce 162) ((T_SWITCH) reduce 162) ((T_THROW) reduce 162) ((T_TRAIT) reduce 162) ((T_TRAIT_C) reduce 162) ((T_TRY) reduce 162) ((T_UNSET) reduce 162) ((T_UNSET_CAST) reduce 162) ((T_VARIABLE) reduce 162) ((T_WHILE) reduce 162) ((T_YIELD) reduce 162) ((T_YIELD_FROM) reduce 162) (("[") reduce 162) (("`") reduce 162) (("{") reduce 162) (("~") reduce 162)) 20080 ((("!") reduce 217) (("\"") reduce 217) (("$") reduce 217) (("(") reduce 217) (("+") reduce 217) (("-") reduce 217) ((";") reduce 217) (("@") reduce 217) ((T_ABSTRACT) reduce 217) ((T_ARRAY) reduce 217) ((T_ARRAY_CAST) reduce 217) ((T_ATTRIBUTE) reduce 217) ((T_BOOL_CAST) reduce 217) ((T_BREAK) reduce 217) ((T_CLASS) reduce 217) ((T_CLASS_C) reduce 217) ((T_CLONE) reduce 217) ((T_CONSTANT_ENCAPSED_STRING) reduce 217) ((T_CONTINUE) reduce 217) ((T_DEC) reduce 217) ((T_DECLARE) reduce 217) ((T_DIR) reduce 217) ((T_DNUMBER) reduce 217) ((T_DO) reduce 217) ((T_DOUBLE_CAST) reduce 217) ((T_ECHO) reduce 217) ((T_ELSE) reduce 217) ((T_ELSEIF) reduce 217) ((T_EMPTY) reduce 217) ((T_ENDDECLARE) reduce 217) ((T_ENUM) reduce 217) ((T_EVAL) reduce 217) ((T_EXIT) reduce 217) ((T_FILE) reduce 217) ((T_FINAL) reduce 217) ((T_FN) reduce 217) ((T_FOR) reduce 217) ((T_FOREACH) reduce 217) ((T_FUNCTION) reduce 217) ((T_FUNC_C) reduce 217) ((T_GLOBAL) reduce 217) ((T_GOTO) reduce 217) ((T_HALT_COMPILER) reduce 217) ((T_IF) reduce 217) ((T_INC) reduce 217) ((T_INCLUDE) reduce 217) ((T_INCLUDE_ONCE) reduce 217) ((T_INLINE_HTML) reduce 217) ((T_INTERFACE) reduce 217) ((T_INT_CAST) reduce 217) ((T_ISSET) reduce 217) ((T_LINE) reduce 217) ((T_LIST) reduce 217) ((T_LNUMBER) reduce 217) ((T_MATCH) reduce 217) ((T_METHOD_C) reduce 217) ((T_NAME_FULLY_QUALIFIED) reduce 217) ((T_NAME_QUALIFIED) reduce 217) ((T_NAME_RELATIVE) reduce 217) ((T_NEW) reduce 217) ((T_NS_C) reduce 217) ((T_OBJECT_CAST) reduce 217) ((T_PRINT) reduce 217) ((T_READONLY) reduce 217) ((T_REQUIRE) reduce 217) ((T_REQUIRE_ONCE) reduce 217) ((T_RETURN) reduce 217) ((T_START_HEREDOC) reduce 217) ((T_STATIC) reduce 217) ((T_STRING) reduce 217) ((T_STRING_CAST) reduce 217) ((T_SWITCH) reduce 217) ((T_THROW) reduce 217) ((T_TRAIT) reduce 217) ((T_TRAIT_C) reduce 217) ((T_TRY) reduce 217) ((T_UNSET) reduce 217) ((T_UNSET_CAST) reduce 217) ((T_VARIABLE) reduce 217) ((T_WHILE) reduce 217) ((T_YIELD) reduce 217) ((T_YIELD_FROM) reduce 217) (("[") reduce 217) (("`") reduce 217) (("{") reduce 217) (("~") reduce 217)) 20083 ((("!") reduce 218) (("\"") reduce 218) (("$") reduce 218) (("(") reduce 218) (("+") reduce 218) (("-") reduce 218) ((";") reduce 218) (("@") reduce 218) ((T_ABSTRACT) reduce 218) ((T_ARRAY) reduce 218) ((T_ARRAY_CAST) reduce 218) ((T_ATTRIBUTE) reduce 218) ((T_BOOL_CAST) reduce 218) ((T_BREAK) reduce 218) ((T_CLASS) reduce 218) ((T_CLASS_C) reduce 218) ((T_CLONE) reduce 218) ((T_CONSTANT_ENCAPSED_STRING) reduce 218) ((T_CONTINUE) reduce 218) ((T_DEC) reduce 218) ((T_DECLARE) reduce 218) ((T_DIR) reduce 218) ((T_DNUMBER) reduce 218) ((T_DO) reduce 218) ((T_DOUBLE_CAST) reduce 218) ((T_ECHO) reduce 218) ((T_ELSE) reduce 218) ((T_ELSEIF) reduce 218) ((T_EMPTY) reduce 218) ((T_ENDDECLARE) reduce 218) ((T_ENUM) reduce 218) ((T_EVAL) reduce 218) ((T_EXIT) reduce 218) ((T_FILE) reduce 218) ((T_FINAL) reduce 218) ((T_FN) reduce 218) ((T_FOR) reduce 218) ((T_FOREACH) reduce 218) ((T_FUNCTION) reduce 218) ((T_FUNC_C) reduce 218) ((T_GLOBAL) reduce 218) ((T_GOTO) reduce 218) ((T_HALT_COMPILER) reduce 218) ((T_IF) reduce 218) ((T_INC) reduce 218) ((T_INCLUDE) reduce 218) ((T_INCLUDE_ONCE) reduce 218) ((T_INLINE_HTML) reduce 218) ((T_INTERFACE) reduce 218) ((T_INT_CAST) reduce 218) ((T_ISSET) reduce 218) ((T_LINE) reduce 218) ((T_LIST) reduce 218) ((T_LNUMBER) reduce 218) ((T_MATCH) reduce 218) ((T_METHOD_C) reduce 218) ((T_NAME_FULLY_QUALIFIED) reduce 218) ((T_NAME_QUALIFIED) reduce 218) ((T_NAME_RELATIVE) reduce 218) ((T_NEW) reduce 218) ((T_NS_C) reduce 218) ((T_OBJECT_CAST) reduce 218) ((T_PRINT) reduce 218) ((T_READONLY) reduce 218) ((T_REQUIRE) reduce 218) ((T_REQUIRE_ONCE) reduce 218) ((T_RETURN) reduce 218) ((T_START_HEREDOC) reduce 218) ((T_STATIC) reduce 218) ((T_STRING) reduce 218) ((T_STRING_CAST) reduce 218) ((T_SWITCH) reduce 218) ((T_THROW) reduce 218) ((T_TRAIT) reduce 218) ((T_TRAIT_C) reduce 218) ((T_TRY) reduce 218) ((T_UNSET) reduce 218) ((T_UNSET_CAST) reduce 218) ((T_VARIABLE) reduce 218) ((T_WHILE) reduce 218) ((T_YIELD) reduce 218) ((T_YIELD_FROM) reduce 218) (("[") reduce 218) (("`") reduce 218) (("{") reduce 218) (("~") reduce 218)) 20084 ((("!") reduce 161) (("\"") reduce 161) (("$") reduce 161) (("(") reduce 161) (("+") reduce 161) (("-") reduce 161) ((";") reduce 161) (("@") reduce 161) ((T_ABSTRACT) reduce 161) ((T_ARRAY) reduce 161) ((T_ARRAY_CAST) reduce 161) ((T_ATTRIBUTE) reduce 161) ((T_BOOL_CAST) reduce 161) ((T_BREAK) reduce 161) ((T_CLASS) reduce 161) ((T_CLASS_C) reduce 161) ((T_CLONE) reduce 161) ((T_CONSTANT_ENCAPSED_STRING) reduce 161) ((T_CONTINUE) reduce 161) ((T_DEC) reduce 161) ((T_DECLARE) reduce 161) ((T_DIR) reduce 161) ((T_DNUMBER) reduce 161) ((T_DO) reduce 161) ((T_DOUBLE_CAST) reduce 161) ((T_ECHO) reduce 161) ((T_ELSE) reduce 161) ((T_ELSEIF) reduce 161) ((T_EMPTY) reduce 161) ((T_ENDDECLARE) reduce 161) ((T_ENUM) reduce 161) ((T_EVAL) reduce 161) ((T_EXIT) reduce 161) ((T_FILE) reduce 161) ((T_FINAL) reduce 161) ((T_FN) reduce 161) ((T_FOR) reduce 161) ((T_FOREACH) reduce 161) ((T_FUNCTION) reduce 161) ((T_FUNC_C) reduce 161) ((T_GLOBAL) reduce 161) ((T_GOTO) reduce 161) ((T_HALT_COMPILER) reduce 161) ((T_IF) reduce 161) ((T_INC) reduce 161) ((T_INCLUDE) reduce 161) ((T_INCLUDE_ONCE) reduce 161) ((T_INLINE_HTML) reduce 161) ((T_INTERFACE) reduce 161) ((T_INT_CAST) reduce 161) ((T_ISSET) reduce 161) ((T_LINE) reduce 161) ((T_LIST) reduce 161) ((T_LNUMBER) reduce 161) ((T_MATCH) reduce 161) ((T_METHOD_C) reduce 161) ((T_NAME_FULLY_QUALIFIED) reduce 161) ((T_NAME_QUALIFIED) reduce 161) ((T_NAME_RELATIVE) reduce 161) ((T_NEW) reduce 161) ((T_NS_C) reduce 161) ((T_OBJECT_CAST) reduce 161) ((T_PRINT) reduce 161) ((T_READONLY) reduce 161) ((T_REQUIRE) reduce 161) ((T_REQUIRE_ONCE) reduce 161) ((T_RETURN) reduce 161) ((T_START_HEREDOC) reduce 161) ((T_STATIC) reduce 161) ((T_STRING) reduce 161) ((T_STRING_CAST) reduce 161) ((T_SWITCH) reduce 161) ((T_THROW) reduce 161) ((T_TRAIT) reduce 161) ((T_TRAIT_C) reduce 161) ((T_TRY) reduce 161) ((T_UNSET) reduce 161) ((T_UNSET_CAST) reduce 161) ((T_VARIABLE) reduce 161) ((T_WHILE) reduce 161) ((T_YIELD) reduce 161) ((T_YIELD_FROM) reduce 161) (("[") reduce 161) (("`") reduce 161) (("{") reduce 161) (("~") reduce 161)) 20093 ((("!") reduce 150) (("\"") reduce 150) (("$") reduce 150) (("(") reduce 150) (("+") reduce 150) (("-") reduce 150) ((";") reduce 150) (("@") reduce 150) ((T_ABSTRACT) reduce 150) ((T_ARRAY) reduce 150) ((T_ARRAY_CAST) reduce 150) ((T_ATTRIBUTE) reduce 150) ((T_BOOL_CAST) reduce 150) ((T_BREAK) reduce 150) ((T_CLASS) reduce 150) ((T_CLASS_C) reduce 150) ((T_CLONE) reduce 150) ((T_CONSTANT_ENCAPSED_STRING) reduce 150) ((T_CONTINUE) reduce 150) ((T_DEC) reduce 150) ((T_DECLARE) reduce 150) ((T_DIR) reduce 150) ((T_DNUMBER) reduce 150) ((T_DO) reduce 150) ((T_DOUBLE_CAST) reduce 150) ((T_ECHO) reduce 150) ((T_ELSE) reduce 150) ((T_ELSEIF) reduce 150) ((T_EMPTY) reduce 150) ((T_ENDDECLARE) reduce 150) ((T_ENUM) reduce 150) ((T_EVAL) reduce 150) ((T_EXIT) reduce 150) ((T_FILE) reduce 150) ((T_FINAL) reduce 150) ((T_FN) reduce 150) ((T_FOR) reduce 150) ((T_FOREACH) reduce 150) ((T_FUNCTION) reduce 150) ((T_FUNC_C) reduce 150) ((T_GLOBAL) reduce 150) ((T_GOTO) reduce 150) ((T_HALT_COMPILER) reduce 150) ((T_IF) reduce 150) ((T_INC) reduce 150) ((T_INCLUDE) reduce 150) ((T_INCLUDE_ONCE) reduce 150) ((T_INLINE_HTML) reduce 150) ((T_INTERFACE) reduce 150) ((T_INT_CAST) reduce 150) ((T_ISSET) reduce 150) ((T_LINE) reduce 150) ((T_LIST) reduce 150) ((T_LNUMBER) reduce 150) ((T_MATCH) reduce 150) ((T_METHOD_C) reduce 150) ((T_NAME_FULLY_QUALIFIED) reduce 150) ((T_NAME_QUALIFIED) reduce 150) ((T_NAME_RELATIVE) reduce 150) ((T_NEW) reduce 150) ((T_NS_C) reduce 150) ((T_OBJECT_CAST) reduce 150) ((T_PRINT) reduce 150) ((T_READONLY) reduce 150) ((T_REQUIRE) reduce 150) ((T_REQUIRE_ONCE) reduce 150) ((T_RETURN) reduce 150) ((T_START_HEREDOC) reduce 150) ((T_STATIC) reduce 150) ((T_STRING) reduce 150) ((T_STRING_CAST) reduce 150) ((T_SWITCH) reduce 150) ((T_THROW) reduce 150) ((T_TRAIT) reduce 150) ((T_TRAIT_C) reduce 150) ((T_TRY) reduce 150) ((T_UNSET) reduce 150) ((T_UNSET_CAST) reduce 150) ((T_VARIABLE) reduce 150) ((T_WHILE) reduce 150) ((T_YIELD) reduce 150) ((T_YIELD_FROM) reduce 150) (("[") reduce 150) (("`") reduce 150) (("{") reduce 150) (("~") reduce 150)) 20094 ((("!") reduce 215) (("\"") reduce 215) (("$") reduce 215) (("(") reduce 215) (("+") reduce 215) (("-") reduce 215) ((";") reduce 215) (("@") reduce 215) ((T_ABSTRACT) reduce 215) ((T_ARRAY) reduce 215) ((T_ARRAY_CAST) reduce 215) ((T_ATTRIBUTE) reduce 215) ((T_BOOL_CAST) reduce 215) ((T_BREAK) reduce 215) ((T_CLASS) reduce 215) ((T_CLASS_C) reduce 215) ((T_CLONE) reduce 215) ((T_CONSTANT_ENCAPSED_STRING) reduce 215) ((T_CONTINUE) reduce 215) ((T_DEC) reduce 215) ((T_DECLARE) reduce 215) ((T_DIR) reduce 215) ((T_DNUMBER) reduce 215) ((T_DO) reduce 215) ((T_DOUBLE_CAST) reduce 215) ((T_ECHO) reduce 215) ((T_ELSE) reduce 215) ((T_ELSEIF) reduce 215) ((T_EMPTY) reduce 215) ((T_ENDDECLARE) reduce 215) ((T_ENUM) reduce 215) ((T_EVAL) reduce 215) ((T_EXIT) reduce 215) ((T_FILE) reduce 215) ((T_FINAL) reduce 215) ((T_FN) reduce 215) ((T_FOR) reduce 215) ((T_FOREACH) reduce 215) ((T_FUNCTION) reduce 215) ((T_FUNC_C) reduce 215) ((T_GLOBAL) reduce 215) ((T_GOTO) reduce 215) ((T_HALT_COMPILER) reduce 215) ((T_IF) reduce 215) ((T_INC) reduce 215) ((T_INCLUDE) reduce 215) ((T_INCLUDE_ONCE) reduce 215) ((T_INLINE_HTML) reduce 215) ((T_INTERFACE) reduce 215) ((T_INT_CAST) reduce 215) ((T_ISSET) reduce 215) ((T_LINE) reduce 215) ((T_LIST) reduce 215) ((T_LNUMBER) reduce 215) ((T_MATCH) reduce 215) ((T_METHOD_C) reduce 215) ((T_NAME_FULLY_QUALIFIED) reduce 215) ((T_NAME_QUALIFIED) reduce 215) ((T_NAME_RELATIVE) reduce 215) ((T_NEW) reduce 215) ((T_NS_C) reduce 215) ((T_OBJECT_CAST) reduce 215) ((T_PRINT) reduce 215) ((T_READONLY) reduce 215) ((T_REQUIRE) reduce 215) ((T_REQUIRE_ONCE) reduce 215) ((T_RETURN) reduce 215) ((T_START_HEREDOC) reduce 215) ((T_STATIC) reduce 215) ((T_STRING) reduce 215) ((T_STRING_CAST) reduce 215) ((T_SWITCH) reduce 215) ((T_THROW) reduce 215) ((T_TRAIT) reduce 215) ((T_TRAIT_C) reduce 215) ((T_TRY) reduce 215) ((T_UNSET) reduce 215) ((T_UNSET_CAST) reduce 215) ((T_VARIABLE) reduce 215) ((T_WHILE) reduce 215) ((T_YIELD) reduce 215) ((T_YIELD_FROM) reduce 215) (("[") reduce 215) (("`") reduce 215) (("{") reduce 215) (("~") reduce 215)) 20097 ((("!") reduce 216) (("\"") reduce 216) (("$") reduce 216) (("(") reduce 216) (("+") reduce 216) (("-") reduce 216) ((";") reduce 216) (("@") reduce 216) ((T_ABSTRACT) reduce 216) ((T_ARRAY) reduce 216) ((T_ARRAY_CAST) reduce 216) ((T_ATTRIBUTE) reduce 216) ((T_BOOL_CAST) reduce 216) ((T_BREAK) reduce 216) ((T_CLASS) reduce 216) ((T_CLASS_C) reduce 216) ((T_CLONE) reduce 216) ((T_CONSTANT_ENCAPSED_STRING) reduce 216) ((T_CONTINUE) reduce 216) ((T_DEC) reduce 216) ((T_DECLARE) reduce 216) ((T_DIR) reduce 216) ((T_DNUMBER) reduce 216) ((T_DO) reduce 216) ((T_DOUBLE_CAST) reduce 216) ((T_ECHO) reduce 216) ((T_ELSE) reduce 216) ((T_ELSEIF) reduce 216) ((T_EMPTY) reduce 216) ((T_ENDDECLARE) reduce 216) ((T_ENUM) reduce 216) ((T_EVAL) reduce 216) ((T_EXIT) reduce 216) ((T_FILE) reduce 216) ((T_FINAL) reduce 216) ((T_FN) reduce 216) ((T_FOR) reduce 216) ((T_FOREACH) reduce 216) ((T_FUNCTION) reduce 216) ((T_FUNC_C) reduce 216) ((T_GLOBAL) reduce 216) ((T_GOTO) reduce 216) ((T_HALT_COMPILER) reduce 216) ((T_IF) reduce 216) ((T_INC) reduce 216) ((T_INCLUDE) reduce 216) ((T_INCLUDE_ONCE) reduce 216) ((T_INLINE_HTML) reduce 216) ((T_INTERFACE) reduce 216) ((T_INT_CAST) reduce 216) ((T_ISSET) reduce 216) ((T_LINE) reduce 216) ((T_LIST) reduce 216) ((T_LNUMBER) reduce 216) ((T_MATCH) reduce 216) ((T_METHOD_C) reduce 216) ((T_NAME_FULLY_QUALIFIED) reduce 216) ((T_NAME_QUALIFIED) reduce 216) ((T_NAME_RELATIVE) reduce 216) ((T_NEW) reduce 216) ((T_NS_C) reduce 216) ((T_OBJECT_CAST) reduce 216) ((T_PRINT) reduce 216) ((T_READONLY) reduce 216) ((T_REQUIRE) reduce 216) ((T_REQUIRE_ONCE) reduce 216) ((T_RETURN) reduce 216) ((T_START_HEREDOC) reduce 216) ((T_STATIC) reduce 216) ((T_STRING) reduce 216) ((T_STRING_CAST) reduce 216) ((T_SWITCH) reduce 216) ((T_THROW) reduce 216) ((T_TRAIT) reduce 216) ((T_TRAIT_C) reduce 216) ((T_TRY) reduce 216) ((T_UNSET) reduce 216) ((T_UNSET_CAST) reduce 216) ((T_VARIABLE) reduce 216) ((T_WHILE) reduce 216) ((T_YIELD) reduce 216) ((T_YIELD_FROM) reduce 216) (("[") reduce 216) (("`") reduce 216) (("{") reduce 216) (("~") reduce 216)) 20099 ((("!") reduce 157) (("\"") reduce 157) (("$") reduce 157) (("(") reduce 157) (("+") reduce 157) (("-") reduce 157) ((";") reduce 157) (("@") reduce 157) ((T_ABSTRACT) reduce 157) ((T_ARRAY) reduce 157) ((T_ARRAY_CAST) reduce 157) ((T_ATTRIBUTE) reduce 157) ((T_BOOL_CAST) reduce 157) ((T_BREAK) reduce 157) ((T_CLASS) reduce 157) ((T_CLASS_C) reduce 157) ((T_CLONE) reduce 157) ((T_CONSTANT_ENCAPSED_STRING) reduce 157) ((T_CONTINUE) reduce 157) ((T_DEC) reduce 157) ((T_DECLARE) reduce 157) ((T_DIR) reduce 157) ((T_DNUMBER) reduce 157) ((T_DO) reduce 157) ((T_DOUBLE_CAST) reduce 157) ((T_ECHO) reduce 157) ((T_ELSE) reduce 157) ((T_ELSEIF) reduce 157) ((T_EMPTY) reduce 157) ((T_ENDDECLARE) reduce 157) ((T_ENUM) reduce 157) ((T_EVAL) reduce 157) ((T_EXIT) reduce 157) ((T_FILE) reduce 157) ((T_FINAL) reduce 157) ((T_FN) reduce 157) ((T_FOR) reduce 157) ((T_FOREACH) reduce 157) ((T_FUNCTION) reduce 157) ((T_FUNC_C) reduce 157) ((T_GLOBAL) reduce 157) ((T_GOTO) reduce 157) ((T_HALT_COMPILER) reduce 157) ((T_IF) reduce 157) ((T_INC) reduce 157) ((T_INCLUDE) reduce 157) ((T_INCLUDE_ONCE) reduce 157) ((T_INLINE_HTML) reduce 157) ((T_INTERFACE) reduce 157) ((T_INT_CAST) reduce 157) ((T_ISSET) reduce 157) ((T_LINE) reduce 157) ((T_LIST) reduce 157) ((T_LNUMBER) reduce 157) ((T_MATCH) reduce 157) ((T_METHOD_C) reduce 157) ((T_NAME_FULLY_QUALIFIED) reduce 157) ((T_NAME_QUALIFIED) reduce 157) ((T_NAME_RELATIVE) reduce 157) ((T_NEW) reduce 157) ((T_NS_C) reduce 157) ((T_OBJECT_CAST) reduce 157) ((T_PRINT) reduce 157) ((T_READONLY) reduce 157) ((T_REQUIRE) reduce 157) ((T_REQUIRE_ONCE) reduce 157) ((T_RETURN) reduce 157) ((T_START_HEREDOC) reduce 157) ((T_STATIC) reduce 157) ((T_STRING) reduce 157) ((T_STRING_CAST) reduce 157) ((T_SWITCH) reduce 157) ((T_THROW) reduce 157) ((T_TRAIT) reduce 157) ((T_TRAIT_C) reduce 157) ((T_TRY) reduce 157) ((T_UNSET) reduce 157) ((T_UNSET_CAST) reduce 157) ((T_VARIABLE) reduce 157) ((T_WHILE) reduce 157) ((T_YIELD) reduce 157) ((T_YIELD_FROM) reduce 157) (("[") reduce 157) (("`") reduce 157) (("{") reduce 157) (("~") reduce 157)) 20105 ((("!") reduce 149) (("\"") reduce 149) (("$") reduce 149) (("(") reduce 149) (("+") reduce 149) (("-") reduce 149) ((";") reduce 149) (("@") reduce 149) ((T_ABSTRACT) reduce 149) ((T_ARRAY) reduce 149) ((T_ARRAY_CAST) reduce 149) ((T_ATTRIBUTE) reduce 149) ((T_BOOL_CAST) reduce 149) ((T_BREAK) reduce 149) ((T_CLASS) reduce 149) ((T_CLASS_C) reduce 149) ((T_CLONE) reduce 149) ((T_CONSTANT_ENCAPSED_STRING) reduce 149) ((T_CONTINUE) reduce 149) ((T_DEC) reduce 149) ((T_DECLARE) reduce 149) ((T_DIR) reduce 149) ((T_DNUMBER) reduce 149) ((T_DO) reduce 149) ((T_DOUBLE_CAST) reduce 149) ((T_ECHO) reduce 149) ((T_ELSE) reduce 149) ((T_ELSEIF) reduce 149) ((T_EMPTY) reduce 149) ((T_ENDDECLARE) reduce 149) ((T_ENUM) reduce 149) ((T_EVAL) reduce 149) ((T_EXIT) reduce 149) ((T_FILE) reduce 149) ((T_FINAL) reduce 149) ((T_FN) reduce 149) ((T_FOR) reduce 149) ((T_FOREACH) reduce 149) ((T_FUNCTION) reduce 149) ((T_FUNC_C) reduce 149) ((T_GLOBAL) reduce 149) ((T_GOTO) reduce 149) ((T_HALT_COMPILER) reduce 149) ((T_IF) reduce 149) ((T_INC) reduce 149) ((T_INCLUDE) reduce 149) ((T_INCLUDE_ONCE) reduce 149) ((T_INLINE_HTML) reduce 149) ((T_INTERFACE) reduce 149) ((T_INT_CAST) reduce 149) ((T_ISSET) reduce 149) ((T_LINE) reduce 149) ((T_LIST) reduce 149) ((T_LNUMBER) reduce 149) ((T_MATCH) reduce 149) ((T_METHOD_C) reduce 149) ((T_NAME_FULLY_QUALIFIED) reduce 149) ((T_NAME_QUALIFIED) reduce 149) ((T_NAME_RELATIVE) reduce 149) ((T_NEW) reduce 149) ((T_NS_C) reduce 149) ((T_OBJECT_CAST) reduce 149) ((T_PRINT) reduce 149) ((T_READONLY) reduce 149) ((T_REQUIRE) reduce 149) ((T_REQUIRE_ONCE) reduce 149) ((T_RETURN) reduce 149) ((T_START_HEREDOC) reduce 149) ((T_STATIC) reduce 149) ((T_STRING) reduce 149) ((T_STRING_CAST) reduce 149) ((T_SWITCH) reduce 149) ((T_THROW) reduce 149) ((T_TRAIT) reduce 149) ((T_TRAIT_C) reduce 149) ((T_TRY) reduce 149) ((T_UNSET) reduce 149) ((T_UNSET_CAST) reduce 149) ((T_VARIABLE) reduce 149) ((T_WHILE) reduce 149) ((T_YIELD) reduce 149) ((T_YIELD_FROM) reduce 149) (("[") reduce 149) (("`") reduce 149) (("{") reduce 149) (("~") reduce 149)) 20110 ((("!") reduce 163) (("\"") reduce 163) (("$") reduce 163) (("(") reduce 163) (("+") reduce 163) (("-") reduce 163) ((";") reduce 163) (("@") reduce 163) ((T_ABSTRACT) reduce 163) ((T_ARRAY) reduce 163) ((T_ARRAY_CAST) reduce 163) ((T_ATTRIBUTE) reduce 163) ((T_BOOL_CAST) reduce 163) ((T_BREAK) reduce 163) ((T_CLASS) reduce 163) ((T_CLASS_C) reduce 163) ((T_CLONE) reduce 163) ((T_CONSTANT_ENCAPSED_STRING) reduce 163) ((T_CONTINUE) reduce 163) ((T_DEC) reduce 163) ((T_DECLARE) reduce 163) ((T_DIR) reduce 163) ((T_DNUMBER) reduce 163) ((T_DO) reduce 163) ((T_DOUBLE_CAST) reduce 163) ((T_ECHO) reduce 163) ((T_ELSE) reduce 163) ((T_ELSEIF) reduce 163) ((T_EMPTY) reduce 163) ((T_ENDDECLARE) reduce 163) ((T_ENUM) reduce 163) ((T_EVAL) reduce 163) ((T_EXIT) reduce 163) ((T_FILE) reduce 163) ((T_FINAL) reduce 163) ((T_FN) reduce 163) ((T_FOR) reduce 163) ((T_FOREACH) reduce 163) ((T_FUNCTION) reduce 163) ((T_FUNC_C) reduce 163) ((T_GLOBAL) reduce 163) ((T_GOTO) reduce 163) ((T_HALT_COMPILER) reduce 163) ((T_IF) reduce 163) ((T_INC) reduce 163) ((T_INCLUDE) reduce 163) ((T_INCLUDE_ONCE) reduce 163) ((T_INLINE_HTML) reduce 163) ((T_INTERFACE) reduce 163) ((T_INT_CAST) reduce 163) ((T_ISSET) reduce 163) ((T_LINE) reduce 163) ((T_LIST) reduce 163) ((T_LNUMBER) reduce 163) ((T_MATCH) reduce 163) ((T_METHOD_C) reduce 163) ((T_NAME_FULLY_QUALIFIED) reduce 163) ((T_NAME_QUALIFIED) reduce 163) ((T_NAME_RELATIVE) reduce 163) ((T_NEW) reduce 163) ((T_NS_C) reduce 163) ((T_OBJECT_CAST) reduce 163) ((T_PRINT) reduce 163) ((T_READONLY) reduce 163) ((T_REQUIRE) reduce 163) ((T_REQUIRE_ONCE) reduce 163) ((T_RETURN) reduce 163) ((T_START_HEREDOC) reduce 163) ((T_STATIC) reduce 163) ((T_STRING) reduce 163) ((T_STRING_CAST) reduce 163) ((T_SWITCH) reduce 163) ((T_THROW) reduce 163) ((T_TRAIT) reduce 163) ((T_TRAIT_C) reduce 163) ((T_TRY) reduce 163) ((T_UNSET) reduce 163) ((T_UNSET_CAST) reduce 163) ((T_VARIABLE) reduce 163) ((T_WHILE) reduce 163) ((T_YIELD) reduce 163) ((T_YIELD_FROM) reduce 163) (("[") reduce 163) (("`") reduce 163) (("{") reduce 163) (("~") reduce 163)) 20111 ((("!") reduce 219) (("\"") reduce 219) (("$") reduce 219) (("(") reduce 219) (("+") reduce 219) (("-") reduce 219) ((";") reduce 219) (("@") reduce 219) ((T_ABSTRACT) reduce 219) ((T_ARRAY) reduce 219) ((T_ARRAY_CAST) reduce 219) ((T_ATTRIBUTE) reduce 219) ((T_BOOL_CAST) reduce 219) ((T_BREAK) reduce 219) ((T_CLASS) reduce 219) ((T_CLASS_C) reduce 219) ((T_CLONE) reduce 219) ((T_CONSTANT_ENCAPSED_STRING) reduce 219) ((T_CONTINUE) reduce 219) ((T_DEC) reduce 219) ((T_DECLARE) reduce 219) ((T_DIR) reduce 219) ((T_DNUMBER) reduce 219) ((T_DO) reduce 219) ((T_DOUBLE_CAST) reduce 219) ((T_ECHO) reduce 219) ((T_ELSE) reduce 219) ((T_ELSEIF) reduce 219) ((T_EMPTY) reduce 219) ((T_ENDDECLARE) reduce 219) ((T_ENUM) reduce 219) ((T_EVAL) reduce 219) ((T_EXIT) reduce 219) ((T_FILE) reduce 219) ((T_FINAL) reduce 219) ((T_FN) reduce 219) ((T_FOR) reduce 219) ((T_FOREACH) reduce 219) ((T_FUNCTION) reduce 219) ((T_FUNC_C) reduce 219) ((T_GLOBAL) reduce 219) ((T_GOTO) reduce 219) ((T_HALT_COMPILER) reduce 219) ((T_IF) reduce 219) ((T_INC) reduce 219) ((T_INCLUDE) reduce 219) ((T_INCLUDE_ONCE) reduce 219) ((T_INLINE_HTML) reduce 219) ((T_INTERFACE) reduce 219) ((T_INT_CAST) reduce 219) ((T_ISSET) reduce 219) ((T_LINE) reduce 219) ((T_LIST) reduce 219) ((T_LNUMBER) reduce 219) ((T_MATCH) reduce 219) ((T_METHOD_C) reduce 219) ((T_NAME_FULLY_QUALIFIED) reduce 219) ((T_NAME_QUALIFIED) reduce 219) ((T_NAME_RELATIVE) reduce 219) ((T_NEW) reduce 219) ((T_NS_C) reduce 219) ((T_OBJECT_CAST) reduce 219) ((T_PRINT) reduce 219) ((T_READONLY) reduce 219) ((T_REQUIRE) reduce 219) ((T_REQUIRE_ONCE) reduce 219) ((T_RETURN) reduce 219) ((T_START_HEREDOC) reduce 219) ((T_STATIC) reduce 219) ((T_STRING) reduce 219) ((T_STRING_CAST) reduce 219) ((T_SWITCH) reduce 219) ((T_THROW) reduce 219) ((T_TRAIT) reduce 219) ((T_TRAIT_C) reduce 219) ((T_TRY) reduce 219) ((T_UNSET) reduce 219) ((T_UNSET_CAST) reduce 219) ((T_VARIABLE) reduce 219) ((T_WHILE) reduce 219) ((T_YIELD) reduce 219) ((T_YIELD_FROM) reduce 219) (("[") reduce 219) (("`") reduce 219) (("{") reduce 219) (("~") reduce 219)) 20114 ((("!") reduce 220) (("\"") reduce 220) (("$") reduce 220) (("(") reduce 220) (("+") reduce 220) (("-") reduce 220) ((";") reduce 220) (("@") reduce 220) ((T_ABSTRACT) reduce 220) ((T_ARRAY) reduce 220) ((T_ARRAY_CAST) reduce 220) ((T_ATTRIBUTE) reduce 220) ((T_BOOL_CAST) reduce 220) ((T_BREAK) reduce 220) ((T_CLASS) reduce 220) ((T_CLASS_C) reduce 220) ((T_CLONE) reduce 220) ((T_CONSTANT_ENCAPSED_STRING) reduce 220) ((T_CONTINUE) reduce 220) ((T_DEC) reduce 220) ((T_DECLARE) reduce 220) ((T_DIR) reduce 220) ((T_DNUMBER) reduce 220) ((T_DO) reduce 220) ((T_DOUBLE_CAST) reduce 220) ((T_ECHO) reduce 220) ((T_ELSE) reduce 220) ((T_ELSEIF) reduce 220) ((T_EMPTY) reduce 220) ((T_ENDDECLARE) reduce 220) ((T_ENUM) reduce 220) ((T_EVAL) reduce 220) ((T_EXIT) reduce 220) ((T_FILE) reduce 220) ((T_FINAL) reduce 220) ((T_FN) reduce 220) ((T_FOR) reduce 220) ((T_FOREACH) reduce 220) ((T_FUNCTION) reduce 220) ((T_FUNC_C) reduce 220) ((T_GLOBAL) reduce 220) ((T_GOTO) reduce 220) ((T_HALT_COMPILER) reduce 220) ((T_IF) reduce 220) ((T_INC) reduce 220) ((T_INCLUDE) reduce 220) ((T_INCLUDE_ONCE) reduce 220) ((T_INLINE_HTML) reduce 220) ((T_INTERFACE) reduce 220) ((T_INT_CAST) reduce 220) ((T_ISSET) reduce 220) ((T_LINE) reduce 220) ((T_LIST) reduce 220) ((T_LNUMBER) reduce 220) ((T_MATCH) reduce 220) ((T_METHOD_C) reduce 220) ((T_NAME_FULLY_QUALIFIED) reduce 220) ((T_NAME_QUALIFIED) reduce 220) ((T_NAME_RELATIVE) reduce 220) ((T_NEW) reduce 220) ((T_NS_C) reduce 220) ((T_OBJECT_CAST) reduce 220) ((T_PRINT) reduce 220) ((T_READONLY) reduce 220) ((T_REQUIRE) reduce 220) ((T_REQUIRE_ONCE) reduce 220) ((T_RETURN) reduce 220) ((T_START_HEREDOC) reduce 220) ((T_STATIC) reduce 220) ((T_STRING) reduce 220) ((T_STRING_CAST) reduce 220) ((T_SWITCH) reduce 220) ((T_THROW) reduce 220) ((T_TRAIT) reduce 220) ((T_TRAIT_C) reduce 220) ((T_TRY) reduce 220) ((T_UNSET) reduce 220) ((T_UNSET_CAST) reduce 220) ((T_VARIABLE) reduce 220) ((T_WHILE) reduce 220) ((T_YIELD) reduce 220) ((T_YIELD_FROM) reduce 220) (("[") reduce 220) (("`") reduce 220) (("{") reduce 220) (("~") reduce 220)) 20116 ((("!") reduce 153) (("\"") reduce 153) (("$") reduce 153) (("(") reduce 153) (("+") reduce 153) (("-") reduce 153) ((";") reduce 153) (("@") reduce 153) ((T_ABSTRACT) reduce 153) ((T_ARRAY) reduce 153) ((T_ARRAY_CAST) reduce 153) ((T_ATTRIBUTE) reduce 153) ((T_BOOL_CAST) reduce 153) ((T_BREAK) reduce 153) ((T_CLASS) reduce 153) ((T_CLASS_C) reduce 153) ((T_CLONE) reduce 153) ((T_CONSTANT_ENCAPSED_STRING) reduce 153) ((T_CONTINUE) reduce 153) ((T_DEC) reduce 153) ((T_DECLARE) reduce 153) ((T_DIR) reduce 153) ((T_DNUMBER) reduce 153) ((T_DO) reduce 153) ((T_DOUBLE_CAST) reduce 153) ((T_ECHO) reduce 153) ((T_ELSE) reduce 153) ((T_ELSEIF) reduce 153) ((T_EMPTY) reduce 153) ((T_ENDDECLARE) reduce 153) ((T_ENUM) reduce 153) ((T_EVAL) reduce 153) ((T_EXIT) reduce 153) ((T_FILE) reduce 153) ((T_FINAL) reduce 153) ((T_FN) reduce 153) ((T_FOR) reduce 153) ((T_FOREACH) reduce 153) ((T_FUNCTION) reduce 153) ((T_FUNC_C) reduce 153) ((T_GLOBAL) reduce 153) ((T_GOTO) reduce 153) ((T_HALT_COMPILER) reduce 153) ((T_IF) reduce 153) ((T_INC) reduce 153) ((T_INCLUDE) reduce 153) ((T_INCLUDE_ONCE) reduce 153) ((T_INLINE_HTML) reduce 153) ((T_INTERFACE) reduce 153) ((T_INT_CAST) reduce 153) ((T_ISSET) reduce 153) ((T_LINE) reduce 153) ((T_LIST) reduce 153) ((T_LNUMBER) reduce 153) ((T_MATCH) reduce 153) ((T_METHOD_C) reduce 153) ((T_NAME_FULLY_QUALIFIED) reduce 153) ((T_NAME_QUALIFIED) reduce 153) ((T_NAME_RELATIVE) reduce 153) ((T_NEW) reduce 153) ((T_NS_C) reduce 153) ((T_OBJECT_CAST) reduce 153) ((T_PRINT) reduce 153) ((T_READONLY) reduce 153) ((T_REQUIRE) reduce 153) ((T_REQUIRE_ONCE) reduce 153) ((T_RETURN) reduce 153) ((T_START_HEREDOC) reduce 153) ((T_STATIC) reduce 153) ((T_STRING) reduce 153) ((T_STRING_CAST) reduce 153) ((T_SWITCH) reduce 153) ((T_THROW) reduce 153) ((T_TRAIT) reduce 153) ((T_TRAIT_C) reduce 153) ((T_TRY) reduce 153) ((T_UNSET) reduce 153) ((T_UNSET_CAST) reduce 153) ((T_VARIABLE) reduce 153) ((T_WHILE) reduce 153) ((T_YIELD) reduce 153) ((T_YIELD_FROM) reduce 153) (("[") reduce 153) (("`") reduce 153) (("{") reduce 153) (("~") reduce 153)) 20118 ((("!") reduce 152) (("\"") reduce 152) (("$") reduce 152) (("(") reduce 152) (("+") reduce 152) (("-") reduce 152) ((";") reduce 152) (("@") reduce 152) ((T_ABSTRACT) reduce 152) ((T_ARRAY) reduce 152) ((T_ARRAY_CAST) reduce 152) ((T_ATTRIBUTE) reduce 152) ((T_BOOL_CAST) reduce 152) ((T_BREAK) reduce 152) ((T_CLASS) reduce 152) ((T_CLASS_C) reduce 152) ((T_CLONE) reduce 152) ((T_CONSTANT_ENCAPSED_STRING) reduce 152) ((T_CONTINUE) reduce 152) ((T_DEC) reduce 152) ((T_DECLARE) reduce 152) ((T_DIR) reduce 152) ((T_DNUMBER) reduce 152) ((T_DO) reduce 152) ((T_DOUBLE_CAST) reduce 152) ((T_ECHO) reduce 152) ((T_ELSE) reduce 152) ((T_ELSEIF) reduce 152) ((T_EMPTY) reduce 152) ((T_ENDDECLARE) reduce 152) ((T_ENUM) reduce 152) ((T_EVAL) reduce 152) ((T_EXIT) reduce 152) ((T_FILE) reduce 152) ((T_FINAL) reduce 152) ((T_FN) reduce 152) ((T_FOR) reduce 152) ((T_FOREACH) reduce 152) ((T_FUNCTION) reduce 152) ((T_FUNC_C) reduce 152) ((T_GLOBAL) reduce 152) ((T_GOTO) reduce 152) ((T_HALT_COMPILER) reduce 152) ((T_IF) reduce 152) ((T_INC) reduce 152) ((T_INCLUDE) reduce 152) ((T_INCLUDE_ONCE) reduce 152) ((T_INLINE_HTML) reduce 152) ((T_INTERFACE) reduce 152) ((T_INT_CAST) reduce 152) ((T_ISSET) reduce 152) ((T_LINE) reduce 152) ((T_LIST) reduce 152) ((T_LNUMBER) reduce 152) ((T_MATCH) reduce 152) ((T_METHOD_C) reduce 152) ((T_NAME_FULLY_QUALIFIED) reduce 152) ((T_NAME_QUALIFIED) reduce 152) ((T_NAME_RELATIVE) reduce 152) ((T_NEW) reduce 152) ((T_NS_C) reduce 152) ((T_OBJECT_CAST) reduce 152) ((T_PRINT) reduce 152) ((T_READONLY) reduce 152) ((T_REQUIRE) reduce 152) ((T_REQUIRE_ONCE) reduce 152) ((T_RETURN) reduce 152) ((T_START_HEREDOC) reduce 152) ((T_STATIC) reduce 152) ((T_STRING) reduce 152) ((T_STRING_CAST) reduce 152) ((T_SWITCH) reduce 152) ((T_THROW) reduce 152) ((T_TRAIT) reduce 152) ((T_TRAIT_C) reduce 152) ((T_TRY) reduce 152) ((T_UNSET) reduce 152) ((T_UNSET_CAST) reduce 152) ((T_VARIABLE) reduce 152) ((T_WHILE) reduce 152) ((T_YIELD) reduce 152) ((T_YIELD_FROM) reduce 152) (("[") reduce 152) (("`") reduce 152) (("{") reduce 152) (("~") reduce 152)) 20119 ((("!") reduce 244) (("\"") reduce 244) (("$") reduce 244) (("(") reduce 244) (("+") reduce 244) (("-") reduce 244) ((";") reduce 244) (("@") reduce 244) ((T_ABSTRACT) reduce 244) ((T_ARRAY) reduce 244) ((T_ARRAY_CAST) reduce 244) ((T_ATTRIBUTE) reduce 244) ((T_BOOL_CAST) reduce 244) ((T_BREAK) reduce 244) ((T_CLASS) reduce 244) ((T_CLASS_C) reduce 244) ((T_CLONE) reduce 244) ((T_CONSTANT_ENCAPSED_STRING) reduce 244) ((T_CONTINUE) reduce 244) ((T_DEC) reduce 244) ((T_DECLARE) reduce 244) ((T_DIR) reduce 244) ((T_DNUMBER) reduce 244) ((T_DO) reduce 244) ((T_DOUBLE_CAST) reduce 244) ((T_ECHO) reduce 244) ((T_EMPTY) reduce 244) ((T_ENDDECLARE) reduce 244) ((T_ENUM) reduce 244) ((T_EVAL) reduce 244) ((T_EXIT) reduce 244) ((T_FILE) reduce 244) ((T_FINAL) reduce 244) ((T_FN) reduce 244) ((T_FOR) reduce 244) ((T_FOREACH) reduce 244) ((T_FUNCTION) reduce 244) ((T_FUNC_C) reduce 244) ((T_GLOBAL) reduce 244) ((T_GOTO) reduce 244) ((T_HALT_COMPILER) reduce 244) ((T_IF) reduce 244) ((T_INC) reduce 244) ((T_INCLUDE) reduce 244) ((T_INCLUDE_ONCE) reduce 244) ((T_INLINE_HTML) reduce 244) ((T_INTERFACE) reduce 244) ((T_INT_CAST) reduce 244) ((T_ISSET) reduce 244) ((T_LINE) reduce 244) ((T_LIST) reduce 244) ((T_LNUMBER) reduce 244) ((T_MATCH) reduce 244) ((T_METHOD_C) reduce 244) ((T_NAME_FULLY_QUALIFIED) reduce 244) ((T_NAME_QUALIFIED) reduce 244) ((T_NAME_RELATIVE) reduce 244) ((T_NEW) reduce 244) ((T_NS_C) reduce 244) ((T_OBJECT_CAST) reduce 244) ((T_PRINT) reduce 244) ((T_READONLY) reduce 244) ((T_REQUIRE) reduce 244) ((T_REQUIRE_ONCE) reduce 244) ((T_RETURN) reduce 244) ((T_START_HEREDOC) reduce 244) ((T_STATIC) reduce 244) ((T_STRING) reduce 244) ((T_STRING_CAST) reduce 244) ((T_SWITCH) reduce 244) ((T_THROW) reduce 244) ((T_TRAIT) reduce 244) ((T_TRAIT_C) reduce 244) ((T_TRY) reduce 244) ((T_UNSET) reduce 244) ((T_UNSET_CAST) reduce 244) ((T_VARIABLE) reduce 244) ((T_WHILE) reduce 244) ((T_YIELD) reduce 244) ((T_YIELD_FROM) reduce 244) (("[") reduce 244) (("`") reduce 244) (("{") reduce 244) (("~") reduce 244)) 20130 ((("!") reduce 455) (("\"") reduce 455) (("$") reduce 455) (("(") reduce 455) (("+") reduce 455) (("-") reduce 455) ((";") reduce 455) (("@") reduce 455) ((T_ABSTRACT) reduce 455) ((T_ARRAY) reduce 455) ((T_ARRAY_CAST) reduce 455) ((T_ATTRIBUTE) reduce 455) ((T_BOOL_CAST) reduce 455) ((T_BREAK) reduce 455) ((T_CLASS) reduce 455) ((T_CLASS_C) reduce 455) ((T_CLONE) reduce 455) ((T_CONSTANT_ENCAPSED_STRING) reduce 455) ((T_CONTINUE) reduce 455) ((T_DEC) reduce 455) ((T_DECLARE) reduce 455) ((T_DIR) reduce 455) ((T_DNUMBER) reduce 455) ((T_DO) reduce 455) ((T_DOUBLE_CAST) reduce 455) ((T_ECHO) reduce 455) ((T_EMPTY) reduce 455) ((T_ENDDECLARE) reduce 455) ((T_ENUM) reduce 455) ((T_EVAL) reduce 455) ((T_EXIT) reduce 455) ((T_FILE) reduce 455) ((T_FINAL) reduce 455) ((T_FN) reduce 455) ((T_FOR) reduce 455) ((T_FOREACH) reduce 455) ((T_FUNCTION) reduce 455) ((T_FUNC_C) reduce 455) ((T_GLOBAL) reduce 455) ((T_GOTO) reduce 455) ((T_HALT_COMPILER) reduce 455) ((T_IF) reduce 455) ((T_INC) reduce 455) ((T_INCLUDE) reduce 455) ((T_INCLUDE_ONCE) reduce 455) ((T_INLINE_HTML) reduce 455) ((T_INTERFACE) reduce 455) ((T_INT_CAST) reduce 455) ((T_ISSET) reduce 455) ((T_LINE) reduce 455) ((T_LIST) reduce 455) ((T_LNUMBER) reduce 455) ((T_MATCH) reduce 455) ((T_METHOD_C) reduce 455) ((T_NAME_FULLY_QUALIFIED) reduce 455) ((T_NAME_QUALIFIED) reduce 455) ((T_NAME_RELATIVE) reduce 455) ((T_NEW) reduce 455) ((T_NS_C) reduce 455) ((T_OBJECT_CAST) reduce 455) ((T_PRINT) reduce 455) ((T_READONLY) reduce 455) ((T_REQUIRE) reduce 455) ((T_REQUIRE_ONCE) reduce 455) ((T_RETURN) reduce 455) ((T_START_HEREDOC) reduce 455) ((T_STATIC) reduce 455) ((T_STRING) reduce 455) ((T_STRING_CAST) reduce 455) ((T_SWITCH) reduce 455) ((T_THROW) reduce 455) ((T_TRAIT) reduce 455) ((T_TRAIT_C) reduce 455) ((T_TRY) reduce 455) ((T_UNSET) reduce 455) ((T_UNSET_CAST) reduce 455) ((T_VARIABLE) reduce 455) ((T_WHILE) reduce 455) ((T_YIELD) reduce 455) ((T_YIELD_FROM) reduce 455) (("[") reduce 455) (("`") reduce 455) (("{") reduce 455) (("~") reduce 455)) 20131 ((("!") reduce 181) (("\"") reduce 181) (("$") reduce 181) (("(") reduce 181) (("+") reduce 181) (("-") reduce 181) ((";") reduce 181) (("@") reduce 181) ((T_ABSTRACT) reduce 181) ((T_ARRAY) reduce 181) ((T_ARRAY_CAST) reduce 181) ((T_ATTRIBUTE) reduce 181) ((T_BOOL_CAST) reduce 181) ((T_BREAK) reduce 181) ((T_CLASS) reduce 181) ((T_CLASS_C) reduce 181) ((T_CLONE) reduce 181) ((T_CONSTANT_ENCAPSED_STRING) reduce 181) ((T_CONTINUE) reduce 181) ((T_DEC) reduce 181) ((T_DECLARE) reduce 181) ((T_DIR) reduce 181) ((T_DNUMBER) reduce 181) ((T_DO) reduce 181) ((T_DOUBLE_CAST) reduce 181) ((T_ECHO) reduce 181) ((T_EMPTY) reduce 181) ((T_ENDDECLARE) reduce 181) ((T_ENUM) reduce 181) ((T_EVAL) reduce 181) ((T_EXIT) reduce 181) ((T_FILE) reduce 181) ((T_FINAL) reduce 181) ((T_FN) reduce 181) ((T_FOR) reduce 181) ((T_FOREACH) reduce 181) ((T_FUNCTION) reduce 181) ((T_FUNC_C) reduce 181) ((T_GLOBAL) reduce 181) ((T_GOTO) reduce 181) ((T_HALT_COMPILER) reduce 181) ((T_IF) reduce 181) ((T_INC) reduce 181) ((T_INCLUDE) reduce 181) ((T_INCLUDE_ONCE) reduce 181) ((T_INLINE_HTML) reduce 181) ((T_INTERFACE) reduce 181) ((T_INT_CAST) reduce 181) ((T_ISSET) reduce 181) ((T_LINE) reduce 181) ((T_LIST) reduce 181) ((T_LNUMBER) reduce 181) ((T_MATCH) reduce 181) ((T_METHOD_C) reduce 181) ((T_NAME_FULLY_QUALIFIED) reduce 181) ((T_NAME_QUALIFIED) reduce 181) ((T_NAME_RELATIVE) reduce 181) ((T_NEW) reduce 181) ((T_NS_C) reduce 181) ((T_OBJECT_CAST) reduce 181) ((T_PRINT) reduce 181) ((T_READONLY) reduce 181) ((T_REQUIRE) reduce 181) ((T_REQUIRE_ONCE) reduce 181) ((T_RETURN) reduce 181) ((T_START_HEREDOC) reduce 181) ((T_STATIC) reduce 181) ((T_STRING) reduce 181) ((T_STRING_CAST) reduce 181) ((T_SWITCH) reduce 181) ((T_THROW) reduce 181) ((T_TRAIT) reduce 181) ((T_TRAIT_C) reduce 181) ((T_TRY) reduce 181) ((T_UNSET) reduce 181) ((T_UNSET_CAST) reduce 181) ((T_VARIABLE) reduce 181) ((T_WHILE) reduce 181) ((T_YIELD) reduce 181) ((T_YIELD_FROM) reduce 181) (("[") reduce 181) (("`") reduce 181) (("{") reduce 181) (("~") reduce 181)) 20132 ((("!") reduce 159) (("\"") reduce 159) (("$") reduce 159) (("(") reduce 159) (("+") reduce 159) (("-") reduce 159) ((";") reduce 159) (("@") reduce 159) ((T_ABSTRACT) reduce 159) ((T_ARRAY) reduce 159) ((T_ARRAY_CAST) reduce 159) ((T_ATTRIBUTE) reduce 159) ((T_BOOL_CAST) reduce 159) ((T_BREAK) reduce 159) ((T_CLASS) reduce 159) ((T_CLASS_C) reduce 159) ((T_CLONE) reduce 159) ((T_CONSTANT_ENCAPSED_STRING) reduce 159) ((T_CONTINUE) reduce 159) ((T_DEC) reduce 159) ((T_DECLARE) reduce 159) ((T_DIR) reduce 159) ((T_DNUMBER) reduce 159) ((T_DO) reduce 159) ((T_DOUBLE_CAST) reduce 159) ((T_ECHO) reduce 159) ((T_EMPTY) reduce 159) ((T_ENDDECLARE) reduce 159) ((T_ENUM) reduce 159) ((T_EVAL) reduce 159) ((T_EXIT) reduce 159) ((T_FILE) reduce 159) ((T_FINAL) reduce 159) ((T_FN) reduce 159) ((T_FOR) reduce 159) ((T_FOREACH) reduce 159) ((T_FUNCTION) reduce 159) ((T_FUNC_C) reduce 159) ((T_GLOBAL) reduce 159) ((T_GOTO) reduce 159) ((T_HALT_COMPILER) reduce 159) ((T_IF) reduce 159) ((T_INC) reduce 159) ((T_INCLUDE) reduce 159) ((T_INCLUDE_ONCE) reduce 159) ((T_INLINE_HTML) reduce 159) ((T_INTERFACE) reduce 159) ((T_INT_CAST) reduce 159) ((T_ISSET) reduce 159) ((T_LINE) reduce 159) ((T_LIST) reduce 159) ((T_LNUMBER) reduce 159) ((T_MATCH) reduce 159) ((T_METHOD_C) reduce 159) ((T_NAME_FULLY_QUALIFIED) reduce 159) ((T_NAME_QUALIFIED) reduce 159) ((T_NAME_RELATIVE) reduce 159) ((T_NEW) reduce 159) ((T_NS_C) reduce 159) ((T_OBJECT_CAST) reduce 159) ((T_PRINT) reduce 159) ((T_READONLY) reduce 159) ((T_REQUIRE) reduce 159) ((T_REQUIRE_ONCE) reduce 159) ((T_RETURN) reduce 159) ((T_START_HEREDOC) reduce 159) ((T_STATIC) reduce 159) ((T_STRING) reduce 159) ((T_STRING_CAST) reduce 159) ((T_SWITCH) reduce 159) ((T_THROW) reduce 159) ((T_TRAIT) reduce 159) ((T_TRAIT_C) reduce 159) ((T_TRY) reduce 159) ((T_UNSET) reduce 159) ((T_UNSET_CAST) reduce 159) ((T_VARIABLE) reduce 159) ((T_WHILE) reduce 159) ((T_YIELD) reduce 159) ((T_YIELD_FROM) reduce 159) (("[") reduce 159) (("`") reduce 159) (("{") reduce 159) (("~") reduce 159)) 20140 ((("!") reduce 186) (("\"") reduce 186) (("$") reduce 186) (("(") reduce 186) (("+") reduce 186) (("-") reduce 186) ((";") reduce 186) (("@") reduce 186) ((T_ABSTRACT) reduce 186) ((T_ARRAY) reduce 186) ((T_ARRAY_CAST) reduce 186) ((T_ATTRIBUTE) reduce 186) ((T_BOOL_CAST) reduce 186) ((T_BREAK) reduce 186) ((T_CLASS) reduce 186) ((T_CLASS_C) reduce 186) ((T_CLONE) reduce 186) ((T_CONSTANT_ENCAPSED_STRING) reduce 186) ((T_CONTINUE) reduce 186) ((T_DEC) reduce 186) ((T_DECLARE) reduce 186) ((T_DIR) reduce 186) ((T_DNUMBER) reduce 186) ((T_DO) reduce 186) ((T_DOUBLE_CAST) reduce 186) ((T_ECHO) reduce 186) ((T_EMPTY) reduce 186) ((T_ENDDECLARE) reduce 186) ((T_ENUM) reduce 186) ((T_EVAL) reduce 186) ((T_EXIT) reduce 186) ((T_FILE) reduce 186) ((T_FINAL) reduce 186) ((T_FN) reduce 186) ((T_FOR) reduce 186) ((T_FOREACH) reduce 186) ((T_FUNCTION) reduce 186) ((T_FUNC_C) reduce 186) ((T_GLOBAL) reduce 186) ((T_GOTO) reduce 186) ((T_HALT_COMPILER) reduce 186) ((T_IF) reduce 186) ((T_INC) reduce 186) ((T_INCLUDE) reduce 186) ((T_INCLUDE_ONCE) reduce 186) ((T_INLINE_HTML) reduce 186) ((T_INTERFACE) reduce 186) ((T_INT_CAST) reduce 186) ((T_ISSET) reduce 186) ((T_LINE) reduce 186) ((T_LIST) reduce 186) ((T_LNUMBER) reduce 186) ((T_MATCH) reduce 186) ((T_METHOD_C) reduce 186) ((T_NAME_FULLY_QUALIFIED) reduce 186) ((T_NAME_QUALIFIED) reduce 186) ((T_NAME_RELATIVE) reduce 186) ((T_NEW) reduce 186) ((T_NS_C) reduce 186) ((T_OBJECT_CAST) reduce 186) ((T_PRINT) reduce 186) ((T_READONLY) reduce 186) ((T_REQUIRE) reduce 186) ((T_REQUIRE_ONCE) reduce 186) ((T_RETURN) reduce 186) ((T_START_HEREDOC) reduce 186) ((T_STATIC) reduce 186) ((T_STRING) reduce 186) ((T_STRING_CAST) reduce 186) ((T_SWITCH) reduce 186) ((T_THROW) reduce 186) ((T_TRAIT) reduce 186) ((T_TRAIT_C) reduce 186) ((T_TRY) reduce 186) ((T_UNSET) reduce 186) ((T_UNSET_CAST) reduce 186) ((T_VARIABLE) reduce 186) ((T_WHILE) reduce 186) ((T_YIELD) reduce 186) ((T_YIELD_FROM) reduce 186) (("[") reduce 186) (("`") reduce 186) (("{") reduce 186) (("~") reduce 186)) 20141 ((("!") reduce 143) (("\"") reduce 143) (("$") reduce 143) (("(") reduce 143) (("+") reduce 143) (("-") reduce 143) ((";") reduce 143) (("@") reduce 143) ((T_ABSTRACT) reduce 143) ((T_ARRAY) reduce 143) ((T_ARRAY_CAST) reduce 143) ((T_ATTRIBUTE) reduce 143) ((T_BOOL_CAST) reduce 143) ((T_BREAK) reduce 143) ((T_CLASS) reduce 143) ((T_CLASS_C) reduce 143) ((T_CLONE) reduce 143) ((T_CONSTANT_ENCAPSED_STRING) reduce 143) ((T_CONTINUE) reduce 143) ((T_DEC) reduce 143) ((T_DECLARE) reduce 143) ((T_DIR) reduce 143) ((T_DNUMBER) reduce 143) ((T_DO) reduce 143) ((T_DOUBLE_CAST) reduce 143) ((T_ECHO) reduce 143) ((T_EMPTY) reduce 143) ((T_ENDDECLARE) reduce 143) ((T_ENUM) reduce 143) ((T_EVAL) reduce 143) ((T_EXIT) reduce 143) ((T_FILE) reduce 143) ((T_FINAL) reduce 143) ((T_FN) reduce 143) ((T_FOR) reduce 143) ((T_FOREACH) reduce 143) ((T_FUNCTION) reduce 143) ((T_FUNC_C) reduce 143) ((T_GLOBAL) reduce 143) ((T_GOTO) reduce 143) ((T_HALT_COMPILER) reduce 143) ((T_IF) reduce 143) ((T_INC) reduce 143) ((T_INCLUDE) reduce 143) ((T_INCLUDE_ONCE) reduce 143) ((T_INLINE_HTML) reduce 143) ((T_INTERFACE) reduce 143) ((T_INT_CAST) reduce 143) ((T_ISSET) reduce 143) ((T_LINE) reduce 143) ((T_LIST) reduce 143) ((T_LNUMBER) reduce 143) ((T_MATCH) reduce 143) ((T_METHOD_C) reduce 143) ((T_NAME_FULLY_QUALIFIED) reduce 143) ((T_NAME_QUALIFIED) reduce 143) ((T_NAME_RELATIVE) reduce 143) ((T_NEW) reduce 143) ((T_NS_C) reduce 143) ((T_OBJECT_CAST) reduce 143) ((T_PRINT) reduce 143) ((T_READONLY) reduce 143) ((T_REQUIRE) reduce 143) ((T_REQUIRE_ONCE) reduce 143) ((T_RETURN) reduce 143) ((T_START_HEREDOC) reduce 143) ((T_STATIC) reduce 143) ((T_STRING) reduce 143) ((T_STRING_CAST) reduce 143) ((T_SWITCH) reduce 143) ((T_THROW) reduce 143) ((T_TRAIT) reduce 143) ((T_TRAIT_C) reduce 143) ((T_TRY) reduce 143) ((T_UNSET) reduce 143) ((T_UNSET_CAST) reduce 143) ((T_VARIABLE) reduce 143) ((T_WHILE) reduce 143) ((T_YIELD) reduce 143) ((T_YIELD_FROM) reduce 143) (("[") reduce 143) (("`") reduce 143) (("{") reduce 143) (("~") reduce 143)) 20144 ((("!") reduce 247) (("\"") reduce 247) (("$") reduce 247) (("(") reduce 247) (("+") reduce 247) (("-") reduce 247) ((";") reduce 247) (("@") reduce 247) ((T_ABSTRACT) reduce 247) ((T_ARRAY) reduce 247) ((T_ARRAY_CAST) reduce 247) ((T_ATTRIBUTE) reduce 247) ((T_BOOL_CAST) reduce 247) ((T_BREAK) reduce 247) ((T_CLASS) reduce 247) ((T_CLASS_C) reduce 247) ((T_CLONE) reduce 247) ((T_CONSTANT_ENCAPSED_STRING) reduce 247) ((T_CONTINUE) reduce 247) ((T_DEC) reduce 247) ((T_DECLARE) reduce 247) ((T_DIR) reduce 247) ((T_DNUMBER) reduce 247) ((T_DO) reduce 247) ((T_DOUBLE_CAST) reduce 247) ((T_ECHO) reduce 247) ((T_EMPTY) reduce 247) ((T_ENDDECLARE) reduce 247) ((T_ENUM) reduce 247) ((T_EVAL) reduce 247) ((T_EXIT) reduce 247) ((T_FILE) reduce 247) ((T_FINAL) reduce 247) ((T_FN) reduce 247) ((T_FOR) reduce 247) ((T_FOREACH) reduce 247) ((T_FUNCTION) reduce 247) ((T_FUNC_C) reduce 247) ((T_GLOBAL) reduce 247) ((T_GOTO) reduce 247) ((T_HALT_COMPILER) reduce 247) ((T_IF) reduce 247) ((T_INC) reduce 247) ((T_INCLUDE) reduce 247) ((T_INCLUDE_ONCE) reduce 247) ((T_INLINE_HTML) reduce 247) ((T_INTERFACE) reduce 247) ((T_INT_CAST) reduce 247) ((T_ISSET) reduce 247) ((T_LINE) reduce 247) ((T_LIST) reduce 247) ((T_LNUMBER) reduce 247) ((T_MATCH) reduce 247) ((T_METHOD_C) reduce 247) ((T_NAME_FULLY_QUALIFIED) reduce 247) ((T_NAME_QUALIFIED) reduce 247) ((T_NAME_RELATIVE) reduce 247) ((T_NEW) reduce 247) ((T_NS_C) reduce 247) ((T_OBJECT_CAST) reduce 247) ((T_PRINT) reduce 247) ((T_READONLY) reduce 247) ((T_REQUIRE) reduce 247) ((T_REQUIRE_ONCE) reduce 247) ((T_RETURN) reduce 247) ((T_START_HEREDOC) reduce 247) ((T_STATIC) reduce 247) ((T_STRING) reduce 247) ((T_STRING_CAST) reduce 247) ((T_SWITCH) reduce 247) ((T_THROW) reduce 247) ((T_TRAIT) reduce 247) ((T_TRAIT_C) reduce 247) ((T_TRY) reduce 247) ((T_UNSET) reduce 247) ((T_UNSET_CAST) reduce 247) ((T_VARIABLE) reduce 247) ((T_WHILE) reduce 247) ((T_YIELD) reduce 247) ((T_YIELD_FROM) reduce 247) (("[") reduce 247) (("`") reduce 247) (("{") reduce 247) (("~") reduce 247)) 20148 ((("!") reduce 248) (("\"") reduce 248) (("$") reduce 248) (("(") reduce 248) (("+") reduce 248) (("-") reduce 248) ((";") reduce 248) (("@") reduce 248) ((T_ABSTRACT) reduce 248) ((T_ARRAY) reduce 248) ((T_ARRAY_CAST) reduce 248) ((T_ATTRIBUTE) reduce 248) ((T_BOOL_CAST) reduce 248) ((T_BREAK) reduce 248) ((T_CLASS) reduce 248) ((T_CLASS_C) reduce 248) ((T_CLONE) reduce 248) ((T_CONSTANT_ENCAPSED_STRING) reduce 248) ((T_CONTINUE) reduce 248) ((T_DEC) reduce 248) ((T_DECLARE) reduce 248) ((T_DIR) reduce 248) ((T_DNUMBER) reduce 248) ((T_DO) reduce 248) ((T_DOUBLE_CAST) reduce 248) ((T_ECHO) reduce 248) ((T_EMPTY) reduce 248) ((T_ENDDECLARE) reduce 248) ((T_ENUM) reduce 248) ((T_EVAL) reduce 248) ((T_EXIT) reduce 248) ((T_FILE) reduce 248) ((T_FINAL) reduce 248) ((T_FN) reduce 248) ((T_FOR) reduce 248) ((T_FOREACH) reduce 248) ((T_FUNCTION) reduce 248) ((T_FUNC_C) reduce 248) ((T_GLOBAL) reduce 248) ((T_GOTO) reduce 248) ((T_HALT_COMPILER) reduce 248) ((T_IF) reduce 248) ((T_INC) reduce 248) ((T_INCLUDE) reduce 248) ((T_INCLUDE_ONCE) reduce 248) ((T_INLINE_HTML) reduce 248) ((T_INTERFACE) reduce 248) ((T_INT_CAST) reduce 248) ((T_ISSET) reduce 248) ((T_LINE) reduce 248) ((T_LIST) reduce 248) ((T_LNUMBER) reduce 248) ((T_MATCH) reduce 248) ((T_METHOD_C) reduce 248) ((T_NAME_FULLY_QUALIFIED) reduce 248) ((T_NAME_QUALIFIED) reduce 248) ((T_NAME_RELATIVE) reduce 248) ((T_NEW) reduce 248) ((T_NS_C) reduce 248) ((T_OBJECT_CAST) reduce 248) ((T_PRINT) reduce 248) ((T_READONLY) reduce 248) ((T_REQUIRE) reduce 248) ((T_REQUIRE_ONCE) reduce 248) ((T_RETURN) reduce 248) ((T_START_HEREDOC) reduce 248) ((T_STATIC) reduce 248) ((T_STRING) reduce 248) ((T_STRING_CAST) reduce 248) ((T_SWITCH) reduce 248) ((T_THROW) reduce 248) ((T_TRAIT) reduce 248) ((T_TRAIT_C) reduce 248) ((T_TRY) reduce 248) ((T_UNSET) reduce 248) ((T_UNSET_CAST) reduce 248) ((T_VARIABLE) reduce 248) ((T_WHILE) reduce 248) ((T_YIELD) reduce 248) ((T_YIELD_FROM) reduce 248) (("[") reduce 248) (("`") reduce 248) (("{") reduce 248) (("~") reduce 248)) 20153 ((("!") reduce 239) (("\"") reduce 239) (("$") reduce 239) (("(") reduce 239) (("+") reduce 239) (("-") reduce 239) ((";") reduce 239) (("@") reduce 239) ((T_ABSTRACT) reduce 239) ((T_ARRAY) reduce 239) ((T_ARRAY_CAST) reduce 239) ((T_ATTRIBUTE) reduce 239) ((T_BOOL_CAST) reduce 239) ((T_BREAK) reduce 239) ((T_CLASS) reduce 239) ((T_CLASS_C) reduce 239) ((T_CLONE) reduce 239) ((T_CONSTANT_ENCAPSED_STRING) reduce 239) ((T_CONTINUE) reduce 239) ((T_DEC) reduce 239) ((T_DECLARE) reduce 239) ((T_DIR) reduce 239) ((T_DNUMBER) reduce 239) ((T_DO) reduce 239) ((T_DOUBLE_CAST) reduce 239) ((T_ECHO) reduce 239) ((T_EMPTY) reduce 239) ((T_ENDDECLARE) reduce 239) ((T_ENUM) reduce 239) ((T_EVAL) reduce 239) ((T_EXIT) reduce 239) ((T_FILE) reduce 239) ((T_FINAL) reduce 239) ((T_FN) reduce 239) ((T_FOR) reduce 239) ((T_FOREACH) reduce 239) ((T_FUNCTION) reduce 239) ((T_FUNC_C) reduce 239) ((T_GLOBAL) reduce 239) ((T_GOTO) reduce 239) ((T_HALT_COMPILER) reduce 239) ((T_IF) reduce 239) ((T_INC) reduce 239) ((T_INCLUDE) reduce 239) ((T_INCLUDE_ONCE) reduce 239) ((T_INLINE_HTML) reduce 239) ((T_INTERFACE) reduce 239) ((T_INT_CAST) reduce 239) ((T_ISSET) reduce 239) ((T_LINE) reduce 239) ((T_LIST) reduce 239) ((T_LNUMBER) reduce 239) ((T_MATCH) reduce 239) ((T_METHOD_C) reduce 239) ((T_NAME_FULLY_QUALIFIED) reduce 239) ((T_NAME_QUALIFIED) reduce 239) ((T_NAME_RELATIVE) reduce 239) ((T_NEW) reduce 239) ((T_NS_C) reduce 239) ((T_OBJECT_CAST) reduce 239) ((T_PRINT) reduce 239) ((T_READONLY) reduce 239) ((T_REQUIRE) reduce 239) ((T_REQUIRE_ONCE) reduce 239) ((T_RETURN) reduce 239) ((T_START_HEREDOC) reduce 239) ((T_STATIC) reduce 239) ((T_STRING) reduce 239) ((T_STRING_CAST) reduce 239) ((T_SWITCH) reduce 239) ((T_THROW) reduce 239) ((T_TRAIT) reduce 239) ((T_TRAIT_C) reduce 239) ((T_TRY) reduce 239) ((T_UNSET) reduce 239) ((T_UNSET_CAST) reduce 239) ((T_VARIABLE) reduce 239) ((T_WHILE) reduce 239) ((T_YIELD) reduce 239) ((T_YIELD_FROM) reduce 239) (("[") reduce 239) (("`") reduce 239) (("{") reduce 239) (("~") reduce 239)) 20154 ((("!") reduce 148) (("\"") reduce 148) (("$") reduce 148) (("(") reduce 148) (("+") reduce 148) (("-") reduce 148) ((";") reduce 148) (("@") reduce 148) ((T_ABSTRACT) reduce 148) ((T_ARRAY) reduce 148) ((T_ARRAY_CAST) reduce 148) ((T_ATTRIBUTE) reduce 148) ((T_BOOL_CAST) reduce 148) ((T_BREAK) reduce 148) ((T_CLASS) reduce 148) ((T_CLASS_C) reduce 148) ((T_CLONE) reduce 148) ((T_CONSTANT_ENCAPSED_STRING) reduce 148) ((T_CONTINUE) reduce 148) ((T_DEC) reduce 148) ((T_DECLARE) reduce 148) ((T_DIR) reduce 148) ((T_DNUMBER) reduce 148) ((T_DO) reduce 148) ((T_DOUBLE_CAST) reduce 148) ((T_ECHO) reduce 148) ((T_EMPTY) reduce 148) ((T_ENDDECLARE) reduce 148) ((T_ENUM) reduce 148) ((T_EVAL) reduce 148) ((T_EXIT) reduce 148) ((T_FILE) reduce 148) ((T_FINAL) reduce 148) ((T_FN) reduce 148) ((T_FOR) reduce 148) ((T_FOREACH) reduce 148) ((T_FUNCTION) reduce 148) ((T_FUNC_C) reduce 148) ((T_GLOBAL) reduce 148) ((T_GOTO) reduce 148) ((T_HALT_COMPILER) reduce 148) ((T_IF) reduce 148) ((T_INC) reduce 148) ((T_INCLUDE) reduce 148) ((T_INCLUDE_ONCE) reduce 148) ((T_INLINE_HTML) reduce 148) ((T_INTERFACE) reduce 148) ((T_INT_CAST) reduce 148) ((T_ISSET) reduce 148) ((T_LINE) reduce 148) ((T_LIST) reduce 148) ((T_LNUMBER) reduce 148) ((T_MATCH) reduce 148) ((T_METHOD_C) reduce 148) ((T_NAME_FULLY_QUALIFIED) reduce 148) ((T_NAME_QUALIFIED) reduce 148) ((T_NAME_RELATIVE) reduce 148) ((T_NEW) reduce 148) ((T_NS_C) reduce 148) ((T_OBJECT_CAST) reduce 148) ((T_PRINT) reduce 148) ((T_READONLY) reduce 148) ((T_REQUIRE) reduce 148) ((T_REQUIRE_ONCE) reduce 148) ((T_RETURN) reduce 148) ((T_START_HEREDOC) reduce 148) ((T_STATIC) reduce 148) ((T_STRING) reduce 148) ((T_STRING_CAST) reduce 148) ((T_SWITCH) reduce 148) ((T_THROW) reduce 148) ((T_TRAIT) reduce 148) ((T_TRAIT_C) reduce 148) ((T_TRY) reduce 148) ((T_UNSET) reduce 148) ((T_UNSET_CAST) reduce 148) ((T_VARIABLE) reduce 148) ((T_WHILE) reduce 148) ((T_YIELD) reduce 148) ((T_YIELD_FROM) reduce 148) (("[") reduce 148) (("`") reduce 148) (("{") reduce 148) (("~") reduce 148)) 20157 ((("!") reduce 240) (("\"") reduce 240) (("$") reduce 240) (("(") reduce 240) (("+") reduce 240) (("-") reduce 240) ((";") reduce 240) (("@") reduce 240) ((T_ABSTRACT) reduce 240) ((T_ARRAY) reduce 240) ((T_ARRAY_CAST) reduce 240) ((T_ATTRIBUTE) reduce 240) ((T_BOOL_CAST) reduce 240) ((T_BREAK) reduce 240) ((T_CLASS) reduce 240) ((T_CLASS_C) reduce 240) ((T_CLONE) reduce 240) ((T_CONSTANT_ENCAPSED_STRING) reduce 240) ((T_CONTINUE) reduce 240) ((T_DEC) reduce 240) ((T_DECLARE) reduce 240) ((T_DIR) reduce 240) ((T_DNUMBER) reduce 240) ((T_DO) reduce 240) ((T_DOUBLE_CAST) reduce 240) ((T_ECHO) reduce 240) ((T_EMPTY) reduce 240) ((T_ENDDECLARE) reduce 240) ((T_ENUM) reduce 240) ((T_EVAL) reduce 240) ((T_EXIT) reduce 240) ((T_FILE) reduce 240) ((T_FINAL) reduce 240) ((T_FN) reduce 240) ((T_FOR) reduce 240) ((T_FOREACH) reduce 240) ((T_FUNCTION) reduce 240) ((T_FUNC_C) reduce 240) ((T_GLOBAL) reduce 240) ((T_GOTO) reduce 240) ((T_HALT_COMPILER) reduce 240) ((T_IF) reduce 240) ((T_INC) reduce 240) ((T_INCLUDE) reduce 240) ((T_INCLUDE_ONCE) reduce 240) ((T_INLINE_HTML) reduce 240) ((T_INTERFACE) reduce 240) ((T_INT_CAST) reduce 240) ((T_ISSET) reduce 240) ((T_LINE) reduce 240) ((T_LIST) reduce 240) ((T_LNUMBER) reduce 240) ((T_MATCH) reduce 240) ((T_METHOD_C) reduce 240) ((T_NAME_FULLY_QUALIFIED) reduce 240) ((T_NAME_QUALIFIED) reduce 240) ((T_NAME_RELATIVE) reduce 240) ((T_NEW) reduce 240) ((T_NS_C) reduce 240) ((T_OBJECT_CAST) reduce 240) ((T_PRINT) reduce 240) ((T_READONLY) reduce 240) ((T_REQUIRE) reduce 240) ((T_REQUIRE_ONCE) reduce 240) ((T_RETURN) reduce 240) ((T_START_HEREDOC) reduce 240) ((T_STATIC) reduce 240) ((T_STRING) reduce 240) ((T_STRING_CAST) reduce 240) ((T_SWITCH) reduce 240) ((T_THROW) reduce 240) ((T_TRAIT) reduce 240) ((T_TRAIT_C) reduce 240) ((T_TRY) reduce 240) ((T_UNSET) reduce 240) ((T_UNSET_CAST) reduce 240) ((T_VARIABLE) reduce 240) ((T_WHILE) reduce 240) ((T_YIELD) reduce 240) ((T_YIELD_FROM) reduce 240) (("[") reduce 240) (("`") reduce 240) (("{") reduce 240) (("~") reduce 240)) 20162 ((("!") reduce 160) (("\"") reduce 160) (("$") reduce 160) (("(") reduce 160) (("+") reduce 160) (("-") reduce 160) ((";") reduce 160) (("@") reduce 160) ((T_ABSTRACT) reduce 160) ((T_ARRAY) reduce 160) ((T_ARRAY_CAST) reduce 160) ((T_ATTRIBUTE) reduce 160) ((T_BOOL_CAST) reduce 160) ((T_BREAK) reduce 160) ((T_CLASS) reduce 160) ((T_CLASS_C) reduce 160) ((T_CLONE) reduce 160) ((T_CONSTANT_ENCAPSED_STRING) reduce 160) ((T_CONTINUE) reduce 160) ((T_DEC) reduce 160) ((T_DECLARE) reduce 160) ((T_DIR) reduce 160) ((T_DNUMBER) reduce 160) ((T_DO) reduce 160) ((T_DOUBLE_CAST) reduce 160) ((T_ECHO) reduce 160) ((T_EMPTY) reduce 160) ((T_ENDDECLARE) reduce 160) ((T_ENUM) reduce 160) ((T_EVAL) reduce 160) ((T_EXIT) reduce 160) ((T_FILE) reduce 160) ((T_FINAL) reduce 160) ((T_FN) reduce 160) ((T_FOR) reduce 160) ((T_FOREACH) reduce 160) ((T_FUNCTION) reduce 160) ((T_FUNC_C) reduce 160) ((T_GLOBAL) reduce 160) ((T_GOTO) reduce 160) ((T_HALT_COMPILER) reduce 160) ((T_IF) reduce 160) ((T_INC) reduce 160) ((T_INCLUDE) reduce 160) ((T_INCLUDE_ONCE) reduce 160) ((T_INLINE_HTML) reduce 160) ((T_INTERFACE) reduce 160) ((T_INT_CAST) reduce 160) ((T_ISSET) reduce 160) ((T_LINE) reduce 160) ((T_LIST) reduce 160) ((T_LNUMBER) reduce 160) ((T_MATCH) reduce 160) ((T_METHOD_C) reduce 160) ((T_NAME_FULLY_QUALIFIED) reduce 160) ((T_NAME_QUALIFIED) reduce 160) ((T_NAME_RELATIVE) reduce 160) ((T_NEW) reduce 160) ((T_NS_C) reduce 160) ((T_OBJECT_CAST) reduce 160) ((T_PRINT) reduce 160) ((T_READONLY) reduce 160) ((T_REQUIRE) reduce 160) ((T_REQUIRE_ONCE) reduce 160) ((T_RETURN) reduce 160) ((T_START_HEREDOC) reduce 160) ((T_STATIC) reduce 160) ((T_STRING) reduce 160) ((T_STRING_CAST) reduce 160) ((T_SWITCH) reduce 160) ((T_THROW) reduce 160) ((T_TRAIT) reduce 160) ((T_TRAIT_C) reduce 160) ((T_TRY) reduce 160) ((T_UNSET) reduce 160) ((T_UNSET_CAST) reduce 160) ((T_VARIABLE) reduce 160) ((T_WHILE) reduce 160) ((T_YIELD) reduce 160) ((T_YIELD_FROM) reduce 160) (("[") reduce 160) (("`") reduce 160) (("{") reduce 160) (("~") reduce 160)) 20165 ((("!") reduce 168) (("\"") reduce 168) (("$") reduce 168) (("(") reduce 168) (("+") reduce 168) (("-") reduce 168) ((";") reduce 168) (("@") reduce 168) ((T_ABSTRACT) reduce 168) ((T_ARRAY) reduce 168) ((T_ARRAY_CAST) reduce 168) ((T_ATTRIBUTE) reduce 168) ((T_BOOL_CAST) reduce 168) ((T_BREAK) reduce 168) ((T_CATCH) reduce 168) ((T_CLASS) reduce 168) ((T_CLASS_C) reduce 168) ((T_CLONE) reduce 168) ((T_CONSTANT_ENCAPSED_STRING) reduce 168) ((T_CONTINUE) reduce 168) ((T_DEC) reduce 168) ((T_DECLARE) reduce 168) ((T_DIR) reduce 168) ((T_DNUMBER) reduce 168) ((T_DO) reduce 168) ((T_DOUBLE_CAST) reduce 168) ((T_ECHO) reduce 168) ((T_EMPTY) reduce 168) ((T_ENDDECLARE) reduce 168) ((T_ENUM) reduce 168) ((T_EVAL) reduce 168) ((T_EXIT) reduce 168) ((T_FILE) reduce 168) ((T_FINAL) reduce 168) ((T_FINALLY) reduce 168) ((T_FN) reduce 168) ((T_FOR) reduce 168) ((T_FOREACH) reduce 168) ((T_FUNCTION) reduce 168) ((T_FUNC_C) reduce 168) ((T_GLOBAL) reduce 168) ((T_GOTO) reduce 168) ((T_HALT_COMPILER) reduce 168) ((T_IF) reduce 168) ((T_INC) reduce 168) ((T_INCLUDE) reduce 168) ((T_INCLUDE_ONCE) reduce 168) ((T_INLINE_HTML) reduce 168) ((T_INTERFACE) reduce 168) ((T_INT_CAST) reduce 168) ((T_ISSET) reduce 168) ((T_LINE) reduce 168) ((T_LIST) reduce 168) ((T_LNUMBER) reduce 168) ((T_MATCH) reduce 168) ((T_METHOD_C) reduce 168) ((T_NAME_FULLY_QUALIFIED) reduce 168) ((T_NAME_QUALIFIED) reduce 168) ((T_NAME_RELATIVE) reduce 168) ((T_NEW) reduce 168) ((T_NS_C) reduce 168) ((T_OBJECT_CAST) reduce 168) ((T_PRINT) reduce 168) ((T_READONLY) reduce 168) ((T_REQUIRE) reduce 168) ((T_REQUIRE_ONCE) reduce 168) ((T_RETURN) reduce 168) ((T_START_HEREDOC) reduce 168) ((T_STATIC) reduce 168) ((T_STRING) reduce 168) ((T_STRING_CAST) reduce 168) ((T_SWITCH) reduce 168) ((T_THROW) reduce 168) ((T_TRAIT) reduce 168) ((T_TRAIT_C) reduce 168) ((T_TRY) reduce 168) ((T_UNSET) reduce 168) ((T_UNSET_CAST) reduce 168) ((T_VARIABLE) reduce 168) ((T_WHILE) reduce 168) ((T_YIELD) reduce 168) ((T_YIELD_FROM) reduce 168) (("[") reduce 168) (("`") reduce 168) (("{") reduce 168) (("~") reduce 168)) 20166 ((("!") reduce 174) (("\"") reduce 174) (("$") reduce 174) (("(") reduce 174) (("+") reduce 174) (("-") reduce 174) ((";") reduce 174) (("@") reduce 174) ((T_ABSTRACT) reduce 174) ((T_ARRAY) reduce 174) ((T_ARRAY_CAST) reduce 174) ((T_ATTRIBUTE) reduce 174) ((T_BOOL_CAST) reduce 174) ((T_BREAK) reduce 174) ((T_CATCH) shift) ((T_CLASS) reduce 174) ((T_CLASS_C) reduce 174) ((T_CLONE) reduce 174) ((T_CONSTANT_ENCAPSED_STRING) reduce 174) ((T_CONTINUE) reduce 174) ((T_DEC) reduce 174) ((T_DECLARE) reduce 174) ((T_DIR) reduce 174) ((T_DNUMBER) reduce 174) ((T_DO) reduce 174) ((T_DOUBLE_CAST) reduce 174) ((T_ECHO) reduce 174) ((T_EMPTY) reduce 174) ((T_ENDDECLARE) reduce 174) ((T_ENUM) reduce 174) ((T_EVAL) reduce 174) ((T_EXIT) reduce 174) ((T_FILE) reduce 174) ((T_FINAL) reduce 174) ((T_FINALLY) shift) ((T_FN) reduce 174) ((T_FOR) reduce 174) ((T_FOREACH) reduce 174) ((T_FUNCTION) reduce 174) ((T_FUNC_C) reduce 174) ((T_GLOBAL) reduce 174) ((T_GOTO) reduce 174) ((T_HALT_COMPILER) reduce 174) ((T_IF) reduce 174) ((T_INC) reduce 174) ((T_INCLUDE) reduce 174) ((T_INCLUDE_ONCE) reduce 174) ((T_INLINE_HTML) reduce 174) ((T_INTERFACE) reduce 174) ((T_INT_CAST) reduce 174) ((T_ISSET) reduce 174) ((T_LINE) reduce 174) ((T_LIST) reduce 174) ((T_LNUMBER) reduce 174) ((T_MATCH) reduce 174) ((T_METHOD_C) reduce 174) ((T_NAME_FULLY_QUALIFIED) reduce 174) ((T_NAME_QUALIFIED) reduce 174) ((T_NAME_RELATIVE) reduce 174) ((T_NEW) reduce 174) ((T_NS_C) reduce 174) ((T_OBJECT_CAST) reduce 174) ((T_PRINT) reduce 174) ((T_READONLY) reduce 174) ((T_REQUIRE) reduce 174) ((T_REQUIRE_ONCE) reduce 174) ((T_RETURN) reduce 174) ((T_START_HEREDOC) reduce 174) ((T_STATIC) reduce 174) ((T_STRING) reduce 174) ((T_STRING_CAST) reduce 174) ((T_SWITCH) reduce 174) ((T_THROW) reduce 174) ((T_TRAIT) reduce 174) ((T_TRAIT_C) reduce 174) ((T_TRY) reduce 174) ((T_UNSET) reduce 174) ((T_UNSET_CAST) reduce 174) ((T_VARIABLE) reduce 174) ((T_WHILE) reduce 174) ((T_YIELD) reduce 174) ((T_YIELD_FROM) reduce 174) (("[") reduce 174) (("`") reduce 174) (("{") reduce 174) (("~") reduce 174)) 20169 ((("!") reduce 165) (("\"") reduce 165) (("$") reduce 165) (("(") reduce 165) (("+") reduce 165) (("-") reduce 165) ((";") reduce 165) (("@") reduce 165) ((T_ABSTRACT) reduce 165) ((T_ARRAY) reduce 165) ((T_ARRAY_CAST) reduce 165) ((T_ATTRIBUTE) reduce 165) ((T_BOOL_CAST) reduce 165) ((T_BREAK) reduce 165) ((T_CLASS) reduce 165) ((T_CLASS_C) reduce 165) ((T_CLONE) reduce 165) ((T_CONSTANT_ENCAPSED_STRING) reduce 165) ((T_CONTINUE) reduce 165) ((T_DEC) reduce 165) ((T_DECLARE) reduce 165) ((T_DIR) reduce 165) ((T_DNUMBER) reduce 165) ((T_DO) reduce 165) ((T_DOUBLE_CAST) reduce 165) ((T_ECHO) reduce 165) ((T_EMPTY) reduce 165) ((T_ENDDECLARE) reduce 165) ((T_ENUM) reduce 165) ((T_EVAL) reduce 165) ((T_EXIT) reduce 165) ((T_FILE) reduce 165) ((T_FINAL) reduce 165) ((T_FN) reduce 165) ((T_FOR) reduce 165) ((T_FOREACH) reduce 165) ((T_FUNCTION) reduce 165) ((T_FUNC_C) reduce 165) ((T_GLOBAL) reduce 165) ((T_GOTO) reduce 165) ((T_HALT_COMPILER) reduce 165) ((T_IF) reduce 165) ((T_INC) reduce 165) ((T_INCLUDE) reduce 165) ((T_INCLUDE_ONCE) reduce 165) ((T_INLINE_HTML) reduce 165) ((T_INTERFACE) reduce 165) ((T_INT_CAST) reduce 165) ((T_ISSET) reduce 165) ((T_LINE) reduce 165) ((T_LIST) reduce 165) ((T_LNUMBER) reduce 165) ((T_MATCH) reduce 165) ((T_METHOD_C) reduce 165) ((T_NAME_FULLY_QUALIFIED) reduce 165) ((T_NAME_QUALIFIED) reduce 165) ((T_NAME_RELATIVE) reduce 165) ((T_NEW) reduce 165) ((T_NS_C) reduce 165) ((T_OBJECT_CAST) reduce 165) ((T_PRINT) reduce 165) ((T_READONLY) reduce 165) ((T_REQUIRE) reduce 165) ((T_REQUIRE_ONCE) reduce 165) ((T_RETURN) reduce 165) ((T_START_HEREDOC) reduce 165) ((T_STATIC) reduce 165) ((T_STRING) reduce 165) ((T_STRING_CAST) reduce 165) ((T_SWITCH) reduce 165) ((T_THROW) reduce 165) ((T_TRAIT) reduce 165) ((T_TRAIT_C) reduce 165) ((T_TRY) reduce 165) ((T_UNSET) reduce 165) ((T_UNSET_CAST) reduce 165) ((T_VARIABLE) reduce 165) ((T_WHILE) reduce 165) ((T_YIELD) reduce 165) ((T_YIELD_FROM) reduce 165) (("[") reduce 165) (("`") reduce 165) (("{") reduce 165) (("~") reduce 165)) 20172 ((("!") reduce 175) (("\"") reduce 175) (("$") reduce 175) (("(") reduce 175) (("+") reduce 175) (("-") reduce 175) ((";") reduce 175) (("@") reduce 175) ((T_ABSTRACT) reduce 175) ((T_ARRAY) reduce 175) ((T_ARRAY_CAST) reduce 175) ((T_ATTRIBUTE) reduce 175) ((T_BOOL_CAST) reduce 175) ((T_BREAK) reduce 175) ((T_CLASS) reduce 175) ((T_CLASS_C) reduce 175) ((T_CLONE) reduce 175) ((T_CONSTANT_ENCAPSED_STRING) reduce 175) ((T_CONTINUE) reduce 175) ((T_DEC) reduce 175) ((T_DECLARE) reduce 175) ((T_DIR) reduce 175) ((T_DNUMBER) reduce 175) ((T_DO) reduce 175) ((T_DOUBLE_CAST) reduce 175) ((T_ECHO) reduce 175) ((T_EMPTY) reduce 175) ((T_ENDDECLARE) reduce 175) ((T_ENUM) reduce 175) ((T_EVAL) reduce 175) ((T_EXIT) reduce 175) ((T_FILE) reduce 175) ((T_FINAL) reduce 175) ((T_FN) reduce 175) ((T_FOR) reduce 175) ((T_FOREACH) reduce 175) ((T_FUNCTION) reduce 175) ((T_FUNC_C) reduce 175) ((T_GLOBAL) reduce 175) ((T_GOTO) reduce 175) ((T_HALT_COMPILER) reduce 175) ((T_IF) reduce 175) ((T_INC) reduce 175) ((T_INCLUDE) reduce 175) ((T_INCLUDE_ONCE) reduce 175) ((T_INLINE_HTML) reduce 175) ((T_INTERFACE) reduce 175) ((T_INT_CAST) reduce 175) ((T_ISSET) reduce 175) ((T_LINE) reduce 175) ((T_LIST) reduce 175) ((T_LNUMBER) reduce 175) ((T_MATCH) reduce 175) ((T_METHOD_C) reduce 175) ((T_NAME_FULLY_QUALIFIED) reduce 175) ((T_NAME_QUALIFIED) reduce 175) ((T_NAME_RELATIVE) reduce 175) ((T_NEW) reduce 175) ((T_NS_C) reduce 175) ((T_OBJECT_CAST) reduce 175) ((T_PRINT) reduce 175) ((T_READONLY) reduce 175) ((T_REQUIRE) reduce 175) ((T_REQUIRE_ONCE) reduce 175) ((T_RETURN) reduce 175) ((T_START_HEREDOC) reduce 175) ((T_STATIC) reduce 175) ((T_STRING) reduce 175) ((T_STRING_CAST) reduce 175) ((T_SWITCH) reduce 175) ((T_THROW) reduce 175) ((T_TRAIT) reduce 175) ((T_TRAIT_C) reduce 175) ((T_TRY) reduce 175) ((T_UNSET) reduce 175) ((T_UNSET_CAST) reduce 175) ((T_VARIABLE) reduce 175) ((T_WHILE) reduce 175) ((T_YIELD) reduce 175) ((T_YIELD_FROM) reduce 175) (("[") reduce 175) (("`") reduce 175) (("{") reduce 175) (("~") reduce 175)) 20179 ((("!") reduce 169) (("\"") reduce 169) (("$") reduce 169) (("(") reduce 169) (("+") reduce 169) (("-") reduce 169) ((";") reduce 169) (("@") reduce 169) ((T_ABSTRACT) reduce 169) ((T_ARRAY) reduce 169) ((T_ARRAY_CAST) reduce 169) ((T_ATTRIBUTE) reduce 169) ((T_BOOL_CAST) reduce 169) ((T_BREAK) reduce 169) ((T_CATCH) reduce 169) ((T_CLASS) reduce 169) ((T_CLASS_C) reduce 169) ((T_CLONE) reduce 169) ((T_CONSTANT_ENCAPSED_STRING) reduce 169) ((T_CONTINUE) reduce 169) ((T_DEC) reduce 169) ((T_DECLARE) reduce 169) ((T_DIR) reduce 169) ((T_DNUMBER) reduce 169) ((T_DO) reduce 169) ((T_DOUBLE_CAST) reduce 169) ((T_ECHO) reduce 169) ((T_EMPTY) reduce 169) ((T_ENDDECLARE) reduce 169) ((T_ENUM) reduce 169) ((T_EVAL) reduce 169) ((T_EXIT) reduce 169) ((T_FILE) reduce 169) ((T_FINAL) reduce 169) ((T_FINALLY) reduce 169) ((T_FN) reduce 169) ((T_FOR) reduce 169) ((T_FOREACH) reduce 169) ((T_FUNCTION) reduce 169) ((T_FUNC_C) reduce 169) ((T_GLOBAL) reduce 169) ((T_GOTO) reduce 169) ((T_HALT_COMPILER) reduce 169) ((T_IF) reduce 169) ((T_INC) reduce 169) ((T_INCLUDE) reduce 169) ((T_INCLUDE_ONCE) reduce 169) ((T_INLINE_HTML) reduce 169) ((T_INTERFACE) reduce 169) ((T_INT_CAST) reduce 169) ((T_ISSET) reduce 169) ((T_LINE) reduce 169) ((T_LIST) reduce 169) ((T_LNUMBER) reduce 169) ((T_MATCH) reduce 169) ((T_METHOD_C) reduce 169) ((T_NAME_FULLY_QUALIFIED) reduce 169) ((T_NAME_QUALIFIED) reduce 169) ((T_NAME_RELATIVE) reduce 169) ((T_NEW) reduce 169) ((T_NS_C) reduce 169) ((T_OBJECT_CAST) reduce 169) ((T_PRINT) reduce 169) ((T_READONLY) reduce 169) ((T_REQUIRE) reduce 169) ((T_REQUIRE_ONCE) reduce 169) ((T_RETURN) reduce 169) ((T_START_HEREDOC) reduce 169) ((T_STATIC) reduce 169) ((T_STRING) reduce 169) ((T_STRING_CAST) reduce 169) ((T_SWITCH) reduce 169) ((T_THROW) reduce 169) ((T_TRAIT) reduce 169) ((T_TRAIT_C) reduce 169) ((T_TRY) reduce 169) ((T_UNSET) reduce 169) ((T_UNSET_CAST) reduce 169) ((T_VARIABLE) reduce 169) ((T_WHILE) reduce 169) ((T_YIELD) reduce 169) ((T_YIELD_FROM) reduce 169) (("[") reduce 169) (("`") reduce 169) (("{") reduce 169) (("~") reduce 169)) 20184 ((("!") reduce 197) (("\"") reduce 197) (("$") reduce 197) (("(") reduce 197) (("+") reduce 197) (("-") reduce 197) ((";") reduce 197) (("@") reduce 197) ((T_ABSTRACT) reduce 197) ((T_ARRAY) reduce 197) ((T_ARRAY_CAST) reduce 197) ((T_ATTRIBUTE) reduce 197) ((T_BOOL_CAST) reduce 197) ((T_BREAK) reduce 197) ((T_CLASS) reduce 197) ((T_CLASS_C) reduce 197) ((T_CLONE) reduce 197) ((T_CONSTANT_ENCAPSED_STRING) reduce 197) ((T_CONTINUE) reduce 197) ((T_DEC) reduce 197) ((T_DECLARE) reduce 197) ((T_DIR) reduce 197) ((T_DNUMBER) reduce 197) ((T_DO) reduce 197) ((T_DOUBLE_CAST) reduce 197) ((T_ECHO) reduce 197) ((T_EMPTY) reduce 197) ((T_ENDDECLARE) reduce 197) ((T_ENUM) reduce 197) ((T_EVAL) reduce 197) ((T_EXIT) reduce 197) ((T_FILE) reduce 197) ((T_FINAL) reduce 197) ((T_FN) reduce 197) ((T_FOR) reduce 197) ((T_FOREACH) reduce 197) ((T_FUNCTION) reduce 197) ((T_FUNC_C) reduce 197) ((T_GLOBAL) reduce 197) ((T_GOTO) reduce 197) ((T_HALT_COMPILER) reduce 197) ((T_IF) reduce 197) ((T_INC) reduce 197) ((T_INCLUDE) reduce 197) ((T_INCLUDE_ONCE) reduce 197) ((T_INLINE_HTML) reduce 197) ((T_INTERFACE) reduce 197) ((T_INT_CAST) reduce 197) ((T_ISSET) reduce 197) ((T_LINE) reduce 197) ((T_LIST) reduce 197) ((T_LNUMBER) reduce 197) ((T_MATCH) reduce 197) ((T_METHOD_C) reduce 197) ((T_NAME_FULLY_QUALIFIED) reduce 197) ((T_NAME_QUALIFIED) reduce 197) ((T_NAME_RELATIVE) reduce 197) ((T_NEW) reduce 197) ((T_NS_C) reduce 197) ((T_OBJECT_CAST) reduce 197) ((T_PRINT) reduce 197) ((T_READONLY) reduce 197) ((T_REQUIRE) reduce 197) ((T_REQUIRE_ONCE) reduce 197) ((T_RETURN) reduce 197) ((T_START_HEREDOC) reduce 197) ((T_STATIC) reduce 197) ((T_STRING) reduce 197) ((T_STRING_CAST) reduce 197) ((T_SWITCH) reduce 197) ((T_THROW) reduce 197) ((T_TRAIT) reduce 197) ((T_TRAIT_C) reduce 197) ((T_TRY) reduce 197) ((T_UNSET) reduce 197) ((T_UNSET_CAST) reduce 197) ((T_VARIABLE) reduce 197) ((T_WHILE) reduce 197) ((T_YIELD) reduce 197) ((T_YIELD_FROM) reduce 197) (("[") reduce 197) (("`") reduce 197) (("{") reduce 197) (("~") reduce 197)) 20189 ((("!") reduce 151) (("\"") reduce 151) (("$") reduce 151) (("(") reduce 151) (("+") reduce 151) (("-") reduce 151) ((";") reduce 151) (("@") reduce 151) ((T_ABSTRACT) reduce 151) ((T_ARRAY) reduce 151) ((T_ARRAY_CAST) reduce 151) ((T_ATTRIBUTE) reduce 151) ((T_BOOL_CAST) reduce 151) ((T_BREAK) reduce 151) ((T_CLASS) reduce 151) ((T_CLASS_C) reduce 151) ((T_CLONE) reduce 151) ((T_CONSTANT_ENCAPSED_STRING) reduce 151) ((T_CONTINUE) reduce 151) ((T_DEC) reduce 151) ((T_DECLARE) reduce 151) ((T_DIR) reduce 151) ((T_DNUMBER) reduce 151) ((T_DO) reduce 151) ((T_DOUBLE_CAST) reduce 151) ((T_ECHO) reduce 151) ((T_EMPTY) reduce 151) ((T_ENDDECLARE) reduce 151) ((T_ENUM) reduce 151) ((T_EVAL) reduce 151) ((T_EXIT) reduce 151) ((T_FILE) reduce 151) ((T_FINAL) reduce 151) ((T_FN) reduce 151) ((T_FOR) reduce 151) ((T_FOREACH) reduce 151) ((T_FUNCTION) reduce 151) ((T_FUNC_C) reduce 151) ((T_GLOBAL) reduce 151) ((T_GOTO) reduce 151) ((T_HALT_COMPILER) reduce 151) ((T_IF) reduce 151) ((T_INC) reduce 151) ((T_INCLUDE) reduce 151) ((T_INCLUDE_ONCE) reduce 151) ((T_INLINE_HTML) reduce 151) ((T_INTERFACE) reduce 151) ((T_INT_CAST) reduce 151) ((T_ISSET) reduce 151) ((T_LINE) reduce 151) ((T_LIST) reduce 151) ((T_LNUMBER) reduce 151) ((T_MATCH) reduce 151) ((T_METHOD_C) reduce 151) ((T_NAME_FULLY_QUALIFIED) reduce 151) ((T_NAME_QUALIFIED) reduce 151) ((T_NAME_RELATIVE) reduce 151) ((T_NEW) reduce 151) ((T_NS_C) reduce 151) ((T_OBJECT_CAST) reduce 151) ((T_PRINT) reduce 151) ((T_READONLY) reduce 151) ((T_REQUIRE) reduce 151) ((T_REQUIRE_ONCE) reduce 151) ((T_RETURN) reduce 151) ((T_START_HEREDOC) reduce 151) ((T_STATIC) reduce 151) ((T_STRING) reduce 151) ((T_STRING_CAST) reduce 151) ((T_SWITCH) reduce 151) ((T_THROW) reduce 151) ((T_TRAIT) reduce 151) ((T_TRAIT_C) reduce 151) ((T_TRY) reduce 151) ((T_UNSET) reduce 151) ((T_UNSET_CAST) reduce 151) ((T_VARIABLE) reduce 151) ((T_WHILE) reduce 151) ((T_YIELD) reduce 151) ((T_YIELD_FROM) reduce 151) (("[") reduce 151) (("`") reduce 151) (("{") reduce 151) (("~") reduce 151)) 20193 ((("!") reduce 221) (("\"") reduce 221) (("$") reduce 221) (("(") reduce 221) (("+") reduce 221) (("-") reduce 221) ((";") reduce 221) (("@") reduce 221) ((T_ABSTRACT) reduce 221) ((T_ARRAY) reduce 221) ((T_ARRAY_CAST) reduce 221) ((T_ATTRIBUTE) reduce 221) ((T_BOOL_CAST) reduce 221) ((T_BREAK) reduce 221) ((T_CLASS) reduce 221) ((T_CLASS_C) reduce 221) ((T_CLONE) reduce 221) ((T_CONSTANT_ENCAPSED_STRING) reduce 221) ((T_CONTINUE) reduce 221) ((T_DEC) reduce 221) ((T_DECLARE) reduce 221) ((T_DIR) reduce 221) ((T_DNUMBER) reduce 221) ((T_DO) reduce 221) ((T_DOUBLE_CAST) reduce 221) ((T_ECHO) reduce 221) ((T_EMPTY) reduce 221) ((T_ENDDECLARE) reduce 221) ((T_ENUM) reduce 221) ((T_EVAL) reduce 221) ((T_EXIT) reduce 221) ((T_FILE) reduce 221) ((T_FINAL) reduce 221) ((T_FN) reduce 221) ((T_FOR) reduce 221) ((T_FOREACH) reduce 221) ((T_FUNCTION) reduce 221) ((T_FUNC_C) reduce 221) ((T_GLOBAL) reduce 221) ((T_GOTO) reduce 221) ((T_HALT_COMPILER) reduce 221) ((T_IF) reduce 221) ((T_INC) reduce 221) ((T_INCLUDE) reduce 221) ((T_INCLUDE_ONCE) reduce 221) ((T_INLINE_HTML) reduce 221) ((T_INTERFACE) reduce 221) ((T_INT_CAST) reduce 221) ((T_ISSET) reduce 221) ((T_LINE) reduce 221) ((T_LIST) reduce 221) ((T_LNUMBER) reduce 221) ((T_MATCH) reduce 221) ((T_METHOD_C) reduce 221) ((T_NAME_FULLY_QUALIFIED) reduce 221) ((T_NAME_QUALIFIED) reduce 221) ((T_NAME_RELATIVE) reduce 221) ((T_NEW) reduce 221) ((T_NS_C) reduce 221) ((T_OBJECT_CAST) reduce 221) ((T_PRINT) reduce 221) ((T_READONLY) reduce 221) ((T_REQUIRE) reduce 221) ((T_REQUIRE_ONCE) reduce 221) ((T_RETURN) reduce 221) ((T_START_HEREDOC) reduce 221) ((T_STATIC) reduce 221) ((T_STRING) reduce 221) ((T_STRING_CAST) reduce 221) ((T_SWITCH) reduce 221) ((T_THROW) reduce 221) ((T_TRAIT) reduce 221) ((T_TRAIT_C) reduce 221) ((T_TRY) reduce 221) ((T_UNSET) reduce 221) ((T_UNSET_CAST) reduce 221) ((T_VARIABLE) reduce 221) ((T_WHILE) reduce 221) ((T_YIELD) reduce 221) ((T_YIELD_FROM) reduce 221) (("[") reduce 221) (("`") reduce 221) (("{") reduce 221) (("~") reduce 221)) 20195 ((("!") reduce 222) (("\"") reduce 222) (("$") reduce 222) (("(") reduce 222) (("+") reduce 222) (("-") reduce 222) ((";") reduce 222) (("@") reduce 222) ((T_ABSTRACT) reduce 222) ((T_ARRAY) reduce 222) ((T_ARRAY_CAST) reduce 222) ((T_ATTRIBUTE) reduce 222) ((T_BOOL_CAST) reduce 222) ((T_BREAK) reduce 222) ((T_CLASS) reduce 222) ((T_CLASS_C) reduce 222) ((T_CLONE) reduce 222) ((T_CONSTANT_ENCAPSED_STRING) reduce 222) ((T_CONTINUE) reduce 222) ((T_DEC) reduce 222) ((T_DECLARE) reduce 222) ((T_DIR) reduce 222) ((T_DNUMBER) reduce 222) ((T_DO) reduce 222) ((T_DOUBLE_CAST) reduce 222) ((T_ECHO) reduce 222) ((T_EMPTY) reduce 222) ((T_ENDDECLARE) reduce 222) ((T_ENUM) reduce 222) ((T_EVAL) reduce 222) ((T_EXIT) reduce 222) ((T_FILE) reduce 222) ((T_FINAL) reduce 222) ((T_FN) reduce 222) ((T_FOR) reduce 222) ((T_FOREACH) reduce 222) ((T_FUNCTION) reduce 222) ((T_FUNC_C) reduce 222) ((T_GLOBAL) reduce 222) ((T_GOTO) reduce 222) ((T_HALT_COMPILER) reduce 222) ((T_IF) reduce 222) ((T_INC) reduce 222) ((T_INCLUDE) reduce 222) ((T_INCLUDE_ONCE) reduce 222) ((T_INLINE_HTML) reduce 222) ((T_INTERFACE) reduce 222) ((T_INT_CAST) reduce 222) ((T_ISSET) reduce 222) ((T_LINE) reduce 222) ((T_LIST) reduce 222) ((T_LNUMBER) reduce 222) ((T_MATCH) reduce 222) ((T_METHOD_C) reduce 222) ((T_NAME_FULLY_QUALIFIED) reduce 222) ((T_NAME_QUALIFIED) reduce 222) ((T_NAME_RELATIVE) reduce 222) ((T_NEW) reduce 222) ((T_NS_C) reduce 222) ((T_OBJECT_CAST) reduce 222) ((T_PRINT) reduce 222) ((T_READONLY) reduce 222) ((T_REQUIRE) reduce 222) ((T_REQUIRE_ONCE) reduce 222) ((T_RETURN) reduce 222) ((T_START_HEREDOC) reduce 222) ((T_STATIC) reduce 222) ((T_STRING) reduce 222) ((T_STRING_CAST) reduce 222) ((T_SWITCH) reduce 222) ((T_THROW) reduce 222) ((T_TRAIT) reduce 222) ((T_TRAIT_C) reduce 222) ((T_TRY) reduce 222) ((T_UNSET) reduce 222) ((T_UNSET_CAST) reduce 222) ((T_VARIABLE) reduce 222) ((T_WHILE) reduce 222) ((T_YIELD) reduce 222) ((T_YIELD_FROM) reduce 222) (("[") reduce 222) (("`") reduce 222) (("{") reduce 222) (("~") reduce 222)) 20199 ((("!") reduce 223) (("\"") reduce 223) (("$") reduce 223) (("(") reduce 223) (("+") reduce 223) (("-") reduce 223) ((";") reduce 223) (("@") reduce 223) ((T_ABSTRACT) reduce 223) ((T_ARRAY) reduce 223) ((T_ARRAY_CAST) reduce 223) ((T_ATTRIBUTE) reduce 223) ((T_BOOL_CAST) reduce 223) ((T_BREAK) reduce 223) ((T_CLASS) reduce 223) ((T_CLASS_C) reduce 223) ((T_CLONE) reduce 223) ((T_CONSTANT_ENCAPSED_STRING) reduce 223) ((T_CONTINUE) reduce 223) ((T_DEC) reduce 223) ((T_DECLARE) reduce 223) ((T_DIR) reduce 223) ((T_DNUMBER) reduce 223) ((T_DO) reduce 223) ((T_DOUBLE_CAST) reduce 223) ((T_ECHO) reduce 223) ((T_EMPTY) reduce 223) ((T_ENDDECLARE) reduce 223) ((T_ENUM) reduce 223) ((T_EVAL) reduce 223) ((T_EXIT) reduce 223) ((T_FILE) reduce 223) ((T_FINAL) reduce 223) ((T_FN) reduce 223) ((T_FOR) reduce 223) ((T_FOREACH) reduce 223) ((T_FUNCTION) reduce 223) ((T_FUNC_C) reduce 223) ((T_GLOBAL) reduce 223) ((T_GOTO) reduce 223) ((T_HALT_COMPILER) reduce 223) ((T_IF) reduce 223) ((T_INC) reduce 223) ((T_INCLUDE) reduce 223) ((T_INCLUDE_ONCE) reduce 223) ((T_INLINE_HTML) reduce 223) ((T_INTERFACE) reduce 223) ((T_INT_CAST) reduce 223) ((T_ISSET) reduce 223) ((T_LINE) reduce 223) ((T_LIST) reduce 223) ((T_LNUMBER) reduce 223) ((T_MATCH) reduce 223) ((T_METHOD_C) reduce 223) ((T_NAME_FULLY_QUALIFIED) reduce 223) ((T_NAME_QUALIFIED) reduce 223) ((T_NAME_RELATIVE) reduce 223) ((T_NEW) reduce 223) ((T_NS_C) reduce 223) ((T_OBJECT_CAST) reduce 223) ((T_PRINT) reduce 223) ((T_READONLY) reduce 223) ((T_REQUIRE) reduce 223) ((T_REQUIRE_ONCE) reduce 223) ((T_RETURN) reduce 223) ((T_START_HEREDOC) reduce 223) ((T_STATIC) reduce 223) ((T_STRING) reduce 223) ((T_STRING_CAST) reduce 223) ((T_SWITCH) reduce 223) ((T_THROW) reduce 223) ((T_TRAIT) reduce 223) ((T_TRAIT_C) reduce 223) ((T_TRY) reduce 223) ((T_UNSET) reduce 223) ((T_UNSET_CAST) reduce 223) ((T_VARIABLE) reduce 223) ((T_WHILE) reduce 223) ((T_YIELD) reduce 223) ((T_YIELD_FROM) reduce 223) (("[") reduce 223) (("`") reduce 223) (("{") reduce 223) (("~") reduce 223)) 20202 ((("!") reduce 224) (("\"") reduce 224) (("$") reduce 224) (("(") reduce 224) (("+") reduce 224) (("-") reduce 224) ((";") reduce 224) (("@") reduce 224) ((T_ABSTRACT) reduce 224) ((T_ARRAY) reduce 224) ((T_ARRAY_CAST) reduce 224) ((T_ATTRIBUTE) reduce 224) ((T_BOOL_CAST) reduce 224) ((T_BREAK) reduce 224) ((T_CLASS) reduce 224) ((T_CLASS_C) reduce 224) ((T_CLONE) reduce 224) ((T_CONSTANT_ENCAPSED_STRING) reduce 224) ((T_CONTINUE) reduce 224) ((T_DEC) reduce 224) ((T_DECLARE) reduce 224) ((T_DIR) reduce 224) ((T_DNUMBER) reduce 224) ((T_DO) reduce 224) ((T_DOUBLE_CAST) reduce 224) ((T_ECHO) reduce 224) ((T_EMPTY) reduce 224) ((T_ENDDECLARE) reduce 224) ((T_ENUM) reduce 224) ((T_EVAL) reduce 224) ((T_EXIT) reduce 224) ((T_FILE) reduce 224) ((T_FINAL) reduce 224) ((T_FN) reduce 224) ((T_FOR) reduce 224) ((T_FOREACH) reduce 224) ((T_FUNCTION) reduce 224) ((T_FUNC_C) reduce 224) ((T_GLOBAL) reduce 224) ((T_GOTO) reduce 224) ((T_HALT_COMPILER) reduce 224) ((T_IF) reduce 224) ((T_INC) reduce 224) ((T_INCLUDE) reduce 224) ((T_INCLUDE_ONCE) reduce 224) ((T_INLINE_HTML) reduce 224) ((T_INTERFACE) reduce 224) ((T_INT_CAST) reduce 224) ((T_ISSET) reduce 224) ((T_LINE) reduce 224) ((T_LIST) reduce 224) ((T_LNUMBER) reduce 224) ((T_MATCH) reduce 224) ((T_METHOD_C) reduce 224) ((T_NAME_FULLY_QUALIFIED) reduce 224) ((T_NAME_QUALIFIED) reduce 224) ((T_NAME_RELATIVE) reduce 224) ((T_NEW) reduce 224) ((T_NS_C) reduce 224) ((T_OBJECT_CAST) reduce 224) ((T_PRINT) reduce 224) ((T_READONLY) reduce 224) ((T_REQUIRE) reduce 224) ((T_REQUIRE_ONCE) reduce 224) ((T_RETURN) reduce 224) ((T_START_HEREDOC) reduce 224) ((T_STATIC) reduce 224) ((T_STRING) reduce 224) ((T_STRING_CAST) reduce 224) ((T_SWITCH) reduce 224) ((T_THROW) reduce 224) ((T_TRAIT) reduce 224) ((T_TRAIT_C) reduce 224) ((T_TRY) reduce 224) ((T_UNSET) reduce 224) ((T_UNSET_CAST) reduce 224) ((T_VARIABLE) reduce 224) ((T_WHILE) reduce 224) ((T_YIELD) reduce 224) ((T_YIELD_FROM) reduce 224) (("[") reduce 224) (("`") reduce 224) (("{") reduce 224) (("~") reduce 224)) 20203 ((("!") reduce 167) (("\"") reduce 167) (("$") reduce 167) (("(") reduce 167) (("+") reduce 167) (("-") reduce 167) ((";") reduce 167) (("@") reduce 167) ((T_ABSTRACT) reduce 167) ((T_ARRAY) reduce 167) ((T_ARRAY_CAST) reduce 167) ((T_ATTRIBUTE) reduce 167) ((T_BOOL_CAST) reduce 167) ((T_BREAK) reduce 167) ((T_CLASS) reduce 167) ((T_CLASS_C) reduce 167) ((T_CLONE) reduce 167) ((T_CONSTANT_ENCAPSED_STRING) reduce 167) ((T_CONTINUE) reduce 167) ((T_DEC) reduce 167) ((T_DECLARE) reduce 167) ((T_DIR) reduce 167) ((T_DNUMBER) reduce 167) ((T_DO) reduce 167) ((T_DOUBLE_CAST) reduce 167) ((T_ECHO) reduce 167) ((T_EMPTY) reduce 167) ((T_ENDDECLARE) reduce 167) ((T_ENUM) reduce 167) ((T_EVAL) reduce 167) ((T_EXIT) reduce 167) ((T_FILE) reduce 167) ((T_FINAL) reduce 167) ((T_FN) reduce 167) ((T_FOR) reduce 167) ((T_FOREACH) reduce 167) ((T_FUNCTION) reduce 167) ((T_FUNC_C) reduce 167) ((T_GLOBAL) reduce 167) ((T_GOTO) reduce 167) ((T_HALT_COMPILER) reduce 167) ((T_IF) reduce 167) ((T_INC) reduce 167) ((T_INCLUDE) reduce 167) ((T_INCLUDE_ONCE) reduce 167) ((T_INLINE_HTML) reduce 167) ((T_INTERFACE) reduce 167) ((T_INT_CAST) reduce 167) ((T_ISSET) reduce 167) ((T_LINE) reduce 167) ((T_LIST) reduce 167) ((T_LNUMBER) reduce 167) ((T_MATCH) reduce 167) ((T_METHOD_C) reduce 167) ((T_NAME_FULLY_QUALIFIED) reduce 167) ((T_NAME_QUALIFIED) reduce 167) ((T_NAME_RELATIVE) reduce 167) ((T_NEW) reduce 167) ((T_NS_C) reduce 167) ((T_OBJECT_CAST) reduce 167) ((T_PRINT) reduce 167) ((T_READONLY) reduce 167) ((T_REQUIRE) reduce 167) ((T_REQUIRE_ONCE) reduce 167) ((T_RETURN) reduce 167) ((T_START_HEREDOC) reduce 167) ((T_STATIC) reduce 167) ((T_STRING) reduce 167) ((T_STRING_CAST) reduce 167) ((T_SWITCH) reduce 167) ((T_THROW) reduce 167) ((T_TRAIT) reduce 167) ((T_TRAIT_C) reduce 167) ((T_TRY) reduce 167) ((T_UNSET) reduce 167) ((T_UNSET_CAST) reduce 167) ((T_VARIABLE) reduce 167) ((T_WHILE) reduce 167) ((T_YIELD) reduce 167) ((T_YIELD_FROM) reduce 167) (("[") reduce 167) (("`") reduce 167) (("{") reduce 167) (("~") reduce 167)) 20205 ((("!") reduce 156) (("\"") reduce 156) (("$") reduce 156) (("(") reduce 156) (("+") reduce 156) (("-") reduce 156) ((";") reduce 156) (("@") reduce 156) ((T_ABSTRACT) reduce 156) ((T_ARRAY) reduce 156) ((T_ARRAY_CAST) reduce 156) ((T_ATTRIBUTE) reduce 156) ((T_BOOL_CAST) reduce 156) ((T_BREAK) reduce 156) ((T_CLASS) reduce 156) ((T_CLASS_C) reduce 156) ((T_CLONE) reduce 156) ((T_CONSTANT_ENCAPSED_STRING) reduce 156) ((T_CONTINUE) reduce 156) ((T_DEC) reduce 156) ((T_DECLARE) reduce 156) ((T_DIR) reduce 156) ((T_DNUMBER) reduce 156) ((T_DO) reduce 156) ((T_DOUBLE_CAST) reduce 156) ((T_ECHO) reduce 156) ((T_EMPTY) reduce 156) ((T_ENDDECLARE) reduce 156) ((T_ENUM) reduce 156) ((T_EVAL) reduce 156) ((T_EXIT) reduce 156) ((T_FILE) reduce 156) ((T_FINAL) reduce 156) ((T_FN) reduce 156) ((T_FOR) reduce 156) ((T_FOREACH) reduce 156) ((T_FUNCTION) reduce 156) ((T_FUNC_C) reduce 156) ((T_GLOBAL) reduce 156) ((T_GOTO) reduce 156) ((T_HALT_COMPILER) reduce 156) ((T_IF) reduce 156) ((T_INC) reduce 156) ((T_INCLUDE) reduce 156) ((T_INCLUDE_ONCE) reduce 156) ((T_INLINE_HTML) reduce 156) ((T_INTERFACE) reduce 156) ((T_INT_CAST) reduce 156) ((T_ISSET) reduce 156) ((T_LINE) reduce 156) ((T_LIST) reduce 156) ((T_LNUMBER) reduce 156) ((T_MATCH) reduce 156) ((T_METHOD_C) reduce 156) ((T_NAME_FULLY_QUALIFIED) reduce 156) ((T_NAME_QUALIFIED) reduce 156) ((T_NAME_RELATIVE) reduce 156) ((T_NEW) reduce 156) ((T_NS_C) reduce 156) ((T_OBJECT_CAST) reduce 156) ((T_PRINT) reduce 156) ((T_READONLY) reduce 156) ((T_REQUIRE) reduce 156) ((T_REQUIRE_ONCE) reduce 156) ((T_RETURN) reduce 156) ((T_START_HEREDOC) reduce 156) ((T_STATIC) reduce 156) ((T_STRING) reduce 156) ((T_STRING_CAST) reduce 156) ((T_SWITCH) reduce 156) ((T_THROW) reduce 156) ((T_TRAIT) reduce 156) ((T_TRAIT_C) reduce 156) ((T_TRY) reduce 156) ((T_UNSET) reduce 156) ((T_UNSET_CAST) reduce 156) ((T_VARIABLE) reduce 156) ((T_WHILE) reduce 156) ((T_YIELD) reduce 156) ((T_YIELD_FROM) reduce 156) (("[") reduce 156) (("`") reduce 156) (("{") reduce 156) (("~") reduce 156)) 20207 ((("!") reduce 154) (("\"") reduce 154) (("$") reduce 154) (("(") reduce 154) (("+") reduce 154) (("-") reduce 154) ((";") reduce 154) (("@") reduce 154) ((T_ABSTRACT) reduce 154) ((T_ARRAY) reduce 154) ((T_ARRAY_CAST) reduce 154) ((T_ATTRIBUTE) reduce 154) ((T_BOOL_CAST) reduce 154) ((T_BREAK) reduce 154) ((T_CLASS) reduce 154) ((T_CLASS_C) reduce 154) ((T_CLONE) reduce 154) ((T_CONSTANT_ENCAPSED_STRING) reduce 154) ((T_CONTINUE) reduce 154) ((T_DEC) reduce 154) ((T_DECLARE) reduce 154) ((T_DIR) reduce 154) ((T_DNUMBER) reduce 154) ((T_DO) reduce 154) ((T_DOUBLE_CAST) reduce 154) ((T_ECHO) reduce 154) ((T_EMPTY) reduce 154) ((T_ENDDECLARE) reduce 154) ((T_ENUM) reduce 154) ((T_EVAL) reduce 154) ((T_EXIT) reduce 154) ((T_FILE) reduce 154) ((T_FINAL) reduce 154) ((T_FN) reduce 154) ((T_FOR) reduce 154) ((T_FOREACH) reduce 154) ((T_FUNCTION) reduce 154) ((T_FUNC_C) reduce 154) ((T_GLOBAL) reduce 154) ((T_GOTO) reduce 154) ((T_HALT_COMPILER) reduce 154) ((T_IF) reduce 154) ((T_INC) reduce 154) ((T_INCLUDE) reduce 154) ((T_INCLUDE_ONCE) reduce 154) ((T_INLINE_HTML) reduce 154) ((T_INTERFACE) reduce 154) ((T_INT_CAST) reduce 154) ((T_ISSET) reduce 154) ((T_LINE) reduce 154) ((T_LIST) reduce 154) ((T_LNUMBER) reduce 154) ((T_MATCH) reduce 154) ((T_METHOD_C) reduce 154) ((T_NAME_FULLY_QUALIFIED) reduce 154) ((T_NAME_QUALIFIED) reduce 154) ((T_NAME_RELATIVE) reduce 154) ((T_NEW) reduce 154) ((T_NS_C) reduce 154) ((T_OBJECT_CAST) reduce 154) ((T_PRINT) reduce 154) ((T_READONLY) reduce 154) ((T_REQUIRE) reduce 154) ((T_REQUIRE_ONCE) reduce 154) ((T_RETURN) reduce 154) ((T_START_HEREDOC) reduce 154) ((T_STATIC) reduce 154) ((T_STRING) reduce 154) ((T_STRING_CAST) reduce 154) ((T_SWITCH) reduce 154) ((T_THROW) reduce 154) ((T_TRAIT) reduce 154) ((T_TRAIT_C) reduce 154) ((T_TRY) reduce 154) ((T_UNSET) reduce 154) ((T_UNSET_CAST) reduce 154) ((T_VARIABLE) reduce 154) ((T_WHILE) reduce 154) ((T_YIELD) reduce 154) ((T_YIELD_FROM) reduce 154) (("[") reduce 154) (("`") reduce 154) (("{") reduce 154) (("~") reduce 154)) 20208 (((T_EXTENDS) shift) (("{") reduce 207)) 20214 ((("!") reduce 198) (("\"") reduce 198) (("$") reduce 198) (("(") reduce 198) (("+") reduce 198) (("-") reduce 198) ((";") reduce 198) (("@") reduce 198) ((T_ABSTRACT) reduce 198) ((T_ARRAY) reduce 198) ((T_ARRAY_CAST) reduce 198) ((T_ATTRIBUTE) reduce 198) ((T_BOOL_CAST) reduce 198) ((T_BREAK) reduce 198) ((T_CLASS) reduce 198) ((T_CLASS_C) reduce 198) ((T_CLONE) reduce 198) ((T_CONSTANT_ENCAPSED_STRING) reduce 198) ((T_CONTINUE) reduce 198) ((T_DEC) reduce 198) ((T_DECLARE) reduce 198) ((T_DIR) reduce 198) ((T_DNUMBER) reduce 198) ((T_DO) reduce 198) ((T_DOUBLE_CAST) reduce 198) ((T_ECHO) reduce 198) ((T_EMPTY) reduce 198) ((T_ENDDECLARE) reduce 198) ((T_ENUM) reduce 198) ((T_EVAL) reduce 198) ((T_EXIT) reduce 198) ((T_FILE) reduce 198) ((T_FINAL) reduce 198) ((T_FN) reduce 198) ((T_FOR) reduce 198) ((T_FOREACH) reduce 198) ((T_FUNCTION) reduce 198) ((T_FUNC_C) reduce 198) ((T_GLOBAL) reduce 198) ((T_GOTO) reduce 198) ((T_HALT_COMPILER) reduce 198) ((T_IF) reduce 198) ((T_INC) reduce 198) ((T_INCLUDE) reduce 198) ((T_INCLUDE_ONCE) reduce 198) ((T_INLINE_HTML) reduce 198) ((T_INTERFACE) reduce 198) ((T_INT_CAST) reduce 198) ((T_ISSET) reduce 198) ((T_LINE) reduce 198) ((T_LIST) reduce 198) ((T_LNUMBER) reduce 198) ((T_MATCH) reduce 198) ((T_METHOD_C) reduce 198) ((T_NAME_FULLY_QUALIFIED) reduce 198) ((T_NAME_QUALIFIED) reduce 198) ((T_NAME_RELATIVE) reduce 198) ((T_NEW) reduce 198) ((T_NS_C) reduce 198) ((T_OBJECT_CAST) reduce 198) ((T_PRINT) reduce 198) ((T_READONLY) reduce 198) ((T_REQUIRE) reduce 198) ((T_REQUIRE_ONCE) reduce 198) ((T_RETURN) reduce 198) ((T_START_HEREDOC) reduce 198) ((T_STATIC) reduce 198) ((T_STRING) reduce 198) ((T_STRING_CAST) reduce 198) ((T_SWITCH) reduce 198) ((T_THROW) reduce 198) ((T_TRAIT) reduce 198) ((T_TRAIT_C) reduce 198) ((T_TRY) reduce 198) ((T_UNSET) reduce 198) ((T_UNSET_CAST) reduce 198) ((T_VARIABLE) reduce 198) ((T_WHILE) reduce 198) ((T_YIELD) reduce 198) ((T_YIELD_FROM) reduce 198) (("[") reduce 198) (("`") reduce 198) (("{") reduce 198) (("~") reduce 198)) 20215 (((",") shift) (("{") reduce 208)) 20220 ((("!") reduce 241) (("\"") reduce 241) (("$") reduce 241) (("(") reduce 241) (("+") reduce 241) (("-") reduce 241) ((";") reduce 241) (("@") reduce 241) ((T_ABSTRACT) reduce 241) ((T_ARRAY) reduce 241) ((T_ARRAY_CAST) reduce 241) ((T_ATTRIBUTE) reduce 241) ((T_BOOL_CAST) reduce 241) ((T_BREAK) reduce 241) ((T_CLASS) reduce 241) ((T_CLASS_C) reduce 241) ((T_CLONE) reduce 241) ((T_CONSTANT_ENCAPSED_STRING) reduce 241) ((T_CONTINUE) reduce 241) ((T_DEC) reduce 241) ((T_DECLARE) reduce 241) ((T_DIR) reduce 241) ((T_DNUMBER) reduce 241) ((T_DO) reduce 241) ((T_DOUBLE_CAST) reduce 241) ((T_ECHO) reduce 241) ((T_ELSE) reduce 241) ((T_ELSEIF) reduce 241) ((T_EMPTY) reduce 241) ((T_ENDDECLARE) reduce 241) ((T_ENUM) reduce 241) ((T_EVAL) reduce 241) ((T_EXIT) reduce 241) ((T_FILE) reduce 241) ((T_FINAL) reduce 241) ((T_FN) reduce 241) ((T_FOR) reduce 241) ((T_FOREACH) reduce 241) ((T_FUNCTION) reduce 241) ((T_FUNC_C) reduce 241) ((T_GLOBAL) reduce 241) ((T_GOTO) reduce 241) ((T_HALT_COMPILER) reduce 241) ((T_IF) reduce 241) ((T_INC) reduce 241) ((T_INCLUDE) reduce 241) ((T_INCLUDE_ONCE) reduce 241) ((T_INLINE_HTML) reduce 241) ((T_INTERFACE) reduce 241) ((T_INT_CAST) reduce 241) ((T_ISSET) reduce 241) ((T_LINE) reduce 241) ((T_LIST) reduce 241) ((T_LNUMBER) reduce 241) ((T_MATCH) reduce 241) ((T_METHOD_C) reduce 241) ((T_NAME_FULLY_QUALIFIED) reduce 241) ((T_NAME_QUALIFIED) reduce 241) ((T_NAME_RELATIVE) reduce 241) ((T_NEW) reduce 241) ((T_NS_C) reduce 241) ((T_OBJECT_CAST) reduce 241) ((T_PRINT) reduce 241) ((T_READONLY) reduce 241) ((T_REQUIRE) reduce 241) ((T_REQUIRE_ONCE) reduce 241) ((T_RETURN) reduce 241) ((T_START_HEREDOC) reduce 241) ((T_STATIC) reduce 241) ((T_STRING) reduce 241) ((T_STRING_CAST) reduce 241) ((T_SWITCH) reduce 241) ((T_THROW) reduce 241) ((T_TRAIT) reduce 241) ((T_TRAIT_C) reduce 241) ((T_TRY) reduce 241) ((T_UNSET) reduce 241) ((T_UNSET_CAST) reduce 241) ((T_VARIABLE) reduce 241) ((T_WHILE) reduce 241) ((T_YIELD) reduce 241) ((T_YIELD_FROM) reduce 241) (("[") reduce 241) (("`") reduce 241) (("{") reduce 241) (("~") reduce 241)) 20221 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) (("+") shift) (("-") shift) ((";") shift) (("@") shift) ((T_ABSTRACT) shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_BREAK) shift) ((T_CLASS) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_CONTINUE) shift) ((T_DEC) shift) ((T_DECLARE) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DO) shift) ((T_DOUBLE_CAST) shift) ((T_ECHO) shift) ((T_ELSE) reduce 245) ((T_ELSEIF) reduce 245) ((T_EMPTY) shift) ((T_ENDIF) reduce 245) ((T_ENUM) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FINAL) shift) ((T_FN) shift) ((T_FOR) shift) ((T_FOREACH) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_GLOBAL) shift) ((T_GOTO) shift) ((T_HALT_COMPILER) shift) ((T_IF) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INLINE_HTML) shift) ((T_INTERFACE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_RETURN) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_SWITCH) shift) ((T_THROW) shift) ((T_TRAIT) shift) ((T_TRAIT_C) shift) ((T_TRY) shift) ((T_UNSET) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_WHILE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("{") shift) (("~") shift)) 20224 ((("!") reduce 144) (("\"") reduce 144) (("$") reduce 144) (("(") reduce 144) (("+") reduce 144) (("-") reduce 144) ((";") reduce 144) (("@") reduce 144) ((T_ABSTRACT) reduce 144) ((T_ARRAY) reduce 144) ((T_ARRAY_CAST) reduce 144) ((T_ATTRIBUTE) reduce 144) ((T_BOOL_CAST) reduce 144) ((T_BREAK) reduce 144) ((T_CLASS) reduce 144) ((T_CLASS_C) reduce 144) ((T_CLONE) reduce 144) ((T_CONSTANT_ENCAPSED_STRING) reduce 144) ((T_CONTINUE) reduce 144) ((T_DEC) reduce 144) ((T_DECLARE) reduce 144) ((T_DIR) reduce 144) ((T_DNUMBER) reduce 144) ((T_DO) reduce 144) ((T_DOUBLE_CAST) reduce 144) ((T_ECHO) reduce 144) ((T_EMPTY) reduce 144) ((T_ENDDECLARE) reduce 144) ((T_ENUM) reduce 144) ((T_EVAL) reduce 144) ((T_EXIT) reduce 144) ((T_FILE) reduce 144) ((T_FINAL) reduce 144) ((T_FN) reduce 144) ((T_FOR) reduce 144) ((T_FOREACH) reduce 144) ((T_FUNCTION) reduce 144) ((T_FUNC_C) reduce 144) ((T_GLOBAL) reduce 144) ((T_GOTO) reduce 144) ((T_HALT_COMPILER) reduce 144) ((T_IF) reduce 144) ((T_INC) reduce 144) ((T_INCLUDE) reduce 144) ((T_INCLUDE_ONCE) reduce 144) ((T_INLINE_HTML) reduce 144) ((T_INTERFACE) reduce 144) ((T_INT_CAST) reduce 144) ((T_ISSET) reduce 144) ((T_LINE) reduce 144) ((T_LIST) reduce 144) ((T_LNUMBER) reduce 144) ((T_MATCH) reduce 144) ((T_METHOD_C) reduce 144) ((T_NAME_FULLY_QUALIFIED) reduce 144) ((T_NAME_QUALIFIED) reduce 144) ((T_NAME_RELATIVE) reduce 144) ((T_NEW) reduce 144) ((T_NS_C) reduce 144) ((T_OBJECT_CAST) reduce 144) ((T_PRINT) reduce 144) ((T_READONLY) reduce 144) ((T_REQUIRE) reduce 144) ((T_REQUIRE_ONCE) reduce 144) ((T_RETURN) reduce 144) ((T_START_HEREDOC) reduce 144) ((T_STATIC) reduce 144) ((T_STRING) reduce 144) ((T_STRING_CAST) reduce 144) ((T_SWITCH) reduce 144) ((T_THROW) reduce 144) ((T_TRAIT) reduce 144) ((T_TRAIT_C) reduce 144) ((T_TRY) reduce 144) ((T_UNSET) reduce 144) ((T_UNSET_CAST) reduce 144) ((T_VARIABLE) reduce 144) ((T_WHILE) reduce 144) ((T_YIELD) reduce 144) ((T_YIELD_FROM) reduce 144) (("[") reduce 144) (("`") reduce 144) (("{") reduce 144) (("~") reduce 144)) 20226 ((("!") reduce 166) (("\"") reduce 166) (("$") reduce 166) (("(") reduce 166) (("+") reduce 166) (("-") reduce 166) ((";") reduce 166) (("@") reduce 166) ((T_ABSTRACT) reduce 166) ((T_ARRAY) reduce 166) ((T_ARRAY_CAST) reduce 166) ((T_ATTRIBUTE) reduce 166) ((T_BOOL_CAST) reduce 166) ((T_BREAK) reduce 166) ((T_CLASS) reduce 166) ((T_CLASS_C) reduce 166) ((T_CLONE) reduce 166) ((T_CONSTANT_ENCAPSED_STRING) reduce 166) ((T_CONTINUE) reduce 166) ((T_DEC) reduce 166) ((T_DECLARE) reduce 166) ((T_DIR) reduce 166) ((T_DNUMBER) reduce 166) ((T_DO) reduce 166) ((T_DOUBLE_CAST) reduce 166) ((T_ECHO) reduce 166) ((T_EMPTY) reduce 166) ((T_ENDDECLARE) reduce 166) ((T_ENUM) reduce 166) ((T_EVAL) reduce 166) ((T_EXIT) reduce 166) ((T_FILE) reduce 166) ((T_FINAL) reduce 166) ((T_FN) reduce 166) ((T_FOR) reduce 166) ((T_FOREACH) reduce 166) ((T_FUNCTION) reduce 166) ((T_FUNC_C) reduce 166) ((T_GLOBAL) reduce 166) ((T_GOTO) reduce 166) ((T_HALT_COMPILER) reduce 166) ((T_IF) reduce 166) ((T_INC) reduce 166) ((T_INCLUDE) reduce 166) ((T_INCLUDE_ONCE) reduce 166) ((T_INLINE_HTML) reduce 166) ((T_INTERFACE) reduce 166) ((T_INT_CAST) reduce 166) ((T_ISSET) reduce 166) ((T_LINE) reduce 166) ((T_LIST) reduce 166) ((T_LNUMBER) reduce 166) ((T_MATCH) reduce 166) ((T_METHOD_C) reduce 166) ((T_NAME_FULLY_QUALIFIED) reduce 166) ((T_NAME_QUALIFIED) reduce 166) ((T_NAME_RELATIVE) reduce 166) ((T_NEW) reduce 166) ((T_NS_C) reduce 166) ((T_OBJECT_CAST) reduce 166) ((T_PRINT) reduce 166) ((T_READONLY) reduce 166) ((T_REQUIRE) reduce 166) ((T_REQUIRE_ONCE) reduce 166) ((T_RETURN) reduce 166) ((T_START_HEREDOC) reduce 166) ((T_STATIC) reduce 166) ((T_STRING) reduce 166) ((T_STRING_CAST) reduce 166) ((T_SWITCH) reduce 166) ((T_THROW) reduce 166) ((T_TRAIT) reduce 166) ((T_TRAIT_C) reduce 166) ((T_TRY) reduce 166) ((T_UNSET) reduce 166) ((T_UNSET_CAST) reduce 166) ((T_VARIABLE) reduce 166) ((T_WHILE) reduce 166) ((T_YIELD) reduce 166) ((T_YIELD_FROM) reduce 166) (("[") reduce 166) (("`") reduce 166) (("{") reduce 166) (("~") reduce 166)) 20228 ((("!") reduce 155) (("\"") reduce 155) (("$") reduce 155) (("(") reduce 155) (("+") reduce 155) (("-") reduce 155) ((";") reduce 155) (("@") reduce 155) ((T_ABSTRACT) reduce 155) ((T_ARRAY) reduce 155) ((T_ARRAY_CAST) reduce 155) ((T_ATTRIBUTE) reduce 155) ((T_BOOL_CAST) reduce 155) ((T_BREAK) reduce 155) ((T_CLASS) reduce 155) ((T_CLASS_C) reduce 155) ((T_CLONE) reduce 155) ((T_CONSTANT_ENCAPSED_STRING) reduce 155) ((T_CONTINUE) reduce 155) ((T_DEC) reduce 155) ((T_DECLARE) reduce 155) ((T_DIR) reduce 155) ((T_DNUMBER) reduce 155) ((T_DO) reduce 155) ((T_DOUBLE_CAST) reduce 155) ((T_ECHO) reduce 155) ((T_EMPTY) reduce 155) ((T_ENDDECLARE) reduce 155) ((T_ENUM) reduce 155) ((T_EVAL) reduce 155) ((T_EXIT) reduce 155) ((T_FILE) reduce 155) ((T_FINAL) reduce 155) ((T_FN) reduce 155) ((T_FOR) reduce 155) ((T_FOREACH) reduce 155) ((T_FUNCTION) reduce 155) ((T_FUNC_C) reduce 155) ((T_GLOBAL) reduce 155) ((T_GOTO) reduce 155) ((T_HALT_COMPILER) reduce 155) ((T_IF) reduce 155) ((T_INC) reduce 155) ((T_INCLUDE) reduce 155) ((T_INCLUDE_ONCE) reduce 155) ((T_INLINE_HTML) reduce 155) ((T_INTERFACE) reduce 155) ((T_INT_CAST) reduce 155) ((T_ISSET) reduce 155) ((T_LINE) reduce 155) ((T_LIST) reduce 155) ((T_LNUMBER) reduce 155) ((T_MATCH) reduce 155) ((T_METHOD_C) reduce 155) ((T_NAME_FULLY_QUALIFIED) reduce 155) ((T_NAME_QUALIFIED) reduce 155) ((T_NAME_RELATIVE) reduce 155) ((T_NEW) reduce 155) ((T_NS_C) reduce 155) ((T_OBJECT_CAST) reduce 155) ((T_PRINT) reduce 155) ((T_READONLY) reduce 155) ((T_REQUIRE) reduce 155) ((T_REQUIRE_ONCE) reduce 155) ((T_RETURN) reduce 155) ((T_START_HEREDOC) reduce 155) ((T_STATIC) reduce 155) ((T_STRING) reduce 155) ((T_STRING_CAST) reduce 155) ((T_SWITCH) reduce 155) ((T_THROW) reduce 155) ((T_TRAIT) reduce 155) ((T_TRAIT_C) reduce 155) ((T_TRY) reduce 155) ((T_UNSET) reduce 155) ((T_UNSET_CAST) reduce 155) ((T_VARIABLE) reduce 155) ((T_WHILE) reduce 155) ((T_YIELD) reduce 155) ((T_YIELD_FROM) reduce 155) (("[") reduce 155) (("`") reduce 155) (("{") reduce 155) (("~") reduce 155)) 20238 ((("!") reduce 162) (("\"") reduce 162) (("$") reduce 162) (("(") reduce 162) (("+") reduce 162) (("-") reduce 162) ((";") reduce 162) (("@") reduce 162) ((T_ABSTRACT) reduce 162) ((T_ARRAY) reduce 162) ((T_ARRAY_CAST) reduce 162) ((T_ATTRIBUTE) reduce 162) ((T_BOOL_CAST) reduce 162) ((T_BREAK) reduce 162) ((T_CLASS) reduce 162) ((T_CLASS_C) reduce 162) ((T_CLONE) reduce 162) ((T_CONSTANT_ENCAPSED_STRING) reduce 162) ((T_CONTINUE) reduce 162) ((T_DEC) reduce 162) ((T_DECLARE) reduce 162) ((T_DIR) reduce 162) ((T_DNUMBER) reduce 162) ((T_DO) reduce 162) ((T_DOUBLE_CAST) reduce 162) ((T_ECHO) reduce 162) ((T_EMPTY) reduce 162) ((T_ENDDECLARE) reduce 162) ((T_ENUM) reduce 162) ((T_EVAL) reduce 162) ((T_EXIT) reduce 162) ((T_FILE) reduce 162) ((T_FINAL) reduce 162) ((T_FN) reduce 162) ((T_FOR) reduce 162) ((T_FOREACH) reduce 162) ((T_FUNCTION) reduce 162) ((T_FUNC_C) reduce 162) ((T_GLOBAL) reduce 162) ((T_GOTO) reduce 162) ((T_HALT_COMPILER) reduce 162) ((T_IF) reduce 162) ((T_INC) reduce 162) ((T_INCLUDE) reduce 162) ((T_INCLUDE_ONCE) reduce 162) ((T_INLINE_HTML) reduce 162) ((T_INTERFACE) reduce 162) ((T_INT_CAST) reduce 162) ((T_ISSET) reduce 162) ((T_LINE) reduce 162) ((T_LIST) reduce 162) ((T_LNUMBER) reduce 162) ((T_MATCH) reduce 162) ((T_METHOD_C) reduce 162) ((T_NAME_FULLY_QUALIFIED) reduce 162) ((T_NAME_QUALIFIED) reduce 162) ((T_NAME_RELATIVE) reduce 162) ((T_NEW) reduce 162) ((T_NS_C) reduce 162) ((T_OBJECT_CAST) reduce 162) ((T_PRINT) reduce 162) ((T_READONLY) reduce 162) ((T_REQUIRE) reduce 162) ((T_REQUIRE_ONCE) reduce 162) ((T_RETURN) reduce 162) ((T_START_HEREDOC) reduce 162) ((T_STATIC) reduce 162) ((T_STRING) reduce 162) ((T_STRING_CAST) reduce 162) ((T_SWITCH) reduce 162) ((T_THROW) reduce 162) ((T_TRAIT) reduce 162) ((T_TRAIT_C) reduce 162) ((T_TRY) reduce 162) ((T_UNSET) reduce 162) ((T_UNSET_CAST) reduce 162) ((T_VARIABLE) reduce 162) ((T_WHILE) reduce 162) ((T_YIELD) reduce 162) ((T_YIELD_FROM) reduce 162) (("[") reduce 162) (("`") reduce 162) (("{") reduce 162) (("~") reduce 162)) 20239 ((("!") reduce 217) (("\"") reduce 217) (("$") reduce 217) (("(") reduce 217) (("+") reduce 217) (("-") reduce 217) ((";") reduce 217) (("@") reduce 217) ((T_ABSTRACT) reduce 217) ((T_ARRAY) reduce 217) ((T_ARRAY_CAST) reduce 217) ((T_ATTRIBUTE) reduce 217) ((T_BOOL_CAST) reduce 217) ((T_BREAK) reduce 217) ((T_CLASS) reduce 217) ((T_CLASS_C) reduce 217) ((T_CLONE) reduce 217) ((T_CONSTANT_ENCAPSED_STRING) reduce 217) ((T_CONTINUE) reduce 217) ((T_DEC) reduce 217) ((T_DECLARE) reduce 217) ((T_DIR) reduce 217) ((T_DNUMBER) reduce 217) ((T_DO) reduce 217) ((T_DOUBLE_CAST) reduce 217) ((T_ECHO) reduce 217) ((T_EMPTY) reduce 217) ((T_ENDDECLARE) reduce 217) ((T_ENUM) reduce 217) ((T_EVAL) reduce 217) ((T_EXIT) reduce 217) ((T_FILE) reduce 217) ((T_FINAL) reduce 217) ((T_FN) reduce 217) ((T_FOR) reduce 217) ((T_FOREACH) reduce 217) ((T_FUNCTION) reduce 217) ((T_FUNC_C) reduce 217) ((T_GLOBAL) reduce 217) ((T_GOTO) reduce 217) ((T_HALT_COMPILER) reduce 217) ((T_IF) reduce 217) ((T_INC) reduce 217) ((T_INCLUDE) reduce 217) ((T_INCLUDE_ONCE) reduce 217) ((T_INLINE_HTML) reduce 217) ((T_INTERFACE) reduce 217) ((T_INT_CAST) reduce 217) ((T_ISSET) reduce 217) ((T_LINE) reduce 217) ((T_LIST) reduce 217) ((T_LNUMBER) reduce 217) ((T_MATCH) reduce 217) ((T_METHOD_C) reduce 217) ((T_NAME_FULLY_QUALIFIED) reduce 217) ((T_NAME_QUALIFIED) reduce 217) ((T_NAME_RELATIVE) reduce 217) ((T_NEW) reduce 217) ((T_NS_C) reduce 217) ((T_OBJECT_CAST) reduce 217) ((T_PRINT) reduce 217) ((T_READONLY) reduce 217) ((T_REQUIRE) reduce 217) ((T_REQUIRE_ONCE) reduce 217) ((T_RETURN) reduce 217) ((T_START_HEREDOC) reduce 217) ((T_STATIC) reduce 217) ((T_STRING) reduce 217) ((T_STRING_CAST) reduce 217) ((T_SWITCH) reduce 217) ((T_THROW) reduce 217) ((T_TRAIT) reduce 217) ((T_TRAIT_C) reduce 217) ((T_TRY) reduce 217) ((T_UNSET) reduce 217) ((T_UNSET_CAST) reduce 217) ((T_VARIABLE) reduce 217) ((T_WHILE) reduce 217) ((T_YIELD) reduce 217) ((T_YIELD_FROM) reduce 217) (("[") reduce 217) (("`") reduce 217) (("{") reduce 217) (("~") reduce 217)) 20242 ((("!") reduce 218) (("\"") reduce 218) (("$") reduce 218) (("(") reduce 218) (("+") reduce 218) (("-") reduce 218) ((";") reduce 218) (("@") reduce 218) ((T_ABSTRACT) reduce 218) ((T_ARRAY) reduce 218) ((T_ARRAY_CAST) reduce 218) ((T_ATTRIBUTE) reduce 218) ((T_BOOL_CAST) reduce 218) ((T_BREAK) reduce 218) ((T_CLASS) reduce 218) ((T_CLASS_C) reduce 218) ((T_CLONE) reduce 218) ((T_CONSTANT_ENCAPSED_STRING) reduce 218) ((T_CONTINUE) reduce 218) ((T_DEC) reduce 218) ((T_DECLARE) reduce 218) ((T_DIR) reduce 218) ((T_DNUMBER) reduce 218) ((T_DO) reduce 218) ((T_DOUBLE_CAST) reduce 218) ((T_ECHO) reduce 218) ((T_EMPTY) reduce 218) ((T_ENDDECLARE) reduce 218) ((T_ENUM) reduce 218) ((T_EVAL) reduce 218) ((T_EXIT) reduce 218) ((T_FILE) reduce 218) ((T_FINAL) reduce 218) ((T_FN) reduce 218) ((T_FOR) reduce 218) ((T_FOREACH) reduce 218) ((T_FUNCTION) reduce 218) ((T_FUNC_C) reduce 218) ((T_GLOBAL) reduce 218) ((T_GOTO) reduce 218) ((T_HALT_COMPILER) reduce 218) ((T_IF) reduce 218) ((T_INC) reduce 218) ((T_INCLUDE) reduce 218) ((T_INCLUDE_ONCE) reduce 218) ((T_INLINE_HTML) reduce 218) ((T_INTERFACE) reduce 218) ((T_INT_CAST) reduce 218) ((T_ISSET) reduce 218) ((T_LINE) reduce 218) ((T_LIST) reduce 218) ((T_LNUMBER) reduce 218) ((T_MATCH) reduce 218) ((T_METHOD_C) reduce 218) ((T_NAME_FULLY_QUALIFIED) reduce 218) ((T_NAME_QUALIFIED) reduce 218) ((T_NAME_RELATIVE) reduce 218) ((T_NEW) reduce 218) ((T_NS_C) reduce 218) ((T_OBJECT_CAST) reduce 218) ((T_PRINT) reduce 218) ((T_READONLY) reduce 218) ((T_REQUIRE) reduce 218) ((T_REQUIRE_ONCE) reduce 218) ((T_RETURN) reduce 218) ((T_START_HEREDOC) reduce 218) ((T_STATIC) reduce 218) ((T_STRING) reduce 218) ((T_STRING_CAST) reduce 218) ((T_SWITCH) reduce 218) ((T_THROW) reduce 218) ((T_TRAIT) reduce 218) ((T_TRAIT_C) reduce 218) ((T_TRY) reduce 218) ((T_UNSET) reduce 218) ((T_UNSET_CAST) reduce 218) ((T_VARIABLE) reduce 218) ((T_WHILE) reduce 218) ((T_YIELD) reduce 218) ((T_YIELD_FROM) reduce 218) (("[") reduce 218) (("`") reduce 218) (("{") reduce 218) (("~") reduce 218)) 20243 ((("!") reduce 161) (("\"") reduce 161) (("$") reduce 161) (("(") reduce 161) (("+") reduce 161) (("-") reduce 161) ((";") reduce 161) (("@") reduce 161) ((T_ABSTRACT) reduce 161) ((T_ARRAY) reduce 161) ((T_ARRAY_CAST) reduce 161) ((T_ATTRIBUTE) reduce 161) ((T_BOOL_CAST) reduce 161) ((T_BREAK) reduce 161) ((T_CLASS) reduce 161) ((T_CLASS_C) reduce 161) ((T_CLONE) reduce 161) ((T_CONSTANT_ENCAPSED_STRING) reduce 161) ((T_CONTINUE) reduce 161) ((T_DEC) reduce 161) ((T_DECLARE) reduce 161) ((T_DIR) reduce 161) ((T_DNUMBER) reduce 161) ((T_DO) reduce 161) ((T_DOUBLE_CAST) reduce 161) ((T_ECHO) reduce 161) ((T_EMPTY) reduce 161) ((T_ENDDECLARE) reduce 161) ((T_ENUM) reduce 161) ((T_EVAL) reduce 161) ((T_EXIT) reduce 161) ((T_FILE) reduce 161) ((T_FINAL) reduce 161) ((T_FN) reduce 161) ((T_FOR) reduce 161) ((T_FOREACH) reduce 161) ((T_FUNCTION) reduce 161) ((T_FUNC_C) reduce 161) ((T_GLOBAL) reduce 161) ((T_GOTO) reduce 161) ((T_HALT_COMPILER) reduce 161) ((T_IF) reduce 161) ((T_INC) reduce 161) ((T_INCLUDE) reduce 161) ((T_INCLUDE_ONCE) reduce 161) ((T_INLINE_HTML) reduce 161) ((T_INTERFACE) reduce 161) ((T_INT_CAST) reduce 161) ((T_ISSET) reduce 161) ((T_LINE) reduce 161) ((T_LIST) reduce 161) ((T_LNUMBER) reduce 161) ((T_MATCH) reduce 161) ((T_METHOD_C) reduce 161) ((T_NAME_FULLY_QUALIFIED) reduce 161) ((T_NAME_QUALIFIED) reduce 161) ((T_NAME_RELATIVE) reduce 161) ((T_NEW) reduce 161) ((T_NS_C) reduce 161) ((T_OBJECT_CAST) reduce 161) ((T_PRINT) reduce 161) ((T_READONLY) reduce 161) ((T_REQUIRE) reduce 161) ((T_REQUIRE_ONCE) reduce 161) ((T_RETURN) reduce 161) ((T_START_HEREDOC) reduce 161) ((T_STATIC) reduce 161) ((T_STRING) reduce 161) ((T_STRING_CAST) reduce 161) ((T_SWITCH) reduce 161) ((T_THROW) reduce 161) ((T_TRAIT) reduce 161) ((T_TRAIT_C) reduce 161) ((T_TRY) reduce 161) ((T_UNSET) reduce 161) ((T_UNSET_CAST) reduce 161) ((T_VARIABLE) reduce 161) ((T_WHILE) reduce 161) ((T_YIELD) reduce 161) ((T_YIELD_FROM) reduce 161) (("[") reduce 161) (("`") reduce 161) (("{") reduce 161) (("~") reduce 161)) 20252 ((("!") reduce 150) (("\"") reduce 150) (("$") reduce 150) (("(") reduce 150) (("+") reduce 150) (("-") reduce 150) ((";") reduce 150) (("@") reduce 150) ((T_ABSTRACT) reduce 150) ((T_ARRAY) reduce 150) ((T_ARRAY_CAST) reduce 150) ((T_ATTRIBUTE) reduce 150) ((T_BOOL_CAST) reduce 150) ((T_BREAK) reduce 150) ((T_CLASS) reduce 150) ((T_CLASS_C) reduce 150) ((T_CLONE) reduce 150) ((T_CONSTANT_ENCAPSED_STRING) reduce 150) ((T_CONTINUE) reduce 150) ((T_DEC) reduce 150) ((T_DECLARE) reduce 150) ((T_DIR) reduce 150) ((T_DNUMBER) reduce 150) ((T_DO) reduce 150) ((T_DOUBLE_CAST) reduce 150) ((T_ECHO) reduce 150) ((T_EMPTY) reduce 150) ((T_ENDDECLARE) reduce 150) ((T_ENUM) reduce 150) ((T_EVAL) reduce 150) ((T_EXIT) reduce 150) ((T_FILE) reduce 150) ((T_FINAL) reduce 150) ((T_FN) reduce 150) ((T_FOR) reduce 150) ((T_FOREACH) reduce 150) ((T_FUNCTION) reduce 150) ((T_FUNC_C) reduce 150) ((T_GLOBAL) reduce 150) ((T_GOTO) reduce 150) ((T_HALT_COMPILER) reduce 150) ((T_IF) reduce 150) ((T_INC) reduce 150) ((T_INCLUDE) reduce 150) ((T_INCLUDE_ONCE) reduce 150) ((T_INLINE_HTML) reduce 150) ((T_INTERFACE) reduce 150) ((T_INT_CAST) reduce 150) ((T_ISSET) reduce 150) ((T_LINE) reduce 150) ((T_LIST) reduce 150) ((T_LNUMBER) reduce 150) ((T_MATCH) reduce 150) ((T_METHOD_C) reduce 150) ((T_NAME_FULLY_QUALIFIED) reduce 150) ((T_NAME_QUALIFIED) reduce 150) ((T_NAME_RELATIVE) reduce 150) ((T_NEW) reduce 150) ((T_NS_C) reduce 150) ((T_OBJECT_CAST) reduce 150) ((T_PRINT) reduce 150) ((T_READONLY) reduce 150) ((T_REQUIRE) reduce 150) ((T_REQUIRE_ONCE) reduce 150) ((T_RETURN) reduce 150) ((T_START_HEREDOC) reduce 150) ((T_STATIC) reduce 150) ((T_STRING) reduce 150) ((T_STRING_CAST) reduce 150) ((T_SWITCH) reduce 150) ((T_THROW) reduce 150) ((T_TRAIT) reduce 150) ((T_TRAIT_C) reduce 150) ((T_TRY) reduce 150) ((T_UNSET) reduce 150) ((T_UNSET_CAST) reduce 150) ((T_VARIABLE) reduce 150) ((T_WHILE) reduce 150) ((T_YIELD) reduce 150) ((T_YIELD_FROM) reduce 150) (("[") reduce 150) (("`") reduce 150) (("{") reduce 150) (("~") reduce 150)) 20253 ((("!") reduce 215) (("\"") reduce 215) (("$") reduce 215) (("(") reduce 215) (("+") reduce 215) (("-") reduce 215) ((";") reduce 215) (("@") reduce 215) ((T_ABSTRACT) reduce 215) ((T_ARRAY) reduce 215) ((T_ARRAY_CAST) reduce 215) ((T_ATTRIBUTE) reduce 215) ((T_BOOL_CAST) reduce 215) ((T_BREAK) reduce 215) ((T_CLASS) reduce 215) ((T_CLASS_C) reduce 215) ((T_CLONE) reduce 215) ((T_CONSTANT_ENCAPSED_STRING) reduce 215) ((T_CONTINUE) reduce 215) ((T_DEC) reduce 215) ((T_DECLARE) reduce 215) ((T_DIR) reduce 215) ((T_DNUMBER) reduce 215) ((T_DO) reduce 215) ((T_DOUBLE_CAST) reduce 215) ((T_ECHO) reduce 215) ((T_EMPTY) reduce 215) ((T_ENDDECLARE) reduce 215) ((T_ENUM) reduce 215) ((T_EVAL) reduce 215) ((T_EXIT) reduce 215) ((T_FILE) reduce 215) ((T_FINAL) reduce 215) ((T_FN) reduce 215) ((T_FOR) reduce 215) ((T_FOREACH) reduce 215) ((T_FUNCTION) reduce 215) ((T_FUNC_C) reduce 215) ((T_GLOBAL) reduce 215) ((T_GOTO) reduce 215) ((T_HALT_COMPILER) reduce 215) ((T_IF) reduce 215) ((T_INC) reduce 215) ((T_INCLUDE) reduce 215) ((T_INCLUDE_ONCE) reduce 215) ((T_INLINE_HTML) reduce 215) ((T_INTERFACE) reduce 215) ((T_INT_CAST) reduce 215) ((T_ISSET) reduce 215) ((T_LINE) reduce 215) ((T_LIST) reduce 215) ((T_LNUMBER) reduce 215) ((T_MATCH) reduce 215) ((T_METHOD_C) reduce 215) ((T_NAME_FULLY_QUALIFIED) reduce 215) ((T_NAME_QUALIFIED) reduce 215) ((T_NAME_RELATIVE) reduce 215) ((T_NEW) reduce 215) ((T_NS_C) reduce 215) ((T_OBJECT_CAST) reduce 215) ((T_PRINT) reduce 215) ((T_READONLY) reduce 215) ((T_REQUIRE) reduce 215) ((T_REQUIRE_ONCE) reduce 215) ((T_RETURN) reduce 215) ((T_START_HEREDOC) reduce 215) ((T_STATIC) reduce 215) ((T_STRING) reduce 215) ((T_STRING_CAST) reduce 215) ((T_SWITCH) reduce 215) ((T_THROW) reduce 215) ((T_TRAIT) reduce 215) ((T_TRAIT_C) reduce 215) ((T_TRY) reduce 215) ((T_UNSET) reduce 215) ((T_UNSET_CAST) reduce 215) ((T_VARIABLE) reduce 215) ((T_WHILE) reduce 215) ((T_YIELD) reduce 215) ((T_YIELD_FROM) reduce 215) (("[") reduce 215) (("`") reduce 215) (("{") reduce 215) (("~") reduce 215)) 20256 ((("!") reduce 216) (("\"") reduce 216) (("$") reduce 216) (("(") reduce 216) (("+") reduce 216) (("-") reduce 216) ((";") reduce 216) (("@") reduce 216) ((T_ABSTRACT) reduce 216) ((T_ARRAY) reduce 216) ((T_ARRAY_CAST) reduce 216) ((T_ATTRIBUTE) reduce 216) ((T_BOOL_CAST) reduce 216) ((T_BREAK) reduce 216) ((T_CLASS) reduce 216) ((T_CLASS_C) reduce 216) ((T_CLONE) reduce 216) ((T_CONSTANT_ENCAPSED_STRING) reduce 216) ((T_CONTINUE) reduce 216) ((T_DEC) reduce 216) ((T_DECLARE) reduce 216) ((T_DIR) reduce 216) ((T_DNUMBER) reduce 216) ((T_DO) reduce 216) ((T_DOUBLE_CAST) reduce 216) ((T_ECHO) reduce 216) ((T_EMPTY) reduce 216) ((T_ENDDECLARE) reduce 216) ((T_ENUM) reduce 216) ((T_EVAL) reduce 216) ((T_EXIT) reduce 216) ((T_FILE) reduce 216) ((T_FINAL) reduce 216) ((T_FN) reduce 216) ((T_FOR) reduce 216) ((T_FOREACH) reduce 216) ((T_FUNCTION) reduce 216) ((T_FUNC_C) reduce 216) ((T_GLOBAL) reduce 216) ((T_GOTO) reduce 216) ((T_HALT_COMPILER) reduce 216) ((T_IF) reduce 216) ((T_INC) reduce 216) ((T_INCLUDE) reduce 216) ((T_INCLUDE_ONCE) reduce 216) ((T_INLINE_HTML) reduce 216) ((T_INTERFACE) reduce 216) ((T_INT_CAST) reduce 216) ((T_ISSET) reduce 216) ((T_LINE) reduce 216) ((T_LIST) reduce 216) ((T_LNUMBER) reduce 216) ((T_MATCH) reduce 216) ((T_METHOD_C) reduce 216) ((T_NAME_FULLY_QUALIFIED) reduce 216) ((T_NAME_QUALIFIED) reduce 216) ((T_NAME_RELATIVE) reduce 216) ((T_NEW) reduce 216) ((T_NS_C) reduce 216) ((T_OBJECT_CAST) reduce 216) ((T_PRINT) reduce 216) ((T_READONLY) reduce 216) ((T_REQUIRE) reduce 216) ((T_REQUIRE_ONCE) reduce 216) ((T_RETURN) reduce 216) ((T_START_HEREDOC) reduce 216) ((T_STATIC) reduce 216) ((T_STRING) reduce 216) ((T_STRING_CAST) reduce 216) ((T_SWITCH) reduce 216) ((T_THROW) reduce 216) ((T_TRAIT) reduce 216) ((T_TRAIT_C) reduce 216) ((T_TRY) reduce 216) ((T_UNSET) reduce 216) ((T_UNSET_CAST) reduce 216) ((T_VARIABLE) reduce 216) ((T_WHILE) reduce 216) ((T_YIELD) reduce 216) ((T_YIELD_FROM) reduce 216) (("[") reduce 216) (("`") reduce 216) (("{") reduce 216) (("~") reduce 216)) 20257 (((":") shift) ((T_IMPLEMENTS) reduce 200) (("{") reduce 200)) 20264 ((("!") reduce 199) (("\"") reduce 199) (("$") reduce 199) (("(") reduce 199) (("+") reduce 199) (("-") reduce 199) ((";") reduce 199) (("@") reduce 199) ((T_ABSTRACT) reduce 199) ((T_ARRAY) reduce 199) ((T_ARRAY_CAST) reduce 199) ((T_ATTRIBUTE) reduce 199) ((T_BOOL_CAST) reduce 199) ((T_BREAK) reduce 199) ((T_CLASS) reduce 199) ((T_CLASS_C) reduce 199) ((T_CLONE) reduce 199) ((T_CONSTANT_ENCAPSED_STRING) reduce 199) ((T_CONTINUE) reduce 199) ((T_DEC) reduce 199) ((T_DECLARE) reduce 199) ((T_DIR) reduce 199) ((T_DNUMBER) reduce 199) ((T_DO) reduce 199) ((T_DOUBLE_CAST) reduce 199) ((T_ECHO) reduce 199) ((T_EMPTY) reduce 199) ((T_ENDDECLARE) reduce 199) ((T_ENUM) reduce 199) ((T_EVAL) reduce 199) ((T_EXIT) reduce 199) ((T_FILE) reduce 199) ((T_FINAL) reduce 199) ((T_FN) reduce 199) ((T_FOR) reduce 199) ((T_FOREACH) reduce 199) ((T_FUNCTION) reduce 199) ((T_FUNC_C) reduce 199) ((T_GLOBAL) reduce 199) ((T_GOTO) reduce 199) ((T_HALT_COMPILER) reduce 199) ((T_IF) reduce 199) ((T_INC) reduce 199) ((T_INCLUDE) reduce 199) ((T_INCLUDE_ONCE) reduce 199) ((T_INLINE_HTML) reduce 199) ((T_INTERFACE) reduce 199) ((T_INT_CAST) reduce 199) ((T_ISSET) reduce 199) ((T_LINE) reduce 199) ((T_LIST) reduce 199) ((T_LNUMBER) reduce 199) ((T_MATCH) reduce 199) ((T_METHOD_C) reduce 199) ((T_NAME_FULLY_QUALIFIED) reduce 199) ((T_NAME_QUALIFIED) reduce 199) ((T_NAME_RELATIVE) reduce 199) ((T_NEW) reduce 199) ((T_NS_C) reduce 199) ((T_OBJECT_CAST) reduce 199) ((T_PRINT) reduce 199) ((T_READONLY) reduce 199) ((T_REQUIRE) reduce 199) ((T_REQUIRE_ONCE) reduce 199) ((T_RETURN) reduce 199) ((T_START_HEREDOC) reduce 199) ((T_STATIC) reduce 199) ((T_STRING) reduce 199) ((T_STRING_CAST) reduce 199) ((T_SWITCH) reduce 199) ((T_THROW) reduce 199) ((T_TRAIT) reduce 199) ((T_TRAIT_C) reduce 199) ((T_TRY) reduce 199) ((T_UNSET) reduce 199) ((T_UNSET_CAST) reduce 199) ((T_VARIABLE) reduce 199) ((T_WHILE) reduce 199) ((T_YIELD) reduce 199) ((T_YIELD_FROM) reduce 199) (("[") reduce 199) (("`") reduce 199) (("{") reduce 199) (("~") reduce 199)) 20266 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 277) ((T_IMPLEMENTS) reduce 277) (("{") reduce 277) (("|") reduce 277)) 20267 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 278) ((T_IMPLEMENTS) reduce 278) (("{") reduce 278) (("|") reduce 278)) 20268 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_IMPLEMENTS) reduce 93) (("{") reduce 93) (("|") reduce 93)) 20269 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_IMPLEMENTS) reduce 92) (("{") reduce 92) (("|") reduce 92)) 20270 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_IMPLEMENTS) reduce 94) (("{") reduce 94) (("|") reduce 94)) 20271 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 266) ((T_IMPLEMENTS) reduce 266) (("{") reduce 266) (("|") reduce 266)) 20272 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_IMPLEMENTS) reduce 91) (("{") reduce 91) (("|") reduce 91)) 20273 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_IMPLEMENTS) reduce 264) (("{") reduce 264)) 20274 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 279) ((T_IMPLEMENTS) reduce 279) (("{") reduce 279) (("|") reduce 279)) 20275 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_IMPLEMENTS) reduce 261) (("{") reduce 261) (("|") reduce 267)) 20276 (((T_IMPLEMENTS) reduce 201) (("{") reduce 201)) 20277 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 265) ((T_IMPLEMENTS) reduce 265) (("{") reduce 265) (("|") reduce 265)) 20278 (((T_IMPLEMENTS) reduce 263) (("{") reduce 263) (("|") shift)) 20282 (((T_IMPLEMENTS) reduce 277) (("{") reduce 277) (("|") reduce 277)) 20283 (((T_IMPLEMENTS) reduce 278) (("{") reduce 278) (("|") reduce 278)) 20284 (((T_IMPLEMENTS) reduce 93) (("{") reduce 93) (("|") reduce 93)) 20285 (((T_IMPLEMENTS) reduce 92) (("{") reduce 92) (("|") reduce 92)) 20286 (((T_IMPLEMENTS) reduce 94) (("{") reduce 94) (("|") reduce 94)) 20287 (((T_IMPLEMENTS) reduce 266) (("{") reduce 266) (("|") reduce 266)) 20288 (((T_IMPLEMENTS) reduce 91) (("{") reduce 91) (("|") reduce 91)) 20289 (((T_IMPLEMENTS) reduce 279) (("{") reduce 279) (("|") reduce 279)) 20290 (((T_IMPLEMENTS) reduce 267) (("{") reduce 267) (("|") reduce 267)) 20291 (((T_IMPLEMENTS) reduce 265) (("{") reduce 265) (("|") reduce 265)) 20292 (((T_IMPLEMENTS) reduce 269) (("{") reduce 269) (("|") reduce 269)) 20294 (((T_IMPLEMENTS) reduce 268) (("{") reduce 268) (("|") reduce 268)) 20296 (((T_IMPLEMENTS) reduce 270) (("{") reduce 270) (("|") reduce 270)) 20298 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 277) ((T_IMPLEMENTS) reduce 277) (("{") reduce 277)) 20299 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 278) ((T_IMPLEMENTS) reduce 278) (("{") reduce 278)) 20300 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_IMPLEMENTS) reduce 93) (("{") reduce 93)) 20301 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_IMPLEMENTS) reduce 92) (("{") reduce 92)) 20302 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_IMPLEMENTS) reduce 94) (("{") reduce 94)) 20303 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 266) ((T_IMPLEMENTS) reduce 266) (("{") reduce 266)) 20304 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_IMPLEMENTS) reduce 91) (("{") reduce 91)) 20305 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 279) ((T_IMPLEMENTS) reduce 279) (("{") reduce 279)) 20306 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 271) ((T_IMPLEMENTS) reduce 271) (("{") reduce 271)) 20307 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 265) ((T_IMPLEMENTS) reduce 265) (("{") reduce 265)) 20309 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 272) ((T_IMPLEMENTS) reduce 272) (("{") reduce 272)) 20310 (((T_IMPLEMENTS) reduce 277) (("{") reduce 277)) 20311 (((T_IMPLEMENTS) reduce 278) (("{") reduce 278)) 20312 (((T_IMPLEMENTS) reduce 266) (("{") reduce 266)) 20313 (((T_IMPLEMENTS) reduce 279) (("{") reduce 279)) 20314 (((T_IMPLEMENTS) reduce 262) (("{") reduce 262)) 20315 (((T_IMPLEMENTS) reduce 265) (("{") reduce 265)) 20316 (((T_ELSE) reduce 220) ((T_ELSEIF) reduce 220) ((T_WHILE) reduce 220)) 20318 ((("!") reduce 157) (("\"") reduce 157) (("$") reduce 157) (("(") reduce 157) (("+") reduce 157) (("-") reduce 157) ((";") reduce 157) (("@") reduce 157) ((T_ABSTRACT) reduce 157) ((T_ARRAY) reduce 157) ((T_ARRAY_CAST) reduce 157) ((T_ATTRIBUTE) reduce 157) ((T_BOOL_CAST) reduce 157) ((T_BREAK) reduce 157) ((T_CLASS) reduce 157) ((T_CLASS_C) reduce 157) ((T_CLONE) reduce 157) ((T_CONSTANT_ENCAPSED_STRING) reduce 157) ((T_CONTINUE) reduce 157) ((T_DEC) reduce 157) ((T_DECLARE) reduce 157) ((T_DIR) reduce 157) ((T_DNUMBER) reduce 157) ((T_DO) reduce 157) ((T_DOUBLE_CAST) reduce 157) ((T_ECHO) reduce 157) ((T_EMPTY) reduce 157) ((T_ENDDECLARE) reduce 157) ((T_ENUM) reduce 157) ((T_EVAL) reduce 157) ((T_EXIT) reduce 157) ((T_FILE) reduce 157) ((T_FINAL) reduce 157) ((T_FN) reduce 157) ((T_FOR) reduce 157) ((T_FOREACH) reduce 157) ((T_FUNCTION) reduce 157) ((T_FUNC_C) reduce 157) ((T_GLOBAL) reduce 157) ((T_GOTO) reduce 157) ((T_HALT_COMPILER) reduce 157) ((T_IF) reduce 157) ((T_INC) reduce 157) ((T_INCLUDE) reduce 157) ((T_INCLUDE_ONCE) reduce 157) ((T_INLINE_HTML) reduce 157) ((T_INTERFACE) reduce 157) ((T_INT_CAST) reduce 157) ((T_ISSET) reduce 157) ((T_LINE) reduce 157) ((T_LIST) reduce 157) ((T_LNUMBER) reduce 157) ((T_MATCH) reduce 157) ((T_METHOD_C) reduce 157) ((T_NAME_FULLY_QUALIFIED) reduce 157) ((T_NAME_QUALIFIED) reduce 157) ((T_NAME_RELATIVE) reduce 157) ((T_NEW) reduce 157) ((T_NS_C) reduce 157) ((T_OBJECT_CAST) reduce 157) ((T_PRINT) reduce 157) ((T_READONLY) reduce 157) ((T_REQUIRE) reduce 157) ((T_REQUIRE_ONCE) reduce 157) ((T_RETURN) reduce 157) ((T_START_HEREDOC) reduce 157) ((T_STATIC) reduce 157) ((T_STRING) reduce 157) ((T_STRING_CAST) reduce 157) ((T_SWITCH) reduce 157) ((T_THROW) reduce 157) ((T_TRAIT) reduce 157) ((T_TRAIT_C) reduce 157) ((T_TRY) reduce 157) ((T_UNSET) reduce 157) ((T_UNSET_CAST) reduce 157) ((T_VARIABLE) reduce 157) ((T_WHILE) reduce 157) ((T_YIELD) reduce 157) ((T_YIELD_FROM) reduce 157) (("[") reduce 157) (("`") reduce 157) (("{") reduce 157) (("~") reduce 157)) 20324 ((("!") reduce 149) (("\"") reduce 149) (("$") reduce 149) (("(") reduce 149) (("+") reduce 149) (("-") reduce 149) ((";") reduce 149) (("@") reduce 149) ((T_ABSTRACT) reduce 149) ((T_ARRAY) reduce 149) ((T_ARRAY_CAST) reduce 149) ((T_ATTRIBUTE) reduce 149) ((T_BOOL_CAST) reduce 149) ((T_BREAK) reduce 149) ((T_CLASS) reduce 149) ((T_CLASS_C) reduce 149) ((T_CLONE) reduce 149) ((T_CONSTANT_ENCAPSED_STRING) reduce 149) ((T_CONTINUE) reduce 149) ((T_DEC) reduce 149) ((T_DECLARE) reduce 149) ((T_DIR) reduce 149) ((T_DNUMBER) reduce 149) ((T_DO) reduce 149) ((T_DOUBLE_CAST) reduce 149) ((T_ECHO) reduce 149) ((T_EMPTY) reduce 149) ((T_ENDDECLARE) reduce 149) ((T_ENUM) reduce 149) ((T_EVAL) reduce 149) ((T_EXIT) reduce 149) ((T_FILE) reduce 149) ((T_FINAL) reduce 149) ((T_FN) reduce 149) ((T_FOR) reduce 149) ((T_FOREACH) reduce 149) ((T_FUNCTION) reduce 149) ((T_FUNC_C) reduce 149) ((T_GLOBAL) reduce 149) ((T_GOTO) reduce 149) ((T_HALT_COMPILER) reduce 149) ((T_IF) reduce 149) ((T_INC) reduce 149) ((T_INCLUDE) reduce 149) ((T_INCLUDE_ONCE) reduce 149) ((T_INLINE_HTML) reduce 149) ((T_INTERFACE) reduce 149) ((T_INT_CAST) reduce 149) ((T_ISSET) reduce 149) ((T_LINE) reduce 149) ((T_LIST) reduce 149) ((T_LNUMBER) reduce 149) ((T_MATCH) reduce 149) ((T_METHOD_C) reduce 149) ((T_NAME_FULLY_QUALIFIED) reduce 149) ((T_NAME_QUALIFIED) reduce 149) ((T_NAME_RELATIVE) reduce 149) ((T_NEW) reduce 149) ((T_NS_C) reduce 149) ((T_OBJECT_CAST) reduce 149) ((T_PRINT) reduce 149) ((T_READONLY) reduce 149) ((T_REQUIRE) reduce 149) ((T_REQUIRE_ONCE) reduce 149) ((T_RETURN) reduce 149) ((T_START_HEREDOC) reduce 149) ((T_STATIC) reduce 149) ((T_STRING) reduce 149) ((T_STRING_CAST) reduce 149) ((T_SWITCH) reduce 149) ((T_THROW) reduce 149) ((T_TRAIT) reduce 149) ((T_TRAIT_C) reduce 149) ((T_TRY) reduce 149) ((T_UNSET) reduce 149) ((T_UNSET_CAST) reduce 149) ((T_VARIABLE) reduce 149) ((T_WHILE) reduce 149) ((T_YIELD) reduce 149) ((T_YIELD_FROM) reduce 149) (("[") reduce 149) (("`") reduce 149) (("{") reduce 149) (("~") reduce 149)) 20329 ((("!") reduce 163) (("\"") reduce 163) (("$") reduce 163) (("(") reduce 163) (("+") reduce 163) (("-") reduce 163) ((";") reduce 163) (("@") reduce 163) ((T_ABSTRACT) reduce 163) ((T_ARRAY) reduce 163) ((T_ARRAY_CAST) reduce 163) ((T_ATTRIBUTE) reduce 163) ((T_BOOL_CAST) reduce 163) ((T_BREAK) reduce 163) ((T_CLASS) reduce 163) ((T_CLASS_C) reduce 163) ((T_CLONE) reduce 163) ((T_CONSTANT_ENCAPSED_STRING) reduce 163) ((T_CONTINUE) reduce 163) ((T_DEC) reduce 163) ((T_DECLARE) reduce 163) ((T_DIR) reduce 163) ((T_DNUMBER) reduce 163) ((T_DO) reduce 163) ((T_DOUBLE_CAST) reduce 163) ((T_ECHO) reduce 163) ((T_EMPTY) reduce 163) ((T_ENDDECLARE) reduce 163) ((T_ENUM) reduce 163) ((T_EVAL) reduce 163) ((T_EXIT) reduce 163) ((T_FILE) reduce 163) ((T_FINAL) reduce 163) ((T_FN) reduce 163) ((T_FOR) reduce 163) ((T_FOREACH) reduce 163) ((T_FUNCTION) reduce 163) ((T_FUNC_C) reduce 163) ((T_GLOBAL) reduce 163) ((T_GOTO) reduce 163) ((T_HALT_COMPILER) reduce 163) ((T_IF) reduce 163) ((T_INC) reduce 163) ((T_INCLUDE) reduce 163) ((T_INCLUDE_ONCE) reduce 163) ((T_INLINE_HTML) reduce 163) ((T_INTERFACE) reduce 163) ((T_INT_CAST) reduce 163) ((T_ISSET) reduce 163) ((T_LINE) reduce 163) ((T_LIST) reduce 163) ((T_LNUMBER) reduce 163) ((T_MATCH) reduce 163) ((T_METHOD_C) reduce 163) ((T_NAME_FULLY_QUALIFIED) reduce 163) ((T_NAME_QUALIFIED) reduce 163) ((T_NAME_RELATIVE) reduce 163) ((T_NEW) reduce 163) ((T_NS_C) reduce 163) ((T_OBJECT_CAST) reduce 163) ((T_PRINT) reduce 163) ((T_READONLY) reduce 163) ((T_REQUIRE) reduce 163) ((T_REQUIRE_ONCE) reduce 163) ((T_RETURN) reduce 163) ((T_START_HEREDOC) reduce 163) ((T_STATIC) reduce 163) ((T_STRING) reduce 163) ((T_STRING_CAST) reduce 163) ((T_SWITCH) reduce 163) ((T_THROW) reduce 163) ((T_TRAIT) reduce 163) ((T_TRAIT_C) reduce 163) ((T_TRY) reduce 163) ((T_UNSET) reduce 163) ((T_UNSET_CAST) reduce 163) ((T_VARIABLE) reduce 163) ((T_WHILE) reduce 163) ((T_YIELD) reduce 163) ((T_YIELD_FROM) reduce 163) (("[") reduce 163) (("`") reduce 163) (("{") reduce 163) (("~") reduce 163)) 20330 ((("!") reduce 219) (("\"") reduce 219) (("$") reduce 219) (("(") reduce 219) (("+") reduce 219) (("-") reduce 219) ((";") reduce 219) (("@") reduce 219) ((T_ABSTRACT) reduce 219) ((T_ARRAY) reduce 219) ((T_ARRAY_CAST) reduce 219) ((T_ATTRIBUTE) reduce 219) ((T_BOOL_CAST) reduce 219) ((T_BREAK) reduce 219) ((T_CLASS) reduce 219) ((T_CLASS_C) reduce 219) ((T_CLONE) reduce 219) ((T_CONSTANT_ENCAPSED_STRING) reduce 219) ((T_CONTINUE) reduce 219) ((T_DEC) reduce 219) ((T_DECLARE) reduce 219) ((T_DIR) reduce 219) ((T_DNUMBER) reduce 219) ((T_DO) reduce 219) ((T_DOUBLE_CAST) reduce 219) ((T_ECHO) reduce 219) ((T_EMPTY) reduce 219) ((T_ENDDECLARE) reduce 219) ((T_ENUM) reduce 219) ((T_EVAL) reduce 219) ((T_EXIT) reduce 219) ((T_FILE) reduce 219) ((T_FINAL) reduce 219) ((T_FN) reduce 219) ((T_FOR) reduce 219) ((T_FOREACH) reduce 219) ((T_FUNCTION) reduce 219) ((T_FUNC_C) reduce 219) ((T_GLOBAL) reduce 219) ((T_GOTO) reduce 219) ((T_HALT_COMPILER) reduce 219) ((T_IF) reduce 219) ((T_INC) reduce 219) ((T_INCLUDE) reduce 219) ((T_INCLUDE_ONCE) reduce 219) ((T_INLINE_HTML) reduce 219) ((T_INTERFACE) reduce 219) ((T_INT_CAST) reduce 219) ((T_ISSET) reduce 219) ((T_LINE) reduce 219) ((T_LIST) reduce 219) ((T_LNUMBER) reduce 219) ((T_MATCH) reduce 219) ((T_METHOD_C) reduce 219) ((T_NAME_FULLY_QUALIFIED) reduce 219) ((T_NAME_QUALIFIED) reduce 219) ((T_NAME_RELATIVE) reduce 219) ((T_NEW) reduce 219) ((T_NS_C) reduce 219) ((T_OBJECT_CAST) reduce 219) ((T_PRINT) reduce 219) ((T_READONLY) reduce 219) ((T_REQUIRE) reduce 219) ((T_REQUIRE_ONCE) reduce 219) ((T_RETURN) reduce 219) ((T_START_HEREDOC) reduce 219) ((T_STATIC) reduce 219) ((T_STRING) reduce 219) ((T_STRING_CAST) reduce 219) ((T_SWITCH) reduce 219) ((T_THROW) reduce 219) ((T_TRAIT) reduce 219) ((T_TRAIT_C) reduce 219) ((T_TRY) reduce 219) ((T_UNSET) reduce 219) ((T_UNSET_CAST) reduce 219) ((T_VARIABLE) reduce 219) ((T_WHILE) reduce 219) ((T_YIELD) reduce 219) ((T_YIELD_FROM) reduce 219) (("[") reduce 219) (("`") reduce 219) (("{") reduce 219) (("~") reduce 219)) 20333 ((("!") reduce 220) (("\"") reduce 220) (("$") reduce 220) (("(") reduce 220) (("+") reduce 220) (("-") reduce 220) ((";") reduce 220) (("@") reduce 220) ((T_ABSTRACT) reduce 220) ((T_ARRAY) reduce 220) ((T_ARRAY_CAST) reduce 220) ((T_ATTRIBUTE) reduce 220) ((T_BOOL_CAST) reduce 220) ((T_BREAK) reduce 220) ((T_CLASS) reduce 220) ((T_CLASS_C) reduce 220) ((T_CLONE) reduce 220) ((T_CONSTANT_ENCAPSED_STRING) reduce 220) ((T_CONTINUE) reduce 220) ((T_DEC) reduce 220) ((T_DECLARE) reduce 220) ((T_DIR) reduce 220) ((T_DNUMBER) reduce 220) ((T_DO) reduce 220) ((T_DOUBLE_CAST) reduce 220) ((T_ECHO) reduce 220) ((T_EMPTY) reduce 220) ((T_ENDDECLARE) reduce 220) ((T_ENUM) reduce 220) ((T_EVAL) reduce 220) ((T_EXIT) reduce 220) ((T_FILE) reduce 220) ((T_FINAL) reduce 220) ((T_FN) reduce 220) ((T_FOR) reduce 220) ((T_FOREACH) reduce 220) ((T_FUNCTION) reduce 220) ((T_FUNC_C) reduce 220) ((T_GLOBAL) reduce 220) ((T_GOTO) reduce 220) ((T_HALT_COMPILER) reduce 220) ((T_IF) reduce 220) ((T_INC) reduce 220) ((T_INCLUDE) reduce 220) ((T_INCLUDE_ONCE) reduce 220) ((T_INLINE_HTML) reduce 220) ((T_INTERFACE) reduce 220) ((T_INT_CAST) reduce 220) ((T_ISSET) reduce 220) ((T_LINE) reduce 220) ((T_LIST) reduce 220) ((T_LNUMBER) reduce 220) ((T_MATCH) reduce 220) ((T_METHOD_C) reduce 220) ((T_NAME_FULLY_QUALIFIED) reduce 220) ((T_NAME_QUALIFIED) reduce 220) ((T_NAME_RELATIVE) reduce 220) ((T_NEW) reduce 220) ((T_NS_C) reduce 220) ((T_OBJECT_CAST) reduce 220) ((T_PRINT) reduce 220) ((T_READONLY) reduce 220) ((T_REQUIRE) reduce 220) ((T_REQUIRE_ONCE) reduce 220) ((T_RETURN) reduce 220) ((T_START_HEREDOC) reduce 220) ((T_STATIC) reduce 220) ((T_STRING) reduce 220) ((T_STRING_CAST) reduce 220) ((T_SWITCH) reduce 220) ((T_THROW) reduce 220) ((T_TRAIT) reduce 220) ((T_TRAIT_C) reduce 220) ((T_TRY) reduce 220) ((T_UNSET) reduce 220) ((T_UNSET_CAST) reduce 220) ((T_VARIABLE) reduce 220) ((T_WHILE) reduce 220) ((T_YIELD) reduce 220) ((T_YIELD_FROM) reduce 220) (("[") reduce 220) (("`") reduce 220) (("{") reduce 220) (("~") reduce 220)) 20335 ((("!") reduce 153) (("\"") reduce 153) (("$") reduce 153) (("(") reduce 153) (("+") reduce 153) (("-") reduce 153) ((";") reduce 153) (("@") reduce 153) ((T_ABSTRACT) reduce 153) ((T_ARRAY) reduce 153) ((T_ARRAY_CAST) reduce 153) ((T_ATTRIBUTE) reduce 153) ((T_BOOL_CAST) reduce 153) ((T_BREAK) reduce 153) ((T_CLASS) reduce 153) ((T_CLASS_C) reduce 153) ((T_CLONE) reduce 153) ((T_CONSTANT_ENCAPSED_STRING) reduce 153) ((T_CONTINUE) reduce 153) ((T_DEC) reduce 153) ((T_DECLARE) reduce 153) ((T_DIR) reduce 153) ((T_DNUMBER) reduce 153) ((T_DO) reduce 153) ((T_DOUBLE_CAST) reduce 153) ((T_ECHO) reduce 153) ((T_EMPTY) reduce 153) ((T_ENDDECLARE) reduce 153) ((T_ENUM) reduce 153) ((T_EVAL) reduce 153) ((T_EXIT) reduce 153) ((T_FILE) reduce 153) ((T_FINAL) reduce 153) ((T_FN) reduce 153) ((T_FOR) reduce 153) ((T_FOREACH) reduce 153) ((T_FUNCTION) reduce 153) ((T_FUNC_C) reduce 153) ((T_GLOBAL) reduce 153) ((T_GOTO) reduce 153) ((T_HALT_COMPILER) reduce 153) ((T_IF) reduce 153) ((T_INC) reduce 153) ((T_INCLUDE) reduce 153) ((T_INCLUDE_ONCE) reduce 153) ((T_INLINE_HTML) reduce 153) ((T_INTERFACE) reduce 153) ((T_INT_CAST) reduce 153) ((T_ISSET) reduce 153) ((T_LINE) reduce 153) ((T_LIST) reduce 153) ((T_LNUMBER) reduce 153) ((T_MATCH) reduce 153) ((T_METHOD_C) reduce 153) ((T_NAME_FULLY_QUALIFIED) reduce 153) ((T_NAME_QUALIFIED) reduce 153) ((T_NAME_RELATIVE) reduce 153) ((T_NEW) reduce 153) ((T_NS_C) reduce 153) ((T_OBJECT_CAST) reduce 153) ((T_PRINT) reduce 153) ((T_READONLY) reduce 153) ((T_REQUIRE) reduce 153) ((T_REQUIRE_ONCE) reduce 153) ((T_RETURN) reduce 153) ((T_START_HEREDOC) reduce 153) ((T_STATIC) reduce 153) ((T_STRING) reduce 153) ((T_STRING_CAST) reduce 153) ((T_SWITCH) reduce 153) ((T_THROW) reduce 153) ((T_TRAIT) reduce 153) ((T_TRAIT_C) reduce 153) ((T_TRY) reduce 153) ((T_UNSET) reduce 153) ((T_UNSET_CAST) reduce 153) ((T_VARIABLE) reduce 153) ((T_WHILE) reduce 153) ((T_YIELD) reduce 153) ((T_YIELD_FROM) reduce 153) (("[") reduce 153) (("`") reduce 153) (("{") reduce 153) (("~") reduce 153)) 20342 ((("!") reduce 187) (("\"") reduce 187) (("$") reduce 187) (("(") reduce 187) (("+") reduce 187) (("-") reduce 187) ((";") reduce 187) (("@") reduce 187) ((T_ABSTRACT) reduce 187) ((T_ARRAY) reduce 187) ((T_ARRAY_CAST) reduce 187) ((T_ATTRIBUTE) reduce 187) ((T_BOOL_CAST) reduce 187) ((T_BREAK) reduce 187) ((T_CLASS) reduce 187) ((T_CLASS_C) reduce 187) ((T_CLONE) reduce 187) ((T_CONSTANT_ENCAPSED_STRING) reduce 187) ((T_CONTINUE) reduce 187) ((T_DEC) reduce 187) ((T_DECLARE) reduce 187) ((T_DIR) reduce 187) ((T_DNUMBER) reduce 187) ((T_DO) reduce 187) ((T_DOUBLE_CAST) reduce 187) ((T_ECHO) reduce 187) ((T_EMPTY) reduce 187) ((T_ENDDECLARE) reduce 187) ((T_ENUM) reduce 187) ((T_EVAL) reduce 187) ((T_EXIT) reduce 187) ((T_FILE) reduce 187) ((T_FINAL) reduce 187) ((T_FN) reduce 187) ((T_FOR) reduce 187) ((T_FOREACH) reduce 187) ((T_FUNCTION) reduce 187) ((T_FUNC_C) reduce 187) ((T_GLOBAL) reduce 187) ((T_GOTO) reduce 187) ((T_HALT_COMPILER) reduce 187) ((T_IF) reduce 187) ((T_INC) reduce 187) ((T_INCLUDE) reduce 187) ((T_INCLUDE_ONCE) reduce 187) ((T_INLINE_HTML) reduce 187) ((T_INTERFACE) reduce 187) ((T_INT_CAST) reduce 187) ((T_ISSET) reduce 187) ((T_LINE) reduce 187) ((T_LIST) reduce 187) ((T_LNUMBER) reduce 187) ((T_MATCH) reduce 187) ((T_METHOD_C) reduce 187) ((T_NAME_FULLY_QUALIFIED) reduce 187) ((T_NAME_QUALIFIED) reduce 187) ((T_NAME_RELATIVE) reduce 187) ((T_NEW) reduce 187) ((T_NS_C) reduce 187) ((T_OBJECT_CAST) reduce 187) ((T_PRINT) reduce 187) ((T_READONLY) reduce 187) ((T_REQUIRE) reduce 187) ((T_REQUIRE_ONCE) reduce 187) ((T_RETURN) reduce 187) ((T_START_HEREDOC) reduce 187) ((T_STATIC) reduce 187) ((T_STRING) reduce 187) ((T_STRING_CAST) reduce 187) ((T_SWITCH) reduce 187) ((T_THROW) reduce 187) ((T_TRAIT) reduce 187) ((T_TRAIT_C) reduce 187) ((T_TRY) reduce 187) ((T_UNSET) reduce 187) ((T_UNSET_CAST) reduce 187) ((T_VARIABLE) reduce 187) ((T_WHILE) reduce 187) ((T_YIELD) reduce 187) ((T_YIELD_FROM) reduce 187) (("[") reduce 187) (("`") reduce 187) (("{") reduce 187) (("~") reduce 187)) 20344 ((("!") reduce 152) (("\"") reduce 152) (("$") reduce 152) (("(") reduce 152) (("+") reduce 152) (("-") reduce 152) ((";") reduce 152) (("@") reduce 152) ((T_ABSTRACT) reduce 152) ((T_ARRAY) reduce 152) ((T_ARRAY_CAST) reduce 152) ((T_ATTRIBUTE) reduce 152) ((T_BOOL_CAST) reduce 152) ((T_BREAK) reduce 152) ((T_CLASS) reduce 152) ((T_CLASS_C) reduce 152) ((T_CLONE) reduce 152) ((T_CONSTANT_ENCAPSED_STRING) reduce 152) ((T_CONTINUE) reduce 152) ((T_DEC) reduce 152) ((T_DECLARE) reduce 152) ((T_DIR) reduce 152) ((T_DNUMBER) reduce 152) ((T_DO) reduce 152) ((T_DOUBLE_CAST) reduce 152) ((T_ECHO) reduce 152) ((T_EMPTY) reduce 152) ((T_ENDDECLARE) reduce 152) ((T_ENUM) reduce 152) ((T_EVAL) reduce 152) ((T_EXIT) reduce 152) ((T_FILE) reduce 152) ((T_FINAL) reduce 152) ((T_FN) reduce 152) ((T_FOR) reduce 152) ((T_FOREACH) reduce 152) ((T_FUNCTION) reduce 152) ((T_FUNC_C) reduce 152) ((T_GLOBAL) reduce 152) ((T_GOTO) reduce 152) ((T_HALT_COMPILER) reduce 152) ((T_IF) reduce 152) ((T_INC) reduce 152) ((T_INCLUDE) reduce 152) ((T_INCLUDE_ONCE) reduce 152) ((T_INLINE_HTML) reduce 152) ((T_INTERFACE) reduce 152) ((T_INT_CAST) reduce 152) ((T_ISSET) reduce 152) ((T_LINE) reduce 152) ((T_LIST) reduce 152) ((T_LNUMBER) reduce 152) ((T_MATCH) reduce 152) ((T_METHOD_C) reduce 152) ((T_NAME_FULLY_QUALIFIED) reduce 152) ((T_NAME_QUALIFIED) reduce 152) ((T_NAME_RELATIVE) reduce 152) ((T_NEW) reduce 152) ((T_NS_C) reduce 152) ((T_OBJECT_CAST) reduce 152) ((T_PRINT) reduce 152) ((T_READONLY) reduce 152) ((T_REQUIRE) reduce 152) ((T_REQUIRE_ONCE) reduce 152) ((T_RETURN) reduce 152) ((T_START_HEREDOC) reduce 152) ((T_STATIC) reduce 152) ((T_STRING) reduce 152) ((T_STRING_CAST) reduce 152) ((T_SWITCH) reduce 152) ((T_THROW) reduce 152) ((T_TRAIT) reduce 152) ((T_TRAIT_C) reduce 152) ((T_TRY) reduce 152) ((T_UNSET) reduce 152) ((T_UNSET_CAST) reduce 152) ((T_VARIABLE) reduce 152) ((T_WHILE) reduce 152) ((T_YIELD) reduce 152) ((T_YIELD_FROM) reduce 152) (("[") reduce 152) (("`") reduce 152) (("{") reduce 152) (("~") reduce 152)) 20346 ((("%") shift) ((")") reduce 454) (("*") shift) (("+") shift) ((",") reduce 454) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 20347 (((")") reduce 355) ((",") reduce 355)) 20349 (((T_ELSE) reduce 153) ((T_ELSEIF) reduce 153) ((T_WHILE) reduce 153)) 20351 (((T_ELSE) reduce 152) ((T_ELSEIF) reduce 152) ((T_WHILE) reduce 152)) 20352 (((T_WHILE) reduce 244)) 20353 (((T_WHILE) reduce 159)) 20356 (((T_WHILE) reduce 247)) 20360 (((T_WHILE) reduce 248)) 20365 (((T_WHILE) reduce 239)) 20366 (((T_WHILE) reduce 148)) 20369 (((T_WHILE) reduce 240)) 20374 (((T_WHILE) reduce 160)) 20377 (((T_CATCH) reduce 168) ((T_FINALLY) reduce 168) ((T_WHILE) reduce 168)) 20378 (((T_CATCH) shift) ((T_FINALLY) shift) ((T_WHILE) reduce 174)) 20381 (((T_WHILE) reduce 165)) 20384 (((T_WHILE) reduce 175)) 20391 (((T_CATCH) reduce 169) ((T_FINALLY) reduce 169) ((T_WHILE) reduce 169)) 20396 (((T_WHILE) reduce 151)) 20400 (((T_WHILE) reduce 221)) 20402 (((T_WHILE) reduce 222)) 20406 (((T_WHILE) reduce 223)) 20409 (((T_WHILE) reduce 224)) 20410 (((T_WHILE) reduce 167)) 20412 (((T_WHILE) reduce 156)) 20414 (((T_WHILE) reduce 154)) 20418 (((T_ELSE) reduce 241) ((T_ELSEIF) reduce 241) ((T_WHILE) reduce 241)) 20420 (((T_WHILE) reduce 166)) 20422 (((T_WHILE) reduce 155)) 20432 (((T_WHILE) reduce 162)) 20433 (((T_WHILE) reduce 217)) 20436 (((T_WHILE) reduce 218)) 20437 (((T_WHILE) reduce 161)) 20446 (((T_WHILE) reduce 150)) 20447 (((T_WHILE) reduce 215)) 20450 (((T_WHILE) reduce 216)) 20452 (((T_WHILE) reduce 157)) 20458 (((T_WHILE) reduce 149)) 20463 (((T_WHILE) reduce 163)) 20464 (((T_WHILE) reduce 219)) 20467 (((T_WHILE) reduce 220)) 20469 (((T_WHILE) reduce 153)) 20471 (((T_WHILE) reduce 152)) 20476 ((("!") reduce 163) (("\"") reduce 163) (("$") reduce 163) (("(") reduce 163) (("+") reduce 163) (("-") reduce 163) ((";") reduce 163) (("@") reduce 163) ((T_ABSTRACT) reduce 163) ((T_ARRAY) reduce 163) ((T_ARRAY_CAST) reduce 163) ((T_ATTRIBUTE) reduce 163) ((T_BOOL_CAST) reduce 163) ((T_BREAK) reduce 163) ((T_CLASS) reduce 163) ((T_CLASS_C) reduce 163) ((T_CLONE) reduce 163) ((T_CONSTANT_ENCAPSED_STRING) reduce 163) ((T_CONTINUE) reduce 163) ((T_DEC) reduce 163) ((T_DECLARE) reduce 163) ((T_DIR) reduce 163) ((T_DNUMBER) reduce 163) ((T_DO) reduce 163) ((T_DOUBLE_CAST) reduce 163) ((T_ECHO) reduce 163) ((T_ELSE) reduce 163) ((T_ELSEIF) reduce 163) ((T_EMPTY) reduce 163) ((T_ENDFOR) reduce 163) ((T_ENUM) reduce 163) ((T_EVAL) reduce 163) ((T_EXIT) reduce 163) ((T_FILE) reduce 163) ((T_FINAL) reduce 163) ((T_FN) reduce 163) ((T_FOR) reduce 163) ((T_FOREACH) reduce 163) ((T_FUNCTION) reduce 163) ((T_FUNC_C) reduce 163) ((T_GLOBAL) reduce 163) ((T_GOTO) reduce 163) ((T_HALT_COMPILER) reduce 163) ((T_IF) reduce 163) ((T_INC) reduce 163) ((T_INCLUDE) reduce 163) ((T_INCLUDE_ONCE) reduce 163) ((T_INLINE_HTML) reduce 163) ((T_INTERFACE) reduce 163) ((T_INT_CAST) reduce 163) ((T_ISSET) reduce 163) ((T_LINE) reduce 163) ((T_LIST) reduce 163) ((T_LNUMBER) reduce 163) ((T_MATCH) reduce 163) ((T_METHOD_C) reduce 163) ((T_NAME_FULLY_QUALIFIED) reduce 163) ((T_NAME_QUALIFIED) reduce 163) ((T_NAME_RELATIVE) reduce 163) ((T_NEW) reduce 163) ((T_NS_C) reduce 163) ((T_OBJECT_CAST) reduce 163) ((T_PRINT) reduce 163) ((T_READONLY) reduce 163) ((T_REQUIRE) reduce 163) ((T_REQUIRE_ONCE) reduce 163) ((T_RETURN) reduce 163) ((T_START_HEREDOC) reduce 163) ((T_STATIC) reduce 163) ((T_STRING) reduce 163) ((T_STRING_CAST) reduce 163) ((T_SWITCH) reduce 163) ((T_THROW) reduce 163) ((T_TRAIT) reduce 163) ((T_TRAIT_C) reduce 163) ((T_TRY) reduce 163) ((T_UNSET) reduce 163) ((T_UNSET_CAST) reduce 163) ((T_VARIABLE) reduce 163) ((T_WHILE) reduce 163) ((T_YIELD) reduce 163) ((T_YIELD_FROM) reduce 163) (("[") reduce 163) (("`") reduce 163) (("{") reduce 163) (("~") reduce 163)) 20477 ((("!") reduce 219) (("\"") reduce 219) (("$") reduce 219) (("(") reduce 219) (("+") reduce 219) (("-") reduce 219) ((";") reduce 219) (("@") reduce 219) ((T_ABSTRACT) reduce 219) ((T_ARRAY) reduce 219) ((T_ARRAY_CAST) reduce 219) ((T_ATTRIBUTE) reduce 219) ((T_BOOL_CAST) reduce 219) ((T_BREAK) reduce 219) ((T_CLASS) reduce 219) ((T_CLASS_C) reduce 219) ((T_CLONE) reduce 219) ((T_CONSTANT_ENCAPSED_STRING) reduce 219) ((T_CONTINUE) reduce 219) ((T_DEC) reduce 219) ((T_DECLARE) reduce 219) ((T_DIR) reduce 219) ((T_DNUMBER) reduce 219) ((T_DO) reduce 219) ((T_DOUBLE_CAST) reduce 219) ((T_ECHO) reduce 219) ((T_ELSE) reduce 219) ((T_ELSEIF) reduce 219) ((T_EMPTY) reduce 219) ((T_ENDFOR) reduce 219) ((T_ENUM) reduce 219) ((T_EVAL) reduce 219) ((T_EXIT) reduce 219) ((T_FILE) reduce 219) ((T_FINAL) reduce 219) ((T_FN) reduce 219) ((T_FOR) reduce 219) ((T_FOREACH) reduce 219) ((T_FUNCTION) reduce 219) ((T_FUNC_C) reduce 219) ((T_GLOBAL) reduce 219) ((T_GOTO) reduce 219) ((T_HALT_COMPILER) reduce 219) ((T_IF) reduce 219) ((T_INC) reduce 219) ((T_INCLUDE) reduce 219) ((T_INCLUDE_ONCE) reduce 219) ((T_INLINE_HTML) reduce 219) ((T_INTERFACE) reduce 219) ((T_INT_CAST) reduce 219) ((T_ISSET) reduce 219) ((T_LINE) reduce 219) ((T_LIST) reduce 219) ((T_LNUMBER) reduce 219) ((T_MATCH) reduce 219) ((T_METHOD_C) reduce 219) ((T_NAME_FULLY_QUALIFIED) reduce 219) ((T_NAME_QUALIFIED) reduce 219) ((T_NAME_RELATIVE) reduce 219) ((T_NEW) reduce 219) ((T_NS_C) reduce 219) ((T_OBJECT_CAST) reduce 219) ((T_PRINT) reduce 219) ((T_READONLY) reduce 219) ((T_REQUIRE) reduce 219) ((T_REQUIRE_ONCE) reduce 219) ((T_RETURN) reduce 219) ((T_START_HEREDOC) reduce 219) ((T_STATIC) reduce 219) ((T_STRING) reduce 219) ((T_STRING_CAST) reduce 219) ((T_SWITCH) reduce 219) ((T_THROW) reduce 219) ((T_TRAIT) reduce 219) ((T_TRAIT_C) reduce 219) ((T_TRY) reduce 219) ((T_UNSET) reduce 219) ((T_UNSET_CAST) reduce 219) ((T_VARIABLE) reduce 219) ((T_WHILE) reduce 219) ((T_YIELD) reduce 219) ((T_YIELD_FROM) reduce 219) (("[") reduce 219) (("`") reduce 219) (("{") reduce 219) (("~") reduce 219)) 20480 ((("!") reduce 220) (("\"") reduce 220) (("$") reduce 220) (("(") reduce 220) (("+") reduce 220) (("-") reduce 220) ((";") reduce 220) (("@") reduce 220) ((T_ABSTRACT) reduce 220) ((T_ARRAY) reduce 220) ((T_ARRAY_CAST) reduce 220) ((T_ATTRIBUTE) reduce 220) ((T_BOOL_CAST) reduce 220) ((T_BREAK) reduce 220) ((T_CLASS) reduce 220) ((T_CLASS_C) reduce 220) ((T_CLONE) reduce 220) ((T_CONSTANT_ENCAPSED_STRING) reduce 220) ((T_CONTINUE) reduce 220) ((T_DEC) reduce 220) ((T_DECLARE) reduce 220) ((T_DIR) reduce 220) ((T_DNUMBER) reduce 220) ((T_DO) reduce 220) ((T_DOUBLE_CAST) reduce 220) ((T_ECHO) reduce 220) ((T_ELSE) reduce 220) ((T_ELSEIF) reduce 220) ((T_EMPTY) reduce 220) ((T_ENDFOR) reduce 220) ((T_ENUM) reduce 220) ((T_EVAL) reduce 220) ((T_EXIT) reduce 220) ((T_FILE) reduce 220) ((T_FINAL) reduce 220) ((T_FN) reduce 220) ((T_FOR) reduce 220) ((T_FOREACH) reduce 220) ((T_FUNCTION) reduce 220) ((T_FUNC_C) reduce 220) ((T_GLOBAL) reduce 220) ((T_GOTO) reduce 220) ((T_HALT_COMPILER) reduce 220) ((T_IF) reduce 220) ((T_INC) reduce 220) ((T_INCLUDE) reduce 220) ((T_INCLUDE_ONCE) reduce 220) ((T_INLINE_HTML) reduce 220) ((T_INTERFACE) reduce 220) ((T_INT_CAST) reduce 220) ((T_ISSET) reduce 220) ((T_LINE) reduce 220) ((T_LIST) reduce 220) ((T_LNUMBER) reduce 220) ((T_MATCH) reduce 220) ((T_METHOD_C) reduce 220) ((T_NAME_FULLY_QUALIFIED) reduce 220) ((T_NAME_QUALIFIED) reduce 220) ((T_NAME_RELATIVE) reduce 220) ((T_NEW) reduce 220) ((T_NS_C) reduce 220) ((T_OBJECT_CAST) reduce 220) ((T_PRINT) reduce 220) ((T_READONLY) reduce 220) ((T_REQUIRE) reduce 220) ((T_REQUIRE_ONCE) reduce 220) ((T_RETURN) reduce 220) ((T_START_HEREDOC) reduce 220) ((T_STATIC) reduce 220) ((T_STRING) reduce 220) ((T_STRING_CAST) reduce 220) ((T_SWITCH) reduce 220) ((T_THROW) reduce 220) ((T_TRAIT) reduce 220) ((T_TRAIT_C) reduce 220) ((T_TRY) reduce 220) ((T_UNSET) reduce 220) ((T_UNSET_CAST) reduce 220) ((T_VARIABLE) reduce 220) ((T_WHILE) reduce 220) ((T_YIELD) reduce 220) ((T_YIELD_FROM) reduce 220) (("[") reduce 220) (("`") reduce 220) (("{") reduce 220) (("~") reduce 220)) 20482 ((("!") reduce 153) (("\"") reduce 153) (("$") reduce 153) (("(") reduce 153) (("+") reduce 153) (("-") reduce 153) ((";") reduce 153) (("@") reduce 153) ((T_ABSTRACT) reduce 153) ((T_ARRAY) reduce 153) ((T_ARRAY_CAST) reduce 153) ((T_ATTRIBUTE) reduce 153) ((T_BOOL_CAST) reduce 153) ((T_BREAK) reduce 153) ((T_CLASS) reduce 153) ((T_CLASS_C) reduce 153) ((T_CLONE) reduce 153) ((T_CONSTANT_ENCAPSED_STRING) reduce 153) ((T_CONTINUE) reduce 153) ((T_DEC) reduce 153) ((T_DECLARE) reduce 153) ((T_DIR) reduce 153) ((T_DNUMBER) reduce 153) ((T_DO) reduce 153) ((T_DOUBLE_CAST) reduce 153) ((T_ECHO) reduce 153) ((T_ELSE) reduce 153) ((T_ELSEIF) reduce 153) ((T_EMPTY) reduce 153) ((T_ENDFOR) reduce 153) ((T_ENUM) reduce 153) ((T_EVAL) reduce 153) ((T_EXIT) reduce 153) ((T_FILE) reduce 153) ((T_FINAL) reduce 153) ((T_FN) reduce 153) ((T_FOR) reduce 153) ((T_FOREACH) reduce 153) ((T_FUNCTION) reduce 153) ((T_FUNC_C) reduce 153) ((T_GLOBAL) reduce 153) ((T_GOTO) reduce 153) ((T_HALT_COMPILER) reduce 153) ((T_IF) reduce 153) ((T_INC) reduce 153) ((T_INCLUDE) reduce 153) ((T_INCLUDE_ONCE) reduce 153) ((T_INLINE_HTML) reduce 153) ((T_INTERFACE) reduce 153) ((T_INT_CAST) reduce 153) ((T_ISSET) reduce 153) ((T_LINE) reduce 153) ((T_LIST) reduce 153) ((T_LNUMBER) reduce 153) ((T_MATCH) reduce 153) ((T_METHOD_C) reduce 153) ((T_NAME_FULLY_QUALIFIED) reduce 153) ((T_NAME_QUALIFIED) reduce 153) ((T_NAME_RELATIVE) reduce 153) ((T_NEW) reduce 153) ((T_NS_C) reduce 153) ((T_OBJECT_CAST) reduce 153) ((T_PRINT) reduce 153) ((T_READONLY) reduce 153) ((T_REQUIRE) reduce 153) ((T_REQUIRE_ONCE) reduce 153) ((T_RETURN) reduce 153) ((T_START_HEREDOC) reduce 153) ((T_STATIC) reduce 153) ((T_STRING) reduce 153) ((T_STRING_CAST) reduce 153) ((T_SWITCH) reduce 153) ((T_THROW) reduce 153) ((T_TRAIT) reduce 153) ((T_TRAIT_C) reduce 153) ((T_TRY) reduce 153) ((T_UNSET) reduce 153) ((T_UNSET_CAST) reduce 153) ((T_VARIABLE) reduce 153) ((T_WHILE) reduce 153) ((T_YIELD) reduce 153) ((T_YIELD_FROM) reduce 153) (("[") reduce 153) (("`") reduce 153) (("{") reduce 153) (("~") reduce 153)) 20484 ((("!") reduce 152) (("\"") reduce 152) (("$") reduce 152) (("(") reduce 152) (("+") reduce 152) (("-") reduce 152) ((";") reduce 152) (("@") reduce 152) ((T_ABSTRACT) reduce 152) ((T_ARRAY) reduce 152) ((T_ARRAY_CAST) reduce 152) ((T_ATTRIBUTE) reduce 152) ((T_BOOL_CAST) reduce 152) ((T_BREAK) reduce 152) ((T_CLASS) reduce 152) ((T_CLASS_C) reduce 152) ((T_CLONE) reduce 152) ((T_CONSTANT_ENCAPSED_STRING) reduce 152) ((T_CONTINUE) reduce 152) ((T_DEC) reduce 152) ((T_DECLARE) reduce 152) ((T_DIR) reduce 152) ((T_DNUMBER) reduce 152) ((T_DO) reduce 152) ((T_DOUBLE_CAST) reduce 152) ((T_ECHO) reduce 152) ((T_ELSE) reduce 152) ((T_ELSEIF) reduce 152) ((T_EMPTY) reduce 152) ((T_ENDFOR) reduce 152) ((T_ENUM) reduce 152) ((T_EVAL) reduce 152) ((T_EXIT) reduce 152) ((T_FILE) reduce 152) ((T_FINAL) reduce 152) ((T_FN) reduce 152) ((T_FOR) reduce 152) ((T_FOREACH) reduce 152) ((T_FUNCTION) reduce 152) ((T_FUNC_C) reduce 152) ((T_GLOBAL) reduce 152) ((T_GOTO) reduce 152) ((T_HALT_COMPILER) reduce 152) ((T_IF) reduce 152) ((T_INC) reduce 152) ((T_INCLUDE) reduce 152) ((T_INCLUDE_ONCE) reduce 152) ((T_INLINE_HTML) reduce 152) ((T_INTERFACE) reduce 152) ((T_INT_CAST) reduce 152) ((T_ISSET) reduce 152) ((T_LINE) reduce 152) ((T_LIST) reduce 152) ((T_LNUMBER) reduce 152) ((T_MATCH) reduce 152) ((T_METHOD_C) reduce 152) ((T_NAME_FULLY_QUALIFIED) reduce 152) ((T_NAME_QUALIFIED) reduce 152) ((T_NAME_RELATIVE) reduce 152) ((T_NEW) reduce 152) ((T_NS_C) reduce 152) ((T_OBJECT_CAST) reduce 152) ((T_PRINT) reduce 152) ((T_READONLY) reduce 152) ((T_REQUIRE) reduce 152) ((T_REQUIRE_ONCE) reduce 152) ((T_RETURN) reduce 152) ((T_START_HEREDOC) reduce 152) ((T_STATIC) reduce 152) ((T_STRING) reduce 152) ((T_STRING_CAST) reduce 152) ((T_SWITCH) reduce 152) ((T_THROW) reduce 152) ((T_TRAIT) reduce 152) ((T_TRAIT_C) reduce 152) ((T_TRY) reduce 152) ((T_UNSET) reduce 152) ((T_UNSET_CAST) reduce 152) ((T_VARIABLE) reduce 152) ((T_WHILE) reduce 152) ((T_YIELD) reduce 152) ((T_YIELD_FROM) reduce 152) (("[") reduce 152) (("`") reduce 152) (("{") reduce 152) (("~") reduce 152)) 20485 ((("!") reduce 244) (("\"") reduce 244) (("$") reduce 244) (("(") reduce 244) (("+") reduce 244) (("-") reduce 244) ((";") reduce 244) (("@") reduce 244) ((T_ABSTRACT) reduce 244) ((T_ARRAY) reduce 244) ((T_ARRAY_CAST) reduce 244) ((T_ATTRIBUTE) reduce 244) ((T_BOOL_CAST) reduce 244) ((T_BREAK) reduce 244) ((T_CLASS) reduce 244) ((T_CLASS_C) reduce 244) ((T_CLONE) reduce 244) ((T_CONSTANT_ENCAPSED_STRING) reduce 244) ((T_CONTINUE) reduce 244) ((T_DEC) reduce 244) ((T_DECLARE) reduce 244) ((T_DIR) reduce 244) ((T_DNUMBER) reduce 244) ((T_DO) reduce 244) ((T_DOUBLE_CAST) reduce 244) ((T_ECHO) reduce 244) ((T_EMPTY) reduce 244) ((T_ENDFOR) reduce 244) ((T_ENUM) reduce 244) ((T_EVAL) reduce 244) ((T_EXIT) reduce 244) ((T_FILE) reduce 244) ((T_FINAL) reduce 244) ((T_FN) reduce 244) ((T_FOR) reduce 244) ((T_FOREACH) reduce 244) ((T_FUNCTION) reduce 244) ((T_FUNC_C) reduce 244) ((T_GLOBAL) reduce 244) ((T_GOTO) reduce 244) ((T_HALT_COMPILER) reduce 244) ((T_IF) reduce 244) ((T_INC) reduce 244) ((T_INCLUDE) reduce 244) ((T_INCLUDE_ONCE) reduce 244) ((T_INLINE_HTML) reduce 244) ((T_INTERFACE) reduce 244) ((T_INT_CAST) reduce 244) ((T_ISSET) reduce 244) ((T_LINE) reduce 244) ((T_LIST) reduce 244) ((T_LNUMBER) reduce 244) ((T_MATCH) reduce 244) ((T_METHOD_C) reduce 244) ((T_NAME_FULLY_QUALIFIED) reduce 244) ((T_NAME_QUALIFIED) reduce 244) ((T_NAME_RELATIVE) reduce 244) ((T_NEW) reduce 244) ((T_NS_C) reduce 244) ((T_OBJECT_CAST) reduce 244) ((T_PRINT) reduce 244) ((T_READONLY) reduce 244) ((T_REQUIRE) reduce 244) ((T_REQUIRE_ONCE) reduce 244) ((T_RETURN) reduce 244) ((T_START_HEREDOC) reduce 244) ((T_STATIC) reduce 244) ((T_STRING) reduce 244) ((T_STRING_CAST) reduce 244) ((T_SWITCH) reduce 244) ((T_THROW) reduce 244) ((T_TRAIT) reduce 244) ((T_TRAIT_C) reduce 244) ((T_TRY) reduce 244) ((T_UNSET) reduce 244) ((T_UNSET_CAST) reduce 244) ((T_VARIABLE) reduce 244) ((T_WHILE) reduce 244) ((T_YIELD) reduce 244) ((T_YIELD_FROM) reduce 244) (("[") reduce 244) (("`") reduce 244) (("{") reduce 244) (("~") reduce 244)) 20496 ((("!") reduce 455) (("\"") reduce 455) (("$") reduce 455) (("(") reduce 455) (("+") reduce 455) (("-") reduce 455) ((";") reduce 455) (("@") reduce 455) ((T_ABSTRACT) reduce 455) ((T_ARRAY) reduce 455) ((T_ARRAY_CAST) reduce 455) ((T_ATTRIBUTE) reduce 455) ((T_BOOL_CAST) reduce 455) ((T_BREAK) reduce 455) ((T_CLASS) reduce 455) ((T_CLASS_C) reduce 455) ((T_CLONE) reduce 455) ((T_CONSTANT_ENCAPSED_STRING) reduce 455) ((T_CONTINUE) reduce 455) ((T_DEC) reduce 455) ((T_DECLARE) reduce 455) ((T_DIR) reduce 455) ((T_DNUMBER) reduce 455) ((T_DO) reduce 455) ((T_DOUBLE_CAST) reduce 455) ((T_ECHO) reduce 455) ((T_EMPTY) reduce 455) ((T_ENDFOR) reduce 455) ((T_ENUM) reduce 455) ((T_EVAL) reduce 455) ((T_EXIT) reduce 455) ((T_FILE) reduce 455) ((T_FINAL) reduce 455) ((T_FN) reduce 455) ((T_FOR) reduce 455) ((T_FOREACH) reduce 455) ((T_FUNCTION) reduce 455) ((T_FUNC_C) reduce 455) ((T_GLOBAL) reduce 455) ((T_GOTO) reduce 455) ((T_HALT_COMPILER) reduce 455) ((T_IF) reduce 455) ((T_INC) reduce 455) ((T_INCLUDE) reduce 455) ((T_INCLUDE_ONCE) reduce 455) ((T_INLINE_HTML) reduce 455) ((T_INTERFACE) reduce 455) ((T_INT_CAST) reduce 455) ((T_ISSET) reduce 455) ((T_LINE) reduce 455) ((T_LIST) reduce 455) ((T_LNUMBER) reduce 455) ((T_MATCH) reduce 455) ((T_METHOD_C) reduce 455) ((T_NAME_FULLY_QUALIFIED) reduce 455) ((T_NAME_QUALIFIED) reduce 455) ((T_NAME_RELATIVE) reduce 455) ((T_NEW) reduce 455) ((T_NS_C) reduce 455) ((T_OBJECT_CAST) reduce 455) ((T_PRINT) reduce 455) ((T_READONLY) reduce 455) ((T_REQUIRE) reduce 455) ((T_REQUIRE_ONCE) reduce 455) ((T_RETURN) reduce 455) ((T_START_HEREDOC) reduce 455) ((T_STATIC) reduce 455) ((T_STRING) reduce 455) ((T_STRING_CAST) reduce 455) ((T_SWITCH) reduce 455) ((T_THROW) reduce 455) ((T_TRAIT) reduce 455) ((T_TRAIT_C) reduce 455) ((T_TRY) reduce 455) ((T_UNSET) reduce 455) ((T_UNSET_CAST) reduce 455) ((T_VARIABLE) reduce 455) ((T_WHILE) reduce 455) ((T_YIELD) reduce 455) ((T_YIELD_FROM) reduce 455) (("[") reduce 455) (("`") reduce 455) (("{") reduce 455) (("~") reduce 455)) 20497 ((("!") reduce 181) (("\"") reduce 181) (("$") reduce 181) (("(") reduce 181) (("+") reduce 181) (("-") reduce 181) ((";") reduce 181) (("@") reduce 181) ((T_ABSTRACT) reduce 181) ((T_ARRAY) reduce 181) ((T_ARRAY_CAST) reduce 181) ((T_ATTRIBUTE) reduce 181) ((T_BOOL_CAST) reduce 181) ((T_BREAK) reduce 181) ((T_CLASS) reduce 181) ((T_CLASS_C) reduce 181) ((T_CLONE) reduce 181) ((T_CONSTANT_ENCAPSED_STRING) reduce 181) ((T_CONTINUE) reduce 181) ((T_DEC) reduce 181) ((T_DECLARE) reduce 181) ((T_DIR) reduce 181) ((T_DNUMBER) reduce 181) ((T_DO) reduce 181) ((T_DOUBLE_CAST) reduce 181) ((T_ECHO) reduce 181) ((T_EMPTY) reduce 181) ((T_ENDFOR) reduce 181) ((T_ENUM) reduce 181) ((T_EVAL) reduce 181) ((T_EXIT) reduce 181) ((T_FILE) reduce 181) ((T_FINAL) reduce 181) ((T_FN) reduce 181) ((T_FOR) reduce 181) ((T_FOREACH) reduce 181) ((T_FUNCTION) reduce 181) ((T_FUNC_C) reduce 181) ((T_GLOBAL) reduce 181) ((T_GOTO) reduce 181) ((T_HALT_COMPILER) reduce 181) ((T_IF) reduce 181) ((T_INC) reduce 181) ((T_INCLUDE) reduce 181) ((T_INCLUDE_ONCE) reduce 181) ((T_INLINE_HTML) reduce 181) ((T_INTERFACE) reduce 181) ((T_INT_CAST) reduce 181) ((T_ISSET) reduce 181) ((T_LINE) reduce 181) ((T_LIST) reduce 181) ((T_LNUMBER) reduce 181) ((T_MATCH) reduce 181) ((T_METHOD_C) reduce 181) ((T_NAME_FULLY_QUALIFIED) reduce 181) ((T_NAME_QUALIFIED) reduce 181) ((T_NAME_RELATIVE) reduce 181) ((T_NEW) reduce 181) ((T_NS_C) reduce 181) ((T_OBJECT_CAST) reduce 181) ((T_PRINT) reduce 181) ((T_READONLY) reduce 181) ((T_REQUIRE) reduce 181) ((T_REQUIRE_ONCE) reduce 181) ((T_RETURN) reduce 181) ((T_START_HEREDOC) reduce 181) ((T_STATIC) reduce 181) ((T_STRING) reduce 181) ((T_STRING_CAST) reduce 181) ((T_SWITCH) reduce 181) ((T_THROW) reduce 181) ((T_TRAIT) reduce 181) ((T_TRAIT_C) reduce 181) ((T_TRY) reduce 181) ((T_UNSET) reduce 181) ((T_UNSET_CAST) reduce 181) ((T_VARIABLE) reduce 181) ((T_WHILE) reduce 181) ((T_YIELD) reduce 181) ((T_YIELD_FROM) reduce 181) (("[") reduce 181) (("`") reduce 181) (("{") reduce 181) (("~") reduce 181)) 20498 ((("!") reduce 159) (("\"") reduce 159) (("$") reduce 159) (("(") reduce 159) (("+") reduce 159) (("-") reduce 159) ((";") reduce 159) (("@") reduce 159) ((T_ABSTRACT) reduce 159) ((T_ARRAY) reduce 159) ((T_ARRAY_CAST) reduce 159) ((T_ATTRIBUTE) reduce 159) ((T_BOOL_CAST) reduce 159) ((T_BREAK) reduce 159) ((T_CLASS) reduce 159) ((T_CLASS_C) reduce 159) ((T_CLONE) reduce 159) ((T_CONSTANT_ENCAPSED_STRING) reduce 159) ((T_CONTINUE) reduce 159) ((T_DEC) reduce 159) ((T_DECLARE) reduce 159) ((T_DIR) reduce 159) ((T_DNUMBER) reduce 159) ((T_DO) reduce 159) ((T_DOUBLE_CAST) reduce 159) ((T_ECHO) reduce 159) ((T_EMPTY) reduce 159) ((T_ENDFOR) reduce 159) ((T_ENUM) reduce 159) ((T_EVAL) reduce 159) ((T_EXIT) reduce 159) ((T_FILE) reduce 159) ((T_FINAL) reduce 159) ((T_FN) reduce 159) ((T_FOR) reduce 159) ((T_FOREACH) reduce 159) ((T_FUNCTION) reduce 159) ((T_FUNC_C) reduce 159) ((T_GLOBAL) reduce 159) ((T_GOTO) reduce 159) ((T_HALT_COMPILER) reduce 159) ((T_IF) reduce 159) ((T_INC) reduce 159) ((T_INCLUDE) reduce 159) ((T_INCLUDE_ONCE) reduce 159) ((T_INLINE_HTML) reduce 159) ((T_INTERFACE) reduce 159) ((T_INT_CAST) reduce 159) ((T_ISSET) reduce 159) ((T_LINE) reduce 159) ((T_LIST) reduce 159) ((T_LNUMBER) reduce 159) ((T_MATCH) reduce 159) ((T_METHOD_C) reduce 159) ((T_NAME_FULLY_QUALIFIED) reduce 159) ((T_NAME_QUALIFIED) reduce 159) ((T_NAME_RELATIVE) reduce 159) ((T_NEW) reduce 159) ((T_NS_C) reduce 159) ((T_OBJECT_CAST) reduce 159) ((T_PRINT) reduce 159) ((T_READONLY) reduce 159) ((T_REQUIRE) reduce 159) ((T_REQUIRE_ONCE) reduce 159) ((T_RETURN) reduce 159) ((T_START_HEREDOC) reduce 159) ((T_STATIC) reduce 159) ((T_STRING) reduce 159) ((T_STRING_CAST) reduce 159) ((T_SWITCH) reduce 159) ((T_THROW) reduce 159) ((T_TRAIT) reduce 159) ((T_TRAIT_C) reduce 159) ((T_TRY) reduce 159) ((T_UNSET) reduce 159) ((T_UNSET_CAST) reduce 159) ((T_VARIABLE) reduce 159) ((T_WHILE) reduce 159) ((T_YIELD) reduce 159) ((T_YIELD_FROM) reduce 159) (("[") reduce 159) (("`") reduce 159) (("{") reduce 159) (("~") reduce 159)) 20506 ((("!") reduce 186) (("\"") reduce 186) (("$") reduce 186) (("(") reduce 186) (("+") reduce 186) (("-") reduce 186) ((";") reduce 186) (("@") reduce 186) ((T_ABSTRACT) reduce 186) ((T_ARRAY) reduce 186) ((T_ARRAY_CAST) reduce 186) ((T_ATTRIBUTE) reduce 186) ((T_BOOL_CAST) reduce 186) ((T_BREAK) reduce 186) ((T_CLASS) reduce 186) ((T_CLASS_C) reduce 186) ((T_CLONE) reduce 186) ((T_CONSTANT_ENCAPSED_STRING) reduce 186) ((T_CONTINUE) reduce 186) ((T_DEC) reduce 186) ((T_DECLARE) reduce 186) ((T_DIR) reduce 186) ((T_DNUMBER) reduce 186) ((T_DO) reduce 186) ((T_DOUBLE_CAST) reduce 186) ((T_ECHO) reduce 186) ((T_EMPTY) reduce 186) ((T_ENDFOR) reduce 186) ((T_ENUM) reduce 186) ((T_EVAL) reduce 186) ((T_EXIT) reduce 186) ((T_FILE) reduce 186) ((T_FINAL) reduce 186) ((T_FN) reduce 186) ((T_FOR) reduce 186) ((T_FOREACH) reduce 186) ((T_FUNCTION) reduce 186) ((T_FUNC_C) reduce 186) ((T_GLOBAL) reduce 186) ((T_GOTO) reduce 186) ((T_HALT_COMPILER) reduce 186) ((T_IF) reduce 186) ((T_INC) reduce 186) ((T_INCLUDE) reduce 186) ((T_INCLUDE_ONCE) reduce 186) ((T_INLINE_HTML) reduce 186) ((T_INTERFACE) reduce 186) ((T_INT_CAST) reduce 186) ((T_ISSET) reduce 186) ((T_LINE) reduce 186) ((T_LIST) reduce 186) ((T_LNUMBER) reduce 186) ((T_MATCH) reduce 186) ((T_METHOD_C) reduce 186) ((T_NAME_FULLY_QUALIFIED) reduce 186) ((T_NAME_QUALIFIED) reduce 186) ((T_NAME_RELATIVE) reduce 186) ((T_NEW) reduce 186) ((T_NS_C) reduce 186) ((T_OBJECT_CAST) reduce 186) ((T_PRINT) reduce 186) ((T_READONLY) reduce 186) ((T_REQUIRE) reduce 186) ((T_REQUIRE_ONCE) reduce 186) ((T_RETURN) reduce 186) ((T_START_HEREDOC) reduce 186) ((T_STATIC) reduce 186) ((T_STRING) reduce 186) ((T_STRING_CAST) reduce 186) ((T_SWITCH) reduce 186) ((T_THROW) reduce 186) ((T_TRAIT) reduce 186) ((T_TRAIT_C) reduce 186) ((T_TRY) reduce 186) ((T_UNSET) reduce 186) ((T_UNSET_CAST) reduce 186) ((T_VARIABLE) reduce 186) ((T_WHILE) reduce 186) ((T_YIELD) reduce 186) ((T_YIELD_FROM) reduce 186) (("[") reduce 186) (("`") reduce 186) (("{") reduce 186) (("~") reduce 186)) 20507 ((("!") reduce 143) (("\"") reduce 143) (("$") reduce 143) (("(") reduce 143) (("+") reduce 143) (("-") reduce 143) ((";") reduce 143) (("@") reduce 143) ((T_ABSTRACT) reduce 143) ((T_ARRAY) reduce 143) ((T_ARRAY_CAST) reduce 143) ((T_ATTRIBUTE) reduce 143) ((T_BOOL_CAST) reduce 143) ((T_BREAK) reduce 143) ((T_CLASS) reduce 143) ((T_CLASS_C) reduce 143) ((T_CLONE) reduce 143) ((T_CONSTANT_ENCAPSED_STRING) reduce 143) ((T_CONTINUE) reduce 143) ((T_DEC) reduce 143) ((T_DECLARE) reduce 143) ((T_DIR) reduce 143) ((T_DNUMBER) reduce 143) ((T_DO) reduce 143) ((T_DOUBLE_CAST) reduce 143) ((T_ECHO) reduce 143) ((T_EMPTY) reduce 143) ((T_ENDFOR) reduce 143) ((T_ENUM) reduce 143) ((T_EVAL) reduce 143) ((T_EXIT) reduce 143) ((T_FILE) reduce 143) ((T_FINAL) reduce 143) ((T_FN) reduce 143) ((T_FOR) reduce 143) ((T_FOREACH) reduce 143) ((T_FUNCTION) reduce 143) ((T_FUNC_C) reduce 143) ((T_GLOBAL) reduce 143) ((T_GOTO) reduce 143) ((T_HALT_COMPILER) reduce 143) ((T_IF) reduce 143) ((T_INC) reduce 143) ((T_INCLUDE) reduce 143) ((T_INCLUDE_ONCE) reduce 143) ((T_INLINE_HTML) reduce 143) ((T_INTERFACE) reduce 143) ((T_INT_CAST) reduce 143) ((T_ISSET) reduce 143) ((T_LINE) reduce 143) ((T_LIST) reduce 143) ((T_LNUMBER) reduce 143) ((T_MATCH) reduce 143) ((T_METHOD_C) reduce 143) ((T_NAME_FULLY_QUALIFIED) reduce 143) ((T_NAME_QUALIFIED) reduce 143) ((T_NAME_RELATIVE) reduce 143) ((T_NEW) reduce 143) ((T_NS_C) reduce 143) ((T_OBJECT_CAST) reduce 143) ((T_PRINT) reduce 143) ((T_READONLY) reduce 143) ((T_REQUIRE) reduce 143) ((T_REQUIRE_ONCE) reduce 143) ((T_RETURN) reduce 143) ((T_START_HEREDOC) reduce 143) ((T_STATIC) reduce 143) ((T_STRING) reduce 143) ((T_STRING_CAST) reduce 143) ((T_SWITCH) reduce 143) ((T_THROW) reduce 143) ((T_TRAIT) reduce 143) ((T_TRAIT_C) reduce 143) ((T_TRY) reduce 143) ((T_UNSET) reduce 143) ((T_UNSET_CAST) reduce 143) ((T_VARIABLE) reduce 143) ((T_WHILE) reduce 143) ((T_YIELD) reduce 143) ((T_YIELD_FROM) reduce 143) (("[") reduce 143) (("`") reduce 143) (("{") reduce 143) (("~") reduce 143)) 20510 ((("!") reduce 247) (("\"") reduce 247) (("$") reduce 247) (("(") reduce 247) (("+") reduce 247) (("-") reduce 247) ((";") reduce 247) (("@") reduce 247) ((T_ABSTRACT) reduce 247) ((T_ARRAY) reduce 247) ((T_ARRAY_CAST) reduce 247) ((T_ATTRIBUTE) reduce 247) ((T_BOOL_CAST) reduce 247) ((T_BREAK) reduce 247) ((T_CLASS) reduce 247) ((T_CLASS_C) reduce 247) ((T_CLONE) reduce 247) ((T_CONSTANT_ENCAPSED_STRING) reduce 247) ((T_CONTINUE) reduce 247) ((T_DEC) reduce 247) ((T_DECLARE) reduce 247) ((T_DIR) reduce 247) ((T_DNUMBER) reduce 247) ((T_DO) reduce 247) ((T_DOUBLE_CAST) reduce 247) ((T_ECHO) reduce 247) ((T_EMPTY) reduce 247) ((T_ENDFOR) reduce 247) ((T_ENUM) reduce 247) ((T_EVAL) reduce 247) ((T_EXIT) reduce 247) ((T_FILE) reduce 247) ((T_FINAL) reduce 247) ((T_FN) reduce 247) ((T_FOR) reduce 247) ((T_FOREACH) reduce 247) ((T_FUNCTION) reduce 247) ((T_FUNC_C) reduce 247) ((T_GLOBAL) reduce 247) ((T_GOTO) reduce 247) ((T_HALT_COMPILER) reduce 247) ((T_IF) reduce 247) ((T_INC) reduce 247) ((T_INCLUDE) reduce 247) ((T_INCLUDE_ONCE) reduce 247) ((T_INLINE_HTML) reduce 247) ((T_INTERFACE) reduce 247) ((T_INT_CAST) reduce 247) ((T_ISSET) reduce 247) ((T_LINE) reduce 247) ((T_LIST) reduce 247) ((T_LNUMBER) reduce 247) ((T_MATCH) reduce 247) ((T_METHOD_C) reduce 247) ((T_NAME_FULLY_QUALIFIED) reduce 247) ((T_NAME_QUALIFIED) reduce 247) ((T_NAME_RELATIVE) reduce 247) ((T_NEW) reduce 247) ((T_NS_C) reduce 247) ((T_OBJECT_CAST) reduce 247) ((T_PRINT) reduce 247) ((T_READONLY) reduce 247) ((T_REQUIRE) reduce 247) ((T_REQUIRE_ONCE) reduce 247) ((T_RETURN) reduce 247) ((T_START_HEREDOC) reduce 247) ((T_STATIC) reduce 247) ((T_STRING) reduce 247) ((T_STRING_CAST) reduce 247) ((T_SWITCH) reduce 247) ((T_THROW) reduce 247) ((T_TRAIT) reduce 247) ((T_TRAIT_C) reduce 247) ((T_TRY) reduce 247) ((T_UNSET) reduce 247) ((T_UNSET_CAST) reduce 247) ((T_VARIABLE) reduce 247) ((T_WHILE) reduce 247) ((T_YIELD) reduce 247) ((T_YIELD_FROM) reduce 247) (("[") reduce 247) (("`") reduce 247) (("{") reduce 247) (("~") reduce 247)) 20514 ((("!") reduce 248) (("\"") reduce 248) (("$") reduce 248) (("(") reduce 248) (("+") reduce 248) (("-") reduce 248) ((";") reduce 248) (("@") reduce 248) ((T_ABSTRACT) reduce 248) ((T_ARRAY) reduce 248) ((T_ARRAY_CAST) reduce 248) ((T_ATTRIBUTE) reduce 248) ((T_BOOL_CAST) reduce 248) ((T_BREAK) reduce 248) ((T_CLASS) reduce 248) ((T_CLASS_C) reduce 248) ((T_CLONE) reduce 248) ((T_CONSTANT_ENCAPSED_STRING) reduce 248) ((T_CONTINUE) reduce 248) ((T_DEC) reduce 248) ((T_DECLARE) reduce 248) ((T_DIR) reduce 248) ((T_DNUMBER) reduce 248) ((T_DO) reduce 248) ((T_DOUBLE_CAST) reduce 248) ((T_ECHO) reduce 248) ((T_EMPTY) reduce 248) ((T_ENDFOR) reduce 248) ((T_ENUM) reduce 248) ((T_EVAL) reduce 248) ((T_EXIT) reduce 248) ((T_FILE) reduce 248) ((T_FINAL) reduce 248) ((T_FN) reduce 248) ((T_FOR) reduce 248) ((T_FOREACH) reduce 248) ((T_FUNCTION) reduce 248) ((T_FUNC_C) reduce 248) ((T_GLOBAL) reduce 248) ((T_GOTO) reduce 248) ((T_HALT_COMPILER) reduce 248) ((T_IF) reduce 248) ((T_INC) reduce 248) ((T_INCLUDE) reduce 248) ((T_INCLUDE_ONCE) reduce 248) ((T_INLINE_HTML) reduce 248) ((T_INTERFACE) reduce 248) ((T_INT_CAST) reduce 248) ((T_ISSET) reduce 248) ((T_LINE) reduce 248) ((T_LIST) reduce 248) ((T_LNUMBER) reduce 248) ((T_MATCH) reduce 248) ((T_METHOD_C) reduce 248) ((T_NAME_FULLY_QUALIFIED) reduce 248) ((T_NAME_QUALIFIED) reduce 248) ((T_NAME_RELATIVE) reduce 248) ((T_NEW) reduce 248) ((T_NS_C) reduce 248) ((T_OBJECT_CAST) reduce 248) ((T_PRINT) reduce 248) ((T_READONLY) reduce 248) ((T_REQUIRE) reduce 248) ((T_REQUIRE_ONCE) reduce 248) ((T_RETURN) reduce 248) ((T_START_HEREDOC) reduce 248) ((T_STATIC) reduce 248) ((T_STRING) reduce 248) ((T_STRING_CAST) reduce 248) ((T_SWITCH) reduce 248) ((T_THROW) reduce 248) ((T_TRAIT) reduce 248) ((T_TRAIT_C) reduce 248) ((T_TRY) reduce 248) ((T_UNSET) reduce 248) ((T_UNSET_CAST) reduce 248) ((T_VARIABLE) reduce 248) ((T_WHILE) reduce 248) ((T_YIELD) reduce 248) ((T_YIELD_FROM) reduce 248) (("[") reduce 248) (("`") reduce 248) (("{") reduce 248) (("~") reduce 248)) 20519 ((("!") reduce 239) (("\"") reduce 239) (("$") reduce 239) (("(") reduce 239) (("+") reduce 239) (("-") reduce 239) ((";") reduce 239) (("@") reduce 239) ((T_ABSTRACT) reduce 239) ((T_ARRAY) reduce 239) ((T_ARRAY_CAST) reduce 239) ((T_ATTRIBUTE) reduce 239) ((T_BOOL_CAST) reduce 239) ((T_BREAK) reduce 239) ((T_CLASS) reduce 239) ((T_CLASS_C) reduce 239) ((T_CLONE) reduce 239) ((T_CONSTANT_ENCAPSED_STRING) reduce 239) ((T_CONTINUE) reduce 239) ((T_DEC) reduce 239) ((T_DECLARE) reduce 239) ((T_DIR) reduce 239) ((T_DNUMBER) reduce 239) ((T_DO) reduce 239) ((T_DOUBLE_CAST) reduce 239) ((T_ECHO) reduce 239) ((T_EMPTY) reduce 239) ((T_ENDFOR) reduce 239) ((T_ENUM) reduce 239) ((T_EVAL) reduce 239) ((T_EXIT) reduce 239) ((T_FILE) reduce 239) ((T_FINAL) reduce 239) ((T_FN) reduce 239) ((T_FOR) reduce 239) ((T_FOREACH) reduce 239) ((T_FUNCTION) reduce 239) ((T_FUNC_C) reduce 239) ((T_GLOBAL) reduce 239) ((T_GOTO) reduce 239) ((T_HALT_COMPILER) reduce 239) ((T_IF) reduce 239) ((T_INC) reduce 239) ((T_INCLUDE) reduce 239) ((T_INCLUDE_ONCE) reduce 239) ((T_INLINE_HTML) reduce 239) ((T_INTERFACE) reduce 239) ((T_INT_CAST) reduce 239) ((T_ISSET) reduce 239) ((T_LINE) reduce 239) ((T_LIST) reduce 239) ((T_LNUMBER) reduce 239) ((T_MATCH) reduce 239) ((T_METHOD_C) reduce 239) ((T_NAME_FULLY_QUALIFIED) reduce 239) ((T_NAME_QUALIFIED) reduce 239) ((T_NAME_RELATIVE) reduce 239) ((T_NEW) reduce 239) ((T_NS_C) reduce 239) ((T_OBJECT_CAST) reduce 239) ((T_PRINT) reduce 239) ((T_READONLY) reduce 239) ((T_REQUIRE) reduce 239) ((T_REQUIRE_ONCE) reduce 239) ((T_RETURN) reduce 239) ((T_START_HEREDOC) reduce 239) ((T_STATIC) reduce 239) ((T_STRING) reduce 239) ((T_STRING_CAST) reduce 239) ((T_SWITCH) reduce 239) ((T_THROW) reduce 239) ((T_TRAIT) reduce 239) ((T_TRAIT_C) reduce 239) ((T_TRY) reduce 239) ((T_UNSET) reduce 239) ((T_UNSET_CAST) reduce 239) ((T_VARIABLE) reduce 239) ((T_WHILE) reduce 239) ((T_YIELD) reduce 239) ((T_YIELD_FROM) reduce 239) (("[") reduce 239) (("`") reduce 239) (("{") reduce 239) (("~") reduce 239)) 20520 ((("!") reduce 148) (("\"") reduce 148) (("$") reduce 148) (("(") reduce 148) (("+") reduce 148) (("-") reduce 148) ((";") reduce 148) (("@") reduce 148) ((T_ABSTRACT) reduce 148) ((T_ARRAY) reduce 148) ((T_ARRAY_CAST) reduce 148) ((T_ATTRIBUTE) reduce 148) ((T_BOOL_CAST) reduce 148) ((T_BREAK) reduce 148) ((T_CLASS) reduce 148) ((T_CLASS_C) reduce 148) ((T_CLONE) reduce 148) ((T_CONSTANT_ENCAPSED_STRING) reduce 148) ((T_CONTINUE) reduce 148) ((T_DEC) reduce 148) ((T_DECLARE) reduce 148) ((T_DIR) reduce 148) ((T_DNUMBER) reduce 148) ((T_DO) reduce 148) ((T_DOUBLE_CAST) reduce 148) ((T_ECHO) reduce 148) ((T_EMPTY) reduce 148) ((T_ENDFOR) reduce 148) ((T_ENUM) reduce 148) ((T_EVAL) reduce 148) ((T_EXIT) reduce 148) ((T_FILE) reduce 148) ((T_FINAL) reduce 148) ((T_FN) reduce 148) ((T_FOR) reduce 148) ((T_FOREACH) reduce 148) ((T_FUNCTION) reduce 148) ((T_FUNC_C) reduce 148) ((T_GLOBAL) reduce 148) ((T_GOTO) reduce 148) ((T_HALT_COMPILER) reduce 148) ((T_IF) reduce 148) ((T_INC) reduce 148) ((T_INCLUDE) reduce 148) ((T_INCLUDE_ONCE) reduce 148) ((T_INLINE_HTML) reduce 148) ((T_INTERFACE) reduce 148) ((T_INT_CAST) reduce 148) ((T_ISSET) reduce 148) ((T_LINE) reduce 148) ((T_LIST) reduce 148) ((T_LNUMBER) reduce 148) ((T_MATCH) reduce 148) ((T_METHOD_C) reduce 148) ((T_NAME_FULLY_QUALIFIED) reduce 148) ((T_NAME_QUALIFIED) reduce 148) ((T_NAME_RELATIVE) reduce 148) ((T_NEW) reduce 148) ((T_NS_C) reduce 148) ((T_OBJECT_CAST) reduce 148) ((T_PRINT) reduce 148) ((T_READONLY) reduce 148) ((T_REQUIRE) reduce 148) ((T_REQUIRE_ONCE) reduce 148) ((T_RETURN) reduce 148) ((T_START_HEREDOC) reduce 148) ((T_STATIC) reduce 148) ((T_STRING) reduce 148) ((T_STRING_CAST) reduce 148) ((T_SWITCH) reduce 148) ((T_THROW) reduce 148) ((T_TRAIT) reduce 148) ((T_TRAIT_C) reduce 148) ((T_TRY) reduce 148) ((T_UNSET) reduce 148) ((T_UNSET_CAST) reduce 148) ((T_VARIABLE) reduce 148) ((T_WHILE) reduce 148) ((T_YIELD) reduce 148) ((T_YIELD_FROM) reduce 148) (("[") reduce 148) (("`") reduce 148) (("{") reduce 148) (("~") reduce 148)) 20523 ((("!") reduce 240) (("\"") reduce 240) (("$") reduce 240) (("(") reduce 240) (("+") reduce 240) (("-") reduce 240) ((";") reduce 240) (("@") reduce 240) ((T_ABSTRACT) reduce 240) ((T_ARRAY) reduce 240) ((T_ARRAY_CAST) reduce 240) ((T_ATTRIBUTE) reduce 240) ((T_BOOL_CAST) reduce 240) ((T_BREAK) reduce 240) ((T_CLASS) reduce 240) ((T_CLASS_C) reduce 240) ((T_CLONE) reduce 240) ((T_CONSTANT_ENCAPSED_STRING) reduce 240) ((T_CONTINUE) reduce 240) ((T_DEC) reduce 240) ((T_DECLARE) reduce 240) ((T_DIR) reduce 240) ((T_DNUMBER) reduce 240) ((T_DO) reduce 240) ((T_DOUBLE_CAST) reduce 240) ((T_ECHO) reduce 240) ((T_EMPTY) reduce 240) ((T_ENDFOR) reduce 240) ((T_ENUM) reduce 240) ((T_EVAL) reduce 240) ((T_EXIT) reduce 240) ((T_FILE) reduce 240) ((T_FINAL) reduce 240) ((T_FN) reduce 240) ((T_FOR) reduce 240) ((T_FOREACH) reduce 240) ((T_FUNCTION) reduce 240) ((T_FUNC_C) reduce 240) ((T_GLOBAL) reduce 240) ((T_GOTO) reduce 240) ((T_HALT_COMPILER) reduce 240) ((T_IF) reduce 240) ((T_INC) reduce 240) ((T_INCLUDE) reduce 240) ((T_INCLUDE_ONCE) reduce 240) ((T_INLINE_HTML) reduce 240) ((T_INTERFACE) reduce 240) ((T_INT_CAST) reduce 240) ((T_ISSET) reduce 240) ((T_LINE) reduce 240) ((T_LIST) reduce 240) ((T_LNUMBER) reduce 240) ((T_MATCH) reduce 240) ((T_METHOD_C) reduce 240) ((T_NAME_FULLY_QUALIFIED) reduce 240) ((T_NAME_QUALIFIED) reduce 240) ((T_NAME_RELATIVE) reduce 240) ((T_NEW) reduce 240) ((T_NS_C) reduce 240) ((T_OBJECT_CAST) reduce 240) ((T_PRINT) reduce 240) ((T_READONLY) reduce 240) ((T_REQUIRE) reduce 240) ((T_REQUIRE_ONCE) reduce 240) ((T_RETURN) reduce 240) ((T_START_HEREDOC) reduce 240) ((T_STATIC) reduce 240) ((T_STRING) reduce 240) ((T_STRING_CAST) reduce 240) ((T_SWITCH) reduce 240) ((T_THROW) reduce 240) ((T_TRAIT) reduce 240) ((T_TRAIT_C) reduce 240) ((T_TRY) reduce 240) ((T_UNSET) reduce 240) ((T_UNSET_CAST) reduce 240) ((T_VARIABLE) reduce 240) ((T_WHILE) reduce 240) ((T_YIELD) reduce 240) ((T_YIELD_FROM) reduce 240) (("[") reduce 240) (("`") reduce 240) (("{") reduce 240) (("~") reduce 240)) 20528 ((("!") reduce 160) (("\"") reduce 160) (("$") reduce 160) (("(") reduce 160) (("+") reduce 160) (("-") reduce 160) ((";") reduce 160) (("@") reduce 160) ((T_ABSTRACT) reduce 160) ((T_ARRAY) reduce 160) ((T_ARRAY_CAST) reduce 160) ((T_ATTRIBUTE) reduce 160) ((T_BOOL_CAST) reduce 160) ((T_BREAK) reduce 160) ((T_CLASS) reduce 160) ((T_CLASS_C) reduce 160) ((T_CLONE) reduce 160) ((T_CONSTANT_ENCAPSED_STRING) reduce 160) ((T_CONTINUE) reduce 160) ((T_DEC) reduce 160) ((T_DECLARE) reduce 160) ((T_DIR) reduce 160) ((T_DNUMBER) reduce 160) ((T_DO) reduce 160) ((T_DOUBLE_CAST) reduce 160) ((T_ECHO) reduce 160) ((T_EMPTY) reduce 160) ((T_ENDFOR) reduce 160) ((T_ENUM) reduce 160) ((T_EVAL) reduce 160) ((T_EXIT) reduce 160) ((T_FILE) reduce 160) ((T_FINAL) reduce 160) ((T_FN) reduce 160) ((T_FOR) reduce 160) ((T_FOREACH) reduce 160) ((T_FUNCTION) reduce 160) ((T_FUNC_C) reduce 160) ((T_GLOBAL) reduce 160) ((T_GOTO) reduce 160) ((T_HALT_COMPILER) reduce 160) ((T_IF) reduce 160) ((T_INC) reduce 160) ((T_INCLUDE) reduce 160) ((T_INCLUDE_ONCE) reduce 160) ((T_INLINE_HTML) reduce 160) ((T_INTERFACE) reduce 160) ((T_INT_CAST) reduce 160) ((T_ISSET) reduce 160) ((T_LINE) reduce 160) ((T_LIST) reduce 160) ((T_LNUMBER) reduce 160) ((T_MATCH) reduce 160) ((T_METHOD_C) reduce 160) ((T_NAME_FULLY_QUALIFIED) reduce 160) ((T_NAME_QUALIFIED) reduce 160) ((T_NAME_RELATIVE) reduce 160) ((T_NEW) reduce 160) ((T_NS_C) reduce 160) ((T_OBJECT_CAST) reduce 160) ((T_PRINT) reduce 160) ((T_READONLY) reduce 160) ((T_REQUIRE) reduce 160) ((T_REQUIRE_ONCE) reduce 160) ((T_RETURN) reduce 160) ((T_START_HEREDOC) reduce 160) ((T_STATIC) reduce 160) ((T_STRING) reduce 160) ((T_STRING_CAST) reduce 160) ((T_SWITCH) reduce 160) ((T_THROW) reduce 160) ((T_TRAIT) reduce 160) ((T_TRAIT_C) reduce 160) ((T_TRY) reduce 160) ((T_UNSET) reduce 160) ((T_UNSET_CAST) reduce 160) ((T_VARIABLE) reduce 160) ((T_WHILE) reduce 160) ((T_YIELD) reduce 160) ((T_YIELD_FROM) reduce 160) (("[") reduce 160) (("`") reduce 160) (("{") reduce 160) (("~") reduce 160)) 20531 ((("!") reduce 168) (("\"") reduce 168) (("$") reduce 168) (("(") reduce 168) (("+") reduce 168) (("-") reduce 168) ((";") reduce 168) (("@") reduce 168) ((T_ABSTRACT) reduce 168) ((T_ARRAY) reduce 168) ((T_ARRAY_CAST) reduce 168) ((T_ATTRIBUTE) reduce 168) ((T_BOOL_CAST) reduce 168) ((T_BREAK) reduce 168) ((T_CATCH) reduce 168) ((T_CLASS) reduce 168) ((T_CLASS_C) reduce 168) ((T_CLONE) reduce 168) ((T_CONSTANT_ENCAPSED_STRING) reduce 168) ((T_CONTINUE) reduce 168) ((T_DEC) reduce 168) ((T_DECLARE) reduce 168) ((T_DIR) reduce 168) ((T_DNUMBER) reduce 168) ((T_DO) reduce 168) ((T_DOUBLE_CAST) reduce 168) ((T_ECHO) reduce 168) ((T_EMPTY) reduce 168) ((T_ENDFOR) reduce 168) ((T_ENUM) reduce 168) ((T_EVAL) reduce 168) ((T_EXIT) reduce 168) ((T_FILE) reduce 168) ((T_FINAL) reduce 168) ((T_FINALLY) reduce 168) ((T_FN) reduce 168) ((T_FOR) reduce 168) ((T_FOREACH) reduce 168) ((T_FUNCTION) reduce 168) ((T_FUNC_C) reduce 168) ((T_GLOBAL) reduce 168) ((T_GOTO) reduce 168) ((T_HALT_COMPILER) reduce 168) ((T_IF) reduce 168) ((T_INC) reduce 168) ((T_INCLUDE) reduce 168) ((T_INCLUDE_ONCE) reduce 168) ((T_INLINE_HTML) reduce 168) ((T_INTERFACE) reduce 168) ((T_INT_CAST) reduce 168) ((T_ISSET) reduce 168) ((T_LINE) reduce 168) ((T_LIST) reduce 168) ((T_LNUMBER) reduce 168) ((T_MATCH) reduce 168) ((T_METHOD_C) reduce 168) ((T_NAME_FULLY_QUALIFIED) reduce 168) ((T_NAME_QUALIFIED) reduce 168) ((T_NAME_RELATIVE) reduce 168) ((T_NEW) reduce 168) ((T_NS_C) reduce 168) ((T_OBJECT_CAST) reduce 168) ((T_PRINT) reduce 168) ((T_READONLY) reduce 168) ((T_REQUIRE) reduce 168) ((T_REQUIRE_ONCE) reduce 168) ((T_RETURN) reduce 168) ((T_START_HEREDOC) reduce 168) ((T_STATIC) reduce 168) ((T_STRING) reduce 168) ((T_STRING_CAST) reduce 168) ((T_SWITCH) reduce 168) ((T_THROW) reduce 168) ((T_TRAIT) reduce 168) ((T_TRAIT_C) reduce 168) ((T_TRY) reduce 168) ((T_UNSET) reduce 168) ((T_UNSET_CAST) reduce 168) ((T_VARIABLE) reduce 168) ((T_WHILE) reduce 168) ((T_YIELD) reduce 168) ((T_YIELD_FROM) reduce 168) (("[") reduce 168) (("`") reduce 168) (("{") reduce 168) (("~") reduce 168)) 20532 ((("!") reduce 174) (("\"") reduce 174) (("$") reduce 174) (("(") reduce 174) (("+") reduce 174) (("-") reduce 174) ((";") reduce 174) (("@") reduce 174) ((T_ABSTRACT) reduce 174) ((T_ARRAY) reduce 174) ((T_ARRAY_CAST) reduce 174) ((T_ATTRIBUTE) reduce 174) ((T_BOOL_CAST) reduce 174) ((T_BREAK) reduce 174) ((T_CATCH) shift) ((T_CLASS) reduce 174) ((T_CLASS_C) reduce 174) ((T_CLONE) reduce 174) ((T_CONSTANT_ENCAPSED_STRING) reduce 174) ((T_CONTINUE) reduce 174) ((T_DEC) reduce 174) ((T_DECLARE) reduce 174) ((T_DIR) reduce 174) ((T_DNUMBER) reduce 174) ((T_DO) reduce 174) ((T_DOUBLE_CAST) reduce 174) ((T_ECHO) reduce 174) ((T_EMPTY) reduce 174) ((T_ENDFOR) reduce 174) ((T_ENUM) reduce 174) ((T_EVAL) reduce 174) ((T_EXIT) reduce 174) ((T_FILE) reduce 174) ((T_FINAL) reduce 174) ((T_FINALLY) shift) ((T_FN) reduce 174) ((T_FOR) reduce 174) ((T_FOREACH) reduce 174) ((T_FUNCTION) reduce 174) ((T_FUNC_C) reduce 174) ((T_GLOBAL) reduce 174) ((T_GOTO) reduce 174) ((T_HALT_COMPILER) reduce 174) ((T_IF) reduce 174) ((T_INC) reduce 174) ((T_INCLUDE) reduce 174) ((T_INCLUDE_ONCE) reduce 174) ((T_INLINE_HTML) reduce 174) ((T_INTERFACE) reduce 174) ((T_INT_CAST) reduce 174) ((T_ISSET) reduce 174) ((T_LINE) reduce 174) ((T_LIST) reduce 174) ((T_LNUMBER) reduce 174) ((T_MATCH) reduce 174) ((T_METHOD_C) reduce 174) ((T_NAME_FULLY_QUALIFIED) reduce 174) ((T_NAME_QUALIFIED) reduce 174) ((T_NAME_RELATIVE) reduce 174) ((T_NEW) reduce 174) ((T_NS_C) reduce 174) ((T_OBJECT_CAST) reduce 174) ((T_PRINT) reduce 174) ((T_READONLY) reduce 174) ((T_REQUIRE) reduce 174) ((T_REQUIRE_ONCE) reduce 174) ((T_RETURN) reduce 174) ((T_START_HEREDOC) reduce 174) ((T_STATIC) reduce 174) ((T_STRING) reduce 174) ((T_STRING_CAST) reduce 174) ((T_SWITCH) reduce 174) ((T_THROW) reduce 174) ((T_TRAIT) reduce 174) ((T_TRAIT_C) reduce 174) ((T_TRY) reduce 174) ((T_UNSET) reduce 174) ((T_UNSET_CAST) reduce 174) ((T_VARIABLE) reduce 174) ((T_WHILE) reduce 174) ((T_YIELD) reduce 174) ((T_YIELD_FROM) reduce 174) (("[") reduce 174) (("`") reduce 174) (("{") reduce 174) (("~") reduce 174)) 20535 ((("!") reduce 165) (("\"") reduce 165) (("$") reduce 165) (("(") reduce 165) (("+") reduce 165) (("-") reduce 165) ((";") reduce 165) (("@") reduce 165) ((T_ABSTRACT) reduce 165) ((T_ARRAY) reduce 165) ((T_ARRAY_CAST) reduce 165) ((T_ATTRIBUTE) reduce 165) ((T_BOOL_CAST) reduce 165) ((T_BREAK) reduce 165) ((T_CLASS) reduce 165) ((T_CLASS_C) reduce 165) ((T_CLONE) reduce 165) ((T_CONSTANT_ENCAPSED_STRING) reduce 165) ((T_CONTINUE) reduce 165) ((T_DEC) reduce 165) ((T_DECLARE) reduce 165) ((T_DIR) reduce 165) ((T_DNUMBER) reduce 165) ((T_DO) reduce 165) ((T_DOUBLE_CAST) reduce 165) ((T_ECHO) reduce 165) ((T_EMPTY) reduce 165) ((T_ENDFOR) reduce 165) ((T_ENUM) reduce 165) ((T_EVAL) reduce 165) ((T_EXIT) reduce 165) ((T_FILE) reduce 165) ((T_FINAL) reduce 165) ((T_FN) reduce 165) ((T_FOR) reduce 165) ((T_FOREACH) reduce 165) ((T_FUNCTION) reduce 165) ((T_FUNC_C) reduce 165) ((T_GLOBAL) reduce 165) ((T_GOTO) reduce 165) ((T_HALT_COMPILER) reduce 165) ((T_IF) reduce 165) ((T_INC) reduce 165) ((T_INCLUDE) reduce 165) ((T_INCLUDE_ONCE) reduce 165) ((T_INLINE_HTML) reduce 165) ((T_INTERFACE) reduce 165) ((T_INT_CAST) reduce 165) ((T_ISSET) reduce 165) ((T_LINE) reduce 165) ((T_LIST) reduce 165) ((T_LNUMBER) reduce 165) ((T_MATCH) reduce 165) ((T_METHOD_C) reduce 165) ((T_NAME_FULLY_QUALIFIED) reduce 165) ((T_NAME_QUALIFIED) reduce 165) ((T_NAME_RELATIVE) reduce 165) ((T_NEW) reduce 165) ((T_NS_C) reduce 165) ((T_OBJECT_CAST) reduce 165) ((T_PRINT) reduce 165) ((T_READONLY) reduce 165) ((T_REQUIRE) reduce 165) ((T_REQUIRE_ONCE) reduce 165) ((T_RETURN) reduce 165) ((T_START_HEREDOC) reduce 165) ((T_STATIC) reduce 165) ((T_STRING) reduce 165) ((T_STRING_CAST) reduce 165) ((T_SWITCH) reduce 165) ((T_THROW) reduce 165) ((T_TRAIT) reduce 165) ((T_TRAIT_C) reduce 165) ((T_TRY) reduce 165) ((T_UNSET) reduce 165) ((T_UNSET_CAST) reduce 165) ((T_VARIABLE) reduce 165) ((T_WHILE) reduce 165) ((T_YIELD) reduce 165) ((T_YIELD_FROM) reduce 165) (("[") reduce 165) (("`") reduce 165) (("{") reduce 165) (("~") reduce 165)) 20538 ((("!") reduce 175) (("\"") reduce 175) (("$") reduce 175) (("(") reduce 175) (("+") reduce 175) (("-") reduce 175) ((";") reduce 175) (("@") reduce 175) ((T_ABSTRACT) reduce 175) ((T_ARRAY) reduce 175) ((T_ARRAY_CAST) reduce 175) ((T_ATTRIBUTE) reduce 175) ((T_BOOL_CAST) reduce 175) ((T_BREAK) reduce 175) ((T_CLASS) reduce 175) ((T_CLASS_C) reduce 175) ((T_CLONE) reduce 175) ((T_CONSTANT_ENCAPSED_STRING) reduce 175) ((T_CONTINUE) reduce 175) ((T_DEC) reduce 175) ((T_DECLARE) reduce 175) ((T_DIR) reduce 175) ((T_DNUMBER) reduce 175) ((T_DO) reduce 175) ((T_DOUBLE_CAST) reduce 175) ((T_ECHO) reduce 175) ((T_EMPTY) reduce 175) ((T_ENDFOR) reduce 175) ((T_ENUM) reduce 175) ((T_EVAL) reduce 175) ((T_EXIT) reduce 175) ((T_FILE) reduce 175) ((T_FINAL) reduce 175) ((T_FN) reduce 175) ((T_FOR) reduce 175) ((T_FOREACH) reduce 175) ((T_FUNCTION) reduce 175) ((T_FUNC_C) reduce 175) ((T_GLOBAL) reduce 175) ((T_GOTO) reduce 175) ((T_HALT_COMPILER) reduce 175) ((T_IF) reduce 175) ((T_INC) reduce 175) ((T_INCLUDE) reduce 175) ((T_INCLUDE_ONCE) reduce 175) ((T_INLINE_HTML) reduce 175) ((T_INTERFACE) reduce 175) ((T_INT_CAST) reduce 175) ((T_ISSET) reduce 175) ((T_LINE) reduce 175) ((T_LIST) reduce 175) ((T_LNUMBER) reduce 175) ((T_MATCH) reduce 175) ((T_METHOD_C) reduce 175) ((T_NAME_FULLY_QUALIFIED) reduce 175) ((T_NAME_QUALIFIED) reduce 175) ((T_NAME_RELATIVE) reduce 175) ((T_NEW) reduce 175) ((T_NS_C) reduce 175) ((T_OBJECT_CAST) reduce 175) ((T_PRINT) reduce 175) ((T_READONLY) reduce 175) ((T_REQUIRE) reduce 175) ((T_REQUIRE_ONCE) reduce 175) ((T_RETURN) reduce 175) ((T_START_HEREDOC) reduce 175) ((T_STATIC) reduce 175) ((T_STRING) reduce 175) ((T_STRING_CAST) reduce 175) ((T_SWITCH) reduce 175) ((T_THROW) reduce 175) ((T_TRAIT) reduce 175) ((T_TRAIT_C) reduce 175) ((T_TRY) reduce 175) ((T_UNSET) reduce 175) ((T_UNSET_CAST) reduce 175) ((T_VARIABLE) reduce 175) ((T_WHILE) reduce 175) ((T_YIELD) reduce 175) ((T_YIELD_FROM) reduce 175) (("[") reduce 175) (("`") reduce 175) (("{") reduce 175) (("~") reduce 175)) 20545 ((("!") reduce 169) (("\"") reduce 169) (("$") reduce 169) (("(") reduce 169) (("+") reduce 169) (("-") reduce 169) ((";") reduce 169) (("@") reduce 169) ((T_ABSTRACT) reduce 169) ((T_ARRAY) reduce 169) ((T_ARRAY_CAST) reduce 169) ((T_ATTRIBUTE) reduce 169) ((T_BOOL_CAST) reduce 169) ((T_BREAK) reduce 169) ((T_CATCH) reduce 169) ((T_CLASS) reduce 169) ((T_CLASS_C) reduce 169) ((T_CLONE) reduce 169) ((T_CONSTANT_ENCAPSED_STRING) reduce 169) ((T_CONTINUE) reduce 169) ((T_DEC) reduce 169) ((T_DECLARE) reduce 169) ((T_DIR) reduce 169) ((T_DNUMBER) reduce 169) ((T_DO) reduce 169) ((T_DOUBLE_CAST) reduce 169) ((T_ECHO) reduce 169) ((T_EMPTY) reduce 169) ((T_ENDFOR) reduce 169) ((T_ENUM) reduce 169) ((T_EVAL) reduce 169) ((T_EXIT) reduce 169) ((T_FILE) reduce 169) ((T_FINAL) reduce 169) ((T_FINALLY) reduce 169) ((T_FN) reduce 169) ((T_FOR) reduce 169) ((T_FOREACH) reduce 169) ((T_FUNCTION) reduce 169) ((T_FUNC_C) reduce 169) ((T_GLOBAL) reduce 169) ((T_GOTO) reduce 169) ((T_HALT_COMPILER) reduce 169) ((T_IF) reduce 169) ((T_INC) reduce 169) ((T_INCLUDE) reduce 169) ((T_INCLUDE_ONCE) reduce 169) ((T_INLINE_HTML) reduce 169) ((T_INTERFACE) reduce 169) ((T_INT_CAST) reduce 169) ((T_ISSET) reduce 169) ((T_LINE) reduce 169) ((T_LIST) reduce 169) ((T_LNUMBER) reduce 169) ((T_MATCH) reduce 169) ((T_METHOD_C) reduce 169) ((T_NAME_FULLY_QUALIFIED) reduce 169) ((T_NAME_QUALIFIED) reduce 169) ((T_NAME_RELATIVE) reduce 169) ((T_NEW) reduce 169) ((T_NS_C) reduce 169) ((T_OBJECT_CAST) reduce 169) ((T_PRINT) reduce 169) ((T_READONLY) reduce 169) ((T_REQUIRE) reduce 169) ((T_REQUIRE_ONCE) reduce 169) ((T_RETURN) reduce 169) ((T_START_HEREDOC) reduce 169) ((T_STATIC) reduce 169) ((T_STRING) reduce 169) ((T_STRING_CAST) reduce 169) ((T_SWITCH) reduce 169) ((T_THROW) reduce 169) ((T_TRAIT) reduce 169) ((T_TRAIT_C) reduce 169) ((T_TRY) reduce 169) ((T_UNSET) reduce 169) ((T_UNSET_CAST) reduce 169) ((T_VARIABLE) reduce 169) ((T_WHILE) reduce 169) ((T_YIELD) reduce 169) ((T_YIELD_FROM) reduce 169) (("[") reduce 169) (("`") reduce 169) (("{") reduce 169) (("~") reduce 169)) 20550 ((("!") reduce 197) (("\"") reduce 197) (("$") reduce 197) (("(") reduce 197) (("+") reduce 197) (("-") reduce 197) ((";") reduce 197) (("@") reduce 197) ((T_ABSTRACT) reduce 197) ((T_ARRAY) reduce 197) ((T_ARRAY_CAST) reduce 197) ((T_ATTRIBUTE) reduce 197) ((T_BOOL_CAST) reduce 197) ((T_BREAK) reduce 197) ((T_CLASS) reduce 197) ((T_CLASS_C) reduce 197) ((T_CLONE) reduce 197) ((T_CONSTANT_ENCAPSED_STRING) reduce 197) ((T_CONTINUE) reduce 197) ((T_DEC) reduce 197) ((T_DECLARE) reduce 197) ((T_DIR) reduce 197) ((T_DNUMBER) reduce 197) ((T_DO) reduce 197) ((T_DOUBLE_CAST) reduce 197) ((T_ECHO) reduce 197) ((T_EMPTY) reduce 197) ((T_ENDFOR) reduce 197) ((T_ENUM) reduce 197) ((T_EVAL) reduce 197) ((T_EXIT) reduce 197) ((T_FILE) reduce 197) ((T_FINAL) reduce 197) ((T_FN) reduce 197) ((T_FOR) reduce 197) ((T_FOREACH) reduce 197) ((T_FUNCTION) reduce 197) ((T_FUNC_C) reduce 197) ((T_GLOBAL) reduce 197) ((T_GOTO) reduce 197) ((T_HALT_COMPILER) reduce 197) ((T_IF) reduce 197) ((T_INC) reduce 197) ((T_INCLUDE) reduce 197) ((T_INCLUDE_ONCE) reduce 197) ((T_INLINE_HTML) reduce 197) ((T_INTERFACE) reduce 197) ((T_INT_CAST) reduce 197) ((T_ISSET) reduce 197) ((T_LINE) reduce 197) ((T_LIST) reduce 197) ((T_LNUMBER) reduce 197) ((T_MATCH) reduce 197) ((T_METHOD_C) reduce 197) ((T_NAME_FULLY_QUALIFIED) reduce 197) ((T_NAME_QUALIFIED) reduce 197) ((T_NAME_RELATIVE) reduce 197) ((T_NEW) reduce 197) ((T_NS_C) reduce 197) ((T_OBJECT_CAST) reduce 197) ((T_PRINT) reduce 197) ((T_READONLY) reduce 197) ((T_REQUIRE) reduce 197) ((T_REQUIRE_ONCE) reduce 197) ((T_RETURN) reduce 197) ((T_START_HEREDOC) reduce 197) ((T_STATIC) reduce 197) ((T_STRING) reduce 197) ((T_STRING_CAST) reduce 197) ((T_SWITCH) reduce 197) ((T_THROW) reduce 197) ((T_TRAIT) reduce 197) ((T_TRAIT_C) reduce 197) ((T_TRY) reduce 197) ((T_UNSET) reduce 197) ((T_UNSET_CAST) reduce 197) ((T_VARIABLE) reduce 197) ((T_WHILE) reduce 197) ((T_YIELD) reduce 197) ((T_YIELD_FROM) reduce 197) (("[") reduce 197) (("`") reduce 197) (("{") reduce 197) (("~") reduce 197)) 20555 ((("!") reduce 151) (("\"") reduce 151) (("$") reduce 151) (("(") reduce 151) (("+") reduce 151) (("-") reduce 151) ((";") reduce 151) (("@") reduce 151) ((T_ABSTRACT) reduce 151) ((T_ARRAY) reduce 151) ((T_ARRAY_CAST) reduce 151) ((T_ATTRIBUTE) reduce 151) ((T_BOOL_CAST) reduce 151) ((T_BREAK) reduce 151) ((T_CLASS) reduce 151) ((T_CLASS_C) reduce 151) ((T_CLONE) reduce 151) ((T_CONSTANT_ENCAPSED_STRING) reduce 151) ((T_CONTINUE) reduce 151) ((T_DEC) reduce 151) ((T_DECLARE) reduce 151) ((T_DIR) reduce 151) ((T_DNUMBER) reduce 151) ((T_DO) reduce 151) ((T_DOUBLE_CAST) reduce 151) ((T_ECHO) reduce 151) ((T_EMPTY) reduce 151) ((T_ENDFOR) reduce 151) ((T_ENUM) reduce 151) ((T_EVAL) reduce 151) ((T_EXIT) reduce 151) ((T_FILE) reduce 151) ((T_FINAL) reduce 151) ((T_FN) reduce 151) ((T_FOR) reduce 151) ((T_FOREACH) reduce 151) ((T_FUNCTION) reduce 151) ((T_FUNC_C) reduce 151) ((T_GLOBAL) reduce 151) ((T_GOTO) reduce 151) ((T_HALT_COMPILER) reduce 151) ((T_IF) reduce 151) ((T_INC) reduce 151) ((T_INCLUDE) reduce 151) ((T_INCLUDE_ONCE) reduce 151) ((T_INLINE_HTML) reduce 151) ((T_INTERFACE) reduce 151) ((T_INT_CAST) reduce 151) ((T_ISSET) reduce 151) ((T_LINE) reduce 151) ((T_LIST) reduce 151) ((T_LNUMBER) reduce 151) ((T_MATCH) reduce 151) ((T_METHOD_C) reduce 151) ((T_NAME_FULLY_QUALIFIED) reduce 151) ((T_NAME_QUALIFIED) reduce 151) ((T_NAME_RELATIVE) reduce 151) ((T_NEW) reduce 151) ((T_NS_C) reduce 151) ((T_OBJECT_CAST) reduce 151) ((T_PRINT) reduce 151) ((T_READONLY) reduce 151) ((T_REQUIRE) reduce 151) ((T_REQUIRE_ONCE) reduce 151) ((T_RETURN) reduce 151) ((T_START_HEREDOC) reduce 151) ((T_STATIC) reduce 151) ((T_STRING) reduce 151) ((T_STRING_CAST) reduce 151) ((T_SWITCH) reduce 151) ((T_THROW) reduce 151) ((T_TRAIT) reduce 151) ((T_TRAIT_C) reduce 151) ((T_TRY) reduce 151) ((T_UNSET) reduce 151) ((T_UNSET_CAST) reduce 151) ((T_VARIABLE) reduce 151) ((T_WHILE) reduce 151) ((T_YIELD) reduce 151) ((T_YIELD_FROM) reduce 151) (("[") reduce 151) (("`") reduce 151) (("{") reduce 151) (("~") reduce 151)) 20559 ((("!") reduce 221) (("\"") reduce 221) (("$") reduce 221) (("(") reduce 221) (("+") reduce 221) (("-") reduce 221) ((";") reduce 221) (("@") reduce 221) ((T_ABSTRACT) reduce 221) ((T_ARRAY) reduce 221) ((T_ARRAY_CAST) reduce 221) ((T_ATTRIBUTE) reduce 221) ((T_BOOL_CAST) reduce 221) ((T_BREAK) reduce 221) ((T_CLASS) reduce 221) ((T_CLASS_C) reduce 221) ((T_CLONE) reduce 221) ((T_CONSTANT_ENCAPSED_STRING) reduce 221) ((T_CONTINUE) reduce 221) ((T_DEC) reduce 221) ((T_DECLARE) reduce 221) ((T_DIR) reduce 221) ((T_DNUMBER) reduce 221) ((T_DO) reduce 221) ((T_DOUBLE_CAST) reduce 221) ((T_ECHO) reduce 221) ((T_EMPTY) reduce 221) ((T_ENDFOR) reduce 221) ((T_ENUM) reduce 221) ((T_EVAL) reduce 221) ((T_EXIT) reduce 221) ((T_FILE) reduce 221) ((T_FINAL) reduce 221) ((T_FN) reduce 221) ((T_FOR) reduce 221) ((T_FOREACH) reduce 221) ((T_FUNCTION) reduce 221) ((T_FUNC_C) reduce 221) ((T_GLOBAL) reduce 221) ((T_GOTO) reduce 221) ((T_HALT_COMPILER) reduce 221) ((T_IF) reduce 221) ((T_INC) reduce 221) ((T_INCLUDE) reduce 221) ((T_INCLUDE_ONCE) reduce 221) ((T_INLINE_HTML) reduce 221) ((T_INTERFACE) reduce 221) ((T_INT_CAST) reduce 221) ((T_ISSET) reduce 221) ((T_LINE) reduce 221) ((T_LIST) reduce 221) ((T_LNUMBER) reduce 221) ((T_MATCH) reduce 221) ((T_METHOD_C) reduce 221) ((T_NAME_FULLY_QUALIFIED) reduce 221) ((T_NAME_QUALIFIED) reduce 221) ((T_NAME_RELATIVE) reduce 221) ((T_NEW) reduce 221) ((T_NS_C) reduce 221) ((T_OBJECT_CAST) reduce 221) ((T_PRINT) reduce 221) ((T_READONLY) reduce 221) ((T_REQUIRE) reduce 221) ((T_REQUIRE_ONCE) reduce 221) ((T_RETURN) reduce 221) ((T_START_HEREDOC) reduce 221) ((T_STATIC) reduce 221) ((T_STRING) reduce 221) ((T_STRING_CAST) reduce 221) ((T_SWITCH) reduce 221) ((T_THROW) reduce 221) ((T_TRAIT) reduce 221) ((T_TRAIT_C) reduce 221) ((T_TRY) reduce 221) ((T_UNSET) reduce 221) ((T_UNSET_CAST) reduce 221) ((T_VARIABLE) reduce 221) ((T_WHILE) reduce 221) ((T_YIELD) reduce 221) ((T_YIELD_FROM) reduce 221) (("[") reduce 221) (("`") reduce 221) (("{") reduce 221) (("~") reduce 221)) 20561 ((("!") reduce 222) (("\"") reduce 222) (("$") reduce 222) (("(") reduce 222) (("+") reduce 222) (("-") reduce 222) ((";") reduce 222) (("@") reduce 222) ((T_ABSTRACT) reduce 222) ((T_ARRAY) reduce 222) ((T_ARRAY_CAST) reduce 222) ((T_ATTRIBUTE) reduce 222) ((T_BOOL_CAST) reduce 222) ((T_BREAK) reduce 222) ((T_CLASS) reduce 222) ((T_CLASS_C) reduce 222) ((T_CLONE) reduce 222) ((T_CONSTANT_ENCAPSED_STRING) reduce 222) ((T_CONTINUE) reduce 222) ((T_DEC) reduce 222) ((T_DECLARE) reduce 222) ((T_DIR) reduce 222) ((T_DNUMBER) reduce 222) ((T_DO) reduce 222) ((T_DOUBLE_CAST) reduce 222) ((T_ECHO) reduce 222) ((T_EMPTY) reduce 222) ((T_ENDFOR) reduce 222) ((T_ENUM) reduce 222) ((T_EVAL) reduce 222) ((T_EXIT) reduce 222) ((T_FILE) reduce 222) ((T_FINAL) reduce 222) ((T_FN) reduce 222) ((T_FOR) reduce 222) ((T_FOREACH) reduce 222) ((T_FUNCTION) reduce 222) ((T_FUNC_C) reduce 222) ((T_GLOBAL) reduce 222) ((T_GOTO) reduce 222) ((T_HALT_COMPILER) reduce 222) ((T_IF) reduce 222) ((T_INC) reduce 222) ((T_INCLUDE) reduce 222) ((T_INCLUDE_ONCE) reduce 222) ((T_INLINE_HTML) reduce 222) ((T_INTERFACE) reduce 222) ((T_INT_CAST) reduce 222) ((T_ISSET) reduce 222) ((T_LINE) reduce 222) ((T_LIST) reduce 222) ((T_LNUMBER) reduce 222) ((T_MATCH) reduce 222) ((T_METHOD_C) reduce 222) ((T_NAME_FULLY_QUALIFIED) reduce 222) ((T_NAME_QUALIFIED) reduce 222) ((T_NAME_RELATIVE) reduce 222) ((T_NEW) reduce 222) ((T_NS_C) reduce 222) ((T_OBJECT_CAST) reduce 222) ((T_PRINT) reduce 222) ((T_READONLY) reduce 222) ((T_REQUIRE) reduce 222) ((T_REQUIRE_ONCE) reduce 222) ((T_RETURN) reduce 222) ((T_START_HEREDOC) reduce 222) ((T_STATIC) reduce 222) ((T_STRING) reduce 222) ((T_STRING_CAST) reduce 222) ((T_SWITCH) reduce 222) ((T_THROW) reduce 222) ((T_TRAIT) reduce 222) ((T_TRAIT_C) reduce 222) ((T_TRY) reduce 222) ((T_UNSET) reduce 222) ((T_UNSET_CAST) reduce 222) ((T_VARIABLE) reduce 222) ((T_WHILE) reduce 222) ((T_YIELD) reduce 222) ((T_YIELD_FROM) reduce 222) (("[") reduce 222) (("`") reduce 222) (("{") reduce 222) (("~") reduce 222)) 20565 ((("!") reduce 223) (("\"") reduce 223) (("$") reduce 223) (("(") reduce 223) (("+") reduce 223) (("-") reduce 223) ((";") reduce 223) (("@") reduce 223) ((T_ABSTRACT) reduce 223) ((T_ARRAY) reduce 223) ((T_ARRAY_CAST) reduce 223) ((T_ATTRIBUTE) reduce 223) ((T_BOOL_CAST) reduce 223) ((T_BREAK) reduce 223) ((T_CLASS) reduce 223) ((T_CLASS_C) reduce 223) ((T_CLONE) reduce 223) ((T_CONSTANT_ENCAPSED_STRING) reduce 223) ((T_CONTINUE) reduce 223) ((T_DEC) reduce 223) ((T_DECLARE) reduce 223) ((T_DIR) reduce 223) ((T_DNUMBER) reduce 223) ((T_DO) reduce 223) ((T_DOUBLE_CAST) reduce 223) ((T_ECHO) reduce 223) ((T_EMPTY) reduce 223) ((T_ENDFOR) reduce 223) ((T_ENUM) reduce 223) ((T_EVAL) reduce 223) ((T_EXIT) reduce 223) ((T_FILE) reduce 223) ((T_FINAL) reduce 223) ((T_FN) reduce 223) ((T_FOR) reduce 223) ((T_FOREACH) reduce 223) ((T_FUNCTION) reduce 223) ((T_FUNC_C) reduce 223) ((T_GLOBAL) reduce 223) ((T_GOTO) reduce 223) ((T_HALT_COMPILER) reduce 223) ((T_IF) reduce 223) ((T_INC) reduce 223) ((T_INCLUDE) reduce 223) ((T_INCLUDE_ONCE) reduce 223) ((T_INLINE_HTML) reduce 223) ((T_INTERFACE) reduce 223) ((T_INT_CAST) reduce 223) ((T_ISSET) reduce 223) ((T_LINE) reduce 223) ((T_LIST) reduce 223) ((T_LNUMBER) reduce 223) ((T_MATCH) reduce 223) ((T_METHOD_C) reduce 223) ((T_NAME_FULLY_QUALIFIED) reduce 223) ((T_NAME_QUALIFIED) reduce 223) ((T_NAME_RELATIVE) reduce 223) ((T_NEW) reduce 223) ((T_NS_C) reduce 223) ((T_OBJECT_CAST) reduce 223) ((T_PRINT) reduce 223) ((T_READONLY) reduce 223) ((T_REQUIRE) reduce 223) ((T_REQUIRE_ONCE) reduce 223) ((T_RETURN) reduce 223) ((T_START_HEREDOC) reduce 223) ((T_STATIC) reduce 223) ((T_STRING) reduce 223) ((T_STRING_CAST) reduce 223) ((T_SWITCH) reduce 223) ((T_THROW) reduce 223) ((T_TRAIT) reduce 223) ((T_TRAIT_C) reduce 223) ((T_TRY) reduce 223) ((T_UNSET) reduce 223) ((T_UNSET_CAST) reduce 223) ((T_VARIABLE) reduce 223) ((T_WHILE) reduce 223) ((T_YIELD) reduce 223) ((T_YIELD_FROM) reduce 223) (("[") reduce 223) (("`") reduce 223) (("{") reduce 223) (("~") reduce 223)) 20568 ((("!") reduce 224) (("\"") reduce 224) (("$") reduce 224) (("(") reduce 224) (("+") reduce 224) (("-") reduce 224) ((";") reduce 224) (("@") reduce 224) ((T_ABSTRACT) reduce 224) ((T_ARRAY) reduce 224) ((T_ARRAY_CAST) reduce 224) ((T_ATTRIBUTE) reduce 224) ((T_BOOL_CAST) reduce 224) ((T_BREAK) reduce 224) ((T_CLASS) reduce 224) ((T_CLASS_C) reduce 224) ((T_CLONE) reduce 224) ((T_CONSTANT_ENCAPSED_STRING) reduce 224) ((T_CONTINUE) reduce 224) ((T_DEC) reduce 224) ((T_DECLARE) reduce 224) ((T_DIR) reduce 224) ((T_DNUMBER) reduce 224) ((T_DO) reduce 224) ((T_DOUBLE_CAST) reduce 224) ((T_ECHO) reduce 224) ((T_EMPTY) reduce 224) ((T_ENDFOR) reduce 224) ((T_ENUM) reduce 224) ((T_EVAL) reduce 224) ((T_EXIT) reduce 224) ((T_FILE) reduce 224) ((T_FINAL) reduce 224) ((T_FN) reduce 224) ((T_FOR) reduce 224) ((T_FOREACH) reduce 224) ((T_FUNCTION) reduce 224) ((T_FUNC_C) reduce 224) ((T_GLOBAL) reduce 224) ((T_GOTO) reduce 224) ((T_HALT_COMPILER) reduce 224) ((T_IF) reduce 224) ((T_INC) reduce 224) ((T_INCLUDE) reduce 224) ((T_INCLUDE_ONCE) reduce 224) ((T_INLINE_HTML) reduce 224) ((T_INTERFACE) reduce 224) ((T_INT_CAST) reduce 224) ((T_ISSET) reduce 224) ((T_LINE) reduce 224) ((T_LIST) reduce 224) ((T_LNUMBER) reduce 224) ((T_MATCH) reduce 224) ((T_METHOD_C) reduce 224) ((T_NAME_FULLY_QUALIFIED) reduce 224) ((T_NAME_QUALIFIED) reduce 224) ((T_NAME_RELATIVE) reduce 224) ((T_NEW) reduce 224) ((T_NS_C) reduce 224) ((T_OBJECT_CAST) reduce 224) ((T_PRINT) reduce 224) ((T_READONLY) reduce 224) ((T_REQUIRE) reduce 224) ((T_REQUIRE_ONCE) reduce 224) ((T_RETURN) reduce 224) ((T_START_HEREDOC) reduce 224) ((T_STATIC) reduce 224) ((T_STRING) reduce 224) ((T_STRING_CAST) reduce 224) ((T_SWITCH) reduce 224) ((T_THROW) reduce 224) ((T_TRAIT) reduce 224) ((T_TRAIT_C) reduce 224) ((T_TRY) reduce 224) ((T_UNSET) reduce 224) ((T_UNSET_CAST) reduce 224) ((T_VARIABLE) reduce 224) ((T_WHILE) reduce 224) ((T_YIELD) reduce 224) ((T_YIELD_FROM) reduce 224) (("[") reduce 224) (("`") reduce 224) (("{") reduce 224) (("~") reduce 224)) 20569 ((("!") reduce 167) (("\"") reduce 167) (("$") reduce 167) (("(") reduce 167) (("+") reduce 167) (("-") reduce 167) ((";") reduce 167) (("@") reduce 167) ((T_ABSTRACT) reduce 167) ((T_ARRAY) reduce 167) ((T_ARRAY_CAST) reduce 167) ((T_ATTRIBUTE) reduce 167) ((T_BOOL_CAST) reduce 167) ((T_BREAK) reduce 167) ((T_CLASS) reduce 167) ((T_CLASS_C) reduce 167) ((T_CLONE) reduce 167) ((T_CONSTANT_ENCAPSED_STRING) reduce 167) ((T_CONTINUE) reduce 167) ((T_DEC) reduce 167) ((T_DECLARE) reduce 167) ((T_DIR) reduce 167) ((T_DNUMBER) reduce 167) ((T_DO) reduce 167) ((T_DOUBLE_CAST) reduce 167) ((T_ECHO) reduce 167) ((T_EMPTY) reduce 167) ((T_ENDFOR) reduce 167) ((T_ENUM) reduce 167) ((T_EVAL) reduce 167) ((T_EXIT) reduce 167) ((T_FILE) reduce 167) ((T_FINAL) reduce 167) ((T_FN) reduce 167) ((T_FOR) reduce 167) ((T_FOREACH) reduce 167) ((T_FUNCTION) reduce 167) ((T_FUNC_C) reduce 167) ((T_GLOBAL) reduce 167) ((T_GOTO) reduce 167) ((T_HALT_COMPILER) reduce 167) ((T_IF) reduce 167) ((T_INC) reduce 167) ((T_INCLUDE) reduce 167) ((T_INCLUDE_ONCE) reduce 167) ((T_INLINE_HTML) reduce 167) ((T_INTERFACE) reduce 167) ((T_INT_CAST) reduce 167) ((T_ISSET) reduce 167) ((T_LINE) reduce 167) ((T_LIST) reduce 167) ((T_LNUMBER) reduce 167) ((T_MATCH) reduce 167) ((T_METHOD_C) reduce 167) ((T_NAME_FULLY_QUALIFIED) reduce 167) ((T_NAME_QUALIFIED) reduce 167) ((T_NAME_RELATIVE) reduce 167) ((T_NEW) reduce 167) ((T_NS_C) reduce 167) ((T_OBJECT_CAST) reduce 167) ((T_PRINT) reduce 167) ((T_READONLY) reduce 167) ((T_REQUIRE) reduce 167) ((T_REQUIRE_ONCE) reduce 167) ((T_RETURN) reduce 167) ((T_START_HEREDOC) reduce 167) ((T_STATIC) reduce 167) ((T_STRING) reduce 167) ((T_STRING_CAST) reduce 167) ((T_SWITCH) reduce 167) ((T_THROW) reduce 167) ((T_TRAIT) reduce 167) ((T_TRAIT_C) reduce 167) ((T_TRY) reduce 167) ((T_UNSET) reduce 167) ((T_UNSET_CAST) reduce 167) ((T_VARIABLE) reduce 167) ((T_WHILE) reduce 167) ((T_YIELD) reduce 167) ((T_YIELD_FROM) reduce 167) (("[") reduce 167) (("`") reduce 167) (("{") reduce 167) (("~") reduce 167)) 20571 ((("!") reduce 156) (("\"") reduce 156) (("$") reduce 156) (("(") reduce 156) (("+") reduce 156) (("-") reduce 156) ((";") reduce 156) (("@") reduce 156) ((T_ABSTRACT) reduce 156) ((T_ARRAY) reduce 156) ((T_ARRAY_CAST) reduce 156) ((T_ATTRIBUTE) reduce 156) ((T_BOOL_CAST) reduce 156) ((T_BREAK) reduce 156) ((T_CLASS) reduce 156) ((T_CLASS_C) reduce 156) ((T_CLONE) reduce 156) ((T_CONSTANT_ENCAPSED_STRING) reduce 156) ((T_CONTINUE) reduce 156) ((T_DEC) reduce 156) ((T_DECLARE) reduce 156) ((T_DIR) reduce 156) ((T_DNUMBER) reduce 156) ((T_DO) reduce 156) ((T_DOUBLE_CAST) reduce 156) ((T_ECHO) reduce 156) ((T_EMPTY) reduce 156) ((T_ENDFOR) reduce 156) ((T_ENUM) reduce 156) ((T_EVAL) reduce 156) ((T_EXIT) reduce 156) ((T_FILE) reduce 156) ((T_FINAL) reduce 156) ((T_FN) reduce 156) ((T_FOR) reduce 156) ((T_FOREACH) reduce 156) ((T_FUNCTION) reduce 156) ((T_FUNC_C) reduce 156) ((T_GLOBAL) reduce 156) ((T_GOTO) reduce 156) ((T_HALT_COMPILER) reduce 156) ((T_IF) reduce 156) ((T_INC) reduce 156) ((T_INCLUDE) reduce 156) ((T_INCLUDE_ONCE) reduce 156) ((T_INLINE_HTML) reduce 156) ((T_INTERFACE) reduce 156) ((T_INT_CAST) reduce 156) ((T_ISSET) reduce 156) ((T_LINE) reduce 156) ((T_LIST) reduce 156) ((T_LNUMBER) reduce 156) ((T_MATCH) reduce 156) ((T_METHOD_C) reduce 156) ((T_NAME_FULLY_QUALIFIED) reduce 156) ((T_NAME_QUALIFIED) reduce 156) ((T_NAME_RELATIVE) reduce 156) ((T_NEW) reduce 156) ((T_NS_C) reduce 156) ((T_OBJECT_CAST) reduce 156) ((T_PRINT) reduce 156) ((T_READONLY) reduce 156) ((T_REQUIRE) reduce 156) ((T_REQUIRE_ONCE) reduce 156) ((T_RETURN) reduce 156) ((T_START_HEREDOC) reduce 156) ((T_STATIC) reduce 156) ((T_STRING) reduce 156) ((T_STRING_CAST) reduce 156) ((T_SWITCH) reduce 156) ((T_THROW) reduce 156) ((T_TRAIT) reduce 156) ((T_TRAIT_C) reduce 156) ((T_TRY) reduce 156) ((T_UNSET) reduce 156) ((T_UNSET_CAST) reduce 156) ((T_VARIABLE) reduce 156) ((T_WHILE) reduce 156) ((T_YIELD) reduce 156) ((T_YIELD_FROM) reduce 156) (("[") reduce 156) (("`") reduce 156) (("{") reduce 156) (("~") reduce 156)) 20573 ((("!") reduce 154) (("\"") reduce 154) (("$") reduce 154) (("(") reduce 154) (("+") reduce 154) (("-") reduce 154) ((";") reduce 154) (("@") reduce 154) ((T_ABSTRACT) reduce 154) ((T_ARRAY) reduce 154) ((T_ARRAY_CAST) reduce 154) ((T_ATTRIBUTE) reduce 154) ((T_BOOL_CAST) reduce 154) ((T_BREAK) reduce 154) ((T_CLASS) reduce 154) ((T_CLASS_C) reduce 154) ((T_CLONE) reduce 154) ((T_CONSTANT_ENCAPSED_STRING) reduce 154) ((T_CONTINUE) reduce 154) ((T_DEC) reduce 154) ((T_DECLARE) reduce 154) ((T_DIR) reduce 154) ((T_DNUMBER) reduce 154) ((T_DO) reduce 154) ((T_DOUBLE_CAST) reduce 154) ((T_ECHO) reduce 154) ((T_EMPTY) reduce 154) ((T_ENDFOR) reduce 154) ((T_ENUM) reduce 154) ((T_EVAL) reduce 154) ((T_EXIT) reduce 154) ((T_FILE) reduce 154) ((T_FINAL) reduce 154) ((T_FN) reduce 154) ((T_FOR) reduce 154) ((T_FOREACH) reduce 154) ((T_FUNCTION) reduce 154) ((T_FUNC_C) reduce 154) ((T_GLOBAL) reduce 154) ((T_GOTO) reduce 154) ((T_HALT_COMPILER) reduce 154) ((T_IF) reduce 154) ((T_INC) reduce 154) ((T_INCLUDE) reduce 154) ((T_INCLUDE_ONCE) reduce 154) ((T_INLINE_HTML) reduce 154) ((T_INTERFACE) reduce 154) ((T_INT_CAST) reduce 154) ((T_ISSET) reduce 154) ((T_LINE) reduce 154) ((T_LIST) reduce 154) ((T_LNUMBER) reduce 154) ((T_MATCH) reduce 154) ((T_METHOD_C) reduce 154) ((T_NAME_FULLY_QUALIFIED) reduce 154) ((T_NAME_QUALIFIED) reduce 154) ((T_NAME_RELATIVE) reduce 154) ((T_NEW) reduce 154) ((T_NS_C) reduce 154) ((T_OBJECT_CAST) reduce 154) ((T_PRINT) reduce 154) ((T_READONLY) reduce 154) ((T_REQUIRE) reduce 154) ((T_REQUIRE_ONCE) reduce 154) ((T_RETURN) reduce 154) ((T_START_HEREDOC) reduce 154) ((T_STATIC) reduce 154) ((T_STRING) reduce 154) ((T_STRING_CAST) reduce 154) ((T_SWITCH) reduce 154) ((T_THROW) reduce 154) ((T_TRAIT) reduce 154) ((T_TRAIT_C) reduce 154) ((T_TRY) reduce 154) ((T_UNSET) reduce 154) ((T_UNSET_CAST) reduce 154) ((T_VARIABLE) reduce 154) ((T_WHILE) reduce 154) ((T_YIELD) reduce 154) ((T_YIELD_FROM) reduce 154) (("[") reduce 154) (("`") reduce 154) (("{") reduce 154) (("~") reduce 154)) 20579 ((("!") reduce 198) (("\"") reduce 198) (("$") reduce 198) (("(") reduce 198) (("+") reduce 198) (("-") reduce 198) ((";") reduce 198) (("@") reduce 198) ((T_ABSTRACT) reduce 198) ((T_ARRAY) reduce 198) ((T_ARRAY_CAST) reduce 198) ((T_ATTRIBUTE) reduce 198) ((T_BOOL_CAST) reduce 198) ((T_BREAK) reduce 198) ((T_CLASS) reduce 198) ((T_CLASS_C) reduce 198) ((T_CLONE) reduce 198) ((T_CONSTANT_ENCAPSED_STRING) reduce 198) ((T_CONTINUE) reduce 198) ((T_DEC) reduce 198) ((T_DECLARE) reduce 198) ((T_DIR) reduce 198) ((T_DNUMBER) reduce 198) ((T_DO) reduce 198) ((T_DOUBLE_CAST) reduce 198) ((T_ECHO) reduce 198) ((T_EMPTY) reduce 198) ((T_ENDFOR) reduce 198) ((T_ENUM) reduce 198) ((T_EVAL) reduce 198) ((T_EXIT) reduce 198) ((T_FILE) reduce 198) ((T_FINAL) reduce 198) ((T_FN) reduce 198) ((T_FOR) reduce 198) ((T_FOREACH) reduce 198) ((T_FUNCTION) reduce 198) ((T_FUNC_C) reduce 198) ((T_GLOBAL) reduce 198) ((T_GOTO) reduce 198) ((T_HALT_COMPILER) reduce 198) ((T_IF) reduce 198) ((T_INC) reduce 198) ((T_INCLUDE) reduce 198) ((T_INCLUDE_ONCE) reduce 198) ((T_INLINE_HTML) reduce 198) ((T_INTERFACE) reduce 198) ((T_INT_CAST) reduce 198) ((T_ISSET) reduce 198) ((T_LINE) reduce 198) ((T_LIST) reduce 198) ((T_LNUMBER) reduce 198) ((T_MATCH) reduce 198) ((T_METHOD_C) reduce 198) ((T_NAME_FULLY_QUALIFIED) reduce 198) ((T_NAME_QUALIFIED) reduce 198) ((T_NAME_RELATIVE) reduce 198) ((T_NEW) reduce 198) ((T_NS_C) reduce 198) ((T_OBJECT_CAST) reduce 198) ((T_PRINT) reduce 198) ((T_READONLY) reduce 198) ((T_REQUIRE) reduce 198) ((T_REQUIRE_ONCE) reduce 198) ((T_RETURN) reduce 198) ((T_START_HEREDOC) reduce 198) ((T_STATIC) reduce 198) ((T_STRING) reduce 198) ((T_STRING_CAST) reduce 198) ((T_SWITCH) reduce 198) ((T_THROW) reduce 198) ((T_TRAIT) reduce 198) ((T_TRAIT_C) reduce 198) ((T_TRY) reduce 198) ((T_UNSET) reduce 198) ((T_UNSET_CAST) reduce 198) ((T_VARIABLE) reduce 198) ((T_WHILE) reduce 198) ((T_YIELD) reduce 198) ((T_YIELD_FROM) reduce 198) (("[") reduce 198) (("`") reduce 198) (("{") reduce 198) (("~") reduce 198)) 20583 ((("!") reduce 241) (("\"") reduce 241) (("$") reduce 241) (("(") reduce 241) (("+") reduce 241) (("-") reduce 241) ((";") reduce 241) (("@") reduce 241) ((T_ABSTRACT) reduce 241) ((T_ARRAY) reduce 241) ((T_ARRAY_CAST) reduce 241) ((T_ATTRIBUTE) reduce 241) ((T_BOOL_CAST) reduce 241) ((T_BREAK) reduce 241) ((T_CLASS) reduce 241) ((T_CLASS_C) reduce 241) ((T_CLONE) reduce 241) ((T_CONSTANT_ENCAPSED_STRING) reduce 241) ((T_CONTINUE) reduce 241) ((T_DEC) reduce 241) ((T_DECLARE) reduce 241) ((T_DIR) reduce 241) ((T_DNUMBER) reduce 241) ((T_DO) reduce 241) ((T_DOUBLE_CAST) reduce 241) ((T_ECHO) reduce 241) ((T_ELSE) reduce 241) ((T_ELSEIF) reduce 241) ((T_EMPTY) reduce 241) ((T_ENDFOR) reduce 241) ((T_ENUM) reduce 241) ((T_EVAL) reduce 241) ((T_EXIT) reduce 241) ((T_FILE) reduce 241) ((T_FINAL) reduce 241) ((T_FN) reduce 241) ((T_FOR) reduce 241) ((T_FOREACH) reduce 241) ((T_FUNCTION) reduce 241) ((T_FUNC_C) reduce 241) ((T_GLOBAL) reduce 241) ((T_GOTO) reduce 241) ((T_HALT_COMPILER) reduce 241) ((T_IF) reduce 241) ((T_INC) reduce 241) ((T_INCLUDE) reduce 241) ((T_INCLUDE_ONCE) reduce 241) ((T_INLINE_HTML) reduce 241) ((T_INTERFACE) reduce 241) ((T_INT_CAST) reduce 241) ((T_ISSET) reduce 241) ((T_LINE) reduce 241) ((T_LIST) reduce 241) ((T_LNUMBER) reduce 241) ((T_MATCH) reduce 241) ((T_METHOD_C) reduce 241) ((T_NAME_FULLY_QUALIFIED) reduce 241) ((T_NAME_QUALIFIED) reduce 241) ((T_NAME_RELATIVE) reduce 241) ((T_NEW) reduce 241) ((T_NS_C) reduce 241) ((T_OBJECT_CAST) reduce 241) ((T_PRINT) reduce 241) ((T_READONLY) reduce 241) ((T_REQUIRE) reduce 241) ((T_REQUIRE_ONCE) reduce 241) ((T_RETURN) reduce 241) ((T_START_HEREDOC) reduce 241) ((T_STATIC) reduce 241) ((T_STRING) reduce 241) ((T_STRING_CAST) reduce 241) ((T_SWITCH) reduce 241) ((T_THROW) reduce 241) ((T_TRAIT) reduce 241) ((T_TRAIT_C) reduce 241) ((T_TRY) reduce 241) ((T_UNSET) reduce 241) ((T_UNSET_CAST) reduce 241) ((T_VARIABLE) reduce 241) ((T_WHILE) reduce 241) ((T_YIELD) reduce 241) ((T_YIELD_FROM) reduce 241) (("[") reduce 241) (("`") reduce 241) (("{") reduce 241) (("~") reduce 241)) 20586 ((("!") reduce 144) (("\"") reduce 144) (("$") reduce 144) (("(") reduce 144) (("+") reduce 144) (("-") reduce 144) ((";") reduce 144) (("@") reduce 144) ((T_ABSTRACT) reduce 144) ((T_ARRAY) reduce 144) ((T_ARRAY_CAST) reduce 144) ((T_ATTRIBUTE) reduce 144) ((T_BOOL_CAST) reduce 144) ((T_BREAK) reduce 144) ((T_CLASS) reduce 144) ((T_CLASS_C) reduce 144) ((T_CLONE) reduce 144) ((T_CONSTANT_ENCAPSED_STRING) reduce 144) ((T_CONTINUE) reduce 144) ((T_DEC) reduce 144) ((T_DECLARE) reduce 144) ((T_DIR) reduce 144) ((T_DNUMBER) reduce 144) ((T_DO) reduce 144) ((T_DOUBLE_CAST) reduce 144) ((T_ECHO) reduce 144) ((T_EMPTY) reduce 144) ((T_ENDFOR) reduce 144) ((T_ENUM) reduce 144) ((T_EVAL) reduce 144) ((T_EXIT) reduce 144) ((T_FILE) reduce 144) ((T_FINAL) reduce 144) ((T_FN) reduce 144) ((T_FOR) reduce 144) ((T_FOREACH) reduce 144) ((T_FUNCTION) reduce 144) ((T_FUNC_C) reduce 144) ((T_GLOBAL) reduce 144) ((T_GOTO) reduce 144) ((T_HALT_COMPILER) reduce 144) ((T_IF) reduce 144) ((T_INC) reduce 144) ((T_INCLUDE) reduce 144) ((T_INCLUDE_ONCE) reduce 144) ((T_INLINE_HTML) reduce 144) ((T_INTERFACE) reduce 144) ((T_INT_CAST) reduce 144) ((T_ISSET) reduce 144) ((T_LINE) reduce 144) ((T_LIST) reduce 144) ((T_LNUMBER) reduce 144) ((T_MATCH) reduce 144) ((T_METHOD_C) reduce 144) ((T_NAME_FULLY_QUALIFIED) reduce 144) ((T_NAME_QUALIFIED) reduce 144) ((T_NAME_RELATIVE) reduce 144) ((T_NEW) reduce 144) ((T_NS_C) reduce 144) ((T_OBJECT_CAST) reduce 144) ((T_PRINT) reduce 144) ((T_READONLY) reduce 144) ((T_REQUIRE) reduce 144) ((T_REQUIRE_ONCE) reduce 144) ((T_RETURN) reduce 144) ((T_START_HEREDOC) reduce 144) ((T_STATIC) reduce 144) ((T_STRING) reduce 144) ((T_STRING_CAST) reduce 144) ((T_SWITCH) reduce 144) ((T_THROW) reduce 144) ((T_TRAIT) reduce 144) ((T_TRAIT_C) reduce 144) ((T_TRY) reduce 144) ((T_UNSET) reduce 144) ((T_UNSET_CAST) reduce 144) ((T_VARIABLE) reduce 144) ((T_WHILE) reduce 144) ((T_YIELD) reduce 144) ((T_YIELD_FROM) reduce 144) (("[") reduce 144) (("`") reduce 144) (("{") reduce 144) (("~") reduce 144)) 20588 ((("!") reduce 166) (("\"") reduce 166) (("$") reduce 166) (("(") reduce 166) (("+") reduce 166) (("-") reduce 166) ((";") reduce 166) (("@") reduce 166) ((T_ABSTRACT) reduce 166) ((T_ARRAY) reduce 166) ((T_ARRAY_CAST) reduce 166) ((T_ATTRIBUTE) reduce 166) ((T_BOOL_CAST) reduce 166) ((T_BREAK) reduce 166) ((T_CLASS) reduce 166) ((T_CLASS_C) reduce 166) ((T_CLONE) reduce 166) ((T_CONSTANT_ENCAPSED_STRING) reduce 166) ((T_CONTINUE) reduce 166) ((T_DEC) reduce 166) ((T_DECLARE) reduce 166) ((T_DIR) reduce 166) ((T_DNUMBER) reduce 166) ((T_DO) reduce 166) ((T_DOUBLE_CAST) reduce 166) ((T_ECHO) reduce 166) ((T_EMPTY) reduce 166) ((T_ENDFOR) reduce 166) ((T_ENUM) reduce 166) ((T_EVAL) reduce 166) ((T_EXIT) reduce 166) ((T_FILE) reduce 166) ((T_FINAL) reduce 166) ((T_FN) reduce 166) ((T_FOR) reduce 166) ((T_FOREACH) reduce 166) ((T_FUNCTION) reduce 166) ((T_FUNC_C) reduce 166) ((T_GLOBAL) reduce 166) ((T_GOTO) reduce 166) ((T_HALT_COMPILER) reduce 166) ((T_IF) reduce 166) ((T_INC) reduce 166) ((T_INCLUDE) reduce 166) ((T_INCLUDE_ONCE) reduce 166) ((T_INLINE_HTML) reduce 166) ((T_INTERFACE) reduce 166) ((T_INT_CAST) reduce 166) ((T_ISSET) reduce 166) ((T_LINE) reduce 166) ((T_LIST) reduce 166) ((T_LNUMBER) reduce 166) ((T_MATCH) reduce 166) ((T_METHOD_C) reduce 166) ((T_NAME_FULLY_QUALIFIED) reduce 166) ((T_NAME_QUALIFIED) reduce 166) ((T_NAME_RELATIVE) reduce 166) ((T_NEW) reduce 166) ((T_NS_C) reduce 166) ((T_OBJECT_CAST) reduce 166) ((T_PRINT) reduce 166) ((T_READONLY) reduce 166) ((T_REQUIRE) reduce 166) ((T_REQUIRE_ONCE) reduce 166) ((T_RETURN) reduce 166) ((T_START_HEREDOC) reduce 166) ((T_STATIC) reduce 166) ((T_STRING) reduce 166) ((T_STRING_CAST) reduce 166) ((T_SWITCH) reduce 166) ((T_THROW) reduce 166) ((T_TRAIT) reduce 166) ((T_TRAIT_C) reduce 166) ((T_TRY) reduce 166) ((T_UNSET) reduce 166) ((T_UNSET_CAST) reduce 166) ((T_VARIABLE) reduce 166) ((T_WHILE) reduce 166) ((T_YIELD) reduce 166) ((T_YIELD_FROM) reduce 166) (("[") reduce 166) (("`") reduce 166) (("{") reduce 166) (("~") reduce 166)) 20590 ((("!") reduce 155) (("\"") reduce 155) (("$") reduce 155) (("(") reduce 155) (("+") reduce 155) (("-") reduce 155) ((";") reduce 155) (("@") reduce 155) ((T_ABSTRACT) reduce 155) ((T_ARRAY) reduce 155) ((T_ARRAY_CAST) reduce 155) ((T_ATTRIBUTE) reduce 155) ((T_BOOL_CAST) reduce 155) ((T_BREAK) reduce 155) ((T_CLASS) reduce 155) ((T_CLASS_C) reduce 155) ((T_CLONE) reduce 155) ((T_CONSTANT_ENCAPSED_STRING) reduce 155) ((T_CONTINUE) reduce 155) ((T_DEC) reduce 155) ((T_DECLARE) reduce 155) ((T_DIR) reduce 155) ((T_DNUMBER) reduce 155) ((T_DO) reduce 155) ((T_DOUBLE_CAST) reduce 155) ((T_ECHO) reduce 155) ((T_EMPTY) reduce 155) ((T_ENDFOR) reduce 155) ((T_ENUM) reduce 155) ((T_EVAL) reduce 155) ((T_EXIT) reduce 155) ((T_FILE) reduce 155) ((T_FINAL) reduce 155) ((T_FN) reduce 155) ((T_FOR) reduce 155) ((T_FOREACH) reduce 155) ((T_FUNCTION) reduce 155) ((T_FUNC_C) reduce 155) ((T_GLOBAL) reduce 155) ((T_GOTO) reduce 155) ((T_HALT_COMPILER) reduce 155) ((T_IF) reduce 155) ((T_INC) reduce 155) ((T_INCLUDE) reduce 155) ((T_INCLUDE_ONCE) reduce 155) ((T_INLINE_HTML) reduce 155) ((T_INTERFACE) reduce 155) ((T_INT_CAST) reduce 155) ((T_ISSET) reduce 155) ((T_LINE) reduce 155) ((T_LIST) reduce 155) ((T_LNUMBER) reduce 155) ((T_MATCH) reduce 155) ((T_METHOD_C) reduce 155) ((T_NAME_FULLY_QUALIFIED) reduce 155) ((T_NAME_QUALIFIED) reduce 155) ((T_NAME_RELATIVE) reduce 155) ((T_NEW) reduce 155) ((T_NS_C) reduce 155) ((T_OBJECT_CAST) reduce 155) ((T_PRINT) reduce 155) ((T_READONLY) reduce 155) ((T_REQUIRE) reduce 155) ((T_REQUIRE_ONCE) reduce 155) ((T_RETURN) reduce 155) ((T_START_HEREDOC) reduce 155) ((T_STATIC) reduce 155) ((T_STRING) reduce 155) ((T_STRING_CAST) reduce 155) ((T_SWITCH) reduce 155) ((T_THROW) reduce 155) ((T_TRAIT) reduce 155) ((T_TRAIT_C) reduce 155) ((T_TRY) reduce 155) ((T_UNSET) reduce 155) ((T_UNSET_CAST) reduce 155) ((T_VARIABLE) reduce 155) ((T_WHILE) reduce 155) ((T_YIELD) reduce 155) ((T_YIELD_FROM) reduce 155) (("[") reduce 155) (("`") reduce 155) (("{") reduce 155) (("~") reduce 155)) 20600 ((("!") reduce 162) (("\"") reduce 162) (("$") reduce 162) (("(") reduce 162) (("+") reduce 162) (("-") reduce 162) ((";") reduce 162) (("@") reduce 162) ((T_ABSTRACT) reduce 162) ((T_ARRAY) reduce 162) ((T_ARRAY_CAST) reduce 162) ((T_ATTRIBUTE) reduce 162) ((T_BOOL_CAST) reduce 162) ((T_BREAK) reduce 162) ((T_CLASS) reduce 162) ((T_CLASS_C) reduce 162) ((T_CLONE) reduce 162) ((T_CONSTANT_ENCAPSED_STRING) reduce 162) ((T_CONTINUE) reduce 162) ((T_DEC) reduce 162) ((T_DECLARE) reduce 162) ((T_DIR) reduce 162) ((T_DNUMBER) reduce 162) ((T_DO) reduce 162) ((T_DOUBLE_CAST) reduce 162) ((T_ECHO) reduce 162) ((T_EMPTY) reduce 162) ((T_ENDFOR) reduce 162) ((T_ENUM) reduce 162) ((T_EVAL) reduce 162) ((T_EXIT) reduce 162) ((T_FILE) reduce 162) ((T_FINAL) reduce 162) ((T_FN) reduce 162) ((T_FOR) reduce 162) ((T_FOREACH) reduce 162) ((T_FUNCTION) reduce 162) ((T_FUNC_C) reduce 162) ((T_GLOBAL) reduce 162) ((T_GOTO) reduce 162) ((T_HALT_COMPILER) reduce 162) ((T_IF) reduce 162) ((T_INC) reduce 162) ((T_INCLUDE) reduce 162) ((T_INCLUDE_ONCE) reduce 162) ((T_INLINE_HTML) reduce 162) ((T_INTERFACE) reduce 162) ((T_INT_CAST) reduce 162) ((T_ISSET) reduce 162) ((T_LINE) reduce 162) ((T_LIST) reduce 162) ((T_LNUMBER) reduce 162) ((T_MATCH) reduce 162) ((T_METHOD_C) reduce 162) ((T_NAME_FULLY_QUALIFIED) reduce 162) ((T_NAME_QUALIFIED) reduce 162) ((T_NAME_RELATIVE) reduce 162) ((T_NEW) reduce 162) ((T_NS_C) reduce 162) ((T_OBJECT_CAST) reduce 162) ((T_PRINT) reduce 162) ((T_READONLY) reduce 162) ((T_REQUIRE) reduce 162) ((T_REQUIRE_ONCE) reduce 162) ((T_RETURN) reduce 162) ((T_START_HEREDOC) reduce 162) ((T_STATIC) reduce 162) ((T_STRING) reduce 162) ((T_STRING_CAST) reduce 162) ((T_SWITCH) reduce 162) ((T_THROW) reduce 162) ((T_TRAIT) reduce 162) ((T_TRAIT_C) reduce 162) ((T_TRY) reduce 162) ((T_UNSET) reduce 162) ((T_UNSET_CAST) reduce 162) ((T_VARIABLE) reduce 162) ((T_WHILE) reduce 162) ((T_YIELD) reduce 162) ((T_YIELD_FROM) reduce 162) (("[") reduce 162) (("`") reduce 162) (("{") reduce 162) (("~") reduce 162)) 20601 ((("!") reduce 217) (("\"") reduce 217) (("$") reduce 217) (("(") reduce 217) (("+") reduce 217) (("-") reduce 217) ((";") reduce 217) (("@") reduce 217) ((T_ABSTRACT) reduce 217) ((T_ARRAY) reduce 217) ((T_ARRAY_CAST) reduce 217) ((T_ATTRIBUTE) reduce 217) ((T_BOOL_CAST) reduce 217) ((T_BREAK) reduce 217) ((T_CLASS) reduce 217) ((T_CLASS_C) reduce 217) ((T_CLONE) reduce 217) ((T_CONSTANT_ENCAPSED_STRING) reduce 217) ((T_CONTINUE) reduce 217) ((T_DEC) reduce 217) ((T_DECLARE) reduce 217) ((T_DIR) reduce 217) ((T_DNUMBER) reduce 217) ((T_DO) reduce 217) ((T_DOUBLE_CAST) reduce 217) ((T_ECHO) reduce 217) ((T_EMPTY) reduce 217) ((T_ENDFOR) reduce 217) ((T_ENUM) reduce 217) ((T_EVAL) reduce 217) ((T_EXIT) reduce 217) ((T_FILE) reduce 217) ((T_FINAL) reduce 217) ((T_FN) reduce 217) ((T_FOR) reduce 217) ((T_FOREACH) reduce 217) ((T_FUNCTION) reduce 217) ((T_FUNC_C) reduce 217) ((T_GLOBAL) reduce 217) ((T_GOTO) reduce 217) ((T_HALT_COMPILER) reduce 217) ((T_IF) reduce 217) ((T_INC) reduce 217) ((T_INCLUDE) reduce 217) ((T_INCLUDE_ONCE) reduce 217) ((T_INLINE_HTML) reduce 217) ((T_INTERFACE) reduce 217) ((T_INT_CAST) reduce 217) ((T_ISSET) reduce 217) ((T_LINE) reduce 217) ((T_LIST) reduce 217) ((T_LNUMBER) reduce 217) ((T_MATCH) reduce 217) ((T_METHOD_C) reduce 217) ((T_NAME_FULLY_QUALIFIED) reduce 217) ((T_NAME_QUALIFIED) reduce 217) ((T_NAME_RELATIVE) reduce 217) ((T_NEW) reduce 217) ((T_NS_C) reduce 217) ((T_OBJECT_CAST) reduce 217) ((T_PRINT) reduce 217) ((T_READONLY) reduce 217) ((T_REQUIRE) reduce 217) ((T_REQUIRE_ONCE) reduce 217) ((T_RETURN) reduce 217) ((T_START_HEREDOC) reduce 217) ((T_STATIC) reduce 217) ((T_STRING) reduce 217) ((T_STRING_CAST) reduce 217) ((T_SWITCH) reduce 217) ((T_THROW) reduce 217) ((T_TRAIT) reduce 217) ((T_TRAIT_C) reduce 217) ((T_TRY) reduce 217) ((T_UNSET) reduce 217) ((T_UNSET_CAST) reduce 217) ((T_VARIABLE) reduce 217) ((T_WHILE) reduce 217) ((T_YIELD) reduce 217) ((T_YIELD_FROM) reduce 217) (("[") reduce 217) (("`") reduce 217) (("{") reduce 217) (("~") reduce 217)) 20604 ((("!") reduce 218) (("\"") reduce 218) (("$") reduce 218) (("(") reduce 218) (("+") reduce 218) (("-") reduce 218) ((";") reduce 218) (("@") reduce 218) ((T_ABSTRACT) reduce 218) ((T_ARRAY) reduce 218) ((T_ARRAY_CAST) reduce 218) ((T_ATTRIBUTE) reduce 218) ((T_BOOL_CAST) reduce 218) ((T_BREAK) reduce 218) ((T_CLASS) reduce 218) ((T_CLASS_C) reduce 218) ((T_CLONE) reduce 218) ((T_CONSTANT_ENCAPSED_STRING) reduce 218) ((T_CONTINUE) reduce 218) ((T_DEC) reduce 218) ((T_DECLARE) reduce 218) ((T_DIR) reduce 218) ((T_DNUMBER) reduce 218) ((T_DO) reduce 218) ((T_DOUBLE_CAST) reduce 218) ((T_ECHO) reduce 218) ((T_EMPTY) reduce 218) ((T_ENDFOR) reduce 218) ((T_ENUM) reduce 218) ((T_EVAL) reduce 218) ((T_EXIT) reduce 218) ((T_FILE) reduce 218) ((T_FINAL) reduce 218) ((T_FN) reduce 218) ((T_FOR) reduce 218) ((T_FOREACH) reduce 218) ((T_FUNCTION) reduce 218) ((T_FUNC_C) reduce 218) ((T_GLOBAL) reduce 218) ((T_GOTO) reduce 218) ((T_HALT_COMPILER) reduce 218) ((T_IF) reduce 218) ((T_INC) reduce 218) ((T_INCLUDE) reduce 218) ((T_INCLUDE_ONCE) reduce 218) ((T_INLINE_HTML) reduce 218) ((T_INTERFACE) reduce 218) ((T_INT_CAST) reduce 218) ((T_ISSET) reduce 218) ((T_LINE) reduce 218) ((T_LIST) reduce 218) ((T_LNUMBER) reduce 218) ((T_MATCH) reduce 218) ((T_METHOD_C) reduce 218) ((T_NAME_FULLY_QUALIFIED) reduce 218) ((T_NAME_QUALIFIED) reduce 218) ((T_NAME_RELATIVE) reduce 218) ((T_NEW) reduce 218) ((T_NS_C) reduce 218) ((T_OBJECT_CAST) reduce 218) ((T_PRINT) reduce 218) ((T_READONLY) reduce 218) ((T_REQUIRE) reduce 218) ((T_REQUIRE_ONCE) reduce 218) ((T_RETURN) reduce 218) ((T_START_HEREDOC) reduce 218) ((T_STATIC) reduce 218) ((T_STRING) reduce 218) ((T_STRING_CAST) reduce 218) ((T_SWITCH) reduce 218) ((T_THROW) reduce 218) ((T_TRAIT) reduce 218) ((T_TRAIT_C) reduce 218) ((T_TRY) reduce 218) ((T_UNSET) reduce 218) ((T_UNSET_CAST) reduce 218) ((T_VARIABLE) reduce 218) ((T_WHILE) reduce 218) ((T_YIELD) reduce 218) ((T_YIELD_FROM) reduce 218) (("[") reduce 218) (("`") reduce 218) (("{") reduce 218) (("~") reduce 218)) 20605 ((("!") reduce 161) (("\"") reduce 161) (("$") reduce 161) (("(") reduce 161) (("+") reduce 161) (("-") reduce 161) ((";") reduce 161) (("@") reduce 161) ((T_ABSTRACT) reduce 161) ((T_ARRAY) reduce 161) ((T_ARRAY_CAST) reduce 161) ((T_ATTRIBUTE) reduce 161) ((T_BOOL_CAST) reduce 161) ((T_BREAK) reduce 161) ((T_CLASS) reduce 161) ((T_CLASS_C) reduce 161) ((T_CLONE) reduce 161) ((T_CONSTANT_ENCAPSED_STRING) reduce 161) ((T_CONTINUE) reduce 161) ((T_DEC) reduce 161) ((T_DECLARE) reduce 161) ((T_DIR) reduce 161) ((T_DNUMBER) reduce 161) ((T_DO) reduce 161) ((T_DOUBLE_CAST) reduce 161) ((T_ECHO) reduce 161) ((T_EMPTY) reduce 161) ((T_ENDFOR) reduce 161) ((T_ENUM) reduce 161) ((T_EVAL) reduce 161) ((T_EXIT) reduce 161) ((T_FILE) reduce 161) ((T_FINAL) reduce 161) ((T_FN) reduce 161) ((T_FOR) reduce 161) ((T_FOREACH) reduce 161) ((T_FUNCTION) reduce 161) ((T_FUNC_C) reduce 161) ((T_GLOBAL) reduce 161) ((T_GOTO) reduce 161) ((T_HALT_COMPILER) reduce 161) ((T_IF) reduce 161) ((T_INC) reduce 161) ((T_INCLUDE) reduce 161) ((T_INCLUDE_ONCE) reduce 161) ((T_INLINE_HTML) reduce 161) ((T_INTERFACE) reduce 161) ((T_INT_CAST) reduce 161) ((T_ISSET) reduce 161) ((T_LINE) reduce 161) ((T_LIST) reduce 161) ((T_LNUMBER) reduce 161) ((T_MATCH) reduce 161) ((T_METHOD_C) reduce 161) ((T_NAME_FULLY_QUALIFIED) reduce 161) ((T_NAME_QUALIFIED) reduce 161) ((T_NAME_RELATIVE) reduce 161) ((T_NEW) reduce 161) ((T_NS_C) reduce 161) ((T_OBJECT_CAST) reduce 161) ((T_PRINT) reduce 161) ((T_READONLY) reduce 161) ((T_REQUIRE) reduce 161) ((T_REQUIRE_ONCE) reduce 161) ((T_RETURN) reduce 161) ((T_START_HEREDOC) reduce 161) ((T_STATIC) reduce 161) ((T_STRING) reduce 161) ((T_STRING_CAST) reduce 161) ((T_SWITCH) reduce 161) ((T_THROW) reduce 161) ((T_TRAIT) reduce 161) ((T_TRAIT_C) reduce 161) ((T_TRY) reduce 161) ((T_UNSET) reduce 161) ((T_UNSET_CAST) reduce 161) ((T_VARIABLE) reduce 161) ((T_WHILE) reduce 161) ((T_YIELD) reduce 161) ((T_YIELD_FROM) reduce 161) (("[") reduce 161) (("`") reduce 161) (("{") reduce 161) (("~") reduce 161)) 20614 ((("!") reduce 150) (("\"") reduce 150) (("$") reduce 150) (("(") reduce 150) (("+") reduce 150) (("-") reduce 150) ((";") reduce 150) (("@") reduce 150) ((T_ABSTRACT) reduce 150) ((T_ARRAY) reduce 150) ((T_ARRAY_CAST) reduce 150) ((T_ATTRIBUTE) reduce 150) ((T_BOOL_CAST) reduce 150) ((T_BREAK) reduce 150) ((T_CLASS) reduce 150) ((T_CLASS_C) reduce 150) ((T_CLONE) reduce 150) ((T_CONSTANT_ENCAPSED_STRING) reduce 150) ((T_CONTINUE) reduce 150) ((T_DEC) reduce 150) ((T_DECLARE) reduce 150) ((T_DIR) reduce 150) ((T_DNUMBER) reduce 150) ((T_DO) reduce 150) ((T_DOUBLE_CAST) reduce 150) ((T_ECHO) reduce 150) ((T_EMPTY) reduce 150) ((T_ENDFOR) reduce 150) ((T_ENUM) reduce 150) ((T_EVAL) reduce 150) ((T_EXIT) reduce 150) ((T_FILE) reduce 150) ((T_FINAL) reduce 150) ((T_FN) reduce 150) ((T_FOR) reduce 150) ((T_FOREACH) reduce 150) ((T_FUNCTION) reduce 150) ((T_FUNC_C) reduce 150) ((T_GLOBAL) reduce 150) ((T_GOTO) reduce 150) ((T_HALT_COMPILER) reduce 150) ((T_IF) reduce 150) ((T_INC) reduce 150) ((T_INCLUDE) reduce 150) ((T_INCLUDE_ONCE) reduce 150) ((T_INLINE_HTML) reduce 150) ((T_INTERFACE) reduce 150) ((T_INT_CAST) reduce 150) ((T_ISSET) reduce 150) ((T_LINE) reduce 150) ((T_LIST) reduce 150) ((T_LNUMBER) reduce 150) ((T_MATCH) reduce 150) ((T_METHOD_C) reduce 150) ((T_NAME_FULLY_QUALIFIED) reduce 150) ((T_NAME_QUALIFIED) reduce 150) ((T_NAME_RELATIVE) reduce 150) ((T_NEW) reduce 150) ((T_NS_C) reduce 150) ((T_OBJECT_CAST) reduce 150) ((T_PRINT) reduce 150) ((T_READONLY) reduce 150) ((T_REQUIRE) reduce 150) ((T_REQUIRE_ONCE) reduce 150) ((T_RETURN) reduce 150) ((T_START_HEREDOC) reduce 150) ((T_STATIC) reduce 150) ((T_STRING) reduce 150) ((T_STRING_CAST) reduce 150) ((T_SWITCH) reduce 150) ((T_THROW) reduce 150) ((T_TRAIT) reduce 150) ((T_TRAIT_C) reduce 150) ((T_TRY) reduce 150) ((T_UNSET) reduce 150) ((T_UNSET_CAST) reduce 150) ((T_VARIABLE) reduce 150) ((T_WHILE) reduce 150) ((T_YIELD) reduce 150) ((T_YIELD_FROM) reduce 150) (("[") reduce 150) (("`") reduce 150) (("{") reduce 150) (("~") reduce 150)) 20615 ((("!") reduce 215) (("\"") reduce 215) (("$") reduce 215) (("(") reduce 215) (("+") reduce 215) (("-") reduce 215) ((";") reduce 215) (("@") reduce 215) ((T_ABSTRACT) reduce 215) ((T_ARRAY) reduce 215) ((T_ARRAY_CAST) reduce 215) ((T_ATTRIBUTE) reduce 215) ((T_BOOL_CAST) reduce 215) ((T_BREAK) reduce 215) ((T_CLASS) reduce 215) ((T_CLASS_C) reduce 215) ((T_CLONE) reduce 215) ((T_CONSTANT_ENCAPSED_STRING) reduce 215) ((T_CONTINUE) reduce 215) ((T_DEC) reduce 215) ((T_DECLARE) reduce 215) ((T_DIR) reduce 215) ((T_DNUMBER) reduce 215) ((T_DO) reduce 215) ((T_DOUBLE_CAST) reduce 215) ((T_ECHO) reduce 215) ((T_EMPTY) reduce 215) ((T_ENDFOR) reduce 215) ((T_ENUM) reduce 215) ((T_EVAL) reduce 215) ((T_EXIT) reduce 215) ((T_FILE) reduce 215) ((T_FINAL) reduce 215) ((T_FN) reduce 215) ((T_FOR) reduce 215) ((T_FOREACH) reduce 215) ((T_FUNCTION) reduce 215) ((T_FUNC_C) reduce 215) ((T_GLOBAL) reduce 215) ((T_GOTO) reduce 215) ((T_HALT_COMPILER) reduce 215) ((T_IF) reduce 215) ((T_INC) reduce 215) ((T_INCLUDE) reduce 215) ((T_INCLUDE_ONCE) reduce 215) ((T_INLINE_HTML) reduce 215) ((T_INTERFACE) reduce 215) ((T_INT_CAST) reduce 215) ((T_ISSET) reduce 215) ((T_LINE) reduce 215) ((T_LIST) reduce 215) ((T_LNUMBER) reduce 215) ((T_MATCH) reduce 215) ((T_METHOD_C) reduce 215) ((T_NAME_FULLY_QUALIFIED) reduce 215) ((T_NAME_QUALIFIED) reduce 215) ((T_NAME_RELATIVE) reduce 215) ((T_NEW) reduce 215) ((T_NS_C) reduce 215) ((T_OBJECT_CAST) reduce 215) ((T_PRINT) reduce 215) ((T_READONLY) reduce 215) ((T_REQUIRE) reduce 215) ((T_REQUIRE_ONCE) reduce 215) ((T_RETURN) reduce 215) ((T_START_HEREDOC) reduce 215) ((T_STATIC) reduce 215) ((T_STRING) reduce 215) ((T_STRING_CAST) reduce 215) ((T_SWITCH) reduce 215) ((T_THROW) reduce 215) ((T_TRAIT) reduce 215) ((T_TRAIT_C) reduce 215) ((T_TRY) reduce 215) ((T_UNSET) reduce 215) ((T_UNSET_CAST) reduce 215) ((T_VARIABLE) reduce 215) ((T_WHILE) reduce 215) ((T_YIELD) reduce 215) ((T_YIELD_FROM) reduce 215) (("[") reduce 215) (("`") reduce 215) (("{") reduce 215) (("~") reduce 215)) 20618 ((("!") reduce 216) (("\"") reduce 216) (("$") reduce 216) (("(") reduce 216) (("+") reduce 216) (("-") reduce 216) ((";") reduce 216) (("@") reduce 216) ((T_ABSTRACT) reduce 216) ((T_ARRAY) reduce 216) ((T_ARRAY_CAST) reduce 216) ((T_ATTRIBUTE) reduce 216) ((T_BOOL_CAST) reduce 216) ((T_BREAK) reduce 216) ((T_CLASS) reduce 216) ((T_CLASS_C) reduce 216) ((T_CLONE) reduce 216) ((T_CONSTANT_ENCAPSED_STRING) reduce 216) ((T_CONTINUE) reduce 216) ((T_DEC) reduce 216) ((T_DECLARE) reduce 216) ((T_DIR) reduce 216) ((T_DNUMBER) reduce 216) ((T_DO) reduce 216) ((T_DOUBLE_CAST) reduce 216) ((T_ECHO) reduce 216) ((T_EMPTY) reduce 216) ((T_ENDFOR) reduce 216) ((T_ENUM) reduce 216) ((T_EVAL) reduce 216) ((T_EXIT) reduce 216) ((T_FILE) reduce 216) ((T_FINAL) reduce 216) ((T_FN) reduce 216) ((T_FOR) reduce 216) ((T_FOREACH) reduce 216) ((T_FUNCTION) reduce 216) ((T_FUNC_C) reduce 216) ((T_GLOBAL) reduce 216) ((T_GOTO) reduce 216) ((T_HALT_COMPILER) reduce 216) ((T_IF) reduce 216) ((T_INC) reduce 216) ((T_INCLUDE) reduce 216) ((T_INCLUDE_ONCE) reduce 216) ((T_INLINE_HTML) reduce 216) ((T_INTERFACE) reduce 216) ((T_INT_CAST) reduce 216) ((T_ISSET) reduce 216) ((T_LINE) reduce 216) ((T_LIST) reduce 216) ((T_LNUMBER) reduce 216) ((T_MATCH) reduce 216) ((T_METHOD_C) reduce 216) ((T_NAME_FULLY_QUALIFIED) reduce 216) ((T_NAME_QUALIFIED) reduce 216) ((T_NAME_RELATIVE) reduce 216) ((T_NEW) reduce 216) ((T_NS_C) reduce 216) ((T_OBJECT_CAST) reduce 216) ((T_PRINT) reduce 216) ((T_READONLY) reduce 216) ((T_REQUIRE) reduce 216) ((T_REQUIRE_ONCE) reduce 216) ((T_RETURN) reduce 216) ((T_START_HEREDOC) reduce 216) ((T_STATIC) reduce 216) ((T_STRING) reduce 216) ((T_STRING_CAST) reduce 216) ((T_SWITCH) reduce 216) ((T_THROW) reduce 216) ((T_TRAIT) reduce 216) ((T_TRAIT_C) reduce 216) ((T_TRY) reduce 216) ((T_UNSET) reduce 216) ((T_UNSET_CAST) reduce 216) ((T_VARIABLE) reduce 216) ((T_WHILE) reduce 216) ((T_YIELD) reduce 216) ((T_YIELD_FROM) reduce 216) (("[") reduce 216) (("`") reduce 216) (("{") reduce 216) (("~") reduce 216)) 20625 ((("!") reduce 199) (("\"") reduce 199) (("$") reduce 199) (("(") reduce 199) (("+") reduce 199) (("-") reduce 199) ((";") reduce 199) (("@") reduce 199) ((T_ABSTRACT) reduce 199) ((T_ARRAY) reduce 199) ((T_ARRAY_CAST) reduce 199) ((T_ATTRIBUTE) reduce 199) ((T_BOOL_CAST) reduce 199) ((T_BREAK) reduce 199) ((T_CLASS) reduce 199) ((T_CLASS_C) reduce 199) ((T_CLONE) reduce 199) ((T_CONSTANT_ENCAPSED_STRING) reduce 199) ((T_CONTINUE) reduce 199) ((T_DEC) reduce 199) ((T_DECLARE) reduce 199) ((T_DIR) reduce 199) ((T_DNUMBER) reduce 199) ((T_DO) reduce 199) ((T_DOUBLE_CAST) reduce 199) ((T_ECHO) reduce 199) ((T_EMPTY) reduce 199) ((T_ENDFOR) reduce 199) ((T_ENUM) reduce 199) ((T_EVAL) reduce 199) ((T_EXIT) reduce 199) ((T_FILE) reduce 199) ((T_FINAL) reduce 199) ((T_FN) reduce 199) ((T_FOR) reduce 199) ((T_FOREACH) reduce 199) ((T_FUNCTION) reduce 199) ((T_FUNC_C) reduce 199) ((T_GLOBAL) reduce 199) ((T_GOTO) reduce 199) ((T_HALT_COMPILER) reduce 199) ((T_IF) reduce 199) ((T_INC) reduce 199) ((T_INCLUDE) reduce 199) ((T_INCLUDE_ONCE) reduce 199) ((T_INLINE_HTML) reduce 199) ((T_INTERFACE) reduce 199) ((T_INT_CAST) reduce 199) ((T_ISSET) reduce 199) ((T_LINE) reduce 199) ((T_LIST) reduce 199) ((T_LNUMBER) reduce 199) ((T_MATCH) reduce 199) ((T_METHOD_C) reduce 199) ((T_NAME_FULLY_QUALIFIED) reduce 199) ((T_NAME_QUALIFIED) reduce 199) ((T_NAME_RELATIVE) reduce 199) ((T_NEW) reduce 199) ((T_NS_C) reduce 199) ((T_OBJECT_CAST) reduce 199) ((T_PRINT) reduce 199) ((T_READONLY) reduce 199) ((T_REQUIRE) reduce 199) ((T_REQUIRE_ONCE) reduce 199) ((T_RETURN) reduce 199) ((T_START_HEREDOC) reduce 199) ((T_STATIC) reduce 199) ((T_STRING) reduce 199) ((T_STRING_CAST) reduce 199) ((T_SWITCH) reduce 199) ((T_THROW) reduce 199) ((T_TRAIT) reduce 199) ((T_TRAIT_C) reduce 199) ((T_TRY) reduce 199) ((T_UNSET) reduce 199) ((T_UNSET_CAST) reduce 199) ((T_VARIABLE) reduce 199) ((T_WHILE) reduce 199) ((T_YIELD) reduce 199) ((T_YIELD_FROM) reduce 199) (("[") reduce 199) (("`") reduce 199) (("{") reduce 199) (("~") reduce 199)) 20626 ((("!") reduce 216) (("\"") reduce 216) (("$") reduce 216) (("(") reduce 216) (("+") reduce 216) (("-") reduce 216) ((";") reduce 216) (("@") reduce 216) ((T_ABSTRACT) reduce 216) ((T_ARRAY) reduce 216) ((T_ARRAY_CAST) reduce 216) ((T_ATTRIBUTE) reduce 216) ((T_BOOL_CAST) reduce 216) ((T_BREAK) reduce 216) ((T_CLASS) reduce 216) ((T_CLASS_C) reduce 216) ((T_CLONE) reduce 216) ((T_CONSTANT_ENCAPSED_STRING) reduce 216) ((T_CONTINUE) reduce 216) ((T_DEC) reduce 216) ((T_DECLARE) reduce 216) ((T_DIR) reduce 216) ((T_DNUMBER) reduce 216) ((T_DO) reduce 216) ((T_DOUBLE_CAST) reduce 216) ((T_ECHO) reduce 216) ((T_ELSE) reduce 216) ((T_ELSEIF) reduce 216) ((T_EMPTY) reduce 216) ((T_ENDFOREACH) reduce 216) ((T_ENUM) reduce 216) ((T_EVAL) reduce 216) ((T_EXIT) reduce 216) ((T_FILE) reduce 216) ((T_FINAL) reduce 216) ((T_FN) reduce 216) ((T_FOR) reduce 216) ((T_FOREACH) reduce 216) ((T_FUNCTION) reduce 216) ((T_FUNC_C) reduce 216) ((T_GLOBAL) reduce 216) ((T_GOTO) reduce 216) ((T_HALT_COMPILER) reduce 216) ((T_IF) reduce 216) ((T_INC) reduce 216) ((T_INCLUDE) reduce 216) ((T_INCLUDE_ONCE) reduce 216) ((T_INLINE_HTML) reduce 216) ((T_INTERFACE) reduce 216) ((T_INT_CAST) reduce 216) ((T_ISSET) reduce 216) ((T_LINE) reduce 216) ((T_LIST) reduce 216) ((T_LNUMBER) reduce 216) ((T_MATCH) reduce 216) ((T_METHOD_C) reduce 216) ((T_NAME_FULLY_QUALIFIED) reduce 216) ((T_NAME_QUALIFIED) reduce 216) ((T_NAME_RELATIVE) reduce 216) ((T_NEW) reduce 216) ((T_NS_C) reduce 216) ((T_OBJECT_CAST) reduce 216) ((T_PRINT) reduce 216) ((T_READONLY) reduce 216) ((T_REQUIRE) reduce 216) ((T_REQUIRE_ONCE) reduce 216) ((T_RETURN) reduce 216) ((T_START_HEREDOC) reduce 216) ((T_STATIC) reduce 216) ((T_STRING) reduce 216) ((T_STRING_CAST) reduce 216) ((T_SWITCH) reduce 216) ((T_THROW) reduce 216) ((T_TRAIT) reduce 216) ((T_TRAIT_C) reduce 216) ((T_TRY) reduce 216) ((T_UNSET) reduce 216) ((T_UNSET_CAST) reduce 216) ((T_VARIABLE) reduce 216) ((T_WHILE) reduce 216) ((T_YIELD) reduce 216) ((T_YIELD_FROM) reduce 216) (("[") reduce 216) (("`") reduce 216) (("{") reduce 216) (("~") reduce 216)) 20628 ((("!") reduce 157) (("\"") reduce 157) (("$") reduce 157) (("(") reduce 157) (("+") reduce 157) (("-") reduce 157) ((";") reduce 157) (("@") reduce 157) ((T_ABSTRACT) reduce 157) ((T_ARRAY) reduce 157) ((T_ARRAY_CAST) reduce 157) ((T_ATTRIBUTE) reduce 157) ((T_BOOL_CAST) reduce 157) ((T_BREAK) reduce 157) ((T_CLASS) reduce 157) ((T_CLASS_C) reduce 157) ((T_CLONE) reduce 157) ((T_CONSTANT_ENCAPSED_STRING) reduce 157) ((T_CONTINUE) reduce 157) ((T_DEC) reduce 157) ((T_DECLARE) reduce 157) ((T_DIR) reduce 157) ((T_DNUMBER) reduce 157) ((T_DO) reduce 157) ((T_DOUBLE_CAST) reduce 157) ((T_ECHO) reduce 157) ((T_EMPTY) reduce 157) ((T_ENDFOR) reduce 157) ((T_ENUM) reduce 157) ((T_EVAL) reduce 157) ((T_EXIT) reduce 157) ((T_FILE) reduce 157) ((T_FINAL) reduce 157) ((T_FN) reduce 157) ((T_FOR) reduce 157) ((T_FOREACH) reduce 157) ((T_FUNCTION) reduce 157) ((T_FUNC_C) reduce 157) ((T_GLOBAL) reduce 157) ((T_GOTO) reduce 157) ((T_HALT_COMPILER) reduce 157) ((T_IF) reduce 157) ((T_INC) reduce 157) ((T_INCLUDE) reduce 157) ((T_INCLUDE_ONCE) reduce 157) ((T_INLINE_HTML) reduce 157) ((T_INTERFACE) reduce 157) ((T_INT_CAST) reduce 157) ((T_ISSET) reduce 157) ((T_LINE) reduce 157) ((T_LIST) reduce 157) ((T_LNUMBER) reduce 157) ((T_MATCH) reduce 157) ((T_METHOD_C) reduce 157) ((T_NAME_FULLY_QUALIFIED) reduce 157) ((T_NAME_QUALIFIED) reduce 157) ((T_NAME_RELATIVE) reduce 157) ((T_NEW) reduce 157) ((T_NS_C) reduce 157) ((T_OBJECT_CAST) reduce 157) ((T_PRINT) reduce 157) ((T_READONLY) reduce 157) ((T_REQUIRE) reduce 157) ((T_REQUIRE_ONCE) reduce 157) ((T_RETURN) reduce 157) ((T_START_HEREDOC) reduce 157) ((T_STATIC) reduce 157) ((T_STRING) reduce 157) ((T_STRING_CAST) reduce 157) ((T_SWITCH) reduce 157) ((T_THROW) reduce 157) ((T_TRAIT) reduce 157) ((T_TRAIT_C) reduce 157) ((T_TRY) reduce 157) ((T_UNSET) reduce 157) ((T_UNSET_CAST) reduce 157) ((T_VARIABLE) reduce 157) ((T_WHILE) reduce 157) ((T_YIELD) reduce 157) ((T_YIELD_FROM) reduce 157) (("[") reduce 157) (("`") reduce 157) (("{") reduce 157) (("~") reduce 157)) 20634 ((("!") reduce 149) (("\"") reduce 149) (("$") reduce 149) (("(") reduce 149) (("+") reduce 149) (("-") reduce 149) ((";") reduce 149) (("@") reduce 149) ((T_ABSTRACT) reduce 149) ((T_ARRAY) reduce 149) ((T_ARRAY_CAST) reduce 149) ((T_ATTRIBUTE) reduce 149) ((T_BOOL_CAST) reduce 149) ((T_BREAK) reduce 149) ((T_CLASS) reduce 149) ((T_CLASS_C) reduce 149) ((T_CLONE) reduce 149) ((T_CONSTANT_ENCAPSED_STRING) reduce 149) ((T_CONTINUE) reduce 149) ((T_DEC) reduce 149) ((T_DECLARE) reduce 149) ((T_DIR) reduce 149) ((T_DNUMBER) reduce 149) ((T_DO) reduce 149) ((T_DOUBLE_CAST) reduce 149) ((T_ECHO) reduce 149) ((T_EMPTY) reduce 149) ((T_ENDFOR) reduce 149) ((T_ENUM) reduce 149) ((T_EVAL) reduce 149) ((T_EXIT) reduce 149) ((T_FILE) reduce 149) ((T_FINAL) reduce 149) ((T_FN) reduce 149) ((T_FOR) reduce 149) ((T_FOREACH) reduce 149) ((T_FUNCTION) reduce 149) ((T_FUNC_C) reduce 149) ((T_GLOBAL) reduce 149) ((T_GOTO) reduce 149) ((T_HALT_COMPILER) reduce 149) ((T_IF) reduce 149) ((T_INC) reduce 149) ((T_INCLUDE) reduce 149) ((T_INCLUDE_ONCE) reduce 149) ((T_INLINE_HTML) reduce 149) ((T_INTERFACE) reduce 149) ((T_INT_CAST) reduce 149) ((T_ISSET) reduce 149) ((T_LINE) reduce 149) ((T_LIST) reduce 149) ((T_LNUMBER) reduce 149) ((T_MATCH) reduce 149) ((T_METHOD_C) reduce 149) ((T_NAME_FULLY_QUALIFIED) reduce 149) ((T_NAME_QUALIFIED) reduce 149) ((T_NAME_RELATIVE) reduce 149) ((T_NEW) reduce 149) ((T_NS_C) reduce 149) ((T_OBJECT_CAST) reduce 149) ((T_PRINT) reduce 149) ((T_READONLY) reduce 149) ((T_REQUIRE) reduce 149) ((T_REQUIRE_ONCE) reduce 149) ((T_RETURN) reduce 149) ((T_START_HEREDOC) reduce 149) ((T_STATIC) reduce 149) ((T_STRING) reduce 149) ((T_STRING_CAST) reduce 149) ((T_SWITCH) reduce 149) ((T_THROW) reduce 149) ((T_TRAIT) reduce 149) ((T_TRAIT_C) reduce 149) ((T_TRY) reduce 149) ((T_UNSET) reduce 149) ((T_UNSET_CAST) reduce 149) ((T_VARIABLE) reduce 149) ((T_WHILE) reduce 149) ((T_YIELD) reduce 149) ((T_YIELD_FROM) reduce 149) (("[") reduce 149) (("`") reduce 149) (("{") reduce 149) (("~") reduce 149)) 20639 ((("!") reduce 163) (("\"") reduce 163) (("$") reduce 163) (("(") reduce 163) (("+") reduce 163) (("-") reduce 163) ((";") reduce 163) (("@") reduce 163) ((T_ABSTRACT) reduce 163) ((T_ARRAY) reduce 163) ((T_ARRAY_CAST) reduce 163) ((T_ATTRIBUTE) reduce 163) ((T_BOOL_CAST) reduce 163) ((T_BREAK) reduce 163) ((T_CLASS) reduce 163) ((T_CLASS_C) reduce 163) ((T_CLONE) reduce 163) ((T_CONSTANT_ENCAPSED_STRING) reduce 163) ((T_CONTINUE) reduce 163) ((T_DEC) reduce 163) ((T_DECLARE) reduce 163) ((T_DIR) reduce 163) ((T_DNUMBER) reduce 163) ((T_DO) reduce 163) ((T_DOUBLE_CAST) reduce 163) ((T_ECHO) reduce 163) ((T_EMPTY) reduce 163) ((T_ENDFOR) reduce 163) ((T_ENUM) reduce 163) ((T_EVAL) reduce 163) ((T_EXIT) reduce 163) ((T_FILE) reduce 163) ((T_FINAL) reduce 163) ((T_FN) reduce 163) ((T_FOR) reduce 163) ((T_FOREACH) reduce 163) ((T_FUNCTION) reduce 163) ((T_FUNC_C) reduce 163) ((T_GLOBAL) reduce 163) ((T_GOTO) reduce 163) ((T_HALT_COMPILER) reduce 163) ((T_IF) reduce 163) ((T_INC) reduce 163) ((T_INCLUDE) reduce 163) ((T_INCLUDE_ONCE) reduce 163) ((T_INLINE_HTML) reduce 163) ((T_INTERFACE) reduce 163) ((T_INT_CAST) reduce 163) ((T_ISSET) reduce 163) ((T_LINE) reduce 163) ((T_LIST) reduce 163) ((T_LNUMBER) reduce 163) ((T_MATCH) reduce 163) ((T_METHOD_C) reduce 163) ((T_NAME_FULLY_QUALIFIED) reduce 163) ((T_NAME_QUALIFIED) reduce 163) ((T_NAME_RELATIVE) reduce 163) ((T_NEW) reduce 163) ((T_NS_C) reduce 163) ((T_OBJECT_CAST) reduce 163) ((T_PRINT) reduce 163) ((T_READONLY) reduce 163) ((T_REQUIRE) reduce 163) ((T_REQUIRE_ONCE) reduce 163) ((T_RETURN) reduce 163) ((T_START_HEREDOC) reduce 163) ((T_STATIC) reduce 163) ((T_STRING) reduce 163) ((T_STRING_CAST) reduce 163) ((T_SWITCH) reduce 163) ((T_THROW) reduce 163) ((T_TRAIT) reduce 163) ((T_TRAIT_C) reduce 163) ((T_TRY) reduce 163) ((T_UNSET) reduce 163) ((T_UNSET_CAST) reduce 163) ((T_VARIABLE) reduce 163) ((T_WHILE) reduce 163) ((T_YIELD) reduce 163) ((T_YIELD_FROM) reduce 163) (("[") reduce 163) (("`") reduce 163) (("{") reduce 163) (("~") reduce 163)) 20640 ((("!") reduce 219) (("\"") reduce 219) (("$") reduce 219) (("(") reduce 219) (("+") reduce 219) (("-") reduce 219) ((";") reduce 219) (("@") reduce 219) ((T_ABSTRACT) reduce 219) ((T_ARRAY) reduce 219) ((T_ARRAY_CAST) reduce 219) ((T_ATTRIBUTE) reduce 219) ((T_BOOL_CAST) reduce 219) ((T_BREAK) reduce 219) ((T_CLASS) reduce 219) ((T_CLASS_C) reduce 219) ((T_CLONE) reduce 219) ((T_CONSTANT_ENCAPSED_STRING) reduce 219) ((T_CONTINUE) reduce 219) ((T_DEC) reduce 219) ((T_DECLARE) reduce 219) ((T_DIR) reduce 219) ((T_DNUMBER) reduce 219) ((T_DO) reduce 219) ((T_DOUBLE_CAST) reduce 219) ((T_ECHO) reduce 219) ((T_EMPTY) reduce 219) ((T_ENDFOR) reduce 219) ((T_ENUM) reduce 219) ((T_EVAL) reduce 219) ((T_EXIT) reduce 219) ((T_FILE) reduce 219) ((T_FINAL) reduce 219) ((T_FN) reduce 219) ((T_FOR) reduce 219) ((T_FOREACH) reduce 219) ((T_FUNCTION) reduce 219) ((T_FUNC_C) reduce 219) ((T_GLOBAL) reduce 219) ((T_GOTO) reduce 219) ((T_HALT_COMPILER) reduce 219) ((T_IF) reduce 219) ((T_INC) reduce 219) ((T_INCLUDE) reduce 219) ((T_INCLUDE_ONCE) reduce 219) ((T_INLINE_HTML) reduce 219) ((T_INTERFACE) reduce 219) ((T_INT_CAST) reduce 219) ((T_ISSET) reduce 219) ((T_LINE) reduce 219) ((T_LIST) reduce 219) ((T_LNUMBER) reduce 219) ((T_MATCH) reduce 219) ((T_METHOD_C) reduce 219) ((T_NAME_FULLY_QUALIFIED) reduce 219) ((T_NAME_QUALIFIED) reduce 219) ((T_NAME_RELATIVE) reduce 219) ((T_NEW) reduce 219) ((T_NS_C) reduce 219) ((T_OBJECT_CAST) reduce 219) ((T_PRINT) reduce 219) ((T_READONLY) reduce 219) ((T_REQUIRE) reduce 219) ((T_REQUIRE_ONCE) reduce 219) ((T_RETURN) reduce 219) ((T_START_HEREDOC) reduce 219) ((T_STATIC) reduce 219) ((T_STRING) reduce 219) ((T_STRING_CAST) reduce 219) ((T_SWITCH) reduce 219) ((T_THROW) reduce 219) ((T_TRAIT) reduce 219) ((T_TRAIT_C) reduce 219) ((T_TRY) reduce 219) ((T_UNSET) reduce 219) ((T_UNSET_CAST) reduce 219) ((T_VARIABLE) reduce 219) ((T_WHILE) reduce 219) ((T_YIELD) reduce 219) ((T_YIELD_FROM) reduce 219) (("[") reduce 219) (("`") reduce 219) (("{") reduce 219) (("~") reduce 219)) 20643 ((("!") reduce 220) (("\"") reduce 220) (("$") reduce 220) (("(") reduce 220) (("+") reduce 220) (("-") reduce 220) ((";") reduce 220) (("@") reduce 220) ((T_ABSTRACT) reduce 220) ((T_ARRAY) reduce 220) ((T_ARRAY_CAST) reduce 220) ((T_ATTRIBUTE) reduce 220) ((T_BOOL_CAST) reduce 220) ((T_BREAK) reduce 220) ((T_CLASS) reduce 220) ((T_CLASS_C) reduce 220) ((T_CLONE) reduce 220) ((T_CONSTANT_ENCAPSED_STRING) reduce 220) ((T_CONTINUE) reduce 220) ((T_DEC) reduce 220) ((T_DECLARE) reduce 220) ((T_DIR) reduce 220) ((T_DNUMBER) reduce 220) ((T_DO) reduce 220) ((T_DOUBLE_CAST) reduce 220) ((T_ECHO) reduce 220) ((T_EMPTY) reduce 220) ((T_ENDFOR) reduce 220) ((T_ENUM) reduce 220) ((T_EVAL) reduce 220) ((T_EXIT) reduce 220) ((T_FILE) reduce 220) ((T_FINAL) reduce 220) ((T_FN) reduce 220) ((T_FOR) reduce 220) ((T_FOREACH) reduce 220) ((T_FUNCTION) reduce 220) ((T_FUNC_C) reduce 220) ((T_GLOBAL) reduce 220) ((T_GOTO) reduce 220) ((T_HALT_COMPILER) reduce 220) ((T_IF) reduce 220) ((T_INC) reduce 220) ((T_INCLUDE) reduce 220) ((T_INCLUDE_ONCE) reduce 220) ((T_INLINE_HTML) reduce 220) ((T_INTERFACE) reduce 220) ((T_INT_CAST) reduce 220) ((T_ISSET) reduce 220) ((T_LINE) reduce 220) ((T_LIST) reduce 220) ((T_LNUMBER) reduce 220) ((T_MATCH) reduce 220) ((T_METHOD_C) reduce 220) ((T_NAME_FULLY_QUALIFIED) reduce 220) ((T_NAME_QUALIFIED) reduce 220) ((T_NAME_RELATIVE) reduce 220) ((T_NEW) reduce 220) ((T_NS_C) reduce 220) ((T_OBJECT_CAST) reduce 220) ((T_PRINT) reduce 220) ((T_READONLY) reduce 220) ((T_REQUIRE) reduce 220) ((T_REQUIRE_ONCE) reduce 220) ((T_RETURN) reduce 220) ((T_START_HEREDOC) reduce 220) ((T_STATIC) reduce 220) ((T_STRING) reduce 220) ((T_STRING_CAST) reduce 220) ((T_SWITCH) reduce 220) ((T_THROW) reduce 220) ((T_TRAIT) reduce 220) ((T_TRAIT_C) reduce 220) ((T_TRY) reduce 220) ((T_UNSET) reduce 220) ((T_UNSET_CAST) reduce 220) ((T_VARIABLE) reduce 220) ((T_WHILE) reduce 220) ((T_YIELD) reduce 220) ((T_YIELD_FROM) reduce 220) (("[") reduce 220) (("`") reduce 220) (("{") reduce 220) (("~") reduce 220)) 20645 ((("!") reduce 153) (("\"") reduce 153) (("$") reduce 153) (("(") reduce 153) (("+") reduce 153) (("-") reduce 153) ((";") reduce 153) (("@") reduce 153) ((T_ABSTRACT) reduce 153) ((T_ARRAY) reduce 153) ((T_ARRAY_CAST) reduce 153) ((T_ATTRIBUTE) reduce 153) ((T_BOOL_CAST) reduce 153) ((T_BREAK) reduce 153) ((T_CLASS) reduce 153) ((T_CLASS_C) reduce 153) ((T_CLONE) reduce 153) ((T_CONSTANT_ENCAPSED_STRING) reduce 153) ((T_CONTINUE) reduce 153) ((T_DEC) reduce 153) ((T_DECLARE) reduce 153) ((T_DIR) reduce 153) ((T_DNUMBER) reduce 153) ((T_DO) reduce 153) ((T_DOUBLE_CAST) reduce 153) ((T_ECHO) reduce 153) ((T_EMPTY) reduce 153) ((T_ENDFOR) reduce 153) ((T_ENUM) reduce 153) ((T_EVAL) reduce 153) ((T_EXIT) reduce 153) ((T_FILE) reduce 153) ((T_FINAL) reduce 153) ((T_FN) reduce 153) ((T_FOR) reduce 153) ((T_FOREACH) reduce 153) ((T_FUNCTION) reduce 153) ((T_FUNC_C) reduce 153) ((T_GLOBAL) reduce 153) ((T_GOTO) reduce 153) ((T_HALT_COMPILER) reduce 153) ((T_IF) reduce 153) ((T_INC) reduce 153) ((T_INCLUDE) reduce 153) ((T_INCLUDE_ONCE) reduce 153) ((T_INLINE_HTML) reduce 153) ((T_INTERFACE) reduce 153) ((T_INT_CAST) reduce 153) ((T_ISSET) reduce 153) ((T_LINE) reduce 153) ((T_LIST) reduce 153) ((T_LNUMBER) reduce 153) ((T_MATCH) reduce 153) ((T_METHOD_C) reduce 153) ((T_NAME_FULLY_QUALIFIED) reduce 153) ((T_NAME_QUALIFIED) reduce 153) ((T_NAME_RELATIVE) reduce 153) ((T_NEW) reduce 153) ((T_NS_C) reduce 153) ((T_OBJECT_CAST) reduce 153) ((T_PRINT) reduce 153) ((T_READONLY) reduce 153) ((T_REQUIRE) reduce 153) ((T_REQUIRE_ONCE) reduce 153) ((T_RETURN) reduce 153) ((T_START_HEREDOC) reduce 153) ((T_STATIC) reduce 153) ((T_STRING) reduce 153) ((T_STRING_CAST) reduce 153) ((T_SWITCH) reduce 153) ((T_THROW) reduce 153) ((T_TRAIT) reduce 153) ((T_TRAIT_C) reduce 153) ((T_TRY) reduce 153) ((T_UNSET) reduce 153) ((T_UNSET_CAST) reduce 153) ((T_VARIABLE) reduce 153) ((T_WHILE) reduce 153) ((T_YIELD) reduce 153) ((T_YIELD_FROM) reduce 153) (("[") reduce 153) (("`") reduce 153) (("{") reduce 153) (("~") reduce 153)) 20652 ((("!") reduce 187) (("\"") reduce 187) (("$") reduce 187) (("(") reduce 187) (("+") reduce 187) (("-") reduce 187) ((";") reduce 187) (("@") reduce 187) ((T_ABSTRACT) reduce 187) ((T_ARRAY) reduce 187) ((T_ARRAY_CAST) reduce 187) ((T_ATTRIBUTE) reduce 187) ((T_BOOL_CAST) reduce 187) ((T_BREAK) reduce 187) ((T_CLASS) reduce 187) ((T_CLASS_C) reduce 187) ((T_CLONE) reduce 187) ((T_CONSTANT_ENCAPSED_STRING) reduce 187) ((T_CONTINUE) reduce 187) ((T_DEC) reduce 187) ((T_DECLARE) reduce 187) ((T_DIR) reduce 187) ((T_DNUMBER) reduce 187) ((T_DO) reduce 187) ((T_DOUBLE_CAST) reduce 187) ((T_ECHO) reduce 187) ((T_EMPTY) reduce 187) ((T_ENDFOR) reduce 187) ((T_ENUM) reduce 187) ((T_EVAL) reduce 187) ((T_EXIT) reduce 187) ((T_FILE) reduce 187) ((T_FINAL) reduce 187) ((T_FN) reduce 187) ((T_FOR) reduce 187) ((T_FOREACH) reduce 187) ((T_FUNCTION) reduce 187) ((T_FUNC_C) reduce 187) ((T_GLOBAL) reduce 187) ((T_GOTO) reduce 187) ((T_HALT_COMPILER) reduce 187) ((T_IF) reduce 187) ((T_INC) reduce 187) ((T_INCLUDE) reduce 187) ((T_INCLUDE_ONCE) reduce 187) ((T_INLINE_HTML) reduce 187) ((T_INTERFACE) reduce 187) ((T_INT_CAST) reduce 187) ((T_ISSET) reduce 187) ((T_LINE) reduce 187) ((T_LIST) reduce 187) ((T_LNUMBER) reduce 187) ((T_MATCH) reduce 187) ((T_METHOD_C) reduce 187) ((T_NAME_FULLY_QUALIFIED) reduce 187) ((T_NAME_QUALIFIED) reduce 187) ((T_NAME_RELATIVE) reduce 187) ((T_NEW) reduce 187) ((T_NS_C) reduce 187) ((T_OBJECT_CAST) reduce 187) ((T_PRINT) reduce 187) ((T_READONLY) reduce 187) ((T_REQUIRE) reduce 187) ((T_REQUIRE_ONCE) reduce 187) ((T_RETURN) reduce 187) ((T_START_HEREDOC) reduce 187) ((T_STATIC) reduce 187) ((T_STRING) reduce 187) ((T_STRING_CAST) reduce 187) ((T_SWITCH) reduce 187) ((T_THROW) reduce 187) ((T_TRAIT) reduce 187) ((T_TRAIT_C) reduce 187) ((T_TRY) reduce 187) ((T_UNSET) reduce 187) ((T_UNSET_CAST) reduce 187) ((T_VARIABLE) reduce 187) ((T_WHILE) reduce 187) ((T_YIELD) reduce 187) ((T_YIELD_FROM) reduce 187) (("[") reduce 187) (("`") reduce 187) (("{") reduce 187) (("~") reduce 187)) 20654 ((("!") reduce 152) (("\"") reduce 152) (("$") reduce 152) (("(") reduce 152) (("+") reduce 152) (("-") reduce 152) ((";") reduce 152) (("@") reduce 152) ((T_ABSTRACT) reduce 152) ((T_ARRAY) reduce 152) ((T_ARRAY_CAST) reduce 152) ((T_ATTRIBUTE) reduce 152) ((T_BOOL_CAST) reduce 152) ((T_BREAK) reduce 152) ((T_CLASS) reduce 152) ((T_CLASS_C) reduce 152) ((T_CLONE) reduce 152) ((T_CONSTANT_ENCAPSED_STRING) reduce 152) ((T_CONTINUE) reduce 152) ((T_DEC) reduce 152) ((T_DECLARE) reduce 152) ((T_DIR) reduce 152) ((T_DNUMBER) reduce 152) ((T_DO) reduce 152) ((T_DOUBLE_CAST) reduce 152) ((T_ECHO) reduce 152) ((T_EMPTY) reduce 152) ((T_ENDFOR) reduce 152) ((T_ENUM) reduce 152) ((T_EVAL) reduce 152) ((T_EXIT) reduce 152) ((T_FILE) reduce 152) ((T_FINAL) reduce 152) ((T_FN) reduce 152) ((T_FOR) reduce 152) ((T_FOREACH) reduce 152) ((T_FUNCTION) reduce 152) ((T_FUNC_C) reduce 152) ((T_GLOBAL) reduce 152) ((T_GOTO) reduce 152) ((T_HALT_COMPILER) reduce 152) ((T_IF) reduce 152) ((T_INC) reduce 152) ((T_INCLUDE) reduce 152) ((T_INCLUDE_ONCE) reduce 152) ((T_INLINE_HTML) reduce 152) ((T_INTERFACE) reduce 152) ((T_INT_CAST) reduce 152) ((T_ISSET) reduce 152) ((T_LINE) reduce 152) ((T_LIST) reduce 152) ((T_LNUMBER) reduce 152) ((T_MATCH) reduce 152) ((T_METHOD_C) reduce 152) ((T_NAME_FULLY_QUALIFIED) reduce 152) ((T_NAME_QUALIFIED) reduce 152) ((T_NAME_RELATIVE) reduce 152) ((T_NEW) reduce 152) ((T_NS_C) reduce 152) ((T_OBJECT_CAST) reduce 152) ((T_PRINT) reduce 152) ((T_READONLY) reduce 152) ((T_REQUIRE) reduce 152) ((T_REQUIRE_ONCE) reduce 152) ((T_RETURN) reduce 152) ((T_START_HEREDOC) reduce 152) ((T_STATIC) reduce 152) ((T_STRING) reduce 152) ((T_STRING_CAST) reduce 152) ((T_SWITCH) reduce 152) ((T_THROW) reduce 152) ((T_TRAIT) reduce 152) ((T_TRAIT_C) reduce 152) ((T_TRY) reduce 152) ((T_UNSET) reduce 152) ((T_UNSET_CAST) reduce 152) ((T_VARIABLE) reduce 152) ((T_WHILE) reduce 152) ((T_YIELD) reduce 152) ((T_YIELD_FROM) reduce 152) (("[") reduce 152) (("`") reduce 152) (("{") reduce 152) (("~") reduce 152)) 20656 ((("!") reduce 157) (("\"") reduce 157) (("$") reduce 157) (("(") reduce 157) (("+") reduce 157) (("-") reduce 157) ((";") reduce 157) (("@") reduce 157) ((T_ABSTRACT) reduce 157) ((T_ARRAY) reduce 157) ((T_ARRAY_CAST) reduce 157) ((T_ATTRIBUTE) reduce 157) ((T_BOOL_CAST) reduce 157) ((T_BREAK) reduce 157) ((T_CLASS) reduce 157) ((T_CLASS_C) reduce 157) ((T_CLONE) reduce 157) ((T_CONSTANT_ENCAPSED_STRING) reduce 157) ((T_CONTINUE) reduce 157) ((T_DEC) reduce 157) ((T_DECLARE) reduce 157) ((T_DIR) reduce 157) ((T_DNUMBER) reduce 157) ((T_DO) reduce 157) ((T_DOUBLE_CAST) reduce 157) ((T_ECHO) reduce 157) ((T_ELSE) reduce 157) ((T_ELSEIF) reduce 157) ((T_EMPTY) reduce 157) ((T_ENDFOREACH) reduce 157) ((T_ENUM) reduce 157) ((T_EVAL) reduce 157) ((T_EXIT) reduce 157) ((T_FILE) reduce 157) ((T_FINAL) reduce 157) ((T_FN) reduce 157) ((T_FOR) reduce 157) ((T_FOREACH) reduce 157) ((T_FUNCTION) reduce 157) ((T_FUNC_C) reduce 157) ((T_GLOBAL) reduce 157) ((T_GOTO) reduce 157) ((T_HALT_COMPILER) reduce 157) ((T_IF) reduce 157) ((T_INC) reduce 157) ((T_INCLUDE) reduce 157) ((T_INCLUDE_ONCE) reduce 157) ((T_INLINE_HTML) reduce 157) ((T_INTERFACE) reduce 157) ((T_INT_CAST) reduce 157) ((T_ISSET) reduce 157) ((T_LINE) reduce 157) ((T_LIST) reduce 157) ((T_LNUMBER) reduce 157) ((T_MATCH) reduce 157) ((T_METHOD_C) reduce 157) ((T_NAME_FULLY_QUALIFIED) reduce 157) ((T_NAME_QUALIFIED) reduce 157) ((T_NAME_RELATIVE) reduce 157) ((T_NEW) reduce 157) ((T_NS_C) reduce 157) ((T_OBJECT_CAST) reduce 157) ((T_PRINT) reduce 157) ((T_READONLY) reduce 157) ((T_REQUIRE) reduce 157) ((T_REQUIRE_ONCE) reduce 157) ((T_RETURN) reduce 157) ((T_START_HEREDOC) reduce 157) ((T_STATIC) reduce 157) ((T_STRING) reduce 157) ((T_STRING_CAST) reduce 157) ((T_SWITCH) reduce 157) ((T_THROW) reduce 157) ((T_TRAIT) reduce 157) ((T_TRAIT_C) reduce 157) ((T_TRY) reduce 157) ((T_UNSET) reduce 157) ((T_UNSET_CAST) reduce 157) ((T_VARIABLE) reduce 157) ((T_WHILE) reduce 157) ((T_YIELD) reduce 157) ((T_YIELD_FROM) reduce 157) (("[") reduce 157) (("`") reduce 157) (("{") reduce 157) (("~") reduce 157)) 20662 ((("!") reduce 149) (("\"") reduce 149) (("$") reduce 149) (("(") reduce 149) (("+") reduce 149) (("-") reduce 149) ((";") reduce 149) (("@") reduce 149) ((T_ABSTRACT) reduce 149) ((T_ARRAY) reduce 149) ((T_ARRAY_CAST) reduce 149) ((T_ATTRIBUTE) reduce 149) ((T_BOOL_CAST) reduce 149) ((T_BREAK) reduce 149) ((T_CLASS) reduce 149) ((T_CLASS_C) reduce 149) ((T_CLONE) reduce 149) ((T_CONSTANT_ENCAPSED_STRING) reduce 149) ((T_CONTINUE) reduce 149) ((T_DEC) reduce 149) ((T_DECLARE) reduce 149) ((T_DIR) reduce 149) ((T_DNUMBER) reduce 149) ((T_DO) reduce 149) ((T_DOUBLE_CAST) reduce 149) ((T_ECHO) reduce 149) ((T_ELSE) reduce 149) ((T_ELSEIF) reduce 149) ((T_EMPTY) reduce 149) ((T_ENDFOREACH) reduce 149) ((T_ENUM) reduce 149) ((T_EVAL) reduce 149) ((T_EXIT) reduce 149) ((T_FILE) reduce 149) ((T_FINAL) reduce 149) ((T_FN) reduce 149) ((T_FOR) reduce 149) ((T_FOREACH) reduce 149) ((T_FUNCTION) reduce 149) ((T_FUNC_C) reduce 149) ((T_GLOBAL) reduce 149) ((T_GOTO) reduce 149) ((T_HALT_COMPILER) reduce 149) ((T_IF) reduce 149) ((T_INC) reduce 149) ((T_INCLUDE) reduce 149) ((T_INCLUDE_ONCE) reduce 149) ((T_INLINE_HTML) reduce 149) ((T_INTERFACE) reduce 149) ((T_INT_CAST) reduce 149) ((T_ISSET) reduce 149) ((T_LINE) reduce 149) ((T_LIST) reduce 149) ((T_LNUMBER) reduce 149) ((T_MATCH) reduce 149) ((T_METHOD_C) reduce 149) ((T_NAME_FULLY_QUALIFIED) reduce 149) ((T_NAME_QUALIFIED) reduce 149) ((T_NAME_RELATIVE) reduce 149) ((T_NEW) reduce 149) ((T_NS_C) reduce 149) ((T_OBJECT_CAST) reduce 149) ((T_PRINT) reduce 149) ((T_READONLY) reduce 149) ((T_REQUIRE) reduce 149) ((T_REQUIRE_ONCE) reduce 149) ((T_RETURN) reduce 149) ((T_START_HEREDOC) reduce 149) ((T_STATIC) reduce 149) ((T_STRING) reduce 149) ((T_STRING_CAST) reduce 149) ((T_SWITCH) reduce 149) ((T_THROW) reduce 149) ((T_TRAIT) reduce 149) ((T_TRAIT_C) reduce 149) ((T_TRY) reduce 149) ((T_UNSET) reduce 149) ((T_UNSET_CAST) reduce 149) ((T_VARIABLE) reduce 149) ((T_WHILE) reduce 149) ((T_YIELD) reduce 149) ((T_YIELD_FROM) reduce 149) (("[") reduce 149) (("`") reduce 149) (("{") reduce 149) (("~") reduce 149)) 20667 ((("!") reduce 163) (("\"") reduce 163) (("$") reduce 163) (("(") reduce 163) (("+") reduce 163) (("-") reduce 163) ((";") reduce 163) (("@") reduce 163) ((T_ABSTRACT) reduce 163) ((T_ARRAY) reduce 163) ((T_ARRAY_CAST) reduce 163) ((T_ATTRIBUTE) reduce 163) ((T_BOOL_CAST) reduce 163) ((T_BREAK) reduce 163) ((T_CLASS) reduce 163) ((T_CLASS_C) reduce 163) ((T_CLONE) reduce 163) ((T_CONSTANT_ENCAPSED_STRING) reduce 163) ((T_CONTINUE) reduce 163) ((T_DEC) reduce 163) ((T_DECLARE) reduce 163) ((T_DIR) reduce 163) ((T_DNUMBER) reduce 163) ((T_DO) reduce 163) ((T_DOUBLE_CAST) reduce 163) ((T_ECHO) reduce 163) ((T_ELSE) reduce 163) ((T_ELSEIF) reduce 163) ((T_EMPTY) reduce 163) ((T_ENDFOREACH) reduce 163) ((T_ENUM) reduce 163) ((T_EVAL) reduce 163) ((T_EXIT) reduce 163) ((T_FILE) reduce 163) ((T_FINAL) reduce 163) ((T_FN) reduce 163) ((T_FOR) reduce 163) ((T_FOREACH) reduce 163) ((T_FUNCTION) reduce 163) ((T_FUNC_C) reduce 163) ((T_GLOBAL) reduce 163) ((T_GOTO) reduce 163) ((T_HALT_COMPILER) reduce 163) ((T_IF) reduce 163) ((T_INC) reduce 163) ((T_INCLUDE) reduce 163) ((T_INCLUDE_ONCE) reduce 163) ((T_INLINE_HTML) reduce 163) ((T_INTERFACE) reduce 163) ((T_INT_CAST) reduce 163) ((T_ISSET) reduce 163) ((T_LINE) reduce 163) ((T_LIST) reduce 163) ((T_LNUMBER) reduce 163) ((T_MATCH) reduce 163) ((T_METHOD_C) reduce 163) ((T_NAME_FULLY_QUALIFIED) reduce 163) ((T_NAME_QUALIFIED) reduce 163) ((T_NAME_RELATIVE) reduce 163) ((T_NEW) reduce 163) ((T_NS_C) reduce 163) ((T_OBJECT_CAST) reduce 163) ((T_PRINT) reduce 163) ((T_READONLY) reduce 163) ((T_REQUIRE) reduce 163) ((T_REQUIRE_ONCE) reduce 163) ((T_RETURN) reduce 163) ((T_START_HEREDOC) reduce 163) ((T_STATIC) reduce 163) ((T_STRING) reduce 163) ((T_STRING_CAST) reduce 163) ((T_SWITCH) reduce 163) ((T_THROW) reduce 163) ((T_TRAIT) reduce 163) ((T_TRAIT_C) reduce 163) ((T_TRY) reduce 163) ((T_UNSET) reduce 163) ((T_UNSET_CAST) reduce 163) ((T_VARIABLE) reduce 163) ((T_WHILE) reduce 163) ((T_YIELD) reduce 163) ((T_YIELD_FROM) reduce 163) (("[") reduce 163) (("`") reduce 163) (("{") reduce 163) (("~") reduce 163)) 20668 ((("!") reduce 219) (("\"") reduce 219) (("$") reduce 219) (("(") reduce 219) (("+") reduce 219) (("-") reduce 219) ((";") reduce 219) (("@") reduce 219) ((T_ABSTRACT) reduce 219) ((T_ARRAY) reduce 219) ((T_ARRAY_CAST) reduce 219) ((T_ATTRIBUTE) reduce 219) ((T_BOOL_CAST) reduce 219) ((T_BREAK) reduce 219) ((T_CLASS) reduce 219) ((T_CLASS_C) reduce 219) ((T_CLONE) reduce 219) ((T_CONSTANT_ENCAPSED_STRING) reduce 219) ((T_CONTINUE) reduce 219) ((T_DEC) reduce 219) ((T_DECLARE) reduce 219) ((T_DIR) reduce 219) ((T_DNUMBER) reduce 219) ((T_DO) reduce 219) ((T_DOUBLE_CAST) reduce 219) ((T_ECHO) reduce 219) ((T_ELSE) reduce 219) ((T_ELSEIF) reduce 219) ((T_EMPTY) reduce 219) ((T_ENDFOREACH) reduce 219) ((T_ENUM) reduce 219) ((T_EVAL) reduce 219) ((T_EXIT) reduce 219) ((T_FILE) reduce 219) ((T_FINAL) reduce 219) ((T_FN) reduce 219) ((T_FOR) reduce 219) ((T_FOREACH) reduce 219) ((T_FUNCTION) reduce 219) ((T_FUNC_C) reduce 219) ((T_GLOBAL) reduce 219) ((T_GOTO) reduce 219) ((T_HALT_COMPILER) reduce 219) ((T_IF) reduce 219) ((T_INC) reduce 219) ((T_INCLUDE) reduce 219) ((T_INCLUDE_ONCE) reduce 219) ((T_INLINE_HTML) reduce 219) ((T_INTERFACE) reduce 219) ((T_INT_CAST) reduce 219) ((T_ISSET) reduce 219) ((T_LINE) reduce 219) ((T_LIST) reduce 219) ((T_LNUMBER) reduce 219) ((T_MATCH) reduce 219) ((T_METHOD_C) reduce 219) ((T_NAME_FULLY_QUALIFIED) reduce 219) ((T_NAME_QUALIFIED) reduce 219) ((T_NAME_RELATIVE) reduce 219) ((T_NEW) reduce 219) ((T_NS_C) reduce 219) ((T_OBJECT_CAST) reduce 219) ((T_PRINT) reduce 219) ((T_READONLY) reduce 219) ((T_REQUIRE) reduce 219) ((T_REQUIRE_ONCE) reduce 219) ((T_RETURN) reduce 219) ((T_START_HEREDOC) reduce 219) ((T_STATIC) reduce 219) ((T_STRING) reduce 219) ((T_STRING_CAST) reduce 219) ((T_SWITCH) reduce 219) ((T_THROW) reduce 219) ((T_TRAIT) reduce 219) ((T_TRAIT_C) reduce 219) ((T_TRY) reduce 219) ((T_UNSET) reduce 219) ((T_UNSET_CAST) reduce 219) ((T_VARIABLE) reduce 219) ((T_WHILE) reduce 219) ((T_YIELD) reduce 219) ((T_YIELD_FROM) reduce 219) (("[") reduce 219) (("`") reduce 219) (("{") reduce 219) (("~") reduce 219)) 20671 ((("!") reduce 220) (("\"") reduce 220) (("$") reduce 220) (("(") reduce 220) (("+") reduce 220) (("-") reduce 220) ((";") reduce 220) (("@") reduce 220) ((T_ABSTRACT) reduce 220) ((T_ARRAY) reduce 220) ((T_ARRAY_CAST) reduce 220) ((T_ATTRIBUTE) reduce 220) ((T_BOOL_CAST) reduce 220) ((T_BREAK) reduce 220) ((T_CLASS) reduce 220) ((T_CLASS_C) reduce 220) ((T_CLONE) reduce 220) ((T_CONSTANT_ENCAPSED_STRING) reduce 220) ((T_CONTINUE) reduce 220) ((T_DEC) reduce 220) ((T_DECLARE) reduce 220) ((T_DIR) reduce 220) ((T_DNUMBER) reduce 220) ((T_DO) reduce 220) ((T_DOUBLE_CAST) reduce 220) ((T_ECHO) reduce 220) ((T_ELSE) reduce 220) ((T_ELSEIF) reduce 220) ((T_EMPTY) reduce 220) ((T_ENDFOREACH) reduce 220) ((T_ENUM) reduce 220) ((T_EVAL) reduce 220) ((T_EXIT) reduce 220) ((T_FILE) reduce 220) ((T_FINAL) reduce 220) ((T_FN) reduce 220) ((T_FOR) reduce 220) ((T_FOREACH) reduce 220) ((T_FUNCTION) reduce 220) ((T_FUNC_C) reduce 220) ((T_GLOBAL) reduce 220) ((T_GOTO) reduce 220) ((T_HALT_COMPILER) reduce 220) ((T_IF) reduce 220) ((T_INC) reduce 220) ((T_INCLUDE) reduce 220) ((T_INCLUDE_ONCE) reduce 220) ((T_INLINE_HTML) reduce 220) ((T_INTERFACE) reduce 220) ((T_INT_CAST) reduce 220) ((T_ISSET) reduce 220) ((T_LINE) reduce 220) ((T_LIST) reduce 220) ((T_LNUMBER) reduce 220) ((T_MATCH) reduce 220) ((T_METHOD_C) reduce 220) ((T_NAME_FULLY_QUALIFIED) reduce 220) ((T_NAME_QUALIFIED) reduce 220) ((T_NAME_RELATIVE) reduce 220) ((T_NEW) reduce 220) ((T_NS_C) reduce 220) ((T_OBJECT_CAST) reduce 220) ((T_PRINT) reduce 220) ((T_READONLY) reduce 220) ((T_REQUIRE) reduce 220) ((T_REQUIRE_ONCE) reduce 220) ((T_RETURN) reduce 220) ((T_START_HEREDOC) reduce 220) ((T_STATIC) reduce 220) ((T_STRING) reduce 220) ((T_STRING_CAST) reduce 220) ((T_SWITCH) reduce 220) ((T_THROW) reduce 220) ((T_TRAIT) reduce 220) ((T_TRAIT_C) reduce 220) ((T_TRY) reduce 220) ((T_UNSET) reduce 220) ((T_UNSET_CAST) reduce 220) ((T_VARIABLE) reduce 220) ((T_WHILE) reduce 220) ((T_YIELD) reduce 220) ((T_YIELD_FROM) reduce 220) (("[") reduce 220) (("`") reduce 220) (("{") reduce 220) (("~") reduce 220)) 20673 ((("!") reduce 153) (("\"") reduce 153) (("$") reduce 153) (("(") reduce 153) (("+") reduce 153) (("-") reduce 153) ((";") reduce 153) (("@") reduce 153) ((T_ABSTRACT) reduce 153) ((T_ARRAY) reduce 153) ((T_ARRAY_CAST) reduce 153) ((T_ATTRIBUTE) reduce 153) ((T_BOOL_CAST) reduce 153) ((T_BREAK) reduce 153) ((T_CLASS) reduce 153) ((T_CLASS_C) reduce 153) ((T_CLONE) reduce 153) ((T_CONSTANT_ENCAPSED_STRING) reduce 153) ((T_CONTINUE) reduce 153) ((T_DEC) reduce 153) ((T_DECLARE) reduce 153) ((T_DIR) reduce 153) ((T_DNUMBER) reduce 153) ((T_DO) reduce 153) ((T_DOUBLE_CAST) reduce 153) ((T_ECHO) reduce 153) ((T_ELSE) reduce 153) ((T_ELSEIF) reduce 153) ((T_EMPTY) reduce 153) ((T_ENDFOREACH) reduce 153) ((T_ENUM) reduce 153) ((T_EVAL) reduce 153) ((T_EXIT) reduce 153) ((T_FILE) reduce 153) ((T_FINAL) reduce 153) ((T_FN) reduce 153) ((T_FOR) reduce 153) ((T_FOREACH) reduce 153) ((T_FUNCTION) reduce 153) ((T_FUNC_C) reduce 153) ((T_GLOBAL) reduce 153) ((T_GOTO) reduce 153) ((T_HALT_COMPILER) reduce 153) ((T_IF) reduce 153) ((T_INC) reduce 153) ((T_INCLUDE) reduce 153) ((T_INCLUDE_ONCE) reduce 153) ((T_INLINE_HTML) reduce 153) ((T_INTERFACE) reduce 153) ((T_INT_CAST) reduce 153) ((T_ISSET) reduce 153) ((T_LINE) reduce 153) ((T_LIST) reduce 153) ((T_LNUMBER) reduce 153) ((T_MATCH) reduce 153) ((T_METHOD_C) reduce 153) ((T_NAME_FULLY_QUALIFIED) reduce 153) ((T_NAME_QUALIFIED) reduce 153) ((T_NAME_RELATIVE) reduce 153) ((T_NEW) reduce 153) ((T_NS_C) reduce 153) ((T_OBJECT_CAST) reduce 153) ((T_PRINT) reduce 153) ((T_READONLY) reduce 153) ((T_REQUIRE) reduce 153) ((T_REQUIRE_ONCE) reduce 153) ((T_RETURN) reduce 153) ((T_START_HEREDOC) reduce 153) ((T_STATIC) reduce 153) ((T_STRING) reduce 153) ((T_STRING_CAST) reduce 153) ((T_SWITCH) reduce 153) ((T_THROW) reduce 153) ((T_TRAIT) reduce 153) ((T_TRAIT_C) reduce 153) ((T_TRY) reduce 153) ((T_UNSET) reduce 153) ((T_UNSET_CAST) reduce 153) ((T_VARIABLE) reduce 153) ((T_WHILE) reduce 153) ((T_YIELD) reduce 153) ((T_YIELD_FROM) reduce 153) (("[") reduce 153) (("`") reduce 153) (("{") reduce 153) (("~") reduce 153)) 20675 ((("!") reduce 152) (("\"") reduce 152) (("$") reduce 152) (("(") reduce 152) (("+") reduce 152) (("-") reduce 152) ((";") reduce 152) (("@") reduce 152) ((T_ABSTRACT) reduce 152) ((T_ARRAY) reduce 152) ((T_ARRAY_CAST) reduce 152) ((T_ATTRIBUTE) reduce 152) ((T_BOOL_CAST) reduce 152) ((T_BREAK) reduce 152) ((T_CLASS) reduce 152) ((T_CLASS_C) reduce 152) ((T_CLONE) reduce 152) ((T_CONSTANT_ENCAPSED_STRING) reduce 152) ((T_CONTINUE) reduce 152) ((T_DEC) reduce 152) ((T_DECLARE) reduce 152) ((T_DIR) reduce 152) ((T_DNUMBER) reduce 152) ((T_DO) reduce 152) ((T_DOUBLE_CAST) reduce 152) ((T_ECHO) reduce 152) ((T_ELSE) reduce 152) ((T_ELSEIF) reduce 152) ((T_EMPTY) reduce 152) ((T_ENDFOREACH) reduce 152) ((T_ENUM) reduce 152) ((T_EVAL) reduce 152) ((T_EXIT) reduce 152) ((T_FILE) reduce 152) ((T_FINAL) reduce 152) ((T_FN) reduce 152) ((T_FOR) reduce 152) ((T_FOREACH) reduce 152) ((T_FUNCTION) reduce 152) ((T_FUNC_C) reduce 152) ((T_GLOBAL) reduce 152) ((T_GOTO) reduce 152) ((T_HALT_COMPILER) reduce 152) ((T_IF) reduce 152) ((T_INC) reduce 152) ((T_INCLUDE) reduce 152) ((T_INCLUDE_ONCE) reduce 152) ((T_INLINE_HTML) reduce 152) ((T_INTERFACE) reduce 152) ((T_INT_CAST) reduce 152) ((T_ISSET) reduce 152) ((T_LINE) reduce 152) ((T_LIST) reduce 152) ((T_LNUMBER) reduce 152) ((T_MATCH) reduce 152) ((T_METHOD_C) reduce 152) ((T_NAME_FULLY_QUALIFIED) reduce 152) ((T_NAME_QUALIFIED) reduce 152) ((T_NAME_RELATIVE) reduce 152) ((T_NEW) reduce 152) ((T_NS_C) reduce 152) ((T_OBJECT_CAST) reduce 152) ((T_PRINT) reduce 152) ((T_READONLY) reduce 152) ((T_REQUIRE) reduce 152) ((T_REQUIRE_ONCE) reduce 152) ((T_RETURN) reduce 152) ((T_START_HEREDOC) reduce 152) ((T_STATIC) reduce 152) ((T_STRING) reduce 152) ((T_STRING_CAST) reduce 152) ((T_SWITCH) reduce 152) ((T_THROW) reduce 152) ((T_TRAIT) reduce 152) ((T_TRAIT_C) reduce 152) ((T_TRY) reduce 152) ((T_UNSET) reduce 152) ((T_UNSET_CAST) reduce 152) ((T_VARIABLE) reduce 152) ((T_WHILE) reduce 152) ((T_YIELD) reduce 152) ((T_YIELD_FROM) reduce 152) (("[") reduce 152) (("`") reduce 152) (("{") reduce 152) (("~") reduce 152)) 20676 ((("!") reduce 244) (("\"") reduce 244) (("$") reduce 244) (("(") reduce 244) (("+") reduce 244) (("-") reduce 244) ((";") reduce 244) (("@") reduce 244) ((T_ABSTRACT) reduce 244) ((T_ARRAY) reduce 244) ((T_ARRAY_CAST) reduce 244) ((T_ATTRIBUTE) reduce 244) ((T_BOOL_CAST) reduce 244) ((T_BREAK) reduce 244) ((T_CLASS) reduce 244) ((T_CLASS_C) reduce 244) ((T_CLONE) reduce 244) ((T_CONSTANT_ENCAPSED_STRING) reduce 244) ((T_CONTINUE) reduce 244) ((T_DEC) reduce 244) ((T_DECLARE) reduce 244) ((T_DIR) reduce 244) ((T_DNUMBER) reduce 244) ((T_DO) reduce 244) ((T_DOUBLE_CAST) reduce 244) ((T_ECHO) reduce 244) ((T_EMPTY) reduce 244) ((T_ENDFOREACH) reduce 244) ((T_ENUM) reduce 244) ((T_EVAL) reduce 244) ((T_EXIT) reduce 244) ((T_FILE) reduce 244) ((T_FINAL) reduce 244) ((T_FN) reduce 244) ((T_FOR) reduce 244) ((T_FOREACH) reduce 244) ((T_FUNCTION) reduce 244) ((T_FUNC_C) reduce 244) ((T_GLOBAL) reduce 244) ((T_GOTO) reduce 244) ((T_HALT_COMPILER) reduce 244) ((T_IF) reduce 244) ((T_INC) reduce 244) ((T_INCLUDE) reduce 244) ((T_INCLUDE_ONCE) reduce 244) ((T_INLINE_HTML) reduce 244) ((T_INTERFACE) reduce 244) ((T_INT_CAST) reduce 244) ((T_ISSET) reduce 244) ((T_LINE) reduce 244) ((T_LIST) reduce 244) ((T_LNUMBER) reduce 244) ((T_MATCH) reduce 244) ((T_METHOD_C) reduce 244) ((T_NAME_FULLY_QUALIFIED) reduce 244) ((T_NAME_QUALIFIED) reduce 244) ((T_NAME_RELATIVE) reduce 244) ((T_NEW) reduce 244) ((T_NS_C) reduce 244) ((T_OBJECT_CAST) reduce 244) ((T_PRINT) reduce 244) ((T_READONLY) reduce 244) ((T_REQUIRE) reduce 244) ((T_REQUIRE_ONCE) reduce 244) ((T_RETURN) reduce 244) ((T_START_HEREDOC) reduce 244) ((T_STATIC) reduce 244) ((T_STRING) reduce 244) ((T_STRING_CAST) reduce 244) ((T_SWITCH) reduce 244) ((T_THROW) reduce 244) ((T_TRAIT) reduce 244) ((T_TRAIT_C) reduce 244) ((T_TRY) reduce 244) ((T_UNSET) reduce 244) ((T_UNSET_CAST) reduce 244) ((T_VARIABLE) reduce 244) ((T_WHILE) reduce 244) ((T_YIELD) reduce 244) ((T_YIELD_FROM) reduce 244) (("[") reduce 244) (("`") reduce 244) (("{") reduce 244) (("~") reduce 244)) 20687 ((("!") reduce 455) (("\"") reduce 455) (("$") reduce 455) (("(") reduce 455) (("+") reduce 455) (("-") reduce 455) ((";") reduce 455) (("@") reduce 455) ((T_ABSTRACT) reduce 455) ((T_ARRAY) reduce 455) ((T_ARRAY_CAST) reduce 455) ((T_ATTRIBUTE) reduce 455) ((T_BOOL_CAST) reduce 455) ((T_BREAK) reduce 455) ((T_CLASS) reduce 455) ((T_CLASS_C) reduce 455) ((T_CLONE) reduce 455) ((T_CONSTANT_ENCAPSED_STRING) reduce 455) ((T_CONTINUE) reduce 455) ((T_DEC) reduce 455) ((T_DECLARE) reduce 455) ((T_DIR) reduce 455) ((T_DNUMBER) reduce 455) ((T_DO) reduce 455) ((T_DOUBLE_CAST) reduce 455) ((T_ECHO) reduce 455) ((T_EMPTY) reduce 455) ((T_ENDFOREACH) reduce 455) ((T_ENUM) reduce 455) ((T_EVAL) reduce 455) ((T_EXIT) reduce 455) ((T_FILE) reduce 455) ((T_FINAL) reduce 455) ((T_FN) reduce 455) ((T_FOR) reduce 455) ((T_FOREACH) reduce 455) ((T_FUNCTION) reduce 455) ((T_FUNC_C) reduce 455) ((T_GLOBAL) reduce 455) ((T_GOTO) reduce 455) ((T_HALT_COMPILER) reduce 455) ((T_IF) reduce 455) ((T_INC) reduce 455) ((T_INCLUDE) reduce 455) ((T_INCLUDE_ONCE) reduce 455) ((T_INLINE_HTML) reduce 455) ((T_INTERFACE) reduce 455) ((T_INT_CAST) reduce 455) ((T_ISSET) reduce 455) ((T_LINE) reduce 455) ((T_LIST) reduce 455) ((T_LNUMBER) reduce 455) ((T_MATCH) reduce 455) ((T_METHOD_C) reduce 455) ((T_NAME_FULLY_QUALIFIED) reduce 455) ((T_NAME_QUALIFIED) reduce 455) ((T_NAME_RELATIVE) reduce 455) ((T_NEW) reduce 455) ((T_NS_C) reduce 455) ((T_OBJECT_CAST) reduce 455) ((T_PRINT) reduce 455) ((T_READONLY) reduce 455) ((T_REQUIRE) reduce 455) ((T_REQUIRE_ONCE) reduce 455) ((T_RETURN) reduce 455) ((T_START_HEREDOC) reduce 455) ((T_STATIC) reduce 455) ((T_STRING) reduce 455) ((T_STRING_CAST) reduce 455) ((T_SWITCH) reduce 455) ((T_THROW) reduce 455) ((T_TRAIT) reduce 455) ((T_TRAIT_C) reduce 455) ((T_TRY) reduce 455) ((T_UNSET) reduce 455) ((T_UNSET_CAST) reduce 455) ((T_VARIABLE) reduce 455) ((T_WHILE) reduce 455) ((T_YIELD) reduce 455) ((T_YIELD_FROM) reduce 455) (("[") reduce 455) (("`") reduce 455) (("{") reduce 455) (("~") reduce 455)) 20688 ((("!") reduce 181) (("\"") reduce 181) (("$") reduce 181) (("(") reduce 181) (("+") reduce 181) (("-") reduce 181) ((";") reduce 181) (("@") reduce 181) ((T_ABSTRACT) reduce 181) ((T_ARRAY) reduce 181) ((T_ARRAY_CAST) reduce 181) ((T_ATTRIBUTE) reduce 181) ((T_BOOL_CAST) reduce 181) ((T_BREAK) reduce 181) ((T_CLASS) reduce 181) ((T_CLASS_C) reduce 181) ((T_CLONE) reduce 181) ((T_CONSTANT_ENCAPSED_STRING) reduce 181) ((T_CONTINUE) reduce 181) ((T_DEC) reduce 181) ((T_DECLARE) reduce 181) ((T_DIR) reduce 181) ((T_DNUMBER) reduce 181) ((T_DO) reduce 181) ((T_DOUBLE_CAST) reduce 181) ((T_ECHO) reduce 181) ((T_EMPTY) reduce 181) ((T_ENDFOREACH) reduce 181) ((T_ENUM) reduce 181) ((T_EVAL) reduce 181) ((T_EXIT) reduce 181) ((T_FILE) reduce 181) ((T_FINAL) reduce 181) ((T_FN) reduce 181) ((T_FOR) reduce 181) ((T_FOREACH) reduce 181) ((T_FUNCTION) reduce 181) ((T_FUNC_C) reduce 181) ((T_GLOBAL) reduce 181) ((T_GOTO) reduce 181) ((T_HALT_COMPILER) reduce 181) ((T_IF) reduce 181) ((T_INC) reduce 181) ((T_INCLUDE) reduce 181) ((T_INCLUDE_ONCE) reduce 181) ((T_INLINE_HTML) reduce 181) ((T_INTERFACE) reduce 181) ((T_INT_CAST) reduce 181) ((T_ISSET) reduce 181) ((T_LINE) reduce 181) ((T_LIST) reduce 181) ((T_LNUMBER) reduce 181) ((T_MATCH) reduce 181) ((T_METHOD_C) reduce 181) ((T_NAME_FULLY_QUALIFIED) reduce 181) ((T_NAME_QUALIFIED) reduce 181) ((T_NAME_RELATIVE) reduce 181) ((T_NEW) reduce 181) ((T_NS_C) reduce 181) ((T_OBJECT_CAST) reduce 181) ((T_PRINT) reduce 181) ((T_READONLY) reduce 181) ((T_REQUIRE) reduce 181) ((T_REQUIRE_ONCE) reduce 181) ((T_RETURN) reduce 181) ((T_START_HEREDOC) reduce 181) ((T_STATIC) reduce 181) ((T_STRING) reduce 181) ((T_STRING_CAST) reduce 181) ((T_SWITCH) reduce 181) ((T_THROW) reduce 181) ((T_TRAIT) reduce 181) ((T_TRAIT_C) reduce 181) ((T_TRY) reduce 181) ((T_UNSET) reduce 181) ((T_UNSET_CAST) reduce 181) ((T_VARIABLE) reduce 181) ((T_WHILE) reduce 181) ((T_YIELD) reduce 181) ((T_YIELD_FROM) reduce 181) (("[") reduce 181) (("`") reduce 181) (("{") reduce 181) (("~") reduce 181)) 20689 ((("!") reduce 159) (("\"") reduce 159) (("$") reduce 159) (("(") reduce 159) (("+") reduce 159) (("-") reduce 159) ((";") reduce 159) (("@") reduce 159) ((T_ABSTRACT) reduce 159) ((T_ARRAY) reduce 159) ((T_ARRAY_CAST) reduce 159) ((T_ATTRIBUTE) reduce 159) ((T_BOOL_CAST) reduce 159) ((T_BREAK) reduce 159) ((T_CLASS) reduce 159) ((T_CLASS_C) reduce 159) ((T_CLONE) reduce 159) ((T_CONSTANT_ENCAPSED_STRING) reduce 159) ((T_CONTINUE) reduce 159) ((T_DEC) reduce 159) ((T_DECLARE) reduce 159) ((T_DIR) reduce 159) ((T_DNUMBER) reduce 159) ((T_DO) reduce 159) ((T_DOUBLE_CAST) reduce 159) ((T_ECHO) reduce 159) ((T_EMPTY) reduce 159) ((T_ENDFOREACH) reduce 159) ((T_ENUM) reduce 159) ((T_EVAL) reduce 159) ((T_EXIT) reduce 159) ((T_FILE) reduce 159) ((T_FINAL) reduce 159) ((T_FN) reduce 159) ((T_FOR) reduce 159) ((T_FOREACH) reduce 159) ((T_FUNCTION) reduce 159) ((T_FUNC_C) reduce 159) ((T_GLOBAL) reduce 159) ((T_GOTO) reduce 159) ((T_HALT_COMPILER) reduce 159) ((T_IF) reduce 159) ((T_INC) reduce 159) ((T_INCLUDE) reduce 159) ((T_INCLUDE_ONCE) reduce 159) ((T_INLINE_HTML) reduce 159) ((T_INTERFACE) reduce 159) ((T_INT_CAST) reduce 159) ((T_ISSET) reduce 159) ((T_LINE) reduce 159) ((T_LIST) reduce 159) ((T_LNUMBER) reduce 159) ((T_MATCH) reduce 159) ((T_METHOD_C) reduce 159) ((T_NAME_FULLY_QUALIFIED) reduce 159) ((T_NAME_QUALIFIED) reduce 159) ((T_NAME_RELATIVE) reduce 159) ((T_NEW) reduce 159) ((T_NS_C) reduce 159) ((T_OBJECT_CAST) reduce 159) ((T_PRINT) reduce 159) ((T_READONLY) reduce 159) ((T_REQUIRE) reduce 159) ((T_REQUIRE_ONCE) reduce 159) ((T_RETURN) reduce 159) ((T_START_HEREDOC) reduce 159) ((T_STATIC) reduce 159) ((T_STRING) reduce 159) ((T_STRING_CAST) reduce 159) ((T_SWITCH) reduce 159) ((T_THROW) reduce 159) ((T_TRAIT) reduce 159) ((T_TRAIT_C) reduce 159) ((T_TRY) reduce 159) ((T_UNSET) reduce 159) ((T_UNSET_CAST) reduce 159) ((T_VARIABLE) reduce 159) ((T_WHILE) reduce 159) ((T_YIELD) reduce 159) ((T_YIELD_FROM) reduce 159) (("[") reduce 159) (("`") reduce 159) (("{") reduce 159) (("~") reduce 159)) 20697 ((("!") reduce 186) (("\"") reduce 186) (("$") reduce 186) (("(") reduce 186) (("+") reduce 186) (("-") reduce 186) ((";") reduce 186) (("@") reduce 186) ((T_ABSTRACT) reduce 186) ((T_ARRAY) reduce 186) ((T_ARRAY_CAST) reduce 186) ((T_ATTRIBUTE) reduce 186) ((T_BOOL_CAST) reduce 186) ((T_BREAK) reduce 186) ((T_CLASS) reduce 186) ((T_CLASS_C) reduce 186) ((T_CLONE) reduce 186) ((T_CONSTANT_ENCAPSED_STRING) reduce 186) ((T_CONTINUE) reduce 186) ((T_DEC) reduce 186) ((T_DECLARE) reduce 186) ((T_DIR) reduce 186) ((T_DNUMBER) reduce 186) ((T_DO) reduce 186) ((T_DOUBLE_CAST) reduce 186) ((T_ECHO) reduce 186) ((T_EMPTY) reduce 186) ((T_ENDFOREACH) reduce 186) ((T_ENUM) reduce 186) ((T_EVAL) reduce 186) ((T_EXIT) reduce 186) ((T_FILE) reduce 186) ((T_FINAL) reduce 186) ((T_FN) reduce 186) ((T_FOR) reduce 186) ((T_FOREACH) reduce 186) ((T_FUNCTION) reduce 186) ((T_FUNC_C) reduce 186) ((T_GLOBAL) reduce 186) ((T_GOTO) reduce 186) ((T_HALT_COMPILER) reduce 186) ((T_IF) reduce 186) ((T_INC) reduce 186) ((T_INCLUDE) reduce 186) ((T_INCLUDE_ONCE) reduce 186) ((T_INLINE_HTML) reduce 186) ((T_INTERFACE) reduce 186) ((T_INT_CAST) reduce 186) ((T_ISSET) reduce 186) ((T_LINE) reduce 186) ((T_LIST) reduce 186) ((T_LNUMBER) reduce 186) ((T_MATCH) reduce 186) ((T_METHOD_C) reduce 186) ((T_NAME_FULLY_QUALIFIED) reduce 186) ((T_NAME_QUALIFIED) reduce 186) ((T_NAME_RELATIVE) reduce 186) ((T_NEW) reduce 186) ((T_NS_C) reduce 186) ((T_OBJECT_CAST) reduce 186) ((T_PRINT) reduce 186) ((T_READONLY) reduce 186) ((T_REQUIRE) reduce 186) ((T_REQUIRE_ONCE) reduce 186) ((T_RETURN) reduce 186) ((T_START_HEREDOC) reduce 186) ((T_STATIC) reduce 186) ((T_STRING) reduce 186) ((T_STRING_CAST) reduce 186) ((T_SWITCH) reduce 186) ((T_THROW) reduce 186) ((T_TRAIT) reduce 186) ((T_TRAIT_C) reduce 186) ((T_TRY) reduce 186) ((T_UNSET) reduce 186) ((T_UNSET_CAST) reduce 186) ((T_VARIABLE) reduce 186) ((T_WHILE) reduce 186) ((T_YIELD) reduce 186) ((T_YIELD_FROM) reduce 186) (("[") reduce 186) (("`") reduce 186) (("{") reduce 186) (("~") reduce 186)) 20698 ((("!") reduce 143) (("\"") reduce 143) (("$") reduce 143) (("(") reduce 143) (("+") reduce 143) (("-") reduce 143) ((";") reduce 143) (("@") reduce 143) ((T_ABSTRACT) reduce 143) ((T_ARRAY) reduce 143) ((T_ARRAY_CAST) reduce 143) ((T_ATTRIBUTE) reduce 143) ((T_BOOL_CAST) reduce 143) ((T_BREAK) reduce 143) ((T_CLASS) reduce 143) ((T_CLASS_C) reduce 143) ((T_CLONE) reduce 143) ((T_CONSTANT_ENCAPSED_STRING) reduce 143) ((T_CONTINUE) reduce 143) ((T_DEC) reduce 143) ((T_DECLARE) reduce 143) ((T_DIR) reduce 143) ((T_DNUMBER) reduce 143) ((T_DO) reduce 143) ((T_DOUBLE_CAST) reduce 143) ((T_ECHO) reduce 143) ((T_EMPTY) reduce 143) ((T_ENDFOREACH) reduce 143) ((T_ENUM) reduce 143) ((T_EVAL) reduce 143) ((T_EXIT) reduce 143) ((T_FILE) reduce 143) ((T_FINAL) reduce 143) ((T_FN) reduce 143) ((T_FOR) reduce 143) ((T_FOREACH) reduce 143) ((T_FUNCTION) reduce 143) ((T_FUNC_C) reduce 143) ((T_GLOBAL) reduce 143) ((T_GOTO) reduce 143) ((T_HALT_COMPILER) reduce 143) ((T_IF) reduce 143) ((T_INC) reduce 143) ((T_INCLUDE) reduce 143) ((T_INCLUDE_ONCE) reduce 143) ((T_INLINE_HTML) reduce 143) ((T_INTERFACE) reduce 143) ((T_INT_CAST) reduce 143) ((T_ISSET) reduce 143) ((T_LINE) reduce 143) ((T_LIST) reduce 143) ((T_LNUMBER) reduce 143) ((T_MATCH) reduce 143) ((T_METHOD_C) reduce 143) ((T_NAME_FULLY_QUALIFIED) reduce 143) ((T_NAME_QUALIFIED) reduce 143) ((T_NAME_RELATIVE) reduce 143) ((T_NEW) reduce 143) ((T_NS_C) reduce 143) ((T_OBJECT_CAST) reduce 143) ((T_PRINT) reduce 143) ((T_READONLY) reduce 143) ((T_REQUIRE) reduce 143) ((T_REQUIRE_ONCE) reduce 143) ((T_RETURN) reduce 143) ((T_START_HEREDOC) reduce 143) ((T_STATIC) reduce 143) ((T_STRING) reduce 143) ((T_STRING_CAST) reduce 143) ((T_SWITCH) reduce 143) ((T_THROW) reduce 143) ((T_TRAIT) reduce 143) ((T_TRAIT_C) reduce 143) ((T_TRY) reduce 143) ((T_UNSET) reduce 143) ((T_UNSET_CAST) reduce 143) ((T_VARIABLE) reduce 143) ((T_WHILE) reduce 143) ((T_YIELD) reduce 143) ((T_YIELD_FROM) reduce 143) (("[") reduce 143) (("`") reduce 143) (("{") reduce 143) (("~") reduce 143)) 20701 ((("!") reduce 247) (("\"") reduce 247) (("$") reduce 247) (("(") reduce 247) (("+") reduce 247) (("-") reduce 247) ((";") reduce 247) (("@") reduce 247) ((T_ABSTRACT) reduce 247) ((T_ARRAY) reduce 247) ((T_ARRAY_CAST) reduce 247) ((T_ATTRIBUTE) reduce 247) ((T_BOOL_CAST) reduce 247) ((T_BREAK) reduce 247) ((T_CLASS) reduce 247) ((T_CLASS_C) reduce 247) ((T_CLONE) reduce 247) ((T_CONSTANT_ENCAPSED_STRING) reduce 247) ((T_CONTINUE) reduce 247) ((T_DEC) reduce 247) ((T_DECLARE) reduce 247) ((T_DIR) reduce 247) ((T_DNUMBER) reduce 247) ((T_DO) reduce 247) ((T_DOUBLE_CAST) reduce 247) ((T_ECHO) reduce 247) ((T_EMPTY) reduce 247) ((T_ENDFOREACH) reduce 247) ((T_ENUM) reduce 247) ((T_EVAL) reduce 247) ((T_EXIT) reduce 247) ((T_FILE) reduce 247) ((T_FINAL) reduce 247) ((T_FN) reduce 247) ((T_FOR) reduce 247) ((T_FOREACH) reduce 247) ((T_FUNCTION) reduce 247) ((T_FUNC_C) reduce 247) ((T_GLOBAL) reduce 247) ((T_GOTO) reduce 247) ((T_HALT_COMPILER) reduce 247) ((T_IF) reduce 247) ((T_INC) reduce 247) ((T_INCLUDE) reduce 247) ((T_INCLUDE_ONCE) reduce 247) ((T_INLINE_HTML) reduce 247) ((T_INTERFACE) reduce 247) ((T_INT_CAST) reduce 247) ((T_ISSET) reduce 247) ((T_LINE) reduce 247) ((T_LIST) reduce 247) ((T_LNUMBER) reduce 247) ((T_MATCH) reduce 247) ((T_METHOD_C) reduce 247) ((T_NAME_FULLY_QUALIFIED) reduce 247) ((T_NAME_QUALIFIED) reduce 247) ((T_NAME_RELATIVE) reduce 247) ((T_NEW) reduce 247) ((T_NS_C) reduce 247) ((T_OBJECT_CAST) reduce 247) ((T_PRINT) reduce 247) ((T_READONLY) reduce 247) ((T_REQUIRE) reduce 247) ((T_REQUIRE_ONCE) reduce 247) ((T_RETURN) reduce 247) ((T_START_HEREDOC) reduce 247) ((T_STATIC) reduce 247) ((T_STRING) reduce 247) ((T_STRING_CAST) reduce 247) ((T_SWITCH) reduce 247) ((T_THROW) reduce 247) ((T_TRAIT) reduce 247) ((T_TRAIT_C) reduce 247) ((T_TRY) reduce 247) ((T_UNSET) reduce 247) ((T_UNSET_CAST) reduce 247) ((T_VARIABLE) reduce 247) ((T_WHILE) reduce 247) ((T_YIELD) reduce 247) ((T_YIELD_FROM) reduce 247) (("[") reduce 247) (("`") reduce 247) (("{") reduce 247) (("~") reduce 247)) 20705 ((("!") reduce 248) (("\"") reduce 248) (("$") reduce 248) (("(") reduce 248) (("+") reduce 248) (("-") reduce 248) ((";") reduce 248) (("@") reduce 248) ((T_ABSTRACT) reduce 248) ((T_ARRAY) reduce 248) ((T_ARRAY_CAST) reduce 248) ((T_ATTRIBUTE) reduce 248) ((T_BOOL_CAST) reduce 248) ((T_BREAK) reduce 248) ((T_CLASS) reduce 248) ((T_CLASS_C) reduce 248) ((T_CLONE) reduce 248) ((T_CONSTANT_ENCAPSED_STRING) reduce 248) ((T_CONTINUE) reduce 248) ((T_DEC) reduce 248) ((T_DECLARE) reduce 248) ((T_DIR) reduce 248) ((T_DNUMBER) reduce 248) ((T_DO) reduce 248) ((T_DOUBLE_CAST) reduce 248) ((T_ECHO) reduce 248) ((T_EMPTY) reduce 248) ((T_ENDFOREACH) reduce 248) ((T_ENUM) reduce 248) ((T_EVAL) reduce 248) ((T_EXIT) reduce 248) ((T_FILE) reduce 248) ((T_FINAL) reduce 248) ((T_FN) reduce 248) ((T_FOR) reduce 248) ((T_FOREACH) reduce 248) ((T_FUNCTION) reduce 248) ((T_FUNC_C) reduce 248) ((T_GLOBAL) reduce 248) ((T_GOTO) reduce 248) ((T_HALT_COMPILER) reduce 248) ((T_IF) reduce 248) ((T_INC) reduce 248) ((T_INCLUDE) reduce 248) ((T_INCLUDE_ONCE) reduce 248) ((T_INLINE_HTML) reduce 248) ((T_INTERFACE) reduce 248) ((T_INT_CAST) reduce 248) ((T_ISSET) reduce 248) ((T_LINE) reduce 248) ((T_LIST) reduce 248) ((T_LNUMBER) reduce 248) ((T_MATCH) reduce 248) ((T_METHOD_C) reduce 248) ((T_NAME_FULLY_QUALIFIED) reduce 248) ((T_NAME_QUALIFIED) reduce 248) ((T_NAME_RELATIVE) reduce 248) ((T_NEW) reduce 248) ((T_NS_C) reduce 248) ((T_OBJECT_CAST) reduce 248) ((T_PRINT) reduce 248) ((T_READONLY) reduce 248) ((T_REQUIRE) reduce 248) ((T_REQUIRE_ONCE) reduce 248) ((T_RETURN) reduce 248) ((T_START_HEREDOC) reduce 248) ((T_STATIC) reduce 248) ((T_STRING) reduce 248) ((T_STRING_CAST) reduce 248) ((T_SWITCH) reduce 248) ((T_THROW) reduce 248) ((T_TRAIT) reduce 248) ((T_TRAIT_C) reduce 248) ((T_TRY) reduce 248) ((T_UNSET) reduce 248) ((T_UNSET_CAST) reduce 248) ((T_VARIABLE) reduce 248) ((T_WHILE) reduce 248) ((T_YIELD) reduce 248) ((T_YIELD_FROM) reduce 248) (("[") reduce 248) (("`") reduce 248) (("{") reduce 248) (("~") reduce 248)) 20710 ((("!") reduce 239) (("\"") reduce 239) (("$") reduce 239) (("(") reduce 239) (("+") reduce 239) (("-") reduce 239) ((";") reduce 239) (("@") reduce 239) ((T_ABSTRACT) reduce 239) ((T_ARRAY) reduce 239) ((T_ARRAY_CAST) reduce 239) ((T_ATTRIBUTE) reduce 239) ((T_BOOL_CAST) reduce 239) ((T_BREAK) reduce 239) ((T_CLASS) reduce 239) ((T_CLASS_C) reduce 239) ((T_CLONE) reduce 239) ((T_CONSTANT_ENCAPSED_STRING) reduce 239) ((T_CONTINUE) reduce 239) ((T_DEC) reduce 239) ((T_DECLARE) reduce 239) ((T_DIR) reduce 239) ((T_DNUMBER) reduce 239) ((T_DO) reduce 239) ((T_DOUBLE_CAST) reduce 239) ((T_ECHO) reduce 239) ((T_EMPTY) reduce 239) ((T_ENDFOREACH) reduce 239) ((T_ENUM) reduce 239) ((T_EVAL) reduce 239) ((T_EXIT) reduce 239) ((T_FILE) reduce 239) ((T_FINAL) reduce 239) ((T_FN) reduce 239) ((T_FOR) reduce 239) ((T_FOREACH) reduce 239) ((T_FUNCTION) reduce 239) ((T_FUNC_C) reduce 239) ((T_GLOBAL) reduce 239) ((T_GOTO) reduce 239) ((T_HALT_COMPILER) reduce 239) ((T_IF) reduce 239) ((T_INC) reduce 239) ((T_INCLUDE) reduce 239) ((T_INCLUDE_ONCE) reduce 239) ((T_INLINE_HTML) reduce 239) ((T_INTERFACE) reduce 239) ((T_INT_CAST) reduce 239) ((T_ISSET) reduce 239) ((T_LINE) reduce 239) ((T_LIST) reduce 239) ((T_LNUMBER) reduce 239) ((T_MATCH) reduce 239) ((T_METHOD_C) reduce 239) ((T_NAME_FULLY_QUALIFIED) reduce 239) ((T_NAME_QUALIFIED) reduce 239) ((T_NAME_RELATIVE) reduce 239) ((T_NEW) reduce 239) ((T_NS_C) reduce 239) ((T_OBJECT_CAST) reduce 239) ((T_PRINT) reduce 239) ((T_READONLY) reduce 239) ((T_REQUIRE) reduce 239) ((T_REQUIRE_ONCE) reduce 239) ((T_RETURN) reduce 239) ((T_START_HEREDOC) reduce 239) ((T_STATIC) reduce 239) ((T_STRING) reduce 239) ((T_STRING_CAST) reduce 239) ((T_SWITCH) reduce 239) ((T_THROW) reduce 239) ((T_TRAIT) reduce 239) ((T_TRAIT_C) reduce 239) ((T_TRY) reduce 239) ((T_UNSET) reduce 239) ((T_UNSET_CAST) reduce 239) ((T_VARIABLE) reduce 239) ((T_WHILE) reduce 239) ((T_YIELD) reduce 239) ((T_YIELD_FROM) reduce 239) (("[") reduce 239) (("`") reduce 239) (("{") reduce 239) (("~") reduce 239)) 20711 ((("!") reduce 148) (("\"") reduce 148) (("$") reduce 148) (("(") reduce 148) (("+") reduce 148) (("-") reduce 148) ((";") reduce 148) (("@") reduce 148) ((T_ABSTRACT) reduce 148) ((T_ARRAY) reduce 148) ((T_ARRAY_CAST) reduce 148) ((T_ATTRIBUTE) reduce 148) ((T_BOOL_CAST) reduce 148) ((T_BREAK) reduce 148) ((T_CLASS) reduce 148) ((T_CLASS_C) reduce 148) ((T_CLONE) reduce 148) ((T_CONSTANT_ENCAPSED_STRING) reduce 148) ((T_CONTINUE) reduce 148) ((T_DEC) reduce 148) ((T_DECLARE) reduce 148) ((T_DIR) reduce 148) ((T_DNUMBER) reduce 148) ((T_DO) reduce 148) ((T_DOUBLE_CAST) reduce 148) ((T_ECHO) reduce 148) ((T_EMPTY) reduce 148) ((T_ENDFOREACH) reduce 148) ((T_ENUM) reduce 148) ((T_EVAL) reduce 148) ((T_EXIT) reduce 148) ((T_FILE) reduce 148) ((T_FINAL) reduce 148) ((T_FN) reduce 148) ((T_FOR) reduce 148) ((T_FOREACH) reduce 148) ((T_FUNCTION) reduce 148) ((T_FUNC_C) reduce 148) ((T_GLOBAL) reduce 148) ((T_GOTO) reduce 148) ((T_HALT_COMPILER) reduce 148) ((T_IF) reduce 148) ((T_INC) reduce 148) ((T_INCLUDE) reduce 148) ((T_INCLUDE_ONCE) reduce 148) ((T_INLINE_HTML) reduce 148) ((T_INTERFACE) reduce 148) ((T_INT_CAST) reduce 148) ((T_ISSET) reduce 148) ((T_LINE) reduce 148) ((T_LIST) reduce 148) ((T_LNUMBER) reduce 148) ((T_MATCH) reduce 148) ((T_METHOD_C) reduce 148) ((T_NAME_FULLY_QUALIFIED) reduce 148) ((T_NAME_QUALIFIED) reduce 148) ((T_NAME_RELATIVE) reduce 148) ((T_NEW) reduce 148) ((T_NS_C) reduce 148) ((T_OBJECT_CAST) reduce 148) ((T_PRINT) reduce 148) ((T_READONLY) reduce 148) ((T_REQUIRE) reduce 148) ((T_REQUIRE_ONCE) reduce 148) ((T_RETURN) reduce 148) ((T_START_HEREDOC) reduce 148) ((T_STATIC) reduce 148) ((T_STRING) reduce 148) ((T_STRING_CAST) reduce 148) ((T_SWITCH) reduce 148) ((T_THROW) reduce 148) ((T_TRAIT) reduce 148) ((T_TRAIT_C) reduce 148) ((T_TRY) reduce 148) ((T_UNSET) reduce 148) ((T_UNSET_CAST) reduce 148) ((T_VARIABLE) reduce 148) ((T_WHILE) reduce 148) ((T_YIELD) reduce 148) ((T_YIELD_FROM) reduce 148) (("[") reduce 148) (("`") reduce 148) (("{") reduce 148) (("~") reduce 148)) 20714 ((("!") reduce 240) (("\"") reduce 240) (("$") reduce 240) (("(") reduce 240) (("+") reduce 240) (("-") reduce 240) ((";") reduce 240) (("@") reduce 240) ((T_ABSTRACT) reduce 240) ((T_ARRAY) reduce 240) ((T_ARRAY_CAST) reduce 240) ((T_ATTRIBUTE) reduce 240) ((T_BOOL_CAST) reduce 240) ((T_BREAK) reduce 240) ((T_CLASS) reduce 240) ((T_CLASS_C) reduce 240) ((T_CLONE) reduce 240) ((T_CONSTANT_ENCAPSED_STRING) reduce 240) ((T_CONTINUE) reduce 240) ((T_DEC) reduce 240) ((T_DECLARE) reduce 240) ((T_DIR) reduce 240) ((T_DNUMBER) reduce 240) ((T_DO) reduce 240) ((T_DOUBLE_CAST) reduce 240) ((T_ECHO) reduce 240) ((T_EMPTY) reduce 240) ((T_ENDFOREACH) reduce 240) ((T_ENUM) reduce 240) ((T_EVAL) reduce 240) ((T_EXIT) reduce 240) ((T_FILE) reduce 240) ((T_FINAL) reduce 240) ((T_FN) reduce 240) ((T_FOR) reduce 240) ((T_FOREACH) reduce 240) ((T_FUNCTION) reduce 240) ((T_FUNC_C) reduce 240) ((T_GLOBAL) reduce 240) ((T_GOTO) reduce 240) ((T_HALT_COMPILER) reduce 240) ((T_IF) reduce 240) ((T_INC) reduce 240) ((T_INCLUDE) reduce 240) ((T_INCLUDE_ONCE) reduce 240) ((T_INLINE_HTML) reduce 240) ((T_INTERFACE) reduce 240) ((T_INT_CAST) reduce 240) ((T_ISSET) reduce 240) ((T_LINE) reduce 240) ((T_LIST) reduce 240) ((T_LNUMBER) reduce 240) ((T_MATCH) reduce 240) ((T_METHOD_C) reduce 240) ((T_NAME_FULLY_QUALIFIED) reduce 240) ((T_NAME_QUALIFIED) reduce 240) ((T_NAME_RELATIVE) reduce 240) ((T_NEW) reduce 240) ((T_NS_C) reduce 240) ((T_OBJECT_CAST) reduce 240) ((T_PRINT) reduce 240) ((T_READONLY) reduce 240) ((T_REQUIRE) reduce 240) ((T_REQUIRE_ONCE) reduce 240) ((T_RETURN) reduce 240) ((T_START_HEREDOC) reduce 240) ((T_STATIC) reduce 240) ((T_STRING) reduce 240) ((T_STRING_CAST) reduce 240) ((T_SWITCH) reduce 240) ((T_THROW) reduce 240) ((T_TRAIT) reduce 240) ((T_TRAIT_C) reduce 240) ((T_TRY) reduce 240) ((T_UNSET) reduce 240) ((T_UNSET_CAST) reduce 240) ((T_VARIABLE) reduce 240) ((T_WHILE) reduce 240) ((T_YIELD) reduce 240) ((T_YIELD_FROM) reduce 240) (("[") reduce 240) (("`") reduce 240) (("{") reduce 240) (("~") reduce 240)) 20719 ((("!") reduce 160) (("\"") reduce 160) (("$") reduce 160) (("(") reduce 160) (("+") reduce 160) (("-") reduce 160) ((";") reduce 160) (("@") reduce 160) ((T_ABSTRACT) reduce 160) ((T_ARRAY) reduce 160) ((T_ARRAY_CAST) reduce 160) ((T_ATTRIBUTE) reduce 160) ((T_BOOL_CAST) reduce 160) ((T_BREAK) reduce 160) ((T_CLASS) reduce 160) ((T_CLASS_C) reduce 160) ((T_CLONE) reduce 160) ((T_CONSTANT_ENCAPSED_STRING) reduce 160) ((T_CONTINUE) reduce 160) ((T_DEC) reduce 160) ((T_DECLARE) reduce 160) ((T_DIR) reduce 160) ((T_DNUMBER) reduce 160) ((T_DO) reduce 160) ((T_DOUBLE_CAST) reduce 160) ((T_ECHO) reduce 160) ((T_EMPTY) reduce 160) ((T_ENDFOREACH) reduce 160) ((T_ENUM) reduce 160) ((T_EVAL) reduce 160) ((T_EXIT) reduce 160) ((T_FILE) reduce 160) ((T_FINAL) reduce 160) ((T_FN) reduce 160) ((T_FOR) reduce 160) ((T_FOREACH) reduce 160) ((T_FUNCTION) reduce 160) ((T_FUNC_C) reduce 160) ((T_GLOBAL) reduce 160) ((T_GOTO) reduce 160) ((T_HALT_COMPILER) reduce 160) ((T_IF) reduce 160) ((T_INC) reduce 160) ((T_INCLUDE) reduce 160) ((T_INCLUDE_ONCE) reduce 160) ((T_INLINE_HTML) reduce 160) ((T_INTERFACE) reduce 160) ((T_INT_CAST) reduce 160) ((T_ISSET) reduce 160) ((T_LINE) reduce 160) ((T_LIST) reduce 160) ((T_LNUMBER) reduce 160) ((T_MATCH) reduce 160) ((T_METHOD_C) reduce 160) ((T_NAME_FULLY_QUALIFIED) reduce 160) ((T_NAME_QUALIFIED) reduce 160) ((T_NAME_RELATIVE) reduce 160) ((T_NEW) reduce 160) ((T_NS_C) reduce 160) ((T_OBJECT_CAST) reduce 160) ((T_PRINT) reduce 160) ((T_READONLY) reduce 160) ((T_REQUIRE) reduce 160) ((T_REQUIRE_ONCE) reduce 160) ((T_RETURN) reduce 160) ((T_START_HEREDOC) reduce 160) ((T_STATIC) reduce 160) ((T_STRING) reduce 160) ((T_STRING_CAST) reduce 160) ((T_SWITCH) reduce 160) ((T_THROW) reduce 160) ((T_TRAIT) reduce 160) ((T_TRAIT_C) reduce 160) ((T_TRY) reduce 160) ((T_UNSET) reduce 160) ((T_UNSET_CAST) reduce 160) ((T_VARIABLE) reduce 160) ((T_WHILE) reduce 160) ((T_YIELD) reduce 160) ((T_YIELD_FROM) reduce 160) (("[") reduce 160) (("`") reduce 160) (("{") reduce 160) (("~") reduce 160)) 20722 ((("!") reduce 168) (("\"") reduce 168) (("$") reduce 168) (("(") reduce 168) (("+") reduce 168) (("-") reduce 168) ((";") reduce 168) (("@") reduce 168) ((T_ABSTRACT) reduce 168) ((T_ARRAY) reduce 168) ((T_ARRAY_CAST) reduce 168) ((T_ATTRIBUTE) reduce 168) ((T_BOOL_CAST) reduce 168) ((T_BREAK) reduce 168) ((T_CATCH) reduce 168) ((T_CLASS) reduce 168) ((T_CLASS_C) reduce 168) ((T_CLONE) reduce 168) ((T_CONSTANT_ENCAPSED_STRING) reduce 168) ((T_CONTINUE) reduce 168) ((T_DEC) reduce 168) ((T_DECLARE) reduce 168) ((T_DIR) reduce 168) ((T_DNUMBER) reduce 168) ((T_DO) reduce 168) ((T_DOUBLE_CAST) reduce 168) ((T_ECHO) reduce 168) ((T_EMPTY) reduce 168) ((T_ENDFOREACH) reduce 168) ((T_ENUM) reduce 168) ((T_EVAL) reduce 168) ((T_EXIT) reduce 168) ((T_FILE) reduce 168) ((T_FINAL) reduce 168) ((T_FINALLY) reduce 168) ((T_FN) reduce 168) ((T_FOR) reduce 168) ((T_FOREACH) reduce 168) ((T_FUNCTION) reduce 168) ((T_FUNC_C) reduce 168) ((T_GLOBAL) reduce 168) ((T_GOTO) reduce 168) ((T_HALT_COMPILER) reduce 168) ((T_IF) reduce 168) ((T_INC) reduce 168) ((T_INCLUDE) reduce 168) ((T_INCLUDE_ONCE) reduce 168) ((T_INLINE_HTML) reduce 168) ((T_INTERFACE) reduce 168) ((T_INT_CAST) reduce 168) ((T_ISSET) reduce 168) ((T_LINE) reduce 168) ((T_LIST) reduce 168) ((T_LNUMBER) reduce 168) ((T_MATCH) reduce 168) ((T_METHOD_C) reduce 168) ((T_NAME_FULLY_QUALIFIED) reduce 168) ((T_NAME_QUALIFIED) reduce 168) ((T_NAME_RELATIVE) reduce 168) ((T_NEW) reduce 168) ((T_NS_C) reduce 168) ((T_OBJECT_CAST) reduce 168) ((T_PRINT) reduce 168) ((T_READONLY) reduce 168) ((T_REQUIRE) reduce 168) ((T_REQUIRE_ONCE) reduce 168) ((T_RETURN) reduce 168) ((T_START_HEREDOC) reduce 168) ((T_STATIC) reduce 168) ((T_STRING) reduce 168) ((T_STRING_CAST) reduce 168) ((T_SWITCH) reduce 168) ((T_THROW) reduce 168) ((T_TRAIT) reduce 168) ((T_TRAIT_C) reduce 168) ((T_TRY) reduce 168) ((T_UNSET) reduce 168) ((T_UNSET_CAST) reduce 168) ((T_VARIABLE) reduce 168) ((T_WHILE) reduce 168) ((T_YIELD) reduce 168) ((T_YIELD_FROM) reduce 168) (("[") reduce 168) (("`") reduce 168) (("{") reduce 168) (("~") reduce 168)) 20723 ((("!") reduce 174) (("\"") reduce 174) (("$") reduce 174) (("(") reduce 174) (("+") reduce 174) (("-") reduce 174) ((";") reduce 174) (("@") reduce 174) ((T_ABSTRACT) reduce 174) ((T_ARRAY) reduce 174) ((T_ARRAY_CAST) reduce 174) ((T_ATTRIBUTE) reduce 174) ((T_BOOL_CAST) reduce 174) ((T_BREAK) reduce 174) ((T_CATCH) shift) ((T_CLASS) reduce 174) ((T_CLASS_C) reduce 174) ((T_CLONE) reduce 174) ((T_CONSTANT_ENCAPSED_STRING) reduce 174) ((T_CONTINUE) reduce 174) ((T_DEC) reduce 174) ((T_DECLARE) reduce 174) ((T_DIR) reduce 174) ((T_DNUMBER) reduce 174) ((T_DO) reduce 174) ((T_DOUBLE_CAST) reduce 174) ((T_ECHO) reduce 174) ((T_EMPTY) reduce 174) ((T_ENDFOREACH) reduce 174) ((T_ENUM) reduce 174) ((T_EVAL) reduce 174) ((T_EXIT) reduce 174) ((T_FILE) reduce 174) ((T_FINAL) reduce 174) ((T_FINALLY) shift) ((T_FN) reduce 174) ((T_FOR) reduce 174) ((T_FOREACH) reduce 174) ((T_FUNCTION) reduce 174) ((T_FUNC_C) reduce 174) ((T_GLOBAL) reduce 174) ((T_GOTO) reduce 174) ((T_HALT_COMPILER) reduce 174) ((T_IF) reduce 174) ((T_INC) reduce 174) ((T_INCLUDE) reduce 174) ((T_INCLUDE_ONCE) reduce 174) ((T_INLINE_HTML) reduce 174) ((T_INTERFACE) reduce 174) ((T_INT_CAST) reduce 174) ((T_ISSET) reduce 174) ((T_LINE) reduce 174) ((T_LIST) reduce 174) ((T_LNUMBER) reduce 174) ((T_MATCH) reduce 174) ((T_METHOD_C) reduce 174) ((T_NAME_FULLY_QUALIFIED) reduce 174) ((T_NAME_QUALIFIED) reduce 174) ((T_NAME_RELATIVE) reduce 174) ((T_NEW) reduce 174) ((T_NS_C) reduce 174) ((T_OBJECT_CAST) reduce 174) ((T_PRINT) reduce 174) ((T_READONLY) reduce 174) ((T_REQUIRE) reduce 174) ((T_REQUIRE_ONCE) reduce 174) ((T_RETURN) reduce 174) ((T_START_HEREDOC) reduce 174) ((T_STATIC) reduce 174) ((T_STRING) reduce 174) ((T_STRING_CAST) reduce 174) ((T_SWITCH) reduce 174) ((T_THROW) reduce 174) ((T_TRAIT) reduce 174) ((T_TRAIT_C) reduce 174) ((T_TRY) reduce 174) ((T_UNSET) reduce 174) ((T_UNSET_CAST) reduce 174) ((T_VARIABLE) reduce 174) ((T_WHILE) reduce 174) ((T_YIELD) reduce 174) ((T_YIELD_FROM) reduce 174) (("[") reduce 174) (("`") reduce 174) (("{") reduce 174) (("~") reduce 174)) 20726 ((("!") reduce 165) (("\"") reduce 165) (("$") reduce 165) (("(") reduce 165) (("+") reduce 165) (("-") reduce 165) ((";") reduce 165) (("@") reduce 165) ((T_ABSTRACT) reduce 165) ((T_ARRAY) reduce 165) ((T_ARRAY_CAST) reduce 165) ((T_ATTRIBUTE) reduce 165) ((T_BOOL_CAST) reduce 165) ((T_BREAK) reduce 165) ((T_CLASS) reduce 165) ((T_CLASS_C) reduce 165) ((T_CLONE) reduce 165) ((T_CONSTANT_ENCAPSED_STRING) reduce 165) ((T_CONTINUE) reduce 165) ((T_DEC) reduce 165) ((T_DECLARE) reduce 165) ((T_DIR) reduce 165) ((T_DNUMBER) reduce 165) ((T_DO) reduce 165) ((T_DOUBLE_CAST) reduce 165) ((T_ECHO) reduce 165) ((T_EMPTY) reduce 165) ((T_ENDFOREACH) reduce 165) ((T_ENUM) reduce 165) ((T_EVAL) reduce 165) ((T_EXIT) reduce 165) ((T_FILE) reduce 165) ((T_FINAL) reduce 165) ((T_FN) reduce 165) ((T_FOR) reduce 165) ((T_FOREACH) reduce 165) ((T_FUNCTION) reduce 165) ((T_FUNC_C) reduce 165) ((T_GLOBAL) reduce 165) ((T_GOTO) reduce 165) ((T_HALT_COMPILER) reduce 165) ((T_IF) reduce 165) ((T_INC) reduce 165) ((T_INCLUDE) reduce 165) ((T_INCLUDE_ONCE) reduce 165) ((T_INLINE_HTML) reduce 165) ((T_INTERFACE) reduce 165) ((T_INT_CAST) reduce 165) ((T_ISSET) reduce 165) ((T_LINE) reduce 165) ((T_LIST) reduce 165) ((T_LNUMBER) reduce 165) ((T_MATCH) reduce 165) ((T_METHOD_C) reduce 165) ((T_NAME_FULLY_QUALIFIED) reduce 165) ((T_NAME_QUALIFIED) reduce 165) ((T_NAME_RELATIVE) reduce 165) ((T_NEW) reduce 165) ((T_NS_C) reduce 165) ((T_OBJECT_CAST) reduce 165) ((T_PRINT) reduce 165) ((T_READONLY) reduce 165) ((T_REQUIRE) reduce 165) ((T_REQUIRE_ONCE) reduce 165) ((T_RETURN) reduce 165) ((T_START_HEREDOC) reduce 165) ((T_STATIC) reduce 165) ((T_STRING) reduce 165) ((T_STRING_CAST) reduce 165) ((T_SWITCH) reduce 165) ((T_THROW) reduce 165) ((T_TRAIT) reduce 165) ((T_TRAIT_C) reduce 165) ((T_TRY) reduce 165) ((T_UNSET) reduce 165) ((T_UNSET_CAST) reduce 165) ((T_VARIABLE) reduce 165) ((T_WHILE) reduce 165) ((T_YIELD) reduce 165) ((T_YIELD_FROM) reduce 165) (("[") reduce 165) (("`") reduce 165) (("{") reduce 165) (("~") reduce 165)) 20729 ((("!") reduce 175) (("\"") reduce 175) (("$") reduce 175) (("(") reduce 175) (("+") reduce 175) (("-") reduce 175) ((";") reduce 175) (("@") reduce 175) ((T_ABSTRACT) reduce 175) ((T_ARRAY) reduce 175) ((T_ARRAY_CAST) reduce 175) ((T_ATTRIBUTE) reduce 175) ((T_BOOL_CAST) reduce 175) ((T_BREAK) reduce 175) ((T_CLASS) reduce 175) ((T_CLASS_C) reduce 175) ((T_CLONE) reduce 175) ((T_CONSTANT_ENCAPSED_STRING) reduce 175) ((T_CONTINUE) reduce 175) ((T_DEC) reduce 175) ((T_DECLARE) reduce 175) ((T_DIR) reduce 175) ((T_DNUMBER) reduce 175) ((T_DO) reduce 175) ((T_DOUBLE_CAST) reduce 175) ((T_ECHO) reduce 175) ((T_EMPTY) reduce 175) ((T_ENDFOREACH) reduce 175) ((T_ENUM) reduce 175) ((T_EVAL) reduce 175) ((T_EXIT) reduce 175) ((T_FILE) reduce 175) ((T_FINAL) reduce 175) ((T_FN) reduce 175) ((T_FOR) reduce 175) ((T_FOREACH) reduce 175) ((T_FUNCTION) reduce 175) ((T_FUNC_C) reduce 175) ((T_GLOBAL) reduce 175) ((T_GOTO) reduce 175) ((T_HALT_COMPILER) reduce 175) ((T_IF) reduce 175) ((T_INC) reduce 175) ((T_INCLUDE) reduce 175) ((T_INCLUDE_ONCE) reduce 175) ((T_INLINE_HTML) reduce 175) ((T_INTERFACE) reduce 175) ((T_INT_CAST) reduce 175) ((T_ISSET) reduce 175) ((T_LINE) reduce 175) ((T_LIST) reduce 175) ((T_LNUMBER) reduce 175) ((T_MATCH) reduce 175) ((T_METHOD_C) reduce 175) ((T_NAME_FULLY_QUALIFIED) reduce 175) ((T_NAME_QUALIFIED) reduce 175) ((T_NAME_RELATIVE) reduce 175) ((T_NEW) reduce 175) ((T_NS_C) reduce 175) ((T_OBJECT_CAST) reduce 175) ((T_PRINT) reduce 175) ((T_READONLY) reduce 175) ((T_REQUIRE) reduce 175) ((T_REQUIRE_ONCE) reduce 175) ((T_RETURN) reduce 175) ((T_START_HEREDOC) reduce 175) ((T_STATIC) reduce 175) ((T_STRING) reduce 175) ((T_STRING_CAST) reduce 175) ((T_SWITCH) reduce 175) ((T_THROW) reduce 175) ((T_TRAIT) reduce 175) ((T_TRAIT_C) reduce 175) ((T_TRY) reduce 175) ((T_UNSET) reduce 175) ((T_UNSET_CAST) reduce 175) ((T_VARIABLE) reduce 175) ((T_WHILE) reduce 175) ((T_YIELD) reduce 175) ((T_YIELD_FROM) reduce 175) (("[") reduce 175) (("`") reduce 175) (("{") reduce 175) (("~") reduce 175)) 20736 ((("!") reduce 169) (("\"") reduce 169) (("$") reduce 169) (("(") reduce 169) (("+") reduce 169) (("-") reduce 169) ((";") reduce 169) (("@") reduce 169) ((T_ABSTRACT) reduce 169) ((T_ARRAY) reduce 169) ((T_ARRAY_CAST) reduce 169) ((T_ATTRIBUTE) reduce 169) ((T_BOOL_CAST) reduce 169) ((T_BREAK) reduce 169) ((T_CATCH) reduce 169) ((T_CLASS) reduce 169) ((T_CLASS_C) reduce 169) ((T_CLONE) reduce 169) ((T_CONSTANT_ENCAPSED_STRING) reduce 169) ((T_CONTINUE) reduce 169) ((T_DEC) reduce 169) ((T_DECLARE) reduce 169) ((T_DIR) reduce 169) ((T_DNUMBER) reduce 169) ((T_DO) reduce 169) ((T_DOUBLE_CAST) reduce 169) ((T_ECHO) reduce 169) ((T_EMPTY) reduce 169) ((T_ENDFOREACH) reduce 169) ((T_ENUM) reduce 169) ((T_EVAL) reduce 169) ((T_EXIT) reduce 169) ((T_FILE) reduce 169) ((T_FINAL) reduce 169) ((T_FINALLY) reduce 169) ((T_FN) reduce 169) ((T_FOR) reduce 169) ((T_FOREACH) reduce 169) ((T_FUNCTION) reduce 169) ((T_FUNC_C) reduce 169) ((T_GLOBAL) reduce 169) ((T_GOTO) reduce 169) ((T_HALT_COMPILER) reduce 169) ((T_IF) reduce 169) ((T_INC) reduce 169) ((T_INCLUDE) reduce 169) ((T_INCLUDE_ONCE) reduce 169) ((T_INLINE_HTML) reduce 169) ((T_INTERFACE) reduce 169) ((T_INT_CAST) reduce 169) ((T_ISSET) reduce 169) ((T_LINE) reduce 169) ((T_LIST) reduce 169) ((T_LNUMBER) reduce 169) ((T_MATCH) reduce 169) ((T_METHOD_C) reduce 169) ((T_NAME_FULLY_QUALIFIED) reduce 169) ((T_NAME_QUALIFIED) reduce 169) ((T_NAME_RELATIVE) reduce 169) ((T_NEW) reduce 169) ((T_NS_C) reduce 169) ((T_OBJECT_CAST) reduce 169) ((T_PRINT) reduce 169) ((T_READONLY) reduce 169) ((T_REQUIRE) reduce 169) ((T_REQUIRE_ONCE) reduce 169) ((T_RETURN) reduce 169) ((T_START_HEREDOC) reduce 169) ((T_STATIC) reduce 169) ((T_STRING) reduce 169) ((T_STRING_CAST) reduce 169) ((T_SWITCH) reduce 169) ((T_THROW) reduce 169) ((T_TRAIT) reduce 169) ((T_TRAIT_C) reduce 169) ((T_TRY) reduce 169) ((T_UNSET) reduce 169) ((T_UNSET_CAST) reduce 169) ((T_VARIABLE) reduce 169) ((T_WHILE) reduce 169) ((T_YIELD) reduce 169) ((T_YIELD_FROM) reduce 169) (("[") reduce 169) (("`") reduce 169) (("{") reduce 169) (("~") reduce 169)) 20741 ((("!") reduce 197) (("\"") reduce 197) (("$") reduce 197) (("(") reduce 197) (("+") reduce 197) (("-") reduce 197) ((";") reduce 197) (("@") reduce 197) ((T_ABSTRACT) reduce 197) ((T_ARRAY) reduce 197) ((T_ARRAY_CAST) reduce 197) ((T_ATTRIBUTE) reduce 197) ((T_BOOL_CAST) reduce 197) ((T_BREAK) reduce 197) ((T_CLASS) reduce 197) ((T_CLASS_C) reduce 197) ((T_CLONE) reduce 197) ((T_CONSTANT_ENCAPSED_STRING) reduce 197) ((T_CONTINUE) reduce 197) ((T_DEC) reduce 197) ((T_DECLARE) reduce 197) ((T_DIR) reduce 197) ((T_DNUMBER) reduce 197) ((T_DO) reduce 197) ((T_DOUBLE_CAST) reduce 197) ((T_ECHO) reduce 197) ((T_EMPTY) reduce 197) ((T_ENDFOREACH) reduce 197) ((T_ENUM) reduce 197) ((T_EVAL) reduce 197) ((T_EXIT) reduce 197) ((T_FILE) reduce 197) ((T_FINAL) reduce 197) ((T_FN) reduce 197) ((T_FOR) reduce 197) ((T_FOREACH) reduce 197) ((T_FUNCTION) reduce 197) ((T_FUNC_C) reduce 197) ((T_GLOBAL) reduce 197) ((T_GOTO) reduce 197) ((T_HALT_COMPILER) reduce 197) ((T_IF) reduce 197) ((T_INC) reduce 197) ((T_INCLUDE) reduce 197) ((T_INCLUDE_ONCE) reduce 197) ((T_INLINE_HTML) reduce 197) ((T_INTERFACE) reduce 197) ((T_INT_CAST) reduce 197) ((T_ISSET) reduce 197) ((T_LINE) reduce 197) ((T_LIST) reduce 197) ((T_LNUMBER) reduce 197) ((T_MATCH) reduce 197) ((T_METHOD_C) reduce 197) ((T_NAME_FULLY_QUALIFIED) reduce 197) ((T_NAME_QUALIFIED) reduce 197) ((T_NAME_RELATIVE) reduce 197) ((T_NEW) reduce 197) ((T_NS_C) reduce 197) ((T_OBJECT_CAST) reduce 197) ((T_PRINT) reduce 197) ((T_READONLY) reduce 197) ((T_REQUIRE) reduce 197) ((T_REQUIRE_ONCE) reduce 197) ((T_RETURN) reduce 197) ((T_START_HEREDOC) reduce 197) ((T_STATIC) reduce 197) ((T_STRING) reduce 197) ((T_STRING_CAST) reduce 197) ((T_SWITCH) reduce 197) ((T_THROW) reduce 197) ((T_TRAIT) reduce 197) ((T_TRAIT_C) reduce 197) ((T_TRY) reduce 197) ((T_UNSET) reduce 197) ((T_UNSET_CAST) reduce 197) ((T_VARIABLE) reduce 197) ((T_WHILE) reduce 197) ((T_YIELD) reduce 197) ((T_YIELD_FROM) reduce 197) (("[") reduce 197) (("`") reduce 197) (("{") reduce 197) (("~") reduce 197)) 20746 ((("!") reduce 151) (("\"") reduce 151) (("$") reduce 151) (("(") reduce 151) (("+") reduce 151) (("-") reduce 151) ((";") reduce 151) (("@") reduce 151) ((T_ABSTRACT) reduce 151) ((T_ARRAY) reduce 151) ((T_ARRAY_CAST) reduce 151) ((T_ATTRIBUTE) reduce 151) ((T_BOOL_CAST) reduce 151) ((T_BREAK) reduce 151) ((T_CLASS) reduce 151) ((T_CLASS_C) reduce 151) ((T_CLONE) reduce 151) ((T_CONSTANT_ENCAPSED_STRING) reduce 151) ((T_CONTINUE) reduce 151) ((T_DEC) reduce 151) ((T_DECLARE) reduce 151) ((T_DIR) reduce 151) ((T_DNUMBER) reduce 151) ((T_DO) reduce 151) ((T_DOUBLE_CAST) reduce 151) ((T_ECHO) reduce 151) ((T_EMPTY) reduce 151) ((T_ENDFOREACH) reduce 151) ((T_ENUM) reduce 151) ((T_EVAL) reduce 151) ((T_EXIT) reduce 151) ((T_FILE) reduce 151) ((T_FINAL) reduce 151) ((T_FN) reduce 151) ((T_FOR) reduce 151) ((T_FOREACH) reduce 151) ((T_FUNCTION) reduce 151) ((T_FUNC_C) reduce 151) ((T_GLOBAL) reduce 151) ((T_GOTO) reduce 151) ((T_HALT_COMPILER) reduce 151) ((T_IF) reduce 151) ((T_INC) reduce 151) ((T_INCLUDE) reduce 151) ((T_INCLUDE_ONCE) reduce 151) ((T_INLINE_HTML) reduce 151) ((T_INTERFACE) reduce 151) ((T_INT_CAST) reduce 151) ((T_ISSET) reduce 151) ((T_LINE) reduce 151) ((T_LIST) reduce 151) ((T_LNUMBER) reduce 151) ((T_MATCH) reduce 151) ((T_METHOD_C) reduce 151) ((T_NAME_FULLY_QUALIFIED) reduce 151) ((T_NAME_QUALIFIED) reduce 151) ((T_NAME_RELATIVE) reduce 151) ((T_NEW) reduce 151) ((T_NS_C) reduce 151) ((T_OBJECT_CAST) reduce 151) ((T_PRINT) reduce 151) ((T_READONLY) reduce 151) ((T_REQUIRE) reduce 151) ((T_REQUIRE_ONCE) reduce 151) ((T_RETURN) reduce 151) ((T_START_HEREDOC) reduce 151) ((T_STATIC) reduce 151) ((T_STRING) reduce 151) ((T_STRING_CAST) reduce 151) ((T_SWITCH) reduce 151) ((T_THROW) reduce 151) ((T_TRAIT) reduce 151) ((T_TRAIT_C) reduce 151) ((T_TRY) reduce 151) ((T_UNSET) reduce 151) ((T_UNSET_CAST) reduce 151) ((T_VARIABLE) reduce 151) ((T_WHILE) reduce 151) ((T_YIELD) reduce 151) ((T_YIELD_FROM) reduce 151) (("[") reduce 151) (("`") reduce 151) (("{") reduce 151) (("~") reduce 151)) 20750 ((("!") reduce 221) (("\"") reduce 221) (("$") reduce 221) (("(") reduce 221) (("+") reduce 221) (("-") reduce 221) ((";") reduce 221) (("@") reduce 221) ((T_ABSTRACT) reduce 221) ((T_ARRAY) reduce 221) ((T_ARRAY_CAST) reduce 221) ((T_ATTRIBUTE) reduce 221) ((T_BOOL_CAST) reduce 221) ((T_BREAK) reduce 221) ((T_CLASS) reduce 221) ((T_CLASS_C) reduce 221) ((T_CLONE) reduce 221) ((T_CONSTANT_ENCAPSED_STRING) reduce 221) ((T_CONTINUE) reduce 221) ((T_DEC) reduce 221) ((T_DECLARE) reduce 221) ((T_DIR) reduce 221) ((T_DNUMBER) reduce 221) ((T_DO) reduce 221) ((T_DOUBLE_CAST) reduce 221) ((T_ECHO) reduce 221) ((T_EMPTY) reduce 221) ((T_ENDFOREACH) reduce 221) ((T_ENUM) reduce 221) ((T_EVAL) reduce 221) ((T_EXIT) reduce 221) ((T_FILE) reduce 221) ((T_FINAL) reduce 221) ((T_FN) reduce 221) ((T_FOR) reduce 221) ((T_FOREACH) reduce 221) ((T_FUNCTION) reduce 221) ((T_FUNC_C) reduce 221) ((T_GLOBAL) reduce 221) ((T_GOTO) reduce 221) ((T_HALT_COMPILER) reduce 221) ((T_IF) reduce 221) ((T_INC) reduce 221) ((T_INCLUDE) reduce 221) ((T_INCLUDE_ONCE) reduce 221) ((T_INLINE_HTML) reduce 221) ((T_INTERFACE) reduce 221) ((T_INT_CAST) reduce 221) ((T_ISSET) reduce 221) ((T_LINE) reduce 221) ((T_LIST) reduce 221) ((T_LNUMBER) reduce 221) ((T_MATCH) reduce 221) ((T_METHOD_C) reduce 221) ((T_NAME_FULLY_QUALIFIED) reduce 221) ((T_NAME_QUALIFIED) reduce 221) ((T_NAME_RELATIVE) reduce 221) ((T_NEW) reduce 221) ((T_NS_C) reduce 221) ((T_OBJECT_CAST) reduce 221) ((T_PRINT) reduce 221) ((T_READONLY) reduce 221) ((T_REQUIRE) reduce 221) ((T_REQUIRE_ONCE) reduce 221) ((T_RETURN) reduce 221) ((T_START_HEREDOC) reduce 221) ((T_STATIC) reduce 221) ((T_STRING) reduce 221) ((T_STRING_CAST) reduce 221) ((T_SWITCH) reduce 221) ((T_THROW) reduce 221) ((T_TRAIT) reduce 221) ((T_TRAIT_C) reduce 221) ((T_TRY) reduce 221) ((T_UNSET) reduce 221) ((T_UNSET_CAST) reduce 221) ((T_VARIABLE) reduce 221) ((T_WHILE) reduce 221) ((T_YIELD) reduce 221) ((T_YIELD_FROM) reduce 221) (("[") reduce 221) (("`") reduce 221) (("{") reduce 221) (("~") reduce 221)) 20752 ((("!") reduce 222) (("\"") reduce 222) (("$") reduce 222) (("(") reduce 222) (("+") reduce 222) (("-") reduce 222) ((";") reduce 222) (("@") reduce 222) ((T_ABSTRACT) reduce 222) ((T_ARRAY) reduce 222) ((T_ARRAY_CAST) reduce 222) ((T_ATTRIBUTE) reduce 222) ((T_BOOL_CAST) reduce 222) ((T_BREAK) reduce 222) ((T_CLASS) reduce 222) ((T_CLASS_C) reduce 222) ((T_CLONE) reduce 222) ((T_CONSTANT_ENCAPSED_STRING) reduce 222) ((T_CONTINUE) reduce 222) ((T_DEC) reduce 222) ((T_DECLARE) reduce 222) ((T_DIR) reduce 222) ((T_DNUMBER) reduce 222) ((T_DO) reduce 222) ((T_DOUBLE_CAST) reduce 222) ((T_ECHO) reduce 222) ((T_EMPTY) reduce 222) ((T_ENDFOREACH) reduce 222) ((T_ENUM) reduce 222) ((T_EVAL) reduce 222) ((T_EXIT) reduce 222) ((T_FILE) reduce 222) ((T_FINAL) reduce 222) ((T_FN) reduce 222) ((T_FOR) reduce 222) ((T_FOREACH) reduce 222) ((T_FUNCTION) reduce 222) ((T_FUNC_C) reduce 222) ((T_GLOBAL) reduce 222) ((T_GOTO) reduce 222) ((T_HALT_COMPILER) reduce 222) ((T_IF) reduce 222) ((T_INC) reduce 222) ((T_INCLUDE) reduce 222) ((T_INCLUDE_ONCE) reduce 222) ((T_INLINE_HTML) reduce 222) ((T_INTERFACE) reduce 222) ((T_INT_CAST) reduce 222) ((T_ISSET) reduce 222) ((T_LINE) reduce 222) ((T_LIST) reduce 222) ((T_LNUMBER) reduce 222) ((T_MATCH) reduce 222) ((T_METHOD_C) reduce 222) ((T_NAME_FULLY_QUALIFIED) reduce 222) ((T_NAME_QUALIFIED) reduce 222) ((T_NAME_RELATIVE) reduce 222) ((T_NEW) reduce 222) ((T_NS_C) reduce 222) ((T_OBJECT_CAST) reduce 222) ((T_PRINT) reduce 222) ((T_READONLY) reduce 222) ((T_REQUIRE) reduce 222) ((T_REQUIRE_ONCE) reduce 222) ((T_RETURN) reduce 222) ((T_START_HEREDOC) reduce 222) ((T_STATIC) reduce 222) ((T_STRING) reduce 222) ((T_STRING_CAST) reduce 222) ((T_SWITCH) reduce 222) ((T_THROW) reduce 222) ((T_TRAIT) reduce 222) ((T_TRAIT_C) reduce 222) ((T_TRY) reduce 222) ((T_UNSET) reduce 222) ((T_UNSET_CAST) reduce 222) ((T_VARIABLE) reduce 222) ((T_WHILE) reduce 222) ((T_YIELD) reduce 222) ((T_YIELD_FROM) reduce 222) (("[") reduce 222) (("`") reduce 222) (("{") reduce 222) (("~") reduce 222)) 20756 ((("!") reduce 223) (("\"") reduce 223) (("$") reduce 223) (("(") reduce 223) (("+") reduce 223) (("-") reduce 223) ((";") reduce 223) (("@") reduce 223) ((T_ABSTRACT) reduce 223) ((T_ARRAY) reduce 223) ((T_ARRAY_CAST) reduce 223) ((T_ATTRIBUTE) reduce 223) ((T_BOOL_CAST) reduce 223) ((T_BREAK) reduce 223) ((T_CLASS) reduce 223) ((T_CLASS_C) reduce 223) ((T_CLONE) reduce 223) ((T_CONSTANT_ENCAPSED_STRING) reduce 223) ((T_CONTINUE) reduce 223) ((T_DEC) reduce 223) ((T_DECLARE) reduce 223) ((T_DIR) reduce 223) ((T_DNUMBER) reduce 223) ((T_DO) reduce 223) ((T_DOUBLE_CAST) reduce 223) ((T_ECHO) reduce 223) ((T_EMPTY) reduce 223) ((T_ENDFOREACH) reduce 223) ((T_ENUM) reduce 223) ((T_EVAL) reduce 223) ((T_EXIT) reduce 223) ((T_FILE) reduce 223) ((T_FINAL) reduce 223) ((T_FN) reduce 223) ((T_FOR) reduce 223) ((T_FOREACH) reduce 223) ((T_FUNCTION) reduce 223) ((T_FUNC_C) reduce 223) ((T_GLOBAL) reduce 223) ((T_GOTO) reduce 223) ((T_HALT_COMPILER) reduce 223) ((T_IF) reduce 223) ((T_INC) reduce 223) ((T_INCLUDE) reduce 223) ((T_INCLUDE_ONCE) reduce 223) ((T_INLINE_HTML) reduce 223) ((T_INTERFACE) reduce 223) ((T_INT_CAST) reduce 223) ((T_ISSET) reduce 223) ((T_LINE) reduce 223) ((T_LIST) reduce 223) ((T_LNUMBER) reduce 223) ((T_MATCH) reduce 223) ((T_METHOD_C) reduce 223) ((T_NAME_FULLY_QUALIFIED) reduce 223) ((T_NAME_QUALIFIED) reduce 223) ((T_NAME_RELATIVE) reduce 223) ((T_NEW) reduce 223) ((T_NS_C) reduce 223) ((T_OBJECT_CAST) reduce 223) ((T_PRINT) reduce 223) ((T_READONLY) reduce 223) ((T_REQUIRE) reduce 223) ((T_REQUIRE_ONCE) reduce 223) ((T_RETURN) reduce 223) ((T_START_HEREDOC) reduce 223) ((T_STATIC) reduce 223) ((T_STRING) reduce 223) ((T_STRING_CAST) reduce 223) ((T_SWITCH) reduce 223) ((T_THROW) reduce 223) ((T_TRAIT) reduce 223) ((T_TRAIT_C) reduce 223) ((T_TRY) reduce 223) ((T_UNSET) reduce 223) ((T_UNSET_CAST) reduce 223) ((T_VARIABLE) reduce 223) ((T_WHILE) reduce 223) ((T_YIELD) reduce 223) ((T_YIELD_FROM) reduce 223) (("[") reduce 223) (("`") reduce 223) (("{") reduce 223) (("~") reduce 223)) 20759 ((("!") reduce 224) (("\"") reduce 224) (("$") reduce 224) (("(") reduce 224) (("+") reduce 224) (("-") reduce 224) ((";") reduce 224) (("@") reduce 224) ((T_ABSTRACT) reduce 224) ((T_ARRAY) reduce 224) ((T_ARRAY_CAST) reduce 224) ((T_ATTRIBUTE) reduce 224) ((T_BOOL_CAST) reduce 224) ((T_BREAK) reduce 224) ((T_CLASS) reduce 224) ((T_CLASS_C) reduce 224) ((T_CLONE) reduce 224) ((T_CONSTANT_ENCAPSED_STRING) reduce 224) ((T_CONTINUE) reduce 224) ((T_DEC) reduce 224) ((T_DECLARE) reduce 224) ((T_DIR) reduce 224) ((T_DNUMBER) reduce 224) ((T_DO) reduce 224) ((T_DOUBLE_CAST) reduce 224) ((T_ECHO) reduce 224) ((T_EMPTY) reduce 224) ((T_ENDFOREACH) reduce 224) ((T_ENUM) reduce 224) ((T_EVAL) reduce 224) ((T_EXIT) reduce 224) ((T_FILE) reduce 224) ((T_FINAL) reduce 224) ((T_FN) reduce 224) ((T_FOR) reduce 224) ((T_FOREACH) reduce 224) ((T_FUNCTION) reduce 224) ((T_FUNC_C) reduce 224) ((T_GLOBAL) reduce 224) ((T_GOTO) reduce 224) ((T_HALT_COMPILER) reduce 224) ((T_IF) reduce 224) ((T_INC) reduce 224) ((T_INCLUDE) reduce 224) ((T_INCLUDE_ONCE) reduce 224) ((T_INLINE_HTML) reduce 224) ((T_INTERFACE) reduce 224) ((T_INT_CAST) reduce 224) ((T_ISSET) reduce 224) ((T_LINE) reduce 224) ((T_LIST) reduce 224) ((T_LNUMBER) reduce 224) ((T_MATCH) reduce 224) ((T_METHOD_C) reduce 224) ((T_NAME_FULLY_QUALIFIED) reduce 224) ((T_NAME_QUALIFIED) reduce 224) ((T_NAME_RELATIVE) reduce 224) ((T_NEW) reduce 224) ((T_NS_C) reduce 224) ((T_OBJECT_CAST) reduce 224) ((T_PRINT) reduce 224) ((T_READONLY) reduce 224) ((T_REQUIRE) reduce 224) ((T_REQUIRE_ONCE) reduce 224) ((T_RETURN) reduce 224) ((T_START_HEREDOC) reduce 224) ((T_STATIC) reduce 224) ((T_STRING) reduce 224) ((T_STRING_CAST) reduce 224) ((T_SWITCH) reduce 224) ((T_THROW) reduce 224) ((T_TRAIT) reduce 224) ((T_TRAIT_C) reduce 224) ((T_TRY) reduce 224) ((T_UNSET) reduce 224) ((T_UNSET_CAST) reduce 224) ((T_VARIABLE) reduce 224) ((T_WHILE) reduce 224) ((T_YIELD) reduce 224) ((T_YIELD_FROM) reduce 224) (("[") reduce 224) (("`") reduce 224) (("{") reduce 224) (("~") reduce 224)) 20760 ((("!") reduce 167) (("\"") reduce 167) (("$") reduce 167) (("(") reduce 167) (("+") reduce 167) (("-") reduce 167) ((";") reduce 167) (("@") reduce 167) ((T_ABSTRACT) reduce 167) ((T_ARRAY) reduce 167) ((T_ARRAY_CAST) reduce 167) ((T_ATTRIBUTE) reduce 167) ((T_BOOL_CAST) reduce 167) ((T_BREAK) reduce 167) ((T_CLASS) reduce 167) ((T_CLASS_C) reduce 167) ((T_CLONE) reduce 167) ((T_CONSTANT_ENCAPSED_STRING) reduce 167) ((T_CONTINUE) reduce 167) ((T_DEC) reduce 167) ((T_DECLARE) reduce 167) ((T_DIR) reduce 167) ((T_DNUMBER) reduce 167) ((T_DO) reduce 167) ((T_DOUBLE_CAST) reduce 167) ((T_ECHO) reduce 167) ((T_EMPTY) reduce 167) ((T_ENDFOREACH) reduce 167) ((T_ENUM) reduce 167) ((T_EVAL) reduce 167) ((T_EXIT) reduce 167) ((T_FILE) reduce 167) ((T_FINAL) reduce 167) ((T_FN) reduce 167) ((T_FOR) reduce 167) ((T_FOREACH) reduce 167) ((T_FUNCTION) reduce 167) ((T_FUNC_C) reduce 167) ((T_GLOBAL) reduce 167) ((T_GOTO) reduce 167) ((T_HALT_COMPILER) reduce 167) ((T_IF) reduce 167) ((T_INC) reduce 167) ((T_INCLUDE) reduce 167) ((T_INCLUDE_ONCE) reduce 167) ((T_INLINE_HTML) reduce 167) ((T_INTERFACE) reduce 167) ((T_INT_CAST) reduce 167) ((T_ISSET) reduce 167) ((T_LINE) reduce 167) ((T_LIST) reduce 167) ((T_LNUMBER) reduce 167) ((T_MATCH) reduce 167) ((T_METHOD_C) reduce 167) ((T_NAME_FULLY_QUALIFIED) reduce 167) ((T_NAME_QUALIFIED) reduce 167) ((T_NAME_RELATIVE) reduce 167) ((T_NEW) reduce 167) ((T_NS_C) reduce 167) ((T_OBJECT_CAST) reduce 167) ((T_PRINT) reduce 167) ((T_READONLY) reduce 167) ((T_REQUIRE) reduce 167) ((T_REQUIRE_ONCE) reduce 167) ((T_RETURN) reduce 167) ((T_START_HEREDOC) reduce 167) ((T_STATIC) reduce 167) ((T_STRING) reduce 167) ((T_STRING_CAST) reduce 167) ((T_SWITCH) reduce 167) ((T_THROW) reduce 167) ((T_TRAIT) reduce 167) ((T_TRAIT_C) reduce 167) ((T_TRY) reduce 167) ((T_UNSET) reduce 167) ((T_UNSET_CAST) reduce 167) ((T_VARIABLE) reduce 167) ((T_WHILE) reduce 167) ((T_YIELD) reduce 167) ((T_YIELD_FROM) reduce 167) (("[") reduce 167) (("`") reduce 167) (("{") reduce 167) (("~") reduce 167)) 20762 ((("!") reduce 156) (("\"") reduce 156) (("$") reduce 156) (("(") reduce 156) (("+") reduce 156) (("-") reduce 156) ((";") reduce 156) (("@") reduce 156) ((T_ABSTRACT) reduce 156) ((T_ARRAY) reduce 156) ((T_ARRAY_CAST) reduce 156) ((T_ATTRIBUTE) reduce 156) ((T_BOOL_CAST) reduce 156) ((T_BREAK) reduce 156) ((T_CLASS) reduce 156) ((T_CLASS_C) reduce 156) ((T_CLONE) reduce 156) ((T_CONSTANT_ENCAPSED_STRING) reduce 156) ((T_CONTINUE) reduce 156) ((T_DEC) reduce 156) ((T_DECLARE) reduce 156) ((T_DIR) reduce 156) ((T_DNUMBER) reduce 156) ((T_DO) reduce 156) ((T_DOUBLE_CAST) reduce 156) ((T_ECHO) reduce 156) ((T_EMPTY) reduce 156) ((T_ENDFOREACH) reduce 156) ((T_ENUM) reduce 156) ((T_EVAL) reduce 156) ((T_EXIT) reduce 156) ((T_FILE) reduce 156) ((T_FINAL) reduce 156) ((T_FN) reduce 156) ((T_FOR) reduce 156) ((T_FOREACH) reduce 156) ((T_FUNCTION) reduce 156) ((T_FUNC_C) reduce 156) ((T_GLOBAL) reduce 156) ((T_GOTO) reduce 156) ((T_HALT_COMPILER) reduce 156) ((T_IF) reduce 156) ((T_INC) reduce 156) ((T_INCLUDE) reduce 156) ((T_INCLUDE_ONCE) reduce 156) ((T_INLINE_HTML) reduce 156) ((T_INTERFACE) reduce 156) ((T_INT_CAST) reduce 156) ((T_ISSET) reduce 156) ((T_LINE) reduce 156) ((T_LIST) reduce 156) ((T_LNUMBER) reduce 156) ((T_MATCH) reduce 156) ((T_METHOD_C) reduce 156) ((T_NAME_FULLY_QUALIFIED) reduce 156) ((T_NAME_QUALIFIED) reduce 156) ((T_NAME_RELATIVE) reduce 156) ((T_NEW) reduce 156) ((T_NS_C) reduce 156) ((T_OBJECT_CAST) reduce 156) ((T_PRINT) reduce 156) ((T_READONLY) reduce 156) ((T_REQUIRE) reduce 156) ((T_REQUIRE_ONCE) reduce 156) ((T_RETURN) reduce 156) ((T_START_HEREDOC) reduce 156) ((T_STATIC) reduce 156) ((T_STRING) reduce 156) ((T_STRING_CAST) reduce 156) ((T_SWITCH) reduce 156) ((T_THROW) reduce 156) ((T_TRAIT) reduce 156) ((T_TRAIT_C) reduce 156) ((T_TRY) reduce 156) ((T_UNSET) reduce 156) ((T_UNSET_CAST) reduce 156) ((T_VARIABLE) reduce 156) ((T_WHILE) reduce 156) ((T_YIELD) reduce 156) ((T_YIELD_FROM) reduce 156) (("[") reduce 156) (("`") reduce 156) (("{") reduce 156) (("~") reduce 156)) 20764 ((("!") reduce 154) (("\"") reduce 154) (("$") reduce 154) (("(") reduce 154) (("+") reduce 154) (("-") reduce 154) ((";") reduce 154) (("@") reduce 154) ((T_ABSTRACT) reduce 154) ((T_ARRAY) reduce 154) ((T_ARRAY_CAST) reduce 154) ((T_ATTRIBUTE) reduce 154) ((T_BOOL_CAST) reduce 154) ((T_BREAK) reduce 154) ((T_CLASS) reduce 154) ((T_CLASS_C) reduce 154) ((T_CLONE) reduce 154) ((T_CONSTANT_ENCAPSED_STRING) reduce 154) ((T_CONTINUE) reduce 154) ((T_DEC) reduce 154) ((T_DECLARE) reduce 154) ((T_DIR) reduce 154) ((T_DNUMBER) reduce 154) ((T_DO) reduce 154) ((T_DOUBLE_CAST) reduce 154) ((T_ECHO) reduce 154) ((T_EMPTY) reduce 154) ((T_ENDFOREACH) reduce 154) ((T_ENUM) reduce 154) ((T_EVAL) reduce 154) ((T_EXIT) reduce 154) ((T_FILE) reduce 154) ((T_FINAL) reduce 154) ((T_FN) reduce 154) ((T_FOR) reduce 154) ((T_FOREACH) reduce 154) ((T_FUNCTION) reduce 154) ((T_FUNC_C) reduce 154) ((T_GLOBAL) reduce 154) ((T_GOTO) reduce 154) ((T_HALT_COMPILER) reduce 154) ((T_IF) reduce 154) ((T_INC) reduce 154) ((T_INCLUDE) reduce 154) ((T_INCLUDE_ONCE) reduce 154) ((T_INLINE_HTML) reduce 154) ((T_INTERFACE) reduce 154) ((T_INT_CAST) reduce 154) ((T_ISSET) reduce 154) ((T_LINE) reduce 154) ((T_LIST) reduce 154) ((T_LNUMBER) reduce 154) ((T_MATCH) reduce 154) ((T_METHOD_C) reduce 154) ((T_NAME_FULLY_QUALIFIED) reduce 154) ((T_NAME_QUALIFIED) reduce 154) ((T_NAME_RELATIVE) reduce 154) ((T_NEW) reduce 154) ((T_NS_C) reduce 154) ((T_OBJECT_CAST) reduce 154) ((T_PRINT) reduce 154) ((T_READONLY) reduce 154) ((T_REQUIRE) reduce 154) ((T_REQUIRE_ONCE) reduce 154) ((T_RETURN) reduce 154) ((T_START_HEREDOC) reduce 154) ((T_STATIC) reduce 154) ((T_STRING) reduce 154) ((T_STRING_CAST) reduce 154) ((T_SWITCH) reduce 154) ((T_THROW) reduce 154) ((T_TRAIT) reduce 154) ((T_TRAIT_C) reduce 154) ((T_TRY) reduce 154) ((T_UNSET) reduce 154) ((T_UNSET_CAST) reduce 154) ((T_VARIABLE) reduce 154) ((T_WHILE) reduce 154) ((T_YIELD) reduce 154) ((T_YIELD_FROM) reduce 154) (("[") reduce 154) (("`") reduce 154) (("{") reduce 154) (("~") reduce 154)) 20770 ((("!") reduce 198) (("\"") reduce 198) (("$") reduce 198) (("(") reduce 198) (("+") reduce 198) (("-") reduce 198) ((";") reduce 198) (("@") reduce 198) ((T_ABSTRACT) reduce 198) ((T_ARRAY) reduce 198) ((T_ARRAY_CAST) reduce 198) ((T_ATTRIBUTE) reduce 198) ((T_BOOL_CAST) reduce 198) ((T_BREAK) reduce 198) ((T_CLASS) reduce 198) ((T_CLASS_C) reduce 198) ((T_CLONE) reduce 198) ((T_CONSTANT_ENCAPSED_STRING) reduce 198) ((T_CONTINUE) reduce 198) ((T_DEC) reduce 198) ((T_DECLARE) reduce 198) ((T_DIR) reduce 198) ((T_DNUMBER) reduce 198) ((T_DO) reduce 198) ((T_DOUBLE_CAST) reduce 198) ((T_ECHO) reduce 198) ((T_EMPTY) reduce 198) ((T_ENDFOREACH) reduce 198) ((T_ENUM) reduce 198) ((T_EVAL) reduce 198) ((T_EXIT) reduce 198) ((T_FILE) reduce 198) ((T_FINAL) reduce 198) ((T_FN) reduce 198) ((T_FOR) reduce 198) ((T_FOREACH) reduce 198) ((T_FUNCTION) reduce 198) ((T_FUNC_C) reduce 198) ((T_GLOBAL) reduce 198) ((T_GOTO) reduce 198) ((T_HALT_COMPILER) reduce 198) ((T_IF) reduce 198) ((T_INC) reduce 198) ((T_INCLUDE) reduce 198) ((T_INCLUDE_ONCE) reduce 198) ((T_INLINE_HTML) reduce 198) ((T_INTERFACE) reduce 198) ((T_INT_CAST) reduce 198) ((T_ISSET) reduce 198) ((T_LINE) reduce 198) ((T_LIST) reduce 198) ((T_LNUMBER) reduce 198) ((T_MATCH) reduce 198) ((T_METHOD_C) reduce 198) ((T_NAME_FULLY_QUALIFIED) reduce 198) ((T_NAME_QUALIFIED) reduce 198) ((T_NAME_RELATIVE) reduce 198) ((T_NEW) reduce 198) ((T_NS_C) reduce 198) ((T_OBJECT_CAST) reduce 198) ((T_PRINT) reduce 198) ((T_READONLY) reduce 198) ((T_REQUIRE) reduce 198) ((T_REQUIRE_ONCE) reduce 198) ((T_RETURN) reduce 198) ((T_START_HEREDOC) reduce 198) ((T_STATIC) reduce 198) ((T_STRING) reduce 198) ((T_STRING_CAST) reduce 198) ((T_SWITCH) reduce 198) ((T_THROW) reduce 198) ((T_TRAIT) reduce 198) ((T_TRAIT_C) reduce 198) ((T_TRY) reduce 198) ((T_UNSET) reduce 198) ((T_UNSET_CAST) reduce 198) ((T_VARIABLE) reduce 198) ((T_WHILE) reduce 198) ((T_YIELD) reduce 198) ((T_YIELD_FROM) reduce 198) (("[") reduce 198) (("`") reduce 198) (("{") reduce 198) (("~") reduce 198)) 20774 ((("!") reduce 241) (("\"") reduce 241) (("$") reduce 241) (("(") reduce 241) (("+") reduce 241) (("-") reduce 241) ((";") reduce 241) (("@") reduce 241) ((T_ABSTRACT) reduce 241) ((T_ARRAY) reduce 241) ((T_ARRAY_CAST) reduce 241) ((T_ATTRIBUTE) reduce 241) ((T_BOOL_CAST) reduce 241) ((T_BREAK) reduce 241) ((T_CLASS) reduce 241) ((T_CLASS_C) reduce 241) ((T_CLONE) reduce 241) ((T_CONSTANT_ENCAPSED_STRING) reduce 241) ((T_CONTINUE) reduce 241) ((T_DEC) reduce 241) ((T_DECLARE) reduce 241) ((T_DIR) reduce 241) ((T_DNUMBER) reduce 241) ((T_DO) reduce 241) ((T_DOUBLE_CAST) reduce 241) ((T_ECHO) reduce 241) ((T_ELSE) reduce 241) ((T_ELSEIF) reduce 241) ((T_EMPTY) reduce 241) ((T_ENDFOREACH) reduce 241) ((T_ENUM) reduce 241) ((T_EVAL) reduce 241) ((T_EXIT) reduce 241) ((T_FILE) reduce 241) ((T_FINAL) reduce 241) ((T_FN) reduce 241) ((T_FOR) reduce 241) ((T_FOREACH) reduce 241) ((T_FUNCTION) reduce 241) ((T_FUNC_C) reduce 241) ((T_GLOBAL) reduce 241) ((T_GOTO) reduce 241) ((T_HALT_COMPILER) reduce 241) ((T_IF) reduce 241) ((T_INC) reduce 241) ((T_INCLUDE) reduce 241) ((T_INCLUDE_ONCE) reduce 241) ((T_INLINE_HTML) reduce 241) ((T_INTERFACE) reduce 241) ((T_INT_CAST) reduce 241) ((T_ISSET) reduce 241) ((T_LINE) reduce 241) ((T_LIST) reduce 241) ((T_LNUMBER) reduce 241) ((T_MATCH) reduce 241) ((T_METHOD_C) reduce 241) ((T_NAME_FULLY_QUALIFIED) reduce 241) ((T_NAME_QUALIFIED) reduce 241) ((T_NAME_RELATIVE) reduce 241) ((T_NEW) reduce 241) ((T_NS_C) reduce 241) ((T_OBJECT_CAST) reduce 241) ((T_PRINT) reduce 241) ((T_READONLY) reduce 241) ((T_REQUIRE) reduce 241) ((T_REQUIRE_ONCE) reduce 241) ((T_RETURN) reduce 241) ((T_START_HEREDOC) reduce 241) ((T_STATIC) reduce 241) ((T_STRING) reduce 241) ((T_STRING_CAST) reduce 241) ((T_SWITCH) reduce 241) ((T_THROW) reduce 241) ((T_TRAIT) reduce 241) ((T_TRAIT_C) reduce 241) ((T_TRY) reduce 241) ((T_UNSET) reduce 241) ((T_UNSET_CAST) reduce 241) ((T_VARIABLE) reduce 241) ((T_WHILE) reduce 241) ((T_YIELD) reduce 241) ((T_YIELD_FROM) reduce 241) (("[") reduce 241) (("`") reduce 241) (("{") reduce 241) (("~") reduce 241)) 20777 ((("!") reduce 144) (("\"") reduce 144) (("$") reduce 144) (("(") reduce 144) (("+") reduce 144) (("-") reduce 144) ((";") reduce 144) (("@") reduce 144) ((T_ABSTRACT) reduce 144) ((T_ARRAY) reduce 144) ((T_ARRAY_CAST) reduce 144) ((T_ATTRIBUTE) reduce 144) ((T_BOOL_CAST) reduce 144) ((T_BREAK) reduce 144) ((T_CLASS) reduce 144) ((T_CLASS_C) reduce 144) ((T_CLONE) reduce 144) ((T_CONSTANT_ENCAPSED_STRING) reduce 144) ((T_CONTINUE) reduce 144) ((T_DEC) reduce 144) ((T_DECLARE) reduce 144) ((T_DIR) reduce 144) ((T_DNUMBER) reduce 144) ((T_DO) reduce 144) ((T_DOUBLE_CAST) reduce 144) ((T_ECHO) reduce 144) ((T_EMPTY) reduce 144) ((T_ENDFOREACH) reduce 144) ((T_ENUM) reduce 144) ((T_EVAL) reduce 144) ((T_EXIT) reduce 144) ((T_FILE) reduce 144) ((T_FINAL) reduce 144) ((T_FN) reduce 144) ((T_FOR) reduce 144) ((T_FOREACH) reduce 144) ((T_FUNCTION) reduce 144) ((T_FUNC_C) reduce 144) ((T_GLOBAL) reduce 144) ((T_GOTO) reduce 144) ((T_HALT_COMPILER) reduce 144) ((T_IF) reduce 144) ((T_INC) reduce 144) ((T_INCLUDE) reduce 144) ((T_INCLUDE_ONCE) reduce 144) ((T_INLINE_HTML) reduce 144) ((T_INTERFACE) reduce 144) ((T_INT_CAST) reduce 144) ((T_ISSET) reduce 144) ((T_LINE) reduce 144) ((T_LIST) reduce 144) ((T_LNUMBER) reduce 144) ((T_MATCH) reduce 144) ((T_METHOD_C) reduce 144) ((T_NAME_FULLY_QUALIFIED) reduce 144) ((T_NAME_QUALIFIED) reduce 144) ((T_NAME_RELATIVE) reduce 144) ((T_NEW) reduce 144) ((T_NS_C) reduce 144) ((T_OBJECT_CAST) reduce 144) ((T_PRINT) reduce 144) ((T_READONLY) reduce 144) ((T_REQUIRE) reduce 144) ((T_REQUIRE_ONCE) reduce 144) ((T_RETURN) reduce 144) ((T_START_HEREDOC) reduce 144) ((T_STATIC) reduce 144) ((T_STRING) reduce 144) ((T_STRING_CAST) reduce 144) ((T_SWITCH) reduce 144) ((T_THROW) reduce 144) ((T_TRAIT) reduce 144) ((T_TRAIT_C) reduce 144) ((T_TRY) reduce 144) ((T_UNSET) reduce 144) ((T_UNSET_CAST) reduce 144) ((T_VARIABLE) reduce 144) ((T_WHILE) reduce 144) ((T_YIELD) reduce 144) ((T_YIELD_FROM) reduce 144) (("[") reduce 144) (("`") reduce 144) (("{") reduce 144) (("~") reduce 144)) 20779 ((("!") reduce 166) (("\"") reduce 166) (("$") reduce 166) (("(") reduce 166) (("+") reduce 166) (("-") reduce 166) ((";") reduce 166) (("@") reduce 166) ((T_ABSTRACT) reduce 166) ((T_ARRAY) reduce 166) ((T_ARRAY_CAST) reduce 166) ((T_ATTRIBUTE) reduce 166) ((T_BOOL_CAST) reduce 166) ((T_BREAK) reduce 166) ((T_CLASS) reduce 166) ((T_CLASS_C) reduce 166) ((T_CLONE) reduce 166) ((T_CONSTANT_ENCAPSED_STRING) reduce 166) ((T_CONTINUE) reduce 166) ((T_DEC) reduce 166) ((T_DECLARE) reduce 166) ((T_DIR) reduce 166) ((T_DNUMBER) reduce 166) ((T_DO) reduce 166) ((T_DOUBLE_CAST) reduce 166) ((T_ECHO) reduce 166) ((T_EMPTY) reduce 166) ((T_ENDFOREACH) reduce 166) ((T_ENUM) reduce 166) ((T_EVAL) reduce 166) ((T_EXIT) reduce 166) ((T_FILE) reduce 166) ((T_FINAL) reduce 166) ((T_FN) reduce 166) ((T_FOR) reduce 166) ((T_FOREACH) reduce 166) ((T_FUNCTION) reduce 166) ((T_FUNC_C) reduce 166) ((T_GLOBAL) reduce 166) ((T_GOTO) reduce 166) ((T_HALT_COMPILER) reduce 166) ((T_IF) reduce 166) ((T_INC) reduce 166) ((T_INCLUDE) reduce 166) ((T_INCLUDE_ONCE) reduce 166) ((T_INLINE_HTML) reduce 166) ((T_INTERFACE) reduce 166) ((T_INT_CAST) reduce 166) ((T_ISSET) reduce 166) ((T_LINE) reduce 166) ((T_LIST) reduce 166) ((T_LNUMBER) reduce 166) ((T_MATCH) reduce 166) ((T_METHOD_C) reduce 166) ((T_NAME_FULLY_QUALIFIED) reduce 166) ((T_NAME_QUALIFIED) reduce 166) ((T_NAME_RELATIVE) reduce 166) ((T_NEW) reduce 166) ((T_NS_C) reduce 166) ((T_OBJECT_CAST) reduce 166) ((T_PRINT) reduce 166) ((T_READONLY) reduce 166) ((T_REQUIRE) reduce 166) ((T_REQUIRE_ONCE) reduce 166) ((T_RETURN) reduce 166) ((T_START_HEREDOC) reduce 166) ((T_STATIC) reduce 166) ((T_STRING) reduce 166) ((T_STRING_CAST) reduce 166) ((T_SWITCH) reduce 166) ((T_THROW) reduce 166) ((T_TRAIT) reduce 166) ((T_TRAIT_C) reduce 166) ((T_TRY) reduce 166) ((T_UNSET) reduce 166) ((T_UNSET_CAST) reduce 166) ((T_VARIABLE) reduce 166) ((T_WHILE) reduce 166) ((T_YIELD) reduce 166) ((T_YIELD_FROM) reduce 166) (("[") reduce 166) (("`") reduce 166) (("{") reduce 166) (("~") reduce 166)) 20781 ((("!") reduce 155) (("\"") reduce 155) (("$") reduce 155) (("(") reduce 155) (("+") reduce 155) (("-") reduce 155) ((";") reduce 155) (("@") reduce 155) ((T_ABSTRACT) reduce 155) ((T_ARRAY) reduce 155) ((T_ARRAY_CAST) reduce 155) ((T_ATTRIBUTE) reduce 155) ((T_BOOL_CAST) reduce 155) ((T_BREAK) reduce 155) ((T_CLASS) reduce 155) ((T_CLASS_C) reduce 155) ((T_CLONE) reduce 155) ((T_CONSTANT_ENCAPSED_STRING) reduce 155) ((T_CONTINUE) reduce 155) ((T_DEC) reduce 155) ((T_DECLARE) reduce 155) ((T_DIR) reduce 155) ((T_DNUMBER) reduce 155) ((T_DO) reduce 155) ((T_DOUBLE_CAST) reduce 155) ((T_ECHO) reduce 155) ((T_EMPTY) reduce 155) ((T_ENDFOREACH) reduce 155) ((T_ENUM) reduce 155) ((T_EVAL) reduce 155) ((T_EXIT) reduce 155) ((T_FILE) reduce 155) ((T_FINAL) reduce 155) ((T_FN) reduce 155) ((T_FOR) reduce 155) ((T_FOREACH) reduce 155) ((T_FUNCTION) reduce 155) ((T_FUNC_C) reduce 155) ((T_GLOBAL) reduce 155) ((T_GOTO) reduce 155) ((T_HALT_COMPILER) reduce 155) ((T_IF) reduce 155) ((T_INC) reduce 155) ((T_INCLUDE) reduce 155) ((T_INCLUDE_ONCE) reduce 155) ((T_INLINE_HTML) reduce 155) ((T_INTERFACE) reduce 155) ((T_INT_CAST) reduce 155) ((T_ISSET) reduce 155) ((T_LINE) reduce 155) ((T_LIST) reduce 155) ((T_LNUMBER) reduce 155) ((T_MATCH) reduce 155) ((T_METHOD_C) reduce 155) ((T_NAME_FULLY_QUALIFIED) reduce 155) ((T_NAME_QUALIFIED) reduce 155) ((T_NAME_RELATIVE) reduce 155) ((T_NEW) reduce 155) ((T_NS_C) reduce 155) ((T_OBJECT_CAST) reduce 155) ((T_PRINT) reduce 155) ((T_READONLY) reduce 155) ((T_REQUIRE) reduce 155) ((T_REQUIRE_ONCE) reduce 155) ((T_RETURN) reduce 155) ((T_START_HEREDOC) reduce 155) ((T_STATIC) reduce 155) ((T_STRING) reduce 155) ((T_STRING_CAST) reduce 155) ((T_SWITCH) reduce 155) ((T_THROW) reduce 155) ((T_TRAIT) reduce 155) ((T_TRAIT_C) reduce 155) ((T_TRY) reduce 155) ((T_UNSET) reduce 155) ((T_UNSET_CAST) reduce 155) ((T_VARIABLE) reduce 155) ((T_WHILE) reduce 155) ((T_YIELD) reduce 155) ((T_YIELD_FROM) reduce 155) (("[") reduce 155) (("`") reduce 155) (("{") reduce 155) (("~") reduce 155)) 20791 ((("!") reduce 162) (("\"") reduce 162) (("$") reduce 162) (("(") reduce 162) (("+") reduce 162) (("-") reduce 162) ((";") reduce 162) (("@") reduce 162) ((T_ABSTRACT) reduce 162) ((T_ARRAY) reduce 162) ((T_ARRAY_CAST) reduce 162) ((T_ATTRIBUTE) reduce 162) ((T_BOOL_CAST) reduce 162) ((T_BREAK) reduce 162) ((T_CLASS) reduce 162) ((T_CLASS_C) reduce 162) ((T_CLONE) reduce 162) ((T_CONSTANT_ENCAPSED_STRING) reduce 162) ((T_CONTINUE) reduce 162) ((T_DEC) reduce 162) ((T_DECLARE) reduce 162) ((T_DIR) reduce 162) ((T_DNUMBER) reduce 162) ((T_DO) reduce 162) ((T_DOUBLE_CAST) reduce 162) ((T_ECHO) reduce 162) ((T_EMPTY) reduce 162) ((T_ENDFOREACH) reduce 162) ((T_ENUM) reduce 162) ((T_EVAL) reduce 162) ((T_EXIT) reduce 162) ((T_FILE) reduce 162) ((T_FINAL) reduce 162) ((T_FN) reduce 162) ((T_FOR) reduce 162) ((T_FOREACH) reduce 162) ((T_FUNCTION) reduce 162) ((T_FUNC_C) reduce 162) ((T_GLOBAL) reduce 162) ((T_GOTO) reduce 162) ((T_HALT_COMPILER) reduce 162) ((T_IF) reduce 162) ((T_INC) reduce 162) ((T_INCLUDE) reduce 162) ((T_INCLUDE_ONCE) reduce 162) ((T_INLINE_HTML) reduce 162) ((T_INTERFACE) reduce 162) ((T_INT_CAST) reduce 162) ((T_ISSET) reduce 162) ((T_LINE) reduce 162) ((T_LIST) reduce 162) ((T_LNUMBER) reduce 162) ((T_MATCH) reduce 162) ((T_METHOD_C) reduce 162) ((T_NAME_FULLY_QUALIFIED) reduce 162) ((T_NAME_QUALIFIED) reduce 162) ((T_NAME_RELATIVE) reduce 162) ((T_NEW) reduce 162) ((T_NS_C) reduce 162) ((T_OBJECT_CAST) reduce 162) ((T_PRINT) reduce 162) ((T_READONLY) reduce 162) ((T_REQUIRE) reduce 162) ((T_REQUIRE_ONCE) reduce 162) ((T_RETURN) reduce 162) ((T_START_HEREDOC) reduce 162) ((T_STATIC) reduce 162) ((T_STRING) reduce 162) ((T_STRING_CAST) reduce 162) ((T_SWITCH) reduce 162) ((T_THROW) reduce 162) ((T_TRAIT) reduce 162) ((T_TRAIT_C) reduce 162) ((T_TRY) reduce 162) ((T_UNSET) reduce 162) ((T_UNSET_CAST) reduce 162) ((T_VARIABLE) reduce 162) ((T_WHILE) reduce 162) ((T_YIELD) reduce 162) ((T_YIELD_FROM) reduce 162) (("[") reduce 162) (("`") reduce 162) (("{") reduce 162) (("~") reduce 162)) 20792 ((("!") reduce 217) (("\"") reduce 217) (("$") reduce 217) (("(") reduce 217) (("+") reduce 217) (("-") reduce 217) ((";") reduce 217) (("@") reduce 217) ((T_ABSTRACT) reduce 217) ((T_ARRAY) reduce 217) ((T_ARRAY_CAST) reduce 217) ((T_ATTRIBUTE) reduce 217) ((T_BOOL_CAST) reduce 217) ((T_BREAK) reduce 217) ((T_CLASS) reduce 217) ((T_CLASS_C) reduce 217) ((T_CLONE) reduce 217) ((T_CONSTANT_ENCAPSED_STRING) reduce 217) ((T_CONTINUE) reduce 217) ((T_DEC) reduce 217) ((T_DECLARE) reduce 217) ((T_DIR) reduce 217) ((T_DNUMBER) reduce 217) ((T_DO) reduce 217) ((T_DOUBLE_CAST) reduce 217) ((T_ECHO) reduce 217) ((T_EMPTY) reduce 217) ((T_ENDFOREACH) reduce 217) ((T_ENUM) reduce 217) ((T_EVAL) reduce 217) ((T_EXIT) reduce 217) ((T_FILE) reduce 217) ((T_FINAL) reduce 217) ((T_FN) reduce 217) ((T_FOR) reduce 217) ((T_FOREACH) reduce 217) ((T_FUNCTION) reduce 217) ((T_FUNC_C) reduce 217) ((T_GLOBAL) reduce 217) ((T_GOTO) reduce 217) ((T_HALT_COMPILER) reduce 217) ((T_IF) reduce 217) ((T_INC) reduce 217) ((T_INCLUDE) reduce 217) ((T_INCLUDE_ONCE) reduce 217) ((T_INLINE_HTML) reduce 217) ((T_INTERFACE) reduce 217) ((T_INT_CAST) reduce 217) ((T_ISSET) reduce 217) ((T_LINE) reduce 217) ((T_LIST) reduce 217) ((T_LNUMBER) reduce 217) ((T_MATCH) reduce 217) ((T_METHOD_C) reduce 217) ((T_NAME_FULLY_QUALIFIED) reduce 217) ((T_NAME_QUALIFIED) reduce 217) ((T_NAME_RELATIVE) reduce 217) ((T_NEW) reduce 217) ((T_NS_C) reduce 217) ((T_OBJECT_CAST) reduce 217) ((T_PRINT) reduce 217) ((T_READONLY) reduce 217) ((T_REQUIRE) reduce 217) ((T_REQUIRE_ONCE) reduce 217) ((T_RETURN) reduce 217) ((T_START_HEREDOC) reduce 217) ((T_STATIC) reduce 217) ((T_STRING) reduce 217) ((T_STRING_CAST) reduce 217) ((T_SWITCH) reduce 217) ((T_THROW) reduce 217) ((T_TRAIT) reduce 217) ((T_TRAIT_C) reduce 217) ((T_TRY) reduce 217) ((T_UNSET) reduce 217) ((T_UNSET_CAST) reduce 217) ((T_VARIABLE) reduce 217) ((T_WHILE) reduce 217) ((T_YIELD) reduce 217) ((T_YIELD_FROM) reduce 217) (("[") reduce 217) (("`") reduce 217) (("{") reduce 217) (("~") reduce 217)) 20795 ((("!") reduce 218) (("\"") reduce 218) (("$") reduce 218) (("(") reduce 218) (("+") reduce 218) (("-") reduce 218) ((";") reduce 218) (("@") reduce 218) ((T_ABSTRACT) reduce 218) ((T_ARRAY) reduce 218) ((T_ARRAY_CAST) reduce 218) ((T_ATTRIBUTE) reduce 218) ((T_BOOL_CAST) reduce 218) ((T_BREAK) reduce 218) ((T_CLASS) reduce 218) ((T_CLASS_C) reduce 218) ((T_CLONE) reduce 218) ((T_CONSTANT_ENCAPSED_STRING) reduce 218) ((T_CONTINUE) reduce 218) ((T_DEC) reduce 218) ((T_DECLARE) reduce 218) ((T_DIR) reduce 218) ((T_DNUMBER) reduce 218) ((T_DO) reduce 218) ((T_DOUBLE_CAST) reduce 218) ((T_ECHO) reduce 218) ((T_EMPTY) reduce 218) ((T_ENDFOREACH) reduce 218) ((T_ENUM) reduce 218) ((T_EVAL) reduce 218) ((T_EXIT) reduce 218) ((T_FILE) reduce 218) ((T_FINAL) reduce 218) ((T_FN) reduce 218) ((T_FOR) reduce 218) ((T_FOREACH) reduce 218) ((T_FUNCTION) reduce 218) ((T_FUNC_C) reduce 218) ((T_GLOBAL) reduce 218) ((T_GOTO) reduce 218) ((T_HALT_COMPILER) reduce 218) ((T_IF) reduce 218) ((T_INC) reduce 218) ((T_INCLUDE) reduce 218) ((T_INCLUDE_ONCE) reduce 218) ((T_INLINE_HTML) reduce 218) ((T_INTERFACE) reduce 218) ((T_INT_CAST) reduce 218) ((T_ISSET) reduce 218) ((T_LINE) reduce 218) ((T_LIST) reduce 218) ((T_LNUMBER) reduce 218) ((T_MATCH) reduce 218) ((T_METHOD_C) reduce 218) ((T_NAME_FULLY_QUALIFIED) reduce 218) ((T_NAME_QUALIFIED) reduce 218) ((T_NAME_RELATIVE) reduce 218) ((T_NEW) reduce 218) ((T_NS_C) reduce 218) ((T_OBJECT_CAST) reduce 218) ((T_PRINT) reduce 218) ((T_READONLY) reduce 218) ((T_REQUIRE) reduce 218) ((T_REQUIRE_ONCE) reduce 218) ((T_RETURN) reduce 218) ((T_START_HEREDOC) reduce 218) ((T_STATIC) reduce 218) ((T_STRING) reduce 218) ((T_STRING_CAST) reduce 218) ((T_SWITCH) reduce 218) ((T_THROW) reduce 218) ((T_TRAIT) reduce 218) ((T_TRAIT_C) reduce 218) ((T_TRY) reduce 218) ((T_UNSET) reduce 218) ((T_UNSET_CAST) reduce 218) ((T_VARIABLE) reduce 218) ((T_WHILE) reduce 218) ((T_YIELD) reduce 218) ((T_YIELD_FROM) reduce 218) (("[") reduce 218) (("`") reduce 218) (("{") reduce 218) (("~") reduce 218)) 20796 ((("!") reduce 161) (("\"") reduce 161) (("$") reduce 161) (("(") reduce 161) (("+") reduce 161) (("-") reduce 161) ((";") reduce 161) (("@") reduce 161) ((T_ABSTRACT) reduce 161) ((T_ARRAY) reduce 161) ((T_ARRAY_CAST) reduce 161) ((T_ATTRIBUTE) reduce 161) ((T_BOOL_CAST) reduce 161) ((T_BREAK) reduce 161) ((T_CLASS) reduce 161) ((T_CLASS_C) reduce 161) ((T_CLONE) reduce 161) ((T_CONSTANT_ENCAPSED_STRING) reduce 161) ((T_CONTINUE) reduce 161) ((T_DEC) reduce 161) ((T_DECLARE) reduce 161) ((T_DIR) reduce 161) ((T_DNUMBER) reduce 161) ((T_DO) reduce 161) ((T_DOUBLE_CAST) reduce 161) ((T_ECHO) reduce 161) ((T_EMPTY) reduce 161) ((T_ENDFOREACH) reduce 161) ((T_ENUM) reduce 161) ((T_EVAL) reduce 161) ((T_EXIT) reduce 161) ((T_FILE) reduce 161) ((T_FINAL) reduce 161) ((T_FN) reduce 161) ((T_FOR) reduce 161) ((T_FOREACH) reduce 161) ((T_FUNCTION) reduce 161) ((T_FUNC_C) reduce 161) ((T_GLOBAL) reduce 161) ((T_GOTO) reduce 161) ((T_HALT_COMPILER) reduce 161) ((T_IF) reduce 161) ((T_INC) reduce 161) ((T_INCLUDE) reduce 161) ((T_INCLUDE_ONCE) reduce 161) ((T_INLINE_HTML) reduce 161) ((T_INTERFACE) reduce 161) ((T_INT_CAST) reduce 161) ((T_ISSET) reduce 161) ((T_LINE) reduce 161) ((T_LIST) reduce 161) ((T_LNUMBER) reduce 161) ((T_MATCH) reduce 161) ((T_METHOD_C) reduce 161) ((T_NAME_FULLY_QUALIFIED) reduce 161) ((T_NAME_QUALIFIED) reduce 161) ((T_NAME_RELATIVE) reduce 161) ((T_NEW) reduce 161) ((T_NS_C) reduce 161) ((T_OBJECT_CAST) reduce 161) ((T_PRINT) reduce 161) ((T_READONLY) reduce 161) ((T_REQUIRE) reduce 161) ((T_REQUIRE_ONCE) reduce 161) ((T_RETURN) reduce 161) ((T_START_HEREDOC) reduce 161) ((T_STATIC) reduce 161) ((T_STRING) reduce 161) ((T_STRING_CAST) reduce 161) ((T_SWITCH) reduce 161) ((T_THROW) reduce 161) ((T_TRAIT) reduce 161) ((T_TRAIT_C) reduce 161) ((T_TRY) reduce 161) ((T_UNSET) reduce 161) ((T_UNSET_CAST) reduce 161) ((T_VARIABLE) reduce 161) ((T_WHILE) reduce 161) ((T_YIELD) reduce 161) ((T_YIELD_FROM) reduce 161) (("[") reduce 161) (("`") reduce 161) (("{") reduce 161) (("~") reduce 161)) 20805 ((("!") reduce 150) (("\"") reduce 150) (("$") reduce 150) (("(") reduce 150) (("+") reduce 150) (("-") reduce 150) ((";") reduce 150) (("@") reduce 150) ((T_ABSTRACT) reduce 150) ((T_ARRAY) reduce 150) ((T_ARRAY_CAST) reduce 150) ((T_ATTRIBUTE) reduce 150) ((T_BOOL_CAST) reduce 150) ((T_BREAK) reduce 150) ((T_CLASS) reduce 150) ((T_CLASS_C) reduce 150) ((T_CLONE) reduce 150) ((T_CONSTANT_ENCAPSED_STRING) reduce 150) ((T_CONTINUE) reduce 150) ((T_DEC) reduce 150) ((T_DECLARE) reduce 150) ((T_DIR) reduce 150) ((T_DNUMBER) reduce 150) ((T_DO) reduce 150) ((T_DOUBLE_CAST) reduce 150) ((T_ECHO) reduce 150) ((T_EMPTY) reduce 150) ((T_ENDFOREACH) reduce 150) ((T_ENUM) reduce 150) ((T_EVAL) reduce 150) ((T_EXIT) reduce 150) ((T_FILE) reduce 150) ((T_FINAL) reduce 150) ((T_FN) reduce 150) ((T_FOR) reduce 150) ((T_FOREACH) reduce 150) ((T_FUNCTION) reduce 150) ((T_FUNC_C) reduce 150) ((T_GLOBAL) reduce 150) ((T_GOTO) reduce 150) ((T_HALT_COMPILER) reduce 150) ((T_IF) reduce 150) ((T_INC) reduce 150) ((T_INCLUDE) reduce 150) ((T_INCLUDE_ONCE) reduce 150) ((T_INLINE_HTML) reduce 150) ((T_INTERFACE) reduce 150) ((T_INT_CAST) reduce 150) ((T_ISSET) reduce 150) ((T_LINE) reduce 150) ((T_LIST) reduce 150) ((T_LNUMBER) reduce 150) ((T_MATCH) reduce 150) ((T_METHOD_C) reduce 150) ((T_NAME_FULLY_QUALIFIED) reduce 150) ((T_NAME_QUALIFIED) reduce 150) ((T_NAME_RELATIVE) reduce 150) ((T_NEW) reduce 150) ((T_NS_C) reduce 150) ((T_OBJECT_CAST) reduce 150) ((T_PRINT) reduce 150) ((T_READONLY) reduce 150) ((T_REQUIRE) reduce 150) ((T_REQUIRE_ONCE) reduce 150) ((T_RETURN) reduce 150) ((T_START_HEREDOC) reduce 150) ((T_STATIC) reduce 150) ((T_STRING) reduce 150) ((T_STRING_CAST) reduce 150) ((T_SWITCH) reduce 150) ((T_THROW) reduce 150) ((T_TRAIT) reduce 150) ((T_TRAIT_C) reduce 150) ((T_TRY) reduce 150) ((T_UNSET) reduce 150) ((T_UNSET_CAST) reduce 150) ((T_VARIABLE) reduce 150) ((T_WHILE) reduce 150) ((T_YIELD) reduce 150) ((T_YIELD_FROM) reduce 150) (("[") reduce 150) (("`") reduce 150) (("{") reduce 150) (("~") reduce 150)) 20806 ((("!") reduce 215) (("\"") reduce 215) (("$") reduce 215) (("(") reduce 215) (("+") reduce 215) (("-") reduce 215) ((";") reduce 215) (("@") reduce 215) ((T_ABSTRACT) reduce 215) ((T_ARRAY) reduce 215) ((T_ARRAY_CAST) reduce 215) ((T_ATTRIBUTE) reduce 215) ((T_BOOL_CAST) reduce 215) ((T_BREAK) reduce 215) ((T_CLASS) reduce 215) ((T_CLASS_C) reduce 215) ((T_CLONE) reduce 215) ((T_CONSTANT_ENCAPSED_STRING) reduce 215) ((T_CONTINUE) reduce 215) ((T_DEC) reduce 215) ((T_DECLARE) reduce 215) ((T_DIR) reduce 215) ((T_DNUMBER) reduce 215) ((T_DO) reduce 215) ((T_DOUBLE_CAST) reduce 215) ((T_ECHO) reduce 215) ((T_EMPTY) reduce 215) ((T_ENDFOREACH) reduce 215) ((T_ENUM) reduce 215) ((T_EVAL) reduce 215) ((T_EXIT) reduce 215) ((T_FILE) reduce 215) ((T_FINAL) reduce 215) ((T_FN) reduce 215) ((T_FOR) reduce 215) ((T_FOREACH) reduce 215) ((T_FUNCTION) reduce 215) ((T_FUNC_C) reduce 215) ((T_GLOBAL) reduce 215) ((T_GOTO) reduce 215) ((T_HALT_COMPILER) reduce 215) ((T_IF) reduce 215) ((T_INC) reduce 215) ((T_INCLUDE) reduce 215) ((T_INCLUDE_ONCE) reduce 215) ((T_INLINE_HTML) reduce 215) ((T_INTERFACE) reduce 215) ((T_INT_CAST) reduce 215) ((T_ISSET) reduce 215) ((T_LINE) reduce 215) ((T_LIST) reduce 215) ((T_LNUMBER) reduce 215) ((T_MATCH) reduce 215) ((T_METHOD_C) reduce 215) ((T_NAME_FULLY_QUALIFIED) reduce 215) ((T_NAME_QUALIFIED) reduce 215) ((T_NAME_RELATIVE) reduce 215) ((T_NEW) reduce 215) ((T_NS_C) reduce 215) ((T_OBJECT_CAST) reduce 215) ((T_PRINT) reduce 215) ((T_READONLY) reduce 215) ((T_REQUIRE) reduce 215) ((T_REQUIRE_ONCE) reduce 215) ((T_RETURN) reduce 215) ((T_START_HEREDOC) reduce 215) ((T_STATIC) reduce 215) ((T_STRING) reduce 215) ((T_STRING_CAST) reduce 215) ((T_SWITCH) reduce 215) ((T_THROW) reduce 215) ((T_TRAIT) reduce 215) ((T_TRAIT_C) reduce 215) ((T_TRY) reduce 215) ((T_UNSET) reduce 215) ((T_UNSET_CAST) reduce 215) ((T_VARIABLE) reduce 215) ((T_WHILE) reduce 215) ((T_YIELD) reduce 215) ((T_YIELD_FROM) reduce 215) (("[") reduce 215) (("`") reduce 215) (("{") reduce 215) (("~") reduce 215)) 20809 ((("!") reduce 216) (("\"") reduce 216) (("$") reduce 216) (("(") reduce 216) (("+") reduce 216) (("-") reduce 216) ((";") reduce 216) (("@") reduce 216) ((T_ABSTRACT) reduce 216) ((T_ARRAY) reduce 216) ((T_ARRAY_CAST) reduce 216) ((T_ATTRIBUTE) reduce 216) ((T_BOOL_CAST) reduce 216) ((T_BREAK) reduce 216) ((T_CLASS) reduce 216) ((T_CLASS_C) reduce 216) ((T_CLONE) reduce 216) ((T_CONSTANT_ENCAPSED_STRING) reduce 216) ((T_CONTINUE) reduce 216) ((T_DEC) reduce 216) ((T_DECLARE) reduce 216) ((T_DIR) reduce 216) ((T_DNUMBER) reduce 216) ((T_DO) reduce 216) ((T_DOUBLE_CAST) reduce 216) ((T_ECHO) reduce 216) ((T_EMPTY) reduce 216) ((T_ENDFOREACH) reduce 216) ((T_ENUM) reduce 216) ((T_EVAL) reduce 216) ((T_EXIT) reduce 216) ((T_FILE) reduce 216) ((T_FINAL) reduce 216) ((T_FN) reduce 216) ((T_FOR) reduce 216) ((T_FOREACH) reduce 216) ((T_FUNCTION) reduce 216) ((T_FUNC_C) reduce 216) ((T_GLOBAL) reduce 216) ((T_GOTO) reduce 216) ((T_HALT_COMPILER) reduce 216) ((T_IF) reduce 216) ((T_INC) reduce 216) ((T_INCLUDE) reduce 216) ((T_INCLUDE_ONCE) reduce 216) ((T_INLINE_HTML) reduce 216) ((T_INTERFACE) reduce 216) ((T_INT_CAST) reduce 216) ((T_ISSET) reduce 216) ((T_LINE) reduce 216) ((T_LIST) reduce 216) ((T_LNUMBER) reduce 216) ((T_MATCH) reduce 216) ((T_METHOD_C) reduce 216) ((T_NAME_FULLY_QUALIFIED) reduce 216) ((T_NAME_QUALIFIED) reduce 216) ((T_NAME_RELATIVE) reduce 216) ((T_NEW) reduce 216) ((T_NS_C) reduce 216) ((T_OBJECT_CAST) reduce 216) ((T_PRINT) reduce 216) ((T_READONLY) reduce 216) ((T_REQUIRE) reduce 216) ((T_REQUIRE_ONCE) reduce 216) ((T_RETURN) reduce 216) ((T_START_HEREDOC) reduce 216) ((T_STATIC) reduce 216) ((T_STRING) reduce 216) ((T_STRING_CAST) reduce 216) ((T_SWITCH) reduce 216) ((T_THROW) reduce 216) ((T_TRAIT) reduce 216) ((T_TRAIT_C) reduce 216) ((T_TRY) reduce 216) ((T_UNSET) reduce 216) ((T_UNSET_CAST) reduce 216) ((T_VARIABLE) reduce 216) ((T_WHILE) reduce 216) ((T_YIELD) reduce 216) ((T_YIELD_FROM) reduce 216) (("[") reduce 216) (("`") reduce 216) (("{") reduce 216) (("~") reduce 216)) 20816 ((("!") reduce 199) (("\"") reduce 199) (("$") reduce 199) (("(") reduce 199) (("+") reduce 199) (("-") reduce 199) ((";") reduce 199) (("@") reduce 199) ((T_ABSTRACT) reduce 199) ((T_ARRAY) reduce 199) ((T_ARRAY_CAST) reduce 199) ((T_ATTRIBUTE) reduce 199) ((T_BOOL_CAST) reduce 199) ((T_BREAK) reduce 199) ((T_CLASS) reduce 199) ((T_CLASS_C) reduce 199) ((T_CLONE) reduce 199) ((T_CONSTANT_ENCAPSED_STRING) reduce 199) ((T_CONTINUE) reduce 199) ((T_DEC) reduce 199) ((T_DECLARE) reduce 199) ((T_DIR) reduce 199) ((T_DNUMBER) reduce 199) ((T_DO) reduce 199) ((T_DOUBLE_CAST) reduce 199) ((T_ECHO) reduce 199) ((T_EMPTY) reduce 199) ((T_ENDFOREACH) reduce 199) ((T_ENUM) reduce 199) ((T_EVAL) reduce 199) ((T_EXIT) reduce 199) ((T_FILE) reduce 199) ((T_FINAL) reduce 199) ((T_FN) reduce 199) ((T_FOR) reduce 199) ((T_FOREACH) reduce 199) ((T_FUNCTION) reduce 199) ((T_FUNC_C) reduce 199) ((T_GLOBAL) reduce 199) ((T_GOTO) reduce 199) ((T_HALT_COMPILER) reduce 199) ((T_IF) reduce 199) ((T_INC) reduce 199) ((T_INCLUDE) reduce 199) ((T_INCLUDE_ONCE) reduce 199) ((T_INLINE_HTML) reduce 199) ((T_INTERFACE) reduce 199) ((T_INT_CAST) reduce 199) ((T_ISSET) reduce 199) ((T_LINE) reduce 199) ((T_LIST) reduce 199) ((T_LNUMBER) reduce 199) ((T_MATCH) reduce 199) ((T_METHOD_C) reduce 199) ((T_NAME_FULLY_QUALIFIED) reduce 199) ((T_NAME_QUALIFIED) reduce 199) ((T_NAME_RELATIVE) reduce 199) ((T_NEW) reduce 199) ((T_NS_C) reduce 199) ((T_OBJECT_CAST) reduce 199) ((T_PRINT) reduce 199) ((T_READONLY) reduce 199) ((T_REQUIRE) reduce 199) ((T_REQUIRE_ONCE) reduce 199) ((T_RETURN) reduce 199) ((T_START_HEREDOC) reduce 199) ((T_STATIC) reduce 199) ((T_STRING) reduce 199) ((T_STRING_CAST) reduce 199) ((T_SWITCH) reduce 199) ((T_THROW) reduce 199) ((T_TRAIT) reduce 199) ((T_TRAIT_C) reduce 199) ((T_TRY) reduce 199) ((T_UNSET) reduce 199) ((T_UNSET_CAST) reduce 199) ((T_VARIABLE) reduce 199) ((T_WHILE) reduce 199) ((T_YIELD) reduce 199) ((T_YIELD_FROM) reduce 199) (("[") reduce 199) (("`") reduce 199) (("{") reduce 199) (("~") reduce 199)) 20817 ((("!") reduce 218) (("\"") reduce 218) (("$") reduce 218) (("(") reduce 218) (("+") reduce 218) (("-") reduce 218) ((";") reduce 218) (("@") reduce 218) ((T_ABSTRACT) reduce 218) ((T_ARRAY) reduce 218) ((T_ARRAY_CAST) reduce 218) ((T_ATTRIBUTE) reduce 218) ((T_BOOL_CAST) reduce 218) ((T_BREAK) reduce 218) ((T_CASE) reduce 218) ((T_CLASS) reduce 218) ((T_CLASS_C) reduce 218) ((T_CLONE) reduce 218) ((T_CONSTANT_ENCAPSED_STRING) reduce 218) ((T_CONTINUE) reduce 218) ((T_DEC) reduce 218) ((T_DECLARE) reduce 218) ((T_DEFAULT) reduce 218) ((T_DIR) reduce 218) ((T_DNUMBER) reduce 218) ((T_DO) reduce 218) ((T_DOUBLE_CAST) reduce 218) ((T_ECHO) reduce 218) ((T_ELSE) reduce 218) ((T_ELSEIF) reduce 218) ((T_EMPTY) reduce 218) ((T_ENDSWITCH) reduce 218) ((T_ENUM) reduce 218) ((T_EVAL) reduce 218) ((T_EXIT) reduce 218) ((T_FILE) reduce 218) ((T_FINAL) reduce 218) ((T_FN) reduce 218) ((T_FOR) reduce 218) ((T_FOREACH) reduce 218) ((T_FUNCTION) reduce 218) ((T_FUNC_C) reduce 218) ((T_GLOBAL) reduce 218) ((T_GOTO) reduce 218) ((T_HALT_COMPILER) reduce 218) ((T_IF) reduce 218) ((T_INC) reduce 218) ((T_INCLUDE) reduce 218) ((T_INCLUDE_ONCE) reduce 218) ((T_INLINE_HTML) reduce 218) ((T_INTERFACE) reduce 218) ((T_INT_CAST) reduce 218) ((T_ISSET) reduce 218) ((T_LINE) reduce 218) ((T_LIST) reduce 218) ((T_LNUMBER) reduce 218) ((T_MATCH) reduce 218) ((T_METHOD_C) reduce 218) ((T_NAME_FULLY_QUALIFIED) reduce 218) ((T_NAME_QUALIFIED) reduce 218) ((T_NAME_RELATIVE) reduce 218) ((T_NEW) reduce 218) ((T_NS_C) reduce 218) ((T_OBJECT_CAST) reduce 218) ((T_PRINT) reduce 218) ((T_READONLY) reduce 218) ((T_REQUIRE) reduce 218) ((T_REQUIRE_ONCE) reduce 218) ((T_RETURN) reduce 218) ((T_START_HEREDOC) reduce 218) ((T_STATIC) reduce 218) ((T_STRING) reduce 218) ((T_STRING_CAST) reduce 218) ((T_SWITCH) reduce 218) ((T_THROW) reduce 218) ((T_TRAIT) reduce 218) ((T_TRAIT_C) reduce 218) ((T_TRY) reduce 218) ((T_UNSET) reduce 218) ((T_UNSET_CAST) reduce 218) ((T_VARIABLE) reduce 218) ((T_WHILE) reduce 218) ((T_YIELD) reduce 218) ((T_YIELD_FROM) reduce 218) (("[") reduce 218) (("`") reduce 218) (("{") reduce 218) (("~") reduce 218)) 20819 ((("!") reduce 157) (("\"") reduce 157) (("$") reduce 157) (("(") reduce 157) (("+") reduce 157) (("-") reduce 157) ((";") reduce 157) (("@") reduce 157) ((T_ABSTRACT) reduce 157) ((T_ARRAY) reduce 157) ((T_ARRAY_CAST) reduce 157) ((T_ATTRIBUTE) reduce 157) ((T_BOOL_CAST) reduce 157) ((T_BREAK) reduce 157) ((T_CLASS) reduce 157) ((T_CLASS_C) reduce 157) ((T_CLONE) reduce 157) ((T_CONSTANT_ENCAPSED_STRING) reduce 157) ((T_CONTINUE) reduce 157) ((T_DEC) reduce 157) ((T_DECLARE) reduce 157) ((T_DIR) reduce 157) ((T_DNUMBER) reduce 157) ((T_DO) reduce 157) ((T_DOUBLE_CAST) reduce 157) ((T_ECHO) reduce 157) ((T_EMPTY) reduce 157) ((T_ENDFOREACH) reduce 157) ((T_ENUM) reduce 157) ((T_EVAL) reduce 157) ((T_EXIT) reduce 157) ((T_FILE) reduce 157) ((T_FINAL) reduce 157) ((T_FN) reduce 157) ((T_FOR) reduce 157) ((T_FOREACH) reduce 157) ((T_FUNCTION) reduce 157) ((T_FUNC_C) reduce 157) ((T_GLOBAL) reduce 157) ((T_GOTO) reduce 157) ((T_HALT_COMPILER) reduce 157) ((T_IF) reduce 157) ((T_INC) reduce 157) ((T_INCLUDE) reduce 157) ((T_INCLUDE_ONCE) reduce 157) ((T_INLINE_HTML) reduce 157) ((T_INTERFACE) reduce 157) ((T_INT_CAST) reduce 157) ((T_ISSET) reduce 157) ((T_LINE) reduce 157) ((T_LIST) reduce 157) ((T_LNUMBER) reduce 157) ((T_MATCH) reduce 157) ((T_METHOD_C) reduce 157) ((T_NAME_FULLY_QUALIFIED) reduce 157) ((T_NAME_QUALIFIED) reduce 157) ((T_NAME_RELATIVE) reduce 157) ((T_NEW) reduce 157) ((T_NS_C) reduce 157) ((T_OBJECT_CAST) reduce 157) ((T_PRINT) reduce 157) ((T_READONLY) reduce 157) ((T_REQUIRE) reduce 157) ((T_REQUIRE_ONCE) reduce 157) ((T_RETURN) reduce 157) ((T_START_HEREDOC) reduce 157) ((T_STATIC) reduce 157) ((T_STRING) reduce 157) ((T_STRING_CAST) reduce 157) ((T_SWITCH) reduce 157) ((T_THROW) reduce 157) ((T_TRAIT) reduce 157) ((T_TRAIT_C) reduce 157) ((T_TRY) reduce 157) ((T_UNSET) reduce 157) ((T_UNSET_CAST) reduce 157) ((T_VARIABLE) reduce 157) ((T_WHILE) reduce 157) ((T_YIELD) reduce 157) ((T_YIELD_FROM) reduce 157) (("[") reduce 157) (("`") reduce 157) (("{") reduce 157) (("~") reduce 157)) 20825 ((("!") reduce 149) (("\"") reduce 149) (("$") reduce 149) (("(") reduce 149) (("+") reduce 149) (("-") reduce 149) ((";") reduce 149) (("@") reduce 149) ((T_ABSTRACT) reduce 149) ((T_ARRAY) reduce 149) ((T_ARRAY_CAST) reduce 149) ((T_ATTRIBUTE) reduce 149) ((T_BOOL_CAST) reduce 149) ((T_BREAK) reduce 149) ((T_CLASS) reduce 149) ((T_CLASS_C) reduce 149) ((T_CLONE) reduce 149) ((T_CONSTANT_ENCAPSED_STRING) reduce 149) ((T_CONTINUE) reduce 149) ((T_DEC) reduce 149) ((T_DECLARE) reduce 149) ((T_DIR) reduce 149) ((T_DNUMBER) reduce 149) ((T_DO) reduce 149) ((T_DOUBLE_CAST) reduce 149) ((T_ECHO) reduce 149) ((T_EMPTY) reduce 149) ((T_ENDFOREACH) reduce 149) ((T_ENUM) reduce 149) ((T_EVAL) reduce 149) ((T_EXIT) reduce 149) ((T_FILE) reduce 149) ((T_FINAL) reduce 149) ((T_FN) reduce 149) ((T_FOR) reduce 149) ((T_FOREACH) reduce 149) ((T_FUNCTION) reduce 149) ((T_FUNC_C) reduce 149) ((T_GLOBAL) reduce 149) ((T_GOTO) reduce 149) ((T_HALT_COMPILER) reduce 149) ((T_IF) reduce 149) ((T_INC) reduce 149) ((T_INCLUDE) reduce 149) ((T_INCLUDE_ONCE) reduce 149) ((T_INLINE_HTML) reduce 149) ((T_INTERFACE) reduce 149) ((T_INT_CAST) reduce 149) ((T_ISSET) reduce 149) ((T_LINE) reduce 149) ((T_LIST) reduce 149) ((T_LNUMBER) reduce 149) ((T_MATCH) reduce 149) ((T_METHOD_C) reduce 149) ((T_NAME_FULLY_QUALIFIED) reduce 149) ((T_NAME_QUALIFIED) reduce 149) ((T_NAME_RELATIVE) reduce 149) ((T_NEW) reduce 149) ((T_NS_C) reduce 149) ((T_OBJECT_CAST) reduce 149) ((T_PRINT) reduce 149) ((T_READONLY) reduce 149) ((T_REQUIRE) reduce 149) ((T_REQUIRE_ONCE) reduce 149) ((T_RETURN) reduce 149) ((T_START_HEREDOC) reduce 149) ((T_STATIC) reduce 149) ((T_STRING) reduce 149) ((T_STRING_CAST) reduce 149) ((T_SWITCH) reduce 149) ((T_THROW) reduce 149) ((T_TRAIT) reduce 149) ((T_TRAIT_C) reduce 149) ((T_TRY) reduce 149) ((T_UNSET) reduce 149) ((T_UNSET_CAST) reduce 149) ((T_VARIABLE) reduce 149) ((T_WHILE) reduce 149) ((T_YIELD) reduce 149) ((T_YIELD_FROM) reduce 149) (("[") reduce 149) (("`") reduce 149) (("{") reduce 149) (("~") reduce 149)) 20830 ((("!") reduce 163) (("\"") reduce 163) (("$") reduce 163) (("(") reduce 163) (("+") reduce 163) (("-") reduce 163) ((";") reduce 163) (("@") reduce 163) ((T_ABSTRACT) reduce 163) ((T_ARRAY) reduce 163) ((T_ARRAY_CAST) reduce 163) ((T_ATTRIBUTE) reduce 163) ((T_BOOL_CAST) reduce 163) ((T_BREAK) reduce 163) ((T_CLASS) reduce 163) ((T_CLASS_C) reduce 163) ((T_CLONE) reduce 163) ((T_CONSTANT_ENCAPSED_STRING) reduce 163) ((T_CONTINUE) reduce 163) ((T_DEC) reduce 163) ((T_DECLARE) reduce 163) ((T_DIR) reduce 163) ((T_DNUMBER) reduce 163) ((T_DO) reduce 163) ((T_DOUBLE_CAST) reduce 163) ((T_ECHO) reduce 163) ((T_EMPTY) reduce 163) ((T_ENDFOREACH) reduce 163) ((T_ENUM) reduce 163) ((T_EVAL) reduce 163) ((T_EXIT) reduce 163) ((T_FILE) reduce 163) ((T_FINAL) reduce 163) ((T_FN) reduce 163) ((T_FOR) reduce 163) ((T_FOREACH) reduce 163) ((T_FUNCTION) reduce 163) ((T_FUNC_C) reduce 163) ((T_GLOBAL) reduce 163) ((T_GOTO) reduce 163) ((T_HALT_COMPILER) reduce 163) ((T_IF) reduce 163) ((T_INC) reduce 163) ((T_INCLUDE) reduce 163) ((T_INCLUDE_ONCE) reduce 163) ((T_INLINE_HTML) reduce 163) ((T_INTERFACE) reduce 163) ((T_INT_CAST) reduce 163) ((T_ISSET) reduce 163) ((T_LINE) reduce 163) ((T_LIST) reduce 163) ((T_LNUMBER) reduce 163) ((T_MATCH) reduce 163) ((T_METHOD_C) reduce 163) ((T_NAME_FULLY_QUALIFIED) reduce 163) ((T_NAME_QUALIFIED) reduce 163) ((T_NAME_RELATIVE) reduce 163) ((T_NEW) reduce 163) ((T_NS_C) reduce 163) ((T_OBJECT_CAST) reduce 163) ((T_PRINT) reduce 163) ((T_READONLY) reduce 163) ((T_REQUIRE) reduce 163) ((T_REQUIRE_ONCE) reduce 163) ((T_RETURN) reduce 163) ((T_START_HEREDOC) reduce 163) ((T_STATIC) reduce 163) ((T_STRING) reduce 163) ((T_STRING_CAST) reduce 163) ((T_SWITCH) reduce 163) ((T_THROW) reduce 163) ((T_TRAIT) reduce 163) ((T_TRAIT_C) reduce 163) ((T_TRY) reduce 163) ((T_UNSET) reduce 163) ((T_UNSET_CAST) reduce 163) ((T_VARIABLE) reduce 163) ((T_WHILE) reduce 163) ((T_YIELD) reduce 163) ((T_YIELD_FROM) reduce 163) (("[") reduce 163) (("`") reduce 163) (("{") reduce 163) (("~") reduce 163)) 20831 ((("!") reduce 219) (("\"") reduce 219) (("$") reduce 219) (("(") reduce 219) (("+") reduce 219) (("-") reduce 219) ((";") reduce 219) (("@") reduce 219) ((T_ABSTRACT) reduce 219) ((T_ARRAY) reduce 219) ((T_ARRAY_CAST) reduce 219) ((T_ATTRIBUTE) reduce 219) ((T_BOOL_CAST) reduce 219) ((T_BREAK) reduce 219) ((T_CLASS) reduce 219) ((T_CLASS_C) reduce 219) ((T_CLONE) reduce 219) ((T_CONSTANT_ENCAPSED_STRING) reduce 219) ((T_CONTINUE) reduce 219) ((T_DEC) reduce 219) ((T_DECLARE) reduce 219) ((T_DIR) reduce 219) ((T_DNUMBER) reduce 219) ((T_DO) reduce 219) ((T_DOUBLE_CAST) reduce 219) ((T_ECHO) reduce 219) ((T_EMPTY) reduce 219) ((T_ENDFOREACH) reduce 219) ((T_ENUM) reduce 219) ((T_EVAL) reduce 219) ((T_EXIT) reduce 219) ((T_FILE) reduce 219) ((T_FINAL) reduce 219) ((T_FN) reduce 219) ((T_FOR) reduce 219) ((T_FOREACH) reduce 219) ((T_FUNCTION) reduce 219) ((T_FUNC_C) reduce 219) ((T_GLOBAL) reduce 219) ((T_GOTO) reduce 219) ((T_HALT_COMPILER) reduce 219) ((T_IF) reduce 219) ((T_INC) reduce 219) ((T_INCLUDE) reduce 219) ((T_INCLUDE_ONCE) reduce 219) ((T_INLINE_HTML) reduce 219) ((T_INTERFACE) reduce 219) ((T_INT_CAST) reduce 219) ((T_ISSET) reduce 219) ((T_LINE) reduce 219) ((T_LIST) reduce 219) ((T_LNUMBER) reduce 219) ((T_MATCH) reduce 219) ((T_METHOD_C) reduce 219) ((T_NAME_FULLY_QUALIFIED) reduce 219) ((T_NAME_QUALIFIED) reduce 219) ((T_NAME_RELATIVE) reduce 219) ((T_NEW) reduce 219) ((T_NS_C) reduce 219) ((T_OBJECT_CAST) reduce 219) ((T_PRINT) reduce 219) ((T_READONLY) reduce 219) ((T_REQUIRE) reduce 219) ((T_REQUIRE_ONCE) reduce 219) ((T_RETURN) reduce 219) ((T_START_HEREDOC) reduce 219) ((T_STATIC) reduce 219) ((T_STRING) reduce 219) ((T_STRING_CAST) reduce 219) ((T_SWITCH) reduce 219) ((T_THROW) reduce 219) ((T_TRAIT) reduce 219) ((T_TRAIT_C) reduce 219) ((T_TRY) reduce 219) ((T_UNSET) reduce 219) ((T_UNSET_CAST) reduce 219) ((T_VARIABLE) reduce 219) ((T_WHILE) reduce 219) ((T_YIELD) reduce 219) ((T_YIELD_FROM) reduce 219) (("[") reduce 219) (("`") reduce 219) (("{") reduce 219) (("~") reduce 219)) 20834 ((("!") reduce 220) (("\"") reduce 220) (("$") reduce 220) (("(") reduce 220) (("+") reduce 220) (("-") reduce 220) ((";") reduce 220) (("@") reduce 220) ((T_ABSTRACT) reduce 220) ((T_ARRAY) reduce 220) ((T_ARRAY_CAST) reduce 220) ((T_ATTRIBUTE) reduce 220) ((T_BOOL_CAST) reduce 220) ((T_BREAK) reduce 220) ((T_CLASS) reduce 220) ((T_CLASS_C) reduce 220) ((T_CLONE) reduce 220) ((T_CONSTANT_ENCAPSED_STRING) reduce 220) ((T_CONTINUE) reduce 220) ((T_DEC) reduce 220) ((T_DECLARE) reduce 220) ((T_DIR) reduce 220) ((T_DNUMBER) reduce 220) ((T_DO) reduce 220) ((T_DOUBLE_CAST) reduce 220) ((T_ECHO) reduce 220) ((T_EMPTY) reduce 220) ((T_ENDFOREACH) reduce 220) ((T_ENUM) reduce 220) ((T_EVAL) reduce 220) ((T_EXIT) reduce 220) ((T_FILE) reduce 220) ((T_FINAL) reduce 220) ((T_FN) reduce 220) ((T_FOR) reduce 220) ((T_FOREACH) reduce 220) ((T_FUNCTION) reduce 220) ((T_FUNC_C) reduce 220) ((T_GLOBAL) reduce 220) ((T_GOTO) reduce 220) ((T_HALT_COMPILER) reduce 220) ((T_IF) reduce 220) ((T_INC) reduce 220) ((T_INCLUDE) reduce 220) ((T_INCLUDE_ONCE) reduce 220) ((T_INLINE_HTML) reduce 220) ((T_INTERFACE) reduce 220) ((T_INT_CAST) reduce 220) ((T_ISSET) reduce 220) ((T_LINE) reduce 220) ((T_LIST) reduce 220) ((T_LNUMBER) reduce 220) ((T_MATCH) reduce 220) ((T_METHOD_C) reduce 220) ((T_NAME_FULLY_QUALIFIED) reduce 220) ((T_NAME_QUALIFIED) reduce 220) ((T_NAME_RELATIVE) reduce 220) ((T_NEW) reduce 220) ((T_NS_C) reduce 220) ((T_OBJECT_CAST) reduce 220) ((T_PRINT) reduce 220) ((T_READONLY) reduce 220) ((T_REQUIRE) reduce 220) ((T_REQUIRE_ONCE) reduce 220) ((T_RETURN) reduce 220) ((T_START_HEREDOC) reduce 220) ((T_STATIC) reduce 220) ((T_STRING) reduce 220) ((T_STRING_CAST) reduce 220) ((T_SWITCH) reduce 220) ((T_THROW) reduce 220) ((T_TRAIT) reduce 220) ((T_TRAIT_C) reduce 220) ((T_TRY) reduce 220) ((T_UNSET) reduce 220) ((T_UNSET_CAST) reduce 220) ((T_VARIABLE) reduce 220) ((T_WHILE) reduce 220) ((T_YIELD) reduce 220) ((T_YIELD_FROM) reduce 220) (("[") reduce 220) (("`") reduce 220) (("{") reduce 220) (("~") reduce 220)) 20836 ((("!") reduce 153) (("\"") reduce 153) (("$") reduce 153) (("(") reduce 153) (("+") reduce 153) (("-") reduce 153) ((";") reduce 153) (("@") reduce 153) ((T_ABSTRACT) reduce 153) ((T_ARRAY) reduce 153) ((T_ARRAY_CAST) reduce 153) ((T_ATTRIBUTE) reduce 153) ((T_BOOL_CAST) reduce 153) ((T_BREAK) reduce 153) ((T_CLASS) reduce 153) ((T_CLASS_C) reduce 153) ((T_CLONE) reduce 153) ((T_CONSTANT_ENCAPSED_STRING) reduce 153) ((T_CONTINUE) reduce 153) ((T_DEC) reduce 153) ((T_DECLARE) reduce 153) ((T_DIR) reduce 153) ((T_DNUMBER) reduce 153) ((T_DO) reduce 153) ((T_DOUBLE_CAST) reduce 153) ((T_ECHO) reduce 153) ((T_EMPTY) reduce 153) ((T_ENDFOREACH) reduce 153) ((T_ENUM) reduce 153) ((T_EVAL) reduce 153) ((T_EXIT) reduce 153) ((T_FILE) reduce 153) ((T_FINAL) reduce 153) ((T_FN) reduce 153) ((T_FOR) reduce 153) ((T_FOREACH) reduce 153) ((T_FUNCTION) reduce 153) ((T_FUNC_C) reduce 153) ((T_GLOBAL) reduce 153) ((T_GOTO) reduce 153) ((T_HALT_COMPILER) reduce 153) ((T_IF) reduce 153) ((T_INC) reduce 153) ((T_INCLUDE) reduce 153) ((T_INCLUDE_ONCE) reduce 153) ((T_INLINE_HTML) reduce 153) ((T_INTERFACE) reduce 153) ((T_INT_CAST) reduce 153) ((T_ISSET) reduce 153) ((T_LINE) reduce 153) ((T_LIST) reduce 153) ((T_LNUMBER) reduce 153) ((T_MATCH) reduce 153) ((T_METHOD_C) reduce 153) ((T_NAME_FULLY_QUALIFIED) reduce 153) ((T_NAME_QUALIFIED) reduce 153) ((T_NAME_RELATIVE) reduce 153) ((T_NEW) reduce 153) ((T_NS_C) reduce 153) ((T_OBJECT_CAST) reduce 153) ((T_PRINT) reduce 153) ((T_READONLY) reduce 153) ((T_REQUIRE) reduce 153) ((T_REQUIRE_ONCE) reduce 153) ((T_RETURN) reduce 153) ((T_START_HEREDOC) reduce 153) ((T_STATIC) reduce 153) ((T_STRING) reduce 153) ((T_STRING_CAST) reduce 153) ((T_SWITCH) reduce 153) ((T_THROW) reduce 153) ((T_TRAIT) reduce 153) ((T_TRAIT_C) reduce 153) ((T_TRY) reduce 153) ((T_UNSET) reduce 153) ((T_UNSET_CAST) reduce 153) ((T_VARIABLE) reduce 153) ((T_WHILE) reduce 153) ((T_YIELD) reduce 153) ((T_YIELD_FROM) reduce 153) (("[") reduce 153) (("`") reduce 153) (("{") reduce 153) (("~") reduce 153)) 20843 ((("!") reduce 187) (("\"") reduce 187) (("$") reduce 187) (("(") reduce 187) (("+") reduce 187) (("-") reduce 187) ((";") reduce 187) (("@") reduce 187) ((T_ABSTRACT) reduce 187) ((T_ARRAY) reduce 187) ((T_ARRAY_CAST) reduce 187) ((T_ATTRIBUTE) reduce 187) ((T_BOOL_CAST) reduce 187) ((T_BREAK) reduce 187) ((T_CLASS) reduce 187) ((T_CLASS_C) reduce 187) ((T_CLONE) reduce 187) ((T_CONSTANT_ENCAPSED_STRING) reduce 187) ((T_CONTINUE) reduce 187) ((T_DEC) reduce 187) ((T_DECLARE) reduce 187) ((T_DIR) reduce 187) ((T_DNUMBER) reduce 187) ((T_DO) reduce 187) ((T_DOUBLE_CAST) reduce 187) ((T_ECHO) reduce 187) ((T_EMPTY) reduce 187) ((T_ENDFOREACH) reduce 187) ((T_ENUM) reduce 187) ((T_EVAL) reduce 187) ((T_EXIT) reduce 187) ((T_FILE) reduce 187) ((T_FINAL) reduce 187) ((T_FN) reduce 187) ((T_FOR) reduce 187) ((T_FOREACH) reduce 187) ((T_FUNCTION) reduce 187) ((T_FUNC_C) reduce 187) ((T_GLOBAL) reduce 187) ((T_GOTO) reduce 187) ((T_HALT_COMPILER) reduce 187) ((T_IF) reduce 187) ((T_INC) reduce 187) ((T_INCLUDE) reduce 187) ((T_INCLUDE_ONCE) reduce 187) ((T_INLINE_HTML) reduce 187) ((T_INTERFACE) reduce 187) ((T_INT_CAST) reduce 187) ((T_ISSET) reduce 187) ((T_LINE) reduce 187) ((T_LIST) reduce 187) ((T_LNUMBER) reduce 187) ((T_MATCH) reduce 187) ((T_METHOD_C) reduce 187) ((T_NAME_FULLY_QUALIFIED) reduce 187) ((T_NAME_QUALIFIED) reduce 187) ((T_NAME_RELATIVE) reduce 187) ((T_NEW) reduce 187) ((T_NS_C) reduce 187) ((T_OBJECT_CAST) reduce 187) ((T_PRINT) reduce 187) ((T_READONLY) reduce 187) ((T_REQUIRE) reduce 187) ((T_REQUIRE_ONCE) reduce 187) ((T_RETURN) reduce 187) ((T_START_HEREDOC) reduce 187) ((T_STATIC) reduce 187) ((T_STRING) reduce 187) ((T_STRING_CAST) reduce 187) ((T_SWITCH) reduce 187) ((T_THROW) reduce 187) ((T_TRAIT) reduce 187) ((T_TRAIT_C) reduce 187) ((T_TRY) reduce 187) ((T_UNSET) reduce 187) ((T_UNSET_CAST) reduce 187) ((T_VARIABLE) reduce 187) ((T_WHILE) reduce 187) ((T_YIELD) reduce 187) ((T_YIELD_FROM) reduce 187) (("[") reduce 187) (("`") reduce 187) (("{") reduce 187) (("~") reduce 187)) 20845 ((("!") reduce 152) (("\"") reduce 152) (("$") reduce 152) (("(") reduce 152) (("+") reduce 152) (("-") reduce 152) ((";") reduce 152) (("@") reduce 152) ((T_ABSTRACT) reduce 152) ((T_ARRAY) reduce 152) ((T_ARRAY_CAST) reduce 152) ((T_ATTRIBUTE) reduce 152) ((T_BOOL_CAST) reduce 152) ((T_BREAK) reduce 152) ((T_CLASS) reduce 152) ((T_CLASS_C) reduce 152) ((T_CLONE) reduce 152) ((T_CONSTANT_ENCAPSED_STRING) reduce 152) ((T_CONTINUE) reduce 152) ((T_DEC) reduce 152) ((T_DECLARE) reduce 152) ((T_DIR) reduce 152) ((T_DNUMBER) reduce 152) ((T_DO) reduce 152) ((T_DOUBLE_CAST) reduce 152) ((T_ECHO) reduce 152) ((T_EMPTY) reduce 152) ((T_ENDFOREACH) reduce 152) ((T_ENUM) reduce 152) ((T_EVAL) reduce 152) ((T_EXIT) reduce 152) ((T_FILE) reduce 152) ((T_FINAL) reduce 152) ((T_FN) reduce 152) ((T_FOR) reduce 152) ((T_FOREACH) reduce 152) ((T_FUNCTION) reduce 152) ((T_FUNC_C) reduce 152) ((T_GLOBAL) reduce 152) ((T_GOTO) reduce 152) ((T_HALT_COMPILER) reduce 152) ((T_IF) reduce 152) ((T_INC) reduce 152) ((T_INCLUDE) reduce 152) ((T_INCLUDE_ONCE) reduce 152) ((T_INLINE_HTML) reduce 152) ((T_INTERFACE) reduce 152) ((T_INT_CAST) reduce 152) ((T_ISSET) reduce 152) ((T_LINE) reduce 152) ((T_LIST) reduce 152) ((T_LNUMBER) reduce 152) ((T_MATCH) reduce 152) ((T_METHOD_C) reduce 152) ((T_NAME_FULLY_QUALIFIED) reduce 152) ((T_NAME_QUALIFIED) reduce 152) ((T_NAME_RELATIVE) reduce 152) ((T_NEW) reduce 152) ((T_NS_C) reduce 152) ((T_OBJECT_CAST) reduce 152) ((T_PRINT) reduce 152) ((T_READONLY) reduce 152) ((T_REQUIRE) reduce 152) ((T_REQUIRE_ONCE) reduce 152) ((T_RETURN) reduce 152) ((T_START_HEREDOC) reduce 152) ((T_STATIC) reduce 152) ((T_STRING) reduce 152) ((T_STRING_CAST) reduce 152) ((T_SWITCH) reduce 152) ((T_THROW) reduce 152) ((T_TRAIT) reduce 152) ((T_TRAIT_C) reduce 152) ((T_TRY) reduce 152) ((T_UNSET) reduce 152) ((T_UNSET_CAST) reduce 152) ((T_VARIABLE) reduce 152) ((T_WHILE) reduce 152) ((T_YIELD) reduce 152) ((T_YIELD_FROM) reduce 152) (("[") reduce 152) (("`") reduce 152) (("{") reduce 152) (("~") reduce 152)) 20848 ((("(") reduce 543) ((")") reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) (("[") reduce 532) (("{") reduce 532)) 20849 ((("(") reduce 467) ((")") reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) (("[") reduce 467) (("{") reduce 467)) 20850 ((("(") reduce 469) ((")") reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) (("[") reduce 469) (("{") reduce 469)) 20856 ((("(") reduce 521) ((")") reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) (("[") reduce 521) (("{") reduce 521)) 20858 ((("(") reduce 520) ((")") reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) (("[") reduce 520) (("{") reduce 520)) 20859 ((("(") reduce 544) ((")") reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) (("[") reduce 544) (("{") reduce 544)) 20860 ((("(") shift) ((")") reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) (("[") reduce 527) (("{") reduce 527)) 20861 ((("(") reduce 546) ((")") reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) (("[") reduce 546) (("{") reduce 546)) 20864 ((("(") reduce 545) ((")") reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) (("[") reduce 545) (("{") reduce 545)) 20865 ((("(") reduce 522) ((")") reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) (("[") reduce 522) (("{") reduce 522)) 20866 ((("(") shift) ((")") reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) (("[") reduce 528) (("{") reduce 528)) 20867 ((("(") reduce 523) ((")") reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) (("[") reduce 523) (("{") reduce 523)) 20868 (((")") reduce 212) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) (("[") reduce 510) (("{") reduce 510)) 20870 ((("(") reduce 483) ((")") reduce 214) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 483) ((T_OBJECT_OPERATOR) reduce 483) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 483) (("[") reduce 483) (("{") reduce 483)) 20871 ((("(") reduce 466) ((")") reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) (("[") reduce 466) (("{") reduce 466)) 20874 (((")") reduce 213)) 20875 ((("(") reduce 531) ((")") reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) (("[") reduce 531) (("{") reduce 531)) 20878 ((("(") reduce 530) ((")") reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) (("[") reduce 530) (("{") reduce 530)) 20879 ((("!") reduce 161) (("\"") reduce 161) (("$") reduce 161) (("(") reduce 161) (("+") reduce 161) (("-") reduce 161) ((";") reduce 161) (("@") reduce 161) ((T_ABSTRACT) reduce 161) ((T_ARRAY) reduce 161) ((T_ARRAY_CAST) reduce 161) ((T_ATTRIBUTE) reduce 161) ((T_BOOL_CAST) reduce 161) ((T_BREAK) reduce 161) ((T_CASE) reduce 161) ((T_CLASS) reduce 161) ((T_CLASS_C) reduce 161) ((T_CLONE) reduce 161) ((T_CONSTANT_ENCAPSED_STRING) reduce 161) ((T_CONTINUE) reduce 161) ((T_DEC) reduce 161) ((T_DECLARE) reduce 161) ((T_DEFAULT) reduce 161) ((T_DIR) reduce 161) ((T_DNUMBER) reduce 161) ((T_DO) reduce 161) ((T_DOUBLE_CAST) reduce 161) ((T_ECHO) reduce 161) ((T_ELSE) reduce 161) ((T_ELSEIF) reduce 161) ((T_EMPTY) reduce 161) ((T_ENDSWITCH) reduce 161) ((T_ENUM) reduce 161) ((T_EVAL) reduce 161) ((T_EXIT) reduce 161) ((T_FILE) reduce 161) ((T_FINAL) reduce 161) ((T_FN) reduce 161) ((T_FOR) reduce 161) ((T_FOREACH) reduce 161) ((T_FUNCTION) reduce 161) ((T_FUNC_C) reduce 161) ((T_GLOBAL) reduce 161) ((T_GOTO) reduce 161) ((T_HALT_COMPILER) reduce 161) ((T_IF) reduce 161) ((T_INC) reduce 161) ((T_INCLUDE) reduce 161) ((T_INCLUDE_ONCE) reduce 161) ((T_INLINE_HTML) reduce 161) ((T_INTERFACE) reduce 161) ((T_INT_CAST) reduce 161) ((T_ISSET) reduce 161) ((T_LINE) reduce 161) ((T_LIST) reduce 161) ((T_LNUMBER) reduce 161) ((T_MATCH) reduce 161) ((T_METHOD_C) reduce 161) ((T_NAME_FULLY_QUALIFIED) reduce 161) ((T_NAME_QUALIFIED) reduce 161) ((T_NAME_RELATIVE) reduce 161) ((T_NEW) reduce 161) ((T_NS_C) reduce 161) ((T_OBJECT_CAST) reduce 161) ((T_PRINT) reduce 161) ((T_READONLY) reduce 161) ((T_REQUIRE) reduce 161) ((T_REQUIRE_ONCE) reduce 161) ((T_RETURN) reduce 161) ((T_START_HEREDOC) reduce 161) ((T_STATIC) reduce 161) ((T_STRING) reduce 161) ((T_STRING_CAST) reduce 161) ((T_SWITCH) reduce 161) ((T_THROW) reduce 161) ((T_TRAIT) reduce 161) ((T_TRAIT_C) reduce 161) ((T_TRY) reduce 161) ((T_UNSET) reduce 161) ((T_UNSET_CAST) reduce 161) ((T_VARIABLE) reduce 161) ((T_WHILE) reduce 161) ((T_YIELD) reduce 161) ((T_YIELD_FROM) reduce 161) (("[") reduce 161) (("`") reduce 161) (("{") reduce 161) (("~") reduce 161)) 20882 ((("(") reduce 543) ((")") reduce 532) ((T_DOUBLE_ARROW) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) (("[") reduce 532) (("{") reduce 532)) 20883 ((("(") reduce 467) ((")") reduce 467) ((T_DOUBLE_ARROW) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) (("[") reduce 467) (("{") reduce 467)) 20884 ((("(") reduce 469) ((")") reduce 469) ((T_DOUBLE_ARROW) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) (("[") reduce 469) (("{") reduce 469)) 20890 ((("(") reduce 521) ((")") reduce 521) ((T_DOUBLE_ARROW) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) (("[") reduce 521) (("{") reduce 521)) 20892 ((("(") reduce 520) ((")") reduce 520) ((T_DOUBLE_ARROW) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) (("[") reduce 520) (("{") reduce 520)) 20893 ((("(") reduce 544) ((")") reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) (("[") reduce 544) (("{") reduce 544)) 20894 ((("(") shift) ((")") reduce 527) ((T_DOUBLE_ARROW) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) (("[") reduce 527) (("{") reduce 527)) 20895 ((("(") reduce 546) ((")") reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) (("[") reduce 546) (("{") reduce 546)) 20898 ((("(") reduce 545) ((")") reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) (("[") reduce 545) (("{") reduce 545)) 20899 ((("(") reduce 522) ((")") reduce 522) ((T_DOUBLE_ARROW) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) (("[") reduce 522) (("{") reduce 522)) 20900 ((("(") shift) ((")") reduce 528) ((T_DOUBLE_ARROW) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) (("[") reduce 528) (("{") reduce 528)) 20901 ((("(") reduce 523) ((")") reduce 523) ((T_DOUBLE_ARROW) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) (("[") reduce 523) (("{") reduce 523)) 20902 (((")") reduce 212) ((T_DOUBLE_ARROW) reduce 212) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) (("[") reduce 510) (("{") reduce 510)) 20904 ((("(") reduce 483) ((")") reduce 214) ((T_DOUBLE_ARROW) reduce 214) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 483) ((T_OBJECT_OPERATOR) reduce 483) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 483) (("[") reduce 483) (("{") reduce 483)) 20905 ((("(") reduce 466) ((")") reduce 466) ((T_DOUBLE_ARROW) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) (("[") reduce 466) (("{") reduce 466)) 20908 (((")") reduce 213) ((T_DOUBLE_ARROW) reduce 213)) 20909 ((("(") reduce 531) ((")") reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) (("[") reduce 531) (("{") reduce 531)) 20912 ((("(") reduce 530) ((")") reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) (("[") reduce 530) (("{") reduce 530)) 21549 ((("!") reduce 150) (("\"") reduce 150) (("$") reduce 150) (("(") reduce 150) (("+") reduce 150) (("-") reduce 150) ((";") reduce 150) (("@") reduce 150) ((T_ABSTRACT) reduce 150) ((T_ARRAY) reduce 150) ((T_ARRAY_CAST) reduce 150) ((T_ATTRIBUTE) reduce 150) ((T_BOOL_CAST) reduce 150) ((T_BREAK) reduce 150) ((T_CASE) reduce 150) ((T_CLASS) reduce 150) ((T_CLASS_C) reduce 150) ((T_CLONE) reduce 150) ((T_CONSTANT_ENCAPSED_STRING) reduce 150) ((T_CONTINUE) reduce 150) ((T_DEC) reduce 150) ((T_DECLARE) reduce 150) ((T_DEFAULT) reduce 150) ((T_DIR) reduce 150) ((T_DNUMBER) reduce 150) ((T_DO) reduce 150) ((T_DOUBLE_CAST) reduce 150) ((T_ECHO) reduce 150) ((T_ELSE) reduce 150) ((T_ELSEIF) reduce 150) ((T_EMPTY) reduce 150) ((T_ENDSWITCH) reduce 150) ((T_ENUM) reduce 150) ((T_EVAL) reduce 150) ((T_EXIT) reduce 150) ((T_FILE) reduce 150) ((T_FINAL) reduce 150) ((T_FN) reduce 150) ((T_FOR) reduce 150) ((T_FOREACH) reduce 150) ((T_FUNCTION) reduce 150) ((T_FUNC_C) reduce 150) ((T_GLOBAL) reduce 150) ((T_GOTO) reduce 150) ((T_HALT_COMPILER) reduce 150) ((T_IF) reduce 150) ((T_INC) reduce 150) ((T_INCLUDE) reduce 150) ((T_INCLUDE_ONCE) reduce 150) ((T_INLINE_HTML) reduce 150) ((T_INTERFACE) reduce 150) ((T_INT_CAST) reduce 150) ((T_ISSET) reduce 150) ((T_LINE) reduce 150) ((T_LIST) reduce 150) ((T_LNUMBER) reduce 150) ((T_MATCH) reduce 150) ((T_METHOD_C) reduce 150) ((T_NAME_FULLY_QUALIFIED) reduce 150) ((T_NAME_QUALIFIED) reduce 150) ((T_NAME_RELATIVE) reduce 150) ((T_NEW) reduce 150) ((T_NS_C) reduce 150) ((T_OBJECT_CAST) reduce 150) ((T_PRINT) reduce 150) ((T_READONLY) reduce 150) ((T_REQUIRE) reduce 150) ((T_REQUIRE_ONCE) reduce 150) ((T_RETURN) reduce 150) ((T_START_HEREDOC) reduce 150) ((T_STATIC) reduce 150) ((T_STRING) reduce 150) ((T_STRING_CAST) reduce 150) ((T_SWITCH) reduce 150) ((T_THROW) reduce 150) ((T_TRAIT) reduce 150) ((T_TRAIT_C) reduce 150) ((T_TRY) reduce 150) ((T_UNSET) reduce 150) ((T_UNSET_CAST) reduce 150) ((T_VARIABLE) reduce 150) ((T_WHILE) reduce 150) ((T_YIELD) reduce 150) ((T_YIELD_FROM) reduce 150) (("[") reduce 150) (("`") reduce 150) (("{") reduce 150) (("~") reduce 150)) 21550 ((("!") reduce 215) (("\"") reduce 215) (("$") reduce 215) (("(") reduce 215) (("+") reduce 215) (("-") reduce 215) ((";") reduce 215) (("@") reduce 215) ((T_ABSTRACT) reduce 215) ((T_ARRAY) reduce 215) ((T_ARRAY_CAST) reduce 215) ((T_ATTRIBUTE) reduce 215) ((T_BOOL_CAST) reduce 215) ((T_BREAK) reduce 215) ((T_CASE) reduce 215) ((T_CLASS) reduce 215) ((T_CLASS_C) reduce 215) ((T_CLONE) reduce 215) ((T_CONSTANT_ENCAPSED_STRING) reduce 215) ((T_CONTINUE) reduce 215) ((T_DEC) reduce 215) ((T_DECLARE) reduce 215) ((T_DEFAULT) reduce 215) ((T_DIR) reduce 215) ((T_DNUMBER) reduce 215) ((T_DO) reduce 215) ((T_DOUBLE_CAST) reduce 215) ((T_ECHO) reduce 215) ((T_ELSE) reduce 215) ((T_ELSEIF) reduce 215) ((T_EMPTY) reduce 215) ((T_ENDSWITCH) reduce 215) ((T_ENUM) reduce 215) ((T_EVAL) reduce 215) ((T_EXIT) reduce 215) ((T_FILE) reduce 215) ((T_FINAL) reduce 215) ((T_FN) reduce 215) ((T_FOR) reduce 215) ((T_FOREACH) reduce 215) ((T_FUNCTION) reduce 215) ((T_FUNC_C) reduce 215) ((T_GLOBAL) reduce 215) ((T_GOTO) reduce 215) ((T_HALT_COMPILER) reduce 215) ((T_IF) reduce 215) ((T_INC) reduce 215) ((T_INCLUDE) reduce 215) ((T_INCLUDE_ONCE) reduce 215) ((T_INLINE_HTML) reduce 215) ((T_INTERFACE) reduce 215) ((T_INT_CAST) reduce 215) ((T_ISSET) reduce 215) ((T_LINE) reduce 215) ((T_LIST) reduce 215) ((T_LNUMBER) reduce 215) ((T_MATCH) reduce 215) ((T_METHOD_C) reduce 215) ((T_NAME_FULLY_QUALIFIED) reduce 215) ((T_NAME_QUALIFIED) reduce 215) ((T_NAME_RELATIVE) reduce 215) ((T_NEW) reduce 215) ((T_NS_C) reduce 215) ((T_OBJECT_CAST) reduce 215) ((T_PRINT) reduce 215) ((T_READONLY) reduce 215) ((T_REQUIRE) reduce 215) ((T_REQUIRE_ONCE) reduce 215) ((T_RETURN) reduce 215) ((T_START_HEREDOC) reduce 215) ((T_STATIC) reduce 215) ((T_STRING) reduce 215) ((T_STRING_CAST) reduce 215) ((T_SWITCH) reduce 215) ((T_THROW) reduce 215) ((T_TRAIT) reduce 215) ((T_TRAIT_C) reduce 215) ((T_TRY) reduce 215) ((T_UNSET) reduce 215) ((T_UNSET_CAST) reduce 215) ((T_VARIABLE) reduce 215) ((T_WHILE) reduce 215) ((T_YIELD) reduce 215) ((T_YIELD_FROM) reduce 215) (("[") reduce 215) (("`") reduce 215) (("{") reduce 215) (("~") reduce 215)) 21553 ((("!") reduce 216) (("\"") reduce 216) (("$") reduce 216) (("(") reduce 216) (("+") reduce 216) (("-") reduce 216) ((";") reduce 216) (("@") reduce 216) ((T_ABSTRACT) reduce 216) ((T_ARRAY) reduce 216) ((T_ARRAY_CAST) reduce 216) ((T_ATTRIBUTE) reduce 216) ((T_BOOL_CAST) reduce 216) ((T_BREAK) reduce 216) ((T_CASE) reduce 216) ((T_CLASS) reduce 216) ((T_CLASS_C) reduce 216) ((T_CLONE) reduce 216) ((T_CONSTANT_ENCAPSED_STRING) reduce 216) ((T_CONTINUE) reduce 216) ((T_DEC) reduce 216) ((T_DECLARE) reduce 216) ((T_DEFAULT) reduce 216) ((T_DIR) reduce 216) ((T_DNUMBER) reduce 216) ((T_DO) reduce 216) ((T_DOUBLE_CAST) reduce 216) ((T_ECHO) reduce 216) ((T_ELSE) reduce 216) ((T_ELSEIF) reduce 216) ((T_EMPTY) reduce 216) ((T_ENDSWITCH) reduce 216) ((T_ENUM) reduce 216) ((T_EVAL) reduce 216) ((T_EXIT) reduce 216) ((T_FILE) reduce 216) ((T_FINAL) reduce 216) ((T_FN) reduce 216) ((T_FOR) reduce 216) ((T_FOREACH) reduce 216) ((T_FUNCTION) reduce 216) ((T_FUNC_C) reduce 216) ((T_GLOBAL) reduce 216) ((T_GOTO) reduce 216) ((T_HALT_COMPILER) reduce 216) ((T_IF) reduce 216) ((T_INC) reduce 216) ((T_INCLUDE) reduce 216) ((T_INCLUDE_ONCE) reduce 216) ((T_INLINE_HTML) reduce 216) ((T_INTERFACE) reduce 216) ((T_INT_CAST) reduce 216) ((T_ISSET) reduce 216) ((T_LINE) reduce 216) ((T_LIST) reduce 216) ((T_LNUMBER) reduce 216) ((T_MATCH) reduce 216) ((T_METHOD_C) reduce 216) ((T_NAME_FULLY_QUALIFIED) reduce 216) ((T_NAME_QUALIFIED) reduce 216) ((T_NAME_RELATIVE) reduce 216) ((T_NEW) reduce 216) ((T_NS_C) reduce 216) ((T_OBJECT_CAST) reduce 216) ((T_PRINT) reduce 216) ((T_READONLY) reduce 216) ((T_REQUIRE) reduce 216) ((T_REQUIRE_ONCE) reduce 216) ((T_RETURN) reduce 216) ((T_START_HEREDOC) reduce 216) ((T_STATIC) reduce 216) ((T_STRING) reduce 216) ((T_STRING_CAST) reduce 216) ((T_SWITCH) reduce 216) ((T_THROW) reduce 216) ((T_TRAIT) reduce 216) ((T_TRAIT_C) reduce 216) ((T_TRY) reduce 216) ((T_UNSET) reduce 216) ((T_UNSET_CAST) reduce 216) ((T_VARIABLE) reduce 216) ((T_WHILE) reduce 216) ((T_YIELD) reduce 216) ((T_YIELD_FROM) reduce 216) (("[") reduce 216) (("`") reduce 216) (("{") reduce 216) (("~") reduce 216)) 21555 ((("!") reduce 157) (("\"") reduce 157) (("$") reduce 157) (("(") reduce 157) (("+") reduce 157) (("-") reduce 157) ((";") reduce 157) (("@") reduce 157) ((T_ABSTRACT) reduce 157) ((T_ARRAY) reduce 157) ((T_ARRAY_CAST) reduce 157) ((T_ATTRIBUTE) reduce 157) ((T_BOOL_CAST) reduce 157) ((T_BREAK) reduce 157) ((T_CASE) reduce 157) ((T_CLASS) reduce 157) ((T_CLASS_C) reduce 157) ((T_CLONE) reduce 157) ((T_CONSTANT_ENCAPSED_STRING) reduce 157) ((T_CONTINUE) reduce 157) ((T_DEC) reduce 157) ((T_DECLARE) reduce 157) ((T_DEFAULT) reduce 157) ((T_DIR) reduce 157) ((T_DNUMBER) reduce 157) ((T_DO) reduce 157) ((T_DOUBLE_CAST) reduce 157) ((T_ECHO) reduce 157) ((T_ELSE) reduce 157) ((T_ELSEIF) reduce 157) ((T_EMPTY) reduce 157) ((T_ENDSWITCH) reduce 157) ((T_ENUM) reduce 157) ((T_EVAL) reduce 157) ((T_EXIT) reduce 157) ((T_FILE) reduce 157) ((T_FINAL) reduce 157) ((T_FN) reduce 157) ((T_FOR) reduce 157) ((T_FOREACH) reduce 157) ((T_FUNCTION) reduce 157) ((T_FUNC_C) reduce 157) ((T_GLOBAL) reduce 157) ((T_GOTO) reduce 157) ((T_HALT_COMPILER) reduce 157) ((T_IF) reduce 157) ((T_INC) reduce 157) ((T_INCLUDE) reduce 157) ((T_INCLUDE_ONCE) reduce 157) ((T_INLINE_HTML) reduce 157) ((T_INTERFACE) reduce 157) ((T_INT_CAST) reduce 157) ((T_ISSET) reduce 157) ((T_LINE) reduce 157) ((T_LIST) reduce 157) ((T_LNUMBER) reduce 157) ((T_MATCH) reduce 157) ((T_METHOD_C) reduce 157) ((T_NAME_FULLY_QUALIFIED) reduce 157) ((T_NAME_QUALIFIED) reduce 157) ((T_NAME_RELATIVE) reduce 157) ((T_NEW) reduce 157) ((T_NS_C) reduce 157) ((T_OBJECT_CAST) reduce 157) ((T_PRINT) reduce 157) ((T_READONLY) reduce 157) ((T_REQUIRE) reduce 157) ((T_REQUIRE_ONCE) reduce 157) ((T_RETURN) reduce 157) ((T_START_HEREDOC) reduce 157) ((T_STATIC) reduce 157) ((T_STRING) reduce 157) ((T_STRING_CAST) reduce 157) ((T_SWITCH) reduce 157) ((T_THROW) reduce 157) ((T_TRAIT) reduce 157) ((T_TRAIT_C) reduce 157) ((T_TRY) reduce 157) ((T_UNSET) reduce 157) ((T_UNSET_CAST) reduce 157) ((T_VARIABLE) reduce 157) ((T_WHILE) reduce 157) ((T_YIELD) reduce 157) ((T_YIELD_FROM) reduce 157) (("[") reduce 157) (("`") reduce 157) (("{") reduce 157) (("~") reduce 157)) 21561 ((("!") reduce 149) (("\"") reduce 149) (("$") reduce 149) (("(") reduce 149) (("+") reduce 149) (("-") reduce 149) ((";") reduce 149) (("@") reduce 149) ((T_ABSTRACT) reduce 149) ((T_ARRAY) reduce 149) ((T_ARRAY_CAST) reduce 149) ((T_ATTRIBUTE) reduce 149) ((T_BOOL_CAST) reduce 149) ((T_BREAK) reduce 149) ((T_CASE) reduce 149) ((T_CLASS) reduce 149) ((T_CLASS_C) reduce 149) ((T_CLONE) reduce 149) ((T_CONSTANT_ENCAPSED_STRING) reduce 149) ((T_CONTINUE) reduce 149) ((T_DEC) reduce 149) ((T_DECLARE) reduce 149) ((T_DEFAULT) reduce 149) ((T_DIR) reduce 149) ((T_DNUMBER) reduce 149) ((T_DO) reduce 149) ((T_DOUBLE_CAST) reduce 149) ((T_ECHO) reduce 149) ((T_ELSE) reduce 149) ((T_ELSEIF) reduce 149) ((T_EMPTY) reduce 149) ((T_ENDSWITCH) reduce 149) ((T_ENUM) reduce 149) ((T_EVAL) reduce 149) ((T_EXIT) reduce 149) ((T_FILE) reduce 149) ((T_FINAL) reduce 149) ((T_FN) reduce 149) ((T_FOR) reduce 149) ((T_FOREACH) reduce 149) ((T_FUNCTION) reduce 149) ((T_FUNC_C) reduce 149) ((T_GLOBAL) reduce 149) ((T_GOTO) reduce 149) ((T_HALT_COMPILER) reduce 149) ((T_IF) reduce 149) ((T_INC) reduce 149) ((T_INCLUDE) reduce 149) ((T_INCLUDE_ONCE) reduce 149) ((T_INLINE_HTML) reduce 149) ((T_INTERFACE) reduce 149) ((T_INT_CAST) reduce 149) ((T_ISSET) reduce 149) ((T_LINE) reduce 149) ((T_LIST) reduce 149) ((T_LNUMBER) reduce 149) ((T_MATCH) reduce 149) ((T_METHOD_C) reduce 149) ((T_NAME_FULLY_QUALIFIED) reduce 149) ((T_NAME_QUALIFIED) reduce 149) ((T_NAME_RELATIVE) reduce 149) ((T_NEW) reduce 149) ((T_NS_C) reduce 149) ((T_OBJECT_CAST) reduce 149) ((T_PRINT) reduce 149) ((T_READONLY) reduce 149) ((T_REQUIRE) reduce 149) ((T_REQUIRE_ONCE) reduce 149) ((T_RETURN) reduce 149) ((T_START_HEREDOC) reduce 149) ((T_STATIC) reduce 149) ((T_STRING) reduce 149) ((T_STRING_CAST) reduce 149) ((T_SWITCH) reduce 149) ((T_THROW) reduce 149) ((T_TRAIT) reduce 149) ((T_TRAIT_C) reduce 149) ((T_TRY) reduce 149) ((T_UNSET) reduce 149) ((T_UNSET_CAST) reduce 149) ((T_VARIABLE) reduce 149) ((T_WHILE) reduce 149) ((T_YIELD) reduce 149) ((T_YIELD_FROM) reduce 149) (("[") reduce 149) (("`") reduce 149) (("{") reduce 149) (("~") reduce 149)) 21566 ((("!") reduce 163) (("\"") reduce 163) (("$") reduce 163) (("(") reduce 163) (("+") reduce 163) (("-") reduce 163) ((";") reduce 163) (("@") reduce 163) ((T_ABSTRACT) reduce 163) ((T_ARRAY) reduce 163) ((T_ARRAY_CAST) reduce 163) ((T_ATTRIBUTE) reduce 163) ((T_BOOL_CAST) reduce 163) ((T_BREAK) reduce 163) ((T_CASE) reduce 163) ((T_CLASS) reduce 163) ((T_CLASS_C) reduce 163) ((T_CLONE) reduce 163) ((T_CONSTANT_ENCAPSED_STRING) reduce 163) ((T_CONTINUE) reduce 163) ((T_DEC) reduce 163) ((T_DECLARE) reduce 163) ((T_DEFAULT) reduce 163) ((T_DIR) reduce 163) ((T_DNUMBER) reduce 163) ((T_DO) reduce 163) ((T_DOUBLE_CAST) reduce 163) ((T_ECHO) reduce 163) ((T_ELSE) reduce 163) ((T_ELSEIF) reduce 163) ((T_EMPTY) reduce 163) ((T_ENDSWITCH) reduce 163) ((T_ENUM) reduce 163) ((T_EVAL) reduce 163) ((T_EXIT) reduce 163) ((T_FILE) reduce 163) ((T_FINAL) reduce 163) ((T_FN) reduce 163) ((T_FOR) reduce 163) ((T_FOREACH) reduce 163) ((T_FUNCTION) reduce 163) ((T_FUNC_C) reduce 163) ((T_GLOBAL) reduce 163) ((T_GOTO) reduce 163) ((T_HALT_COMPILER) reduce 163) ((T_IF) reduce 163) ((T_INC) reduce 163) ((T_INCLUDE) reduce 163) ((T_INCLUDE_ONCE) reduce 163) ((T_INLINE_HTML) reduce 163) ((T_INTERFACE) reduce 163) ((T_INT_CAST) reduce 163) ((T_ISSET) reduce 163) ((T_LINE) reduce 163) ((T_LIST) reduce 163) ((T_LNUMBER) reduce 163) ((T_MATCH) reduce 163) ((T_METHOD_C) reduce 163) ((T_NAME_FULLY_QUALIFIED) reduce 163) ((T_NAME_QUALIFIED) reduce 163) ((T_NAME_RELATIVE) reduce 163) ((T_NEW) reduce 163) ((T_NS_C) reduce 163) ((T_OBJECT_CAST) reduce 163) ((T_PRINT) reduce 163) ((T_READONLY) reduce 163) ((T_REQUIRE) reduce 163) ((T_REQUIRE_ONCE) reduce 163) ((T_RETURN) reduce 163) ((T_START_HEREDOC) reduce 163) ((T_STATIC) reduce 163) ((T_STRING) reduce 163) ((T_STRING_CAST) reduce 163) ((T_SWITCH) reduce 163) ((T_THROW) reduce 163) ((T_TRAIT) reduce 163) ((T_TRAIT_C) reduce 163) ((T_TRY) reduce 163) ((T_UNSET) reduce 163) ((T_UNSET_CAST) reduce 163) ((T_VARIABLE) reduce 163) ((T_WHILE) reduce 163) ((T_YIELD) reduce 163) ((T_YIELD_FROM) reduce 163) (("[") reduce 163) (("`") reduce 163) (("{") reduce 163) (("~") reduce 163)) 21567 ((("!") reduce 219) (("\"") reduce 219) (("$") reduce 219) (("(") reduce 219) (("+") reduce 219) (("-") reduce 219) ((";") reduce 219) (("@") reduce 219) ((T_ABSTRACT) reduce 219) ((T_ARRAY) reduce 219) ((T_ARRAY_CAST) reduce 219) ((T_ATTRIBUTE) reduce 219) ((T_BOOL_CAST) reduce 219) ((T_BREAK) reduce 219) ((T_CASE) reduce 219) ((T_CLASS) reduce 219) ((T_CLASS_C) reduce 219) ((T_CLONE) reduce 219) ((T_CONSTANT_ENCAPSED_STRING) reduce 219) ((T_CONTINUE) reduce 219) ((T_DEC) reduce 219) ((T_DECLARE) reduce 219) ((T_DEFAULT) reduce 219) ((T_DIR) reduce 219) ((T_DNUMBER) reduce 219) ((T_DO) reduce 219) ((T_DOUBLE_CAST) reduce 219) ((T_ECHO) reduce 219) ((T_ELSE) reduce 219) ((T_ELSEIF) reduce 219) ((T_EMPTY) reduce 219) ((T_ENDSWITCH) reduce 219) ((T_ENUM) reduce 219) ((T_EVAL) reduce 219) ((T_EXIT) reduce 219) ((T_FILE) reduce 219) ((T_FINAL) reduce 219) ((T_FN) reduce 219) ((T_FOR) reduce 219) ((T_FOREACH) reduce 219) ((T_FUNCTION) reduce 219) ((T_FUNC_C) reduce 219) ((T_GLOBAL) reduce 219) ((T_GOTO) reduce 219) ((T_HALT_COMPILER) reduce 219) ((T_IF) reduce 219) ((T_INC) reduce 219) ((T_INCLUDE) reduce 219) ((T_INCLUDE_ONCE) reduce 219) ((T_INLINE_HTML) reduce 219) ((T_INTERFACE) reduce 219) ((T_INT_CAST) reduce 219) ((T_ISSET) reduce 219) ((T_LINE) reduce 219) ((T_LIST) reduce 219) ((T_LNUMBER) reduce 219) ((T_MATCH) reduce 219) ((T_METHOD_C) reduce 219) ((T_NAME_FULLY_QUALIFIED) reduce 219) ((T_NAME_QUALIFIED) reduce 219) ((T_NAME_RELATIVE) reduce 219) ((T_NEW) reduce 219) ((T_NS_C) reduce 219) ((T_OBJECT_CAST) reduce 219) ((T_PRINT) reduce 219) ((T_READONLY) reduce 219) ((T_REQUIRE) reduce 219) ((T_REQUIRE_ONCE) reduce 219) ((T_RETURN) reduce 219) ((T_START_HEREDOC) reduce 219) ((T_STATIC) reduce 219) ((T_STRING) reduce 219) ((T_STRING_CAST) reduce 219) ((T_SWITCH) reduce 219) ((T_THROW) reduce 219) ((T_TRAIT) reduce 219) ((T_TRAIT_C) reduce 219) ((T_TRY) reduce 219) ((T_UNSET) reduce 219) ((T_UNSET_CAST) reduce 219) ((T_VARIABLE) reduce 219) ((T_WHILE) reduce 219) ((T_YIELD) reduce 219) ((T_YIELD_FROM) reduce 219) (("[") reduce 219) (("`") reduce 219) (("{") reduce 219) (("~") reduce 219)) 21570 ((("!") reduce 220) (("\"") reduce 220) (("$") reduce 220) (("(") reduce 220) (("+") reduce 220) (("-") reduce 220) ((";") reduce 220) (("@") reduce 220) ((T_ABSTRACT) reduce 220) ((T_ARRAY) reduce 220) ((T_ARRAY_CAST) reduce 220) ((T_ATTRIBUTE) reduce 220) ((T_BOOL_CAST) reduce 220) ((T_BREAK) reduce 220) ((T_CASE) reduce 220) ((T_CLASS) reduce 220) ((T_CLASS_C) reduce 220) ((T_CLONE) reduce 220) ((T_CONSTANT_ENCAPSED_STRING) reduce 220) ((T_CONTINUE) reduce 220) ((T_DEC) reduce 220) ((T_DECLARE) reduce 220) ((T_DEFAULT) reduce 220) ((T_DIR) reduce 220) ((T_DNUMBER) reduce 220) ((T_DO) reduce 220) ((T_DOUBLE_CAST) reduce 220) ((T_ECHO) reduce 220) ((T_ELSE) reduce 220) ((T_ELSEIF) reduce 220) ((T_EMPTY) reduce 220) ((T_ENDSWITCH) reduce 220) ((T_ENUM) reduce 220) ((T_EVAL) reduce 220) ((T_EXIT) reduce 220) ((T_FILE) reduce 220) ((T_FINAL) reduce 220) ((T_FN) reduce 220) ((T_FOR) reduce 220) ((T_FOREACH) reduce 220) ((T_FUNCTION) reduce 220) ((T_FUNC_C) reduce 220) ((T_GLOBAL) reduce 220) ((T_GOTO) reduce 220) ((T_HALT_COMPILER) reduce 220) ((T_IF) reduce 220) ((T_INC) reduce 220) ((T_INCLUDE) reduce 220) ((T_INCLUDE_ONCE) reduce 220) ((T_INLINE_HTML) reduce 220) ((T_INTERFACE) reduce 220) ((T_INT_CAST) reduce 220) ((T_ISSET) reduce 220) ((T_LINE) reduce 220) ((T_LIST) reduce 220) ((T_LNUMBER) reduce 220) ((T_MATCH) reduce 220) ((T_METHOD_C) reduce 220) ((T_NAME_FULLY_QUALIFIED) reduce 220) ((T_NAME_QUALIFIED) reduce 220) ((T_NAME_RELATIVE) reduce 220) ((T_NEW) reduce 220) ((T_NS_C) reduce 220) ((T_OBJECT_CAST) reduce 220) ((T_PRINT) reduce 220) ((T_READONLY) reduce 220) ((T_REQUIRE) reduce 220) ((T_REQUIRE_ONCE) reduce 220) ((T_RETURN) reduce 220) ((T_START_HEREDOC) reduce 220) ((T_STATIC) reduce 220) ((T_STRING) reduce 220) ((T_STRING_CAST) reduce 220) ((T_SWITCH) reduce 220) ((T_THROW) reduce 220) ((T_TRAIT) reduce 220) ((T_TRAIT_C) reduce 220) ((T_TRY) reduce 220) ((T_UNSET) reduce 220) ((T_UNSET_CAST) reduce 220) ((T_VARIABLE) reduce 220) ((T_WHILE) reduce 220) ((T_YIELD) reduce 220) ((T_YIELD_FROM) reduce 220) (("[") reduce 220) (("`") reduce 220) (("{") reduce 220) (("~") reduce 220)) 21572 ((("!") reduce 153) (("\"") reduce 153) (("$") reduce 153) (("(") reduce 153) (("+") reduce 153) (("-") reduce 153) ((";") reduce 153) (("@") reduce 153) ((T_ABSTRACT) reduce 153) ((T_ARRAY) reduce 153) ((T_ARRAY_CAST) reduce 153) ((T_ATTRIBUTE) reduce 153) ((T_BOOL_CAST) reduce 153) ((T_BREAK) reduce 153) ((T_CASE) reduce 153) ((T_CLASS) reduce 153) ((T_CLASS_C) reduce 153) ((T_CLONE) reduce 153) ((T_CONSTANT_ENCAPSED_STRING) reduce 153) ((T_CONTINUE) reduce 153) ((T_DEC) reduce 153) ((T_DECLARE) reduce 153) ((T_DEFAULT) reduce 153) ((T_DIR) reduce 153) ((T_DNUMBER) reduce 153) ((T_DO) reduce 153) ((T_DOUBLE_CAST) reduce 153) ((T_ECHO) reduce 153) ((T_ELSE) reduce 153) ((T_ELSEIF) reduce 153) ((T_EMPTY) reduce 153) ((T_ENDSWITCH) reduce 153) ((T_ENUM) reduce 153) ((T_EVAL) reduce 153) ((T_EXIT) reduce 153) ((T_FILE) reduce 153) ((T_FINAL) reduce 153) ((T_FN) reduce 153) ((T_FOR) reduce 153) ((T_FOREACH) reduce 153) ((T_FUNCTION) reduce 153) ((T_FUNC_C) reduce 153) ((T_GLOBAL) reduce 153) ((T_GOTO) reduce 153) ((T_HALT_COMPILER) reduce 153) ((T_IF) reduce 153) ((T_INC) reduce 153) ((T_INCLUDE) reduce 153) ((T_INCLUDE_ONCE) reduce 153) ((T_INLINE_HTML) reduce 153) ((T_INTERFACE) reduce 153) ((T_INT_CAST) reduce 153) ((T_ISSET) reduce 153) ((T_LINE) reduce 153) ((T_LIST) reduce 153) ((T_LNUMBER) reduce 153) ((T_MATCH) reduce 153) ((T_METHOD_C) reduce 153) ((T_NAME_FULLY_QUALIFIED) reduce 153) ((T_NAME_QUALIFIED) reduce 153) ((T_NAME_RELATIVE) reduce 153) ((T_NEW) reduce 153) ((T_NS_C) reduce 153) ((T_OBJECT_CAST) reduce 153) ((T_PRINT) reduce 153) ((T_READONLY) reduce 153) ((T_REQUIRE) reduce 153) ((T_REQUIRE_ONCE) reduce 153) ((T_RETURN) reduce 153) ((T_START_HEREDOC) reduce 153) ((T_STATIC) reduce 153) ((T_STRING) reduce 153) ((T_STRING_CAST) reduce 153) ((T_SWITCH) reduce 153) ((T_THROW) reduce 153) ((T_TRAIT) reduce 153) ((T_TRAIT_C) reduce 153) ((T_TRY) reduce 153) ((T_UNSET) reduce 153) ((T_UNSET_CAST) reduce 153) ((T_VARIABLE) reduce 153) ((T_WHILE) reduce 153) ((T_YIELD) reduce 153) ((T_YIELD_FROM) reduce 153) (("[") reduce 153) (("`") reduce 153) (("{") reduce 153) (("~") reduce 153)) 21574 ((("!") reduce 152) (("\"") reduce 152) (("$") reduce 152) (("(") reduce 152) (("+") reduce 152) (("-") reduce 152) ((";") reduce 152) (("@") reduce 152) ((T_ABSTRACT) reduce 152) ((T_ARRAY) reduce 152) ((T_ARRAY_CAST) reduce 152) ((T_ATTRIBUTE) reduce 152) ((T_BOOL_CAST) reduce 152) ((T_BREAK) reduce 152) ((T_CASE) reduce 152) ((T_CLASS) reduce 152) ((T_CLASS_C) reduce 152) ((T_CLONE) reduce 152) ((T_CONSTANT_ENCAPSED_STRING) reduce 152) ((T_CONTINUE) reduce 152) ((T_DEC) reduce 152) ((T_DECLARE) reduce 152) ((T_DEFAULT) reduce 152) ((T_DIR) reduce 152) ((T_DNUMBER) reduce 152) ((T_DO) reduce 152) ((T_DOUBLE_CAST) reduce 152) ((T_ECHO) reduce 152) ((T_ELSE) reduce 152) ((T_ELSEIF) reduce 152) ((T_EMPTY) reduce 152) ((T_ENDSWITCH) reduce 152) ((T_ENUM) reduce 152) ((T_EVAL) reduce 152) ((T_EXIT) reduce 152) ((T_FILE) reduce 152) ((T_FINAL) reduce 152) ((T_FN) reduce 152) ((T_FOR) reduce 152) ((T_FOREACH) reduce 152) ((T_FUNCTION) reduce 152) ((T_FUNC_C) reduce 152) ((T_GLOBAL) reduce 152) ((T_GOTO) reduce 152) ((T_HALT_COMPILER) reduce 152) ((T_IF) reduce 152) ((T_INC) reduce 152) ((T_INCLUDE) reduce 152) ((T_INCLUDE_ONCE) reduce 152) ((T_INLINE_HTML) reduce 152) ((T_INTERFACE) reduce 152) ((T_INT_CAST) reduce 152) ((T_ISSET) reduce 152) ((T_LINE) reduce 152) ((T_LIST) reduce 152) ((T_LNUMBER) reduce 152) ((T_MATCH) reduce 152) ((T_METHOD_C) reduce 152) ((T_NAME_FULLY_QUALIFIED) reduce 152) ((T_NAME_QUALIFIED) reduce 152) ((T_NAME_RELATIVE) reduce 152) ((T_NEW) reduce 152) ((T_NS_C) reduce 152) ((T_OBJECT_CAST) reduce 152) ((T_PRINT) reduce 152) ((T_READONLY) reduce 152) ((T_REQUIRE) reduce 152) ((T_REQUIRE_ONCE) reduce 152) ((T_RETURN) reduce 152) ((T_START_HEREDOC) reduce 152) ((T_STATIC) reduce 152) ((T_STRING) reduce 152) ((T_STRING_CAST) reduce 152) ((T_SWITCH) reduce 152) ((T_THROW) reduce 152) ((T_TRAIT) reduce 152) ((T_TRAIT_C) reduce 152) ((T_TRY) reduce 152) ((T_UNSET) reduce 152) ((T_UNSET_CAST) reduce 152) ((T_VARIABLE) reduce 152) ((T_WHILE) reduce 152) ((T_YIELD) reduce 152) ((T_YIELD_FROM) reduce 152) (("[") reduce 152) (("`") reduce 152) (("{") reduce 152) (("~") reduce 152)) 21575 ((("!") reduce 244) (("\"") reduce 244) (("$") reduce 244) (("(") reduce 244) (("+") reduce 244) (("-") reduce 244) ((";") reduce 244) (("@") reduce 244) ((T_ABSTRACT) reduce 244) ((T_ARRAY) reduce 244) ((T_ARRAY_CAST) reduce 244) ((T_ATTRIBUTE) reduce 244) ((T_BOOL_CAST) reduce 244) ((T_BREAK) reduce 244) ((T_CASE) reduce 244) ((T_CLASS) reduce 244) ((T_CLASS_C) reduce 244) ((T_CLONE) reduce 244) ((T_CONSTANT_ENCAPSED_STRING) reduce 244) ((T_CONTINUE) reduce 244) ((T_DEC) reduce 244) ((T_DECLARE) reduce 244) ((T_DEFAULT) reduce 244) ((T_DIR) reduce 244) ((T_DNUMBER) reduce 244) ((T_DO) reduce 244) ((T_DOUBLE_CAST) reduce 244) ((T_ECHO) reduce 244) ((T_EMPTY) reduce 244) ((T_ENDSWITCH) reduce 244) ((T_ENUM) reduce 244) ((T_EVAL) reduce 244) ((T_EXIT) reduce 244) ((T_FILE) reduce 244) ((T_FINAL) reduce 244) ((T_FN) reduce 244) ((T_FOR) reduce 244) ((T_FOREACH) reduce 244) ((T_FUNCTION) reduce 244) ((T_FUNC_C) reduce 244) ((T_GLOBAL) reduce 244) ((T_GOTO) reduce 244) ((T_HALT_COMPILER) reduce 244) ((T_IF) reduce 244) ((T_INC) reduce 244) ((T_INCLUDE) reduce 244) ((T_INCLUDE_ONCE) reduce 244) ((T_INLINE_HTML) reduce 244) ((T_INTERFACE) reduce 244) ((T_INT_CAST) reduce 244) ((T_ISSET) reduce 244) ((T_LINE) reduce 244) ((T_LIST) reduce 244) ((T_LNUMBER) reduce 244) ((T_MATCH) reduce 244) ((T_METHOD_C) reduce 244) ((T_NAME_FULLY_QUALIFIED) reduce 244) ((T_NAME_QUALIFIED) reduce 244) ((T_NAME_RELATIVE) reduce 244) ((T_NEW) reduce 244) ((T_NS_C) reduce 244) ((T_OBJECT_CAST) reduce 244) ((T_PRINT) reduce 244) ((T_READONLY) reduce 244) ((T_REQUIRE) reduce 244) ((T_REQUIRE_ONCE) reduce 244) ((T_RETURN) reduce 244) ((T_START_HEREDOC) reduce 244) ((T_STATIC) reduce 244) ((T_STRING) reduce 244) ((T_STRING_CAST) reduce 244) ((T_SWITCH) reduce 244) ((T_THROW) reduce 244) ((T_TRAIT) reduce 244) ((T_TRAIT_C) reduce 244) ((T_TRY) reduce 244) ((T_UNSET) reduce 244) ((T_UNSET_CAST) reduce 244) ((T_VARIABLE) reduce 244) ((T_WHILE) reduce 244) ((T_YIELD) reduce 244) ((T_YIELD_FROM) reduce 244) (("[") reduce 244) (("`") reduce 244) (("{") reduce 244) (("~") reduce 244)) 21586 ((("!") reduce 455) (("\"") reduce 455) (("$") reduce 455) (("(") reduce 455) (("+") reduce 455) (("-") reduce 455) ((";") reduce 455) (("@") reduce 455) ((T_ABSTRACT) reduce 455) ((T_ARRAY) reduce 455) ((T_ARRAY_CAST) reduce 455) ((T_ATTRIBUTE) reduce 455) ((T_BOOL_CAST) reduce 455) ((T_BREAK) reduce 455) ((T_CASE) reduce 455) ((T_CLASS) reduce 455) ((T_CLASS_C) reduce 455) ((T_CLONE) reduce 455) ((T_CONSTANT_ENCAPSED_STRING) reduce 455) ((T_CONTINUE) reduce 455) ((T_DEC) reduce 455) ((T_DECLARE) reduce 455) ((T_DEFAULT) reduce 455) ((T_DIR) reduce 455) ((T_DNUMBER) reduce 455) ((T_DO) reduce 455) ((T_DOUBLE_CAST) reduce 455) ((T_ECHO) reduce 455) ((T_EMPTY) reduce 455) ((T_ENDSWITCH) reduce 455) ((T_ENUM) reduce 455) ((T_EVAL) reduce 455) ((T_EXIT) reduce 455) ((T_FILE) reduce 455) ((T_FINAL) reduce 455) ((T_FN) reduce 455) ((T_FOR) reduce 455) ((T_FOREACH) reduce 455) ((T_FUNCTION) reduce 455) ((T_FUNC_C) reduce 455) ((T_GLOBAL) reduce 455) ((T_GOTO) reduce 455) ((T_HALT_COMPILER) reduce 455) ((T_IF) reduce 455) ((T_INC) reduce 455) ((T_INCLUDE) reduce 455) ((T_INCLUDE_ONCE) reduce 455) ((T_INLINE_HTML) reduce 455) ((T_INTERFACE) reduce 455) ((T_INT_CAST) reduce 455) ((T_ISSET) reduce 455) ((T_LINE) reduce 455) ((T_LIST) reduce 455) ((T_LNUMBER) reduce 455) ((T_MATCH) reduce 455) ((T_METHOD_C) reduce 455) ((T_NAME_FULLY_QUALIFIED) reduce 455) ((T_NAME_QUALIFIED) reduce 455) ((T_NAME_RELATIVE) reduce 455) ((T_NEW) reduce 455) ((T_NS_C) reduce 455) ((T_OBJECT_CAST) reduce 455) ((T_PRINT) reduce 455) ((T_READONLY) reduce 455) ((T_REQUIRE) reduce 455) ((T_REQUIRE_ONCE) reduce 455) ((T_RETURN) reduce 455) ((T_START_HEREDOC) reduce 455) ((T_STATIC) reduce 455) ((T_STRING) reduce 455) ((T_STRING_CAST) reduce 455) ((T_SWITCH) reduce 455) ((T_THROW) reduce 455) ((T_TRAIT) reduce 455) ((T_TRAIT_C) reduce 455) ((T_TRY) reduce 455) ((T_UNSET) reduce 455) ((T_UNSET_CAST) reduce 455) ((T_VARIABLE) reduce 455) ((T_WHILE) reduce 455) ((T_YIELD) reduce 455) ((T_YIELD_FROM) reduce 455) (("[") reduce 455) (("`") reduce 455) (("{") reduce 455) (("~") reduce 455)) 21587 ((("!") reduce 181) (("\"") reduce 181) (("$") reduce 181) (("(") reduce 181) (("+") reduce 181) (("-") reduce 181) ((";") reduce 181) (("@") reduce 181) ((T_ABSTRACT) reduce 181) ((T_ARRAY) reduce 181) ((T_ARRAY_CAST) reduce 181) ((T_ATTRIBUTE) reduce 181) ((T_BOOL_CAST) reduce 181) ((T_BREAK) reduce 181) ((T_CASE) reduce 181) ((T_CLASS) reduce 181) ((T_CLASS_C) reduce 181) ((T_CLONE) reduce 181) ((T_CONSTANT_ENCAPSED_STRING) reduce 181) ((T_CONTINUE) reduce 181) ((T_DEC) reduce 181) ((T_DECLARE) reduce 181) ((T_DEFAULT) reduce 181) ((T_DIR) reduce 181) ((T_DNUMBER) reduce 181) ((T_DO) reduce 181) ((T_DOUBLE_CAST) reduce 181) ((T_ECHO) reduce 181) ((T_EMPTY) reduce 181) ((T_ENDSWITCH) reduce 181) ((T_ENUM) reduce 181) ((T_EVAL) reduce 181) ((T_EXIT) reduce 181) ((T_FILE) reduce 181) ((T_FINAL) reduce 181) ((T_FN) reduce 181) ((T_FOR) reduce 181) ((T_FOREACH) reduce 181) ((T_FUNCTION) reduce 181) ((T_FUNC_C) reduce 181) ((T_GLOBAL) reduce 181) ((T_GOTO) reduce 181) ((T_HALT_COMPILER) reduce 181) ((T_IF) reduce 181) ((T_INC) reduce 181) ((T_INCLUDE) reduce 181) ((T_INCLUDE_ONCE) reduce 181) ((T_INLINE_HTML) reduce 181) ((T_INTERFACE) reduce 181) ((T_INT_CAST) reduce 181) ((T_ISSET) reduce 181) ((T_LINE) reduce 181) ((T_LIST) reduce 181) ((T_LNUMBER) reduce 181) ((T_MATCH) reduce 181) ((T_METHOD_C) reduce 181) ((T_NAME_FULLY_QUALIFIED) reduce 181) ((T_NAME_QUALIFIED) reduce 181) ((T_NAME_RELATIVE) reduce 181) ((T_NEW) reduce 181) ((T_NS_C) reduce 181) ((T_OBJECT_CAST) reduce 181) ((T_PRINT) reduce 181) ((T_READONLY) reduce 181) ((T_REQUIRE) reduce 181) ((T_REQUIRE_ONCE) reduce 181) ((T_RETURN) reduce 181) ((T_START_HEREDOC) reduce 181) ((T_STATIC) reduce 181) ((T_STRING) reduce 181) ((T_STRING_CAST) reduce 181) ((T_SWITCH) reduce 181) ((T_THROW) reduce 181) ((T_TRAIT) reduce 181) ((T_TRAIT_C) reduce 181) ((T_TRY) reduce 181) ((T_UNSET) reduce 181) ((T_UNSET_CAST) reduce 181) ((T_VARIABLE) reduce 181) ((T_WHILE) reduce 181) ((T_YIELD) reduce 181) ((T_YIELD_FROM) reduce 181) (("[") reduce 181) (("`") reduce 181) (("{") reduce 181) (("~") reduce 181)) 21588 ((("!") reduce 159) (("\"") reduce 159) (("$") reduce 159) (("(") reduce 159) (("+") reduce 159) (("-") reduce 159) ((";") reduce 159) (("@") reduce 159) ((T_ABSTRACT) reduce 159) ((T_ARRAY) reduce 159) ((T_ARRAY_CAST) reduce 159) ((T_ATTRIBUTE) reduce 159) ((T_BOOL_CAST) reduce 159) ((T_BREAK) reduce 159) ((T_CASE) reduce 159) ((T_CLASS) reduce 159) ((T_CLASS_C) reduce 159) ((T_CLONE) reduce 159) ((T_CONSTANT_ENCAPSED_STRING) reduce 159) ((T_CONTINUE) reduce 159) ((T_DEC) reduce 159) ((T_DECLARE) reduce 159) ((T_DEFAULT) reduce 159) ((T_DIR) reduce 159) ((T_DNUMBER) reduce 159) ((T_DO) reduce 159) ((T_DOUBLE_CAST) reduce 159) ((T_ECHO) reduce 159) ((T_EMPTY) reduce 159) ((T_ENDSWITCH) reduce 159) ((T_ENUM) reduce 159) ((T_EVAL) reduce 159) ((T_EXIT) reduce 159) ((T_FILE) reduce 159) ((T_FINAL) reduce 159) ((T_FN) reduce 159) ((T_FOR) reduce 159) ((T_FOREACH) reduce 159) ((T_FUNCTION) reduce 159) ((T_FUNC_C) reduce 159) ((T_GLOBAL) reduce 159) ((T_GOTO) reduce 159) ((T_HALT_COMPILER) reduce 159) ((T_IF) reduce 159) ((T_INC) reduce 159) ((T_INCLUDE) reduce 159) ((T_INCLUDE_ONCE) reduce 159) ((T_INLINE_HTML) reduce 159) ((T_INTERFACE) reduce 159) ((T_INT_CAST) reduce 159) ((T_ISSET) reduce 159) ((T_LINE) reduce 159) ((T_LIST) reduce 159) ((T_LNUMBER) reduce 159) ((T_MATCH) reduce 159) ((T_METHOD_C) reduce 159) ((T_NAME_FULLY_QUALIFIED) reduce 159) ((T_NAME_QUALIFIED) reduce 159) ((T_NAME_RELATIVE) reduce 159) ((T_NEW) reduce 159) ((T_NS_C) reduce 159) ((T_OBJECT_CAST) reduce 159) ((T_PRINT) reduce 159) ((T_READONLY) reduce 159) ((T_REQUIRE) reduce 159) ((T_REQUIRE_ONCE) reduce 159) ((T_RETURN) reduce 159) ((T_START_HEREDOC) reduce 159) ((T_STATIC) reduce 159) ((T_STRING) reduce 159) ((T_STRING_CAST) reduce 159) ((T_SWITCH) reduce 159) ((T_THROW) reduce 159) ((T_TRAIT) reduce 159) ((T_TRAIT_C) reduce 159) ((T_TRY) reduce 159) ((T_UNSET) reduce 159) ((T_UNSET_CAST) reduce 159) ((T_VARIABLE) reduce 159) ((T_WHILE) reduce 159) ((T_YIELD) reduce 159) ((T_YIELD_FROM) reduce 159) (("[") reduce 159) (("`") reduce 159) (("{") reduce 159) (("~") reduce 159)) 21596 ((("!") reduce 186) (("\"") reduce 186) (("$") reduce 186) (("(") reduce 186) (("+") reduce 186) (("-") reduce 186) ((";") reduce 186) (("@") reduce 186) ((T_ABSTRACT) reduce 186) ((T_ARRAY) reduce 186) ((T_ARRAY_CAST) reduce 186) ((T_ATTRIBUTE) reduce 186) ((T_BOOL_CAST) reduce 186) ((T_BREAK) reduce 186) ((T_CASE) reduce 186) ((T_CLASS) reduce 186) ((T_CLASS_C) reduce 186) ((T_CLONE) reduce 186) ((T_CONSTANT_ENCAPSED_STRING) reduce 186) ((T_CONTINUE) reduce 186) ((T_DEC) reduce 186) ((T_DECLARE) reduce 186) ((T_DEFAULT) reduce 186) ((T_DIR) reduce 186) ((T_DNUMBER) reduce 186) ((T_DO) reduce 186) ((T_DOUBLE_CAST) reduce 186) ((T_ECHO) reduce 186) ((T_EMPTY) reduce 186) ((T_ENDSWITCH) reduce 186) ((T_ENUM) reduce 186) ((T_EVAL) reduce 186) ((T_EXIT) reduce 186) ((T_FILE) reduce 186) ((T_FINAL) reduce 186) ((T_FN) reduce 186) ((T_FOR) reduce 186) ((T_FOREACH) reduce 186) ((T_FUNCTION) reduce 186) ((T_FUNC_C) reduce 186) ((T_GLOBAL) reduce 186) ((T_GOTO) reduce 186) ((T_HALT_COMPILER) reduce 186) ((T_IF) reduce 186) ((T_INC) reduce 186) ((T_INCLUDE) reduce 186) ((T_INCLUDE_ONCE) reduce 186) ((T_INLINE_HTML) reduce 186) ((T_INTERFACE) reduce 186) ((T_INT_CAST) reduce 186) ((T_ISSET) reduce 186) ((T_LINE) reduce 186) ((T_LIST) reduce 186) ((T_LNUMBER) reduce 186) ((T_MATCH) reduce 186) ((T_METHOD_C) reduce 186) ((T_NAME_FULLY_QUALIFIED) reduce 186) ((T_NAME_QUALIFIED) reduce 186) ((T_NAME_RELATIVE) reduce 186) ((T_NEW) reduce 186) ((T_NS_C) reduce 186) ((T_OBJECT_CAST) reduce 186) ((T_PRINT) reduce 186) ((T_READONLY) reduce 186) ((T_REQUIRE) reduce 186) ((T_REQUIRE_ONCE) reduce 186) ((T_RETURN) reduce 186) ((T_START_HEREDOC) reduce 186) ((T_STATIC) reduce 186) ((T_STRING) reduce 186) ((T_STRING_CAST) reduce 186) ((T_SWITCH) reduce 186) ((T_THROW) reduce 186) ((T_TRAIT) reduce 186) ((T_TRAIT_C) reduce 186) ((T_TRY) reduce 186) ((T_UNSET) reduce 186) ((T_UNSET_CAST) reduce 186) ((T_VARIABLE) reduce 186) ((T_WHILE) reduce 186) ((T_YIELD) reduce 186) ((T_YIELD_FROM) reduce 186) (("[") reduce 186) (("`") reduce 186) (("{") reduce 186) (("~") reduce 186)) 21597 ((("!") reduce 143) (("\"") reduce 143) (("$") reduce 143) (("(") reduce 143) (("+") reduce 143) (("-") reduce 143) ((";") reduce 143) (("@") reduce 143) ((T_ABSTRACT) reduce 143) ((T_ARRAY) reduce 143) ((T_ARRAY_CAST) reduce 143) ((T_ATTRIBUTE) reduce 143) ((T_BOOL_CAST) reduce 143) ((T_BREAK) reduce 143) ((T_CASE) reduce 143) ((T_CLASS) reduce 143) ((T_CLASS_C) reduce 143) ((T_CLONE) reduce 143) ((T_CONSTANT_ENCAPSED_STRING) reduce 143) ((T_CONTINUE) reduce 143) ((T_DEC) reduce 143) ((T_DECLARE) reduce 143) ((T_DEFAULT) reduce 143) ((T_DIR) reduce 143) ((T_DNUMBER) reduce 143) ((T_DO) reduce 143) ((T_DOUBLE_CAST) reduce 143) ((T_ECHO) reduce 143) ((T_EMPTY) reduce 143) ((T_ENDSWITCH) reduce 143) ((T_ENUM) reduce 143) ((T_EVAL) reduce 143) ((T_EXIT) reduce 143) ((T_FILE) reduce 143) ((T_FINAL) reduce 143) ((T_FN) reduce 143) ((T_FOR) reduce 143) ((T_FOREACH) reduce 143) ((T_FUNCTION) reduce 143) ((T_FUNC_C) reduce 143) ((T_GLOBAL) reduce 143) ((T_GOTO) reduce 143) ((T_HALT_COMPILER) reduce 143) ((T_IF) reduce 143) ((T_INC) reduce 143) ((T_INCLUDE) reduce 143) ((T_INCLUDE_ONCE) reduce 143) ((T_INLINE_HTML) reduce 143) ((T_INTERFACE) reduce 143) ((T_INT_CAST) reduce 143) ((T_ISSET) reduce 143) ((T_LINE) reduce 143) ((T_LIST) reduce 143) ((T_LNUMBER) reduce 143) ((T_MATCH) reduce 143) ((T_METHOD_C) reduce 143) ((T_NAME_FULLY_QUALIFIED) reduce 143) ((T_NAME_QUALIFIED) reduce 143) ((T_NAME_RELATIVE) reduce 143) ((T_NEW) reduce 143) ((T_NS_C) reduce 143) ((T_OBJECT_CAST) reduce 143) ((T_PRINT) reduce 143) ((T_READONLY) reduce 143) ((T_REQUIRE) reduce 143) ((T_REQUIRE_ONCE) reduce 143) ((T_RETURN) reduce 143) ((T_START_HEREDOC) reduce 143) ((T_STATIC) reduce 143) ((T_STRING) reduce 143) ((T_STRING_CAST) reduce 143) ((T_SWITCH) reduce 143) ((T_THROW) reduce 143) ((T_TRAIT) reduce 143) ((T_TRAIT_C) reduce 143) ((T_TRY) reduce 143) ((T_UNSET) reduce 143) ((T_UNSET_CAST) reduce 143) ((T_VARIABLE) reduce 143) ((T_WHILE) reduce 143) ((T_YIELD) reduce 143) ((T_YIELD_FROM) reduce 143) (("[") reduce 143) (("`") reduce 143) (("{") reduce 143) (("~") reduce 143)) 21600 ((("!") reduce 247) (("\"") reduce 247) (("$") reduce 247) (("(") reduce 247) (("+") reduce 247) (("-") reduce 247) ((";") reduce 247) (("@") reduce 247) ((T_ABSTRACT) reduce 247) ((T_ARRAY) reduce 247) ((T_ARRAY_CAST) reduce 247) ((T_ATTRIBUTE) reduce 247) ((T_BOOL_CAST) reduce 247) ((T_BREAK) reduce 247) ((T_CASE) reduce 247) ((T_CLASS) reduce 247) ((T_CLASS_C) reduce 247) ((T_CLONE) reduce 247) ((T_CONSTANT_ENCAPSED_STRING) reduce 247) ((T_CONTINUE) reduce 247) ((T_DEC) reduce 247) ((T_DECLARE) reduce 247) ((T_DEFAULT) reduce 247) ((T_DIR) reduce 247) ((T_DNUMBER) reduce 247) ((T_DO) reduce 247) ((T_DOUBLE_CAST) reduce 247) ((T_ECHO) reduce 247) ((T_EMPTY) reduce 247) ((T_ENDSWITCH) reduce 247) ((T_ENUM) reduce 247) ((T_EVAL) reduce 247) ((T_EXIT) reduce 247) ((T_FILE) reduce 247) ((T_FINAL) reduce 247) ((T_FN) reduce 247) ((T_FOR) reduce 247) ((T_FOREACH) reduce 247) ((T_FUNCTION) reduce 247) ((T_FUNC_C) reduce 247) ((T_GLOBAL) reduce 247) ((T_GOTO) reduce 247) ((T_HALT_COMPILER) reduce 247) ((T_IF) reduce 247) ((T_INC) reduce 247) ((T_INCLUDE) reduce 247) ((T_INCLUDE_ONCE) reduce 247) ((T_INLINE_HTML) reduce 247) ((T_INTERFACE) reduce 247) ((T_INT_CAST) reduce 247) ((T_ISSET) reduce 247) ((T_LINE) reduce 247) ((T_LIST) reduce 247) ((T_LNUMBER) reduce 247) ((T_MATCH) reduce 247) ((T_METHOD_C) reduce 247) ((T_NAME_FULLY_QUALIFIED) reduce 247) ((T_NAME_QUALIFIED) reduce 247) ((T_NAME_RELATIVE) reduce 247) ((T_NEW) reduce 247) ((T_NS_C) reduce 247) ((T_OBJECT_CAST) reduce 247) ((T_PRINT) reduce 247) ((T_READONLY) reduce 247) ((T_REQUIRE) reduce 247) ((T_REQUIRE_ONCE) reduce 247) ((T_RETURN) reduce 247) ((T_START_HEREDOC) reduce 247) ((T_STATIC) reduce 247) ((T_STRING) reduce 247) ((T_STRING_CAST) reduce 247) ((T_SWITCH) reduce 247) ((T_THROW) reduce 247) ((T_TRAIT) reduce 247) ((T_TRAIT_C) reduce 247) ((T_TRY) reduce 247) ((T_UNSET) reduce 247) ((T_UNSET_CAST) reduce 247) ((T_VARIABLE) reduce 247) ((T_WHILE) reduce 247) ((T_YIELD) reduce 247) ((T_YIELD_FROM) reduce 247) (("[") reduce 247) (("`") reduce 247) (("{") reduce 247) (("~") reduce 247)) 21604 ((("!") reduce 248) (("\"") reduce 248) (("$") reduce 248) (("(") reduce 248) (("+") reduce 248) (("-") reduce 248) ((";") reduce 248) (("@") reduce 248) ((T_ABSTRACT) reduce 248) ((T_ARRAY) reduce 248) ((T_ARRAY_CAST) reduce 248) ((T_ATTRIBUTE) reduce 248) ((T_BOOL_CAST) reduce 248) ((T_BREAK) reduce 248) ((T_CASE) reduce 248) ((T_CLASS) reduce 248) ((T_CLASS_C) reduce 248) ((T_CLONE) reduce 248) ((T_CONSTANT_ENCAPSED_STRING) reduce 248) ((T_CONTINUE) reduce 248) ((T_DEC) reduce 248) ((T_DECLARE) reduce 248) ((T_DEFAULT) reduce 248) ((T_DIR) reduce 248) ((T_DNUMBER) reduce 248) ((T_DO) reduce 248) ((T_DOUBLE_CAST) reduce 248) ((T_ECHO) reduce 248) ((T_EMPTY) reduce 248) ((T_ENDSWITCH) reduce 248) ((T_ENUM) reduce 248) ((T_EVAL) reduce 248) ((T_EXIT) reduce 248) ((T_FILE) reduce 248) ((T_FINAL) reduce 248) ((T_FN) reduce 248) ((T_FOR) reduce 248) ((T_FOREACH) reduce 248) ((T_FUNCTION) reduce 248) ((T_FUNC_C) reduce 248) ((T_GLOBAL) reduce 248) ((T_GOTO) reduce 248) ((T_HALT_COMPILER) reduce 248) ((T_IF) reduce 248) ((T_INC) reduce 248) ((T_INCLUDE) reduce 248) ((T_INCLUDE_ONCE) reduce 248) ((T_INLINE_HTML) reduce 248) ((T_INTERFACE) reduce 248) ((T_INT_CAST) reduce 248) ((T_ISSET) reduce 248) ((T_LINE) reduce 248) ((T_LIST) reduce 248) ((T_LNUMBER) reduce 248) ((T_MATCH) reduce 248) ((T_METHOD_C) reduce 248) ((T_NAME_FULLY_QUALIFIED) reduce 248) ((T_NAME_QUALIFIED) reduce 248) ((T_NAME_RELATIVE) reduce 248) ((T_NEW) reduce 248) ((T_NS_C) reduce 248) ((T_OBJECT_CAST) reduce 248) ((T_PRINT) reduce 248) ((T_READONLY) reduce 248) ((T_REQUIRE) reduce 248) ((T_REQUIRE_ONCE) reduce 248) ((T_RETURN) reduce 248) ((T_START_HEREDOC) reduce 248) ((T_STATIC) reduce 248) ((T_STRING) reduce 248) ((T_STRING_CAST) reduce 248) ((T_SWITCH) reduce 248) ((T_THROW) reduce 248) ((T_TRAIT) reduce 248) ((T_TRAIT_C) reduce 248) ((T_TRY) reduce 248) ((T_UNSET) reduce 248) ((T_UNSET_CAST) reduce 248) ((T_VARIABLE) reduce 248) ((T_WHILE) reduce 248) ((T_YIELD) reduce 248) ((T_YIELD_FROM) reduce 248) (("[") reduce 248) (("`") reduce 248) (("{") reduce 248) (("~") reduce 248)) 21609 ((("!") reduce 239) (("\"") reduce 239) (("$") reduce 239) (("(") reduce 239) (("+") reduce 239) (("-") reduce 239) ((";") reduce 239) (("@") reduce 239) ((T_ABSTRACT) reduce 239) ((T_ARRAY) reduce 239) ((T_ARRAY_CAST) reduce 239) ((T_ATTRIBUTE) reduce 239) ((T_BOOL_CAST) reduce 239) ((T_BREAK) reduce 239) ((T_CASE) reduce 239) ((T_CLASS) reduce 239) ((T_CLASS_C) reduce 239) ((T_CLONE) reduce 239) ((T_CONSTANT_ENCAPSED_STRING) reduce 239) ((T_CONTINUE) reduce 239) ((T_DEC) reduce 239) ((T_DECLARE) reduce 239) ((T_DEFAULT) reduce 239) ((T_DIR) reduce 239) ((T_DNUMBER) reduce 239) ((T_DO) reduce 239) ((T_DOUBLE_CAST) reduce 239) ((T_ECHO) reduce 239) ((T_EMPTY) reduce 239) ((T_ENDSWITCH) reduce 239) ((T_ENUM) reduce 239) ((T_EVAL) reduce 239) ((T_EXIT) reduce 239) ((T_FILE) reduce 239) ((T_FINAL) reduce 239) ((T_FN) reduce 239) ((T_FOR) reduce 239) ((T_FOREACH) reduce 239) ((T_FUNCTION) reduce 239) ((T_FUNC_C) reduce 239) ((T_GLOBAL) reduce 239) ((T_GOTO) reduce 239) ((T_HALT_COMPILER) reduce 239) ((T_IF) reduce 239) ((T_INC) reduce 239) ((T_INCLUDE) reduce 239) ((T_INCLUDE_ONCE) reduce 239) ((T_INLINE_HTML) reduce 239) ((T_INTERFACE) reduce 239) ((T_INT_CAST) reduce 239) ((T_ISSET) reduce 239) ((T_LINE) reduce 239) ((T_LIST) reduce 239) ((T_LNUMBER) reduce 239) ((T_MATCH) reduce 239) ((T_METHOD_C) reduce 239) ((T_NAME_FULLY_QUALIFIED) reduce 239) ((T_NAME_QUALIFIED) reduce 239) ((T_NAME_RELATIVE) reduce 239) ((T_NEW) reduce 239) ((T_NS_C) reduce 239) ((T_OBJECT_CAST) reduce 239) ((T_PRINT) reduce 239) ((T_READONLY) reduce 239) ((T_REQUIRE) reduce 239) ((T_REQUIRE_ONCE) reduce 239) ((T_RETURN) reduce 239) ((T_START_HEREDOC) reduce 239) ((T_STATIC) reduce 239) ((T_STRING) reduce 239) ((T_STRING_CAST) reduce 239) ((T_SWITCH) reduce 239) ((T_THROW) reduce 239) ((T_TRAIT) reduce 239) ((T_TRAIT_C) reduce 239) ((T_TRY) reduce 239) ((T_UNSET) reduce 239) ((T_UNSET_CAST) reduce 239) ((T_VARIABLE) reduce 239) ((T_WHILE) reduce 239) ((T_YIELD) reduce 239) ((T_YIELD_FROM) reduce 239) (("[") reduce 239) (("`") reduce 239) (("{") reduce 239) (("~") reduce 239)) 21610 ((("!") reduce 148) (("\"") reduce 148) (("$") reduce 148) (("(") reduce 148) (("+") reduce 148) (("-") reduce 148) ((";") reduce 148) (("@") reduce 148) ((T_ABSTRACT) reduce 148) ((T_ARRAY) reduce 148) ((T_ARRAY_CAST) reduce 148) ((T_ATTRIBUTE) reduce 148) ((T_BOOL_CAST) reduce 148) ((T_BREAK) reduce 148) ((T_CASE) reduce 148) ((T_CLASS) reduce 148) ((T_CLASS_C) reduce 148) ((T_CLONE) reduce 148) ((T_CONSTANT_ENCAPSED_STRING) reduce 148) ((T_CONTINUE) reduce 148) ((T_DEC) reduce 148) ((T_DECLARE) reduce 148) ((T_DEFAULT) reduce 148) ((T_DIR) reduce 148) ((T_DNUMBER) reduce 148) ((T_DO) reduce 148) ((T_DOUBLE_CAST) reduce 148) ((T_ECHO) reduce 148) ((T_EMPTY) reduce 148) ((T_ENDSWITCH) reduce 148) ((T_ENUM) reduce 148) ((T_EVAL) reduce 148) ((T_EXIT) reduce 148) ((T_FILE) reduce 148) ((T_FINAL) reduce 148) ((T_FN) reduce 148) ((T_FOR) reduce 148) ((T_FOREACH) reduce 148) ((T_FUNCTION) reduce 148) ((T_FUNC_C) reduce 148) ((T_GLOBAL) reduce 148) ((T_GOTO) reduce 148) ((T_HALT_COMPILER) reduce 148) ((T_IF) reduce 148) ((T_INC) reduce 148) ((T_INCLUDE) reduce 148) ((T_INCLUDE_ONCE) reduce 148) ((T_INLINE_HTML) reduce 148) ((T_INTERFACE) reduce 148) ((T_INT_CAST) reduce 148) ((T_ISSET) reduce 148) ((T_LINE) reduce 148) ((T_LIST) reduce 148) ((T_LNUMBER) reduce 148) ((T_MATCH) reduce 148) ((T_METHOD_C) reduce 148) ((T_NAME_FULLY_QUALIFIED) reduce 148) ((T_NAME_QUALIFIED) reduce 148) ((T_NAME_RELATIVE) reduce 148) ((T_NEW) reduce 148) ((T_NS_C) reduce 148) ((T_OBJECT_CAST) reduce 148) ((T_PRINT) reduce 148) ((T_READONLY) reduce 148) ((T_REQUIRE) reduce 148) ((T_REQUIRE_ONCE) reduce 148) ((T_RETURN) reduce 148) ((T_START_HEREDOC) reduce 148) ((T_STATIC) reduce 148) ((T_STRING) reduce 148) ((T_STRING_CAST) reduce 148) ((T_SWITCH) reduce 148) ((T_THROW) reduce 148) ((T_TRAIT) reduce 148) ((T_TRAIT_C) reduce 148) ((T_TRY) reduce 148) ((T_UNSET) reduce 148) ((T_UNSET_CAST) reduce 148) ((T_VARIABLE) reduce 148) ((T_WHILE) reduce 148) ((T_YIELD) reduce 148) ((T_YIELD_FROM) reduce 148) (("[") reduce 148) (("`") reduce 148) (("{") reduce 148) (("~") reduce 148)) 21613 ((("!") reduce 240) (("\"") reduce 240) (("$") reduce 240) (("(") reduce 240) (("+") reduce 240) (("-") reduce 240) ((";") reduce 240) (("@") reduce 240) ((T_ABSTRACT) reduce 240) ((T_ARRAY) reduce 240) ((T_ARRAY_CAST) reduce 240) ((T_ATTRIBUTE) reduce 240) ((T_BOOL_CAST) reduce 240) ((T_BREAK) reduce 240) ((T_CASE) reduce 240) ((T_CLASS) reduce 240) ((T_CLASS_C) reduce 240) ((T_CLONE) reduce 240) ((T_CONSTANT_ENCAPSED_STRING) reduce 240) ((T_CONTINUE) reduce 240) ((T_DEC) reduce 240) ((T_DECLARE) reduce 240) ((T_DEFAULT) reduce 240) ((T_DIR) reduce 240) ((T_DNUMBER) reduce 240) ((T_DO) reduce 240) ((T_DOUBLE_CAST) reduce 240) ((T_ECHO) reduce 240) ((T_EMPTY) reduce 240) ((T_ENDSWITCH) reduce 240) ((T_ENUM) reduce 240) ((T_EVAL) reduce 240) ((T_EXIT) reduce 240) ((T_FILE) reduce 240) ((T_FINAL) reduce 240) ((T_FN) reduce 240) ((T_FOR) reduce 240) ((T_FOREACH) reduce 240) ((T_FUNCTION) reduce 240) ((T_FUNC_C) reduce 240) ((T_GLOBAL) reduce 240) ((T_GOTO) reduce 240) ((T_HALT_COMPILER) reduce 240) ((T_IF) reduce 240) ((T_INC) reduce 240) ((T_INCLUDE) reduce 240) ((T_INCLUDE_ONCE) reduce 240) ((T_INLINE_HTML) reduce 240) ((T_INTERFACE) reduce 240) ((T_INT_CAST) reduce 240) ((T_ISSET) reduce 240) ((T_LINE) reduce 240) ((T_LIST) reduce 240) ((T_LNUMBER) reduce 240) ((T_MATCH) reduce 240) ((T_METHOD_C) reduce 240) ((T_NAME_FULLY_QUALIFIED) reduce 240) ((T_NAME_QUALIFIED) reduce 240) ((T_NAME_RELATIVE) reduce 240) ((T_NEW) reduce 240) ((T_NS_C) reduce 240) ((T_OBJECT_CAST) reduce 240) ((T_PRINT) reduce 240) ((T_READONLY) reduce 240) ((T_REQUIRE) reduce 240) ((T_REQUIRE_ONCE) reduce 240) ((T_RETURN) reduce 240) ((T_START_HEREDOC) reduce 240) ((T_STATIC) reduce 240) ((T_STRING) reduce 240) ((T_STRING_CAST) reduce 240) ((T_SWITCH) reduce 240) ((T_THROW) reduce 240) ((T_TRAIT) reduce 240) ((T_TRAIT_C) reduce 240) ((T_TRY) reduce 240) ((T_UNSET) reduce 240) ((T_UNSET_CAST) reduce 240) ((T_VARIABLE) reduce 240) ((T_WHILE) reduce 240) ((T_YIELD) reduce 240) ((T_YIELD_FROM) reduce 240) (("[") reduce 240) (("`") reduce 240) (("{") reduce 240) (("~") reduce 240)) 21618 ((("!") reduce 160) (("\"") reduce 160) (("$") reduce 160) (("(") reduce 160) (("+") reduce 160) (("-") reduce 160) ((";") reduce 160) (("@") reduce 160) ((T_ABSTRACT) reduce 160) ((T_ARRAY) reduce 160) ((T_ARRAY_CAST) reduce 160) ((T_ATTRIBUTE) reduce 160) ((T_BOOL_CAST) reduce 160) ((T_BREAK) reduce 160) ((T_CASE) reduce 160) ((T_CLASS) reduce 160) ((T_CLASS_C) reduce 160) ((T_CLONE) reduce 160) ((T_CONSTANT_ENCAPSED_STRING) reduce 160) ((T_CONTINUE) reduce 160) ((T_DEC) reduce 160) ((T_DECLARE) reduce 160) ((T_DEFAULT) reduce 160) ((T_DIR) reduce 160) ((T_DNUMBER) reduce 160) ((T_DO) reduce 160) ((T_DOUBLE_CAST) reduce 160) ((T_ECHO) reduce 160) ((T_EMPTY) reduce 160) ((T_ENDSWITCH) reduce 160) ((T_ENUM) reduce 160) ((T_EVAL) reduce 160) ((T_EXIT) reduce 160) ((T_FILE) reduce 160) ((T_FINAL) reduce 160) ((T_FN) reduce 160) ((T_FOR) reduce 160) ((T_FOREACH) reduce 160) ((T_FUNCTION) reduce 160) ((T_FUNC_C) reduce 160) ((T_GLOBAL) reduce 160) ((T_GOTO) reduce 160) ((T_HALT_COMPILER) reduce 160) ((T_IF) reduce 160) ((T_INC) reduce 160) ((T_INCLUDE) reduce 160) ((T_INCLUDE_ONCE) reduce 160) ((T_INLINE_HTML) reduce 160) ((T_INTERFACE) reduce 160) ((T_INT_CAST) reduce 160) ((T_ISSET) reduce 160) ((T_LINE) reduce 160) ((T_LIST) reduce 160) ((T_LNUMBER) reduce 160) ((T_MATCH) reduce 160) ((T_METHOD_C) reduce 160) ((T_NAME_FULLY_QUALIFIED) reduce 160) ((T_NAME_QUALIFIED) reduce 160) ((T_NAME_RELATIVE) reduce 160) ((T_NEW) reduce 160) ((T_NS_C) reduce 160) ((T_OBJECT_CAST) reduce 160) ((T_PRINT) reduce 160) ((T_READONLY) reduce 160) ((T_REQUIRE) reduce 160) ((T_REQUIRE_ONCE) reduce 160) ((T_RETURN) reduce 160) ((T_START_HEREDOC) reduce 160) ((T_STATIC) reduce 160) ((T_STRING) reduce 160) ((T_STRING_CAST) reduce 160) ((T_SWITCH) reduce 160) ((T_THROW) reduce 160) ((T_TRAIT) reduce 160) ((T_TRAIT_C) reduce 160) ((T_TRY) reduce 160) ((T_UNSET) reduce 160) ((T_UNSET_CAST) reduce 160) ((T_VARIABLE) reduce 160) ((T_WHILE) reduce 160) ((T_YIELD) reduce 160) ((T_YIELD_FROM) reduce 160) (("[") reduce 160) (("`") reduce 160) (("{") reduce 160) (("~") reduce 160)) 21621 ((("!") reduce 168) (("\"") reduce 168) (("$") reduce 168) (("(") reduce 168) (("+") reduce 168) (("-") reduce 168) ((";") reduce 168) (("@") reduce 168) ((T_ABSTRACT) reduce 168) ((T_ARRAY) reduce 168) ((T_ARRAY_CAST) reduce 168) ((T_ATTRIBUTE) reduce 168) ((T_BOOL_CAST) reduce 168) ((T_BREAK) reduce 168) ((T_CASE) reduce 168) ((T_CATCH) reduce 168) ((T_CLASS) reduce 168) ((T_CLASS_C) reduce 168) ((T_CLONE) reduce 168) ((T_CONSTANT_ENCAPSED_STRING) reduce 168) ((T_CONTINUE) reduce 168) ((T_DEC) reduce 168) ((T_DECLARE) reduce 168) ((T_DEFAULT) reduce 168) ((T_DIR) reduce 168) ((T_DNUMBER) reduce 168) ((T_DO) reduce 168) ((T_DOUBLE_CAST) reduce 168) ((T_ECHO) reduce 168) ((T_EMPTY) reduce 168) ((T_ENDSWITCH) reduce 168) ((T_ENUM) reduce 168) ((T_EVAL) reduce 168) ((T_EXIT) reduce 168) ((T_FILE) reduce 168) ((T_FINAL) reduce 168) ((T_FINALLY) reduce 168) ((T_FN) reduce 168) ((T_FOR) reduce 168) ((T_FOREACH) reduce 168) ((T_FUNCTION) reduce 168) ((T_FUNC_C) reduce 168) ((T_GLOBAL) reduce 168) ((T_GOTO) reduce 168) ((T_HALT_COMPILER) reduce 168) ((T_IF) reduce 168) ((T_INC) reduce 168) ((T_INCLUDE) reduce 168) ((T_INCLUDE_ONCE) reduce 168) ((T_INLINE_HTML) reduce 168) ((T_INTERFACE) reduce 168) ((T_INT_CAST) reduce 168) ((T_ISSET) reduce 168) ((T_LINE) reduce 168) ((T_LIST) reduce 168) ((T_LNUMBER) reduce 168) ((T_MATCH) reduce 168) ((T_METHOD_C) reduce 168) ((T_NAME_FULLY_QUALIFIED) reduce 168) ((T_NAME_QUALIFIED) reduce 168) ((T_NAME_RELATIVE) reduce 168) ((T_NEW) reduce 168) ((T_NS_C) reduce 168) ((T_OBJECT_CAST) reduce 168) ((T_PRINT) reduce 168) ((T_READONLY) reduce 168) ((T_REQUIRE) reduce 168) ((T_REQUIRE_ONCE) reduce 168) ((T_RETURN) reduce 168) ((T_START_HEREDOC) reduce 168) ((T_STATIC) reduce 168) ((T_STRING) reduce 168) ((T_STRING_CAST) reduce 168) ((T_SWITCH) reduce 168) ((T_THROW) reduce 168) ((T_TRAIT) reduce 168) ((T_TRAIT_C) reduce 168) ((T_TRY) reduce 168) ((T_UNSET) reduce 168) ((T_UNSET_CAST) reduce 168) ((T_VARIABLE) reduce 168) ((T_WHILE) reduce 168) ((T_YIELD) reduce 168) ((T_YIELD_FROM) reduce 168) (("[") reduce 168) (("`") reduce 168) (("{") reduce 168) (("~") reduce 168)) 21622 ((("!") reduce 174) (("\"") reduce 174) (("$") reduce 174) (("(") reduce 174) (("+") reduce 174) (("-") reduce 174) ((";") reduce 174) (("@") reduce 174) ((T_ABSTRACT) reduce 174) ((T_ARRAY) reduce 174) ((T_ARRAY_CAST) reduce 174) ((T_ATTRIBUTE) reduce 174) ((T_BOOL_CAST) reduce 174) ((T_BREAK) reduce 174) ((T_CASE) reduce 174) ((T_CATCH) shift) ((T_CLASS) reduce 174) ((T_CLASS_C) reduce 174) ((T_CLONE) reduce 174) ((T_CONSTANT_ENCAPSED_STRING) reduce 174) ((T_CONTINUE) reduce 174) ((T_DEC) reduce 174) ((T_DECLARE) reduce 174) ((T_DEFAULT) reduce 174) ((T_DIR) reduce 174) ((T_DNUMBER) reduce 174) ((T_DO) reduce 174) ((T_DOUBLE_CAST) reduce 174) ((T_ECHO) reduce 174) ((T_EMPTY) reduce 174) ((T_ENDSWITCH) reduce 174) ((T_ENUM) reduce 174) ((T_EVAL) reduce 174) ((T_EXIT) reduce 174) ((T_FILE) reduce 174) ((T_FINAL) reduce 174) ((T_FINALLY) shift) ((T_FN) reduce 174) ((T_FOR) reduce 174) ((T_FOREACH) reduce 174) ((T_FUNCTION) reduce 174) ((T_FUNC_C) reduce 174) ((T_GLOBAL) reduce 174) ((T_GOTO) reduce 174) ((T_HALT_COMPILER) reduce 174) ((T_IF) reduce 174) ((T_INC) reduce 174) ((T_INCLUDE) reduce 174) ((T_INCLUDE_ONCE) reduce 174) ((T_INLINE_HTML) reduce 174) ((T_INTERFACE) reduce 174) ((T_INT_CAST) reduce 174) ((T_ISSET) reduce 174) ((T_LINE) reduce 174) ((T_LIST) reduce 174) ((T_LNUMBER) reduce 174) ((T_MATCH) reduce 174) ((T_METHOD_C) reduce 174) ((T_NAME_FULLY_QUALIFIED) reduce 174) ((T_NAME_QUALIFIED) reduce 174) ((T_NAME_RELATIVE) reduce 174) ((T_NEW) reduce 174) ((T_NS_C) reduce 174) ((T_OBJECT_CAST) reduce 174) ((T_PRINT) reduce 174) ((T_READONLY) reduce 174) ((T_REQUIRE) reduce 174) ((T_REQUIRE_ONCE) reduce 174) ((T_RETURN) reduce 174) ((T_START_HEREDOC) reduce 174) ((T_STATIC) reduce 174) ((T_STRING) reduce 174) ((T_STRING_CAST) reduce 174) ((T_SWITCH) reduce 174) ((T_THROW) reduce 174) ((T_TRAIT) reduce 174) ((T_TRAIT_C) reduce 174) ((T_TRY) reduce 174) ((T_UNSET) reduce 174) ((T_UNSET_CAST) reduce 174) ((T_VARIABLE) reduce 174) ((T_WHILE) reduce 174) ((T_YIELD) reduce 174) ((T_YIELD_FROM) reduce 174) (("[") reduce 174) (("`") reduce 174) (("{") reduce 174) (("~") reduce 174)) 21625 ((("!") reduce 165) (("\"") reduce 165) (("$") reduce 165) (("(") reduce 165) (("+") reduce 165) (("-") reduce 165) ((";") reduce 165) (("@") reduce 165) ((T_ABSTRACT) reduce 165) ((T_ARRAY) reduce 165) ((T_ARRAY_CAST) reduce 165) ((T_ATTRIBUTE) reduce 165) ((T_BOOL_CAST) reduce 165) ((T_BREAK) reduce 165) ((T_CASE) reduce 165) ((T_CLASS) reduce 165) ((T_CLASS_C) reduce 165) ((T_CLONE) reduce 165) ((T_CONSTANT_ENCAPSED_STRING) reduce 165) ((T_CONTINUE) reduce 165) ((T_DEC) reduce 165) ((T_DECLARE) reduce 165) ((T_DEFAULT) reduce 165) ((T_DIR) reduce 165) ((T_DNUMBER) reduce 165) ((T_DO) reduce 165) ((T_DOUBLE_CAST) reduce 165) ((T_ECHO) reduce 165) ((T_EMPTY) reduce 165) ((T_ENDSWITCH) reduce 165) ((T_ENUM) reduce 165) ((T_EVAL) reduce 165) ((T_EXIT) reduce 165) ((T_FILE) reduce 165) ((T_FINAL) reduce 165) ((T_FN) reduce 165) ((T_FOR) reduce 165) ((T_FOREACH) reduce 165) ((T_FUNCTION) reduce 165) ((T_FUNC_C) reduce 165) ((T_GLOBAL) reduce 165) ((T_GOTO) reduce 165) ((T_HALT_COMPILER) reduce 165) ((T_IF) reduce 165) ((T_INC) reduce 165) ((T_INCLUDE) reduce 165) ((T_INCLUDE_ONCE) reduce 165) ((T_INLINE_HTML) reduce 165) ((T_INTERFACE) reduce 165) ((T_INT_CAST) reduce 165) ((T_ISSET) reduce 165) ((T_LINE) reduce 165) ((T_LIST) reduce 165) ((T_LNUMBER) reduce 165) ((T_MATCH) reduce 165) ((T_METHOD_C) reduce 165) ((T_NAME_FULLY_QUALIFIED) reduce 165) ((T_NAME_QUALIFIED) reduce 165) ((T_NAME_RELATIVE) reduce 165) ((T_NEW) reduce 165) ((T_NS_C) reduce 165) ((T_OBJECT_CAST) reduce 165) ((T_PRINT) reduce 165) ((T_READONLY) reduce 165) ((T_REQUIRE) reduce 165) ((T_REQUIRE_ONCE) reduce 165) ((T_RETURN) reduce 165) ((T_START_HEREDOC) reduce 165) ((T_STATIC) reduce 165) ((T_STRING) reduce 165) ((T_STRING_CAST) reduce 165) ((T_SWITCH) reduce 165) ((T_THROW) reduce 165) ((T_TRAIT) reduce 165) ((T_TRAIT_C) reduce 165) ((T_TRY) reduce 165) ((T_UNSET) reduce 165) ((T_UNSET_CAST) reduce 165) ((T_VARIABLE) reduce 165) ((T_WHILE) reduce 165) ((T_YIELD) reduce 165) ((T_YIELD_FROM) reduce 165) (("[") reduce 165) (("`") reduce 165) (("{") reduce 165) (("~") reduce 165)) 21628 ((("!") reduce 175) (("\"") reduce 175) (("$") reduce 175) (("(") reduce 175) (("+") reduce 175) (("-") reduce 175) ((";") reduce 175) (("@") reduce 175) ((T_ABSTRACT) reduce 175) ((T_ARRAY) reduce 175) ((T_ARRAY_CAST) reduce 175) ((T_ATTRIBUTE) reduce 175) ((T_BOOL_CAST) reduce 175) ((T_BREAK) reduce 175) ((T_CASE) reduce 175) ((T_CLASS) reduce 175) ((T_CLASS_C) reduce 175) ((T_CLONE) reduce 175) ((T_CONSTANT_ENCAPSED_STRING) reduce 175) ((T_CONTINUE) reduce 175) ((T_DEC) reduce 175) ((T_DECLARE) reduce 175) ((T_DEFAULT) reduce 175) ((T_DIR) reduce 175) ((T_DNUMBER) reduce 175) ((T_DO) reduce 175) ((T_DOUBLE_CAST) reduce 175) ((T_ECHO) reduce 175) ((T_EMPTY) reduce 175) ((T_ENDSWITCH) reduce 175) ((T_ENUM) reduce 175) ((T_EVAL) reduce 175) ((T_EXIT) reduce 175) ((T_FILE) reduce 175) ((T_FINAL) reduce 175) ((T_FN) reduce 175) ((T_FOR) reduce 175) ((T_FOREACH) reduce 175) ((T_FUNCTION) reduce 175) ((T_FUNC_C) reduce 175) ((T_GLOBAL) reduce 175) ((T_GOTO) reduce 175) ((T_HALT_COMPILER) reduce 175) ((T_IF) reduce 175) ((T_INC) reduce 175) ((T_INCLUDE) reduce 175) ((T_INCLUDE_ONCE) reduce 175) ((T_INLINE_HTML) reduce 175) ((T_INTERFACE) reduce 175) ((T_INT_CAST) reduce 175) ((T_ISSET) reduce 175) ((T_LINE) reduce 175) ((T_LIST) reduce 175) ((T_LNUMBER) reduce 175) ((T_MATCH) reduce 175) ((T_METHOD_C) reduce 175) ((T_NAME_FULLY_QUALIFIED) reduce 175) ((T_NAME_QUALIFIED) reduce 175) ((T_NAME_RELATIVE) reduce 175) ((T_NEW) reduce 175) ((T_NS_C) reduce 175) ((T_OBJECT_CAST) reduce 175) ((T_PRINT) reduce 175) ((T_READONLY) reduce 175) ((T_REQUIRE) reduce 175) ((T_REQUIRE_ONCE) reduce 175) ((T_RETURN) reduce 175) ((T_START_HEREDOC) reduce 175) ((T_STATIC) reduce 175) ((T_STRING) reduce 175) ((T_STRING_CAST) reduce 175) ((T_SWITCH) reduce 175) ((T_THROW) reduce 175) ((T_TRAIT) reduce 175) ((T_TRAIT_C) reduce 175) ((T_TRY) reduce 175) ((T_UNSET) reduce 175) ((T_UNSET_CAST) reduce 175) ((T_VARIABLE) reduce 175) ((T_WHILE) reduce 175) ((T_YIELD) reduce 175) ((T_YIELD_FROM) reduce 175) (("[") reduce 175) (("`") reduce 175) (("{") reduce 175) (("~") reduce 175)) 21635 ((("!") reduce 169) (("\"") reduce 169) (("$") reduce 169) (("(") reduce 169) (("+") reduce 169) (("-") reduce 169) ((";") reduce 169) (("@") reduce 169) ((T_ABSTRACT) reduce 169) ((T_ARRAY) reduce 169) ((T_ARRAY_CAST) reduce 169) ((T_ATTRIBUTE) reduce 169) ((T_BOOL_CAST) reduce 169) ((T_BREAK) reduce 169) ((T_CASE) reduce 169) ((T_CATCH) reduce 169) ((T_CLASS) reduce 169) ((T_CLASS_C) reduce 169) ((T_CLONE) reduce 169) ((T_CONSTANT_ENCAPSED_STRING) reduce 169) ((T_CONTINUE) reduce 169) ((T_DEC) reduce 169) ((T_DECLARE) reduce 169) ((T_DEFAULT) reduce 169) ((T_DIR) reduce 169) ((T_DNUMBER) reduce 169) ((T_DO) reduce 169) ((T_DOUBLE_CAST) reduce 169) ((T_ECHO) reduce 169) ((T_EMPTY) reduce 169) ((T_ENDSWITCH) reduce 169) ((T_ENUM) reduce 169) ((T_EVAL) reduce 169) ((T_EXIT) reduce 169) ((T_FILE) reduce 169) ((T_FINAL) reduce 169) ((T_FINALLY) reduce 169) ((T_FN) reduce 169) ((T_FOR) reduce 169) ((T_FOREACH) reduce 169) ((T_FUNCTION) reduce 169) ((T_FUNC_C) reduce 169) ((T_GLOBAL) reduce 169) ((T_GOTO) reduce 169) ((T_HALT_COMPILER) reduce 169) ((T_IF) reduce 169) ((T_INC) reduce 169) ((T_INCLUDE) reduce 169) ((T_INCLUDE_ONCE) reduce 169) ((T_INLINE_HTML) reduce 169) ((T_INTERFACE) reduce 169) ((T_INT_CAST) reduce 169) ((T_ISSET) reduce 169) ((T_LINE) reduce 169) ((T_LIST) reduce 169) ((T_LNUMBER) reduce 169) ((T_MATCH) reduce 169) ((T_METHOD_C) reduce 169) ((T_NAME_FULLY_QUALIFIED) reduce 169) ((T_NAME_QUALIFIED) reduce 169) ((T_NAME_RELATIVE) reduce 169) ((T_NEW) reduce 169) ((T_NS_C) reduce 169) ((T_OBJECT_CAST) reduce 169) ((T_PRINT) reduce 169) ((T_READONLY) reduce 169) ((T_REQUIRE) reduce 169) ((T_REQUIRE_ONCE) reduce 169) ((T_RETURN) reduce 169) ((T_START_HEREDOC) reduce 169) ((T_STATIC) reduce 169) ((T_STRING) reduce 169) ((T_STRING_CAST) reduce 169) ((T_SWITCH) reduce 169) ((T_THROW) reduce 169) ((T_TRAIT) reduce 169) ((T_TRAIT_C) reduce 169) ((T_TRY) reduce 169) ((T_UNSET) reduce 169) ((T_UNSET_CAST) reduce 169) ((T_VARIABLE) reduce 169) ((T_WHILE) reduce 169) ((T_YIELD) reduce 169) ((T_YIELD_FROM) reduce 169) (("[") reduce 169) (("`") reduce 169) (("{") reduce 169) (("~") reduce 169)) 21640 ((("!") reduce 197) (("\"") reduce 197) (("$") reduce 197) (("(") reduce 197) (("+") reduce 197) (("-") reduce 197) ((";") reduce 197) (("@") reduce 197) ((T_ABSTRACT) reduce 197) ((T_ARRAY) reduce 197) ((T_ARRAY_CAST) reduce 197) ((T_ATTRIBUTE) reduce 197) ((T_BOOL_CAST) reduce 197) ((T_BREAK) reduce 197) ((T_CASE) reduce 197) ((T_CLASS) reduce 197) ((T_CLASS_C) reduce 197) ((T_CLONE) reduce 197) ((T_CONSTANT_ENCAPSED_STRING) reduce 197) ((T_CONTINUE) reduce 197) ((T_DEC) reduce 197) ((T_DECLARE) reduce 197) ((T_DEFAULT) reduce 197) ((T_DIR) reduce 197) ((T_DNUMBER) reduce 197) ((T_DO) reduce 197) ((T_DOUBLE_CAST) reduce 197) ((T_ECHO) reduce 197) ((T_EMPTY) reduce 197) ((T_ENDSWITCH) reduce 197) ((T_ENUM) reduce 197) ((T_EVAL) reduce 197) ((T_EXIT) reduce 197) ((T_FILE) reduce 197) ((T_FINAL) reduce 197) ((T_FN) reduce 197) ((T_FOR) reduce 197) ((T_FOREACH) reduce 197) ((T_FUNCTION) reduce 197) ((T_FUNC_C) reduce 197) ((T_GLOBAL) reduce 197) ((T_GOTO) reduce 197) ((T_HALT_COMPILER) reduce 197) ((T_IF) reduce 197) ((T_INC) reduce 197) ((T_INCLUDE) reduce 197) ((T_INCLUDE_ONCE) reduce 197) ((T_INLINE_HTML) reduce 197) ((T_INTERFACE) reduce 197) ((T_INT_CAST) reduce 197) ((T_ISSET) reduce 197) ((T_LINE) reduce 197) ((T_LIST) reduce 197) ((T_LNUMBER) reduce 197) ((T_MATCH) reduce 197) ((T_METHOD_C) reduce 197) ((T_NAME_FULLY_QUALIFIED) reduce 197) ((T_NAME_QUALIFIED) reduce 197) ((T_NAME_RELATIVE) reduce 197) ((T_NEW) reduce 197) ((T_NS_C) reduce 197) ((T_OBJECT_CAST) reduce 197) ((T_PRINT) reduce 197) ((T_READONLY) reduce 197) ((T_REQUIRE) reduce 197) ((T_REQUIRE_ONCE) reduce 197) ((T_RETURN) reduce 197) ((T_START_HEREDOC) reduce 197) ((T_STATIC) reduce 197) ((T_STRING) reduce 197) ((T_STRING_CAST) reduce 197) ((T_SWITCH) reduce 197) ((T_THROW) reduce 197) ((T_TRAIT) reduce 197) ((T_TRAIT_C) reduce 197) ((T_TRY) reduce 197) ((T_UNSET) reduce 197) ((T_UNSET_CAST) reduce 197) ((T_VARIABLE) reduce 197) ((T_WHILE) reduce 197) ((T_YIELD) reduce 197) ((T_YIELD_FROM) reduce 197) (("[") reduce 197) (("`") reduce 197) (("{") reduce 197) (("~") reduce 197)) 21645 ((("!") reduce 151) (("\"") reduce 151) (("$") reduce 151) (("(") reduce 151) (("+") reduce 151) (("-") reduce 151) ((";") reduce 151) (("@") reduce 151) ((T_ABSTRACT) reduce 151) ((T_ARRAY) reduce 151) ((T_ARRAY_CAST) reduce 151) ((T_ATTRIBUTE) reduce 151) ((T_BOOL_CAST) reduce 151) ((T_BREAK) reduce 151) ((T_CASE) reduce 151) ((T_CLASS) reduce 151) ((T_CLASS_C) reduce 151) ((T_CLONE) reduce 151) ((T_CONSTANT_ENCAPSED_STRING) reduce 151) ((T_CONTINUE) reduce 151) ((T_DEC) reduce 151) ((T_DECLARE) reduce 151) ((T_DEFAULT) reduce 151) ((T_DIR) reduce 151) ((T_DNUMBER) reduce 151) ((T_DO) reduce 151) ((T_DOUBLE_CAST) reduce 151) ((T_ECHO) reduce 151) ((T_EMPTY) reduce 151) ((T_ENDSWITCH) reduce 151) ((T_ENUM) reduce 151) ((T_EVAL) reduce 151) ((T_EXIT) reduce 151) ((T_FILE) reduce 151) ((T_FINAL) reduce 151) ((T_FN) reduce 151) ((T_FOR) reduce 151) ((T_FOREACH) reduce 151) ((T_FUNCTION) reduce 151) ((T_FUNC_C) reduce 151) ((T_GLOBAL) reduce 151) ((T_GOTO) reduce 151) ((T_HALT_COMPILER) reduce 151) ((T_IF) reduce 151) ((T_INC) reduce 151) ((T_INCLUDE) reduce 151) ((T_INCLUDE_ONCE) reduce 151) ((T_INLINE_HTML) reduce 151) ((T_INTERFACE) reduce 151) ((T_INT_CAST) reduce 151) ((T_ISSET) reduce 151) ((T_LINE) reduce 151) ((T_LIST) reduce 151) ((T_LNUMBER) reduce 151) ((T_MATCH) reduce 151) ((T_METHOD_C) reduce 151) ((T_NAME_FULLY_QUALIFIED) reduce 151) ((T_NAME_QUALIFIED) reduce 151) ((T_NAME_RELATIVE) reduce 151) ((T_NEW) reduce 151) ((T_NS_C) reduce 151) ((T_OBJECT_CAST) reduce 151) ((T_PRINT) reduce 151) ((T_READONLY) reduce 151) ((T_REQUIRE) reduce 151) ((T_REQUIRE_ONCE) reduce 151) ((T_RETURN) reduce 151) ((T_START_HEREDOC) reduce 151) ((T_STATIC) reduce 151) ((T_STRING) reduce 151) ((T_STRING_CAST) reduce 151) ((T_SWITCH) reduce 151) ((T_THROW) reduce 151) ((T_TRAIT) reduce 151) ((T_TRAIT_C) reduce 151) ((T_TRY) reduce 151) ((T_UNSET) reduce 151) ((T_UNSET_CAST) reduce 151) ((T_VARIABLE) reduce 151) ((T_WHILE) reduce 151) ((T_YIELD) reduce 151) ((T_YIELD_FROM) reduce 151) (("[") reduce 151) (("`") reduce 151) (("{") reduce 151) (("~") reduce 151)) 21649 ((("!") reduce 221) (("\"") reduce 221) (("$") reduce 221) (("(") reduce 221) (("+") reduce 221) (("-") reduce 221) ((";") reduce 221) (("@") reduce 221) ((T_ABSTRACT) reduce 221) ((T_ARRAY) reduce 221) ((T_ARRAY_CAST) reduce 221) ((T_ATTRIBUTE) reduce 221) ((T_BOOL_CAST) reduce 221) ((T_BREAK) reduce 221) ((T_CASE) reduce 221) ((T_CLASS) reduce 221) ((T_CLASS_C) reduce 221) ((T_CLONE) reduce 221) ((T_CONSTANT_ENCAPSED_STRING) reduce 221) ((T_CONTINUE) reduce 221) ((T_DEC) reduce 221) ((T_DECLARE) reduce 221) ((T_DEFAULT) reduce 221) ((T_DIR) reduce 221) ((T_DNUMBER) reduce 221) ((T_DO) reduce 221) ((T_DOUBLE_CAST) reduce 221) ((T_ECHO) reduce 221) ((T_EMPTY) reduce 221) ((T_ENDSWITCH) reduce 221) ((T_ENUM) reduce 221) ((T_EVAL) reduce 221) ((T_EXIT) reduce 221) ((T_FILE) reduce 221) ((T_FINAL) reduce 221) ((T_FN) reduce 221) ((T_FOR) reduce 221) ((T_FOREACH) reduce 221) ((T_FUNCTION) reduce 221) ((T_FUNC_C) reduce 221) ((T_GLOBAL) reduce 221) ((T_GOTO) reduce 221) ((T_HALT_COMPILER) reduce 221) ((T_IF) reduce 221) ((T_INC) reduce 221) ((T_INCLUDE) reduce 221) ((T_INCLUDE_ONCE) reduce 221) ((T_INLINE_HTML) reduce 221) ((T_INTERFACE) reduce 221) ((T_INT_CAST) reduce 221) ((T_ISSET) reduce 221) ((T_LINE) reduce 221) ((T_LIST) reduce 221) ((T_LNUMBER) reduce 221) ((T_MATCH) reduce 221) ((T_METHOD_C) reduce 221) ((T_NAME_FULLY_QUALIFIED) reduce 221) ((T_NAME_QUALIFIED) reduce 221) ((T_NAME_RELATIVE) reduce 221) ((T_NEW) reduce 221) ((T_NS_C) reduce 221) ((T_OBJECT_CAST) reduce 221) ((T_PRINT) reduce 221) ((T_READONLY) reduce 221) ((T_REQUIRE) reduce 221) ((T_REQUIRE_ONCE) reduce 221) ((T_RETURN) reduce 221) ((T_START_HEREDOC) reduce 221) ((T_STATIC) reduce 221) ((T_STRING) reduce 221) ((T_STRING_CAST) reduce 221) ((T_SWITCH) reduce 221) ((T_THROW) reduce 221) ((T_TRAIT) reduce 221) ((T_TRAIT_C) reduce 221) ((T_TRY) reduce 221) ((T_UNSET) reduce 221) ((T_UNSET_CAST) reduce 221) ((T_VARIABLE) reduce 221) ((T_WHILE) reduce 221) ((T_YIELD) reduce 221) ((T_YIELD_FROM) reduce 221) (("[") reduce 221) (("`") reduce 221) (("{") reduce 221) (("~") reduce 221)) 21651 ((("!") reduce 222) (("\"") reduce 222) (("$") reduce 222) (("(") reduce 222) (("+") reduce 222) (("-") reduce 222) ((";") reduce 222) (("@") reduce 222) ((T_ABSTRACT) reduce 222) ((T_ARRAY) reduce 222) ((T_ARRAY_CAST) reduce 222) ((T_ATTRIBUTE) reduce 222) ((T_BOOL_CAST) reduce 222) ((T_BREAK) reduce 222) ((T_CASE) reduce 222) ((T_CLASS) reduce 222) ((T_CLASS_C) reduce 222) ((T_CLONE) reduce 222) ((T_CONSTANT_ENCAPSED_STRING) reduce 222) ((T_CONTINUE) reduce 222) ((T_DEC) reduce 222) ((T_DECLARE) reduce 222) ((T_DEFAULT) reduce 222) ((T_DIR) reduce 222) ((T_DNUMBER) reduce 222) ((T_DO) reduce 222) ((T_DOUBLE_CAST) reduce 222) ((T_ECHO) reduce 222) ((T_EMPTY) reduce 222) ((T_ENDSWITCH) reduce 222) ((T_ENUM) reduce 222) ((T_EVAL) reduce 222) ((T_EXIT) reduce 222) ((T_FILE) reduce 222) ((T_FINAL) reduce 222) ((T_FN) reduce 222) ((T_FOR) reduce 222) ((T_FOREACH) reduce 222) ((T_FUNCTION) reduce 222) ((T_FUNC_C) reduce 222) ((T_GLOBAL) reduce 222) ((T_GOTO) reduce 222) ((T_HALT_COMPILER) reduce 222) ((T_IF) reduce 222) ((T_INC) reduce 222) ((T_INCLUDE) reduce 222) ((T_INCLUDE_ONCE) reduce 222) ((T_INLINE_HTML) reduce 222) ((T_INTERFACE) reduce 222) ((T_INT_CAST) reduce 222) ((T_ISSET) reduce 222) ((T_LINE) reduce 222) ((T_LIST) reduce 222) ((T_LNUMBER) reduce 222) ((T_MATCH) reduce 222) ((T_METHOD_C) reduce 222) ((T_NAME_FULLY_QUALIFIED) reduce 222) ((T_NAME_QUALIFIED) reduce 222) ((T_NAME_RELATIVE) reduce 222) ((T_NEW) reduce 222) ((T_NS_C) reduce 222) ((T_OBJECT_CAST) reduce 222) ((T_PRINT) reduce 222) ((T_READONLY) reduce 222) ((T_REQUIRE) reduce 222) ((T_REQUIRE_ONCE) reduce 222) ((T_RETURN) reduce 222) ((T_START_HEREDOC) reduce 222) ((T_STATIC) reduce 222) ((T_STRING) reduce 222) ((T_STRING_CAST) reduce 222) ((T_SWITCH) reduce 222) ((T_THROW) reduce 222) ((T_TRAIT) reduce 222) ((T_TRAIT_C) reduce 222) ((T_TRY) reduce 222) ((T_UNSET) reduce 222) ((T_UNSET_CAST) reduce 222) ((T_VARIABLE) reduce 222) ((T_WHILE) reduce 222) ((T_YIELD) reduce 222) ((T_YIELD_FROM) reduce 222) (("[") reduce 222) (("`") reduce 222) (("{") reduce 222) (("~") reduce 222)) 21655 ((("!") reduce 223) (("\"") reduce 223) (("$") reduce 223) (("(") reduce 223) (("+") reduce 223) (("-") reduce 223) ((";") reduce 223) (("@") reduce 223) ((T_ABSTRACT) reduce 223) ((T_ARRAY) reduce 223) ((T_ARRAY_CAST) reduce 223) ((T_ATTRIBUTE) reduce 223) ((T_BOOL_CAST) reduce 223) ((T_BREAK) reduce 223) ((T_CASE) reduce 223) ((T_CLASS) reduce 223) ((T_CLASS_C) reduce 223) ((T_CLONE) reduce 223) ((T_CONSTANT_ENCAPSED_STRING) reduce 223) ((T_CONTINUE) reduce 223) ((T_DEC) reduce 223) ((T_DECLARE) reduce 223) ((T_DEFAULT) reduce 223) ((T_DIR) reduce 223) ((T_DNUMBER) reduce 223) ((T_DO) reduce 223) ((T_DOUBLE_CAST) reduce 223) ((T_ECHO) reduce 223) ((T_EMPTY) reduce 223) ((T_ENDSWITCH) reduce 223) ((T_ENUM) reduce 223) ((T_EVAL) reduce 223) ((T_EXIT) reduce 223) ((T_FILE) reduce 223) ((T_FINAL) reduce 223) ((T_FN) reduce 223) ((T_FOR) reduce 223) ((T_FOREACH) reduce 223) ((T_FUNCTION) reduce 223) ((T_FUNC_C) reduce 223) ((T_GLOBAL) reduce 223) ((T_GOTO) reduce 223) ((T_HALT_COMPILER) reduce 223) ((T_IF) reduce 223) ((T_INC) reduce 223) ((T_INCLUDE) reduce 223) ((T_INCLUDE_ONCE) reduce 223) ((T_INLINE_HTML) reduce 223) ((T_INTERFACE) reduce 223) ((T_INT_CAST) reduce 223) ((T_ISSET) reduce 223) ((T_LINE) reduce 223) ((T_LIST) reduce 223) ((T_LNUMBER) reduce 223) ((T_MATCH) reduce 223) ((T_METHOD_C) reduce 223) ((T_NAME_FULLY_QUALIFIED) reduce 223) ((T_NAME_QUALIFIED) reduce 223) ((T_NAME_RELATIVE) reduce 223) ((T_NEW) reduce 223) ((T_NS_C) reduce 223) ((T_OBJECT_CAST) reduce 223) ((T_PRINT) reduce 223) ((T_READONLY) reduce 223) ((T_REQUIRE) reduce 223) ((T_REQUIRE_ONCE) reduce 223) ((T_RETURN) reduce 223) ((T_START_HEREDOC) reduce 223) ((T_STATIC) reduce 223) ((T_STRING) reduce 223) ((T_STRING_CAST) reduce 223) ((T_SWITCH) reduce 223) ((T_THROW) reduce 223) ((T_TRAIT) reduce 223) ((T_TRAIT_C) reduce 223) ((T_TRY) reduce 223) ((T_UNSET) reduce 223) ((T_UNSET_CAST) reduce 223) ((T_VARIABLE) reduce 223) ((T_WHILE) reduce 223) ((T_YIELD) reduce 223) ((T_YIELD_FROM) reduce 223) (("[") reduce 223) (("`") reduce 223) (("{") reduce 223) (("~") reduce 223)) 21658 ((("!") reduce 224) (("\"") reduce 224) (("$") reduce 224) (("(") reduce 224) (("+") reduce 224) (("-") reduce 224) ((";") reduce 224) (("@") reduce 224) ((T_ABSTRACT) reduce 224) ((T_ARRAY) reduce 224) ((T_ARRAY_CAST) reduce 224) ((T_ATTRIBUTE) reduce 224) ((T_BOOL_CAST) reduce 224) ((T_BREAK) reduce 224) ((T_CASE) reduce 224) ((T_CLASS) reduce 224) ((T_CLASS_C) reduce 224) ((T_CLONE) reduce 224) ((T_CONSTANT_ENCAPSED_STRING) reduce 224) ((T_CONTINUE) reduce 224) ((T_DEC) reduce 224) ((T_DECLARE) reduce 224) ((T_DEFAULT) reduce 224) ((T_DIR) reduce 224) ((T_DNUMBER) reduce 224) ((T_DO) reduce 224) ((T_DOUBLE_CAST) reduce 224) ((T_ECHO) reduce 224) ((T_EMPTY) reduce 224) ((T_ENDSWITCH) reduce 224) ((T_ENUM) reduce 224) ((T_EVAL) reduce 224) ((T_EXIT) reduce 224) ((T_FILE) reduce 224) ((T_FINAL) reduce 224) ((T_FN) reduce 224) ((T_FOR) reduce 224) ((T_FOREACH) reduce 224) ((T_FUNCTION) reduce 224) ((T_FUNC_C) reduce 224) ((T_GLOBAL) reduce 224) ((T_GOTO) reduce 224) ((T_HALT_COMPILER) reduce 224) ((T_IF) reduce 224) ((T_INC) reduce 224) ((T_INCLUDE) reduce 224) ((T_INCLUDE_ONCE) reduce 224) ((T_INLINE_HTML) reduce 224) ((T_INTERFACE) reduce 224) ((T_INT_CAST) reduce 224) ((T_ISSET) reduce 224) ((T_LINE) reduce 224) ((T_LIST) reduce 224) ((T_LNUMBER) reduce 224) ((T_MATCH) reduce 224) ((T_METHOD_C) reduce 224) ((T_NAME_FULLY_QUALIFIED) reduce 224) ((T_NAME_QUALIFIED) reduce 224) ((T_NAME_RELATIVE) reduce 224) ((T_NEW) reduce 224) ((T_NS_C) reduce 224) ((T_OBJECT_CAST) reduce 224) ((T_PRINT) reduce 224) ((T_READONLY) reduce 224) ((T_REQUIRE) reduce 224) ((T_REQUIRE_ONCE) reduce 224) ((T_RETURN) reduce 224) ((T_START_HEREDOC) reduce 224) ((T_STATIC) reduce 224) ((T_STRING) reduce 224) ((T_STRING_CAST) reduce 224) ((T_SWITCH) reduce 224) ((T_THROW) reduce 224) ((T_TRAIT) reduce 224) ((T_TRAIT_C) reduce 224) ((T_TRY) reduce 224) ((T_UNSET) reduce 224) ((T_UNSET_CAST) reduce 224) ((T_VARIABLE) reduce 224) ((T_WHILE) reduce 224) ((T_YIELD) reduce 224) ((T_YIELD_FROM) reduce 224) (("[") reduce 224) (("`") reduce 224) (("{") reduce 224) (("~") reduce 224)) 21659 ((("!") reduce 167) (("\"") reduce 167) (("$") reduce 167) (("(") reduce 167) (("+") reduce 167) (("-") reduce 167) ((";") reduce 167) (("@") reduce 167) ((T_ABSTRACT) reduce 167) ((T_ARRAY) reduce 167) ((T_ARRAY_CAST) reduce 167) ((T_ATTRIBUTE) reduce 167) ((T_BOOL_CAST) reduce 167) ((T_BREAK) reduce 167) ((T_CASE) reduce 167) ((T_CLASS) reduce 167) ((T_CLASS_C) reduce 167) ((T_CLONE) reduce 167) ((T_CONSTANT_ENCAPSED_STRING) reduce 167) ((T_CONTINUE) reduce 167) ((T_DEC) reduce 167) ((T_DECLARE) reduce 167) ((T_DEFAULT) reduce 167) ((T_DIR) reduce 167) ((T_DNUMBER) reduce 167) ((T_DO) reduce 167) ((T_DOUBLE_CAST) reduce 167) ((T_ECHO) reduce 167) ((T_EMPTY) reduce 167) ((T_ENDSWITCH) reduce 167) ((T_ENUM) reduce 167) ((T_EVAL) reduce 167) ((T_EXIT) reduce 167) ((T_FILE) reduce 167) ((T_FINAL) reduce 167) ((T_FN) reduce 167) ((T_FOR) reduce 167) ((T_FOREACH) reduce 167) ((T_FUNCTION) reduce 167) ((T_FUNC_C) reduce 167) ((T_GLOBAL) reduce 167) ((T_GOTO) reduce 167) ((T_HALT_COMPILER) reduce 167) ((T_IF) reduce 167) ((T_INC) reduce 167) ((T_INCLUDE) reduce 167) ((T_INCLUDE_ONCE) reduce 167) ((T_INLINE_HTML) reduce 167) ((T_INTERFACE) reduce 167) ((T_INT_CAST) reduce 167) ((T_ISSET) reduce 167) ((T_LINE) reduce 167) ((T_LIST) reduce 167) ((T_LNUMBER) reduce 167) ((T_MATCH) reduce 167) ((T_METHOD_C) reduce 167) ((T_NAME_FULLY_QUALIFIED) reduce 167) ((T_NAME_QUALIFIED) reduce 167) ((T_NAME_RELATIVE) reduce 167) ((T_NEW) reduce 167) ((T_NS_C) reduce 167) ((T_OBJECT_CAST) reduce 167) ((T_PRINT) reduce 167) ((T_READONLY) reduce 167) ((T_REQUIRE) reduce 167) ((T_REQUIRE_ONCE) reduce 167) ((T_RETURN) reduce 167) ((T_START_HEREDOC) reduce 167) ((T_STATIC) reduce 167) ((T_STRING) reduce 167) ((T_STRING_CAST) reduce 167) ((T_SWITCH) reduce 167) ((T_THROW) reduce 167) ((T_TRAIT) reduce 167) ((T_TRAIT_C) reduce 167) ((T_TRY) reduce 167) ((T_UNSET) reduce 167) ((T_UNSET_CAST) reduce 167) ((T_VARIABLE) reduce 167) ((T_WHILE) reduce 167) ((T_YIELD) reduce 167) ((T_YIELD_FROM) reduce 167) (("[") reduce 167) (("`") reduce 167) (("{") reduce 167) (("~") reduce 167)) 21661 ((("!") reduce 156) (("\"") reduce 156) (("$") reduce 156) (("(") reduce 156) (("+") reduce 156) (("-") reduce 156) ((";") reduce 156) (("@") reduce 156) ((T_ABSTRACT) reduce 156) ((T_ARRAY) reduce 156) ((T_ARRAY_CAST) reduce 156) ((T_ATTRIBUTE) reduce 156) ((T_BOOL_CAST) reduce 156) ((T_BREAK) reduce 156) ((T_CASE) reduce 156) ((T_CLASS) reduce 156) ((T_CLASS_C) reduce 156) ((T_CLONE) reduce 156) ((T_CONSTANT_ENCAPSED_STRING) reduce 156) ((T_CONTINUE) reduce 156) ((T_DEC) reduce 156) ((T_DECLARE) reduce 156) ((T_DEFAULT) reduce 156) ((T_DIR) reduce 156) ((T_DNUMBER) reduce 156) ((T_DO) reduce 156) ((T_DOUBLE_CAST) reduce 156) ((T_ECHO) reduce 156) ((T_EMPTY) reduce 156) ((T_ENDSWITCH) reduce 156) ((T_ENUM) reduce 156) ((T_EVAL) reduce 156) ((T_EXIT) reduce 156) ((T_FILE) reduce 156) ((T_FINAL) reduce 156) ((T_FN) reduce 156) ((T_FOR) reduce 156) ((T_FOREACH) reduce 156) ((T_FUNCTION) reduce 156) ((T_FUNC_C) reduce 156) ((T_GLOBAL) reduce 156) ((T_GOTO) reduce 156) ((T_HALT_COMPILER) reduce 156) ((T_IF) reduce 156) ((T_INC) reduce 156) ((T_INCLUDE) reduce 156) ((T_INCLUDE_ONCE) reduce 156) ((T_INLINE_HTML) reduce 156) ((T_INTERFACE) reduce 156) ((T_INT_CAST) reduce 156) ((T_ISSET) reduce 156) ((T_LINE) reduce 156) ((T_LIST) reduce 156) ((T_LNUMBER) reduce 156) ((T_MATCH) reduce 156) ((T_METHOD_C) reduce 156) ((T_NAME_FULLY_QUALIFIED) reduce 156) ((T_NAME_QUALIFIED) reduce 156) ((T_NAME_RELATIVE) reduce 156) ((T_NEW) reduce 156) ((T_NS_C) reduce 156) ((T_OBJECT_CAST) reduce 156) ((T_PRINT) reduce 156) ((T_READONLY) reduce 156) ((T_REQUIRE) reduce 156) ((T_REQUIRE_ONCE) reduce 156) ((T_RETURN) reduce 156) ((T_START_HEREDOC) reduce 156) ((T_STATIC) reduce 156) ((T_STRING) reduce 156) ((T_STRING_CAST) reduce 156) ((T_SWITCH) reduce 156) ((T_THROW) reduce 156) ((T_TRAIT) reduce 156) ((T_TRAIT_C) reduce 156) ((T_TRY) reduce 156) ((T_UNSET) reduce 156) ((T_UNSET_CAST) reduce 156) ((T_VARIABLE) reduce 156) ((T_WHILE) reduce 156) ((T_YIELD) reduce 156) ((T_YIELD_FROM) reduce 156) (("[") reduce 156) (("`") reduce 156) (("{") reduce 156) (("~") reduce 156)) 21663 ((("!") reduce 154) (("\"") reduce 154) (("$") reduce 154) (("(") reduce 154) (("+") reduce 154) (("-") reduce 154) ((";") reduce 154) (("@") reduce 154) ((T_ABSTRACT) reduce 154) ((T_ARRAY) reduce 154) ((T_ARRAY_CAST) reduce 154) ((T_ATTRIBUTE) reduce 154) ((T_BOOL_CAST) reduce 154) ((T_BREAK) reduce 154) ((T_CASE) reduce 154) ((T_CLASS) reduce 154) ((T_CLASS_C) reduce 154) ((T_CLONE) reduce 154) ((T_CONSTANT_ENCAPSED_STRING) reduce 154) ((T_CONTINUE) reduce 154) ((T_DEC) reduce 154) ((T_DECLARE) reduce 154) ((T_DEFAULT) reduce 154) ((T_DIR) reduce 154) ((T_DNUMBER) reduce 154) ((T_DO) reduce 154) ((T_DOUBLE_CAST) reduce 154) ((T_ECHO) reduce 154) ((T_EMPTY) reduce 154) ((T_ENDSWITCH) reduce 154) ((T_ENUM) reduce 154) ((T_EVAL) reduce 154) ((T_EXIT) reduce 154) ((T_FILE) reduce 154) ((T_FINAL) reduce 154) ((T_FN) reduce 154) ((T_FOR) reduce 154) ((T_FOREACH) reduce 154) ((T_FUNCTION) reduce 154) ((T_FUNC_C) reduce 154) ((T_GLOBAL) reduce 154) ((T_GOTO) reduce 154) ((T_HALT_COMPILER) reduce 154) ((T_IF) reduce 154) ((T_INC) reduce 154) ((T_INCLUDE) reduce 154) ((T_INCLUDE_ONCE) reduce 154) ((T_INLINE_HTML) reduce 154) ((T_INTERFACE) reduce 154) ((T_INT_CAST) reduce 154) ((T_ISSET) reduce 154) ((T_LINE) reduce 154) ((T_LIST) reduce 154) ((T_LNUMBER) reduce 154) ((T_MATCH) reduce 154) ((T_METHOD_C) reduce 154) ((T_NAME_FULLY_QUALIFIED) reduce 154) ((T_NAME_QUALIFIED) reduce 154) ((T_NAME_RELATIVE) reduce 154) ((T_NEW) reduce 154) ((T_NS_C) reduce 154) ((T_OBJECT_CAST) reduce 154) ((T_PRINT) reduce 154) ((T_READONLY) reduce 154) ((T_REQUIRE) reduce 154) ((T_REQUIRE_ONCE) reduce 154) ((T_RETURN) reduce 154) ((T_START_HEREDOC) reduce 154) ((T_STATIC) reduce 154) ((T_STRING) reduce 154) ((T_STRING_CAST) reduce 154) ((T_SWITCH) reduce 154) ((T_THROW) reduce 154) ((T_TRAIT) reduce 154) ((T_TRAIT_C) reduce 154) ((T_TRY) reduce 154) ((T_UNSET) reduce 154) ((T_UNSET_CAST) reduce 154) ((T_VARIABLE) reduce 154) ((T_WHILE) reduce 154) ((T_YIELD) reduce 154) ((T_YIELD_FROM) reduce 154) (("[") reduce 154) (("`") reduce 154) (("{") reduce 154) (("~") reduce 154)) 21669 ((("!") reduce 198) (("\"") reduce 198) (("$") reduce 198) (("(") reduce 198) (("+") reduce 198) (("-") reduce 198) ((";") reduce 198) (("@") reduce 198) ((T_ABSTRACT) reduce 198) ((T_ARRAY) reduce 198) ((T_ARRAY_CAST) reduce 198) ((T_ATTRIBUTE) reduce 198) ((T_BOOL_CAST) reduce 198) ((T_BREAK) reduce 198) ((T_CASE) reduce 198) ((T_CLASS) reduce 198) ((T_CLASS_C) reduce 198) ((T_CLONE) reduce 198) ((T_CONSTANT_ENCAPSED_STRING) reduce 198) ((T_CONTINUE) reduce 198) ((T_DEC) reduce 198) ((T_DECLARE) reduce 198) ((T_DEFAULT) reduce 198) ((T_DIR) reduce 198) ((T_DNUMBER) reduce 198) ((T_DO) reduce 198) ((T_DOUBLE_CAST) reduce 198) ((T_ECHO) reduce 198) ((T_EMPTY) reduce 198) ((T_ENDSWITCH) reduce 198) ((T_ENUM) reduce 198) ((T_EVAL) reduce 198) ((T_EXIT) reduce 198) ((T_FILE) reduce 198) ((T_FINAL) reduce 198) ((T_FN) reduce 198) ((T_FOR) reduce 198) ((T_FOREACH) reduce 198) ((T_FUNCTION) reduce 198) ((T_FUNC_C) reduce 198) ((T_GLOBAL) reduce 198) ((T_GOTO) reduce 198) ((T_HALT_COMPILER) reduce 198) ((T_IF) reduce 198) ((T_INC) reduce 198) ((T_INCLUDE) reduce 198) ((T_INCLUDE_ONCE) reduce 198) ((T_INLINE_HTML) reduce 198) ((T_INTERFACE) reduce 198) ((T_INT_CAST) reduce 198) ((T_ISSET) reduce 198) ((T_LINE) reduce 198) ((T_LIST) reduce 198) ((T_LNUMBER) reduce 198) ((T_MATCH) reduce 198) ((T_METHOD_C) reduce 198) ((T_NAME_FULLY_QUALIFIED) reduce 198) ((T_NAME_QUALIFIED) reduce 198) ((T_NAME_RELATIVE) reduce 198) ((T_NEW) reduce 198) ((T_NS_C) reduce 198) ((T_OBJECT_CAST) reduce 198) ((T_PRINT) reduce 198) ((T_READONLY) reduce 198) ((T_REQUIRE) reduce 198) ((T_REQUIRE_ONCE) reduce 198) ((T_RETURN) reduce 198) ((T_START_HEREDOC) reduce 198) ((T_STATIC) reduce 198) ((T_STRING) reduce 198) ((T_STRING_CAST) reduce 198) ((T_SWITCH) reduce 198) ((T_THROW) reduce 198) ((T_TRAIT) reduce 198) ((T_TRAIT_C) reduce 198) ((T_TRY) reduce 198) ((T_UNSET) reduce 198) ((T_UNSET_CAST) reduce 198) ((T_VARIABLE) reduce 198) ((T_WHILE) reduce 198) ((T_YIELD) reduce 198) ((T_YIELD_FROM) reduce 198) (("[") reduce 198) (("`") reduce 198) (("{") reduce 198) (("~") reduce 198)) 21673 ((("!") reduce 241) (("\"") reduce 241) (("$") reduce 241) (("(") reduce 241) (("+") reduce 241) (("-") reduce 241) ((";") reduce 241) (("@") reduce 241) ((T_ABSTRACT) reduce 241) ((T_ARRAY) reduce 241) ((T_ARRAY_CAST) reduce 241) ((T_ATTRIBUTE) reduce 241) ((T_BOOL_CAST) reduce 241) ((T_BREAK) reduce 241) ((T_CASE) reduce 241) ((T_CLASS) reduce 241) ((T_CLASS_C) reduce 241) ((T_CLONE) reduce 241) ((T_CONSTANT_ENCAPSED_STRING) reduce 241) ((T_CONTINUE) reduce 241) ((T_DEC) reduce 241) ((T_DECLARE) reduce 241) ((T_DEFAULT) reduce 241) ((T_DIR) reduce 241) ((T_DNUMBER) reduce 241) ((T_DO) reduce 241) ((T_DOUBLE_CAST) reduce 241) ((T_ECHO) reduce 241) ((T_ELSE) reduce 241) ((T_ELSEIF) reduce 241) ((T_EMPTY) reduce 241) ((T_ENDSWITCH) reduce 241) ((T_ENUM) reduce 241) ((T_EVAL) reduce 241) ((T_EXIT) reduce 241) ((T_FILE) reduce 241) ((T_FINAL) reduce 241) ((T_FN) reduce 241) ((T_FOR) reduce 241) ((T_FOREACH) reduce 241) ((T_FUNCTION) reduce 241) ((T_FUNC_C) reduce 241) ((T_GLOBAL) reduce 241) ((T_GOTO) reduce 241) ((T_HALT_COMPILER) reduce 241) ((T_IF) reduce 241) ((T_INC) reduce 241) ((T_INCLUDE) reduce 241) ((T_INCLUDE_ONCE) reduce 241) ((T_INLINE_HTML) reduce 241) ((T_INTERFACE) reduce 241) ((T_INT_CAST) reduce 241) ((T_ISSET) reduce 241) ((T_LINE) reduce 241) ((T_LIST) reduce 241) ((T_LNUMBER) reduce 241) ((T_MATCH) reduce 241) ((T_METHOD_C) reduce 241) ((T_NAME_FULLY_QUALIFIED) reduce 241) ((T_NAME_QUALIFIED) reduce 241) ((T_NAME_RELATIVE) reduce 241) ((T_NEW) reduce 241) ((T_NS_C) reduce 241) ((T_OBJECT_CAST) reduce 241) ((T_PRINT) reduce 241) ((T_READONLY) reduce 241) ((T_REQUIRE) reduce 241) ((T_REQUIRE_ONCE) reduce 241) ((T_RETURN) reduce 241) ((T_START_HEREDOC) reduce 241) ((T_STATIC) reduce 241) ((T_STRING) reduce 241) ((T_STRING_CAST) reduce 241) ((T_SWITCH) reduce 241) ((T_THROW) reduce 241) ((T_TRAIT) reduce 241) ((T_TRAIT_C) reduce 241) ((T_TRY) reduce 241) ((T_UNSET) reduce 241) ((T_UNSET_CAST) reduce 241) ((T_VARIABLE) reduce 241) ((T_WHILE) reduce 241) ((T_YIELD) reduce 241) ((T_YIELD_FROM) reduce 241) (("[") reduce 241) (("`") reduce 241) (("{") reduce 241) (("~") reduce 241)) 21676 ((("!") reduce 144) (("\"") reduce 144) (("$") reduce 144) (("(") reduce 144) (("+") reduce 144) (("-") reduce 144) ((";") reduce 144) (("@") reduce 144) ((T_ABSTRACT) reduce 144) ((T_ARRAY) reduce 144) ((T_ARRAY_CAST) reduce 144) ((T_ATTRIBUTE) reduce 144) ((T_BOOL_CAST) reduce 144) ((T_BREAK) reduce 144) ((T_CASE) reduce 144) ((T_CLASS) reduce 144) ((T_CLASS_C) reduce 144) ((T_CLONE) reduce 144) ((T_CONSTANT_ENCAPSED_STRING) reduce 144) ((T_CONTINUE) reduce 144) ((T_DEC) reduce 144) ((T_DECLARE) reduce 144) ((T_DEFAULT) reduce 144) ((T_DIR) reduce 144) ((T_DNUMBER) reduce 144) ((T_DO) reduce 144) ((T_DOUBLE_CAST) reduce 144) ((T_ECHO) reduce 144) ((T_EMPTY) reduce 144) ((T_ENDSWITCH) reduce 144) ((T_ENUM) reduce 144) ((T_EVAL) reduce 144) ((T_EXIT) reduce 144) ((T_FILE) reduce 144) ((T_FINAL) reduce 144) ((T_FN) reduce 144) ((T_FOR) reduce 144) ((T_FOREACH) reduce 144) ((T_FUNCTION) reduce 144) ((T_FUNC_C) reduce 144) ((T_GLOBAL) reduce 144) ((T_GOTO) reduce 144) ((T_HALT_COMPILER) reduce 144) ((T_IF) reduce 144) ((T_INC) reduce 144) ((T_INCLUDE) reduce 144) ((T_INCLUDE_ONCE) reduce 144) ((T_INLINE_HTML) reduce 144) ((T_INTERFACE) reduce 144) ((T_INT_CAST) reduce 144) ((T_ISSET) reduce 144) ((T_LINE) reduce 144) ((T_LIST) reduce 144) ((T_LNUMBER) reduce 144) ((T_MATCH) reduce 144) ((T_METHOD_C) reduce 144) ((T_NAME_FULLY_QUALIFIED) reduce 144) ((T_NAME_QUALIFIED) reduce 144) ((T_NAME_RELATIVE) reduce 144) ((T_NEW) reduce 144) ((T_NS_C) reduce 144) ((T_OBJECT_CAST) reduce 144) ((T_PRINT) reduce 144) ((T_READONLY) reduce 144) ((T_REQUIRE) reduce 144) ((T_REQUIRE_ONCE) reduce 144) ((T_RETURN) reduce 144) ((T_START_HEREDOC) reduce 144) ((T_STATIC) reduce 144) ((T_STRING) reduce 144) ((T_STRING_CAST) reduce 144) ((T_SWITCH) reduce 144) ((T_THROW) reduce 144) ((T_TRAIT) reduce 144) ((T_TRAIT_C) reduce 144) ((T_TRY) reduce 144) ((T_UNSET) reduce 144) ((T_UNSET_CAST) reduce 144) ((T_VARIABLE) reduce 144) ((T_WHILE) reduce 144) ((T_YIELD) reduce 144) ((T_YIELD_FROM) reduce 144) (("[") reduce 144) (("`") reduce 144) (("{") reduce 144) (("~") reduce 144)) 21678 ((("!") reduce 166) (("\"") reduce 166) (("$") reduce 166) (("(") reduce 166) (("+") reduce 166) (("-") reduce 166) ((";") reduce 166) (("@") reduce 166) ((T_ABSTRACT) reduce 166) ((T_ARRAY) reduce 166) ((T_ARRAY_CAST) reduce 166) ((T_ATTRIBUTE) reduce 166) ((T_BOOL_CAST) reduce 166) ((T_BREAK) reduce 166) ((T_CASE) reduce 166) ((T_CLASS) reduce 166) ((T_CLASS_C) reduce 166) ((T_CLONE) reduce 166) ((T_CONSTANT_ENCAPSED_STRING) reduce 166) ((T_CONTINUE) reduce 166) ((T_DEC) reduce 166) ((T_DECLARE) reduce 166) ((T_DEFAULT) reduce 166) ((T_DIR) reduce 166) ((T_DNUMBER) reduce 166) ((T_DO) reduce 166) ((T_DOUBLE_CAST) reduce 166) ((T_ECHO) reduce 166) ((T_EMPTY) reduce 166) ((T_ENDSWITCH) reduce 166) ((T_ENUM) reduce 166) ((T_EVAL) reduce 166) ((T_EXIT) reduce 166) ((T_FILE) reduce 166) ((T_FINAL) reduce 166) ((T_FN) reduce 166) ((T_FOR) reduce 166) ((T_FOREACH) reduce 166) ((T_FUNCTION) reduce 166) ((T_FUNC_C) reduce 166) ((T_GLOBAL) reduce 166) ((T_GOTO) reduce 166) ((T_HALT_COMPILER) reduce 166) ((T_IF) reduce 166) ((T_INC) reduce 166) ((T_INCLUDE) reduce 166) ((T_INCLUDE_ONCE) reduce 166) ((T_INLINE_HTML) reduce 166) ((T_INTERFACE) reduce 166) ((T_INT_CAST) reduce 166) ((T_ISSET) reduce 166) ((T_LINE) reduce 166) ((T_LIST) reduce 166) ((T_LNUMBER) reduce 166) ((T_MATCH) reduce 166) ((T_METHOD_C) reduce 166) ((T_NAME_FULLY_QUALIFIED) reduce 166) ((T_NAME_QUALIFIED) reduce 166) ((T_NAME_RELATIVE) reduce 166) ((T_NEW) reduce 166) ((T_NS_C) reduce 166) ((T_OBJECT_CAST) reduce 166) ((T_PRINT) reduce 166) ((T_READONLY) reduce 166) ((T_REQUIRE) reduce 166) ((T_REQUIRE_ONCE) reduce 166) ((T_RETURN) reduce 166) ((T_START_HEREDOC) reduce 166) ((T_STATIC) reduce 166) ((T_STRING) reduce 166) ((T_STRING_CAST) reduce 166) ((T_SWITCH) reduce 166) ((T_THROW) reduce 166) ((T_TRAIT) reduce 166) ((T_TRAIT_C) reduce 166) ((T_TRY) reduce 166) ((T_UNSET) reduce 166) ((T_UNSET_CAST) reduce 166) ((T_VARIABLE) reduce 166) ((T_WHILE) reduce 166) ((T_YIELD) reduce 166) ((T_YIELD_FROM) reduce 166) (("[") reduce 166) (("`") reduce 166) (("{") reduce 166) (("~") reduce 166)) 21680 ((("!") reduce 155) (("\"") reduce 155) (("$") reduce 155) (("(") reduce 155) (("+") reduce 155) (("-") reduce 155) ((";") reduce 155) (("@") reduce 155) ((T_ABSTRACT) reduce 155) ((T_ARRAY) reduce 155) ((T_ARRAY_CAST) reduce 155) ((T_ATTRIBUTE) reduce 155) ((T_BOOL_CAST) reduce 155) ((T_BREAK) reduce 155) ((T_CASE) reduce 155) ((T_CLASS) reduce 155) ((T_CLASS_C) reduce 155) ((T_CLONE) reduce 155) ((T_CONSTANT_ENCAPSED_STRING) reduce 155) ((T_CONTINUE) reduce 155) ((T_DEC) reduce 155) ((T_DECLARE) reduce 155) ((T_DEFAULT) reduce 155) ((T_DIR) reduce 155) ((T_DNUMBER) reduce 155) ((T_DO) reduce 155) ((T_DOUBLE_CAST) reduce 155) ((T_ECHO) reduce 155) ((T_EMPTY) reduce 155) ((T_ENDSWITCH) reduce 155) ((T_ENUM) reduce 155) ((T_EVAL) reduce 155) ((T_EXIT) reduce 155) ((T_FILE) reduce 155) ((T_FINAL) reduce 155) ((T_FN) reduce 155) ((T_FOR) reduce 155) ((T_FOREACH) reduce 155) ((T_FUNCTION) reduce 155) ((T_FUNC_C) reduce 155) ((T_GLOBAL) reduce 155) ((T_GOTO) reduce 155) ((T_HALT_COMPILER) reduce 155) ((T_IF) reduce 155) ((T_INC) reduce 155) ((T_INCLUDE) reduce 155) ((T_INCLUDE_ONCE) reduce 155) ((T_INLINE_HTML) reduce 155) ((T_INTERFACE) reduce 155) ((T_INT_CAST) reduce 155) ((T_ISSET) reduce 155) ((T_LINE) reduce 155) ((T_LIST) reduce 155) ((T_LNUMBER) reduce 155) ((T_MATCH) reduce 155) ((T_METHOD_C) reduce 155) ((T_NAME_FULLY_QUALIFIED) reduce 155) ((T_NAME_QUALIFIED) reduce 155) ((T_NAME_RELATIVE) reduce 155) ((T_NEW) reduce 155) ((T_NS_C) reduce 155) ((T_OBJECT_CAST) reduce 155) ((T_PRINT) reduce 155) ((T_READONLY) reduce 155) ((T_REQUIRE) reduce 155) ((T_REQUIRE_ONCE) reduce 155) ((T_RETURN) reduce 155) ((T_START_HEREDOC) reduce 155) ((T_STATIC) reduce 155) ((T_STRING) reduce 155) ((T_STRING_CAST) reduce 155) ((T_SWITCH) reduce 155) ((T_THROW) reduce 155) ((T_TRAIT) reduce 155) ((T_TRAIT_C) reduce 155) ((T_TRY) reduce 155) ((T_UNSET) reduce 155) ((T_UNSET_CAST) reduce 155) ((T_VARIABLE) reduce 155) ((T_WHILE) reduce 155) ((T_YIELD) reduce 155) ((T_YIELD_FROM) reduce 155) (("[") reduce 155) (("`") reduce 155) (("{") reduce 155) (("~") reduce 155)) 21690 ((("!") reduce 162) (("\"") reduce 162) (("$") reduce 162) (("(") reduce 162) (("+") reduce 162) (("-") reduce 162) ((";") reduce 162) (("@") reduce 162) ((T_ABSTRACT) reduce 162) ((T_ARRAY) reduce 162) ((T_ARRAY_CAST) reduce 162) ((T_ATTRIBUTE) reduce 162) ((T_BOOL_CAST) reduce 162) ((T_BREAK) reduce 162) ((T_CASE) reduce 162) ((T_CLASS) reduce 162) ((T_CLASS_C) reduce 162) ((T_CLONE) reduce 162) ((T_CONSTANT_ENCAPSED_STRING) reduce 162) ((T_CONTINUE) reduce 162) ((T_DEC) reduce 162) ((T_DECLARE) reduce 162) ((T_DEFAULT) reduce 162) ((T_DIR) reduce 162) ((T_DNUMBER) reduce 162) ((T_DO) reduce 162) ((T_DOUBLE_CAST) reduce 162) ((T_ECHO) reduce 162) ((T_EMPTY) reduce 162) ((T_ENDSWITCH) reduce 162) ((T_ENUM) reduce 162) ((T_EVAL) reduce 162) ((T_EXIT) reduce 162) ((T_FILE) reduce 162) ((T_FINAL) reduce 162) ((T_FN) reduce 162) ((T_FOR) reduce 162) ((T_FOREACH) reduce 162) ((T_FUNCTION) reduce 162) ((T_FUNC_C) reduce 162) ((T_GLOBAL) reduce 162) ((T_GOTO) reduce 162) ((T_HALT_COMPILER) reduce 162) ((T_IF) reduce 162) ((T_INC) reduce 162) ((T_INCLUDE) reduce 162) ((T_INCLUDE_ONCE) reduce 162) ((T_INLINE_HTML) reduce 162) ((T_INTERFACE) reduce 162) ((T_INT_CAST) reduce 162) ((T_ISSET) reduce 162) ((T_LINE) reduce 162) ((T_LIST) reduce 162) ((T_LNUMBER) reduce 162) ((T_MATCH) reduce 162) ((T_METHOD_C) reduce 162) ((T_NAME_FULLY_QUALIFIED) reduce 162) ((T_NAME_QUALIFIED) reduce 162) ((T_NAME_RELATIVE) reduce 162) ((T_NEW) reduce 162) ((T_NS_C) reduce 162) ((T_OBJECT_CAST) reduce 162) ((T_PRINT) reduce 162) ((T_READONLY) reduce 162) ((T_REQUIRE) reduce 162) ((T_REQUIRE_ONCE) reduce 162) ((T_RETURN) reduce 162) ((T_START_HEREDOC) reduce 162) ((T_STATIC) reduce 162) ((T_STRING) reduce 162) ((T_STRING_CAST) reduce 162) ((T_SWITCH) reduce 162) ((T_THROW) reduce 162) ((T_TRAIT) reduce 162) ((T_TRAIT_C) reduce 162) ((T_TRY) reduce 162) ((T_UNSET) reduce 162) ((T_UNSET_CAST) reduce 162) ((T_VARIABLE) reduce 162) ((T_WHILE) reduce 162) ((T_YIELD) reduce 162) ((T_YIELD_FROM) reduce 162) (("[") reduce 162) (("`") reduce 162) (("{") reduce 162) (("~") reduce 162)) 21691 ((("!") reduce 217) (("\"") reduce 217) (("$") reduce 217) (("(") reduce 217) (("+") reduce 217) (("-") reduce 217) ((";") reduce 217) (("@") reduce 217) ((T_ABSTRACT) reduce 217) ((T_ARRAY) reduce 217) ((T_ARRAY_CAST) reduce 217) ((T_ATTRIBUTE) reduce 217) ((T_BOOL_CAST) reduce 217) ((T_BREAK) reduce 217) ((T_CASE) reduce 217) ((T_CLASS) reduce 217) ((T_CLASS_C) reduce 217) ((T_CLONE) reduce 217) ((T_CONSTANT_ENCAPSED_STRING) reduce 217) ((T_CONTINUE) reduce 217) ((T_DEC) reduce 217) ((T_DECLARE) reduce 217) ((T_DEFAULT) reduce 217) ((T_DIR) reduce 217) ((T_DNUMBER) reduce 217) ((T_DO) reduce 217) ((T_DOUBLE_CAST) reduce 217) ((T_ECHO) reduce 217) ((T_EMPTY) reduce 217) ((T_ENDSWITCH) reduce 217) ((T_ENUM) reduce 217) ((T_EVAL) reduce 217) ((T_EXIT) reduce 217) ((T_FILE) reduce 217) ((T_FINAL) reduce 217) ((T_FN) reduce 217) ((T_FOR) reduce 217) ((T_FOREACH) reduce 217) ((T_FUNCTION) reduce 217) ((T_FUNC_C) reduce 217) ((T_GLOBAL) reduce 217) ((T_GOTO) reduce 217) ((T_HALT_COMPILER) reduce 217) ((T_IF) reduce 217) ((T_INC) reduce 217) ((T_INCLUDE) reduce 217) ((T_INCLUDE_ONCE) reduce 217) ((T_INLINE_HTML) reduce 217) ((T_INTERFACE) reduce 217) ((T_INT_CAST) reduce 217) ((T_ISSET) reduce 217) ((T_LINE) reduce 217) ((T_LIST) reduce 217) ((T_LNUMBER) reduce 217) ((T_MATCH) reduce 217) ((T_METHOD_C) reduce 217) ((T_NAME_FULLY_QUALIFIED) reduce 217) ((T_NAME_QUALIFIED) reduce 217) ((T_NAME_RELATIVE) reduce 217) ((T_NEW) reduce 217) ((T_NS_C) reduce 217) ((T_OBJECT_CAST) reduce 217) ((T_PRINT) reduce 217) ((T_READONLY) reduce 217) ((T_REQUIRE) reduce 217) ((T_REQUIRE_ONCE) reduce 217) ((T_RETURN) reduce 217) ((T_START_HEREDOC) reduce 217) ((T_STATIC) reduce 217) ((T_STRING) reduce 217) ((T_STRING_CAST) reduce 217) ((T_SWITCH) reduce 217) ((T_THROW) reduce 217) ((T_TRAIT) reduce 217) ((T_TRAIT_C) reduce 217) ((T_TRY) reduce 217) ((T_UNSET) reduce 217) ((T_UNSET_CAST) reduce 217) ((T_VARIABLE) reduce 217) ((T_WHILE) reduce 217) ((T_YIELD) reduce 217) ((T_YIELD_FROM) reduce 217) (("[") reduce 217) (("`") reduce 217) (("{") reduce 217) (("~") reduce 217)) 21694 ((("!") reduce 218) (("\"") reduce 218) (("$") reduce 218) (("(") reduce 218) (("+") reduce 218) (("-") reduce 218) ((";") reduce 218) (("@") reduce 218) ((T_ABSTRACT) reduce 218) ((T_ARRAY) reduce 218) ((T_ARRAY_CAST) reduce 218) ((T_ATTRIBUTE) reduce 218) ((T_BOOL_CAST) reduce 218) ((T_BREAK) reduce 218) ((T_CASE) reduce 218) ((T_CLASS) reduce 218) ((T_CLASS_C) reduce 218) ((T_CLONE) reduce 218) ((T_CONSTANT_ENCAPSED_STRING) reduce 218) ((T_CONTINUE) reduce 218) ((T_DEC) reduce 218) ((T_DECLARE) reduce 218) ((T_DEFAULT) reduce 218) ((T_DIR) reduce 218) ((T_DNUMBER) reduce 218) ((T_DO) reduce 218) ((T_DOUBLE_CAST) reduce 218) ((T_ECHO) reduce 218) ((T_EMPTY) reduce 218) ((T_ENDSWITCH) reduce 218) ((T_ENUM) reduce 218) ((T_EVAL) reduce 218) ((T_EXIT) reduce 218) ((T_FILE) reduce 218) ((T_FINAL) reduce 218) ((T_FN) reduce 218) ((T_FOR) reduce 218) ((T_FOREACH) reduce 218) ((T_FUNCTION) reduce 218) ((T_FUNC_C) reduce 218) ((T_GLOBAL) reduce 218) ((T_GOTO) reduce 218) ((T_HALT_COMPILER) reduce 218) ((T_IF) reduce 218) ((T_INC) reduce 218) ((T_INCLUDE) reduce 218) ((T_INCLUDE_ONCE) reduce 218) ((T_INLINE_HTML) reduce 218) ((T_INTERFACE) reduce 218) ((T_INT_CAST) reduce 218) ((T_ISSET) reduce 218) ((T_LINE) reduce 218) ((T_LIST) reduce 218) ((T_LNUMBER) reduce 218) ((T_MATCH) reduce 218) ((T_METHOD_C) reduce 218) ((T_NAME_FULLY_QUALIFIED) reduce 218) ((T_NAME_QUALIFIED) reduce 218) ((T_NAME_RELATIVE) reduce 218) ((T_NEW) reduce 218) ((T_NS_C) reduce 218) ((T_OBJECT_CAST) reduce 218) ((T_PRINT) reduce 218) ((T_READONLY) reduce 218) ((T_REQUIRE) reduce 218) ((T_REQUIRE_ONCE) reduce 218) ((T_RETURN) reduce 218) ((T_START_HEREDOC) reduce 218) ((T_STATIC) reduce 218) ((T_STRING) reduce 218) ((T_STRING_CAST) reduce 218) ((T_SWITCH) reduce 218) ((T_THROW) reduce 218) ((T_TRAIT) reduce 218) ((T_TRAIT_C) reduce 218) ((T_TRY) reduce 218) ((T_UNSET) reduce 218) ((T_UNSET_CAST) reduce 218) ((T_VARIABLE) reduce 218) ((T_WHILE) reduce 218) ((T_YIELD) reduce 218) ((T_YIELD_FROM) reduce 218) (("[") reduce 218) (("`") reduce 218) (("{") reduce 218) (("~") reduce 218)) 21695 ((("!") reduce 161) (("\"") reduce 161) (("$") reduce 161) (("(") reduce 161) (("+") reduce 161) (("-") reduce 161) ((";") reduce 161) (("@") reduce 161) ((T_ABSTRACT) reduce 161) ((T_ARRAY) reduce 161) ((T_ARRAY_CAST) reduce 161) ((T_ATTRIBUTE) reduce 161) ((T_BOOL_CAST) reduce 161) ((T_BREAK) reduce 161) ((T_CASE) reduce 161) ((T_CLASS) reduce 161) ((T_CLASS_C) reduce 161) ((T_CLONE) reduce 161) ((T_CONSTANT_ENCAPSED_STRING) reduce 161) ((T_CONTINUE) reduce 161) ((T_DEC) reduce 161) ((T_DECLARE) reduce 161) ((T_DEFAULT) reduce 161) ((T_DIR) reduce 161) ((T_DNUMBER) reduce 161) ((T_DO) reduce 161) ((T_DOUBLE_CAST) reduce 161) ((T_ECHO) reduce 161) ((T_EMPTY) reduce 161) ((T_ENDSWITCH) reduce 161) ((T_ENUM) reduce 161) ((T_EVAL) reduce 161) ((T_EXIT) reduce 161) ((T_FILE) reduce 161) ((T_FINAL) reduce 161) ((T_FN) reduce 161) ((T_FOR) reduce 161) ((T_FOREACH) reduce 161) ((T_FUNCTION) reduce 161) ((T_FUNC_C) reduce 161) ((T_GLOBAL) reduce 161) ((T_GOTO) reduce 161) ((T_HALT_COMPILER) reduce 161) ((T_IF) reduce 161) ((T_INC) reduce 161) ((T_INCLUDE) reduce 161) ((T_INCLUDE_ONCE) reduce 161) ((T_INLINE_HTML) reduce 161) ((T_INTERFACE) reduce 161) ((T_INT_CAST) reduce 161) ((T_ISSET) reduce 161) ((T_LINE) reduce 161) ((T_LIST) reduce 161) ((T_LNUMBER) reduce 161) ((T_MATCH) reduce 161) ((T_METHOD_C) reduce 161) ((T_NAME_FULLY_QUALIFIED) reduce 161) ((T_NAME_QUALIFIED) reduce 161) ((T_NAME_RELATIVE) reduce 161) ((T_NEW) reduce 161) ((T_NS_C) reduce 161) ((T_OBJECT_CAST) reduce 161) ((T_PRINT) reduce 161) ((T_READONLY) reduce 161) ((T_REQUIRE) reduce 161) ((T_REQUIRE_ONCE) reduce 161) ((T_RETURN) reduce 161) ((T_START_HEREDOC) reduce 161) ((T_STATIC) reduce 161) ((T_STRING) reduce 161) ((T_STRING_CAST) reduce 161) ((T_SWITCH) reduce 161) ((T_THROW) reduce 161) ((T_TRAIT) reduce 161) ((T_TRAIT_C) reduce 161) ((T_TRY) reduce 161) ((T_UNSET) reduce 161) ((T_UNSET_CAST) reduce 161) ((T_VARIABLE) reduce 161) ((T_WHILE) reduce 161) ((T_YIELD) reduce 161) ((T_YIELD_FROM) reduce 161) (("[") reduce 161) (("`") reduce 161) (("{") reduce 161) (("~") reduce 161)) 21704 ((("!") reduce 150) (("\"") reduce 150) (("$") reduce 150) (("(") reduce 150) (("+") reduce 150) (("-") reduce 150) ((";") reduce 150) (("@") reduce 150) ((T_ABSTRACT) reduce 150) ((T_ARRAY) reduce 150) ((T_ARRAY_CAST) reduce 150) ((T_ATTRIBUTE) reduce 150) ((T_BOOL_CAST) reduce 150) ((T_BREAK) reduce 150) ((T_CASE) reduce 150) ((T_CLASS) reduce 150) ((T_CLASS_C) reduce 150) ((T_CLONE) reduce 150) ((T_CONSTANT_ENCAPSED_STRING) reduce 150) ((T_CONTINUE) reduce 150) ((T_DEC) reduce 150) ((T_DECLARE) reduce 150) ((T_DEFAULT) reduce 150) ((T_DIR) reduce 150) ((T_DNUMBER) reduce 150) ((T_DO) reduce 150) ((T_DOUBLE_CAST) reduce 150) ((T_ECHO) reduce 150) ((T_EMPTY) reduce 150) ((T_ENDSWITCH) reduce 150) ((T_ENUM) reduce 150) ((T_EVAL) reduce 150) ((T_EXIT) reduce 150) ((T_FILE) reduce 150) ((T_FINAL) reduce 150) ((T_FN) reduce 150) ((T_FOR) reduce 150) ((T_FOREACH) reduce 150) ((T_FUNCTION) reduce 150) ((T_FUNC_C) reduce 150) ((T_GLOBAL) reduce 150) ((T_GOTO) reduce 150) ((T_HALT_COMPILER) reduce 150) ((T_IF) reduce 150) ((T_INC) reduce 150) ((T_INCLUDE) reduce 150) ((T_INCLUDE_ONCE) reduce 150) ((T_INLINE_HTML) reduce 150) ((T_INTERFACE) reduce 150) ((T_INT_CAST) reduce 150) ((T_ISSET) reduce 150) ((T_LINE) reduce 150) ((T_LIST) reduce 150) ((T_LNUMBER) reduce 150) ((T_MATCH) reduce 150) ((T_METHOD_C) reduce 150) ((T_NAME_FULLY_QUALIFIED) reduce 150) ((T_NAME_QUALIFIED) reduce 150) ((T_NAME_RELATIVE) reduce 150) ((T_NEW) reduce 150) ((T_NS_C) reduce 150) ((T_OBJECT_CAST) reduce 150) ((T_PRINT) reduce 150) ((T_READONLY) reduce 150) ((T_REQUIRE) reduce 150) ((T_REQUIRE_ONCE) reduce 150) ((T_RETURN) reduce 150) ((T_START_HEREDOC) reduce 150) ((T_STATIC) reduce 150) ((T_STRING) reduce 150) ((T_STRING_CAST) reduce 150) ((T_SWITCH) reduce 150) ((T_THROW) reduce 150) ((T_TRAIT) reduce 150) ((T_TRAIT_C) reduce 150) ((T_TRY) reduce 150) ((T_UNSET) reduce 150) ((T_UNSET_CAST) reduce 150) ((T_VARIABLE) reduce 150) ((T_WHILE) reduce 150) ((T_YIELD) reduce 150) ((T_YIELD_FROM) reduce 150) (("[") reduce 150) (("`") reduce 150) (("{") reduce 150) (("~") reduce 150)) 21705 ((("!") reduce 215) (("\"") reduce 215) (("$") reduce 215) (("(") reduce 215) (("+") reduce 215) (("-") reduce 215) ((";") reduce 215) (("@") reduce 215) ((T_ABSTRACT) reduce 215) ((T_ARRAY) reduce 215) ((T_ARRAY_CAST) reduce 215) ((T_ATTRIBUTE) reduce 215) ((T_BOOL_CAST) reduce 215) ((T_BREAK) reduce 215) ((T_CASE) reduce 215) ((T_CLASS) reduce 215) ((T_CLASS_C) reduce 215) ((T_CLONE) reduce 215) ((T_CONSTANT_ENCAPSED_STRING) reduce 215) ((T_CONTINUE) reduce 215) ((T_DEC) reduce 215) ((T_DECLARE) reduce 215) ((T_DEFAULT) reduce 215) ((T_DIR) reduce 215) ((T_DNUMBER) reduce 215) ((T_DO) reduce 215) ((T_DOUBLE_CAST) reduce 215) ((T_ECHO) reduce 215) ((T_EMPTY) reduce 215) ((T_ENDSWITCH) reduce 215) ((T_ENUM) reduce 215) ((T_EVAL) reduce 215) ((T_EXIT) reduce 215) ((T_FILE) reduce 215) ((T_FINAL) reduce 215) ((T_FN) reduce 215) ((T_FOR) reduce 215) ((T_FOREACH) reduce 215) ((T_FUNCTION) reduce 215) ((T_FUNC_C) reduce 215) ((T_GLOBAL) reduce 215) ((T_GOTO) reduce 215) ((T_HALT_COMPILER) reduce 215) ((T_IF) reduce 215) ((T_INC) reduce 215) ((T_INCLUDE) reduce 215) ((T_INCLUDE_ONCE) reduce 215) ((T_INLINE_HTML) reduce 215) ((T_INTERFACE) reduce 215) ((T_INT_CAST) reduce 215) ((T_ISSET) reduce 215) ((T_LINE) reduce 215) ((T_LIST) reduce 215) ((T_LNUMBER) reduce 215) ((T_MATCH) reduce 215) ((T_METHOD_C) reduce 215) ((T_NAME_FULLY_QUALIFIED) reduce 215) ((T_NAME_QUALIFIED) reduce 215) ((T_NAME_RELATIVE) reduce 215) ((T_NEW) reduce 215) ((T_NS_C) reduce 215) ((T_OBJECT_CAST) reduce 215) ((T_PRINT) reduce 215) ((T_READONLY) reduce 215) ((T_REQUIRE) reduce 215) ((T_REQUIRE_ONCE) reduce 215) ((T_RETURN) reduce 215) ((T_START_HEREDOC) reduce 215) ((T_STATIC) reduce 215) ((T_STRING) reduce 215) ((T_STRING_CAST) reduce 215) ((T_SWITCH) reduce 215) ((T_THROW) reduce 215) ((T_TRAIT) reduce 215) ((T_TRAIT_C) reduce 215) ((T_TRY) reduce 215) ((T_UNSET) reduce 215) ((T_UNSET_CAST) reduce 215) ((T_VARIABLE) reduce 215) ((T_WHILE) reduce 215) ((T_YIELD) reduce 215) ((T_YIELD_FROM) reduce 215) (("[") reduce 215) (("`") reduce 215) (("{") reduce 215) (("~") reduce 215)) 21708 ((("!") reduce 216) (("\"") reduce 216) (("$") reduce 216) (("(") reduce 216) (("+") reduce 216) (("-") reduce 216) ((";") reduce 216) (("@") reduce 216) ((T_ABSTRACT) reduce 216) ((T_ARRAY) reduce 216) ((T_ARRAY_CAST) reduce 216) ((T_ATTRIBUTE) reduce 216) ((T_BOOL_CAST) reduce 216) ((T_BREAK) reduce 216) ((T_CASE) reduce 216) ((T_CLASS) reduce 216) ((T_CLASS_C) reduce 216) ((T_CLONE) reduce 216) ((T_CONSTANT_ENCAPSED_STRING) reduce 216) ((T_CONTINUE) reduce 216) ((T_DEC) reduce 216) ((T_DECLARE) reduce 216) ((T_DEFAULT) reduce 216) ((T_DIR) reduce 216) ((T_DNUMBER) reduce 216) ((T_DO) reduce 216) ((T_DOUBLE_CAST) reduce 216) ((T_ECHO) reduce 216) ((T_EMPTY) reduce 216) ((T_ENDSWITCH) reduce 216) ((T_ENUM) reduce 216) ((T_EVAL) reduce 216) ((T_EXIT) reduce 216) ((T_FILE) reduce 216) ((T_FINAL) reduce 216) ((T_FN) reduce 216) ((T_FOR) reduce 216) ((T_FOREACH) reduce 216) ((T_FUNCTION) reduce 216) ((T_FUNC_C) reduce 216) ((T_GLOBAL) reduce 216) ((T_GOTO) reduce 216) ((T_HALT_COMPILER) reduce 216) ((T_IF) reduce 216) ((T_INC) reduce 216) ((T_INCLUDE) reduce 216) ((T_INCLUDE_ONCE) reduce 216) ((T_INLINE_HTML) reduce 216) ((T_INTERFACE) reduce 216) ((T_INT_CAST) reduce 216) ((T_ISSET) reduce 216) ((T_LINE) reduce 216) ((T_LIST) reduce 216) ((T_LNUMBER) reduce 216) ((T_MATCH) reduce 216) ((T_METHOD_C) reduce 216) ((T_NAME_FULLY_QUALIFIED) reduce 216) ((T_NAME_QUALIFIED) reduce 216) ((T_NAME_RELATIVE) reduce 216) ((T_NEW) reduce 216) ((T_NS_C) reduce 216) ((T_OBJECT_CAST) reduce 216) ((T_PRINT) reduce 216) ((T_READONLY) reduce 216) ((T_REQUIRE) reduce 216) ((T_REQUIRE_ONCE) reduce 216) ((T_RETURN) reduce 216) ((T_START_HEREDOC) reduce 216) ((T_STATIC) reduce 216) ((T_STRING) reduce 216) ((T_STRING_CAST) reduce 216) ((T_SWITCH) reduce 216) ((T_THROW) reduce 216) ((T_TRAIT) reduce 216) ((T_TRAIT_C) reduce 216) ((T_TRY) reduce 216) ((T_UNSET) reduce 216) ((T_UNSET_CAST) reduce 216) ((T_VARIABLE) reduce 216) ((T_WHILE) reduce 216) ((T_YIELD) reduce 216) ((T_YIELD_FROM) reduce 216) (("[") reduce 216) (("`") reduce 216) (("{") reduce 216) (("~") reduce 216)) 21715 ((("!") reduce 199) (("\"") reduce 199) (("$") reduce 199) (("(") reduce 199) (("+") reduce 199) (("-") reduce 199) ((";") reduce 199) (("@") reduce 199) ((T_ABSTRACT) reduce 199) ((T_ARRAY) reduce 199) ((T_ARRAY_CAST) reduce 199) ((T_ATTRIBUTE) reduce 199) ((T_BOOL_CAST) reduce 199) ((T_BREAK) reduce 199) ((T_CASE) reduce 199) ((T_CLASS) reduce 199) ((T_CLASS_C) reduce 199) ((T_CLONE) reduce 199) ((T_CONSTANT_ENCAPSED_STRING) reduce 199) ((T_CONTINUE) reduce 199) ((T_DEC) reduce 199) ((T_DECLARE) reduce 199) ((T_DEFAULT) reduce 199) ((T_DIR) reduce 199) ((T_DNUMBER) reduce 199) ((T_DO) reduce 199) ((T_DOUBLE_CAST) reduce 199) ((T_ECHO) reduce 199) ((T_EMPTY) reduce 199) ((T_ENDSWITCH) reduce 199) ((T_ENUM) reduce 199) ((T_EVAL) reduce 199) ((T_EXIT) reduce 199) ((T_FILE) reduce 199) ((T_FINAL) reduce 199) ((T_FN) reduce 199) ((T_FOR) reduce 199) ((T_FOREACH) reduce 199) ((T_FUNCTION) reduce 199) ((T_FUNC_C) reduce 199) ((T_GLOBAL) reduce 199) ((T_GOTO) reduce 199) ((T_HALT_COMPILER) reduce 199) ((T_IF) reduce 199) ((T_INC) reduce 199) ((T_INCLUDE) reduce 199) ((T_INCLUDE_ONCE) reduce 199) ((T_INLINE_HTML) reduce 199) ((T_INTERFACE) reduce 199) ((T_INT_CAST) reduce 199) ((T_ISSET) reduce 199) ((T_LINE) reduce 199) ((T_LIST) reduce 199) ((T_LNUMBER) reduce 199) ((T_MATCH) reduce 199) ((T_METHOD_C) reduce 199) ((T_NAME_FULLY_QUALIFIED) reduce 199) ((T_NAME_QUALIFIED) reduce 199) ((T_NAME_RELATIVE) reduce 199) ((T_NEW) reduce 199) ((T_NS_C) reduce 199) ((T_OBJECT_CAST) reduce 199) ((T_PRINT) reduce 199) ((T_READONLY) reduce 199) ((T_REQUIRE) reduce 199) ((T_REQUIRE_ONCE) reduce 199) ((T_RETURN) reduce 199) ((T_START_HEREDOC) reduce 199) ((T_STATIC) reduce 199) ((T_STRING) reduce 199) ((T_STRING_CAST) reduce 199) ((T_SWITCH) reduce 199) ((T_THROW) reduce 199) ((T_TRAIT) reduce 199) ((T_TRAIT_C) reduce 199) ((T_TRY) reduce 199) ((T_UNSET) reduce 199) ((T_UNSET_CAST) reduce 199) ((T_VARIABLE) reduce 199) ((T_WHILE) reduce 199) ((T_YIELD) reduce 199) ((T_YIELD_FROM) reduce 199) (("[") reduce 199) (("`") reduce 199) (("{") reduce 199) (("~") reduce 199)) 21717 ((("!") reduce 157) (("\"") reduce 157) (("$") reduce 157) (("(") reduce 157) (("+") reduce 157) (("-") reduce 157) ((";") reduce 157) (("@") reduce 157) ((T_ABSTRACT) reduce 157) ((T_ARRAY) reduce 157) ((T_ARRAY_CAST) reduce 157) ((T_ATTRIBUTE) reduce 157) ((T_BOOL_CAST) reduce 157) ((T_BREAK) reduce 157) ((T_CASE) reduce 157) ((T_CLASS) reduce 157) ((T_CLASS_C) reduce 157) ((T_CLONE) reduce 157) ((T_CONSTANT_ENCAPSED_STRING) reduce 157) ((T_CONTINUE) reduce 157) ((T_DEC) reduce 157) ((T_DECLARE) reduce 157) ((T_DEFAULT) reduce 157) ((T_DIR) reduce 157) ((T_DNUMBER) reduce 157) ((T_DO) reduce 157) ((T_DOUBLE_CAST) reduce 157) ((T_ECHO) reduce 157) ((T_EMPTY) reduce 157) ((T_ENDSWITCH) reduce 157) ((T_ENUM) reduce 157) ((T_EVAL) reduce 157) ((T_EXIT) reduce 157) ((T_FILE) reduce 157) ((T_FINAL) reduce 157) ((T_FN) reduce 157) ((T_FOR) reduce 157) ((T_FOREACH) reduce 157) ((T_FUNCTION) reduce 157) ((T_FUNC_C) reduce 157) ((T_GLOBAL) reduce 157) ((T_GOTO) reduce 157) ((T_HALT_COMPILER) reduce 157) ((T_IF) reduce 157) ((T_INC) reduce 157) ((T_INCLUDE) reduce 157) ((T_INCLUDE_ONCE) reduce 157) ((T_INLINE_HTML) reduce 157) ((T_INTERFACE) reduce 157) ((T_INT_CAST) reduce 157) ((T_ISSET) reduce 157) ((T_LINE) reduce 157) ((T_LIST) reduce 157) ((T_LNUMBER) reduce 157) ((T_MATCH) reduce 157) ((T_METHOD_C) reduce 157) ((T_NAME_FULLY_QUALIFIED) reduce 157) ((T_NAME_QUALIFIED) reduce 157) ((T_NAME_RELATIVE) reduce 157) ((T_NEW) reduce 157) ((T_NS_C) reduce 157) ((T_OBJECT_CAST) reduce 157) ((T_PRINT) reduce 157) ((T_READONLY) reduce 157) ((T_REQUIRE) reduce 157) ((T_REQUIRE_ONCE) reduce 157) ((T_RETURN) reduce 157) ((T_START_HEREDOC) reduce 157) ((T_STATIC) reduce 157) ((T_STRING) reduce 157) ((T_STRING_CAST) reduce 157) ((T_SWITCH) reduce 157) ((T_THROW) reduce 157) ((T_TRAIT) reduce 157) ((T_TRAIT_C) reduce 157) ((T_TRY) reduce 157) ((T_UNSET) reduce 157) ((T_UNSET_CAST) reduce 157) ((T_VARIABLE) reduce 157) ((T_WHILE) reduce 157) ((T_YIELD) reduce 157) ((T_YIELD_FROM) reduce 157) (("[") reduce 157) (("`") reduce 157) (("{") reduce 157) (("~") reduce 157)) 21723 ((("!") reduce 149) (("\"") reduce 149) (("$") reduce 149) (("(") reduce 149) (("+") reduce 149) (("-") reduce 149) ((";") reduce 149) (("@") reduce 149) ((T_ABSTRACT) reduce 149) ((T_ARRAY) reduce 149) ((T_ARRAY_CAST) reduce 149) ((T_ATTRIBUTE) reduce 149) ((T_BOOL_CAST) reduce 149) ((T_BREAK) reduce 149) ((T_CASE) reduce 149) ((T_CLASS) reduce 149) ((T_CLASS_C) reduce 149) ((T_CLONE) reduce 149) ((T_CONSTANT_ENCAPSED_STRING) reduce 149) ((T_CONTINUE) reduce 149) ((T_DEC) reduce 149) ((T_DECLARE) reduce 149) ((T_DEFAULT) reduce 149) ((T_DIR) reduce 149) ((T_DNUMBER) reduce 149) ((T_DO) reduce 149) ((T_DOUBLE_CAST) reduce 149) ((T_ECHO) reduce 149) ((T_EMPTY) reduce 149) ((T_ENDSWITCH) reduce 149) ((T_ENUM) reduce 149) ((T_EVAL) reduce 149) ((T_EXIT) reduce 149) ((T_FILE) reduce 149) ((T_FINAL) reduce 149) ((T_FN) reduce 149) ((T_FOR) reduce 149) ((T_FOREACH) reduce 149) ((T_FUNCTION) reduce 149) ((T_FUNC_C) reduce 149) ((T_GLOBAL) reduce 149) ((T_GOTO) reduce 149) ((T_HALT_COMPILER) reduce 149) ((T_IF) reduce 149) ((T_INC) reduce 149) ((T_INCLUDE) reduce 149) ((T_INCLUDE_ONCE) reduce 149) ((T_INLINE_HTML) reduce 149) ((T_INTERFACE) reduce 149) ((T_INT_CAST) reduce 149) ((T_ISSET) reduce 149) ((T_LINE) reduce 149) ((T_LIST) reduce 149) ((T_LNUMBER) reduce 149) ((T_MATCH) reduce 149) ((T_METHOD_C) reduce 149) ((T_NAME_FULLY_QUALIFIED) reduce 149) ((T_NAME_QUALIFIED) reduce 149) ((T_NAME_RELATIVE) reduce 149) ((T_NEW) reduce 149) ((T_NS_C) reduce 149) ((T_OBJECT_CAST) reduce 149) ((T_PRINT) reduce 149) ((T_READONLY) reduce 149) ((T_REQUIRE) reduce 149) ((T_REQUIRE_ONCE) reduce 149) ((T_RETURN) reduce 149) ((T_START_HEREDOC) reduce 149) ((T_STATIC) reduce 149) ((T_STRING) reduce 149) ((T_STRING_CAST) reduce 149) ((T_SWITCH) reduce 149) ((T_THROW) reduce 149) ((T_TRAIT) reduce 149) ((T_TRAIT_C) reduce 149) ((T_TRY) reduce 149) ((T_UNSET) reduce 149) ((T_UNSET_CAST) reduce 149) ((T_VARIABLE) reduce 149) ((T_WHILE) reduce 149) ((T_YIELD) reduce 149) ((T_YIELD_FROM) reduce 149) (("[") reduce 149) (("`") reduce 149) (("{") reduce 149) (("~") reduce 149)) 21728 ((("!") reduce 163) (("\"") reduce 163) (("$") reduce 163) (("(") reduce 163) (("+") reduce 163) (("-") reduce 163) ((";") reduce 163) (("@") reduce 163) ((T_ABSTRACT) reduce 163) ((T_ARRAY) reduce 163) ((T_ARRAY_CAST) reduce 163) ((T_ATTRIBUTE) reduce 163) ((T_BOOL_CAST) reduce 163) ((T_BREAK) reduce 163) ((T_CASE) reduce 163) ((T_CLASS) reduce 163) ((T_CLASS_C) reduce 163) ((T_CLONE) reduce 163) ((T_CONSTANT_ENCAPSED_STRING) reduce 163) ((T_CONTINUE) reduce 163) ((T_DEC) reduce 163) ((T_DECLARE) reduce 163) ((T_DEFAULT) reduce 163) ((T_DIR) reduce 163) ((T_DNUMBER) reduce 163) ((T_DO) reduce 163) ((T_DOUBLE_CAST) reduce 163) ((T_ECHO) reduce 163) ((T_EMPTY) reduce 163) ((T_ENDSWITCH) reduce 163) ((T_ENUM) reduce 163) ((T_EVAL) reduce 163) ((T_EXIT) reduce 163) ((T_FILE) reduce 163) ((T_FINAL) reduce 163) ((T_FN) reduce 163) ((T_FOR) reduce 163) ((T_FOREACH) reduce 163) ((T_FUNCTION) reduce 163) ((T_FUNC_C) reduce 163) ((T_GLOBAL) reduce 163) ((T_GOTO) reduce 163) ((T_HALT_COMPILER) reduce 163) ((T_IF) reduce 163) ((T_INC) reduce 163) ((T_INCLUDE) reduce 163) ((T_INCLUDE_ONCE) reduce 163) ((T_INLINE_HTML) reduce 163) ((T_INTERFACE) reduce 163) ((T_INT_CAST) reduce 163) ((T_ISSET) reduce 163) ((T_LINE) reduce 163) ((T_LIST) reduce 163) ((T_LNUMBER) reduce 163) ((T_MATCH) reduce 163) ((T_METHOD_C) reduce 163) ((T_NAME_FULLY_QUALIFIED) reduce 163) ((T_NAME_QUALIFIED) reduce 163) ((T_NAME_RELATIVE) reduce 163) ((T_NEW) reduce 163) ((T_NS_C) reduce 163) ((T_OBJECT_CAST) reduce 163) ((T_PRINT) reduce 163) ((T_READONLY) reduce 163) ((T_REQUIRE) reduce 163) ((T_REQUIRE_ONCE) reduce 163) ((T_RETURN) reduce 163) ((T_START_HEREDOC) reduce 163) ((T_STATIC) reduce 163) ((T_STRING) reduce 163) ((T_STRING_CAST) reduce 163) ((T_SWITCH) reduce 163) ((T_THROW) reduce 163) ((T_TRAIT) reduce 163) ((T_TRAIT_C) reduce 163) ((T_TRY) reduce 163) ((T_UNSET) reduce 163) ((T_UNSET_CAST) reduce 163) ((T_VARIABLE) reduce 163) ((T_WHILE) reduce 163) ((T_YIELD) reduce 163) ((T_YIELD_FROM) reduce 163) (("[") reduce 163) (("`") reduce 163) (("{") reduce 163) (("~") reduce 163)) 21729 ((("!") reduce 219) (("\"") reduce 219) (("$") reduce 219) (("(") reduce 219) (("+") reduce 219) (("-") reduce 219) ((";") reduce 219) (("@") reduce 219) ((T_ABSTRACT) reduce 219) ((T_ARRAY) reduce 219) ((T_ARRAY_CAST) reduce 219) ((T_ATTRIBUTE) reduce 219) ((T_BOOL_CAST) reduce 219) ((T_BREAK) reduce 219) ((T_CASE) reduce 219) ((T_CLASS) reduce 219) ((T_CLASS_C) reduce 219) ((T_CLONE) reduce 219) ((T_CONSTANT_ENCAPSED_STRING) reduce 219) ((T_CONTINUE) reduce 219) ((T_DEC) reduce 219) ((T_DECLARE) reduce 219) ((T_DEFAULT) reduce 219) ((T_DIR) reduce 219) ((T_DNUMBER) reduce 219) ((T_DO) reduce 219) ((T_DOUBLE_CAST) reduce 219) ((T_ECHO) reduce 219) ((T_EMPTY) reduce 219) ((T_ENDSWITCH) reduce 219) ((T_ENUM) reduce 219) ((T_EVAL) reduce 219) ((T_EXIT) reduce 219) ((T_FILE) reduce 219) ((T_FINAL) reduce 219) ((T_FN) reduce 219) ((T_FOR) reduce 219) ((T_FOREACH) reduce 219) ((T_FUNCTION) reduce 219) ((T_FUNC_C) reduce 219) ((T_GLOBAL) reduce 219) ((T_GOTO) reduce 219) ((T_HALT_COMPILER) reduce 219) ((T_IF) reduce 219) ((T_INC) reduce 219) ((T_INCLUDE) reduce 219) ((T_INCLUDE_ONCE) reduce 219) ((T_INLINE_HTML) reduce 219) ((T_INTERFACE) reduce 219) ((T_INT_CAST) reduce 219) ((T_ISSET) reduce 219) ((T_LINE) reduce 219) ((T_LIST) reduce 219) ((T_LNUMBER) reduce 219) ((T_MATCH) reduce 219) ((T_METHOD_C) reduce 219) ((T_NAME_FULLY_QUALIFIED) reduce 219) ((T_NAME_QUALIFIED) reduce 219) ((T_NAME_RELATIVE) reduce 219) ((T_NEW) reduce 219) ((T_NS_C) reduce 219) ((T_OBJECT_CAST) reduce 219) ((T_PRINT) reduce 219) ((T_READONLY) reduce 219) ((T_REQUIRE) reduce 219) ((T_REQUIRE_ONCE) reduce 219) ((T_RETURN) reduce 219) ((T_START_HEREDOC) reduce 219) ((T_STATIC) reduce 219) ((T_STRING) reduce 219) ((T_STRING_CAST) reduce 219) ((T_SWITCH) reduce 219) ((T_THROW) reduce 219) ((T_TRAIT) reduce 219) ((T_TRAIT_C) reduce 219) ((T_TRY) reduce 219) ((T_UNSET) reduce 219) ((T_UNSET_CAST) reduce 219) ((T_VARIABLE) reduce 219) ((T_WHILE) reduce 219) ((T_YIELD) reduce 219) ((T_YIELD_FROM) reduce 219) (("[") reduce 219) (("`") reduce 219) (("{") reduce 219) (("~") reduce 219)) 21732 ((("!") reduce 220) (("\"") reduce 220) (("$") reduce 220) (("(") reduce 220) (("+") reduce 220) (("-") reduce 220) ((";") reduce 220) (("@") reduce 220) ((T_ABSTRACT) reduce 220) ((T_ARRAY) reduce 220) ((T_ARRAY_CAST) reduce 220) ((T_ATTRIBUTE) reduce 220) ((T_BOOL_CAST) reduce 220) ((T_BREAK) reduce 220) ((T_CASE) reduce 220) ((T_CLASS) reduce 220) ((T_CLASS_C) reduce 220) ((T_CLONE) reduce 220) ((T_CONSTANT_ENCAPSED_STRING) reduce 220) ((T_CONTINUE) reduce 220) ((T_DEC) reduce 220) ((T_DECLARE) reduce 220) ((T_DEFAULT) reduce 220) ((T_DIR) reduce 220) ((T_DNUMBER) reduce 220) ((T_DO) reduce 220) ((T_DOUBLE_CAST) reduce 220) ((T_ECHO) reduce 220) ((T_EMPTY) reduce 220) ((T_ENDSWITCH) reduce 220) ((T_ENUM) reduce 220) ((T_EVAL) reduce 220) ((T_EXIT) reduce 220) ((T_FILE) reduce 220) ((T_FINAL) reduce 220) ((T_FN) reduce 220) ((T_FOR) reduce 220) ((T_FOREACH) reduce 220) ((T_FUNCTION) reduce 220) ((T_FUNC_C) reduce 220) ((T_GLOBAL) reduce 220) ((T_GOTO) reduce 220) ((T_HALT_COMPILER) reduce 220) ((T_IF) reduce 220) ((T_INC) reduce 220) ((T_INCLUDE) reduce 220) ((T_INCLUDE_ONCE) reduce 220) ((T_INLINE_HTML) reduce 220) ((T_INTERFACE) reduce 220) ((T_INT_CAST) reduce 220) ((T_ISSET) reduce 220) ((T_LINE) reduce 220) ((T_LIST) reduce 220) ((T_LNUMBER) reduce 220) ((T_MATCH) reduce 220) ((T_METHOD_C) reduce 220) ((T_NAME_FULLY_QUALIFIED) reduce 220) ((T_NAME_QUALIFIED) reduce 220) ((T_NAME_RELATIVE) reduce 220) ((T_NEW) reduce 220) ((T_NS_C) reduce 220) ((T_OBJECT_CAST) reduce 220) ((T_PRINT) reduce 220) ((T_READONLY) reduce 220) ((T_REQUIRE) reduce 220) ((T_REQUIRE_ONCE) reduce 220) ((T_RETURN) reduce 220) ((T_START_HEREDOC) reduce 220) ((T_STATIC) reduce 220) ((T_STRING) reduce 220) ((T_STRING_CAST) reduce 220) ((T_SWITCH) reduce 220) ((T_THROW) reduce 220) ((T_TRAIT) reduce 220) ((T_TRAIT_C) reduce 220) ((T_TRY) reduce 220) ((T_UNSET) reduce 220) ((T_UNSET_CAST) reduce 220) ((T_VARIABLE) reduce 220) ((T_WHILE) reduce 220) ((T_YIELD) reduce 220) ((T_YIELD_FROM) reduce 220) (("[") reduce 220) (("`") reduce 220) (("{") reduce 220) (("~") reduce 220)) 21734 ((("!") reduce 153) (("\"") reduce 153) (("$") reduce 153) (("(") reduce 153) (("+") reduce 153) (("-") reduce 153) ((";") reduce 153) (("@") reduce 153) ((T_ABSTRACT) reduce 153) ((T_ARRAY) reduce 153) ((T_ARRAY_CAST) reduce 153) ((T_ATTRIBUTE) reduce 153) ((T_BOOL_CAST) reduce 153) ((T_BREAK) reduce 153) ((T_CASE) reduce 153) ((T_CLASS) reduce 153) ((T_CLASS_C) reduce 153) ((T_CLONE) reduce 153) ((T_CONSTANT_ENCAPSED_STRING) reduce 153) ((T_CONTINUE) reduce 153) ((T_DEC) reduce 153) ((T_DECLARE) reduce 153) ((T_DEFAULT) reduce 153) ((T_DIR) reduce 153) ((T_DNUMBER) reduce 153) ((T_DO) reduce 153) ((T_DOUBLE_CAST) reduce 153) ((T_ECHO) reduce 153) ((T_EMPTY) reduce 153) ((T_ENDSWITCH) reduce 153) ((T_ENUM) reduce 153) ((T_EVAL) reduce 153) ((T_EXIT) reduce 153) ((T_FILE) reduce 153) ((T_FINAL) reduce 153) ((T_FN) reduce 153) ((T_FOR) reduce 153) ((T_FOREACH) reduce 153) ((T_FUNCTION) reduce 153) ((T_FUNC_C) reduce 153) ((T_GLOBAL) reduce 153) ((T_GOTO) reduce 153) ((T_HALT_COMPILER) reduce 153) ((T_IF) reduce 153) ((T_INC) reduce 153) ((T_INCLUDE) reduce 153) ((T_INCLUDE_ONCE) reduce 153) ((T_INLINE_HTML) reduce 153) ((T_INTERFACE) reduce 153) ((T_INT_CAST) reduce 153) ((T_ISSET) reduce 153) ((T_LINE) reduce 153) ((T_LIST) reduce 153) ((T_LNUMBER) reduce 153) ((T_MATCH) reduce 153) ((T_METHOD_C) reduce 153) ((T_NAME_FULLY_QUALIFIED) reduce 153) ((T_NAME_QUALIFIED) reduce 153) ((T_NAME_RELATIVE) reduce 153) ((T_NEW) reduce 153) ((T_NS_C) reduce 153) ((T_OBJECT_CAST) reduce 153) ((T_PRINT) reduce 153) ((T_READONLY) reduce 153) ((T_REQUIRE) reduce 153) ((T_REQUIRE_ONCE) reduce 153) ((T_RETURN) reduce 153) ((T_START_HEREDOC) reduce 153) ((T_STATIC) reduce 153) ((T_STRING) reduce 153) ((T_STRING_CAST) reduce 153) ((T_SWITCH) reduce 153) ((T_THROW) reduce 153) ((T_TRAIT) reduce 153) ((T_TRAIT_C) reduce 153) ((T_TRY) reduce 153) ((T_UNSET) reduce 153) ((T_UNSET_CAST) reduce 153) ((T_VARIABLE) reduce 153) ((T_WHILE) reduce 153) ((T_YIELD) reduce 153) ((T_YIELD_FROM) reduce 153) (("[") reduce 153) (("`") reduce 153) (("{") reduce 153) (("~") reduce 153)) 21741 ((("!") reduce 187) (("\"") reduce 187) (("$") reduce 187) (("(") reduce 187) (("+") reduce 187) (("-") reduce 187) ((";") reduce 187) (("@") reduce 187) ((T_ABSTRACT) reduce 187) ((T_ARRAY) reduce 187) ((T_ARRAY_CAST) reduce 187) ((T_ATTRIBUTE) reduce 187) ((T_BOOL_CAST) reduce 187) ((T_BREAK) reduce 187) ((T_CASE) reduce 187) ((T_CLASS) reduce 187) ((T_CLASS_C) reduce 187) ((T_CLONE) reduce 187) ((T_CONSTANT_ENCAPSED_STRING) reduce 187) ((T_CONTINUE) reduce 187) ((T_DEC) reduce 187) ((T_DECLARE) reduce 187) ((T_DEFAULT) reduce 187) ((T_DIR) reduce 187) ((T_DNUMBER) reduce 187) ((T_DO) reduce 187) ((T_DOUBLE_CAST) reduce 187) ((T_ECHO) reduce 187) ((T_EMPTY) reduce 187) ((T_ENDSWITCH) reduce 187) ((T_ENUM) reduce 187) ((T_EVAL) reduce 187) ((T_EXIT) reduce 187) ((T_FILE) reduce 187) ((T_FINAL) reduce 187) ((T_FN) reduce 187) ((T_FOR) reduce 187) ((T_FOREACH) reduce 187) ((T_FUNCTION) reduce 187) ((T_FUNC_C) reduce 187) ((T_GLOBAL) reduce 187) ((T_GOTO) reduce 187) ((T_HALT_COMPILER) reduce 187) ((T_IF) reduce 187) ((T_INC) reduce 187) ((T_INCLUDE) reduce 187) ((T_INCLUDE_ONCE) reduce 187) ((T_INLINE_HTML) reduce 187) ((T_INTERFACE) reduce 187) ((T_INT_CAST) reduce 187) ((T_ISSET) reduce 187) ((T_LINE) reduce 187) ((T_LIST) reduce 187) ((T_LNUMBER) reduce 187) ((T_MATCH) reduce 187) ((T_METHOD_C) reduce 187) ((T_NAME_FULLY_QUALIFIED) reduce 187) ((T_NAME_QUALIFIED) reduce 187) ((T_NAME_RELATIVE) reduce 187) ((T_NEW) reduce 187) ((T_NS_C) reduce 187) ((T_OBJECT_CAST) reduce 187) ((T_PRINT) reduce 187) ((T_READONLY) reduce 187) ((T_REQUIRE) reduce 187) ((T_REQUIRE_ONCE) reduce 187) ((T_RETURN) reduce 187) ((T_START_HEREDOC) reduce 187) ((T_STATIC) reduce 187) ((T_STRING) reduce 187) ((T_STRING_CAST) reduce 187) ((T_SWITCH) reduce 187) ((T_THROW) reduce 187) ((T_TRAIT) reduce 187) ((T_TRAIT_C) reduce 187) ((T_TRY) reduce 187) ((T_UNSET) reduce 187) ((T_UNSET_CAST) reduce 187) ((T_VARIABLE) reduce 187) ((T_WHILE) reduce 187) ((T_YIELD) reduce 187) ((T_YIELD_FROM) reduce 187) (("[") reduce 187) (("`") reduce 187) (("{") reduce 187) (("~") reduce 187)) 21743 ((("!") reduce 152) (("\"") reduce 152) (("$") reduce 152) (("(") reduce 152) (("+") reduce 152) (("-") reduce 152) ((";") reduce 152) (("@") reduce 152) ((T_ABSTRACT) reduce 152) ((T_ARRAY) reduce 152) ((T_ARRAY_CAST) reduce 152) ((T_ATTRIBUTE) reduce 152) ((T_BOOL_CAST) reduce 152) ((T_BREAK) reduce 152) ((T_CASE) reduce 152) ((T_CLASS) reduce 152) ((T_CLASS_C) reduce 152) ((T_CLONE) reduce 152) ((T_CONSTANT_ENCAPSED_STRING) reduce 152) ((T_CONTINUE) reduce 152) ((T_DEC) reduce 152) ((T_DECLARE) reduce 152) ((T_DEFAULT) reduce 152) ((T_DIR) reduce 152) ((T_DNUMBER) reduce 152) ((T_DO) reduce 152) ((T_DOUBLE_CAST) reduce 152) ((T_ECHO) reduce 152) ((T_EMPTY) reduce 152) ((T_ENDSWITCH) reduce 152) ((T_ENUM) reduce 152) ((T_EVAL) reduce 152) ((T_EXIT) reduce 152) ((T_FILE) reduce 152) ((T_FINAL) reduce 152) ((T_FN) reduce 152) ((T_FOR) reduce 152) ((T_FOREACH) reduce 152) ((T_FUNCTION) reduce 152) ((T_FUNC_C) reduce 152) ((T_GLOBAL) reduce 152) ((T_GOTO) reduce 152) ((T_HALT_COMPILER) reduce 152) ((T_IF) reduce 152) ((T_INC) reduce 152) ((T_INCLUDE) reduce 152) ((T_INCLUDE_ONCE) reduce 152) ((T_INLINE_HTML) reduce 152) ((T_INTERFACE) reduce 152) ((T_INT_CAST) reduce 152) ((T_ISSET) reduce 152) ((T_LINE) reduce 152) ((T_LIST) reduce 152) ((T_LNUMBER) reduce 152) ((T_MATCH) reduce 152) ((T_METHOD_C) reduce 152) ((T_NAME_FULLY_QUALIFIED) reduce 152) ((T_NAME_QUALIFIED) reduce 152) ((T_NAME_RELATIVE) reduce 152) ((T_NEW) reduce 152) ((T_NS_C) reduce 152) ((T_OBJECT_CAST) reduce 152) ((T_PRINT) reduce 152) ((T_READONLY) reduce 152) ((T_REQUIRE) reduce 152) ((T_REQUIRE_ONCE) reduce 152) ((T_RETURN) reduce 152) ((T_START_HEREDOC) reduce 152) ((T_STATIC) reduce 152) ((T_STRING) reduce 152) ((T_STRING_CAST) reduce 152) ((T_SWITCH) reduce 152) ((T_THROW) reduce 152) ((T_TRAIT) reduce 152) ((T_TRAIT_C) reduce 152) ((T_TRY) reduce 152) ((T_UNSET) reduce 152) ((T_UNSET_CAST) reduce 152) ((T_VARIABLE) reduce 152) ((T_WHILE) reduce 152) ((T_YIELD) reduce 152) ((T_YIELD_FROM) reduce 152) (("[") reduce 152) (("`") reduce 152) (("{") reduce 152) (("~") reduce 152)) 21754 ((("%") reduce 502) (("*") reduce 502) (("+") reduce 502) (("-") reduce 502) ((".") reduce 502) (("/") reduce 502) ((":") reduce 502) ((";") reduce 502) (("<") reduce 502) ((">") reduce 502) (("?") reduce 502) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_BOOLEAN_AND) reduce 502) ((T_BOOLEAN_OR) reduce 502) ((T_COALESCE) reduce 502) ((T_INSTANCEOF) reduce 502) ((T_IS_EQUAL) reduce 502) ((T_IS_GREATER_OR_EQUAL) reduce 502) ((T_IS_IDENTICAL) reduce 502) ((T_IS_NOT_EQUAL) reduce 502) ((T_IS_NOT_IDENTICAL) reduce 502) ((T_IS_SMALLER_OR_EQUAL) reduce 502) ((T_LOGICAL_AND) reduce 502) ((T_LOGICAL_OR) reduce 502) ((T_LOGICAL_XOR) reduce 502) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 502) ((T_OBJECT_OPERATOR) reduce 502) ((T_POW) reduce 502) ((T_SL) reduce 502) ((T_SPACESHIP) reduce 502) ((T_SR) reduce 502) (("[") reduce 502) (("^") reduce 502) (("{") reduce 502) (("|") reduce 502)) 21756 ((("%") reduce 484) (("(") reduce 484) (("*") reduce 484) (("+") reduce 484) (("-") reduce 484) ((".") reduce 484) (("/") reduce 484) ((":") reduce 484) ((";") reduce 484) (("<") reduce 484) ((">") reduce 484) (("?") reduce 484) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_BOOLEAN_AND) reduce 484) ((T_BOOLEAN_OR) reduce 484) ((T_COALESCE) reduce 484) ((T_INSTANCEOF) reduce 484) ((T_IS_EQUAL) reduce 484) ((T_IS_GREATER_OR_EQUAL) reduce 484) ((T_IS_IDENTICAL) reduce 484) ((T_IS_NOT_EQUAL) reduce 484) ((T_IS_NOT_IDENTICAL) reduce 484) ((T_IS_SMALLER_OR_EQUAL) reduce 484) ((T_LOGICAL_AND) reduce 484) ((T_LOGICAL_OR) reduce 484) ((T_LOGICAL_XOR) reduce 484) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 484) ((T_OBJECT_OPERATOR) reduce 484) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 484) ((T_POW) reduce 484) ((T_SL) reduce 484) ((T_SPACESHIP) reduce 484) ((T_SR) reduce 484) (("[") reduce 484) (("^") reduce 484) (("{") reduce 484) (("|") reduce 484)) 21758 ((("%") reduce 497) (("*") reduce 497) (("+") reduce 497) (("-") reduce 497) ((".") reduce 497) (("/") reduce 497) ((":") reduce 497) ((";") reduce 497) (("<") reduce 497) ((">") reduce 497) (("?") reduce 497) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_BOOLEAN_AND) reduce 497) ((T_BOOLEAN_OR) reduce 497) ((T_COALESCE) reduce 497) ((T_INSTANCEOF) reduce 497) ((T_IS_EQUAL) reduce 497) ((T_IS_GREATER_OR_EQUAL) reduce 497) ((T_IS_IDENTICAL) reduce 497) ((T_IS_NOT_EQUAL) reduce 497) ((T_IS_NOT_IDENTICAL) reduce 497) ((T_IS_SMALLER_OR_EQUAL) reduce 497) ((T_LOGICAL_AND) reduce 497) ((T_LOGICAL_OR) reduce 497) ((T_LOGICAL_XOR) reduce 497) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 497) ((T_OBJECT_OPERATOR) reduce 497) ((T_POW) reduce 497) ((T_SL) reduce 497) ((T_SPACESHIP) reduce 497) ((T_SR) reduce 497) (("[") reduce 497) (("^") reduce 497) (("{") reduce 497) (("|") reduce 497)) 21759 ((("%") reduce 487) (("*") reduce 487) (("+") reduce 487) (("-") reduce 487) ((".") reduce 487) (("/") reduce 487) ((":") reduce 487) ((";") reduce 487) (("<") reduce 487) ((">") reduce 487) (("?") reduce 487) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_BOOLEAN_AND) reduce 487) ((T_BOOLEAN_OR) reduce 487) ((T_COALESCE) reduce 487) ((T_INSTANCEOF) reduce 487) ((T_IS_EQUAL) reduce 487) ((T_IS_GREATER_OR_EQUAL) reduce 487) ((T_IS_IDENTICAL) reduce 487) ((T_IS_NOT_EQUAL) reduce 487) ((T_IS_NOT_IDENTICAL) reduce 487) ((T_IS_SMALLER_OR_EQUAL) reduce 487) ((T_LOGICAL_AND) reduce 487) ((T_LOGICAL_OR) reduce 487) ((T_LOGICAL_XOR) reduce 487) ((T_POW) reduce 487) ((T_SL) reduce 487) ((T_SPACESHIP) reduce 487) ((T_SR) reduce 487) (("^") reduce 487) (("|") reduce 487)) 21763 ((("%") reduce 475) (("(") shift) (("*") reduce 475) (("+") reduce 475) (("-") reduce 475) ((".") reduce 475) (("/") reduce 475) ((":") reduce 475) ((";") reduce 475) (("<") reduce 475) ((">") reduce 475) (("?") reduce 475) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_BOOLEAN_AND) reduce 475) ((T_BOOLEAN_OR) reduce 475) ((T_COALESCE) reduce 475) ((T_INSTANCEOF) reduce 475) ((T_IS_EQUAL) reduce 475) ((T_IS_GREATER_OR_EQUAL) reduce 475) ((T_IS_IDENTICAL) reduce 475) ((T_IS_NOT_EQUAL) reduce 475) ((T_IS_NOT_IDENTICAL) reduce 475) ((T_IS_SMALLER_OR_EQUAL) reduce 475) ((T_LOGICAL_AND) reduce 475) ((T_LOGICAL_OR) reduce 475) ((T_LOGICAL_XOR) reduce 475) ((T_POW) reduce 475) ((T_SL) reduce 475) ((T_SPACESHIP) reduce 475) ((T_SR) reduce 475) (("^") reduce 475) (("|") reduce 475)) 21764 ((("%") reduce 496) (("*") reduce 496) (("+") reduce 496) (("-") reduce 496) ((".") reduce 496) (("/") reduce 496) ((":") reduce 496) ((";") reduce 496) (("<") reduce 496) ((">") reduce 496) (("?") reduce 496) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_BOOLEAN_AND) reduce 496) ((T_BOOLEAN_OR) reduce 496) ((T_COALESCE) reduce 496) ((T_INSTANCEOF) reduce 496) ((T_IS_EQUAL) reduce 496) ((T_IS_GREATER_OR_EQUAL) reduce 496) ((T_IS_IDENTICAL) reduce 496) ((T_IS_NOT_EQUAL) reduce 496) ((T_IS_NOT_IDENTICAL) reduce 496) ((T_IS_SMALLER_OR_EQUAL) reduce 496) ((T_LOGICAL_AND) reduce 496) ((T_LOGICAL_OR) reduce 496) ((T_LOGICAL_XOR) reduce 496) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 496) ((T_OBJECT_OPERATOR) reduce 496) ((T_POW) reduce 496) ((T_SL) reduce 496) ((T_SPACESHIP) reduce 496) ((T_SR) reduce 496) (("[") reduce 496) (("^") reduce 496) (("{") reduce 496) (("|") reduce 496)) 21765 ((("%") reduce 500) (("*") reduce 500) (("+") reduce 500) (("-") reduce 500) ((".") reduce 500) (("/") reduce 500) ((":") reduce 500) ((";") reduce 500) (("<") reduce 500) ((">") reduce 500) (("?") reduce 500) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_BOOLEAN_AND) reduce 500) ((T_BOOLEAN_OR) reduce 500) ((T_COALESCE) reduce 500) ((T_INSTANCEOF) reduce 500) ((T_IS_EQUAL) reduce 500) ((T_IS_GREATER_OR_EQUAL) reduce 500) ((T_IS_IDENTICAL) reduce 500) ((T_IS_NOT_EQUAL) reduce 500) ((T_IS_NOT_IDENTICAL) reduce 500) ((T_IS_SMALLER_OR_EQUAL) reduce 500) ((T_LOGICAL_AND) reduce 500) ((T_LOGICAL_OR) reduce 500) ((T_LOGICAL_XOR) reduce 500) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 500) ((T_OBJECT_OPERATOR) reduce 500) ((T_POW) reduce 500) ((T_SL) reduce 500) ((T_SPACESHIP) reduce 500) ((T_SR) reduce 500) (("[") reduce 500) (("^") reduce 500) (("{") reduce 500) (("|") reduce 500)) 21771 ((("%") reduce 495) (("*") reduce 495) (("+") reduce 495) (("-") reduce 495) ((".") reduce 495) (("/") reduce 495) ((":") reduce 495) ((";") reduce 495) (("<") reduce 495) ((">") reduce 495) (("?") reduce 495) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_BOOLEAN_AND) reduce 495) ((T_BOOLEAN_OR) reduce 495) ((T_COALESCE) reduce 495) ((T_INSTANCEOF) reduce 495) ((T_IS_EQUAL) reduce 495) ((T_IS_GREATER_OR_EQUAL) reduce 495) ((T_IS_IDENTICAL) reduce 495) ((T_IS_NOT_EQUAL) reduce 495) ((T_IS_NOT_IDENTICAL) reduce 495) ((T_IS_SMALLER_OR_EQUAL) reduce 495) ((T_LOGICAL_AND) reduce 495) ((T_LOGICAL_OR) reduce 495) ((T_LOGICAL_XOR) reduce 495) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 495) ((T_OBJECT_OPERATOR) reduce 495) ((T_POW) reduce 495) ((T_SL) reduce 495) ((T_SPACESHIP) reduce 495) ((T_SR) reduce 495) (("[") reduce 495) (("^") reduce 495) (("{") reduce 495) (("|") reduce 495)) 21773 ((("%") reduce 486) (("*") reduce 486) (("+") reduce 486) (("-") reduce 486) ((".") reduce 486) (("/") reduce 486) ((":") reduce 486) ((";") reduce 486) (("<") reduce 486) ((">") reduce 486) (("?") reduce 486) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_BOOLEAN_AND) reduce 486) ((T_BOOLEAN_OR) reduce 486) ((T_COALESCE) reduce 486) ((T_INSTANCEOF) reduce 486) ((T_IS_EQUAL) reduce 486) ((T_IS_GREATER_OR_EQUAL) reduce 486) ((T_IS_IDENTICAL) reduce 486) ((T_IS_NOT_EQUAL) reduce 486) ((T_IS_NOT_IDENTICAL) reduce 486) ((T_IS_SMALLER_OR_EQUAL) reduce 486) ((T_LOGICAL_AND) reduce 486) ((T_LOGICAL_OR) reduce 486) ((T_LOGICAL_XOR) reduce 486) ((T_POW) reduce 486) ((T_SL) reduce 486) ((T_SPACESHIP) reduce 486) ((T_SR) reduce 486) (("^") reduce 486) (("|") reduce 486)) 21775 ((("%") reduce 499) (("*") reduce 499) (("+") reduce 499) (("-") reduce 499) ((".") reduce 499) (("/") reduce 499) ((":") reduce 499) ((";") reduce 499) (("<") reduce 499) ((">") reduce 499) (("?") reduce 499) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_BOOLEAN_AND) reduce 499) ((T_BOOLEAN_OR) reduce 499) ((T_COALESCE) reduce 499) ((T_INSTANCEOF) reduce 499) ((T_IS_EQUAL) reduce 499) ((T_IS_GREATER_OR_EQUAL) reduce 499) ((T_IS_IDENTICAL) reduce 499) ((T_IS_NOT_EQUAL) reduce 499) ((T_IS_NOT_IDENTICAL) reduce 499) ((T_IS_SMALLER_OR_EQUAL) reduce 499) ((T_LOGICAL_AND) reduce 499) ((T_LOGICAL_OR) reduce 499) ((T_LOGICAL_XOR) reduce 499) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 499) ((T_OBJECT_OPERATOR) reduce 499) ((T_POW) reduce 499) ((T_SL) reduce 499) ((T_SPACESHIP) reduce 499) ((T_SR) reduce 499) (("[") reduce 499) (("^") reduce 499) (("{") reduce 499) (("|") reduce 499)) 21776 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) ((":") reduce 93) ((";") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 93) ((T_OBJECT_OPERATOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("[") reduce 93) (("^") reduce 93) (("{") reduce 93) (("|") reduce 93)) 21777 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) ((":") reduce 92) ((";") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 92) ((T_OBJECT_OPERATOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("[") reduce 92) (("^") reduce 92) (("{") reduce 92) (("|") reduce 92)) 21778 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) ((":") reduce 94) ((";") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 94) ((T_OBJECT_OPERATOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("[") reduce 94) (("^") reduce 94) (("{") reduce 94) (("|") reduce 94)) 21780 ((("%") reduce 501) (("*") reduce 501) (("+") reduce 501) (("-") reduce 501) ((".") reduce 501) (("/") reduce 501) ((":") reduce 501) ((";") reduce 501) (("<") reduce 501) ((">") reduce 501) (("?") reduce 501) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_BOOLEAN_AND) reduce 501) ((T_BOOLEAN_OR) reduce 501) ((T_COALESCE) reduce 501) ((T_INSTANCEOF) reduce 501) ((T_IS_EQUAL) reduce 501) ((T_IS_GREATER_OR_EQUAL) reduce 501) ((T_IS_IDENTICAL) reduce 501) ((T_IS_NOT_EQUAL) reduce 501) ((T_IS_NOT_IDENTICAL) reduce 501) ((T_IS_SMALLER_OR_EQUAL) reduce 501) ((T_LOGICAL_AND) reduce 501) ((T_LOGICAL_OR) reduce 501) ((T_LOGICAL_XOR) reduce 501) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 501) ((T_OBJECT_OPERATOR) reduce 501) ((T_POW) reduce 501) ((T_SL) reduce 501) ((T_SPACESHIP) reduce 501) ((T_SR) reduce 501) (("[") reduce 501) (("^") reduce 501) (("{") reduce 501) (("|") reduce 501)) 21788 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) ((":") reduce 91) ((";") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 91) ((T_OBJECT_OPERATOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("[") reduce 91) (("^") reduce 91) (("{") reduce 91) (("|") reduce 91)) 21791 ((("%") reduce 498) (("*") reduce 498) (("+") reduce 498) (("-") reduce 498) ((".") reduce 498) (("/") reduce 498) ((":") reduce 498) ((";") reduce 498) (("<") reduce 498) ((">") reduce 498) (("?") reduce 498) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_BOOLEAN_AND) reduce 498) ((T_BOOLEAN_OR) reduce 498) ((T_COALESCE) reduce 498) ((T_INSTANCEOF) reduce 498) ((T_IS_EQUAL) reduce 498) ((T_IS_GREATER_OR_EQUAL) reduce 498) ((T_IS_IDENTICAL) reduce 498) ((T_IS_NOT_EQUAL) reduce 498) ((T_IS_NOT_IDENTICAL) reduce 498) ((T_IS_SMALLER_OR_EQUAL) reduce 498) ((T_LOGICAL_AND) reduce 498) ((T_LOGICAL_OR) reduce 498) ((T_LOGICAL_XOR) reduce 498) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 498) ((T_OBJECT_OPERATOR) reduce 498) ((T_POW) reduce 498) ((T_SL) reduce 498) ((T_SPACESHIP) reduce 498) ((T_SR) reduce 498) (("[") reduce 498) (("^") reduce 498) (("{") reduce 498) (("|") reduce 498)) 21793 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) ((":") reduce 529) ((";") reduce 529) (("<") reduce 529) (("=") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AND_EQUAL) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_COALESCE_EQUAL) reduce 529) ((T_CONCAT_EQUAL) reduce 529) ((T_DEC) reduce 529) ((T_DIV_EQUAL) reduce 529) ((T_INC) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_MINUS_EQUAL) reduce 529) ((T_MOD_EQUAL) reduce 529) ((T_MUL_EQUAL) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_OR_EQUAL) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_PLUS_EQUAL) reduce 529) ((T_POW) reduce 529) ((T_POW_EQUAL) reduce 529) ((T_SL) reduce 529) ((T_SL_EQUAL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) ((T_SR_EQUAL) reduce 529) ((T_XOR_EQUAL) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 21794 ((("!") shift) (("\"") shift) (("$") shift) (("%") reduce 440) (("(") shift) (("*") reduce 440) (("+") shift) (("-") shift) ((".") reduce 440) (("/") reduce 440) ((":") reduce 440) ((";") reduce 440) (("<") reduce 440) ((">") reduce 440) (("?") reduce 440) (("@") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOLEAN_AND) reduce 440) ((T_BOOLEAN_OR) reduce 440) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_COALESCE) reduce 440) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INSTANCEOF) reduce 440) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_IS_EQUAL) reduce 440) ((T_IS_GREATER_OR_EQUAL) reduce 440) ((T_IS_IDENTICAL) reduce 440) ((T_IS_NOT_EQUAL) reduce 440) ((T_IS_NOT_IDENTICAL) reduce 440) ((T_IS_SMALLER_OR_EQUAL) reduce 440) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_LOGICAL_AND) reduce 440) ((T_LOGICAL_OR) reduce 440) ((T_LOGICAL_XOR) reduce 440) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_POW) reduce 440) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_SL) reduce 440) ((T_SPACESHIP) reduce 440) ((T_SR) reduce 440) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("^") reduce 440) (("`") shift) (("|") reduce 440) (("~") shift)) 21801 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) ((":") reduce 525) ((";") reduce 525) (("<") reduce 525) (("=") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AND_EQUAL) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_COALESCE_EQUAL) reduce 525) ((T_CONCAT_EQUAL) reduce 525) ((T_DEC) reduce 525) ((T_DIV_EQUAL) reduce 525) ((T_INC) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_MINUS_EQUAL) reduce 525) ((T_MOD_EQUAL) reduce 525) ((T_MUL_EQUAL) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_OR_EQUAL) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_PLUS_EQUAL) reduce 525) ((T_POW) reduce 525) ((T_POW_EQUAL) reduce 525) ((T_SL) reduce 525) ((T_SL_EQUAL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) ((T_SR_EQUAL) reduce 525) ((T_XOR_EQUAL) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 21802 ((("%") reduce 493) (("*") reduce 493) (("+") reduce 493) (("-") reduce 493) ((".") reduce 493) (("/") reduce 493) ((":") reduce 493) ((";") reduce 493) (("<") reduce 493) ((">") reduce 493) (("?") reduce 493) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_BOOLEAN_AND) reduce 493) ((T_BOOLEAN_OR) reduce 493) ((T_COALESCE) reduce 493) ((T_INSTANCEOF) reduce 493) ((T_IS_EQUAL) reduce 493) ((T_IS_GREATER_OR_EQUAL) reduce 493) ((T_IS_IDENTICAL) reduce 493) ((T_IS_NOT_EQUAL) reduce 493) ((T_IS_NOT_IDENTICAL) reduce 493) ((T_IS_SMALLER_OR_EQUAL) reduce 493) ((T_LOGICAL_AND) reduce 493) ((T_LOGICAL_OR) reduce 493) ((T_LOGICAL_XOR) reduce 493) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 513) ((T_OBJECT_OPERATOR) reduce 513) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 513) ((T_POW) reduce 493) ((T_SL) reduce 493) ((T_SPACESHIP) reduce 493) ((T_SR) reduce 493) (("[") reduce 513) (("^") reduce 493) (("{") reduce 513) (("|") reduce 493)) 21804 ((("%") reduce 492) (("*") reduce 492) (("+") reduce 492) (("-") reduce 492) ((".") reduce 492) (("/") reduce 492) ((":") reduce 492) ((";") reduce 492) (("<") reduce 492) ((">") reduce 492) (("?") reduce 492) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_BOOLEAN_AND) reduce 492) ((T_BOOLEAN_OR) reduce 492) ((T_COALESCE) reduce 492) ((T_INSTANCEOF) reduce 492) ((T_IS_EQUAL) reduce 492) ((T_IS_GREATER_OR_EQUAL) reduce 492) ((T_IS_IDENTICAL) reduce 492) ((T_IS_NOT_EQUAL) reduce 492) ((T_IS_NOT_IDENTICAL) reduce 492) ((T_IS_SMALLER_OR_EQUAL) reduce 492) ((T_LOGICAL_AND) reduce 492) ((T_LOGICAL_OR) reduce 492) ((T_LOGICAL_XOR) reduce 492) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 515) ((T_OBJECT_OPERATOR) reduce 515) ((T_POW) reduce 492) ((T_SL) reduce 492) ((T_SPACESHIP) reduce 492) ((T_SR) reduce 492) (("[") reduce 515) (("^") reduce 492) (("{") reduce 515) (("|") reduce 492)) 21805 ((("%") reduce 491) (("(") reduce 518) (("*") reduce 491) (("+") reduce 491) (("-") reduce 491) ((".") reduce 491) (("/") reduce 491) ((":") reduce 491) ((";") reduce 491) (("<") reduce 491) ((">") reduce 491) (("?") reduce 491) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_BOOLEAN_AND) reduce 491) ((T_BOOLEAN_OR) reduce 491) ((T_COALESCE) reduce 491) ((T_INSTANCEOF) reduce 491) ((T_IS_EQUAL) reduce 491) ((T_IS_GREATER_OR_EQUAL) reduce 491) ((T_IS_IDENTICAL) reduce 491) ((T_IS_NOT_EQUAL) reduce 491) ((T_IS_NOT_IDENTICAL) reduce 491) ((T_IS_SMALLER_OR_EQUAL) reduce 491) ((T_LOGICAL_AND) reduce 491) ((T_LOGICAL_OR) reduce 491) ((T_LOGICAL_XOR) reduce 491) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 512) ((T_OBJECT_OPERATOR) reduce 512) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 512) ((T_POW) reduce 491) ((T_SL) reduce 491) ((T_SPACESHIP) reduce 491) ((T_SR) reduce 491) (("[") reduce 512) (("^") reduce 491) (("{") reduce 512) (("|") reduce 491)) 21806 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") shift) ((";") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 21809 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) ((":") reduce 524) ((";") reduce 524) (("<") reduce 524) (("=") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AND_EQUAL) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_COALESCE_EQUAL) reduce 524) ((T_CONCAT_EQUAL) reduce 524) ((T_DEC) reduce 524) ((T_DIV_EQUAL) reduce 524) ((T_INC) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_MINUS_EQUAL) reduce 524) ((T_MOD_EQUAL) reduce 524) ((T_MUL_EQUAL) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_OR_EQUAL) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_PLUS_EQUAL) reduce 524) ((T_POW) reduce 524) ((T_POW_EQUAL) reduce 524) ((T_SL) reduce 524) ((T_SL_EQUAL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) ((T_SR_EQUAL) reduce 524) ((T_XOR_EQUAL) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 21810 ((("%") reduce 445) (("*") reduce 445) (("+") reduce 445) (("-") reduce 445) ((".") reduce 445) (("/") reduce 445) ((":") reduce 445) ((";") reduce 445) (("<") reduce 445) ((">") reduce 445) (("?") reduce 445) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_BOOLEAN_AND) reduce 445) ((T_BOOLEAN_OR) reduce 445) ((T_COALESCE) reduce 445) ((T_INSTANCEOF) reduce 445) ((T_IS_EQUAL) reduce 445) ((T_IS_GREATER_OR_EQUAL) reduce 445) ((T_IS_IDENTICAL) reduce 445) ((T_IS_NOT_EQUAL) reduce 445) ((T_IS_NOT_IDENTICAL) reduce 445) ((T_IS_SMALLER_OR_EQUAL) reduce 445) ((T_LOGICAL_AND) reduce 445) ((T_LOGICAL_OR) reduce 445) ((T_LOGICAL_XOR) reduce 445) ((T_POW) reduce 445) ((T_SL) reduce 445) ((T_SPACESHIP) reduce 445) ((T_SR) reduce 445) (("^") reduce 445) (("|") reduce 445)) 21811 ((("%") reduce 427) (("*") reduce 427) (("+") reduce 427) (("-") reduce 427) ((".") reduce 427) (("/") reduce 427) ((":") reduce 427) ((";") reduce 427) (("<") reduce 427) ((">") reduce 427) (("?") reduce 427) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_BOOLEAN_AND) reduce 427) ((T_BOOLEAN_OR) reduce 427) ((T_COALESCE) reduce 427) ((T_INSTANCEOF) reduce 427) ((T_IS_EQUAL) reduce 427) ((T_IS_GREATER_OR_EQUAL) reduce 427) ((T_IS_IDENTICAL) reduce 427) ((T_IS_NOT_EQUAL) reduce 427) ((T_IS_NOT_IDENTICAL) reduce 427) ((T_IS_SMALLER_OR_EQUAL) reduce 427) ((T_LOGICAL_AND) reduce 427) ((T_LOGICAL_OR) reduce 427) ((T_LOGICAL_XOR) reduce 427) ((T_POW) reduce 427) ((T_SL) reduce 427) ((T_SPACESHIP) reduce 427) ((T_SR) reduce 427) (("^") reduce 427) (("|") reduce 427)) 21812 ((("%") reduce 449) (("*") reduce 449) (("+") reduce 449) (("-") reduce 449) ((".") reduce 449) (("/") reduce 449) ((":") reduce 449) ((";") reduce 449) (("<") reduce 449) ((">") reduce 449) (("?") reduce 449) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_BOOLEAN_AND) reduce 449) ((T_BOOLEAN_OR) reduce 449) ((T_COALESCE) reduce 449) ((T_INSTANCEOF) reduce 449) ((T_IS_EQUAL) reduce 449) ((T_IS_GREATER_OR_EQUAL) reduce 449) ((T_IS_IDENTICAL) reduce 449) ((T_IS_NOT_EQUAL) reduce 449) ((T_IS_NOT_IDENTICAL) reduce 449) ((T_IS_SMALLER_OR_EQUAL) reduce 449) ((T_LOGICAL_AND) reduce 449) ((T_LOGICAL_OR) reduce 449) ((T_LOGICAL_XOR) reduce 449) ((T_POW) reduce 449) ((T_SL) reduce 449) ((T_SPACESHIP) reduce 449) ((T_SR) reduce 449) (("^") reduce 449) (("|") reduce 449)) 21813 ((("%") reduce 494) (("(") shift) (("*") reduce 494) (("+") reduce 494) (("-") reduce 494) ((".") reduce 494) (("/") reduce 494) ((":") reduce 494) ((";") reduce 494) (("<") reduce 494) ((">") reduce 494) (("?") reduce 494) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_BOOLEAN_AND) reduce 494) ((T_BOOLEAN_OR) reduce 494) ((T_COALESCE) reduce 494) ((T_INSTANCEOF) reduce 494) ((T_IS_EQUAL) reduce 494) ((T_IS_GREATER_OR_EQUAL) reduce 494) ((T_IS_IDENTICAL) reduce 494) ((T_IS_NOT_EQUAL) reduce 494) ((T_IS_NOT_IDENTICAL) reduce 494) ((T_IS_SMALLER_OR_EQUAL) reduce 494) ((T_LOGICAL_AND) reduce 494) ((T_LOGICAL_OR) reduce 494) ((T_LOGICAL_XOR) reduce 494) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 494) ((T_OBJECT_OPERATOR) reduce 494) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 494) ((T_SL) reduce 494) ((T_SPACESHIP) reduce 494) ((T_SR) reduce 494) (("[") reduce 494) (("^") reduce 494) (("{") reduce 494) (("|") reduce 494)) 21814 ((("%") reduce 423) (("*") reduce 423) (("+") reduce 423) (("-") reduce 423) ((".") reduce 423) (("/") reduce 423) ((":") reduce 423) ((";") reduce 423) (("<") reduce 423) ((">") reduce 423) (("?") reduce 423) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_BOOLEAN_AND) reduce 423) ((T_BOOLEAN_OR) reduce 423) ((T_COALESCE) reduce 423) ((T_INSTANCEOF) reduce 423) ((T_IS_EQUAL) reduce 423) ((T_IS_GREATER_OR_EQUAL) reduce 423) ((T_IS_IDENTICAL) reduce 423) ((T_IS_NOT_EQUAL) reduce 423) ((T_IS_NOT_IDENTICAL) reduce 423) ((T_IS_SMALLER_OR_EQUAL) reduce 423) ((T_LOGICAL_AND) reduce 423) ((T_LOGICAL_OR) reduce 423) ((T_LOGICAL_XOR) reduce 423) ((T_POW) reduce 423) ((T_SL) reduce 423) ((T_SPACESHIP) reduce 423) ((T_SR) reduce 423) (("^") reduce 423) (("|") reduce 423)) 21815 ((("%") reduce 437) (("*") reduce 437) (("+") reduce 437) (("-") reduce 437) ((".") reduce 437) (("/") reduce 437) ((":") reduce 437) ((";") reduce 437) (("<") reduce 437) ((">") reduce 437) (("?") reduce 437) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_BOOLEAN_AND) reduce 437) ((T_BOOLEAN_OR) reduce 437) ((T_COALESCE) reduce 437) ((T_INSTANCEOF) reduce 437) ((T_IS_EQUAL) reduce 437) ((T_IS_GREATER_OR_EQUAL) reduce 437) ((T_IS_IDENTICAL) reduce 437) ((T_IS_NOT_EQUAL) reduce 437) ((T_IS_NOT_IDENTICAL) reduce 437) ((T_IS_SMALLER_OR_EQUAL) reduce 437) ((T_LOGICAL_AND) reduce 437) ((T_LOGICAL_OR) reduce 437) ((T_LOGICAL_XOR) reduce 437) ((T_POW) reduce 437) ((T_SL) reduce 437) ((T_SPACESHIP) reduce 437) ((T_SR) reduce 437) (("^") reduce 437) (("|") reduce 437)) 21816 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) ((":") reduce 519) ((";") reduce 519) (("<") reduce 519) (("=") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AND_EQUAL) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_COALESCE_EQUAL) reduce 519) ((T_CONCAT_EQUAL) reduce 519) ((T_DEC) reduce 519) ((T_DIV_EQUAL) reduce 519) ((T_INC) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_MINUS_EQUAL) reduce 519) ((T_MOD_EQUAL) reduce 519) ((T_MUL_EQUAL) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_OR_EQUAL) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_PLUS_EQUAL) reduce 519) ((T_POW) reduce 519) ((T_POW_EQUAL) reduce 519) ((T_SL) reduce 519) ((T_SL_EQUAL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) ((T_SR_EQUAL) reduce 519) ((T_XOR_EQUAL) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 21817 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) ((":") reduce 526) ((";") reduce 526) (("<") reduce 526) (("=") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AND_EQUAL) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_COALESCE_EQUAL) reduce 526) ((T_CONCAT_EQUAL) reduce 526) ((T_DEC) reduce 526) ((T_DIV_EQUAL) reduce 526) ((T_INC) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_MINUS_EQUAL) reduce 526) ((T_MOD_EQUAL) reduce 526) ((T_MUL_EQUAL) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_OR_EQUAL) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_PLUS_EQUAL) reduce 526) ((T_POW) reduce 526) ((T_POW_EQUAL) reduce 526) ((T_SL) reduce 526) ((T_SL_EQUAL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) ((T_SR_EQUAL) reduce 526) ((T_XOR_EQUAL) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 21818 ((("%") reduce 367) (("*") reduce 367) (("+") reduce 367) (("-") reduce 367) ((".") reduce 367) (("/") reduce 367) ((":") reduce 367) ((";") reduce 367) (("<") reduce 367) (("=") shift) ((">") reduce 367) (("?") reduce 367) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AND_EQUAL) shift) ((T_BOOLEAN_AND) reduce 367) ((T_BOOLEAN_OR) reduce 367) ((T_COALESCE) reduce 367) ((T_COALESCE_EQUAL) shift) ((T_CONCAT_EQUAL) shift) ((T_DEC) shift) ((T_DIV_EQUAL) shift) ((T_INC) shift) ((T_INSTANCEOF) reduce 367) ((T_IS_EQUAL) reduce 367) ((T_IS_GREATER_OR_EQUAL) reduce 367) ((T_IS_IDENTICAL) reduce 367) ((T_IS_NOT_EQUAL) reduce 367) ((T_IS_NOT_IDENTICAL) reduce 367) ((T_IS_SMALLER_OR_EQUAL) reduce 367) ((T_LOGICAL_AND) reduce 367) ((T_LOGICAL_OR) reduce 367) ((T_LOGICAL_XOR) reduce 367) ((T_MINUS_EQUAL) shift) ((T_MOD_EQUAL) shift) ((T_MUL_EQUAL) shift) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_OR_EQUAL) shift) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_PLUS_EQUAL) shift) ((T_POW) reduce 367) ((T_POW_EQUAL) shift) ((T_SL) reduce 367) ((T_SL_EQUAL) shift) ((T_SPACESHIP) reduce 367) ((T_SR) reduce 367) ((T_SR_EQUAL) shift) ((T_XOR_EQUAL) shift) (("[") reduce 510) (("^") reduce 367) (("{") reduce 510) (("|") reduce 367)) 21821 ((("%") reduce 411) (("*") reduce 411) (("+") reduce 411) (("-") reduce 411) ((".") reduce 411) (("/") reduce 411) ((":") reduce 411) ((";") reduce 411) (("<") reduce 411) ((">") reduce 411) (("?") reduce 411) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_BOOLEAN_AND) reduce 411) ((T_BOOLEAN_OR) reduce 411) ((T_COALESCE) reduce 411) ((T_INSTANCEOF) reduce 411) ((T_IS_EQUAL) reduce 411) ((T_IS_GREATER_OR_EQUAL) reduce 411) ((T_IS_IDENTICAL) reduce 411) ((T_IS_NOT_EQUAL) reduce 411) ((T_IS_NOT_IDENTICAL) reduce 411) ((T_IS_SMALLER_OR_EQUAL) reduce 411) ((T_LOGICAL_AND) reduce 411) ((T_LOGICAL_OR) reduce 411) ((T_LOGICAL_XOR) reduce 411) ((T_POW) shift) ((T_SL) reduce 411) ((T_SPACESHIP) reduce 411) ((T_SR) reduce 411) (("^") reduce 411) (("|") reduce 411)) 21852 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 395) ((";") reduce 395) (("<") shift) ((">") shift) (("?") reduce 395) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 395) ((T_BOOLEAN_OR) reduce 395) ((T_COALESCE) reduce 395) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 395) ((T_LOGICAL_OR) reduce 395) ((T_LOGICAL_XOR) reduce 395) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") reduce 395)) 21853 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 398) ((";") reduce 398) (("<") shift) ((">") shift) (("?") reduce 398) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 398) ((T_BOOLEAN_OR) reduce 398) ((T_COALESCE) reduce 398) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 398) ((T_LOGICAL_OR) reduce 398) ((T_LOGICAL_XOR) reduce 398) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 398) (("|") reduce 398)) 21854 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 407) (("/") shift) ((":") reduce 407) ((";") reduce 407) (("<") reduce 407) ((">") reduce 407) (("?") reduce 407) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_BOOLEAN_AND) reduce 407) ((T_BOOLEAN_OR) reduce 407) ((T_COALESCE) reduce 407) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 407) ((T_IS_GREATER_OR_EQUAL) reduce 407) ((T_IS_IDENTICAL) reduce 407) ((T_IS_NOT_EQUAL) reduce 407) ((T_IS_NOT_IDENTICAL) reduce 407) ((T_IS_SMALLER_OR_EQUAL) reduce 407) ((T_LOGICAL_AND) reduce 407) ((T_LOGICAL_OR) reduce 407) ((T_LOGICAL_XOR) reduce 407) ((T_POW) shift) ((T_SL) reduce 407) ((T_SPACESHIP) reduce 407) ((T_SR) reduce 407) (("^") reduce 407) (("|") reduce 407)) 21855 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 420) ((";") reduce 420) (("<") shift) ((">") shift) (("?") reduce 420) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_BOOLEAN_AND) reduce 420) ((T_BOOLEAN_OR) reduce 420) ((T_COALESCE) reduce 420) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 420) ((T_LOGICAL_OR) reduce 420) ((T_LOGICAL_XOR) reduce 420) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 420) (("|") reduce 420)) 21856 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 406) (("/") shift) ((":") reduce 406) ((";") reduce 406) (("<") reduce 406) ((">") reduce 406) (("?") reduce 406) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_BOOLEAN_AND) reduce 406) ((T_BOOLEAN_OR) reduce 406) ((T_COALESCE) reduce 406) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 406) ((T_IS_GREATER_OR_EQUAL) reduce 406) ((T_IS_IDENTICAL) reduce 406) ((T_IS_NOT_EQUAL) reduce 406) ((T_IS_NOT_IDENTICAL) reduce 406) ((T_IS_SMALLER_OR_EQUAL) reduce 406) ((T_LOGICAL_AND) reduce 406) ((T_LOGICAL_OR) reduce 406) ((T_LOGICAL_XOR) reduce 406) ((T_POW) shift) ((T_SL) reduce 406) ((T_SPACESHIP) reduce 406) ((T_SR) reduce 406) (("^") reduce 406) (("|") reduce 406)) 21857 ((("%") reduce 403) (("*") reduce 403) (("+") reduce 403) (("-") reduce 403) ((".") reduce 403) (("/") reduce 403) ((":") reduce 403) ((";") reduce 403) (("<") reduce 403) ((">") reduce 403) (("?") reduce 403) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_BOOLEAN_AND) reduce 403) ((T_BOOLEAN_OR) reduce 403) ((T_COALESCE) reduce 403) ((T_INSTANCEOF) reduce 403) ((T_IS_EQUAL) reduce 403) ((T_IS_GREATER_OR_EQUAL) reduce 403) ((T_IS_IDENTICAL) reduce 403) ((T_IS_NOT_EQUAL) reduce 403) ((T_IS_NOT_IDENTICAL) reduce 403) ((T_IS_SMALLER_OR_EQUAL) reduce 403) ((T_LOGICAL_AND) reduce 403) ((T_LOGICAL_OR) reduce 403) ((T_LOGICAL_XOR) reduce 403) ((T_POW) shift) ((T_SL) reduce 403) ((T_SPACESHIP) reduce 403) ((T_SR) reduce 403) (("^") reduce 403) (("|") reduce 403)) 21858 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 394) ((";") reduce 394) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 394) ((T_LOGICAL_XOR) reduce 394) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 21859 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 392) ((";") reduce 392) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 392) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 21860 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 393) ((";") reduce 393) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 393) ((T_LOGICAL_OR) reduce 393) ((T_LOGICAL_XOR) reduce 393) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 21861 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 417) ((";") reduce 417) (("<") shift) ((">") shift) (("?") reduce 417) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_BOOLEAN_AND) reduce 417) ((T_BOOLEAN_OR) reduce 417) ((T_COALESCE) reduce 417) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 417) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 417) ((T_IS_NOT_EQUAL) reduce 417) ((T_IS_NOT_IDENTICAL) reduce 417) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 417) ((T_LOGICAL_OR) reduce 417) ((T_LOGICAL_XOR) reduce 417) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 417) ((T_SR) shift) (("^") reduce 417) (("|") reduce 417)) 21862 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 413) ((";") reduce 413) (("<") shift) ((">") shift) (("?") reduce 413) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_BOOLEAN_AND) reduce 413) ((T_BOOLEAN_OR) reduce 413) ((T_COALESCE) reduce 413) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 413) ((T_LOGICAL_OR) reduce 413) ((T_LOGICAL_XOR) reduce 413) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 413) (("|") reduce 413)) 21863 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 415) ((";") reduce 415) (("<") shift) ((">") shift) (("?") reduce 415) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_BOOLEAN_AND) reduce 415) ((T_BOOLEAN_OR) reduce 415) ((T_COALESCE) reduce 415) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 415) ((T_LOGICAL_OR) reduce 415) ((T_LOGICAL_XOR) reduce 415) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 415) (("|") reduce 415)) 21864 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 412) ((";") reduce 412) (("<") shift) ((">") shift) (("?") reduce 412) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_BOOLEAN_AND) reduce 412) ((T_BOOLEAN_OR) reduce 412) ((T_COALESCE) reduce 412) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 412) ((T_LOGICAL_OR) reduce 412) ((T_LOGICAL_XOR) reduce 412) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 412) (("|") reduce 412)) 21865 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 419) ((";") reduce 419) (("<") shift) ((">") shift) (("?") reduce 419) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_BOOLEAN_AND) reduce 419) ((T_BOOLEAN_OR) reduce 419) ((T_COALESCE) reduce 419) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 419) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 419) ((T_IS_NOT_EQUAL) reduce 419) ((T_IS_NOT_IDENTICAL) reduce 419) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 419) ((T_LOGICAL_OR) reduce 419) ((T_LOGICAL_XOR) reduce 419) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 419) ((T_SR) shift) (("^") reduce 419) (("|") reduce 419)) 21866 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 414) ((";") reduce 414) (("<") shift) ((">") shift) (("?") reduce 414) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_BOOLEAN_AND) reduce 414) ((T_BOOLEAN_OR) reduce 414) ((T_COALESCE) reduce 414) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 414) ((T_LOGICAL_OR) reduce 414) ((T_LOGICAL_XOR) reduce 414) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 414) (("|") reduce 414)) 21869 ((("%") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) ((":") reduce 93) ((";") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93)) 21870 ((("%") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) ((":") reduce 92) ((";") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92)) 21871 ((("%") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) ((":") reduce 94) ((";") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94)) 21872 ((("%") reduce 470) (("*") reduce 470) (("+") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) ((":") reduce 470) ((";") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470)) 21873 ((("%") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) ((":") reduce 91) ((";") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91)) 21874 ((("%") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) ((":") reduce 529) ((";") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 21875 ((("%") reduce 472) (("*") reduce 472) (("+") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) ((":") reduce 472) ((";") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472)) 21876 ((("%") reduce 421) (("*") reduce 421) (("+") reduce 421) (("-") reduce 421) ((".") reduce 421) (("/") reduce 421) ((":") reduce 421) ((";") reduce 421) (("<") reduce 421) ((">") reduce 421) (("?") reduce 421) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_BOOLEAN_AND) reduce 421) ((T_BOOLEAN_OR) reduce 421) ((T_COALESCE) reduce 421) ((T_INSTANCEOF) reduce 421) ((T_IS_EQUAL) reduce 421) ((T_IS_GREATER_OR_EQUAL) reduce 421) ((T_IS_IDENTICAL) reduce 421) ((T_IS_NOT_EQUAL) reduce 421) ((T_IS_NOT_IDENTICAL) reduce 421) ((T_IS_SMALLER_OR_EQUAL) reduce 421) ((T_LOGICAL_AND) reduce 421) ((T_LOGICAL_OR) reduce 421) ((T_LOGICAL_XOR) reduce 421) ((T_POW) reduce 421) ((T_SL) reduce 421) ((T_SPACESHIP) reduce 421) ((T_SR) reduce 421) (("^") reduce 421) (("|") reduce 421)) 21877 ((("%") reduce 471) (("*") reduce 471) (("+") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) ((":") reduce 471) ((";") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471)) 21878 ((("%") reduce 473) (("*") reduce 473) (("+") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) ((":") reduce 473) ((";") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 21879 ((("%") reduce 534) (("*") reduce 534) (("+") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) ((":") reduce 534) ((";") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 21886 ((("%") reduce 536) (("*") reduce 536) (("+") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) ((":") reduce 536) ((";") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 21888 ((("%") reduce 535) (("*") reduce 535) (("+") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) ((":") reduce 535) ((";") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 21889 ((("%") reduce 540) (("*") reduce 540) (("+") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) ((":") reduce 540) ((";") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 21890 ((("%") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) ((":") reduce 544) ((";") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 21891 ((("%") reduce 537) (("*") reduce 537) (("+") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) ((":") reduce 537) ((";") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 21892 ((("%") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) ((":") reduce 546) ((";") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 21895 ((("%") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) ((":") reduce 545) ((";") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 21896 ((("%") reduce 538) (("*") reduce 538) (("+") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) ((":") reduce 538) ((";") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 21898 ((("%") reduce 539) (("*") reduce 539) (("+") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) ((":") reduce 539) ((";") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 21900 ((("%") reduce 474) (("*") reduce 474) (("+") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) ((":") reduce 474) ((";") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474)) 21901 ((("%") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) ((":") reduce 531) ((";") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 21904 ((("%") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) ((":") reduce 530) ((";") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 21905 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 426) ((";") reduce 426) (("<") shift) ((">") shift) (("?") reduce 426) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 426) ((T_LOGICAL_OR) reduce 426) ((T_LOGICAL_XOR) reduce 426) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 21906 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 390) ((";") reduce 390) (("<") shift) ((">") shift) (("?") reduce 390) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) reduce 390) ((T_COALESCE) reduce 390) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 390) ((T_LOGICAL_OR) reduce 390) ((T_LOGICAL_XOR) reduce 390) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 21907 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 391) ((";") reduce 391) (("<") shift) ((">") shift) (("?") reduce 391) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 391) ((T_BOOLEAN_OR) reduce 391) ((T_COALESCE) reduce 391) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 391) ((T_LOGICAL_OR) reduce 391) ((T_LOGICAL_XOR) reduce 391) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 21908 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 396) ((";") reduce 396) (("<") shift) ((">") shift) (("?") reduce 396) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_BOOLEAN_AND) reduce 396) ((T_BOOLEAN_OR) reduce 396) ((T_COALESCE) reduce 396) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 396) ((T_LOGICAL_OR) reduce 396) ((T_LOGICAL_XOR) reduce 396) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 396) (("|") reduce 396)) 21909 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 397) ((";") reduce 397) (("<") shift) ((">") shift) (("?") reduce 397) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_BOOLEAN_AND) reduce 397) ((T_BOOLEAN_OR) reduce 397) ((T_COALESCE) reduce 397) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 397) ((T_LOGICAL_OR) reduce 397) ((T_LOGICAL_XOR) reduce 397) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 397) (("|") reduce 397)) 21913 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 424) ((";") reduce 424) (("<") shift) ((">") shift) (("?") reduce 424) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 424) ((T_LOGICAL_OR) reduce 424) ((T_LOGICAL_XOR) reduce 424) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 21914 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 425) ((";") reduce 425) (("<") shift) ((">") shift) (("?") reduce 425) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 425) ((T_LOGICAL_OR) reduce 425) ((T_LOGICAL_XOR) reduce 425) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 21915 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 418) ((";") reduce 418) (("<") shift) ((">") shift) (("?") reduce 418) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_BOOLEAN_AND) reduce 418) ((T_BOOLEAN_OR) reduce 418) ((T_COALESCE) reduce 418) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 418) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 418) ((T_IS_NOT_EQUAL) reduce 418) ((T_IS_NOT_IDENTICAL) reduce 418) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 418) ((T_LOGICAL_OR) reduce 418) ((T_LOGICAL_XOR) reduce 418) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 418) ((T_SR) shift) (("^") reduce 418) (("|") reduce 418)) 21916 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 416) ((";") reduce 416) (("<") shift) ((">") shift) (("?") reduce 416) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_BOOLEAN_AND) reduce 416) ((T_BOOLEAN_OR) reduce 416) ((T_COALESCE) reduce 416) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 416) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 416) ((T_IS_NOT_EQUAL) reduce 416) ((T_IS_NOT_IDENTICAL) reduce 416) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 416) ((T_LOGICAL_OR) reduce 416) ((T_LOGICAL_XOR) reduce 416) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 416) ((T_SR) shift) (("^") reduce 416) (("|") reduce 416)) 21917 ((("%") reduce 404) (("*") reduce 404) (("+") reduce 404) (("-") reduce 404) ((".") reduce 404) (("/") reduce 404) ((":") reduce 404) ((";") reduce 404) (("<") reduce 404) ((">") reduce 404) (("?") reduce 404) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_BOOLEAN_AND) reduce 404) ((T_BOOLEAN_OR) reduce 404) ((T_COALESCE) reduce 404) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 404) ((T_IS_GREATER_OR_EQUAL) reduce 404) ((T_IS_IDENTICAL) reduce 404) ((T_IS_NOT_EQUAL) reduce 404) ((T_IS_NOT_IDENTICAL) reduce 404) ((T_IS_SMALLER_OR_EQUAL) reduce 404) ((T_LOGICAL_AND) reduce 404) ((T_LOGICAL_OR) reduce 404) ((T_LOGICAL_XOR) reduce 404) ((T_POW) shift) ((T_SL) reduce 404) ((T_SPACESHIP) reduce 404) ((T_SR) reduce 404) (("^") reduce 404) (("|") reduce 404)) 21918 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 399) (("/") shift) ((":") reduce 399) ((";") reduce 399) (("<") reduce 399) ((">") reduce 399) (("?") reduce 399) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_BOOLEAN_AND) reduce 399) ((T_BOOLEAN_OR) reduce 399) ((T_COALESCE) reduce 399) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 399) ((T_IS_GREATER_OR_EQUAL) reduce 399) ((T_IS_IDENTICAL) reduce 399) ((T_IS_NOT_EQUAL) reduce 399) ((T_IS_NOT_IDENTICAL) reduce 399) ((T_IS_SMALLER_OR_EQUAL) reduce 399) ((T_LOGICAL_AND) reduce 399) ((T_LOGICAL_OR) reduce 399) ((T_LOGICAL_XOR) reduce 399) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 399) ((T_SR) shift) (("^") reduce 399) (("|") reduce 399)) 21919 ((("%") shift) (("*") shift) (("+") reduce 401) (("-") reduce 401) ((".") reduce 401) (("/") shift) ((":") reduce 401) ((";") reduce 401) (("<") reduce 401) ((">") reduce 401) (("?") reduce 401) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_BOOLEAN_AND) reduce 401) ((T_BOOLEAN_OR) reduce 401) ((T_COALESCE) reduce 401) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 401) ((T_IS_GREATER_OR_EQUAL) reduce 401) ((T_IS_IDENTICAL) reduce 401) ((T_IS_NOT_EQUAL) reduce 401) ((T_IS_NOT_IDENTICAL) reduce 401) ((T_IS_SMALLER_OR_EQUAL) reduce 401) ((T_LOGICAL_AND) reduce 401) ((T_LOGICAL_OR) reduce 401) ((T_LOGICAL_XOR) reduce 401) ((T_POW) shift) ((T_SL) reduce 401) ((T_SPACESHIP) reduce 401) ((T_SR) reduce 401) (("^") reduce 401) (("|") reduce 401)) 21920 ((("%") shift) (("*") shift) (("+") reduce 400) (("-") reduce 400) ((".") reduce 400) (("/") shift) ((":") reduce 400) ((";") reduce 400) (("<") reduce 400) ((">") reduce 400) (("?") reduce 400) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_BOOLEAN_AND) reduce 400) ((T_BOOLEAN_OR) reduce 400) ((T_COALESCE) reduce 400) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 400) ((T_IS_GREATER_OR_EQUAL) reduce 400) ((T_IS_IDENTICAL) reduce 400) ((T_IS_NOT_EQUAL) reduce 400) ((T_IS_NOT_IDENTICAL) reduce 400) ((T_IS_SMALLER_OR_EQUAL) reduce 400) ((T_LOGICAL_AND) reduce 400) ((T_LOGICAL_OR) reduce 400) ((T_LOGICAL_XOR) reduce 400) ((T_POW) shift) ((T_SL) reduce 400) ((T_SPACESHIP) reduce 400) ((T_SR) reduce 400) (("^") reduce 400) (("|") reduce 400)) 21921 ((("%") reduce 402) (("*") reduce 402) (("+") reduce 402) (("-") reduce 402) ((".") reduce 402) (("/") reduce 402) ((":") reduce 402) ((";") reduce 402) (("<") reduce 402) ((">") reduce 402) (("?") reduce 402) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_BOOLEAN_AND) reduce 402) ((T_BOOLEAN_OR) reduce 402) ((T_COALESCE) reduce 402) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 402) ((T_IS_GREATER_OR_EQUAL) reduce 402) ((T_IS_IDENTICAL) reduce 402) ((T_IS_NOT_EQUAL) reduce 402) ((T_IS_NOT_IDENTICAL) reduce 402) ((T_IS_SMALLER_OR_EQUAL) reduce 402) ((T_LOGICAL_AND) reduce 402) ((T_LOGICAL_OR) reduce 402) ((T_LOGICAL_XOR) reduce 402) ((T_POW) shift) ((T_SL) reduce 402) ((T_SPACESHIP) reduce 402) ((T_SR) reduce 402) (("^") reduce 402) (("|") reduce 402)) 21922 ((("%") reduce 405) (("*") reduce 405) (("+") reduce 405) (("-") reduce 405) ((".") reduce 405) (("/") reduce 405) ((":") reduce 405) ((";") reduce 405) (("<") reduce 405) ((">") reduce 405) (("?") reduce 405) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_BOOLEAN_AND) reduce 405) ((T_BOOLEAN_OR) reduce 405) ((T_COALESCE) reduce 405) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 405) ((T_IS_GREATER_OR_EQUAL) reduce 405) ((T_IS_IDENTICAL) reduce 405) ((T_IS_NOT_EQUAL) reduce 405) ((T_IS_NOT_IDENTICAL) reduce 405) ((T_IS_SMALLER_OR_EQUAL) reduce 405) ((T_LOGICAL_AND) reduce 405) ((T_LOGICAL_OR) reduce 405) ((T_LOGICAL_XOR) reduce 405) ((T_POW) shift) ((T_SL) reduce 405) ((T_SPACESHIP) reduce 405) ((T_SR) reduce 405) (("^") reduce 405) (("|") reduce 405)) 21924 ((("%") reduce 73) (("(") reduce 73) (("*") reduce 73) (("+") reduce 73) (("-") reduce 73) ((".") reduce 73) (("/") reduce 73) ((":") reduce 73) ((";") reduce 73) (("<") reduce 73) ((">") reduce 73) (("?") reduce 73) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_BOOLEAN_AND) reduce 73) ((T_BOOLEAN_OR) reduce 73) ((T_COALESCE) reduce 73) ((T_INSTANCEOF) reduce 73) ((T_IS_EQUAL) reduce 73) ((T_IS_GREATER_OR_EQUAL) reduce 73) ((T_IS_IDENTICAL) reduce 73) ((T_IS_NOT_EQUAL) reduce 73) ((T_IS_NOT_IDENTICAL) reduce 73) ((T_IS_SMALLER_OR_EQUAL) reduce 73) ((T_LOGICAL_AND) reduce 73) ((T_LOGICAL_OR) reduce 73) ((T_LOGICAL_XOR) reduce 73) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 73) ((T_OBJECT_OPERATOR) reduce 73) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 73) ((T_POW) reduce 73) ((T_SL) reduce 73) ((T_SPACESHIP) reduce 73) ((T_SR) reduce 73) (("[") reduce 73) (("^") reduce 73) (("{") reduce 73) (("|") reduce 73)) 21925 ((("%") reduce 52) (("(") reduce 52) (("*") reduce 52) (("+") reduce 52) (("-") reduce 52) ((".") reduce 52) (("/") reduce 52) ((":") reduce 52) ((";") reduce 52) (("<") reduce 52) ((">") reduce 52) (("?") reduce 52) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_BOOLEAN_AND) reduce 52) ((T_BOOLEAN_OR) reduce 52) ((T_COALESCE) reduce 52) ((T_INSTANCEOF) reduce 52) ((T_IS_EQUAL) reduce 52) ((T_IS_GREATER_OR_EQUAL) reduce 52) ((T_IS_IDENTICAL) reduce 52) ((T_IS_NOT_EQUAL) reduce 52) ((T_IS_NOT_IDENTICAL) reduce 52) ((T_IS_SMALLER_OR_EQUAL) reduce 52) ((T_LOGICAL_AND) reduce 52) ((T_LOGICAL_OR) reduce 52) ((T_LOGICAL_XOR) reduce 52) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 52) ((T_OBJECT_OPERATOR) reduce 52) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 52) ((T_POW) reduce 52) ((T_SL) reduce 52) ((T_SPACESHIP) reduce 52) ((T_SR) reduce 52) (("[") reduce 52) (("^") reduce 52) (("{") reduce 52) (("|") reduce 52)) 21926 ((("%") reduce 27) (("(") reduce 27) (("*") reduce 27) (("+") reduce 27) (("-") reduce 27) ((".") reduce 27) (("/") reduce 27) ((":") reduce 27) ((";") reduce 27) (("<") reduce 27) ((">") reduce 27) (("?") reduce 27) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_BOOLEAN_AND) reduce 27) ((T_BOOLEAN_OR) reduce 27) ((T_COALESCE) reduce 27) ((T_INSTANCEOF) reduce 27) ((T_IS_EQUAL) reduce 27) ((T_IS_GREATER_OR_EQUAL) reduce 27) ((T_IS_IDENTICAL) reduce 27) ((T_IS_NOT_EQUAL) reduce 27) ((T_IS_NOT_IDENTICAL) reduce 27) ((T_IS_SMALLER_OR_EQUAL) reduce 27) ((T_LOGICAL_AND) reduce 27) ((T_LOGICAL_OR) reduce 27) ((T_LOGICAL_XOR) reduce 27) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 27) ((T_OBJECT_OPERATOR) reduce 27) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 27) ((T_POW) reduce 27) ((T_SL) reduce 27) ((T_SPACESHIP) reduce 27) ((T_SR) reduce 27) (("[") reduce 27) (("^") reduce 27) (("{") reduce 27) (("|") reduce 27)) 21927 ((("%") reduce 51) (("(") reduce 51) (("*") reduce 51) (("+") reduce 51) (("-") reduce 51) ((".") reduce 51) (("/") reduce 51) ((":") reduce 51) ((";") reduce 51) (("<") reduce 51) ((">") reduce 51) (("?") reduce 51) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_BOOLEAN_AND) reduce 51) ((T_BOOLEAN_OR) reduce 51) ((T_COALESCE) reduce 51) ((T_INSTANCEOF) reduce 51) ((T_IS_EQUAL) reduce 51) ((T_IS_GREATER_OR_EQUAL) reduce 51) ((T_IS_IDENTICAL) reduce 51) ((T_IS_NOT_EQUAL) reduce 51) ((T_IS_NOT_IDENTICAL) reduce 51) ((T_IS_SMALLER_OR_EQUAL) reduce 51) ((T_LOGICAL_AND) reduce 51) ((T_LOGICAL_OR) reduce 51) ((T_LOGICAL_XOR) reduce 51) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 51) ((T_OBJECT_OPERATOR) reduce 51) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 51) ((T_POW) reduce 51) ((T_SL) reduce 51) ((T_SPACESHIP) reduce 51) ((T_SR) reduce 51) (("[") reduce 51) (("^") reduce 51) (("{") reduce 51) (("|") reduce 51)) 21928 ((("%") reduce 53) (("(") reduce 53) (("*") reduce 53) (("+") reduce 53) (("-") reduce 53) ((".") reduce 53) (("/") reduce 53) ((":") reduce 53) ((";") reduce 53) (("<") reduce 53) ((">") reduce 53) (("?") reduce 53) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_BOOLEAN_AND) reduce 53) ((T_BOOLEAN_OR) reduce 53) ((T_COALESCE) reduce 53) ((T_INSTANCEOF) reduce 53) ((T_IS_EQUAL) reduce 53) ((T_IS_GREATER_OR_EQUAL) reduce 53) ((T_IS_IDENTICAL) reduce 53) ((T_IS_NOT_EQUAL) reduce 53) ((T_IS_NOT_IDENTICAL) reduce 53) ((T_IS_SMALLER_OR_EQUAL) reduce 53) ((T_LOGICAL_AND) reduce 53) ((T_LOGICAL_OR) reduce 53) ((T_LOGICAL_XOR) reduce 53) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 53) ((T_OBJECT_OPERATOR) reduce 53) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 53) ((T_POW) reduce 53) ((T_SL) reduce 53) ((T_SPACESHIP) reduce 53) ((T_SR) reduce 53) (("[") reduce 53) (("^") reduce 53) (("{") reduce 53) (("|") reduce 53)) 21929 ((("%") reduce 49) (("(") reduce 49) (("*") reduce 49) (("+") reduce 49) (("-") reduce 49) ((".") reduce 49) (("/") reduce 49) ((":") reduce 49) ((";") reduce 49) (("<") reduce 49) ((">") reduce 49) (("?") reduce 49) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_BOOLEAN_AND) reduce 49) ((T_BOOLEAN_OR) reduce 49) ((T_COALESCE) reduce 49) ((T_INSTANCEOF) reduce 49) ((T_IS_EQUAL) reduce 49) ((T_IS_GREATER_OR_EQUAL) reduce 49) ((T_IS_IDENTICAL) reduce 49) ((T_IS_NOT_EQUAL) reduce 49) ((T_IS_NOT_IDENTICAL) reduce 49) ((T_IS_SMALLER_OR_EQUAL) reduce 49) ((T_LOGICAL_AND) reduce 49) ((T_LOGICAL_OR) reduce 49) ((T_LOGICAL_XOR) reduce 49) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 49) ((T_OBJECT_OPERATOR) reduce 49) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 49) ((T_POW) reduce 49) ((T_SL) reduce 49) ((T_SPACESHIP) reduce 49) ((T_SR) reduce 49) (("[") reduce 49) (("^") reduce 49) (("{") reduce 49) (("|") reduce 49)) 21930 ((("%") reduce 29) (("(") reduce 29) (("*") reduce 29) (("+") reduce 29) (("-") reduce 29) ((".") reduce 29) (("/") reduce 29) ((":") reduce 29) ((";") reduce 29) (("<") reduce 29) ((">") reduce 29) (("?") reduce 29) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_BOOLEAN_AND) reduce 29) ((T_BOOLEAN_OR) reduce 29) ((T_COALESCE) reduce 29) ((T_INSTANCEOF) reduce 29) ((T_IS_EQUAL) reduce 29) ((T_IS_GREATER_OR_EQUAL) reduce 29) ((T_IS_IDENTICAL) reduce 29) ((T_IS_NOT_EQUAL) reduce 29) ((T_IS_NOT_IDENTICAL) reduce 29) ((T_IS_SMALLER_OR_EQUAL) reduce 29) ((T_LOGICAL_AND) reduce 29) ((T_LOGICAL_OR) reduce 29) ((T_LOGICAL_XOR) reduce 29) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 29) ((T_OBJECT_OPERATOR) reduce 29) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 29) ((T_POW) reduce 29) ((T_SL) reduce 29) ((T_SPACESHIP) reduce 29) ((T_SR) reduce 29) (("[") reduce 29) (("^") reduce 29) (("{") reduce 29) (("|") reduce 29)) 21931 ((("%") reduce 59) (("(") reduce 59) (("*") reduce 59) (("+") reduce 59) (("-") reduce 59) ((".") reduce 59) (("/") reduce 59) ((":") reduce 59) ((";") reduce 59) (("<") reduce 59) ((">") reduce 59) (("?") reduce 59) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_BOOLEAN_AND) reduce 59) ((T_BOOLEAN_OR) reduce 59) ((T_COALESCE) reduce 59) ((T_INSTANCEOF) reduce 59) ((T_IS_EQUAL) reduce 59) ((T_IS_GREATER_OR_EQUAL) reduce 59) ((T_IS_IDENTICAL) reduce 59) ((T_IS_NOT_EQUAL) reduce 59) ((T_IS_NOT_IDENTICAL) reduce 59) ((T_IS_SMALLER_OR_EQUAL) reduce 59) ((T_LOGICAL_AND) reduce 59) ((T_LOGICAL_OR) reduce 59) ((T_LOGICAL_XOR) reduce 59) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 59) ((T_OBJECT_OPERATOR) reduce 59) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 59) ((T_POW) reduce 59) ((T_SL) reduce 59) ((T_SPACESHIP) reduce 59) ((T_SR) reduce 59) (("[") reduce 59) (("^") reduce 59) (("{") reduce 59) (("|") reduce 59)) 21932 ((("%") reduce 60) (("(") reduce 60) (("*") reduce 60) (("+") reduce 60) (("-") reduce 60) ((".") reduce 60) (("/") reduce 60) ((":") reduce 60) ((";") reduce 60) (("<") reduce 60) ((">") reduce 60) (("?") reduce 60) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_BOOLEAN_AND) reduce 60) ((T_BOOLEAN_OR) reduce 60) ((T_COALESCE) reduce 60) ((T_INSTANCEOF) reduce 60) ((T_IS_EQUAL) reduce 60) ((T_IS_GREATER_OR_EQUAL) reduce 60) ((T_IS_IDENTICAL) reduce 60) ((T_IS_NOT_EQUAL) reduce 60) ((T_IS_NOT_IDENTICAL) reduce 60) ((T_IS_SMALLER_OR_EQUAL) reduce 60) ((T_LOGICAL_AND) reduce 60) ((T_LOGICAL_OR) reduce 60) ((T_LOGICAL_XOR) reduce 60) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 60) ((T_OBJECT_OPERATOR) reduce 60) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 60) ((T_POW) reduce 60) ((T_SL) reduce 60) ((T_SPACESHIP) reduce 60) ((T_SR) reduce 60) (("[") reduce 60) (("^") reduce 60) (("{") reduce 60) (("|") reduce 60)) 21933 ((("%") reduce 11) (("(") reduce 11) (("*") reduce 11) (("+") reduce 11) (("-") reduce 11) ((".") reduce 11) (("/") reduce 11) ((":") reduce 11) ((";") reduce 11) (("<") reduce 11) ((">") reduce 11) (("?") reduce 11) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_BOOLEAN_AND) reduce 11) ((T_BOOLEAN_OR) reduce 11) ((T_COALESCE) reduce 11) ((T_INSTANCEOF) reduce 11) ((T_IS_EQUAL) reduce 11) ((T_IS_GREATER_OR_EQUAL) reduce 11) ((T_IS_IDENTICAL) reduce 11) ((T_IS_NOT_EQUAL) reduce 11) ((T_IS_NOT_IDENTICAL) reduce 11) ((T_IS_SMALLER_OR_EQUAL) reduce 11) ((T_LOGICAL_AND) reduce 11) ((T_LOGICAL_OR) reduce 11) ((T_LOGICAL_XOR) reduce 11) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 11) ((T_OBJECT_OPERATOR) reduce 11) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 11) ((T_POW) reduce 11) ((T_SL) reduce 11) ((T_SPACESHIP) reduce 11) ((T_SR) reduce 11) (("[") reduce 11) (("^") reduce 11) (("{") reduce 11) (("|") reduce 11)) 21934 ((("%") reduce 42) (("(") reduce 42) (("*") reduce 42) (("+") reduce 42) (("-") reduce 42) ((".") reduce 42) (("/") reduce 42) ((":") reduce 42) ((";") reduce 42) (("<") reduce 42) ((">") reduce 42) (("?") reduce 42) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_BOOLEAN_AND) reduce 42) ((T_BOOLEAN_OR) reduce 42) ((T_COALESCE) reduce 42) ((T_INSTANCEOF) reduce 42) ((T_IS_EQUAL) reduce 42) ((T_IS_GREATER_OR_EQUAL) reduce 42) ((T_IS_IDENTICAL) reduce 42) ((T_IS_NOT_EQUAL) reduce 42) ((T_IS_NOT_IDENTICAL) reduce 42) ((T_IS_SMALLER_OR_EQUAL) reduce 42) ((T_LOGICAL_AND) reduce 42) ((T_LOGICAL_OR) reduce 42) ((T_LOGICAL_XOR) reduce 42) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 42) ((T_OBJECT_OPERATOR) reduce 42) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 42) ((T_POW) reduce 42) ((T_SL) reduce 42) ((T_SPACESHIP) reduce 42) ((T_SR) reduce 42) (("[") reduce 42) (("^") reduce 42) (("{") reduce 42) (("|") reduce 42)) 21935 ((("%") reduce 39) (("(") reduce 39) (("*") reduce 39) (("+") reduce 39) (("-") reduce 39) ((".") reduce 39) (("/") reduce 39) ((":") reduce 39) ((";") reduce 39) (("<") reduce 39) ((">") reduce 39) (("?") reduce 39) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_BOOLEAN_AND) reduce 39) ((T_BOOLEAN_OR) reduce 39) ((T_COALESCE) reduce 39) ((T_INSTANCEOF) reduce 39) ((T_IS_EQUAL) reduce 39) ((T_IS_GREATER_OR_EQUAL) reduce 39) ((T_IS_IDENTICAL) reduce 39) ((T_IS_NOT_EQUAL) reduce 39) ((T_IS_NOT_IDENTICAL) reduce 39) ((T_IS_SMALLER_OR_EQUAL) reduce 39) ((T_LOGICAL_AND) reduce 39) ((T_LOGICAL_OR) reduce 39) ((T_LOGICAL_XOR) reduce 39) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 39) ((T_OBJECT_OPERATOR) reduce 39) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 39) ((T_POW) reduce 39) ((T_SL) reduce 39) ((T_SPACESHIP) reduce 39) ((T_SR) reduce 39) (("[") reduce 39) (("^") reduce 39) (("{") reduce 39) (("|") reduce 39)) 21936 ((("%") reduce 25) (("(") reduce 25) (("*") reduce 25) (("+") reduce 25) (("-") reduce 25) ((".") reduce 25) (("/") reduce 25) ((":") reduce 25) ((";") reduce 25) (("<") reduce 25) ((">") reduce 25) (("?") reduce 25) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_BOOLEAN_AND) reduce 25) ((T_BOOLEAN_OR) reduce 25) ((T_COALESCE) reduce 25) ((T_INSTANCEOF) reduce 25) ((T_IS_EQUAL) reduce 25) ((T_IS_GREATER_OR_EQUAL) reduce 25) ((T_IS_IDENTICAL) reduce 25) ((T_IS_NOT_EQUAL) reduce 25) ((T_IS_NOT_IDENTICAL) reduce 25) ((T_IS_SMALLER_OR_EQUAL) reduce 25) ((T_LOGICAL_AND) reduce 25) ((T_LOGICAL_OR) reduce 25) ((T_LOGICAL_XOR) reduce 25) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 25) ((T_OBJECT_OPERATOR) reduce 25) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 25) ((T_POW) reduce 25) ((T_SL) reduce 25) ((T_SPACESHIP) reduce 25) ((T_SR) reduce 25) (("[") reduce 25) (("^") reduce 25) (("{") reduce 25) (("|") reduce 25)) 21937 ((("%") reduce 50) (("(") reduce 50) (("*") reduce 50) (("+") reduce 50) (("-") reduce 50) ((".") reduce 50) (("/") reduce 50) ((":") reduce 50) ((";") reduce 50) (("<") reduce 50) ((">") reduce 50) (("?") reduce 50) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_BOOLEAN_AND) reduce 50) ((T_BOOLEAN_OR) reduce 50) ((T_COALESCE) reduce 50) ((T_INSTANCEOF) reduce 50) ((T_IS_EQUAL) reduce 50) ((T_IS_GREATER_OR_EQUAL) reduce 50) ((T_IS_IDENTICAL) reduce 50) ((T_IS_NOT_EQUAL) reduce 50) ((T_IS_NOT_IDENTICAL) reduce 50) ((T_IS_SMALLER_OR_EQUAL) reduce 50) ((T_LOGICAL_AND) reduce 50) ((T_LOGICAL_OR) reduce 50) ((T_LOGICAL_XOR) reduce 50) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 50) ((T_OBJECT_OPERATOR) reduce 50) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 50) ((T_POW) reduce 50) ((T_SL) reduce 50) ((T_SPACESHIP) reduce 50) ((T_SR) reduce 50) (("[") reduce 50) (("^") reduce 50) (("{") reduce 50) (("|") reduce 50)) 21938 ((("%") reduce 66) (("(") reduce 66) (("*") reduce 66) (("+") reduce 66) (("-") reduce 66) ((".") reduce 66) (("/") reduce 66) ((":") reduce 66) ((";") reduce 66) (("<") reduce 66) ((">") reduce 66) (("?") reduce 66) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_BOOLEAN_AND) reduce 66) ((T_BOOLEAN_OR) reduce 66) ((T_COALESCE) reduce 66) ((T_INSTANCEOF) reduce 66) ((T_IS_EQUAL) reduce 66) ((T_IS_GREATER_OR_EQUAL) reduce 66) ((T_IS_IDENTICAL) reduce 66) ((T_IS_NOT_EQUAL) reduce 66) ((T_IS_NOT_IDENTICAL) reduce 66) ((T_IS_SMALLER_OR_EQUAL) reduce 66) ((T_LOGICAL_AND) reduce 66) ((T_LOGICAL_OR) reduce 66) ((T_LOGICAL_XOR) reduce 66) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 66) ((T_OBJECT_OPERATOR) reduce 66) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 66) ((T_POW) reduce 66) ((T_SL) reduce 66) ((T_SPACESHIP) reduce 66) ((T_SR) reduce 66) (("[") reduce 66) (("^") reduce 66) (("{") reduce 66) (("|") reduce 66)) 21939 ((("%") reduce 18) (("(") reduce 18) (("*") reduce 18) (("+") reduce 18) (("-") reduce 18) ((".") reduce 18) (("/") reduce 18) ((":") reduce 18) ((";") reduce 18) (("<") reduce 18) ((">") reduce 18) (("?") reduce 18) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_BOOLEAN_AND) reduce 18) ((T_BOOLEAN_OR) reduce 18) ((T_COALESCE) reduce 18) ((T_INSTANCEOF) reduce 18) ((T_IS_EQUAL) reduce 18) ((T_IS_GREATER_OR_EQUAL) reduce 18) ((T_IS_IDENTICAL) reduce 18) ((T_IS_NOT_EQUAL) reduce 18) ((T_IS_NOT_IDENTICAL) reduce 18) ((T_IS_SMALLER_OR_EQUAL) reduce 18) ((T_LOGICAL_AND) reduce 18) ((T_LOGICAL_OR) reduce 18) ((T_LOGICAL_XOR) reduce 18) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 18) ((T_OBJECT_OPERATOR) reduce 18) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 18) ((T_POW) reduce 18) ((T_SL) reduce 18) ((T_SPACESHIP) reduce 18) ((T_SR) reduce 18) (("[") reduce 18) (("^") reduce 18) (("{") reduce 18) (("|") reduce 18)) 21940 ((("%") reduce 17) (("(") reduce 17) (("*") reduce 17) (("+") reduce 17) (("-") reduce 17) ((".") reduce 17) (("/") reduce 17) ((":") reduce 17) ((";") reduce 17) (("<") reduce 17) ((">") reduce 17) (("?") reduce 17) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_BOOLEAN_AND) reduce 17) ((T_BOOLEAN_OR) reduce 17) ((T_COALESCE) reduce 17) ((T_INSTANCEOF) reduce 17) ((T_IS_EQUAL) reduce 17) ((T_IS_GREATER_OR_EQUAL) reduce 17) ((T_IS_IDENTICAL) reduce 17) ((T_IS_NOT_EQUAL) reduce 17) ((T_IS_NOT_IDENTICAL) reduce 17) ((T_IS_SMALLER_OR_EQUAL) reduce 17) ((T_LOGICAL_AND) reduce 17) ((T_LOGICAL_OR) reduce 17) ((T_LOGICAL_XOR) reduce 17) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 17) ((T_OBJECT_OPERATOR) reduce 17) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 17) ((T_POW) reduce 17) ((T_SL) reduce 17) ((T_SPACESHIP) reduce 17) ((T_SR) reduce 17) (("[") reduce 17) (("^") reduce 17) (("{") reduce 17) (("|") reduce 17)) 21941 ((("%") reduce 15) (("(") reduce 15) (("*") reduce 15) (("+") reduce 15) (("-") reduce 15) ((".") reduce 15) (("/") reduce 15) ((":") reduce 15) ((";") reduce 15) (("<") reduce 15) ((">") reduce 15) (("?") reduce 15) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_BOOLEAN_AND) reduce 15) ((T_BOOLEAN_OR) reduce 15) ((T_COALESCE) reduce 15) ((T_INSTANCEOF) reduce 15) ((T_IS_EQUAL) reduce 15) ((T_IS_GREATER_OR_EQUAL) reduce 15) ((T_IS_IDENTICAL) reduce 15) ((T_IS_NOT_EQUAL) reduce 15) ((T_IS_NOT_IDENTICAL) reduce 15) ((T_IS_SMALLER_OR_EQUAL) reduce 15) ((T_LOGICAL_AND) reduce 15) ((T_LOGICAL_OR) reduce 15) ((T_LOGICAL_XOR) reduce 15) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 15) ((T_OBJECT_OPERATOR) reduce 15) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 15) ((T_POW) reduce 15) ((T_SL) reduce 15) ((T_SPACESHIP) reduce 15) ((T_SR) reduce 15) (("[") reduce 15) (("^") reduce 15) (("{") reduce 15) (("|") reduce 15)) 21942 ((("%") reduce 14) (("(") reduce 14) (("*") reduce 14) (("+") reduce 14) (("-") reduce 14) ((".") reduce 14) (("/") reduce 14) ((":") reduce 14) ((";") reduce 14) (("<") reduce 14) ((">") reduce 14) (("?") reduce 14) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_BOOLEAN_AND) reduce 14) ((T_BOOLEAN_OR) reduce 14) ((T_COALESCE) reduce 14) ((T_INSTANCEOF) reduce 14) ((T_IS_EQUAL) reduce 14) ((T_IS_GREATER_OR_EQUAL) reduce 14) ((T_IS_IDENTICAL) reduce 14) ((T_IS_NOT_EQUAL) reduce 14) ((T_IS_NOT_IDENTICAL) reduce 14) ((T_IS_SMALLER_OR_EQUAL) reduce 14) ((T_LOGICAL_AND) reduce 14) ((T_LOGICAL_OR) reduce 14) ((T_LOGICAL_XOR) reduce 14) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 14) ((T_OBJECT_OPERATOR) reduce 14) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 14) ((T_POW) reduce 14) ((T_SL) reduce 14) ((T_SPACESHIP) reduce 14) ((T_SR) reduce 14) (("[") reduce 14) (("^") reduce 14) (("{") reduce 14) (("|") reduce 14)) 21943 ((("%") reduce 38) (("(") reduce 38) (("*") reduce 38) (("+") reduce 38) (("-") reduce 38) ((".") reduce 38) (("/") reduce 38) ((":") reduce 38) ((";") reduce 38) (("<") reduce 38) ((">") reduce 38) (("?") reduce 38) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_BOOLEAN_AND) reduce 38) ((T_BOOLEAN_OR) reduce 38) ((T_COALESCE) reduce 38) ((T_INSTANCEOF) reduce 38) ((T_IS_EQUAL) reduce 38) ((T_IS_GREATER_OR_EQUAL) reduce 38) ((T_IS_IDENTICAL) reduce 38) ((T_IS_NOT_EQUAL) reduce 38) ((T_IS_NOT_IDENTICAL) reduce 38) ((T_IS_SMALLER_OR_EQUAL) reduce 38) ((T_LOGICAL_AND) reduce 38) ((T_LOGICAL_OR) reduce 38) ((T_LOGICAL_XOR) reduce 38) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 38) ((T_OBJECT_OPERATOR) reduce 38) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 38) ((T_POW) reduce 38) ((T_SL) reduce 38) ((T_SPACESHIP) reduce 38) ((T_SR) reduce 38) (("[") reduce 38) (("^") reduce 38) (("{") reduce 38) (("|") reduce 38)) 21944 ((("%") reduce 26) (("(") reduce 26) (("*") reduce 26) (("+") reduce 26) (("-") reduce 26) ((".") reduce 26) (("/") reduce 26) ((":") reduce 26) ((";") reduce 26) (("<") reduce 26) ((">") reduce 26) (("?") reduce 26) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_BOOLEAN_AND) reduce 26) ((T_BOOLEAN_OR) reduce 26) ((T_COALESCE) reduce 26) ((T_INSTANCEOF) reduce 26) ((T_IS_EQUAL) reduce 26) ((T_IS_GREATER_OR_EQUAL) reduce 26) ((T_IS_IDENTICAL) reduce 26) ((T_IS_NOT_EQUAL) reduce 26) ((T_IS_NOT_IDENTICAL) reduce 26) ((T_IS_SMALLER_OR_EQUAL) reduce 26) ((T_LOGICAL_AND) reduce 26) ((T_LOGICAL_OR) reduce 26) ((T_LOGICAL_XOR) reduce 26) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 26) ((T_OBJECT_OPERATOR) reduce 26) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 26) ((T_POW) reduce 26) ((T_SL) reduce 26) ((T_SPACESHIP) reduce 26) ((T_SR) reduce 26) (("[") reduce 26) (("^") reduce 26) (("{") reduce 26) (("|") reduce 26)) 21945 ((("%") reduce 22) (("(") reduce 22) (("*") reduce 22) (("+") reduce 22) (("-") reduce 22) ((".") reduce 22) (("/") reduce 22) ((":") reduce 22) ((";") reduce 22) (("<") reduce 22) ((">") reduce 22) (("?") reduce 22) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_BOOLEAN_AND) reduce 22) ((T_BOOLEAN_OR) reduce 22) ((T_COALESCE) reduce 22) ((T_INSTANCEOF) reduce 22) ((T_IS_EQUAL) reduce 22) ((T_IS_GREATER_OR_EQUAL) reduce 22) ((T_IS_IDENTICAL) reduce 22) ((T_IS_NOT_EQUAL) reduce 22) ((T_IS_NOT_IDENTICAL) reduce 22) ((T_IS_SMALLER_OR_EQUAL) reduce 22) ((T_LOGICAL_AND) reduce 22) ((T_LOGICAL_OR) reduce 22) ((T_LOGICAL_XOR) reduce 22) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 22) ((T_OBJECT_OPERATOR) reduce 22) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 22) ((T_POW) reduce 22) ((T_SL) reduce 22) ((T_SPACESHIP) reduce 22) ((T_SR) reduce 22) (("[") reduce 22) (("^") reduce 22) (("{") reduce 22) (("|") reduce 22)) 21946 ((("%") reduce 24) (("(") reduce 24) (("*") reduce 24) (("+") reduce 24) (("-") reduce 24) ((".") reduce 24) (("/") reduce 24) ((":") reduce 24) ((";") reduce 24) (("<") reduce 24) ((">") reduce 24) (("?") reduce 24) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_BOOLEAN_AND) reduce 24) ((T_BOOLEAN_OR) reduce 24) ((T_COALESCE) reduce 24) ((T_INSTANCEOF) reduce 24) ((T_IS_EQUAL) reduce 24) ((T_IS_GREATER_OR_EQUAL) reduce 24) ((T_IS_IDENTICAL) reduce 24) ((T_IS_NOT_EQUAL) reduce 24) ((T_IS_NOT_IDENTICAL) reduce 24) ((T_IS_SMALLER_OR_EQUAL) reduce 24) ((T_LOGICAL_AND) reduce 24) ((T_LOGICAL_OR) reduce 24) ((T_LOGICAL_XOR) reduce 24) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 24) ((T_OBJECT_OPERATOR) reduce 24) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 24) ((T_POW) reduce 24) ((T_SL) reduce 24) ((T_SPACESHIP) reduce 24) ((T_SR) reduce 24) (("[") reduce 24) (("^") reduce 24) (("{") reduce 24) (("|") reduce 24)) 21947 ((("%") reduce 16) (("(") reduce 16) (("*") reduce 16) (("+") reduce 16) (("-") reduce 16) ((".") reduce 16) (("/") reduce 16) ((":") reduce 16) ((";") reduce 16) (("<") reduce 16) ((">") reduce 16) (("?") reduce 16) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_BOOLEAN_AND) reduce 16) ((T_BOOLEAN_OR) reduce 16) ((T_COALESCE) reduce 16) ((T_INSTANCEOF) reduce 16) ((T_IS_EQUAL) reduce 16) ((T_IS_GREATER_OR_EQUAL) reduce 16) ((T_IS_IDENTICAL) reduce 16) ((T_IS_NOT_EQUAL) reduce 16) ((T_IS_NOT_IDENTICAL) reduce 16) ((T_IS_SMALLER_OR_EQUAL) reduce 16) ((T_LOGICAL_AND) reduce 16) ((T_LOGICAL_OR) reduce 16) ((T_LOGICAL_XOR) reduce 16) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 16) ((T_OBJECT_OPERATOR) reduce 16) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 16) ((T_POW) reduce 16) ((T_SL) reduce 16) ((T_SPACESHIP) reduce 16) ((T_SR) reduce 16) (("[") reduce 16) (("^") reduce 16) (("{") reduce 16) (("|") reduce 16)) 21948 ((("%") reduce 48) (("(") reduce 48) (("*") reduce 48) (("+") reduce 48) (("-") reduce 48) ((".") reduce 48) (("/") reduce 48) ((":") reduce 48) ((";") reduce 48) (("<") reduce 48) ((">") reduce 48) (("?") reduce 48) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_BOOLEAN_AND) reduce 48) ((T_BOOLEAN_OR) reduce 48) ((T_COALESCE) reduce 48) ((T_INSTANCEOF) reduce 48) ((T_IS_EQUAL) reduce 48) ((T_IS_GREATER_OR_EQUAL) reduce 48) ((T_IS_IDENTICAL) reduce 48) ((T_IS_NOT_EQUAL) reduce 48) ((T_IS_NOT_IDENTICAL) reduce 48) ((T_IS_SMALLER_OR_EQUAL) reduce 48) ((T_LOGICAL_AND) reduce 48) ((T_LOGICAL_OR) reduce 48) ((T_LOGICAL_XOR) reduce 48) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 48) ((T_OBJECT_OPERATOR) reduce 48) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 48) ((T_POW) reduce 48) ((T_SL) reduce 48) ((T_SPACESHIP) reduce 48) ((T_SR) reduce 48) (("[") reduce 48) (("^") reduce 48) (("{") reduce 48) (("|") reduce 48)) 21949 ((("%") reduce 20) (("(") reduce 20) (("*") reduce 20) (("+") reduce 20) (("-") reduce 20) ((".") reduce 20) (("/") reduce 20) ((":") reduce 20) ((";") reduce 20) (("<") reduce 20) ((">") reduce 20) (("?") reduce 20) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_BOOLEAN_AND) reduce 20) ((T_BOOLEAN_OR) reduce 20) ((T_COALESCE) reduce 20) ((T_INSTANCEOF) reduce 20) ((T_IS_EQUAL) reduce 20) ((T_IS_GREATER_OR_EQUAL) reduce 20) ((T_IS_IDENTICAL) reduce 20) ((T_IS_NOT_EQUAL) reduce 20) ((T_IS_NOT_IDENTICAL) reduce 20) ((T_IS_SMALLER_OR_EQUAL) reduce 20) ((T_LOGICAL_AND) reduce 20) ((T_LOGICAL_OR) reduce 20) ((T_LOGICAL_XOR) reduce 20) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 20) ((T_OBJECT_OPERATOR) reduce 20) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 20) ((T_POW) reduce 20) ((T_SL) reduce 20) ((T_SPACESHIP) reduce 20) ((T_SR) reduce 20) (("[") reduce 20) (("^") reduce 20) (("{") reduce 20) (("|") reduce 20)) 21950 ((("%") reduce 70) (("(") reduce 70) (("*") reduce 70) (("+") reduce 70) (("-") reduce 70) ((".") reduce 70) (("/") reduce 70) ((":") reduce 70) ((";") reduce 70) (("<") reduce 70) ((">") reduce 70) (("?") reduce 70) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_BOOLEAN_AND) reduce 70) ((T_BOOLEAN_OR) reduce 70) ((T_COALESCE) reduce 70) ((T_INSTANCEOF) reduce 70) ((T_IS_EQUAL) reduce 70) ((T_IS_GREATER_OR_EQUAL) reduce 70) ((T_IS_IDENTICAL) reduce 70) ((T_IS_NOT_EQUAL) reduce 70) ((T_IS_NOT_IDENTICAL) reduce 70) ((T_IS_SMALLER_OR_EQUAL) reduce 70) ((T_LOGICAL_AND) reduce 70) ((T_LOGICAL_OR) reduce 70) ((T_LOGICAL_XOR) reduce 70) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 70) ((T_OBJECT_OPERATOR) reduce 70) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 70) ((T_POW) reduce 70) ((T_SL) reduce 70) ((T_SPACESHIP) reduce 70) ((T_SR) reduce 70) (("[") reduce 70) (("^") reduce 70) (("{") reduce 70) (("|") reduce 70)) 21951 ((("%") reduce 3) (("(") reduce 3) (("*") reduce 3) (("+") reduce 3) (("-") reduce 3) ((".") reduce 3) (("/") reduce 3) ((":") reduce 3) ((";") reduce 3) (("<") reduce 3) ((">") reduce 3) (("?") reduce 3) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_BOOLEAN_AND) reduce 3) ((T_BOOLEAN_OR) reduce 3) ((T_COALESCE) reduce 3) ((T_INSTANCEOF) reduce 3) ((T_IS_EQUAL) reduce 3) ((T_IS_GREATER_OR_EQUAL) reduce 3) ((T_IS_IDENTICAL) reduce 3) ((T_IS_NOT_EQUAL) reduce 3) ((T_IS_NOT_IDENTICAL) reduce 3) ((T_IS_SMALLER_OR_EQUAL) reduce 3) ((T_LOGICAL_AND) reduce 3) ((T_LOGICAL_OR) reduce 3) ((T_LOGICAL_XOR) reduce 3) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 3) ((T_OBJECT_OPERATOR) reduce 3) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 3) ((T_POW) reduce 3) ((T_SL) reduce 3) ((T_SPACESHIP) reduce 3) ((T_SR) reduce 3) (("[") reduce 3) (("^") reduce 3) (("{") reduce 3) (("|") reduce 3)) 21952 ((("%") reduce 12) (("(") reduce 12) (("*") reduce 12) (("+") reduce 12) (("-") reduce 12) ((".") reduce 12) (("/") reduce 12) ((":") reduce 12) ((";") reduce 12) (("<") reduce 12) ((">") reduce 12) (("?") reduce 12) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_BOOLEAN_AND) reduce 12) ((T_BOOLEAN_OR) reduce 12) ((T_COALESCE) reduce 12) ((T_INSTANCEOF) reduce 12) ((T_IS_EQUAL) reduce 12) ((T_IS_GREATER_OR_EQUAL) reduce 12) ((T_IS_IDENTICAL) reduce 12) ((T_IS_NOT_EQUAL) reduce 12) ((T_IS_NOT_IDENTICAL) reduce 12) ((T_IS_SMALLER_OR_EQUAL) reduce 12) ((T_LOGICAL_AND) reduce 12) ((T_LOGICAL_OR) reduce 12) ((T_LOGICAL_XOR) reduce 12) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 12) ((T_OBJECT_OPERATOR) reduce 12) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 12) ((T_POW) reduce 12) ((T_SL) reduce 12) ((T_SPACESHIP) reduce 12) ((T_SR) reduce 12) (("[") reduce 12) (("^") reduce 12) (("{") reduce 12) (("|") reduce 12)) 21953 ((("%") reduce 54) (("(") reduce 54) (("*") reduce 54) (("+") reduce 54) (("-") reduce 54) ((".") reduce 54) (("/") reduce 54) ((":") reduce 54) ((";") reduce 54) (("<") reduce 54) ((">") reduce 54) (("?") reduce 54) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_BOOLEAN_AND) reduce 54) ((T_BOOLEAN_OR) reduce 54) ((T_COALESCE) reduce 54) ((T_INSTANCEOF) reduce 54) ((T_IS_EQUAL) reduce 54) ((T_IS_GREATER_OR_EQUAL) reduce 54) ((T_IS_IDENTICAL) reduce 54) ((T_IS_NOT_EQUAL) reduce 54) ((T_IS_NOT_IDENTICAL) reduce 54) ((T_IS_SMALLER_OR_EQUAL) reduce 54) ((T_LOGICAL_AND) reduce 54) ((T_LOGICAL_OR) reduce 54) ((T_LOGICAL_XOR) reduce 54) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 54) ((T_OBJECT_OPERATOR) reduce 54) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 54) ((T_POW) reduce 54) ((T_SL) reduce 54) ((T_SPACESHIP) reduce 54) ((T_SR) reduce 54) (("[") reduce 54) (("^") reduce 54) (("{") reduce 54) (("|") reduce 54)) 21954 ((("%") reduce 65) (("(") reduce 65) (("*") reduce 65) (("+") reduce 65) (("-") reduce 65) ((".") reduce 65) (("/") reduce 65) ((":") reduce 65) ((";") reduce 65) (("<") reduce 65) ((">") reduce 65) (("?") reduce 65) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_BOOLEAN_AND) reduce 65) ((T_BOOLEAN_OR) reduce 65) ((T_COALESCE) reduce 65) ((T_INSTANCEOF) reduce 65) ((T_IS_EQUAL) reduce 65) ((T_IS_GREATER_OR_EQUAL) reduce 65) ((T_IS_IDENTICAL) reduce 65) ((T_IS_NOT_EQUAL) reduce 65) ((T_IS_NOT_IDENTICAL) reduce 65) ((T_IS_SMALLER_OR_EQUAL) reduce 65) ((T_LOGICAL_AND) reduce 65) ((T_LOGICAL_OR) reduce 65) ((T_LOGICAL_XOR) reduce 65) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 65) ((T_OBJECT_OPERATOR) reduce 65) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 65) ((T_POW) reduce 65) ((T_SL) reduce 65) ((T_SPACESHIP) reduce 65) ((T_SR) reduce 65) (("[") reduce 65) (("^") reduce 65) (("{") reduce 65) (("|") reduce 65)) 21955 ((("%") reduce 74) (("(") reduce 74) (("*") reduce 74) (("+") reduce 74) (("-") reduce 74) ((".") reduce 74) (("/") reduce 74) ((":") reduce 74) ((";") reduce 74) (("<") reduce 74) ((">") reduce 74) (("?") reduce 74) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_BOOLEAN_AND) reduce 74) ((T_BOOLEAN_OR) reduce 74) ((T_COALESCE) reduce 74) ((T_INSTANCEOF) reduce 74) ((T_IS_EQUAL) reduce 74) ((T_IS_GREATER_OR_EQUAL) reduce 74) ((T_IS_IDENTICAL) reduce 74) ((T_IS_NOT_EQUAL) reduce 74) ((T_IS_NOT_IDENTICAL) reduce 74) ((T_IS_SMALLER_OR_EQUAL) reduce 74) ((T_LOGICAL_AND) reduce 74) ((T_LOGICAL_OR) reduce 74) ((T_LOGICAL_XOR) reduce 74) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 74) ((T_OBJECT_OPERATOR) reduce 74) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 74) ((T_POW) reduce 74) ((T_SL) reduce 74) ((T_SPACESHIP) reduce 74) ((T_SR) reduce 74) (("[") reduce 74) (("^") reduce 74) (("{") reduce 74) (("|") reduce 74)) 21956 ((("%") reduce 30) (("(") reduce 30) (("*") reduce 30) (("+") reduce 30) (("-") reduce 30) ((".") reduce 30) (("/") reduce 30) ((":") reduce 30) ((";") reduce 30) (("<") reduce 30) ((">") reduce 30) (("?") reduce 30) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_BOOLEAN_AND) reduce 30) ((T_BOOLEAN_OR) reduce 30) ((T_COALESCE) reduce 30) ((T_INSTANCEOF) reduce 30) ((T_IS_EQUAL) reduce 30) ((T_IS_GREATER_OR_EQUAL) reduce 30) ((T_IS_IDENTICAL) reduce 30) ((T_IS_NOT_EQUAL) reduce 30) ((T_IS_NOT_IDENTICAL) reduce 30) ((T_IS_SMALLER_OR_EQUAL) reduce 30) ((T_LOGICAL_AND) reduce 30) ((T_LOGICAL_OR) reduce 30) ((T_LOGICAL_XOR) reduce 30) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 30) ((T_OBJECT_OPERATOR) reduce 30) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 30) ((T_POW) reduce 30) ((T_SL) reduce 30) ((T_SPACESHIP) reduce 30) ((T_SR) reduce 30) (("[") reduce 30) (("^") reduce 30) (("{") reduce 30) (("|") reduce 30)) 21957 ((("%") reduce 68) (("(") reduce 68) (("*") reduce 68) (("+") reduce 68) (("-") reduce 68) ((".") reduce 68) (("/") reduce 68) ((":") reduce 68) ((";") reduce 68) (("<") reduce 68) ((">") reduce 68) (("?") reduce 68) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_BOOLEAN_AND) reduce 68) ((T_BOOLEAN_OR) reduce 68) ((T_COALESCE) reduce 68) ((T_INSTANCEOF) reduce 68) ((T_IS_EQUAL) reduce 68) ((T_IS_GREATER_OR_EQUAL) reduce 68) ((T_IS_IDENTICAL) reduce 68) ((T_IS_NOT_EQUAL) reduce 68) ((T_IS_NOT_IDENTICAL) reduce 68) ((T_IS_SMALLER_OR_EQUAL) reduce 68) ((T_LOGICAL_AND) reduce 68) ((T_LOGICAL_OR) reduce 68) ((T_LOGICAL_XOR) reduce 68) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 68) ((T_OBJECT_OPERATOR) reduce 68) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 68) ((T_POW) reduce 68) ((T_SL) reduce 68) ((T_SPACESHIP) reduce 68) ((T_SR) reduce 68) (("[") reduce 68) (("^") reduce 68) (("{") reduce 68) (("|") reduce 68)) 21958 ((("%") reduce 21) (("(") reduce 21) (("*") reduce 21) (("+") reduce 21) (("-") reduce 21) ((".") reduce 21) (("/") reduce 21) ((":") reduce 21) ((";") reduce 21) (("<") reduce 21) ((">") reduce 21) (("?") reduce 21) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_BOOLEAN_AND) reduce 21) ((T_BOOLEAN_OR) reduce 21) ((T_COALESCE) reduce 21) ((T_INSTANCEOF) reduce 21) ((T_IS_EQUAL) reduce 21) ((T_IS_GREATER_OR_EQUAL) reduce 21) ((T_IS_IDENTICAL) reduce 21) ((T_IS_NOT_EQUAL) reduce 21) ((T_IS_NOT_IDENTICAL) reduce 21) ((T_IS_SMALLER_OR_EQUAL) reduce 21) ((T_LOGICAL_AND) reduce 21) ((T_LOGICAL_OR) reduce 21) ((T_LOGICAL_XOR) reduce 21) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 21) ((T_OBJECT_OPERATOR) reduce 21) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 21) ((T_POW) reduce 21) ((T_SL) reduce 21) ((T_SPACESHIP) reduce 21) ((T_SR) reduce 21) (("[") reduce 21) (("^") reduce 21) (("{") reduce 21) (("|") reduce 21)) 21959 ((("%") reduce 23) (("(") reduce 23) (("*") reduce 23) (("+") reduce 23) (("-") reduce 23) ((".") reduce 23) (("/") reduce 23) ((":") reduce 23) ((";") reduce 23) (("<") reduce 23) ((">") reduce 23) (("?") reduce 23) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_BOOLEAN_AND) reduce 23) ((T_BOOLEAN_OR) reduce 23) ((T_COALESCE) reduce 23) ((T_INSTANCEOF) reduce 23) ((T_IS_EQUAL) reduce 23) ((T_IS_GREATER_OR_EQUAL) reduce 23) ((T_IS_IDENTICAL) reduce 23) ((T_IS_NOT_EQUAL) reduce 23) ((T_IS_NOT_IDENTICAL) reduce 23) ((T_IS_SMALLER_OR_EQUAL) reduce 23) ((T_LOGICAL_AND) reduce 23) ((T_LOGICAL_OR) reduce 23) ((T_LOGICAL_XOR) reduce 23) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 23) ((T_OBJECT_OPERATOR) reduce 23) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 23) ((T_POW) reduce 23) ((T_SL) reduce 23) ((T_SPACESHIP) reduce 23) ((T_SR) reduce 23) (("[") reduce 23) (("^") reduce 23) (("{") reduce 23) (("|") reduce 23)) 21960 ((("%") reduce 41) (("(") reduce 41) (("*") reduce 41) (("+") reduce 41) (("-") reduce 41) ((".") reduce 41) (("/") reduce 41) ((":") reduce 41) ((";") reduce 41) (("<") reduce 41) ((">") reduce 41) (("?") reduce 41) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_BOOLEAN_AND) reduce 41) ((T_BOOLEAN_OR) reduce 41) ((T_COALESCE) reduce 41) ((T_INSTANCEOF) reduce 41) ((T_IS_EQUAL) reduce 41) ((T_IS_GREATER_OR_EQUAL) reduce 41) ((T_IS_IDENTICAL) reduce 41) ((T_IS_NOT_EQUAL) reduce 41) ((T_IS_NOT_IDENTICAL) reduce 41) ((T_IS_SMALLER_OR_EQUAL) reduce 41) ((T_LOGICAL_AND) reduce 41) ((T_LOGICAL_OR) reduce 41) ((T_LOGICAL_XOR) reduce 41) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 41) ((T_OBJECT_OPERATOR) reduce 41) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 41) ((T_POW) reduce 41) ((T_SL) reduce 41) ((T_SPACESHIP) reduce 41) ((T_SR) reduce 41) (("[") reduce 41) (("^") reduce 41) (("{") reduce 41) (("|") reduce 41)) 21961 ((("%") reduce 62) (("(") reduce 62) (("*") reduce 62) (("+") reduce 62) (("-") reduce 62) ((".") reduce 62) (("/") reduce 62) ((":") reduce 62) ((";") reduce 62) (("<") reduce 62) ((">") reduce 62) (("?") reduce 62) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_BOOLEAN_AND) reduce 62) ((T_BOOLEAN_OR) reduce 62) ((T_COALESCE) reduce 62) ((T_INSTANCEOF) reduce 62) ((T_IS_EQUAL) reduce 62) ((T_IS_GREATER_OR_EQUAL) reduce 62) ((T_IS_IDENTICAL) reduce 62) ((T_IS_NOT_EQUAL) reduce 62) ((T_IS_NOT_IDENTICAL) reduce 62) ((T_IS_SMALLER_OR_EQUAL) reduce 62) ((T_LOGICAL_AND) reduce 62) ((T_LOGICAL_OR) reduce 62) ((T_LOGICAL_XOR) reduce 62) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 62) ((T_OBJECT_OPERATOR) reduce 62) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 62) ((T_POW) reduce 62) ((T_SL) reduce 62) ((T_SPACESHIP) reduce 62) ((T_SR) reduce 62) (("[") reduce 62) (("^") reduce 62) (("{") reduce 62) (("|") reduce 62)) 21962 ((("%") reduce 34) (("(") reduce 34) (("*") reduce 34) (("+") reduce 34) (("-") reduce 34) ((".") reduce 34) (("/") reduce 34) ((":") reduce 34) ((";") reduce 34) (("<") reduce 34) ((">") reduce 34) (("?") reduce 34) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_BOOLEAN_AND) reduce 34) ((T_BOOLEAN_OR) reduce 34) ((T_COALESCE) reduce 34) ((T_INSTANCEOF) reduce 34) ((T_IS_EQUAL) reduce 34) ((T_IS_GREATER_OR_EQUAL) reduce 34) ((T_IS_IDENTICAL) reduce 34) ((T_IS_NOT_EQUAL) reduce 34) ((T_IS_NOT_IDENTICAL) reduce 34) ((T_IS_SMALLER_OR_EQUAL) reduce 34) ((T_LOGICAL_AND) reduce 34) ((T_LOGICAL_OR) reduce 34) ((T_LOGICAL_XOR) reduce 34) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 34) ((T_OBJECT_OPERATOR) reduce 34) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 34) ((T_POW) reduce 34) ((T_SL) reduce 34) ((T_SPACESHIP) reduce 34) ((T_SR) reduce 34) (("[") reduce 34) (("^") reduce 34) (("{") reduce 34) (("|") reduce 34)) 21963 ((("%") reduce 40) (("(") reduce 40) (("*") reduce 40) (("+") reduce 40) (("-") reduce 40) ((".") reduce 40) (("/") reduce 40) ((":") reduce 40) ((";") reduce 40) (("<") reduce 40) ((">") reduce 40) (("?") reduce 40) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_BOOLEAN_AND) reduce 40) ((T_BOOLEAN_OR) reduce 40) ((T_COALESCE) reduce 40) ((T_INSTANCEOF) reduce 40) ((T_IS_EQUAL) reduce 40) ((T_IS_GREATER_OR_EQUAL) reduce 40) ((T_IS_IDENTICAL) reduce 40) ((T_IS_NOT_EQUAL) reduce 40) ((T_IS_NOT_IDENTICAL) reduce 40) ((T_IS_SMALLER_OR_EQUAL) reduce 40) ((T_LOGICAL_AND) reduce 40) ((T_LOGICAL_OR) reduce 40) ((T_LOGICAL_XOR) reduce 40) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 40) ((T_OBJECT_OPERATOR) reduce 40) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 40) ((T_POW) reduce 40) ((T_SL) reduce 40) ((T_SPACESHIP) reduce 40) ((T_SR) reduce 40) (("[") reduce 40) (("^") reduce 40) (("{") reduce 40) (("|") reduce 40)) 21964 ((("%") reduce 13) (("(") reduce 13) (("*") reduce 13) (("+") reduce 13) (("-") reduce 13) ((".") reduce 13) (("/") reduce 13) ((":") reduce 13) ((";") reduce 13) (("<") reduce 13) ((">") reduce 13) (("?") reduce 13) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_BOOLEAN_AND) reduce 13) ((T_BOOLEAN_OR) reduce 13) ((T_COALESCE) reduce 13) ((T_INSTANCEOF) reduce 13) ((T_IS_EQUAL) reduce 13) ((T_IS_GREATER_OR_EQUAL) reduce 13) ((T_IS_IDENTICAL) reduce 13) ((T_IS_NOT_EQUAL) reduce 13) ((T_IS_NOT_IDENTICAL) reduce 13) ((T_IS_SMALLER_OR_EQUAL) reduce 13) ((T_LOGICAL_AND) reduce 13) ((T_LOGICAL_OR) reduce 13) ((T_LOGICAL_XOR) reduce 13) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 13) ((T_OBJECT_OPERATOR) reduce 13) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 13) ((T_POW) reduce 13) ((T_SL) reduce 13) ((T_SPACESHIP) reduce 13) ((T_SR) reduce 13) (("[") reduce 13) (("^") reduce 13) (("{") reduce 13) (("|") reduce 13)) 21965 ((("%") reduce 55) (("(") reduce 55) (("*") reduce 55) (("+") reduce 55) (("-") reduce 55) ((".") reduce 55) (("/") reduce 55) ((":") reduce 55) ((";") reduce 55) (("<") reduce 55) ((">") reduce 55) (("?") reduce 55) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_BOOLEAN_AND) reduce 55) ((T_BOOLEAN_OR) reduce 55) ((T_COALESCE) reduce 55) ((T_INSTANCEOF) reduce 55) ((T_IS_EQUAL) reduce 55) ((T_IS_GREATER_OR_EQUAL) reduce 55) ((T_IS_IDENTICAL) reduce 55) ((T_IS_NOT_EQUAL) reduce 55) ((T_IS_NOT_IDENTICAL) reduce 55) ((T_IS_SMALLER_OR_EQUAL) reduce 55) ((T_LOGICAL_AND) reduce 55) ((T_LOGICAL_OR) reduce 55) ((T_LOGICAL_XOR) reduce 55) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 55) ((T_OBJECT_OPERATOR) reduce 55) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 55) ((T_POW) reduce 55) ((T_SL) reduce 55) ((T_SPACESHIP) reduce 55) ((T_SR) reduce 55) (("[") reduce 55) (("^") reduce 55) (("{") reduce 55) (("|") reduce 55)) 21966 ((("%") reduce 1) (("(") reduce 1) (("*") reduce 1) (("+") reduce 1) (("-") reduce 1) ((".") reduce 1) (("/") reduce 1) ((":") reduce 1) ((";") reduce 1) (("<") reduce 1) ((">") reduce 1) (("?") reduce 1) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_BOOLEAN_AND) reduce 1) ((T_BOOLEAN_OR) reduce 1) ((T_COALESCE) reduce 1) ((T_INSTANCEOF) reduce 1) ((T_IS_EQUAL) reduce 1) ((T_IS_GREATER_OR_EQUAL) reduce 1) ((T_IS_IDENTICAL) reduce 1) ((T_IS_NOT_EQUAL) reduce 1) ((T_IS_NOT_IDENTICAL) reduce 1) ((T_IS_SMALLER_OR_EQUAL) reduce 1) ((T_LOGICAL_AND) reduce 1) ((T_LOGICAL_OR) reduce 1) ((T_LOGICAL_XOR) reduce 1) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 1) ((T_OBJECT_OPERATOR) reduce 1) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 1) ((T_POW) reduce 1) ((T_SL) reduce 1) ((T_SPACESHIP) reduce 1) ((T_SR) reduce 1) (("[") reduce 1) (("^") reduce 1) (("{") reduce 1) (("|") reduce 1)) 21967 ((("%") reduce 2) (("(") reduce 2) (("*") reduce 2) (("+") reduce 2) (("-") reduce 2) ((".") reduce 2) (("/") reduce 2) ((":") reduce 2) ((";") reduce 2) (("<") reduce 2) ((">") reduce 2) (("?") reduce 2) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_BOOLEAN_AND) reduce 2) ((T_BOOLEAN_OR) reduce 2) ((T_COALESCE) reduce 2) ((T_INSTANCEOF) reduce 2) ((T_IS_EQUAL) reduce 2) ((T_IS_GREATER_OR_EQUAL) reduce 2) ((T_IS_IDENTICAL) reduce 2) ((T_IS_NOT_EQUAL) reduce 2) ((T_IS_NOT_IDENTICAL) reduce 2) ((T_IS_SMALLER_OR_EQUAL) reduce 2) ((T_LOGICAL_AND) reduce 2) ((T_LOGICAL_OR) reduce 2) ((T_LOGICAL_XOR) reduce 2) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 2) ((T_OBJECT_OPERATOR) reduce 2) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 2) ((T_POW) reduce 2) ((T_SL) reduce 2) ((T_SPACESHIP) reduce 2) ((T_SR) reduce 2) (("[") reduce 2) (("^") reduce 2) (("{") reduce 2) (("|") reduce 2)) 21968 ((("%") reduce 9) (("(") reduce 9) (("*") reduce 9) (("+") reduce 9) (("-") reduce 9) ((".") reduce 9) (("/") reduce 9) ((":") reduce 9) ((";") reduce 9) (("<") reduce 9) ((">") reduce 9) (("?") reduce 9) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_BOOLEAN_AND) reduce 9) ((T_BOOLEAN_OR) reduce 9) ((T_COALESCE) reduce 9) ((T_INSTANCEOF) reduce 9) ((T_IS_EQUAL) reduce 9) ((T_IS_GREATER_OR_EQUAL) reduce 9) ((T_IS_IDENTICAL) reduce 9) ((T_IS_NOT_EQUAL) reduce 9) ((T_IS_NOT_IDENTICAL) reduce 9) ((T_IS_SMALLER_OR_EQUAL) reduce 9) ((T_LOGICAL_AND) reduce 9) ((T_LOGICAL_OR) reduce 9) ((T_LOGICAL_XOR) reduce 9) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 9) ((T_OBJECT_OPERATOR) reduce 9) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 9) ((T_POW) reduce 9) ((T_SL) reduce 9) ((T_SPACESHIP) reduce 9) ((T_SR) reduce 9) (("[") reduce 9) (("^") reduce 9) (("{") reduce 9) (("|") reduce 9)) 21969 ((("%") reduce 33) (("(") reduce 33) (("*") reduce 33) (("+") reduce 33) (("-") reduce 33) ((".") reduce 33) (("/") reduce 33) ((":") reduce 33) ((";") reduce 33) (("<") reduce 33) ((">") reduce 33) (("?") reduce 33) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_BOOLEAN_AND) reduce 33) ((T_BOOLEAN_OR) reduce 33) ((T_COALESCE) reduce 33) ((T_INSTANCEOF) reduce 33) ((T_IS_EQUAL) reduce 33) ((T_IS_GREATER_OR_EQUAL) reduce 33) ((T_IS_IDENTICAL) reduce 33) ((T_IS_NOT_EQUAL) reduce 33) ((T_IS_NOT_IDENTICAL) reduce 33) ((T_IS_SMALLER_OR_EQUAL) reduce 33) ((T_LOGICAL_AND) reduce 33) ((T_LOGICAL_OR) reduce 33) ((T_LOGICAL_XOR) reduce 33) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 33) ((T_OBJECT_OPERATOR) reduce 33) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 33) ((T_POW) reduce 33) ((T_SL) reduce 33) ((T_SPACESHIP) reduce 33) ((T_SR) reduce 33) (("[") reduce 33) (("^") reduce 33) (("{") reduce 33) (("|") reduce 33)) 21970 ((("%") reduce 58) (("(") reduce 58) (("*") reduce 58) (("+") reduce 58) (("-") reduce 58) ((".") reduce 58) (("/") reduce 58) ((":") reduce 58) ((";") reduce 58) (("<") reduce 58) ((">") reduce 58) (("?") reduce 58) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_BOOLEAN_AND) reduce 58) ((T_BOOLEAN_OR) reduce 58) ((T_COALESCE) reduce 58) ((T_INSTANCEOF) reduce 58) ((T_IS_EQUAL) reduce 58) ((T_IS_GREATER_OR_EQUAL) reduce 58) ((T_IS_IDENTICAL) reduce 58) ((T_IS_NOT_EQUAL) reduce 58) ((T_IS_NOT_IDENTICAL) reduce 58) ((T_IS_SMALLER_OR_EQUAL) reduce 58) ((T_LOGICAL_AND) reduce 58) ((T_LOGICAL_OR) reduce 58) ((T_LOGICAL_XOR) reduce 58) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 58) ((T_OBJECT_OPERATOR) reduce 58) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 58) ((T_POW) reduce 58) ((T_SL) reduce 58) ((T_SPACESHIP) reduce 58) ((T_SR) reduce 58) (("[") reduce 58) (("^") reduce 58) (("{") reduce 58) (("|") reduce 58)) 21971 ((("%") reduce 37) (("(") reduce 37) (("*") reduce 37) (("+") reduce 37) (("-") reduce 37) ((".") reduce 37) (("/") reduce 37) ((":") reduce 37) ((";") reduce 37) (("<") reduce 37) ((">") reduce 37) (("?") reduce 37) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_BOOLEAN_AND) reduce 37) ((T_BOOLEAN_OR) reduce 37) ((T_COALESCE) reduce 37) ((T_INSTANCEOF) reduce 37) ((T_IS_EQUAL) reduce 37) ((T_IS_GREATER_OR_EQUAL) reduce 37) ((T_IS_IDENTICAL) reduce 37) ((T_IS_NOT_EQUAL) reduce 37) ((T_IS_NOT_IDENTICAL) reduce 37) ((T_IS_SMALLER_OR_EQUAL) reduce 37) ((T_LOGICAL_AND) reduce 37) ((T_LOGICAL_OR) reduce 37) ((T_LOGICAL_XOR) reduce 37) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 37) ((T_OBJECT_OPERATOR) reduce 37) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 37) ((T_POW) reduce 37) ((T_SL) reduce 37) ((T_SPACESHIP) reduce 37) ((T_SR) reduce 37) (("[") reduce 37) (("^") reduce 37) (("{") reduce 37) (("|") reduce 37)) 21972 ((("%") reduce 64) (("(") reduce 64) (("*") reduce 64) (("+") reduce 64) (("-") reduce 64) ((".") reduce 64) (("/") reduce 64) ((":") reduce 64) ((";") reduce 64) (("<") reduce 64) ((">") reduce 64) (("?") reduce 64) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_BOOLEAN_AND) reduce 64) ((T_BOOLEAN_OR) reduce 64) ((T_COALESCE) reduce 64) ((T_INSTANCEOF) reduce 64) ((T_IS_EQUAL) reduce 64) ((T_IS_GREATER_OR_EQUAL) reduce 64) ((T_IS_IDENTICAL) reduce 64) ((T_IS_NOT_EQUAL) reduce 64) ((T_IS_NOT_IDENTICAL) reduce 64) ((T_IS_SMALLER_OR_EQUAL) reduce 64) ((T_LOGICAL_AND) reduce 64) ((T_LOGICAL_OR) reduce 64) ((T_LOGICAL_XOR) reduce 64) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 64) ((T_OBJECT_OPERATOR) reduce 64) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 64) ((T_POW) reduce 64) ((T_SL) reduce 64) ((T_SPACESHIP) reduce 64) ((T_SR) reduce 64) (("[") reduce 64) (("^") reduce 64) (("{") reduce 64) (("|") reduce 64)) 21973 ((("%") reduce 46) (("(") reduce 46) (("*") reduce 46) (("+") reduce 46) (("-") reduce 46) ((".") reduce 46) (("/") reduce 46) ((":") reduce 46) ((";") reduce 46) (("<") reduce 46) ((">") reduce 46) (("?") reduce 46) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_BOOLEAN_AND) reduce 46) ((T_BOOLEAN_OR) reduce 46) ((T_COALESCE) reduce 46) ((T_INSTANCEOF) reduce 46) ((T_IS_EQUAL) reduce 46) ((T_IS_GREATER_OR_EQUAL) reduce 46) ((T_IS_IDENTICAL) reduce 46) ((T_IS_NOT_EQUAL) reduce 46) ((T_IS_NOT_IDENTICAL) reduce 46) ((T_IS_SMALLER_OR_EQUAL) reduce 46) ((T_LOGICAL_AND) reduce 46) ((T_LOGICAL_OR) reduce 46) ((T_LOGICAL_XOR) reduce 46) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 46) ((T_OBJECT_OPERATOR) reduce 46) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 46) ((T_POW) reduce 46) ((T_SL) reduce 46) ((T_SPACESHIP) reduce 46) ((T_SR) reduce 46) (("[") reduce 46) (("^") reduce 46) (("{") reduce 46) (("|") reduce 46)) 21974 ((("%") reduce 8) (("(") reduce 8) (("*") reduce 8) (("+") reduce 8) (("-") reduce 8) ((".") reduce 8) (("/") reduce 8) ((":") reduce 8) ((";") reduce 8) (("<") reduce 8) ((">") reduce 8) (("?") reduce 8) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_BOOLEAN_AND) reduce 8) ((T_BOOLEAN_OR) reduce 8) ((T_COALESCE) reduce 8) ((T_INSTANCEOF) reduce 8) ((T_IS_EQUAL) reduce 8) ((T_IS_GREATER_OR_EQUAL) reduce 8) ((T_IS_IDENTICAL) reduce 8) ((T_IS_NOT_EQUAL) reduce 8) ((T_IS_NOT_IDENTICAL) reduce 8) ((T_IS_SMALLER_OR_EQUAL) reduce 8) ((T_LOGICAL_AND) reduce 8) ((T_LOGICAL_OR) reduce 8) ((T_LOGICAL_XOR) reduce 8) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 8) ((T_OBJECT_OPERATOR) reduce 8) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 8) ((T_POW) reduce 8) ((T_SL) reduce 8) ((T_SPACESHIP) reduce 8) ((T_SR) reduce 8) (("[") reduce 8) (("^") reduce 8) (("{") reduce 8) (("|") reduce 8)) 21975 ((("%") reduce 6) (("(") reduce 6) (("*") reduce 6) (("+") reduce 6) (("-") reduce 6) ((".") reduce 6) (("/") reduce 6) ((":") reduce 6) ((";") reduce 6) (("<") reduce 6) ((">") reduce 6) (("?") reduce 6) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_BOOLEAN_AND) reduce 6) ((T_BOOLEAN_OR) reduce 6) ((T_COALESCE) reduce 6) ((T_INSTANCEOF) reduce 6) ((T_IS_EQUAL) reduce 6) ((T_IS_GREATER_OR_EQUAL) reduce 6) ((T_IS_IDENTICAL) reduce 6) ((T_IS_NOT_EQUAL) reduce 6) ((T_IS_NOT_IDENTICAL) reduce 6) ((T_IS_SMALLER_OR_EQUAL) reduce 6) ((T_LOGICAL_AND) reduce 6) ((T_LOGICAL_OR) reduce 6) ((T_LOGICAL_XOR) reduce 6) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 6) ((T_OBJECT_OPERATOR) reduce 6) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 6) ((T_POW) reduce 6) ((T_SL) reduce 6) ((T_SPACESHIP) reduce 6) ((T_SR) reduce 6) (("[") reduce 6) (("^") reduce 6) (("{") reduce 6) (("|") reduce 6)) 21976 ((("%") reduce 7) (("(") reduce 7) (("*") reduce 7) (("+") reduce 7) (("-") reduce 7) ((".") reduce 7) (("/") reduce 7) ((":") reduce 7) ((";") reduce 7) (("<") reduce 7) ((">") reduce 7) (("?") reduce 7) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_BOOLEAN_AND) reduce 7) ((T_BOOLEAN_OR) reduce 7) ((T_COALESCE) reduce 7) ((T_INSTANCEOF) reduce 7) ((T_IS_EQUAL) reduce 7) ((T_IS_GREATER_OR_EQUAL) reduce 7) ((T_IS_IDENTICAL) reduce 7) ((T_IS_NOT_EQUAL) reduce 7) ((T_IS_NOT_IDENTICAL) reduce 7) ((T_IS_SMALLER_OR_EQUAL) reduce 7) ((T_LOGICAL_AND) reduce 7) ((T_LOGICAL_OR) reduce 7) ((T_LOGICAL_XOR) reduce 7) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 7) ((T_OBJECT_OPERATOR) reduce 7) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 7) ((T_POW) reduce 7) ((T_SL) reduce 7) ((T_SPACESHIP) reduce 7) ((T_SR) reduce 7) (("[") reduce 7) (("^") reduce 7) (("{") reduce 7) (("|") reduce 7)) 21977 ((("%") reduce 69) (("(") reduce 69) (("*") reduce 69) (("+") reduce 69) (("-") reduce 69) ((".") reduce 69) (("/") reduce 69) ((":") reduce 69) ((";") reduce 69) (("<") reduce 69) ((">") reduce 69) (("?") reduce 69) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_BOOLEAN_AND) reduce 69) ((T_BOOLEAN_OR) reduce 69) ((T_COALESCE) reduce 69) ((T_INSTANCEOF) reduce 69) ((T_IS_EQUAL) reduce 69) ((T_IS_GREATER_OR_EQUAL) reduce 69) ((T_IS_IDENTICAL) reduce 69) ((T_IS_NOT_EQUAL) reduce 69) ((T_IS_NOT_IDENTICAL) reduce 69) ((T_IS_SMALLER_OR_EQUAL) reduce 69) ((T_LOGICAL_AND) reduce 69) ((T_LOGICAL_OR) reduce 69) ((T_LOGICAL_XOR) reduce 69) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 69) ((T_OBJECT_OPERATOR) reduce 69) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 69) ((T_POW) reduce 69) ((T_SL) reduce 69) ((T_SPACESHIP) reduce 69) ((T_SR) reduce 69) (("[") reduce 69) (("^") reduce 69) (("{") reduce 69) (("|") reduce 69)) 21978 ((("%") reduce 63) (("(") reduce 63) (("*") reduce 63) (("+") reduce 63) (("-") reduce 63) ((".") reduce 63) (("/") reduce 63) ((":") reduce 63) ((";") reduce 63) (("<") reduce 63) ((">") reduce 63) (("?") reduce 63) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_BOOLEAN_AND) reduce 63) ((T_BOOLEAN_OR) reduce 63) ((T_COALESCE) reduce 63) ((T_INSTANCEOF) reduce 63) ((T_IS_EQUAL) reduce 63) ((T_IS_GREATER_OR_EQUAL) reduce 63) ((T_IS_IDENTICAL) reduce 63) ((T_IS_NOT_EQUAL) reduce 63) ((T_IS_NOT_IDENTICAL) reduce 63) ((T_IS_SMALLER_OR_EQUAL) reduce 63) ((T_LOGICAL_AND) reduce 63) ((T_LOGICAL_OR) reduce 63) ((T_LOGICAL_XOR) reduce 63) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 63) ((T_OBJECT_OPERATOR) reduce 63) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 63) ((T_POW) reduce 63) ((T_SL) reduce 63) ((T_SPACESHIP) reduce 63) ((T_SR) reduce 63) (("[") reduce 63) (("^") reduce 63) (("{") reduce 63) (("|") reduce 63)) 21979 ((("%") reduce 56) (("(") reduce 56) (("*") reduce 56) (("+") reduce 56) (("-") reduce 56) ((".") reduce 56) (("/") reduce 56) ((":") reduce 56) ((";") reduce 56) (("<") reduce 56) ((">") reduce 56) (("?") reduce 56) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_BOOLEAN_AND) reduce 56) ((T_BOOLEAN_OR) reduce 56) ((T_COALESCE) reduce 56) ((T_INSTANCEOF) reduce 56) ((T_IS_EQUAL) reduce 56) ((T_IS_GREATER_OR_EQUAL) reduce 56) ((T_IS_IDENTICAL) reduce 56) ((T_IS_NOT_EQUAL) reduce 56) ((T_IS_NOT_IDENTICAL) reduce 56) ((T_IS_SMALLER_OR_EQUAL) reduce 56) ((T_LOGICAL_AND) reduce 56) ((T_LOGICAL_OR) reduce 56) ((T_LOGICAL_XOR) reduce 56) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 56) ((T_OBJECT_OPERATOR) reduce 56) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 56) ((T_POW) reduce 56) ((T_SL) reduce 56) ((T_SPACESHIP) reduce 56) ((T_SR) reduce 56) (("[") reduce 56) (("^") reduce 56) (("{") reduce 56) (("|") reduce 56)) 21980 ((("%") reduce 10) (("(") reduce 10) (("*") reduce 10) (("+") reduce 10) (("-") reduce 10) ((".") reduce 10) (("/") reduce 10) ((":") reduce 10) ((";") reduce 10) (("<") reduce 10) ((">") reduce 10) (("?") reduce 10) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_BOOLEAN_AND) reduce 10) ((T_BOOLEAN_OR) reduce 10) ((T_COALESCE) reduce 10) ((T_INSTANCEOF) reduce 10) ((T_IS_EQUAL) reduce 10) ((T_IS_GREATER_OR_EQUAL) reduce 10) ((T_IS_IDENTICAL) reduce 10) ((T_IS_NOT_EQUAL) reduce 10) ((T_IS_NOT_IDENTICAL) reduce 10) ((T_IS_SMALLER_OR_EQUAL) reduce 10) ((T_LOGICAL_AND) reduce 10) ((T_LOGICAL_OR) reduce 10) ((T_LOGICAL_XOR) reduce 10) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 10) ((T_OBJECT_OPERATOR) reduce 10) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 10) ((T_POW) reduce 10) ((T_SL) reduce 10) ((T_SPACESHIP) reduce 10) ((T_SR) reduce 10) (("[") reduce 10) (("^") reduce 10) (("{") reduce 10) (("|") reduce 10)) 21981 ((("%") reduce 67) (("(") reduce 67) (("*") reduce 67) (("+") reduce 67) (("-") reduce 67) ((".") reduce 67) (("/") reduce 67) ((":") reduce 67) ((";") reduce 67) (("<") reduce 67) ((">") reduce 67) (("?") reduce 67) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_BOOLEAN_AND) reduce 67) ((T_BOOLEAN_OR) reduce 67) ((T_COALESCE) reduce 67) ((T_INSTANCEOF) reduce 67) ((T_IS_EQUAL) reduce 67) ((T_IS_GREATER_OR_EQUAL) reduce 67) ((T_IS_IDENTICAL) reduce 67) ((T_IS_NOT_EQUAL) reduce 67) ((T_IS_NOT_IDENTICAL) reduce 67) ((T_IS_SMALLER_OR_EQUAL) reduce 67) ((T_LOGICAL_AND) reduce 67) ((T_LOGICAL_OR) reduce 67) ((T_LOGICAL_XOR) reduce 67) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 67) ((T_OBJECT_OPERATOR) reduce 67) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 67) ((T_POW) reduce 67) ((T_SL) reduce 67) ((T_SPACESHIP) reduce 67) ((T_SR) reduce 67) (("[") reduce 67) (("^") reduce 67) (("{") reduce 67) (("|") reduce 67)) 21982 ((("%") reduce 44) (("(") reduce 44) (("*") reduce 44) (("+") reduce 44) (("-") reduce 44) ((".") reduce 44) (("/") reduce 44) ((":") reduce 44) ((";") reduce 44) (("<") reduce 44) ((">") reduce 44) (("?") reduce 44) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_BOOLEAN_AND) reduce 44) ((T_BOOLEAN_OR) reduce 44) ((T_COALESCE) reduce 44) ((T_INSTANCEOF) reduce 44) ((T_IS_EQUAL) reduce 44) ((T_IS_GREATER_OR_EQUAL) reduce 44) ((T_IS_IDENTICAL) reduce 44) ((T_IS_NOT_EQUAL) reduce 44) ((T_IS_NOT_IDENTICAL) reduce 44) ((T_IS_SMALLER_OR_EQUAL) reduce 44) ((T_LOGICAL_AND) reduce 44) ((T_LOGICAL_OR) reduce 44) ((T_LOGICAL_XOR) reduce 44) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 44) ((T_OBJECT_OPERATOR) reduce 44) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 44) ((T_POW) reduce 44) ((T_SL) reduce 44) ((T_SPACESHIP) reduce 44) ((T_SR) reduce 44) (("[") reduce 44) (("^") reduce 44) (("{") reduce 44) (("|") reduce 44)) 21983 ((("%") reduce 75) (("(") reduce 75) (("*") reduce 75) (("+") reduce 75) (("-") reduce 75) ((".") reduce 75) (("/") reduce 75) ((":") reduce 75) ((";") reduce 75) (("<") reduce 75) ((">") reduce 75) (("?") reduce 75) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_BOOLEAN_AND) reduce 75) ((T_BOOLEAN_OR) reduce 75) ((T_COALESCE) reduce 75) ((T_INSTANCEOF) reduce 75) ((T_IS_EQUAL) reduce 75) ((T_IS_GREATER_OR_EQUAL) reduce 75) ((T_IS_IDENTICAL) reduce 75) ((T_IS_NOT_EQUAL) reduce 75) ((T_IS_NOT_IDENTICAL) reduce 75) ((T_IS_SMALLER_OR_EQUAL) reduce 75) ((T_LOGICAL_AND) reduce 75) ((T_LOGICAL_OR) reduce 75) ((T_LOGICAL_XOR) reduce 75) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 75) ((T_OBJECT_OPERATOR) reduce 75) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 75) ((T_POW) reduce 75) ((T_SL) reduce 75) ((T_SPACESHIP) reduce 75) ((T_SR) reduce 75) (("[") reduce 75) (("^") reduce 75) (("{") reduce 75) (("|") reduce 75)) 21984 ((("%") reduce 76) (("(") reduce 76) (("*") reduce 76) (("+") reduce 76) (("-") reduce 76) ((".") reduce 76) (("/") reduce 76) ((":") reduce 76) ((";") reduce 76) (("<") reduce 76) ((">") reduce 76) (("?") reduce 76) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_BOOLEAN_AND) reduce 76) ((T_BOOLEAN_OR) reduce 76) ((T_COALESCE) reduce 76) ((T_INSTANCEOF) reduce 76) ((T_IS_EQUAL) reduce 76) ((T_IS_GREATER_OR_EQUAL) reduce 76) ((T_IS_IDENTICAL) reduce 76) ((T_IS_NOT_EQUAL) reduce 76) ((T_IS_NOT_IDENTICAL) reduce 76) ((T_IS_SMALLER_OR_EQUAL) reduce 76) ((T_LOGICAL_AND) reduce 76) ((T_LOGICAL_OR) reduce 76) ((T_LOGICAL_XOR) reduce 76) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 76) ((T_OBJECT_OPERATOR) reduce 76) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 76) ((T_POW) reduce 76) ((T_SL) reduce 76) ((T_SPACESHIP) reduce 76) ((T_SR) reduce 76) (("[") reduce 76) (("^") reduce 76) (("{") reduce 76) (("|") reduce 76)) 21985 ((("%") reduce 77) (("(") reduce 77) (("*") reduce 77) (("+") reduce 77) (("-") reduce 77) ((".") reduce 77) (("/") reduce 77) ((":") reduce 77) ((";") reduce 77) (("<") reduce 77) ((">") reduce 77) (("?") reduce 77) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_BOOLEAN_AND) reduce 77) ((T_BOOLEAN_OR) reduce 77) ((T_COALESCE) reduce 77) ((T_INSTANCEOF) reduce 77) ((T_IS_EQUAL) reduce 77) ((T_IS_GREATER_OR_EQUAL) reduce 77) ((T_IS_IDENTICAL) reduce 77) ((T_IS_NOT_EQUAL) reduce 77) ((T_IS_NOT_IDENTICAL) reduce 77) ((T_IS_SMALLER_OR_EQUAL) reduce 77) ((T_LOGICAL_AND) reduce 77) ((T_LOGICAL_OR) reduce 77) ((T_LOGICAL_XOR) reduce 77) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 77) ((T_OBJECT_OPERATOR) reduce 77) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 77) ((T_POW) reduce 77) ((T_SL) reduce 77) ((T_SPACESHIP) reduce 77) ((T_SR) reduce 77) (("[") reduce 77) (("^") reduce 77) (("{") reduce 77) (("|") reduce 77)) 21986 ((("%") reduce 78) (("(") reduce 78) (("*") reduce 78) (("+") reduce 78) (("-") reduce 78) ((".") reduce 78) (("/") reduce 78) ((":") reduce 78) ((";") reduce 78) (("<") reduce 78) ((">") reduce 78) (("?") reduce 78) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_BOOLEAN_AND) reduce 78) ((T_BOOLEAN_OR) reduce 78) ((T_COALESCE) reduce 78) ((T_INSTANCEOF) reduce 78) ((T_IS_EQUAL) reduce 78) ((T_IS_GREATER_OR_EQUAL) reduce 78) ((T_IS_IDENTICAL) reduce 78) ((T_IS_NOT_EQUAL) reduce 78) ((T_IS_NOT_IDENTICAL) reduce 78) ((T_IS_SMALLER_OR_EQUAL) reduce 78) ((T_LOGICAL_AND) reduce 78) ((T_LOGICAL_OR) reduce 78) ((T_LOGICAL_XOR) reduce 78) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 78) ((T_OBJECT_OPERATOR) reduce 78) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 78) ((T_POW) reduce 78) ((T_SL) reduce 78) ((T_SPACESHIP) reduce 78) ((T_SR) reduce 78) (("[") reduce 78) (("^") reduce 78) (("{") reduce 78) (("|") reduce 78)) 21987 ((("%") reduce 4) (("(") reduce 4) (("*") reduce 4) (("+") reduce 4) (("-") reduce 4) ((".") reduce 4) (("/") reduce 4) ((":") reduce 4) ((";") reduce 4) (("<") reduce 4) ((">") reduce 4) (("?") reduce 4) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_BOOLEAN_AND) reduce 4) ((T_BOOLEAN_OR) reduce 4) ((T_COALESCE) reduce 4) ((T_INSTANCEOF) reduce 4) ((T_IS_EQUAL) reduce 4) ((T_IS_GREATER_OR_EQUAL) reduce 4) ((T_IS_IDENTICAL) reduce 4) ((T_IS_NOT_EQUAL) reduce 4) ((T_IS_NOT_IDENTICAL) reduce 4) ((T_IS_SMALLER_OR_EQUAL) reduce 4) ((T_LOGICAL_AND) reduce 4) ((T_LOGICAL_OR) reduce 4) ((T_LOGICAL_XOR) reduce 4) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 4) ((T_OBJECT_OPERATOR) reduce 4) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 4) ((T_POW) reduce 4) ((T_SL) reduce 4) ((T_SPACESHIP) reduce 4) ((T_SR) reduce 4) (("[") reduce 4) (("^") reduce 4) (("{") reduce 4) (("|") reduce 4)) 21988 ((("%") reduce 5) (("(") reduce 5) (("*") reduce 5) (("+") reduce 5) (("-") reduce 5) ((".") reduce 5) (("/") reduce 5) ((":") reduce 5) ((";") reduce 5) (("<") reduce 5) ((">") reduce 5) (("?") reduce 5) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_BOOLEAN_AND) reduce 5) ((T_BOOLEAN_OR) reduce 5) ((T_COALESCE) reduce 5) ((T_INSTANCEOF) reduce 5) ((T_IS_EQUAL) reduce 5) ((T_IS_GREATER_OR_EQUAL) reduce 5) ((T_IS_IDENTICAL) reduce 5) ((T_IS_NOT_EQUAL) reduce 5) ((T_IS_NOT_IDENTICAL) reduce 5) ((T_IS_SMALLER_OR_EQUAL) reduce 5) ((T_LOGICAL_AND) reduce 5) ((T_LOGICAL_OR) reduce 5) ((T_LOGICAL_XOR) reduce 5) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 5) ((T_OBJECT_OPERATOR) reduce 5) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 5) ((T_POW) reduce 5) ((T_SL) reduce 5) ((T_SPACESHIP) reduce 5) ((T_SR) reduce 5) (("[") reduce 5) (("^") reduce 5) (("{") reduce 5) (("|") reduce 5)) 21989 ((("%") reduce 43) (("(") reduce 43) (("*") reduce 43) (("+") reduce 43) (("-") reduce 43) ((".") reduce 43) (("/") reduce 43) ((":") reduce 43) ((";") reduce 43) (("<") reduce 43) ((">") reduce 43) (("?") reduce 43) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_BOOLEAN_AND) reduce 43) ((T_BOOLEAN_OR) reduce 43) ((T_COALESCE) reduce 43) ((T_INSTANCEOF) reduce 43) ((T_IS_EQUAL) reduce 43) ((T_IS_GREATER_OR_EQUAL) reduce 43) ((T_IS_IDENTICAL) reduce 43) ((T_IS_NOT_EQUAL) reduce 43) ((T_IS_NOT_IDENTICAL) reduce 43) ((T_IS_SMALLER_OR_EQUAL) reduce 43) ((T_LOGICAL_AND) reduce 43) ((T_LOGICAL_OR) reduce 43) ((T_LOGICAL_XOR) reduce 43) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 43) ((T_OBJECT_OPERATOR) reduce 43) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 43) ((T_POW) reduce 43) ((T_SL) reduce 43) ((T_SPACESHIP) reduce 43) ((T_SR) reduce 43) (("[") reduce 43) (("^") reduce 43) (("{") reduce 43) (("|") reduce 43)) 21990 ((("%") reduce 72) (("(") reduce 72) (("*") reduce 72) (("+") reduce 72) (("-") reduce 72) ((".") reduce 72) (("/") reduce 72) ((":") reduce 72) ((";") reduce 72) (("<") reduce 72) ((">") reduce 72) (("?") reduce 72) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_BOOLEAN_AND) reduce 72) ((T_BOOLEAN_OR) reduce 72) ((T_COALESCE) reduce 72) ((T_INSTANCEOF) reduce 72) ((T_IS_EQUAL) reduce 72) ((T_IS_GREATER_OR_EQUAL) reduce 72) ((T_IS_IDENTICAL) reduce 72) ((T_IS_NOT_EQUAL) reduce 72) ((T_IS_NOT_IDENTICAL) reduce 72) ((T_IS_SMALLER_OR_EQUAL) reduce 72) ((T_LOGICAL_AND) reduce 72) ((T_LOGICAL_OR) reduce 72) ((T_LOGICAL_XOR) reduce 72) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 72) ((T_OBJECT_OPERATOR) reduce 72) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 72) ((T_POW) reduce 72) ((T_SL) reduce 72) ((T_SPACESHIP) reduce 72) ((T_SR) reduce 72) (("[") reduce 72) (("^") reduce 72) (("{") reduce 72) (("|") reduce 72)) 21991 ((("%") reduce 81) (("(") reduce 81) (("*") reduce 81) (("+") reduce 81) (("-") reduce 81) ((".") reduce 81) (("/") reduce 81) ((":") reduce 81) ((";") reduce 81) (("<") reduce 81) ((">") reduce 81) (("?") reduce 81) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_BOOLEAN_AND) reduce 81) ((T_BOOLEAN_OR) reduce 81) ((T_COALESCE) reduce 81) ((T_INSTANCEOF) reduce 81) ((T_IS_EQUAL) reduce 81) ((T_IS_GREATER_OR_EQUAL) reduce 81) ((T_IS_IDENTICAL) reduce 81) ((T_IS_NOT_EQUAL) reduce 81) ((T_IS_NOT_IDENTICAL) reduce 81) ((T_IS_SMALLER_OR_EQUAL) reduce 81) ((T_LOGICAL_AND) reduce 81) ((T_LOGICAL_OR) reduce 81) ((T_LOGICAL_XOR) reduce 81) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 81) ((T_OBJECT_OPERATOR) reduce 81) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 81) ((T_POW) reduce 81) ((T_SL) reduce 81) ((T_SPACESHIP) reduce 81) ((T_SR) reduce 81) (("[") reduce 81) (("^") reduce 81) (("{") reduce 81) (("|") reduce 81)) 21992 ((("%") reduce 47) (("(") reduce 47) (("*") reduce 47) (("+") reduce 47) (("-") reduce 47) ((".") reduce 47) (("/") reduce 47) ((":") reduce 47) ((";") reduce 47) (("<") reduce 47) ((">") reduce 47) (("?") reduce 47) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_BOOLEAN_AND) reduce 47) ((T_BOOLEAN_OR) reduce 47) ((T_COALESCE) reduce 47) ((T_INSTANCEOF) reduce 47) ((T_IS_EQUAL) reduce 47) ((T_IS_GREATER_OR_EQUAL) reduce 47) ((T_IS_IDENTICAL) reduce 47) ((T_IS_NOT_EQUAL) reduce 47) ((T_IS_NOT_IDENTICAL) reduce 47) ((T_IS_SMALLER_OR_EQUAL) reduce 47) ((T_LOGICAL_AND) reduce 47) ((T_LOGICAL_OR) reduce 47) ((T_LOGICAL_XOR) reduce 47) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 47) ((T_OBJECT_OPERATOR) reduce 47) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 47) ((T_POW) reduce 47) ((T_SL) reduce 47) ((T_SPACESHIP) reduce 47) ((T_SR) reduce 47) (("[") reduce 47) (("^") reduce 47) (("{") reduce 47) (("|") reduce 47)) 21993 ((("%") reduce 31) (("(") reduce 31) (("*") reduce 31) (("+") reduce 31) (("-") reduce 31) ((".") reduce 31) (("/") reduce 31) ((":") reduce 31) ((";") reduce 31) (("<") reduce 31) ((">") reduce 31) (("?") reduce 31) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_BOOLEAN_AND) reduce 31) ((T_BOOLEAN_OR) reduce 31) ((T_COALESCE) reduce 31) ((T_INSTANCEOF) reduce 31) ((T_IS_EQUAL) reduce 31) ((T_IS_GREATER_OR_EQUAL) reduce 31) ((T_IS_IDENTICAL) reduce 31) ((T_IS_NOT_EQUAL) reduce 31) ((T_IS_NOT_IDENTICAL) reduce 31) ((T_IS_SMALLER_OR_EQUAL) reduce 31) ((T_LOGICAL_AND) reduce 31) ((T_LOGICAL_OR) reduce 31) ((T_LOGICAL_XOR) reduce 31) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 31) ((T_OBJECT_OPERATOR) reduce 31) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 31) ((T_POW) reduce 31) ((T_SL) reduce 31) ((T_SPACESHIP) reduce 31) ((T_SR) reduce 31) (("[") reduce 31) (("^") reduce 31) (("{") reduce 31) (("|") reduce 31)) 21994 ((("%") reduce 57) (("(") reduce 57) (("*") reduce 57) (("+") reduce 57) (("-") reduce 57) ((".") reduce 57) (("/") reduce 57) ((":") reduce 57) ((";") reduce 57) (("<") reduce 57) ((">") reduce 57) (("?") reduce 57) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_BOOLEAN_AND) reduce 57) ((T_BOOLEAN_OR) reduce 57) ((T_COALESCE) reduce 57) ((T_INSTANCEOF) reduce 57) ((T_IS_EQUAL) reduce 57) ((T_IS_GREATER_OR_EQUAL) reduce 57) ((T_IS_IDENTICAL) reduce 57) ((T_IS_NOT_EQUAL) reduce 57) ((T_IS_NOT_IDENTICAL) reduce 57) ((T_IS_SMALLER_OR_EQUAL) reduce 57) ((T_LOGICAL_AND) reduce 57) ((T_LOGICAL_OR) reduce 57) ((T_LOGICAL_XOR) reduce 57) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 57) ((T_OBJECT_OPERATOR) reduce 57) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 57) ((T_POW) reduce 57) ((T_SL) reduce 57) ((T_SPACESHIP) reduce 57) ((T_SR) reduce 57) (("[") reduce 57) (("^") reduce 57) (("{") reduce 57) (("|") reduce 57)) 21995 ((("%") reduce 61) (("(") reduce 61) (("*") reduce 61) (("+") reduce 61) (("-") reduce 61) ((".") reduce 61) (("/") reduce 61) ((":") reduce 61) ((";") reduce 61) (("<") reduce 61) ((">") reduce 61) (("?") reduce 61) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_BOOLEAN_AND) reduce 61) ((T_BOOLEAN_OR) reduce 61) ((T_COALESCE) reduce 61) ((T_INSTANCEOF) reduce 61) ((T_IS_EQUAL) reduce 61) ((T_IS_GREATER_OR_EQUAL) reduce 61) ((T_IS_IDENTICAL) reduce 61) ((T_IS_NOT_EQUAL) reduce 61) ((T_IS_NOT_IDENTICAL) reduce 61) ((T_IS_SMALLER_OR_EQUAL) reduce 61) ((T_LOGICAL_AND) reduce 61) ((T_LOGICAL_OR) reduce 61) ((T_LOGICAL_XOR) reduce 61) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 61) ((T_OBJECT_OPERATOR) reduce 61) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 61) ((T_POW) reduce 61) ((T_SL) reduce 61) ((T_SPACESHIP) reduce 61) ((T_SR) reduce 61) (("[") reduce 61) (("^") reduce 61) (("{") reduce 61) (("|") reduce 61)) 21996 ((("%") reduce 28) (("(") reduce 28) (("*") reduce 28) (("+") reduce 28) (("-") reduce 28) ((".") reduce 28) (("/") reduce 28) ((":") reduce 28) ((";") reduce 28) (("<") reduce 28) ((">") reduce 28) (("?") reduce 28) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_BOOLEAN_AND) reduce 28) ((T_BOOLEAN_OR) reduce 28) ((T_COALESCE) reduce 28) ((T_INSTANCEOF) reduce 28) ((T_IS_EQUAL) reduce 28) ((T_IS_GREATER_OR_EQUAL) reduce 28) ((T_IS_IDENTICAL) reduce 28) ((T_IS_NOT_EQUAL) reduce 28) ((T_IS_NOT_IDENTICAL) reduce 28) ((T_IS_SMALLER_OR_EQUAL) reduce 28) ((T_LOGICAL_AND) reduce 28) ((T_LOGICAL_OR) reduce 28) ((T_LOGICAL_XOR) reduce 28) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 28) ((T_OBJECT_OPERATOR) reduce 28) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 28) ((T_POW) reduce 28) ((T_SL) reduce 28) ((T_SPACESHIP) reduce 28) ((T_SR) reduce 28) (("[") reduce 28) (("^") reduce 28) (("{") reduce 28) (("|") reduce 28)) 21997 ((("%") reduce 36) (("(") reduce 36) (("*") reduce 36) (("+") reduce 36) (("-") reduce 36) ((".") reduce 36) (("/") reduce 36) ((":") reduce 36) ((";") reduce 36) (("<") reduce 36) ((">") reduce 36) (("?") reduce 36) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_BOOLEAN_AND) reduce 36) ((T_BOOLEAN_OR) reduce 36) ((T_COALESCE) reduce 36) ((T_INSTANCEOF) reduce 36) ((T_IS_EQUAL) reduce 36) ((T_IS_GREATER_OR_EQUAL) reduce 36) ((T_IS_IDENTICAL) reduce 36) ((T_IS_NOT_EQUAL) reduce 36) ((T_IS_NOT_IDENTICAL) reduce 36) ((T_IS_SMALLER_OR_EQUAL) reduce 36) ((T_LOGICAL_AND) reduce 36) ((T_LOGICAL_OR) reduce 36) ((T_LOGICAL_XOR) reduce 36) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 36) ((T_OBJECT_OPERATOR) reduce 36) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 36) ((T_POW) reduce 36) ((T_SL) reduce 36) ((T_SPACESHIP) reduce 36) ((T_SR) reduce 36) (("[") reduce 36) (("^") reduce 36) (("{") reduce 36) (("|") reduce 36)) 21998 ((("%") reduce 32) (("(") reduce 32) (("*") reduce 32) (("+") reduce 32) (("-") reduce 32) ((".") reduce 32) (("/") reduce 32) ((":") reduce 32) ((";") reduce 32) (("<") reduce 32) ((">") reduce 32) (("?") reduce 32) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_BOOLEAN_AND) reduce 32) ((T_BOOLEAN_OR) reduce 32) ((T_COALESCE) reduce 32) ((T_INSTANCEOF) reduce 32) ((T_IS_EQUAL) reduce 32) ((T_IS_GREATER_OR_EQUAL) reduce 32) ((T_IS_IDENTICAL) reduce 32) ((T_IS_NOT_EQUAL) reduce 32) ((T_IS_NOT_IDENTICAL) reduce 32) ((T_IS_SMALLER_OR_EQUAL) reduce 32) ((T_LOGICAL_AND) reduce 32) ((T_LOGICAL_OR) reduce 32) ((T_LOGICAL_XOR) reduce 32) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 32) ((T_OBJECT_OPERATOR) reduce 32) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 32) ((T_POW) reduce 32) ((T_SL) reduce 32) ((T_SPACESHIP) reduce 32) ((T_SR) reduce 32) (("[") reduce 32) (("^") reduce 32) (("{") reduce 32) (("|") reduce 32)) 21999 ((("%") reduce 35) (("(") reduce 35) (("*") reduce 35) (("+") reduce 35) (("-") reduce 35) ((".") reduce 35) (("/") reduce 35) ((":") reduce 35) ((";") reduce 35) (("<") reduce 35) ((">") reduce 35) (("?") reduce 35) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_BOOLEAN_AND) reduce 35) ((T_BOOLEAN_OR) reduce 35) ((T_COALESCE) reduce 35) ((T_INSTANCEOF) reduce 35) ((T_IS_EQUAL) reduce 35) ((T_IS_GREATER_OR_EQUAL) reduce 35) ((T_IS_IDENTICAL) reduce 35) ((T_IS_NOT_EQUAL) reduce 35) ((T_IS_NOT_IDENTICAL) reduce 35) ((T_IS_SMALLER_OR_EQUAL) reduce 35) ((T_LOGICAL_AND) reduce 35) ((T_LOGICAL_OR) reduce 35) ((T_LOGICAL_XOR) reduce 35) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 35) ((T_OBJECT_OPERATOR) reduce 35) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 35) ((T_POW) reduce 35) ((T_SL) reduce 35) ((T_SPACESHIP) reduce 35) ((T_SR) reduce 35) (("[") reduce 35) (("^") reduce 35) (("{") reduce 35) (("|") reduce 35)) 22000 ((("%") reduce 19) (("(") reduce 19) (("*") reduce 19) (("+") reduce 19) (("-") reduce 19) ((".") reduce 19) (("/") reduce 19) ((":") reduce 19) ((";") reduce 19) (("<") reduce 19) ((">") reduce 19) (("?") reduce 19) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_BOOLEAN_AND) reduce 19) ((T_BOOLEAN_OR) reduce 19) ((T_COALESCE) reduce 19) ((T_INSTANCEOF) reduce 19) ((T_IS_EQUAL) reduce 19) ((T_IS_GREATER_OR_EQUAL) reduce 19) ((T_IS_IDENTICAL) reduce 19) ((T_IS_NOT_EQUAL) reduce 19) ((T_IS_NOT_IDENTICAL) reduce 19) ((T_IS_SMALLER_OR_EQUAL) reduce 19) ((T_LOGICAL_AND) reduce 19) ((T_LOGICAL_OR) reduce 19) ((T_LOGICAL_XOR) reduce 19) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 19) ((T_OBJECT_OPERATOR) reduce 19) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 19) ((T_POW) reduce 19) ((T_SL) reduce 19) ((T_SPACESHIP) reduce 19) ((T_SR) reduce 19) (("[") reduce 19) (("^") reduce 19) (("{") reduce 19) (("|") reduce 19)) 22001 ((("%") reduce 45) (("(") reduce 45) (("*") reduce 45) (("+") reduce 45) (("-") reduce 45) ((".") reduce 45) (("/") reduce 45) ((":") reduce 45) ((";") reduce 45) (("<") reduce 45) ((">") reduce 45) (("?") reduce 45) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_BOOLEAN_AND) reduce 45) ((T_BOOLEAN_OR) reduce 45) ((T_COALESCE) reduce 45) ((T_INSTANCEOF) reduce 45) ((T_IS_EQUAL) reduce 45) ((T_IS_GREATER_OR_EQUAL) reduce 45) ((T_IS_IDENTICAL) reduce 45) ((T_IS_NOT_EQUAL) reduce 45) ((T_IS_NOT_IDENTICAL) reduce 45) ((T_IS_SMALLER_OR_EQUAL) reduce 45) ((T_LOGICAL_AND) reduce 45) ((T_LOGICAL_OR) reduce 45) ((T_LOGICAL_XOR) reduce 45) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 45) ((T_OBJECT_OPERATOR) reduce 45) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 45) ((T_POW) reduce 45) ((T_SL) reduce 45) ((T_SPACESHIP) reduce 45) ((T_SR) reduce 45) (("[") reduce 45) (("^") reduce 45) (("{") reduce 45) (("|") reduce 45)) 22002 ((("%") reduce 504) (("(") reduce 541) (("*") reduce 504) (("+") reduce 504) (("-") reduce 504) ((".") reduce 504) (("/") reduce 504) ((":") reduce 504) ((";") reduce 504) (("<") reduce 504) ((">") reduce 504) (("?") reduce 504) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_BOOLEAN_AND) reduce 504) ((T_BOOLEAN_OR) reduce 504) ((T_COALESCE) reduce 504) ((T_INSTANCEOF) reduce 504) ((T_IS_EQUAL) reduce 504) ((T_IS_GREATER_OR_EQUAL) reduce 504) ((T_IS_IDENTICAL) reduce 504) ((T_IS_NOT_EQUAL) reduce 504) ((T_IS_NOT_IDENTICAL) reduce 504) ((T_IS_SMALLER_OR_EQUAL) reduce 504) ((T_LOGICAL_AND) reduce 504) ((T_LOGICAL_OR) reduce 504) ((T_LOGICAL_XOR) reduce 504) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 504) ((T_OBJECT_OPERATOR) reduce 504) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 504) ((T_POW) reduce 504) ((T_SL) reduce 504) ((T_SPACESHIP) reduce 504) ((T_SR) reduce 504) (("[") reduce 504) (("^") reduce 504) (("{") reduce 504) (("|") reduce 504)) 22004 ((("%") reduce 71) (("(") reduce 71) (("*") reduce 71) (("+") reduce 71) (("-") reduce 71) ((".") reduce 71) (("/") reduce 71) ((":") reduce 71) ((";") reduce 71) (("<") reduce 71) ((">") reduce 71) (("?") reduce 71) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_BOOLEAN_AND) reduce 71) ((T_BOOLEAN_OR) reduce 71) ((T_COALESCE) reduce 71) ((T_INSTANCEOF) reduce 71) ((T_IS_EQUAL) reduce 71) ((T_IS_GREATER_OR_EQUAL) reduce 71) ((T_IS_IDENTICAL) reduce 71) ((T_IS_NOT_EQUAL) reduce 71) ((T_IS_NOT_IDENTICAL) reduce 71) ((T_IS_SMALLER_OR_EQUAL) reduce 71) ((T_LOGICAL_AND) reduce 71) ((T_LOGICAL_OR) reduce 71) ((T_LOGICAL_XOR) reduce 71) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 71) ((T_OBJECT_OPERATOR) reduce 71) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 71) ((T_POW) reduce 71) ((T_SL) reduce 71) ((T_SPACESHIP) reduce 71) ((T_SR) reduce 71) (("[") reduce 71) (("^") reduce 71) (("{") reduce 71) (("|") reduce 71)) 22005 ((("%") reduce 82) (("(") reduce 82) (("*") reduce 82) (("+") reduce 82) (("-") reduce 82) ((".") reduce 82) (("/") reduce 82) ((":") reduce 82) ((";") reduce 82) (("<") reduce 82) ((">") reduce 82) (("?") reduce 82) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_BOOLEAN_AND) reduce 82) ((T_BOOLEAN_OR) reduce 82) ((T_COALESCE) reduce 82) ((T_INSTANCEOF) reduce 82) ((T_IS_EQUAL) reduce 82) ((T_IS_GREATER_OR_EQUAL) reduce 82) ((T_IS_IDENTICAL) reduce 82) ((T_IS_NOT_EQUAL) reduce 82) ((T_IS_NOT_IDENTICAL) reduce 82) ((T_IS_SMALLER_OR_EQUAL) reduce 82) ((T_LOGICAL_AND) reduce 82) ((T_LOGICAL_OR) reduce 82) ((T_LOGICAL_XOR) reduce 82) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 82) ((T_OBJECT_OPERATOR) reduce 82) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 82) ((T_POW) reduce 82) ((T_SL) reduce 82) ((T_SPACESHIP) reduce 82) ((T_SR) reduce 82) (("[") reduce 82) (("^") reduce 82) (("{") reduce 82) (("|") reduce 82)) 22006 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) ((":") reduce 533) ((";") reduce 533) (("<") reduce 533) (("=") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AND_EQUAL) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_COALESCE_EQUAL) reduce 533) ((T_CONCAT_EQUAL) reduce 533) ((T_DEC) reduce 533) ((T_DIV_EQUAL) reduce 533) ((T_INC) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_MINUS_EQUAL) reduce 533) ((T_MOD_EQUAL) reduce 533) ((T_MUL_EQUAL) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_OR_EQUAL) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_PLUS_EQUAL) reduce 533) ((T_POW) reduce 533) ((T_POW_EQUAL) reduce 533) ((T_SL) reduce 533) ((T_SL_EQUAL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) ((T_SR_EQUAL) reduce 533) ((T_XOR_EQUAL) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 22009 ((("%") reduce 506) (("(") reduce 542) (("*") reduce 506) (("+") reduce 506) (("-") reduce 506) ((".") reduce 506) (("/") reduce 506) ((":") reduce 506) ((";") reduce 506) (("<") reduce 506) ((">") reduce 506) (("?") reduce 506) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_BOOLEAN_AND) reduce 506) ((T_BOOLEAN_OR) reduce 506) ((T_COALESCE) reduce 506) ((T_INSTANCEOF) reduce 506) ((T_IS_EQUAL) reduce 506) ((T_IS_GREATER_OR_EQUAL) reduce 506) ((T_IS_IDENTICAL) reduce 506) ((T_IS_NOT_EQUAL) reduce 506) ((T_IS_NOT_IDENTICAL) reduce 506) ((T_IS_SMALLER_OR_EQUAL) reduce 506) ((T_LOGICAL_AND) reduce 506) ((T_LOGICAL_OR) reduce 506) ((T_LOGICAL_XOR) reduce 506) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 506) ((T_OBJECT_OPERATOR) reduce 506) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 506) ((T_POW) reduce 506) ((T_SL) reduce 506) ((T_SPACESHIP) reduce 506) ((T_SR) reduce 506) (("[") reduce 506) (("^") reduce 506) (("{") reduce 506) (("|") reduce 506)) 22011 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) ((":") reduce 468) ((";") reduce 468) (("<") reduce 468) (("=") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AND_EQUAL) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_COALESCE_EQUAL) reduce 468) ((T_CONCAT_EQUAL) reduce 468) ((T_DEC) reduce 468) ((T_DIV_EQUAL) reduce 468) ((T_INC) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_MINUS_EQUAL) reduce 468) ((T_MOD_EQUAL) reduce 468) ((T_MUL_EQUAL) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_OR_EQUAL) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_PLUS_EQUAL) reduce 468) ((T_POW) reduce 468) ((T_POW_EQUAL) reduce 468) ((T_SL) reduce 468) ((T_SL_EQUAL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) ((T_SR_EQUAL) reduce 468) ((T_XOR_EQUAL) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 22012 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) ((":") reduce 288) ((";") reduce 288) (("<") reduce 288) (("=") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AND_EQUAL) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_COALESCE_EQUAL) reduce 288) ((T_CONCAT_EQUAL) reduce 288) ((T_DEC) reduce 288) ((T_DIV_EQUAL) reduce 288) ((T_INC) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_MINUS_EQUAL) reduce 288) ((T_MOD_EQUAL) reduce 288) ((T_MUL_EQUAL) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_OR_EQUAL) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_PLUS_EQUAL) reduce 288) ((T_POW) reduce 288) ((T_POW_EQUAL) reduce 288) ((T_SL) reduce 288) ((T_SL_EQUAL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) ((T_SR_EQUAL) reduce 288) ((T_XOR_EQUAL) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 22016 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) ((":") reduce 289) ((";") reduce 289) (("<") reduce 289) (("=") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AND_EQUAL) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_COALESCE_EQUAL) reduce 289) ((T_CONCAT_EQUAL) reduce 289) ((T_DEC) reduce 289) ((T_DIV_EQUAL) reduce 289) ((T_INC) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_MINUS_EQUAL) reduce 289) ((T_MOD_EQUAL) reduce 289) ((T_MUL_EQUAL) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_OR_EQUAL) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_PLUS_EQUAL) reduce 289) ((T_POW) reduce 289) ((T_POW_EQUAL) reduce 289) ((T_SL) reduce 289) ((T_SL_EQUAL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) ((T_SR_EQUAL) reduce 289) ((T_XOR_EQUAL) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 22017 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) ((":") reduce 290) ((";") reduce 290) (("<") reduce 290) (("=") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AND_EQUAL) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_COALESCE_EQUAL) reduce 290) ((T_CONCAT_EQUAL) reduce 290) ((T_DEC) reduce 290) ((T_DIV_EQUAL) reduce 290) ((T_INC) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_MINUS_EQUAL) reduce 290) ((T_MOD_EQUAL) reduce 290) ((T_MUL_EQUAL) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_OR_EQUAL) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_PLUS_EQUAL) reduce 290) ((T_POW) reduce 290) ((T_POW_EQUAL) reduce 290) ((T_SL) reduce 290) ((T_SL_EQUAL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) ((T_SR_EQUAL) reduce 290) ((T_XOR_EQUAL) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 22022 ((("%") reduce 388) (("*") reduce 388) (("+") reduce 388) (("-") reduce 388) ((".") reduce 388) (("/") reduce 388) ((":") reduce 388) ((";") reduce 388) (("<") reduce 388) ((">") reduce 388) (("?") reduce 388) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_BOOLEAN_AND) reduce 388) ((T_BOOLEAN_OR) reduce 388) ((T_COALESCE) reduce 388) ((T_INSTANCEOF) reduce 388) ((T_IS_EQUAL) reduce 388) ((T_IS_GREATER_OR_EQUAL) reduce 388) ((T_IS_IDENTICAL) reduce 388) ((T_IS_NOT_EQUAL) reduce 388) ((T_IS_NOT_IDENTICAL) reduce 388) ((T_IS_SMALLER_OR_EQUAL) reduce 388) ((T_LOGICAL_AND) reduce 388) ((T_LOGICAL_OR) reduce 388) ((T_LOGICAL_XOR) reduce 388) ((T_POW) reduce 388) ((T_SL) reduce 388) ((T_SPACESHIP) reduce 388) ((T_SR) reduce 388) (("^") reduce 388) (("|") reduce 388)) 22024 ((("%") reduce 386) (("*") reduce 386) (("+") reduce 386) (("-") reduce 386) ((".") reduce 386) (("/") reduce 386) ((":") reduce 386) ((";") reduce 386) (("<") reduce 386) ((">") reduce 386) (("?") reduce 386) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_BOOLEAN_AND) reduce 386) ((T_BOOLEAN_OR) reduce 386) ((T_COALESCE) reduce 386) ((T_INSTANCEOF) reduce 386) ((T_IS_EQUAL) reduce 386) ((T_IS_GREATER_OR_EQUAL) reduce 386) ((T_IS_IDENTICAL) reduce 386) ((T_IS_NOT_EQUAL) reduce 386) ((T_IS_NOT_IDENTICAL) reduce 386) ((T_IS_SMALLER_OR_EQUAL) reduce 386) ((T_LOGICAL_AND) reduce 386) ((T_LOGICAL_OR) reduce 386) ((T_LOGICAL_XOR) reduce 386) ((T_POW) reduce 386) ((T_SL) reduce 386) ((T_SPACESHIP) reduce 386) ((T_SR) reduce 386) (("^") reduce 386) (("|") reduce 386)) 22034 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 382) ((";") reduce 382) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 382) ((T_LOGICAL_OR) reduce 382) ((T_LOGICAL_XOR) reduce 382) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22035 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 384) ((";") reduce 384) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 384) ((T_LOGICAL_OR) reduce 384) ((T_LOGICAL_XOR) reduce 384) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22036 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 383) ((";") reduce 383) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 383) ((T_LOGICAL_OR) reduce 383) ((T_LOGICAL_XOR) reduce 383) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22037 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 376) ((";") reduce 376) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 376) ((T_LOGICAL_OR) reduce 376) ((T_LOGICAL_XOR) reduce 376) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22038 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 373) ((";") reduce 373) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 373) ((T_LOGICAL_OR) reduce 373) ((T_LOGICAL_XOR) reduce 373) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22039 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 381) ((";") reduce 381) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 381) ((T_LOGICAL_OR) reduce 381) ((T_LOGICAL_XOR) reduce 381) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22040 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 375) ((";") reduce 375) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 375) ((T_LOGICAL_OR) reduce 375) ((T_LOGICAL_XOR) reduce 375) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22041 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 379) ((";") reduce 379) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 379) ((T_LOGICAL_OR) reduce 379) ((T_LOGICAL_XOR) reduce 379) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22042 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 374) ((";") reduce 374) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 374) ((T_LOGICAL_OR) reduce 374) ((T_LOGICAL_XOR) reduce 374) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22043 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 377) ((";") reduce 377) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 377) ((T_LOGICAL_OR) reduce 377) ((T_LOGICAL_XOR) reduce 377) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22044 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 378) ((";") reduce 378) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 378) ((T_LOGICAL_OR) reduce 378) ((T_LOGICAL_XOR) reduce 378) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22045 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 385) ((";") reduce 385) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 385) ((T_LOGICAL_OR) reduce 385) ((T_LOGICAL_XOR) reduce 385) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22046 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 380) ((";") reduce 380) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 380) ((T_LOGICAL_OR) reduce 380) ((T_LOGICAL_XOR) reduce 380) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22048 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 370) ((";") reduce 370) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 370) ((T_LOGICAL_OR) reduce 370) ((T_LOGICAL_XOR) reduce 370) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22051 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) ((":") reduce 529) ((";") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 22054 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) ((":") reduce 525) ((";") reduce 525) (("<") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_POW) reduce 525) ((T_SL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 22056 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) ((":") reduce 524) ((";") reduce 524) (("<") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_POW) reduce 524) ((T_SL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 22058 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) ((":") reduce 519) ((";") reduce 519) (("<") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_POW) reduce 519) ((T_SL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 22059 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) ((":") reduce 526) ((";") reduce 526) (("<") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_POW) reduce 526) ((T_SL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 22060 ((("%") reduce 371) (("*") reduce 371) (("+") reduce 371) (("-") reduce 371) ((".") reduce 371) (("/") reduce 371) ((":") reduce 371) ((";") reduce 371) (("<") reduce 371) ((">") reduce 371) (("?") reduce 371) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_BOOLEAN_AND) reduce 371) ((T_BOOLEAN_OR) reduce 371) ((T_COALESCE) reduce 371) ((T_INSTANCEOF) reduce 371) ((T_IS_EQUAL) reduce 371) ((T_IS_GREATER_OR_EQUAL) reduce 371) ((T_IS_IDENTICAL) reduce 371) ((T_IS_NOT_EQUAL) reduce 371) ((T_IS_NOT_IDENTICAL) reduce 371) ((T_IS_SMALLER_OR_EQUAL) reduce 371) ((T_LOGICAL_AND) reduce 371) ((T_LOGICAL_OR) reduce 371) ((T_LOGICAL_XOR) reduce 371) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 371) ((T_SL) reduce 371) ((T_SPACESHIP) reduce 371) ((T_SR) reduce 371) (("[") reduce 510) (("^") reduce 371) (("{") reduce 510) (("|") reduce 371)) 22064 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) ((":") reduce 533) ((";") reduce 533) (("<") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_POW) reduce 533) ((T_SL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 22066 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) ((":") reduce 468) ((";") reduce 468) (("<") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_POW) reduce 468) ((T_SL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 22067 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) ((":") reduce 288) ((";") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 22071 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) ((":") reduce 289) ((";") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 22072 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) ((":") reduce 290) ((";") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 22073 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) ((":") reduce 465) ((";") reduce 465) (("<") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_POW) reduce 465) ((T_SL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 22076 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) ((":") reduce 532) ((";") reduce 532) (("<") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_POW) reduce 532) ((T_SL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 22077 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) ((":") reduce 467) ((";") reduce 467) (("<") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_POW) reduce 467) ((T_SL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 22078 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) ((":") reduce 469) ((";") reduce 469) (("<") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_POW) reduce 469) ((T_SL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 22084 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) ((":") reduce 521) ((";") reduce 521) (("<") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_POW) reduce 521) ((T_SL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 22086 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) ((":") reduce 520) ((";") reduce 520) (("<") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_POW) reduce 520) ((T_SL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 22087 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) ((":") reduce 544) ((";") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 22088 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) ((":") reduce 527) ((";") reduce 527) (("<") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_POW) reduce 527) ((T_SL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 22089 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) ((":") reduce 546) ((";") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 22092 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) ((":") reduce 545) ((";") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 22093 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) ((":") reduce 522) ((";") reduce 522) (("<") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_POW) reduce 522) ((T_SL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 22094 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) ((":") reduce 528) ((";") reduce 528) (("<") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_POW) reduce 528) ((T_SL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 22095 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) ((":") reduce 523) ((";") reduce 523) (("<") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_POW) reduce 523) ((T_SL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 22096 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) ((":") reduce 466) ((";") reduce 466) (("<") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_POW) reduce 466) ((T_SL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 22097 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) ((":") reduce 531) ((";") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 22100 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) ((":") reduce 530) ((";") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 22101 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) ((":") reduce 465) ((";") reduce 465) (("<") reduce 465) (("=") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AND_EQUAL) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_COALESCE_EQUAL) reduce 465) ((T_CONCAT_EQUAL) reduce 465) ((T_DEC) reduce 465) ((T_DIV_EQUAL) reduce 465) ((T_INC) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_MINUS_EQUAL) reduce 465) ((T_MOD_EQUAL) reduce 465) ((T_MUL_EQUAL) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_OR_EQUAL) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_PLUS_EQUAL) reduce 465) ((T_POW) reduce 465) ((T_POW_EQUAL) reduce 465) ((T_SL) reduce 465) ((T_SL_EQUAL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) ((T_SR_EQUAL) reduce 465) ((T_XOR_EQUAL) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 22112 ((("%") reduce 455) (("*") reduce 455) (("+") reduce 455) (("-") reduce 455) ((".") reduce 455) (("/") reduce 455) ((":") reduce 455) ((";") reduce 455) (("<") reduce 455) ((">") reduce 455) (("?") reduce 455) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_BOOLEAN_AND) reduce 455) ((T_BOOLEAN_OR) reduce 455) ((T_COALESCE) reduce 455) ((T_INSTANCEOF) reduce 455) ((T_IS_EQUAL) reduce 455) ((T_IS_GREATER_OR_EQUAL) reduce 455) ((T_IS_IDENTICAL) reduce 455) ((T_IS_NOT_EQUAL) reduce 455) ((T_IS_NOT_IDENTICAL) reduce 455) ((T_IS_SMALLER_OR_EQUAL) reduce 455) ((T_LOGICAL_AND) reduce 455) ((T_LOGICAL_OR) reduce 455) ((T_LOGICAL_XOR) reduce 455) ((T_POW) reduce 455) ((T_SL) reduce 455) ((T_SPACESHIP) reduce 455) ((T_SR) reduce 455) (("^") reduce 455) (("|") reduce 455)) 22113 ((("%") reduce 450) (("*") reduce 450) (("+") reduce 450) (("-") reduce 450) ((".") reduce 450) (("/") reduce 450) ((":") reduce 450) ((";") reduce 450) (("<") reduce 450) ((">") reduce 450) (("?") reduce 450) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_BOOLEAN_AND) reduce 450) ((T_BOOLEAN_OR) reduce 450) ((T_COALESCE) reduce 450) ((T_INSTANCEOF) reduce 450) ((T_IS_EQUAL) reduce 450) ((T_IS_GREATER_OR_EQUAL) reduce 450) ((T_IS_IDENTICAL) reduce 450) ((T_IS_NOT_EQUAL) reduce 450) ((T_IS_NOT_IDENTICAL) reduce 450) ((T_IS_SMALLER_OR_EQUAL) reduce 450) ((T_LOGICAL_AND) reduce 450) ((T_LOGICAL_OR) reduce 450) ((T_LOGICAL_XOR) reduce 450) ((T_POW) reduce 450) ((T_SL) reduce 450) ((T_SPACESHIP) reduce 450) ((T_SR) reduce 450) (("^") reduce 450) (("|") reduce 450)) 22185 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 455) ((";") reduce 455) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22503 ((("%") reduce 451) (("*") reduce 451) (("+") reduce 451) (("-") reduce 451) ((".") reduce 451) (("/") reduce 451) ((":") reduce 451) ((";") reduce 451) (("<") reduce 451) ((">") reduce 451) (("?") reduce 451) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_BOOLEAN_AND) reduce 451) ((T_BOOLEAN_OR) reduce 451) ((T_COALESCE) reduce 451) ((T_INSTANCEOF) reduce 451) ((T_IS_EQUAL) reduce 451) ((T_IS_GREATER_OR_EQUAL) reduce 451) ((T_IS_IDENTICAL) reduce 451) ((T_IS_NOT_EQUAL) reduce 451) ((T_IS_NOT_IDENTICAL) reduce 451) ((T_IS_SMALLER_OR_EQUAL) reduce 451) ((T_LOGICAL_AND) reduce 451) ((T_LOGICAL_OR) reduce 451) ((T_LOGICAL_XOR) reduce 451) ((T_POW) reduce 451) ((T_SL) reduce 451) ((T_SPACESHIP) reduce 451) ((T_SR) reduce 451) (("^") reduce 451) (("|") reduce 451)) 22506 ((("%") reduce 503) (("(") reduce 541) (("*") reduce 503) (("+") reduce 503) (("-") reduce 503) ((".") reduce 503) (("/") reduce 503) ((":") reduce 503) ((";") reduce 503) (("<") reduce 503) ((">") reduce 503) (("?") reduce 503) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_BOOLEAN_AND) reduce 503) ((T_BOOLEAN_OR) reduce 503) ((T_COALESCE) reduce 503) ((T_INSTANCEOF) reduce 503) ((T_IS_EQUAL) reduce 503) ((T_IS_GREATER_OR_EQUAL) reduce 503) ((T_IS_IDENTICAL) reduce 503) ((T_IS_NOT_EQUAL) reduce 503) ((T_IS_NOT_IDENTICAL) reduce 503) ((T_IS_SMALLER_OR_EQUAL) reduce 503) ((T_LOGICAL_AND) reduce 503) ((T_LOGICAL_OR) reduce 503) ((T_LOGICAL_XOR) reduce 503) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 503) ((T_OBJECT_OPERATOR) reduce 503) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 503) ((T_POW) reduce 503) ((T_SL) reduce 503) ((T_SPACESHIP) reduce 503) ((T_SR) reduce 503) (("[") reduce 503) (("^") reduce 503) (("{") reduce 503) (("|") reduce 503)) 22508 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) ((":") reduce 532) ((";") reduce 532) (("<") reduce 532) (("=") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AND_EQUAL) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_COALESCE_EQUAL) reduce 532) ((T_CONCAT_EQUAL) reduce 532) ((T_DEC) reduce 532) ((T_DIV_EQUAL) reduce 532) ((T_INC) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_MINUS_EQUAL) reduce 532) ((T_MOD_EQUAL) reduce 532) ((T_MUL_EQUAL) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_OR_EQUAL) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_PLUS_EQUAL) reduce 532) ((T_POW) reduce 532) ((T_POW_EQUAL) reduce 532) ((T_SL) reduce 532) ((T_SL_EQUAL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) ((T_SR_EQUAL) reduce 532) ((T_XOR_EQUAL) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 22511 ((("%") reduce 505) (("(") reduce 542) (("*") reduce 505) (("+") reduce 505) (("-") reduce 505) ((".") reduce 505) (("/") reduce 505) ((":") reduce 505) ((";") reduce 505) (("<") reduce 505) ((">") reduce 505) (("?") reduce 505) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_BOOLEAN_AND) reduce 505) ((T_BOOLEAN_OR) reduce 505) ((T_COALESCE) reduce 505) ((T_INSTANCEOF) reduce 505) ((T_IS_EQUAL) reduce 505) ((T_IS_GREATER_OR_EQUAL) reduce 505) ((T_IS_IDENTICAL) reduce 505) ((T_IS_NOT_EQUAL) reduce 505) ((T_IS_NOT_IDENTICAL) reduce 505) ((T_IS_SMALLER_OR_EQUAL) reduce 505) ((T_LOGICAL_AND) reduce 505) ((T_LOGICAL_OR) reduce 505) ((T_LOGICAL_XOR) reduce 505) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 505) ((T_OBJECT_OPERATOR) reduce 505) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 505) ((T_POW) reduce 505) ((T_SL) reduce 505) ((T_SPACESHIP) reduce 505) ((T_SR) reduce 505) (("[") reduce 505) (("^") reduce 505) (("{") reduce 505) (("|") reduce 505)) 22512 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) ((":") reduce 467) ((";") reduce 467) (("<") reduce 467) (("=") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AND_EQUAL) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_COALESCE_EQUAL) reduce 467) ((T_CONCAT_EQUAL) reduce 467) ((T_DEC) reduce 467) ((T_DIV_EQUAL) reduce 467) ((T_INC) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_MINUS_EQUAL) reduce 467) ((T_MOD_EQUAL) reduce 467) ((T_MUL_EQUAL) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_OR_EQUAL) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_PLUS_EQUAL) reduce 467) ((T_POW) reduce 467) ((T_POW_EQUAL) reduce 467) ((T_SL) reduce 467) ((T_SL_EQUAL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) ((T_SR_EQUAL) reduce 467) ((T_XOR_EQUAL) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 22513 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) ((":") reduce 469) ((";") reduce 469) (("<") reduce 469) (("=") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AND_EQUAL) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_COALESCE_EQUAL) reduce 469) ((T_CONCAT_EQUAL) reduce 469) ((T_DEC) reduce 469) ((T_DIV_EQUAL) reduce 469) ((T_INC) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_MINUS_EQUAL) reduce 469) ((T_MOD_EQUAL) reduce 469) ((T_MUL_EQUAL) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_OR_EQUAL) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_PLUS_EQUAL) reduce 469) ((T_POW) reduce 469) ((T_POW_EQUAL) reduce 469) ((T_SL) reduce 469) ((T_SL_EQUAL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) ((T_SR_EQUAL) reduce 469) ((T_XOR_EQUAL) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 22515 ((("%") reduce 446) (("*") reduce 446) (("+") reduce 446) (("-") reduce 446) ((".") reduce 446) (("/") reduce 446) ((":") reduce 446) ((";") reduce 446) (("<") reduce 446) ((">") reduce 446) (("?") reduce 446) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_BOOLEAN_AND) reduce 446) ((T_BOOLEAN_OR) reduce 446) ((T_COALESCE) reduce 446) ((T_INSTANCEOF) reduce 446) ((T_IS_EQUAL) reduce 446) ((T_IS_GREATER_OR_EQUAL) reduce 446) ((T_IS_IDENTICAL) reduce 446) ((T_IS_NOT_EQUAL) reduce 446) ((T_IS_NOT_IDENTICAL) reduce 446) ((T_IS_SMALLER_OR_EQUAL) reduce 446) ((T_LOGICAL_AND) reduce 446) ((T_LOGICAL_OR) reduce 446) ((T_LOGICAL_XOR) reduce 446) ((T_POW) reduce 446) ((T_SL) reduce 446) ((T_SPACESHIP) reduce 446) ((T_SR) reduce 446) (("^") reduce 446) (("|") reduce 446)) 22516 ((("%") reduce 448) (("*") reduce 448) (("+") reduce 448) (("-") reduce 448) ((".") reduce 448) (("/") reduce 448) ((":") reduce 448) ((";") reduce 448) (("<") reduce 448) ((">") reduce 448) (("?") reduce 448) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_BOOLEAN_AND) reduce 448) ((T_BOOLEAN_OR) reduce 448) ((T_COALESCE) reduce 448) ((T_INSTANCEOF) reduce 448) ((T_IS_EQUAL) reduce 448) ((T_IS_GREATER_OR_EQUAL) reduce 448) ((T_IS_IDENTICAL) reduce 448) ((T_IS_NOT_EQUAL) reduce 448) ((T_IS_NOT_IDENTICAL) reduce 448) ((T_IS_SMALLER_OR_EQUAL) reduce 448) ((T_LOGICAL_AND) reduce 448) ((T_LOGICAL_OR) reduce 448) ((T_LOGICAL_XOR) reduce 448) ((T_POW) reduce 448) ((T_SL) reduce 448) ((T_SPACESHIP) reduce 448) ((T_SR) reduce 448) (("^") reduce 448) (("|") reduce 448)) 22522 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) ((":") reduce 521) ((";") reduce 521) (("<") reduce 521) (("=") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AND_EQUAL) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_COALESCE_EQUAL) reduce 521) ((T_CONCAT_EQUAL) reduce 521) ((T_DEC) reduce 521) ((T_DIV_EQUAL) reduce 521) ((T_INC) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_MINUS_EQUAL) reduce 521) ((T_MOD_EQUAL) reduce 521) ((T_MUL_EQUAL) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_OR_EQUAL) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_PLUS_EQUAL) reduce 521) ((T_POW) reduce 521) ((T_POW_EQUAL) reduce 521) ((T_SL) reduce 521) ((T_SL_EQUAL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) ((T_SR_EQUAL) reduce 521) ((T_XOR_EQUAL) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 22524 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) ((":") reduce 520) ((";") reduce 520) (("<") reduce 520) (("=") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AND_EQUAL) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_COALESCE_EQUAL) reduce 520) ((T_CONCAT_EQUAL) reduce 520) ((T_DEC) reduce 520) ((T_DIV_EQUAL) reduce 520) ((T_INC) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_MINUS_EQUAL) reduce 520) ((T_MOD_EQUAL) reduce 520) ((T_MUL_EQUAL) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_OR_EQUAL) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_PLUS_EQUAL) reduce 520) ((T_POW) reduce 520) ((T_POW_EQUAL) reduce 520) ((T_SL) reduce 520) ((T_SL_EQUAL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) ((T_SR_EQUAL) reduce 520) ((T_XOR_EQUAL) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 22525 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) ((":") reduce 544) ((";") reduce 544) (("<") reduce 544) (("=") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AND_EQUAL) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_COALESCE_EQUAL) reduce 544) ((T_CONCAT_EQUAL) reduce 544) ((T_DEC) reduce 544) ((T_DIV_EQUAL) reduce 544) ((T_INC) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_MINUS_EQUAL) reduce 544) ((T_MOD_EQUAL) reduce 544) ((T_MUL_EQUAL) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_OR_EQUAL) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_PLUS_EQUAL) reduce 544) ((T_POW) reduce 544) ((T_POW_EQUAL) reduce 544) ((T_SL) reduce 544) ((T_SL_EQUAL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) ((T_SR_EQUAL) reduce 544) ((T_XOR_EQUAL) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 22526 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) ((":") reduce 527) ((";") reduce 527) (("<") reduce 527) (("=") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AND_EQUAL) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_COALESCE_EQUAL) reduce 527) ((T_CONCAT_EQUAL) reduce 527) ((T_DEC) reduce 527) ((T_DIV_EQUAL) reduce 527) ((T_INC) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_MINUS_EQUAL) reduce 527) ((T_MOD_EQUAL) reduce 527) ((T_MUL_EQUAL) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_OR_EQUAL) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_PLUS_EQUAL) reduce 527) ((T_POW) reduce 527) ((T_POW_EQUAL) reduce 527) ((T_SL) reduce 527) ((T_SL_EQUAL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) ((T_SR_EQUAL) reduce 527) ((T_XOR_EQUAL) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 22527 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) ((":") reduce 546) ((";") reduce 546) (("<") reduce 546) (("=") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AND_EQUAL) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_COALESCE_EQUAL) reduce 546) ((T_CONCAT_EQUAL) reduce 546) ((T_DEC) reduce 546) ((T_DIV_EQUAL) reduce 546) ((T_INC) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_MINUS_EQUAL) reduce 546) ((T_MOD_EQUAL) reduce 546) ((T_MUL_EQUAL) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_OR_EQUAL) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_PLUS_EQUAL) reduce 546) ((T_POW) reduce 546) ((T_POW_EQUAL) reduce 546) ((T_SL) reduce 546) ((T_SL_EQUAL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) ((T_SR_EQUAL) reduce 546) ((T_XOR_EQUAL) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 22530 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) ((":") reduce 545) ((";") reduce 545) (("<") reduce 545) (("=") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AND_EQUAL) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_COALESCE_EQUAL) reduce 545) ((T_CONCAT_EQUAL) reduce 545) ((T_DEC) reduce 545) ((T_DIV_EQUAL) reduce 545) ((T_INC) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_MINUS_EQUAL) reduce 545) ((T_MOD_EQUAL) reduce 545) ((T_MUL_EQUAL) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_OR_EQUAL) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_PLUS_EQUAL) reduce 545) ((T_POW) reduce 545) ((T_POW_EQUAL) reduce 545) ((T_SL) reduce 545) ((T_SL_EQUAL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) ((T_SR_EQUAL) reduce 545) ((T_XOR_EQUAL) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 22531 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) ((":") reduce 522) ((";") reduce 522) (("<") reduce 522) (("=") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AND_EQUAL) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_COALESCE_EQUAL) reduce 522) ((T_CONCAT_EQUAL) reduce 522) ((T_DEC) reduce 522) ((T_DIV_EQUAL) reduce 522) ((T_INC) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_MINUS_EQUAL) reduce 522) ((T_MOD_EQUAL) reduce 522) ((T_MUL_EQUAL) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_OR_EQUAL) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_PLUS_EQUAL) reduce 522) ((T_POW) reduce 522) ((T_POW_EQUAL) reduce 522) ((T_SL) reduce 522) ((T_SL_EQUAL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) ((T_SR_EQUAL) reduce 522) ((T_XOR_EQUAL) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 22532 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) ((":") reduce 528) ((";") reduce 528) (("<") reduce 528) (("=") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AND_EQUAL) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_COALESCE_EQUAL) reduce 528) ((T_CONCAT_EQUAL) reduce 528) ((T_DEC) reduce 528) ((T_DIV_EQUAL) reduce 528) ((T_INC) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_MINUS_EQUAL) reduce 528) ((T_MOD_EQUAL) reduce 528) ((T_MUL_EQUAL) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_OR_EQUAL) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_PLUS_EQUAL) reduce 528) ((T_POW) reduce 528) ((T_POW_EQUAL) reduce 528) ((T_SL) reduce 528) ((T_SL_EQUAL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) ((T_SR_EQUAL) reduce 528) ((T_XOR_EQUAL) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 22533 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) ((":") reduce 523) ((";") reduce 523) (("<") reduce 523) (("=") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AND_EQUAL) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_COALESCE_EQUAL) reduce 523) ((T_CONCAT_EQUAL) reduce 523) ((T_DEC) reduce 523) ((T_DIV_EQUAL) reduce 523) ((T_INC) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_MINUS_EQUAL) reduce 523) ((T_MOD_EQUAL) reduce 523) ((T_MUL_EQUAL) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_OR_EQUAL) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_PLUS_EQUAL) reduce 523) ((T_POW) reduce 523) ((T_POW_EQUAL) reduce 523) ((T_SL) reduce 523) ((T_SL_EQUAL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) ((T_SR_EQUAL) reduce 523) ((T_XOR_EQUAL) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 22535 ((("%") reduce 438) (("*") reduce 438) (("+") reduce 438) (("-") reduce 438) ((".") reduce 438) (("/") reduce 438) ((":") reduce 438) ((";") reduce 438) (("<") reduce 438) ((">") reduce 438) (("?") reduce 438) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_BOOLEAN_AND) reduce 438) ((T_BOOLEAN_OR) reduce 438) ((T_COALESCE) reduce 438) ((T_INSTANCEOF) reduce 438) ((T_IS_EQUAL) reduce 438) ((T_IS_GREATER_OR_EQUAL) reduce 438) ((T_IS_IDENTICAL) reduce 438) ((T_IS_NOT_EQUAL) reduce 438) ((T_IS_NOT_IDENTICAL) reduce 438) ((T_IS_SMALLER_OR_EQUAL) reduce 438) ((T_LOGICAL_AND) reduce 438) ((T_LOGICAL_OR) reduce 438) ((T_LOGICAL_XOR) reduce 438) ((T_POW) reduce 438) ((T_SL) reduce 438) ((T_SPACESHIP) reduce 438) ((T_SR) reduce 438) (("^") reduce 438) (("|") reduce 438)) 22537 ((("%") reduce 483) (("(") reduce 483) (("*") reduce 483) (("+") reduce 483) (("-") reduce 483) ((".") reduce 483) (("/") reduce 483) ((":") reduce 483) ((";") reduce 483) (("<") reduce 483) (("=") shift) ((">") reduce 483) (("?") reduce 483) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_BOOLEAN_AND) reduce 483) ((T_BOOLEAN_OR) reduce 483) ((T_COALESCE) reduce 483) ((T_INSTANCEOF) reduce 483) ((T_IS_EQUAL) reduce 483) ((T_IS_GREATER_OR_EQUAL) reduce 483) ((T_IS_IDENTICAL) reduce 483) ((T_IS_NOT_EQUAL) reduce 483) ((T_IS_NOT_IDENTICAL) reduce 483) ((T_IS_SMALLER_OR_EQUAL) reduce 483) ((T_LOGICAL_AND) reduce 483) ((T_LOGICAL_OR) reduce 483) ((T_LOGICAL_XOR) reduce 483) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 483) ((T_OBJECT_OPERATOR) reduce 483) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 483) ((T_POW) reduce 483) ((T_SL) reduce 483) ((T_SPACESHIP) reduce 483) ((T_SR) reduce 483) (("[") reduce 483) (("^") reduce 483) (("{") reduce 483) (("|") reduce 483)) 22539 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 369) ((";") reduce 369) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 369) ((T_LOGICAL_OR) reduce 369) ((T_LOGICAL_XOR) reduce 369) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22540 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 443) ((";") reduce 443) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 443) ((T_LOGICAL_OR) reduce 443) ((T_LOGICAL_XOR) reduce 443) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22551 ((("%") reduce 502) (("*") reduce 502) (("+") reduce 502) (("-") reduce 502) ((".") reduce 502) (("/") reduce 502) ((":") reduce 502) ((";") reduce 502) (("<") reduce 502) ((">") reduce 502) (("?") reduce 502) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_BOOLEAN_AND) reduce 502) ((T_BOOLEAN_OR) reduce 502) ((T_COALESCE) reduce 502) ((T_DOUBLE_ARROW) reduce 502) ((T_INSTANCEOF) reduce 502) ((T_IS_EQUAL) reduce 502) ((T_IS_GREATER_OR_EQUAL) reduce 502) ((T_IS_IDENTICAL) reduce 502) ((T_IS_NOT_EQUAL) reduce 502) ((T_IS_NOT_IDENTICAL) reduce 502) ((T_IS_SMALLER_OR_EQUAL) reduce 502) ((T_LOGICAL_AND) reduce 502) ((T_LOGICAL_OR) reduce 502) ((T_LOGICAL_XOR) reduce 502) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 502) ((T_OBJECT_OPERATOR) reduce 502) ((T_POW) reduce 502) ((T_SL) reduce 502) ((T_SPACESHIP) reduce 502) ((T_SR) reduce 502) (("[") reduce 502) (("^") reduce 502) (("{") reduce 502) (("|") reduce 502)) 22553 ((("%") reduce 484) (("(") reduce 484) (("*") reduce 484) (("+") reduce 484) (("-") reduce 484) ((".") reduce 484) (("/") reduce 484) ((":") reduce 484) ((";") reduce 484) (("<") reduce 484) ((">") reduce 484) (("?") reduce 484) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_BOOLEAN_AND) reduce 484) ((T_BOOLEAN_OR) reduce 484) ((T_COALESCE) reduce 484) ((T_DOUBLE_ARROW) reduce 484) ((T_INSTANCEOF) reduce 484) ((T_IS_EQUAL) reduce 484) ((T_IS_GREATER_OR_EQUAL) reduce 484) ((T_IS_IDENTICAL) reduce 484) ((T_IS_NOT_EQUAL) reduce 484) ((T_IS_NOT_IDENTICAL) reduce 484) ((T_IS_SMALLER_OR_EQUAL) reduce 484) ((T_LOGICAL_AND) reduce 484) ((T_LOGICAL_OR) reduce 484) ((T_LOGICAL_XOR) reduce 484) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 484) ((T_OBJECT_OPERATOR) reduce 484) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 484) ((T_POW) reduce 484) ((T_SL) reduce 484) ((T_SPACESHIP) reduce 484) ((T_SR) reduce 484) (("[") reduce 484) (("^") reduce 484) (("{") reduce 484) (("|") reduce 484)) 22555 ((("%") reduce 497) (("*") reduce 497) (("+") reduce 497) (("-") reduce 497) ((".") reduce 497) (("/") reduce 497) ((":") reduce 497) ((";") reduce 497) (("<") reduce 497) ((">") reduce 497) (("?") reduce 497) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_BOOLEAN_AND) reduce 497) ((T_BOOLEAN_OR) reduce 497) ((T_COALESCE) reduce 497) ((T_DOUBLE_ARROW) reduce 497) ((T_INSTANCEOF) reduce 497) ((T_IS_EQUAL) reduce 497) ((T_IS_GREATER_OR_EQUAL) reduce 497) ((T_IS_IDENTICAL) reduce 497) ((T_IS_NOT_EQUAL) reduce 497) ((T_IS_NOT_IDENTICAL) reduce 497) ((T_IS_SMALLER_OR_EQUAL) reduce 497) ((T_LOGICAL_AND) reduce 497) ((T_LOGICAL_OR) reduce 497) ((T_LOGICAL_XOR) reduce 497) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 497) ((T_OBJECT_OPERATOR) reduce 497) ((T_POW) reduce 497) ((T_SL) reduce 497) ((T_SPACESHIP) reduce 497) ((T_SR) reduce 497) (("[") reduce 497) (("^") reduce 497) (("{") reduce 497) (("|") reduce 497)) 22556 ((("%") reduce 487) (("*") reduce 487) (("+") reduce 487) (("-") reduce 487) ((".") reduce 487) (("/") reduce 487) ((":") reduce 487) ((";") reduce 487) (("<") reduce 487) ((">") reduce 487) (("?") reduce 487) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_BOOLEAN_AND) reduce 487) ((T_BOOLEAN_OR) reduce 487) ((T_COALESCE) reduce 487) ((T_DOUBLE_ARROW) reduce 487) ((T_INSTANCEOF) reduce 487) ((T_IS_EQUAL) reduce 487) ((T_IS_GREATER_OR_EQUAL) reduce 487) ((T_IS_IDENTICAL) reduce 487) ((T_IS_NOT_EQUAL) reduce 487) ((T_IS_NOT_IDENTICAL) reduce 487) ((T_IS_SMALLER_OR_EQUAL) reduce 487) ((T_LOGICAL_AND) reduce 487) ((T_LOGICAL_OR) reduce 487) ((T_LOGICAL_XOR) reduce 487) ((T_POW) reduce 487) ((T_SL) reduce 487) ((T_SPACESHIP) reduce 487) ((T_SR) reduce 487) (("^") reduce 487) (("|") reduce 487)) 22560 ((("%") reduce 475) (("(") shift) (("*") reduce 475) (("+") reduce 475) (("-") reduce 475) ((".") reduce 475) (("/") reduce 475) ((":") reduce 475) ((";") reduce 475) (("<") reduce 475) ((">") reduce 475) (("?") reduce 475) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_BOOLEAN_AND) reduce 475) ((T_BOOLEAN_OR) reduce 475) ((T_COALESCE) reduce 475) ((T_DOUBLE_ARROW) reduce 475) ((T_INSTANCEOF) reduce 475) ((T_IS_EQUAL) reduce 475) ((T_IS_GREATER_OR_EQUAL) reduce 475) ((T_IS_IDENTICAL) reduce 475) ((T_IS_NOT_EQUAL) reduce 475) ((T_IS_NOT_IDENTICAL) reduce 475) ((T_IS_SMALLER_OR_EQUAL) reduce 475) ((T_LOGICAL_AND) reduce 475) ((T_LOGICAL_OR) reduce 475) ((T_LOGICAL_XOR) reduce 475) ((T_POW) reduce 475) ((T_SL) reduce 475) ((T_SPACESHIP) reduce 475) ((T_SR) reduce 475) (("^") reduce 475) (("|") reduce 475)) 22561 ((("%") reduce 496) (("*") reduce 496) (("+") reduce 496) (("-") reduce 496) ((".") reduce 496) (("/") reduce 496) ((":") reduce 496) ((";") reduce 496) (("<") reduce 496) ((">") reduce 496) (("?") reduce 496) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_BOOLEAN_AND) reduce 496) ((T_BOOLEAN_OR) reduce 496) ((T_COALESCE) reduce 496) ((T_DOUBLE_ARROW) reduce 496) ((T_INSTANCEOF) reduce 496) ((T_IS_EQUAL) reduce 496) ((T_IS_GREATER_OR_EQUAL) reduce 496) ((T_IS_IDENTICAL) reduce 496) ((T_IS_NOT_EQUAL) reduce 496) ((T_IS_NOT_IDENTICAL) reduce 496) ((T_IS_SMALLER_OR_EQUAL) reduce 496) ((T_LOGICAL_AND) reduce 496) ((T_LOGICAL_OR) reduce 496) ((T_LOGICAL_XOR) reduce 496) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 496) ((T_OBJECT_OPERATOR) reduce 496) ((T_POW) reduce 496) ((T_SL) reduce 496) ((T_SPACESHIP) reduce 496) ((T_SR) reduce 496) (("[") reduce 496) (("^") reduce 496) (("{") reduce 496) (("|") reduce 496)) 22562 ((("%") reduce 500) (("*") reduce 500) (("+") reduce 500) (("-") reduce 500) ((".") reduce 500) (("/") reduce 500) ((":") reduce 500) ((";") reduce 500) (("<") reduce 500) ((">") reduce 500) (("?") reduce 500) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_BOOLEAN_AND) reduce 500) ((T_BOOLEAN_OR) reduce 500) ((T_COALESCE) reduce 500) ((T_DOUBLE_ARROW) reduce 500) ((T_INSTANCEOF) reduce 500) ((T_IS_EQUAL) reduce 500) ((T_IS_GREATER_OR_EQUAL) reduce 500) ((T_IS_IDENTICAL) reduce 500) ((T_IS_NOT_EQUAL) reduce 500) ((T_IS_NOT_IDENTICAL) reduce 500) ((T_IS_SMALLER_OR_EQUAL) reduce 500) ((T_LOGICAL_AND) reduce 500) ((T_LOGICAL_OR) reduce 500) ((T_LOGICAL_XOR) reduce 500) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 500) ((T_OBJECT_OPERATOR) reduce 500) ((T_POW) reduce 500) ((T_SL) reduce 500) ((T_SPACESHIP) reduce 500) ((T_SR) reduce 500) (("[") reduce 500) (("^") reduce 500) (("{") reduce 500) (("|") reduce 500)) 22568 ((("%") reduce 495) (("*") reduce 495) (("+") reduce 495) (("-") reduce 495) ((".") reduce 495) (("/") reduce 495) ((":") reduce 495) ((";") reduce 495) (("<") reduce 495) ((">") reduce 495) (("?") reduce 495) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_BOOLEAN_AND) reduce 495) ((T_BOOLEAN_OR) reduce 495) ((T_COALESCE) reduce 495) ((T_DOUBLE_ARROW) reduce 495) ((T_INSTANCEOF) reduce 495) ((T_IS_EQUAL) reduce 495) ((T_IS_GREATER_OR_EQUAL) reduce 495) ((T_IS_IDENTICAL) reduce 495) ((T_IS_NOT_EQUAL) reduce 495) ((T_IS_NOT_IDENTICAL) reduce 495) ((T_IS_SMALLER_OR_EQUAL) reduce 495) ((T_LOGICAL_AND) reduce 495) ((T_LOGICAL_OR) reduce 495) ((T_LOGICAL_XOR) reduce 495) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 495) ((T_OBJECT_OPERATOR) reduce 495) ((T_POW) reduce 495) ((T_SL) reduce 495) ((T_SPACESHIP) reduce 495) ((T_SR) reduce 495) (("[") reduce 495) (("^") reduce 495) (("{") reduce 495) (("|") reduce 495)) 22570 ((("%") reduce 486) (("*") reduce 486) (("+") reduce 486) (("-") reduce 486) ((".") reduce 486) (("/") reduce 486) ((":") reduce 486) ((";") reduce 486) (("<") reduce 486) ((">") reduce 486) (("?") reduce 486) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_BOOLEAN_AND) reduce 486) ((T_BOOLEAN_OR) reduce 486) ((T_COALESCE) reduce 486) ((T_DOUBLE_ARROW) reduce 486) ((T_INSTANCEOF) reduce 486) ((T_IS_EQUAL) reduce 486) ((T_IS_GREATER_OR_EQUAL) reduce 486) ((T_IS_IDENTICAL) reduce 486) ((T_IS_NOT_EQUAL) reduce 486) ((T_IS_NOT_IDENTICAL) reduce 486) ((T_IS_SMALLER_OR_EQUAL) reduce 486) ((T_LOGICAL_AND) reduce 486) ((T_LOGICAL_OR) reduce 486) ((T_LOGICAL_XOR) reduce 486) ((T_POW) reduce 486) ((T_SL) reduce 486) ((T_SPACESHIP) reduce 486) ((T_SR) reduce 486) (("^") reduce 486) (("|") reduce 486)) 22572 ((("%") reduce 499) (("*") reduce 499) (("+") reduce 499) (("-") reduce 499) ((".") reduce 499) (("/") reduce 499) ((":") reduce 499) ((";") reduce 499) (("<") reduce 499) ((">") reduce 499) (("?") reduce 499) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_BOOLEAN_AND) reduce 499) ((T_BOOLEAN_OR) reduce 499) ((T_COALESCE) reduce 499) ((T_DOUBLE_ARROW) reduce 499) ((T_INSTANCEOF) reduce 499) ((T_IS_EQUAL) reduce 499) ((T_IS_GREATER_OR_EQUAL) reduce 499) ((T_IS_IDENTICAL) reduce 499) ((T_IS_NOT_EQUAL) reduce 499) ((T_IS_NOT_IDENTICAL) reduce 499) ((T_IS_SMALLER_OR_EQUAL) reduce 499) ((T_LOGICAL_AND) reduce 499) ((T_LOGICAL_OR) reduce 499) ((T_LOGICAL_XOR) reduce 499) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 499) ((T_OBJECT_OPERATOR) reduce 499) ((T_POW) reduce 499) ((T_SL) reduce 499) ((T_SPACESHIP) reduce 499) ((T_SR) reduce 499) (("[") reduce 499) (("^") reduce 499) (("{") reduce 499) (("|") reduce 499)) 22573 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) ((":") reduce 93) ((";") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 93) ((T_OBJECT_OPERATOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("[") reduce 93) (("^") reduce 93) (("{") reduce 93) (("|") reduce 93)) 22574 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) ((":") reduce 92) ((";") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 92) ((T_OBJECT_OPERATOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("[") reduce 92) (("^") reduce 92) (("{") reduce 92) (("|") reduce 92)) 22575 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) ((":") reduce 94) ((";") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 94) ((T_OBJECT_OPERATOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("[") reduce 94) (("^") reduce 94) (("{") reduce 94) (("|") reduce 94)) 22577 ((("%") reduce 501) (("*") reduce 501) (("+") reduce 501) (("-") reduce 501) ((".") reduce 501) (("/") reduce 501) ((":") reduce 501) ((";") reduce 501) (("<") reduce 501) ((">") reduce 501) (("?") reduce 501) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_BOOLEAN_AND) reduce 501) ((T_BOOLEAN_OR) reduce 501) ((T_COALESCE) reduce 501) ((T_DOUBLE_ARROW) reduce 501) ((T_INSTANCEOF) reduce 501) ((T_IS_EQUAL) reduce 501) ((T_IS_GREATER_OR_EQUAL) reduce 501) ((T_IS_IDENTICAL) reduce 501) ((T_IS_NOT_EQUAL) reduce 501) ((T_IS_NOT_IDENTICAL) reduce 501) ((T_IS_SMALLER_OR_EQUAL) reduce 501) ((T_LOGICAL_AND) reduce 501) ((T_LOGICAL_OR) reduce 501) ((T_LOGICAL_XOR) reduce 501) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 501) ((T_OBJECT_OPERATOR) reduce 501) ((T_POW) reduce 501) ((T_SL) reduce 501) ((T_SPACESHIP) reduce 501) ((T_SR) reduce 501) (("[") reduce 501) (("^") reduce 501) (("{") reduce 501) (("|") reduce 501)) 22585 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) ((":") reduce 91) ((";") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 91) ((T_OBJECT_OPERATOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("[") reduce 91) (("^") reduce 91) (("{") reduce 91) (("|") reduce 91)) 22588 ((("%") reduce 498) (("*") reduce 498) (("+") reduce 498) (("-") reduce 498) ((".") reduce 498) (("/") reduce 498) ((":") reduce 498) ((";") reduce 498) (("<") reduce 498) ((">") reduce 498) (("?") reduce 498) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_BOOLEAN_AND) reduce 498) ((T_BOOLEAN_OR) reduce 498) ((T_COALESCE) reduce 498) ((T_DOUBLE_ARROW) reduce 498) ((T_INSTANCEOF) reduce 498) ((T_IS_EQUAL) reduce 498) ((T_IS_GREATER_OR_EQUAL) reduce 498) ((T_IS_IDENTICAL) reduce 498) ((T_IS_NOT_EQUAL) reduce 498) ((T_IS_NOT_IDENTICAL) reduce 498) ((T_IS_SMALLER_OR_EQUAL) reduce 498) ((T_LOGICAL_AND) reduce 498) ((T_LOGICAL_OR) reduce 498) ((T_LOGICAL_XOR) reduce 498) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 498) ((T_OBJECT_OPERATOR) reduce 498) ((T_POW) reduce 498) ((T_SL) reduce 498) ((T_SPACESHIP) reduce 498) ((T_SR) reduce 498) (("[") reduce 498) (("^") reduce 498) (("{") reduce 498) (("|") reduce 498)) 22590 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) ((":") reduce 529) ((";") reduce 529) (("<") reduce 529) (("=") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AND_EQUAL) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_COALESCE_EQUAL) reduce 529) ((T_CONCAT_EQUAL) reduce 529) ((T_DEC) reduce 529) ((T_DIV_EQUAL) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INC) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_MINUS_EQUAL) reduce 529) ((T_MOD_EQUAL) reduce 529) ((T_MUL_EQUAL) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_OR_EQUAL) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_PLUS_EQUAL) reduce 529) ((T_POW) reduce 529) ((T_POW_EQUAL) reduce 529) ((T_SL) reduce 529) ((T_SL_EQUAL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) ((T_SR_EQUAL) reduce 529) ((T_XOR_EQUAL) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 22591 ((("!") shift) (("\"") shift) (("$") shift) (("%") reduce 440) (("(") shift) (("*") reduce 440) (("+") shift) (("-") shift) ((".") reduce 440) (("/") reduce 440) ((":") reduce 440) ((";") reduce 440) (("<") reduce 440) ((">") reduce 440) (("?") reduce 440) (("@") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOLEAN_AND) reduce 440) ((T_BOOLEAN_OR) reduce 440) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_COALESCE) reduce 440) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_ARROW) reduce 440) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INSTANCEOF) reduce 440) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_IS_EQUAL) reduce 440) ((T_IS_GREATER_OR_EQUAL) reduce 440) ((T_IS_IDENTICAL) reduce 440) ((T_IS_NOT_EQUAL) reduce 440) ((T_IS_NOT_IDENTICAL) reduce 440) ((T_IS_SMALLER_OR_EQUAL) reduce 440) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_LOGICAL_AND) reduce 440) ((T_LOGICAL_OR) reduce 440) ((T_LOGICAL_XOR) reduce 440) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_POW) reduce 440) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_SL) reduce 440) ((T_SPACESHIP) reduce 440) ((T_SR) reduce 440) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("^") reduce 440) (("`") shift) (("|") reduce 440) (("~") shift)) 22598 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) ((":") reduce 525) ((";") reduce 525) (("<") reduce 525) (("=") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AND_EQUAL) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_COALESCE_EQUAL) reduce 525) ((T_CONCAT_EQUAL) reduce 525) ((T_DEC) reduce 525) ((T_DIV_EQUAL) reduce 525) ((T_DOUBLE_ARROW) reduce 525) ((T_INC) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_MINUS_EQUAL) reduce 525) ((T_MOD_EQUAL) reduce 525) ((T_MUL_EQUAL) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_OR_EQUAL) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_PLUS_EQUAL) reduce 525) ((T_POW) reduce 525) ((T_POW_EQUAL) reduce 525) ((T_SL) reduce 525) ((T_SL_EQUAL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) ((T_SR_EQUAL) reduce 525) ((T_XOR_EQUAL) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 22599 ((("%") reduce 493) (("*") reduce 493) (("+") reduce 493) (("-") reduce 493) ((".") reduce 493) (("/") reduce 493) ((":") reduce 493) ((";") reduce 493) (("<") reduce 493) ((">") reduce 493) (("?") reduce 493) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_BOOLEAN_AND) reduce 493) ((T_BOOLEAN_OR) reduce 493) ((T_COALESCE) reduce 493) ((T_DOUBLE_ARROW) reduce 493) ((T_INSTANCEOF) reduce 493) ((T_IS_EQUAL) reduce 493) ((T_IS_GREATER_OR_EQUAL) reduce 493) ((T_IS_IDENTICAL) reduce 493) ((T_IS_NOT_EQUAL) reduce 493) ((T_IS_NOT_IDENTICAL) reduce 493) ((T_IS_SMALLER_OR_EQUAL) reduce 493) ((T_LOGICAL_AND) reduce 493) ((T_LOGICAL_OR) reduce 493) ((T_LOGICAL_XOR) reduce 493) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 513) ((T_OBJECT_OPERATOR) reduce 513) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 513) ((T_POW) reduce 493) ((T_SL) reduce 493) ((T_SPACESHIP) reduce 493) ((T_SR) reduce 493) (("[") reduce 513) (("^") reduce 493) (("{") reduce 513) (("|") reduce 493)) 22601 ((("%") reduce 492) (("*") reduce 492) (("+") reduce 492) (("-") reduce 492) ((".") reduce 492) (("/") reduce 492) ((":") reduce 492) ((";") reduce 492) (("<") reduce 492) ((">") reduce 492) (("?") reduce 492) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_BOOLEAN_AND) reduce 492) ((T_BOOLEAN_OR) reduce 492) ((T_COALESCE) reduce 492) ((T_DOUBLE_ARROW) reduce 492) ((T_INSTANCEOF) reduce 492) ((T_IS_EQUAL) reduce 492) ((T_IS_GREATER_OR_EQUAL) reduce 492) ((T_IS_IDENTICAL) reduce 492) ((T_IS_NOT_EQUAL) reduce 492) ((T_IS_NOT_IDENTICAL) reduce 492) ((T_IS_SMALLER_OR_EQUAL) reduce 492) ((T_LOGICAL_AND) reduce 492) ((T_LOGICAL_OR) reduce 492) ((T_LOGICAL_XOR) reduce 492) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 515) ((T_OBJECT_OPERATOR) reduce 515) ((T_POW) reduce 492) ((T_SL) reduce 492) ((T_SPACESHIP) reduce 492) ((T_SR) reduce 492) (("[") reduce 515) (("^") reduce 492) (("{") reduce 515) (("|") reduce 492)) 22602 ((("%") reduce 491) (("(") reduce 518) (("*") reduce 491) (("+") reduce 491) (("-") reduce 491) ((".") reduce 491) (("/") reduce 491) ((":") reduce 491) ((";") reduce 491) (("<") reduce 491) ((">") reduce 491) (("?") reduce 491) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_BOOLEAN_AND) reduce 491) ((T_BOOLEAN_OR) reduce 491) ((T_COALESCE) reduce 491) ((T_DOUBLE_ARROW) reduce 491) ((T_INSTANCEOF) reduce 491) ((T_IS_EQUAL) reduce 491) ((T_IS_GREATER_OR_EQUAL) reduce 491) ((T_IS_IDENTICAL) reduce 491) ((T_IS_NOT_EQUAL) reduce 491) ((T_IS_NOT_IDENTICAL) reduce 491) ((T_IS_SMALLER_OR_EQUAL) reduce 491) ((T_LOGICAL_AND) reduce 491) ((T_LOGICAL_OR) reduce 491) ((T_LOGICAL_XOR) reduce 491) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 512) ((T_OBJECT_OPERATOR) reduce 512) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 512) ((T_POW) reduce 491) ((T_SL) reduce 491) ((T_SPACESHIP) reduce 491) ((T_SR) reduce 491) (("[") reduce 512) (("^") reduce 491) (("{") reduce 512) (("|") reduce 491)) 22603 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 441) ((";") reduce 441) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 441) ((T_LOGICAL_OR) reduce 441) ((T_LOGICAL_XOR) reduce 441) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22606 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) ((":") reduce 524) ((";") reduce 524) (("<") reduce 524) (("=") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AND_EQUAL) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_COALESCE_EQUAL) reduce 524) ((T_CONCAT_EQUAL) reduce 524) ((T_DEC) reduce 524) ((T_DIV_EQUAL) reduce 524) ((T_DOUBLE_ARROW) reduce 524) ((T_INC) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_MINUS_EQUAL) reduce 524) ((T_MOD_EQUAL) reduce 524) ((T_MUL_EQUAL) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_OR_EQUAL) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_PLUS_EQUAL) reduce 524) ((T_POW) reduce 524) ((T_POW_EQUAL) reduce 524) ((T_SL) reduce 524) ((T_SL_EQUAL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) ((T_SR_EQUAL) reduce 524) ((T_XOR_EQUAL) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 22607 ((("%") reduce 445) (("*") reduce 445) (("+") reduce 445) (("-") reduce 445) ((".") reduce 445) (("/") reduce 445) ((":") reduce 445) ((";") reduce 445) (("<") reduce 445) ((">") reduce 445) (("?") reduce 445) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_BOOLEAN_AND) reduce 445) ((T_BOOLEAN_OR) reduce 445) ((T_COALESCE) reduce 445) ((T_DOUBLE_ARROW) reduce 445) ((T_INSTANCEOF) reduce 445) ((T_IS_EQUAL) reduce 445) ((T_IS_GREATER_OR_EQUAL) reduce 445) ((T_IS_IDENTICAL) reduce 445) ((T_IS_NOT_EQUAL) reduce 445) ((T_IS_NOT_IDENTICAL) reduce 445) ((T_IS_SMALLER_OR_EQUAL) reduce 445) ((T_LOGICAL_AND) reduce 445) ((T_LOGICAL_OR) reduce 445) ((T_LOGICAL_XOR) reduce 445) ((T_POW) reduce 445) ((T_SL) reduce 445) ((T_SPACESHIP) reduce 445) ((T_SR) reduce 445) (("^") reduce 445) (("|") reduce 445)) 22608 ((("%") reduce 427) (("*") reduce 427) (("+") reduce 427) (("-") reduce 427) ((".") reduce 427) (("/") reduce 427) ((":") reduce 427) ((";") reduce 427) (("<") reduce 427) ((">") reduce 427) (("?") reduce 427) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_BOOLEAN_AND) reduce 427) ((T_BOOLEAN_OR) reduce 427) ((T_COALESCE) reduce 427) ((T_DOUBLE_ARROW) reduce 427) ((T_INSTANCEOF) reduce 427) ((T_IS_EQUAL) reduce 427) ((T_IS_GREATER_OR_EQUAL) reduce 427) ((T_IS_IDENTICAL) reduce 427) ((T_IS_NOT_EQUAL) reduce 427) ((T_IS_NOT_IDENTICAL) reduce 427) ((T_IS_SMALLER_OR_EQUAL) reduce 427) ((T_LOGICAL_AND) reduce 427) ((T_LOGICAL_OR) reduce 427) ((T_LOGICAL_XOR) reduce 427) ((T_POW) reduce 427) ((T_SL) reduce 427) ((T_SPACESHIP) reduce 427) ((T_SR) reduce 427) (("^") reduce 427) (("|") reduce 427)) 22609 ((("%") reduce 449) (("*") reduce 449) (("+") reduce 449) (("-") reduce 449) ((".") reduce 449) (("/") reduce 449) ((":") reduce 449) ((";") reduce 449) (("<") reduce 449) ((">") reduce 449) (("?") reduce 449) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_BOOLEAN_AND) reduce 449) ((T_BOOLEAN_OR) reduce 449) ((T_COALESCE) reduce 449) ((T_DOUBLE_ARROW) reduce 449) ((T_INSTANCEOF) reduce 449) ((T_IS_EQUAL) reduce 449) ((T_IS_GREATER_OR_EQUAL) reduce 449) ((T_IS_IDENTICAL) reduce 449) ((T_IS_NOT_EQUAL) reduce 449) ((T_IS_NOT_IDENTICAL) reduce 449) ((T_IS_SMALLER_OR_EQUAL) reduce 449) ((T_LOGICAL_AND) reduce 449) ((T_LOGICAL_OR) reduce 449) ((T_LOGICAL_XOR) reduce 449) ((T_POW) reduce 449) ((T_SL) reduce 449) ((T_SPACESHIP) reduce 449) ((T_SR) reduce 449) (("^") reduce 449) (("|") reduce 449)) 22610 ((("%") reduce 494) (("(") shift) (("*") reduce 494) (("+") reduce 494) (("-") reduce 494) ((".") reduce 494) (("/") reduce 494) ((":") reduce 494) ((";") reduce 494) (("<") reduce 494) ((">") reduce 494) (("?") reduce 494) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_BOOLEAN_AND) reduce 494) ((T_BOOLEAN_OR) reduce 494) ((T_COALESCE) reduce 494) ((T_DOUBLE_ARROW) reduce 494) ((T_INSTANCEOF) reduce 494) ((T_IS_EQUAL) reduce 494) ((T_IS_GREATER_OR_EQUAL) reduce 494) ((T_IS_IDENTICAL) reduce 494) ((T_IS_NOT_EQUAL) reduce 494) ((T_IS_NOT_IDENTICAL) reduce 494) ((T_IS_SMALLER_OR_EQUAL) reduce 494) ((T_LOGICAL_AND) reduce 494) ((T_LOGICAL_OR) reduce 494) ((T_LOGICAL_XOR) reduce 494) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 494) ((T_OBJECT_OPERATOR) reduce 494) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 494) ((T_SL) reduce 494) ((T_SPACESHIP) reduce 494) ((T_SR) reduce 494) (("[") reduce 494) (("^") reduce 494) (("{") reduce 494) (("|") reduce 494)) 22611 ((("%") reduce 423) (("*") reduce 423) (("+") reduce 423) (("-") reduce 423) ((".") reduce 423) (("/") reduce 423) ((":") reduce 423) ((";") reduce 423) (("<") reduce 423) ((">") reduce 423) (("?") reduce 423) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_BOOLEAN_AND) reduce 423) ((T_BOOLEAN_OR) reduce 423) ((T_COALESCE) reduce 423) ((T_DOUBLE_ARROW) reduce 423) ((T_INSTANCEOF) reduce 423) ((T_IS_EQUAL) reduce 423) ((T_IS_GREATER_OR_EQUAL) reduce 423) ((T_IS_IDENTICAL) reduce 423) ((T_IS_NOT_EQUAL) reduce 423) ((T_IS_NOT_IDENTICAL) reduce 423) ((T_IS_SMALLER_OR_EQUAL) reduce 423) ((T_LOGICAL_AND) reduce 423) ((T_LOGICAL_OR) reduce 423) ((T_LOGICAL_XOR) reduce 423) ((T_POW) reduce 423) ((T_SL) reduce 423) ((T_SPACESHIP) reduce 423) ((T_SR) reduce 423) (("^") reduce 423) (("|") reduce 423)) 22612 ((("%") reduce 437) (("*") reduce 437) (("+") reduce 437) (("-") reduce 437) ((".") reduce 437) (("/") reduce 437) ((":") reduce 437) ((";") reduce 437) (("<") reduce 437) ((">") reduce 437) (("?") reduce 437) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_BOOLEAN_AND) reduce 437) ((T_BOOLEAN_OR) reduce 437) ((T_COALESCE) reduce 437) ((T_DOUBLE_ARROW) reduce 437) ((T_INSTANCEOF) reduce 437) ((T_IS_EQUAL) reduce 437) ((T_IS_GREATER_OR_EQUAL) reduce 437) ((T_IS_IDENTICAL) reduce 437) ((T_IS_NOT_EQUAL) reduce 437) ((T_IS_NOT_IDENTICAL) reduce 437) ((T_IS_SMALLER_OR_EQUAL) reduce 437) ((T_LOGICAL_AND) reduce 437) ((T_LOGICAL_OR) reduce 437) ((T_LOGICAL_XOR) reduce 437) ((T_POW) reduce 437) ((T_SL) reduce 437) ((T_SPACESHIP) reduce 437) ((T_SR) reduce 437) (("^") reduce 437) (("|") reduce 437)) 22613 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) ((":") reduce 519) ((";") reduce 519) (("<") reduce 519) (("=") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AND_EQUAL) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_COALESCE_EQUAL) reduce 519) ((T_CONCAT_EQUAL) reduce 519) ((T_DEC) reduce 519) ((T_DIV_EQUAL) reduce 519) ((T_DOUBLE_ARROW) reduce 519) ((T_INC) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_MINUS_EQUAL) reduce 519) ((T_MOD_EQUAL) reduce 519) ((T_MUL_EQUAL) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_OR_EQUAL) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_PLUS_EQUAL) reduce 519) ((T_POW) reduce 519) ((T_POW_EQUAL) reduce 519) ((T_SL) reduce 519) ((T_SL_EQUAL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) ((T_SR_EQUAL) reduce 519) ((T_XOR_EQUAL) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 22614 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) ((":") reduce 526) ((";") reduce 526) (("<") reduce 526) (("=") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AND_EQUAL) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_COALESCE_EQUAL) reduce 526) ((T_CONCAT_EQUAL) reduce 526) ((T_DEC) reduce 526) ((T_DIV_EQUAL) reduce 526) ((T_DOUBLE_ARROW) reduce 526) ((T_INC) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_MINUS_EQUAL) reduce 526) ((T_MOD_EQUAL) reduce 526) ((T_MUL_EQUAL) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_OR_EQUAL) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_PLUS_EQUAL) reduce 526) ((T_POW) reduce 526) ((T_POW_EQUAL) reduce 526) ((T_SL) reduce 526) ((T_SL_EQUAL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) ((T_SR_EQUAL) reduce 526) ((T_XOR_EQUAL) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 22615 ((("%") reduce 367) (("*") reduce 367) (("+") reduce 367) (("-") reduce 367) ((".") reduce 367) (("/") reduce 367) ((":") reduce 367) ((";") reduce 367) (("<") reduce 367) (("=") shift) ((">") reduce 367) (("?") reduce 367) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AND_EQUAL) shift) ((T_BOOLEAN_AND) reduce 367) ((T_BOOLEAN_OR) reduce 367) ((T_COALESCE) reduce 367) ((T_COALESCE_EQUAL) shift) ((T_CONCAT_EQUAL) shift) ((T_DEC) shift) ((T_DIV_EQUAL) shift) ((T_DOUBLE_ARROW) reduce 367) ((T_INC) shift) ((T_INSTANCEOF) reduce 367) ((T_IS_EQUAL) reduce 367) ((T_IS_GREATER_OR_EQUAL) reduce 367) ((T_IS_IDENTICAL) reduce 367) ((T_IS_NOT_EQUAL) reduce 367) ((T_IS_NOT_IDENTICAL) reduce 367) ((T_IS_SMALLER_OR_EQUAL) reduce 367) ((T_LOGICAL_AND) reduce 367) ((T_LOGICAL_OR) reduce 367) ((T_LOGICAL_XOR) reduce 367) ((T_MINUS_EQUAL) shift) ((T_MOD_EQUAL) shift) ((T_MUL_EQUAL) shift) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_OR_EQUAL) shift) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_PLUS_EQUAL) shift) ((T_POW) reduce 367) ((T_POW_EQUAL) shift) ((T_SL) reduce 367) ((T_SL_EQUAL) shift) ((T_SPACESHIP) reduce 367) ((T_SR) reduce 367) ((T_SR_EQUAL) shift) ((T_XOR_EQUAL) shift) (("[") reduce 510) (("^") reduce 367) (("{") reduce 510) (("|") reduce 367)) 22618 ((("%") reduce 411) (("*") reduce 411) (("+") reduce 411) (("-") reduce 411) ((".") reduce 411) (("/") reduce 411) ((":") reduce 411) ((";") reduce 411) (("<") reduce 411) ((">") reduce 411) (("?") reduce 411) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_BOOLEAN_AND) reduce 411) ((T_BOOLEAN_OR) reduce 411) ((T_COALESCE) reduce 411) ((T_DOUBLE_ARROW) reduce 411) ((T_INSTANCEOF) reduce 411) ((T_IS_EQUAL) reduce 411) ((T_IS_GREATER_OR_EQUAL) reduce 411) ((T_IS_IDENTICAL) reduce 411) ((T_IS_NOT_EQUAL) reduce 411) ((T_IS_NOT_IDENTICAL) reduce 411) ((T_IS_SMALLER_OR_EQUAL) reduce 411) ((T_LOGICAL_AND) reduce 411) ((T_LOGICAL_OR) reduce 411) ((T_LOGICAL_XOR) reduce 411) ((T_POW) shift) ((T_SL) reduce 411) ((T_SPACESHIP) reduce 411) ((T_SR) reduce 411) (("^") reduce 411) (("|") reduce 411)) 22649 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 395) ((";") reduce 395) (("<") shift) ((">") shift) (("?") reduce 395) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 395) ((T_BOOLEAN_OR) reduce 395) ((T_COALESCE) reduce 395) ((T_DOUBLE_ARROW) reduce 395) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 395) ((T_LOGICAL_OR) reduce 395) ((T_LOGICAL_XOR) reduce 395) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") reduce 395)) 22650 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 398) ((";") reduce 398) (("<") shift) ((">") shift) (("?") reduce 398) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 398) ((T_BOOLEAN_OR) reduce 398) ((T_COALESCE) reduce 398) ((T_DOUBLE_ARROW) reduce 398) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 398) ((T_LOGICAL_OR) reduce 398) ((T_LOGICAL_XOR) reduce 398) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 398) (("|") reduce 398)) 22651 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 407) (("/") shift) ((":") reduce 407) ((";") reduce 407) (("<") reduce 407) ((">") reduce 407) (("?") reduce 407) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_BOOLEAN_AND) reduce 407) ((T_BOOLEAN_OR) reduce 407) ((T_COALESCE) reduce 407) ((T_DOUBLE_ARROW) reduce 407) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 407) ((T_IS_GREATER_OR_EQUAL) reduce 407) ((T_IS_IDENTICAL) reduce 407) ((T_IS_NOT_EQUAL) reduce 407) ((T_IS_NOT_IDENTICAL) reduce 407) ((T_IS_SMALLER_OR_EQUAL) reduce 407) ((T_LOGICAL_AND) reduce 407) ((T_LOGICAL_OR) reduce 407) ((T_LOGICAL_XOR) reduce 407) ((T_POW) shift) ((T_SL) reduce 407) ((T_SPACESHIP) reduce 407) ((T_SR) reduce 407) (("^") reduce 407) (("|") reduce 407)) 22652 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 420) ((";") reduce 420) (("<") shift) ((">") shift) (("?") reduce 420) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_BOOLEAN_AND) reduce 420) ((T_BOOLEAN_OR) reduce 420) ((T_COALESCE) reduce 420) ((T_DOUBLE_ARROW) reduce 420) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 420) ((T_LOGICAL_OR) reduce 420) ((T_LOGICAL_XOR) reduce 420) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 420) (("|") reduce 420)) 22653 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 406) (("/") shift) ((":") reduce 406) ((";") reduce 406) (("<") reduce 406) ((">") reduce 406) (("?") reduce 406) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_BOOLEAN_AND) reduce 406) ((T_BOOLEAN_OR) reduce 406) ((T_COALESCE) reduce 406) ((T_DOUBLE_ARROW) reduce 406) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 406) ((T_IS_GREATER_OR_EQUAL) reduce 406) ((T_IS_IDENTICAL) reduce 406) ((T_IS_NOT_EQUAL) reduce 406) ((T_IS_NOT_IDENTICAL) reduce 406) ((T_IS_SMALLER_OR_EQUAL) reduce 406) ((T_LOGICAL_AND) reduce 406) ((T_LOGICAL_OR) reduce 406) ((T_LOGICAL_XOR) reduce 406) ((T_POW) shift) ((T_SL) reduce 406) ((T_SPACESHIP) reduce 406) ((T_SR) reduce 406) (("^") reduce 406) (("|") reduce 406)) 22654 ((("%") reduce 403) (("*") reduce 403) (("+") reduce 403) (("-") reduce 403) ((".") reduce 403) (("/") reduce 403) ((":") reduce 403) ((";") reduce 403) (("<") reduce 403) ((">") reduce 403) (("?") reduce 403) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_BOOLEAN_AND) reduce 403) ((T_BOOLEAN_OR) reduce 403) ((T_COALESCE) reduce 403) ((T_DOUBLE_ARROW) reduce 403) ((T_INSTANCEOF) reduce 403) ((T_IS_EQUAL) reduce 403) ((T_IS_GREATER_OR_EQUAL) reduce 403) ((T_IS_IDENTICAL) reduce 403) ((T_IS_NOT_EQUAL) reduce 403) ((T_IS_NOT_IDENTICAL) reduce 403) ((T_IS_SMALLER_OR_EQUAL) reduce 403) ((T_LOGICAL_AND) reduce 403) ((T_LOGICAL_OR) reduce 403) ((T_LOGICAL_XOR) reduce 403) ((T_POW) shift) ((T_SL) reduce 403) ((T_SPACESHIP) reduce 403) ((T_SR) reduce 403) (("^") reduce 403) (("|") reduce 403)) 22655 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 394) ((";") reduce 394) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 394) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 394) ((T_LOGICAL_XOR) reduce 394) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22656 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 392) ((";") reduce 392) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 392) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 392) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22657 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 393) ((";") reduce 393) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 393) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 393) ((T_LOGICAL_OR) reduce 393) ((T_LOGICAL_XOR) reduce 393) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22658 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 417) ((";") reduce 417) (("<") shift) ((">") shift) (("?") reduce 417) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_BOOLEAN_AND) reduce 417) ((T_BOOLEAN_OR) reduce 417) ((T_COALESCE) reduce 417) ((T_DOUBLE_ARROW) reduce 417) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 417) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 417) ((T_IS_NOT_EQUAL) reduce 417) ((T_IS_NOT_IDENTICAL) reduce 417) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 417) ((T_LOGICAL_OR) reduce 417) ((T_LOGICAL_XOR) reduce 417) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 417) ((T_SR) shift) (("^") reduce 417) (("|") reduce 417)) 22659 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 413) ((";") reduce 413) (("<") shift) ((">") shift) (("?") reduce 413) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_BOOLEAN_AND) reduce 413) ((T_BOOLEAN_OR) reduce 413) ((T_COALESCE) reduce 413) ((T_DOUBLE_ARROW) reduce 413) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 413) ((T_LOGICAL_OR) reduce 413) ((T_LOGICAL_XOR) reduce 413) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 413) (("|") reduce 413)) 22660 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 415) ((";") reduce 415) (("<") shift) ((">") shift) (("?") reduce 415) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_BOOLEAN_AND) reduce 415) ((T_BOOLEAN_OR) reduce 415) ((T_COALESCE) reduce 415) ((T_DOUBLE_ARROW) reduce 415) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 415) ((T_LOGICAL_OR) reduce 415) ((T_LOGICAL_XOR) reduce 415) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 415) (("|") reduce 415)) 22661 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 412) ((";") reduce 412) (("<") shift) ((">") shift) (("?") reduce 412) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_BOOLEAN_AND) reduce 412) ((T_BOOLEAN_OR) reduce 412) ((T_COALESCE) reduce 412) ((T_DOUBLE_ARROW) reduce 412) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 412) ((T_LOGICAL_OR) reduce 412) ((T_LOGICAL_XOR) reduce 412) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 412) (("|") reduce 412)) 22662 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 419) ((";") reduce 419) (("<") shift) ((">") shift) (("?") reduce 419) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_BOOLEAN_AND) reduce 419) ((T_BOOLEAN_OR) reduce 419) ((T_COALESCE) reduce 419) ((T_DOUBLE_ARROW) reduce 419) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 419) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 419) ((T_IS_NOT_EQUAL) reduce 419) ((T_IS_NOT_IDENTICAL) reduce 419) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 419) ((T_LOGICAL_OR) reduce 419) ((T_LOGICAL_XOR) reduce 419) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 419) ((T_SR) shift) (("^") reduce 419) (("|") reduce 419)) 22663 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 414) ((";") reduce 414) (("<") shift) ((">") shift) (("?") reduce 414) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_BOOLEAN_AND) reduce 414) ((T_BOOLEAN_OR) reduce 414) ((T_COALESCE) reduce 414) ((T_DOUBLE_ARROW) reduce 414) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 414) ((T_LOGICAL_OR) reduce 414) ((T_LOGICAL_XOR) reduce 414) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 414) (("|") reduce 414)) 22666 ((("%") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) ((":") reduce 93) ((";") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93)) 22667 ((("%") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) ((":") reduce 92) ((";") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92)) 22668 ((("%") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) ((":") reduce 94) ((";") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94)) 22669 ((("%") reduce 470) (("*") reduce 470) (("+") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) ((":") reduce 470) ((";") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_DOUBLE_ARROW) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470)) 22670 ((("%") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) ((":") reduce 91) ((";") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91)) 22671 ((("%") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) ((":") reduce 529) ((";") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 22672 ((("%") reduce 472) (("*") reduce 472) (("+") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) ((":") reduce 472) ((";") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_DOUBLE_ARROW) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472)) 22673 ((("%") reduce 421) (("*") reduce 421) (("+") reduce 421) (("-") reduce 421) ((".") reduce 421) (("/") reduce 421) ((":") reduce 421) ((";") reduce 421) (("<") reduce 421) ((">") reduce 421) (("?") reduce 421) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_BOOLEAN_AND) reduce 421) ((T_BOOLEAN_OR) reduce 421) ((T_COALESCE) reduce 421) ((T_DOUBLE_ARROW) reduce 421) ((T_INSTANCEOF) reduce 421) ((T_IS_EQUAL) reduce 421) ((T_IS_GREATER_OR_EQUAL) reduce 421) ((T_IS_IDENTICAL) reduce 421) ((T_IS_NOT_EQUAL) reduce 421) ((T_IS_NOT_IDENTICAL) reduce 421) ((T_IS_SMALLER_OR_EQUAL) reduce 421) ((T_LOGICAL_AND) reduce 421) ((T_LOGICAL_OR) reduce 421) ((T_LOGICAL_XOR) reduce 421) ((T_POW) reduce 421) ((T_SL) reduce 421) ((T_SPACESHIP) reduce 421) ((T_SR) reduce 421) (("^") reduce 421) (("|") reduce 421)) 22674 ((("%") reduce 471) (("*") reduce 471) (("+") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) ((":") reduce 471) ((";") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_DOUBLE_ARROW) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471)) 22675 ((("%") reduce 473) (("*") reduce 473) (("+") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) ((":") reduce 473) ((";") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_DOUBLE_ARROW) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 22676 ((("%") reduce 534) (("*") reduce 534) (("+") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) ((":") reduce 534) ((";") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_DOUBLE_ARROW) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 22683 ((("%") reduce 536) (("*") reduce 536) (("+") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) ((":") reduce 536) ((";") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_DOUBLE_ARROW) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 22685 ((("%") reduce 535) (("*") reduce 535) (("+") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) ((":") reduce 535) ((";") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_DOUBLE_ARROW) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 22686 ((("%") reduce 540) (("*") reduce 540) (("+") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) ((":") reduce 540) ((";") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_DOUBLE_ARROW) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 22687 ((("%") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) ((":") reduce 544) ((";") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 22688 ((("%") reduce 537) (("*") reduce 537) (("+") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) ((":") reduce 537) ((";") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_DOUBLE_ARROW) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 22689 ((("%") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) ((":") reduce 546) ((";") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 22692 ((("%") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) ((":") reduce 545) ((";") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 22693 ((("%") reduce 538) (("*") reduce 538) (("+") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) ((":") reduce 538) ((";") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_DOUBLE_ARROW) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 22695 ((("%") reduce 539) (("*") reduce 539) (("+") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) ((":") reduce 539) ((";") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_DOUBLE_ARROW) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 22697 ((("%") reduce 474) (("*") reduce 474) (("+") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) ((":") reduce 474) ((";") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_DOUBLE_ARROW) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474)) 22698 ((("%") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) ((":") reduce 531) ((";") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 22701 ((("%") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) ((":") reduce 530) ((";") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 22702 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 426) ((";") reduce 426) (("<") shift) ((">") shift) (("?") reduce 426) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 426) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 426) ((T_LOGICAL_OR) reduce 426) ((T_LOGICAL_XOR) reduce 426) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22703 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 390) ((";") reduce 390) (("<") shift) ((">") shift) (("?") reduce 390) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) reduce 390) ((T_COALESCE) reduce 390) ((T_DOUBLE_ARROW) reduce 390) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 390) ((T_LOGICAL_OR) reduce 390) ((T_LOGICAL_XOR) reduce 390) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22704 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 391) ((";") reduce 391) (("<") shift) ((">") shift) (("?") reduce 391) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 391) ((T_BOOLEAN_OR) reduce 391) ((T_COALESCE) reduce 391) ((T_DOUBLE_ARROW) reduce 391) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 391) ((T_LOGICAL_OR) reduce 391) ((T_LOGICAL_XOR) reduce 391) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22705 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 396) ((";") reduce 396) (("<") shift) ((">") shift) (("?") reduce 396) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_BOOLEAN_AND) reduce 396) ((T_BOOLEAN_OR) reduce 396) ((T_COALESCE) reduce 396) ((T_DOUBLE_ARROW) reduce 396) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 396) ((T_LOGICAL_OR) reduce 396) ((T_LOGICAL_XOR) reduce 396) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 396) (("|") reduce 396)) 22706 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 397) ((";") reduce 397) (("<") shift) ((">") shift) (("?") reduce 397) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_BOOLEAN_AND) reduce 397) ((T_BOOLEAN_OR) reduce 397) ((T_COALESCE) reduce 397) ((T_DOUBLE_ARROW) reduce 397) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 397) ((T_LOGICAL_OR) reduce 397) ((T_LOGICAL_XOR) reduce 397) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 397) (("|") reduce 397)) 22710 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 424) ((";") reduce 424) (("<") shift) ((">") shift) (("?") reduce 424) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 424) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 424) ((T_LOGICAL_OR) reduce 424) ((T_LOGICAL_XOR) reduce 424) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22711 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 425) ((";") reduce 425) (("<") shift) ((">") shift) (("?") reduce 425) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 425) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 425) ((T_LOGICAL_OR) reduce 425) ((T_LOGICAL_XOR) reduce 425) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22712 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 418) ((";") reduce 418) (("<") shift) ((">") shift) (("?") reduce 418) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_BOOLEAN_AND) reduce 418) ((T_BOOLEAN_OR) reduce 418) ((T_COALESCE) reduce 418) ((T_DOUBLE_ARROW) reduce 418) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 418) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 418) ((T_IS_NOT_EQUAL) reduce 418) ((T_IS_NOT_IDENTICAL) reduce 418) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 418) ((T_LOGICAL_OR) reduce 418) ((T_LOGICAL_XOR) reduce 418) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 418) ((T_SR) shift) (("^") reduce 418) (("|") reduce 418)) 22713 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 416) ((";") reduce 416) (("<") shift) ((">") shift) (("?") reduce 416) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_BOOLEAN_AND) reduce 416) ((T_BOOLEAN_OR) reduce 416) ((T_COALESCE) reduce 416) ((T_DOUBLE_ARROW) reduce 416) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 416) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 416) ((T_IS_NOT_EQUAL) reduce 416) ((T_IS_NOT_IDENTICAL) reduce 416) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 416) ((T_LOGICAL_OR) reduce 416) ((T_LOGICAL_XOR) reduce 416) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 416) ((T_SR) shift) (("^") reduce 416) (("|") reduce 416)) 22714 ((("%") reduce 404) (("*") reduce 404) (("+") reduce 404) (("-") reduce 404) ((".") reduce 404) (("/") reduce 404) ((":") reduce 404) ((";") reduce 404) (("<") reduce 404) ((">") reduce 404) (("?") reduce 404) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_BOOLEAN_AND) reduce 404) ((T_BOOLEAN_OR) reduce 404) ((T_COALESCE) reduce 404) ((T_DOUBLE_ARROW) reduce 404) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 404) ((T_IS_GREATER_OR_EQUAL) reduce 404) ((T_IS_IDENTICAL) reduce 404) ((T_IS_NOT_EQUAL) reduce 404) ((T_IS_NOT_IDENTICAL) reduce 404) ((T_IS_SMALLER_OR_EQUAL) reduce 404) ((T_LOGICAL_AND) reduce 404) ((T_LOGICAL_OR) reduce 404) ((T_LOGICAL_XOR) reduce 404) ((T_POW) shift) ((T_SL) reduce 404) ((T_SPACESHIP) reduce 404) ((T_SR) reduce 404) (("^") reduce 404) (("|") reduce 404)) 22715 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 399) (("/") shift) ((":") reduce 399) ((";") reduce 399) (("<") reduce 399) ((">") reduce 399) (("?") reduce 399) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_BOOLEAN_AND) reduce 399) ((T_BOOLEAN_OR) reduce 399) ((T_COALESCE) reduce 399) ((T_DOUBLE_ARROW) reduce 399) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 399) ((T_IS_GREATER_OR_EQUAL) reduce 399) ((T_IS_IDENTICAL) reduce 399) ((T_IS_NOT_EQUAL) reduce 399) ((T_IS_NOT_IDENTICAL) reduce 399) ((T_IS_SMALLER_OR_EQUAL) reduce 399) ((T_LOGICAL_AND) reduce 399) ((T_LOGICAL_OR) reduce 399) ((T_LOGICAL_XOR) reduce 399) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 399) ((T_SR) shift) (("^") reduce 399) (("|") reduce 399)) 22716 ((("%") shift) (("*") shift) (("+") reduce 401) (("-") reduce 401) ((".") reduce 401) (("/") shift) ((":") reduce 401) ((";") reduce 401) (("<") reduce 401) ((">") reduce 401) (("?") reduce 401) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_BOOLEAN_AND) reduce 401) ((T_BOOLEAN_OR) reduce 401) ((T_COALESCE) reduce 401) ((T_DOUBLE_ARROW) reduce 401) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 401) ((T_IS_GREATER_OR_EQUAL) reduce 401) ((T_IS_IDENTICAL) reduce 401) ((T_IS_NOT_EQUAL) reduce 401) ((T_IS_NOT_IDENTICAL) reduce 401) ((T_IS_SMALLER_OR_EQUAL) reduce 401) ((T_LOGICAL_AND) reduce 401) ((T_LOGICAL_OR) reduce 401) ((T_LOGICAL_XOR) reduce 401) ((T_POW) shift) ((T_SL) reduce 401) ((T_SPACESHIP) reduce 401) ((T_SR) reduce 401) (("^") reduce 401) (("|") reduce 401)) 22717 ((("%") shift) (("*") shift) (("+") reduce 400) (("-") reduce 400) ((".") reduce 400) (("/") shift) ((":") reduce 400) ((";") reduce 400) (("<") reduce 400) ((">") reduce 400) (("?") reduce 400) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_BOOLEAN_AND) reduce 400) ((T_BOOLEAN_OR) reduce 400) ((T_COALESCE) reduce 400) ((T_DOUBLE_ARROW) reduce 400) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 400) ((T_IS_GREATER_OR_EQUAL) reduce 400) ((T_IS_IDENTICAL) reduce 400) ((T_IS_NOT_EQUAL) reduce 400) ((T_IS_NOT_IDENTICAL) reduce 400) ((T_IS_SMALLER_OR_EQUAL) reduce 400) ((T_LOGICAL_AND) reduce 400) ((T_LOGICAL_OR) reduce 400) ((T_LOGICAL_XOR) reduce 400) ((T_POW) shift) ((T_SL) reduce 400) ((T_SPACESHIP) reduce 400) ((T_SR) reduce 400) (("^") reduce 400) (("|") reduce 400)) 22718 ((("%") reduce 402) (("*") reduce 402) (("+") reduce 402) (("-") reduce 402) ((".") reduce 402) (("/") reduce 402) ((":") reduce 402) ((";") reduce 402) (("<") reduce 402) ((">") reduce 402) (("?") reduce 402) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_BOOLEAN_AND) reduce 402) ((T_BOOLEAN_OR) reduce 402) ((T_COALESCE) reduce 402) ((T_DOUBLE_ARROW) reduce 402) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 402) ((T_IS_GREATER_OR_EQUAL) reduce 402) ((T_IS_IDENTICAL) reduce 402) ((T_IS_NOT_EQUAL) reduce 402) ((T_IS_NOT_IDENTICAL) reduce 402) ((T_IS_SMALLER_OR_EQUAL) reduce 402) ((T_LOGICAL_AND) reduce 402) ((T_LOGICAL_OR) reduce 402) ((T_LOGICAL_XOR) reduce 402) ((T_POW) shift) ((T_SL) reduce 402) ((T_SPACESHIP) reduce 402) ((T_SR) reduce 402) (("^") reduce 402) (("|") reduce 402)) 22719 ((("%") reduce 405) (("*") reduce 405) (("+") reduce 405) (("-") reduce 405) ((".") reduce 405) (("/") reduce 405) ((":") reduce 405) ((";") reduce 405) (("<") reduce 405) ((">") reduce 405) (("?") reduce 405) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_BOOLEAN_AND) reduce 405) ((T_BOOLEAN_OR) reduce 405) ((T_COALESCE) reduce 405) ((T_DOUBLE_ARROW) reduce 405) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 405) ((T_IS_GREATER_OR_EQUAL) reduce 405) ((T_IS_IDENTICAL) reduce 405) ((T_IS_NOT_EQUAL) reduce 405) ((T_IS_NOT_IDENTICAL) reduce 405) ((T_IS_SMALLER_OR_EQUAL) reduce 405) ((T_LOGICAL_AND) reduce 405) ((T_LOGICAL_OR) reduce 405) ((T_LOGICAL_XOR) reduce 405) ((T_POW) shift) ((T_SL) reduce 405) ((T_SPACESHIP) reduce 405) ((T_SR) reduce 405) (("^") reduce 405) (("|") reduce 405)) 22721 ((("%") reduce 73) (("(") reduce 73) (("*") reduce 73) (("+") reduce 73) (("-") reduce 73) ((".") reduce 73) (("/") reduce 73) ((":") reduce 73) ((";") reduce 73) (("<") reduce 73) ((">") reduce 73) (("?") reduce 73) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_BOOLEAN_AND) reduce 73) ((T_BOOLEAN_OR) reduce 73) ((T_COALESCE) reduce 73) ((T_DOUBLE_ARROW) reduce 73) ((T_INSTANCEOF) reduce 73) ((T_IS_EQUAL) reduce 73) ((T_IS_GREATER_OR_EQUAL) reduce 73) ((T_IS_IDENTICAL) reduce 73) ((T_IS_NOT_EQUAL) reduce 73) ((T_IS_NOT_IDENTICAL) reduce 73) ((T_IS_SMALLER_OR_EQUAL) reduce 73) ((T_LOGICAL_AND) reduce 73) ((T_LOGICAL_OR) reduce 73) ((T_LOGICAL_XOR) reduce 73) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 73) ((T_OBJECT_OPERATOR) reduce 73) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 73) ((T_POW) reduce 73) ((T_SL) reduce 73) ((T_SPACESHIP) reduce 73) ((T_SR) reduce 73) (("[") reduce 73) (("^") reduce 73) (("{") reduce 73) (("|") reduce 73)) 22722 ((("%") reduce 52) (("(") reduce 52) (("*") reduce 52) (("+") reduce 52) (("-") reduce 52) ((".") reduce 52) (("/") reduce 52) ((":") reduce 52) ((";") reduce 52) (("<") reduce 52) ((">") reduce 52) (("?") reduce 52) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_BOOLEAN_AND) reduce 52) ((T_BOOLEAN_OR) reduce 52) ((T_COALESCE) reduce 52) ((T_DOUBLE_ARROW) reduce 52) ((T_INSTANCEOF) reduce 52) ((T_IS_EQUAL) reduce 52) ((T_IS_GREATER_OR_EQUAL) reduce 52) ((T_IS_IDENTICAL) reduce 52) ((T_IS_NOT_EQUAL) reduce 52) ((T_IS_NOT_IDENTICAL) reduce 52) ((T_IS_SMALLER_OR_EQUAL) reduce 52) ((T_LOGICAL_AND) reduce 52) ((T_LOGICAL_OR) reduce 52) ((T_LOGICAL_XOR) reduce 52) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 52) ((T_OBJECT_OPERATOR) reduce 52) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 52) ((T_POW) reduce 52) ((T_SL) reduce 52) ((T_SPACESHIP) reduce 52) ((T_SR) reduce 52) (("[") reduce 52) (("^") reduce 52) (("{") reduce 52) (("|") reduce 52)) 22723 ((("%") reduce 27) (("(") reduce 27) (("*") reduce 27) (("+") reduce 27) (("-") reduce 27) ((".") reduce 27) (("/") reduce 27) ((":") reduce 27) ((";") reduce 27) (("<") reduce 27) ((">") reduce 27) (("?") reduce 27) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_BOOLEAN_AND) reduce 27) ((T_BOOLEAN_OR) reduce 27) ((T_COALESCE) reduce 27) ((T_DOUBLE_ARROW) reduce 27) ((T_INSTANCEOF) reduce 27) ((T_IS_EQUAL) reduce 27) ((T_IS_GREATER_OR_EQUAL) reduce 27) ((T_IS_IDENTICAL) reduce 27) ((T_IS_NOT_EQUAL) reduce 27) ((T_IS_NOT_IDENTICAL) reduce 27) ((T_IS_SMALLER_OR_EQUAL) reduce 27) ((T_LOGICAL_AND) reduce 27) ((T_LOGICAL_OR) reduce 27) ((T_LOGICAL_XOR) reduce 27) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 27) ((T_OBJECT_OPERATOR) reduce 27) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 27) ((T_POW) reduce 27) ((T_SL) reduce 27) ((T_SPACESHIP) reduce 27) ((T_SR) reduce 27) (("[") reduce 27) (("^") reduce 27) (("{") reduce 27) (("|") reduce 27)) 22724 ((("%") reduce 51) (("(") reduce 51) (("*") reduce 51) (("+") reduce 51) (("-") reduce 51) ((".") reduce 51) (("/") reduce 51) ((":") reduce 51) ((";") reduce 51) (("<") reduce 51) ((">") reduce 51) (("?") reduce 51) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_BOOLEAN_AND) reduce 51) ((T_BOOLEAN_OR) reduce 51) ((T_COALESCE) reduce 51) ((T_DOUBLE_ARROW) reduce 51) ((T_INSTANCEOF) reduce 51) ((T_IS_EQUAL) reduce 51) ((T_IS_GREATER_OR_EQUAL) reduce 51) ((T_IS_IDENTICAL) reduce 51) ((T_IS_NOT_EQUAL) reduce 51) ((T_IS_NOT_IDENTICAL) reduce 51) ((T_IS_SMALLER_OR_EQUAL) reduce 51) ((T_LOGICAL_AND) reduce 51) ((T_LOGICAL_OR) reduce 51) ((T_LOGICAL_XOR) reduce 51) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 51) ((T_OBJECT_OPERATOR) reduce 51) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 51) ((T_POW) reduce 51) ((T_SL) reduce 51) ((T_SPACESHIP) reduce 51) ((T_SR) reduce 51) (("[") reduce 51) (("^") reduce 51) (("{") reduce 51) (("|") reduce 51)) 22725 ((("%") reduce 53) (("(") reduce 53) (("*") reduce 53) (("+") reduce 53) (("-") reduce 53) ((".") reduce 53) (("/") reduce 53) ((":") reduce 53) ((";") reduce 53) (("<") reduce 53) ((">") reduce 53) (("?") reduce 53) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_BOOLEAN_AND) reduce 53) ((T_BOOLEAN_OR) reduce 53) ((T_COALESCE) reduce 53) ((T_DOUBLE_ARROW) reduce 53) ((T_INSTANCEOF) reduce 53) ((T_IS_EQUAL) reduce 53) ((T_IS_GREATER_OR_EQUAL) reduce 53) ((T_IS_IDENTICAL) reduce 53) ((T_IS_NOT_EQUAL) reduce 53) ((T_IS_NOT_IDENTICAL) reduce 53) ((T_IS_SMALLER_OR_EQUAL) reduce 53) ((T_LOGICAL_AND) reduce 53) ((T_LOGICAL_OR) reduce 53) ((T_LOGICAL_XOR) reduce 53) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 53) ((T_OBJECT_OPERATOR) reduce 53) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 53) ((T_POW) reduce 53) ((T_SL) reduce 53) ((T_SPACESHIP) reduce 53) ((T_SR) reduce 53) (("[") reduce 53) (("^") reduce 53) (("{") reduce 53) (("|") reduce 53)) 22726 ((("%") reduce 49) (("(") reduce 49) (("*") reduce 49) (("+") reduce 49) (("-") reduce 49) ((".") reduce 49) (("/") reduce 49) ((":") reduce 49) ((";") reduce 49) (("<") reduce 49) ((">") reduce 49) (("?") reduce 49) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_BOOLEAN_AND) reduce 49) ((T_BOOLEAN_OR) reduce 49) ((T_COALESCE) reduce 49) ((T_DOUBLE_ARROW) reduce 49) ((T_INSTANCEOF) reduce 49) ((T_IS_EQUAL) reduce 49) ((T_IS_GREATER_OR_EQUAL) reduce 49) ((T_IS_IDENTICAL) reduce 49) ((T_IS_NOT_EQUAL) reduce 49) ((T_IS_NOT_IDENTICAL) reduce 49) ((T_IS_SMALLER_OR_EQUAL) reduce 49) ((T_LOGICAL_AND) reduce 49) ((T_LOGICAL_OR) reduce 49) ((T_LOGICAL_XOR) reduce 49) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 49) ((T_OBJECT_OPERATOR) reduce 49) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 49) ((T_POW) reduce 49) ((T_SL) reduce 49) ((T_SPACESHIP) reduce 49) ((T_SR) reduce 49) (("[") reduce 49) (("^") reduce 49) (("{") reduce 49) (("|") reduce 49)) 22727 ((("%") reduce 29) (("(") reduce 29) (("*") reduce 29) (("+") reduce 29) (("-") reduce 29) ((".") reduce 29) (("/") reduce 29) ((":") reduce 29) ((";") reduce 29) (("<") reduce 29) ((">") reduce 29) (("?") reduce 29) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_BOOLEAN_AND) reduce 29) ((T_BOOLEAN_OR) reduce 29) ((T_COALESCE) reduce 29) ((T_DOUBLE_ARROW) reduce 29) ((T_INSTANCEOF) reduce 29) ((T_IS_EQUAL) reduce 29) ((T_IS_GREATER_OR_EQUAL) reduce 29) ((T_IS_IDENTICAL) reduce 29) ((T_IS_NOT_EQUAL) reduce 29) ((T_IS_NOT_IDENTICAL) reduce 29) ((T_IS_SMALLER_OR_EQUAL) reduce 29) ((T_LOGICAL_AND) reduce 29) ((T_LOGICAL_OR) reduce 29) ((T_LOGICAL_XOR) reduce 29) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 29) ((T_OBJECT_OPERATOR) reduce 29) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 29) ((T_POW) reduce 29) ((T_SL) reduce 29) ((T_SPACESHIP) reduce 29) ((T_SR) reduce 29) (("[") reduce 29) (("^") reduce 29) (("{") reduce 29) (("|") reduce 29)) 22728 ((("%") reduce 59) (("(") reduce 59) (("*") reduce 59) (("+") reduce 59) (("-") reduce 59) ((".") reduce 59) (("/") reduce 59) ((":") reduce 59) ((";") reduce 59) (("<") reduce 59) ((">") reduce 59) (("?") reduce 59) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_BOOLEAN_AND) reduce 59) ((T_BOOLEAN_OR) reduce 59) ((T_COALESCE) reduce 59) ((T_DOUBLE_ARROW) reduce 59) ((T_INSTANCEOF) reduce 59) ((T_IS_EQUAL) reduce 59) ((T_IS_GREATER_OR_EQUAL) reduce 59) ((T_IS_IDENTICAL) reduce 59) ((T_IS_NOT_EQUAL) reduce 59) ((T_IS_NOT_IDENTICAL) reduce 59) ((T_IS_SMALLER_OR_EQUAL) reduce 59) ((T_LOGICAL_AND) reduce 59) ((T_LOGICAL_OR) reduce 59) ((T_LOGICAL_XOR) reduce 59) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 59) ((T_OBJECT_OPERATOR) reduce 59) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 59) ((T_POW) reduce 59) ((T_SL) reduce 59) ((T_SPACESHIP) reduce 59) ((T_SR) reduce 59) (("[") reduce 59) (("^") reduce 59) (("{") reduce 59) (("|") reduce 59)) 22729 ((("%") reduce 60) (("(") reduce 60) (("*") reduce 60) (("+") reduce 60) (("-") reduce 60) ((".") reduce 60) (("/") reduce 60) ((":") reduce 60) ((";") reduce 60) (("<") reduce 60) ((">") reduce 60) (("?") reduce 60) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_BOOLEAN_AND) reduce 60) ((T_BOOLEAN_OR) reduce 60) ((T_COALESCE) reduce 60) ((T_DOUBLE_ARROW) reduce 60) ((T_INSTANCEOF) reduce 60) ((T_IS_EQUAL) reduce 60) ((T_IS_GREATER_OR_EQUAL) reduce 60) ((T_IS_IDENTICAL) reduce 60) ((T_IS_NOT_EQUAL) reduce 60) ((T_IS_NOT_IDENTICAL) reduce 60) ((T_IS_SMALLER_OR_EQUAL) reduce 60) ((T_LOGICAL_AND) reduce 60) ((T_LOGICAL_OR) reduce 60) ((T_LOGICAL_XOR) reduce 60) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 60) ((T_OBJECT_OPERATOR) reduce 60) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 60) ((T_POW) reduce 60) ((T_SL) reduce 60) ((T_SPACESHIP) reduce 60) ((T_SR) reduce 60) (("[") reduce 60) (("^") reduce 60) (("{") reduce 60) (("|") reduce 60)) 22730 ((("%") reduce 11) (("(") reduce 11) (("*") reduce 11) (("+") reduce 11) (("-") reduce 11) ((".") reduce 11) (("/") reduce 11) ((":") reduce 11) ((";") reduce 11) (("<") reduce 11) ((">") reduce 11) (("?") reduce 11) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_BOOLEAN_AND) reduce 11) ((T_BOOLEAN_OR) reduce 11) ((T_COALESCE) reduce 11) ((T_DOUBLE_ARROW) reduce 11) ((T_INSTANCEOF) reduce 11) ((T_IS_EQUAL) reduce 11) ((T_IS_GREATER_OR_EQUAL) reduce 11) ((T_IS_IDENTICAL) reduce 11) ((T_IS_NOT_EQUAL) reduce 11) ((T_IS_NOT_IDENTICAL) reduce 11) ((T_IS_SMALLER_OR_EQUAL) reduce 11) ((T_LOGICAL_AND) reduce 11) ((T_LOGICAL_OR) reduce 11) ((T_LOGICAL_XOR) reduce 11) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 11) ((T_OBJECT_OPERATOR) reduce 11) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 11) ((T_POW) reduce 11) ((T_SL) reduce 11) ((T_SPACESHIP) reduce 11) ((T_SR) reduce 11) (("[") reduce 11) (("^") reduce 11) (("{") reduce 11) (("|") reduce 11)) 22731 ((("%") reduce 42) (("(") reduce 42) (("*") reduce 42) (("+") reduce 42) (("-") reduce 42) ((".") reduce 42) (("/") reduce 42) ((":") reduce 42) ((";") reduce 42) (("<") reduce 42) ((">") reduce 42) (("?") reduce 42) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_BOOLEAN_AND) reduce 42) ((T_BOOLEAN_OR) reduce 42) ((T_COALESCE) reduce 42) ((T_DOUBLE_ARROW) reduce 42) ((T_INSTANCEOF) reduce 42) ((T_IS_EQUAL) reduce 42) ((T_IS_GREATER_OR_EQUAL) reduce 42) ((T_IS_IDENTICAL) reduce 42) ((T_IS_NOT_EQUAL) reduce 42) ((T_IS_NOT_IDENTICAL) reduce 42) ((T_IS_SMALLER_OR_EQUAL) reduce 42) ((T_LOGICAL_AND) reduce 42) ((T_LOGICAL_OR) reduce 42) ((T_LOGICAL_XOR) reduce 42) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 42) ((T_OBJECT_OPERATOR) reduce 42) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 42) ((T_POW) reduce 42) ((T_SL) reduce 42) ((T_SPACESHIP) reduce 42) ((T_SR) reduce 42) (("[") reduce 42) (("^") reduce 42) (("{") reduce 42) (("|") reduce 42)) 22732 ((("%") reduce 39) (("(") reduce 39) (("*") reduce 39) (("+") reduce 39) (("-") reduce 39) ((".") reduce 39) (("/") reduce 39) ((":") reduce 39) ((";") reduce 39) (("<") reduce 39) ((">") reduce 39) (("?") reduce 39) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_BOOLEAN_AND) reduce 39) ((T_BOOLEAN_OR) reduce 39) ((T_COALESCE) reduce 39) ((T_DOUBLE_ARROW) reduce 39) ((T_INSTANCEOF) reduce 39) ((T_IS_EQUAL) reduce 39) ((T_IS_GREATER_OR_EQUAL) reduce 39) ((T_IS_IDENTICAL) reduce 39) ((T_IS_NOT_EQUAL) reduce 39) ((T_IS_NOT_IDENTICAL) reduce 39) ((T_IS_SMALLER_OR_EQUAL) reduce 39) ((T_LOGICAL_AND) reduce 39) ((T_LOGICAL_OR) reduce 39) ((T_LOGICAL_XOR) reduce 39) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 39) ((T_OBJECT_OPERATOR) reduce 39) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 39) ((T_POW) reduce 39) ((T_SL) reduce 39) ((T_SPACESHIP) reduce 39) ((T_SR) reduce 39) (("[") reduce 39) (("^") reduce 39) (("{") reduce 39) (("|") reduce 39)) 22733 ((("%") reduce 25) (("(") reduce 25) (("*") reduce 25) (("+") reduce 25) (("-") reduce 25) ((".") reduce 25) (("/") reduce 25) ((":") reduce 25) ((";") reduce 25) (("<") reduce 25) ((">") reduce 25) (("?") reduce 25) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_BOOLEAN_AND) reduce 25) ((T_BOOLEAN_OR) reduce 25) ((T_COALESCE) reduce 25) ((T_DOUBLE_ARROW) reduce 25) ((T_INSTANCEOF) reduce 25) ((T_IS_EQUAL) reduce 25) ((T_IS_GREATER_OR_EQUAL) reduce 25) ((T_IS_IDENTICAL) reduce 25) ((T_IS_NOT_EQUAL) reduce 25) ((T_IS_NOT_IDENTICAL) reduce 25) ((T_IS_SMALLER_OR_EQUAL) reduce 25) ((T_LOGICAL_AND) reduce 25) ((T_LOGICAL_OR) reduce 25) ((T_LOGICAL_XOR) reduce 25) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 25) ((T_OBJECT_OPERATOR) reduce 25) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 25) ((T_POW) reduce 25) ((T_SL) reduce 25) ((T_SPACESHIP) reduce 25) ((T_SR) reduce 25) (("[") reduce 25) (("^") reduce 25) (("{") reduce 25) (("|") reduce 25)) 22734 ((("%") reduce 50) (("(") reduce 50) (("*") reduce 50) (("+") reduce 50) (("-") reduce 50) ((".") reduce 50) (("/") reduce 50) ((":") reduce 50) ((";") reduce 50) (("<") reduce 50) ((">") reduce 50) (("?") reduce 50) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_BOOLEAN_AND) reduce 50) ((T_BOOLEAN_OR) reduce 50) ((T_COALESCE) reduce 50) ((T_DOUBLE_ARROW) reduce 50) ((T_INSTANCEOF) reduce 50) ((T_IS_EQUAL) reduce 50) ((T_IS_GREATER_OR_EQUAL) reduce 50) ((T_IS_IDENTICAL) reduce 50) ((T_IS_NOT_EQUAL) reduce 50) ((T_IS_NOT_IDENTICAL) reduce 50) ((T_IS_SMALLER_OR_EQUAL) reduce 50) ((T_LOGICAL_AND) reduce 50) ((T_LOGICAL_OR) reduce 50) ((T_LOGICAL_XOR) reduce 50) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 50) ((T_OBJECT_OPERATOR) reduce 50) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 50) ((T_POW) reduce 50) ((T_SL) reduce 50) ((T_SPACESHIP) reduce 50) ((T_SR) reduce 50) (("[") reduce 50) (("^") reduce 50) (("{") reduce 50) (("|") reduce 50)) 22735 ((("%") reduce 66) (("(") reduce 66) (("*") reduce 66) (("+") reduce 66) (("-") reduce 66) ((".") reduce 66) (("/") reduce 66) ((":") reduce 66) ((";") reduce 66) (("<") reduce 66) ((">") reduce 66) (("?") reduce 66) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_BOOLEAN_AND) reduce 66) ((T_BOOLEAN_OR) reduce 66) ((T_COALESCE) reduce 66) ((T_DOUBLE_ARROW) reduce 66) ((T_INSTANCEOF) reduce 66) ((T_IS_EQUAL) reduce 66) ((T_IS_GREATER_OR_EQUAL) reduce 66) ((T_IS_IDENTICAL) reduce 66) ((T_IS_NOT_EQUAL) reduce 66) ((T_IS_NOT_IDENTICAL) reduce 66) ((T_IS_SMALLER_OR_EQUAL) reduce 66) ((T_LOGICAL_AND) reduce 66) ((T_LOGICAL_OR) reduce 66) ((T_LOGICAL_XOR) reduce 66) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 66) ((T_OBJECT_OPERATOR) reduce 66) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 66) ((T_POW) reduce 66) ((T_SL) reduce 66) ((T_SPACESHIP) reduce 66) ((T_SR) reduce 66) (("[") reduce 66) (("^") reduce 66) (("{") reduce 66) (("|") reduce 66)) 22736 ((("%") reduce 18) (("(") reduce 18) (("*") reduce 18) (("+") reduce 18) (("-") reduce 18) ((".") reduce 18) (("/") reduce 18) ((":") reduce 18) ((";") reduce 18) (("<") reduce 18) ((">") reduce 18) (("?") reduce 18) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_BOOLEAN_AND) reduce 18) ((T_BOOLEAN_OR) reduce 18) ((T_COALESCE) reduce 18) ((T_DOUBLE_ARROW) reduce 18) ((T_INSTANCEOF) reduce 18) ((T_IS_EQUAL) reduce 18) ((T_IS_GREATER_OR_EQUAL) reduce 18) ((T_IS_IDENTICAL) reduce 18) ((T_IS_NOT_EQUAL) reduce 18) ((T_IS_NOT_IDENTICAL) reduce 18) ((T_IS_SMALLER_OR_EQUAL) reduce 18) ((T_LOGICAL_AND) reduce 18) ((T_LOGICAL_OR) reduce 18) ((T_LOGICAL_XOR) reduce 18) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 18) ((T_OBJECT_OPERATOR) reduce 18) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 18) ((T_POW) reduce 18) ((T_SL) reduce 18) ((T_SPACESHIP) reduce 18) ((T_SR) reduce 18) (("[") reduce 18) (("^") reduce 18) (("{") reduce 18) (("|") reduce 18)) 22737 ((("%") reduce 17) (("(") reduce 17) (("*") reduce 17) (("+") reduce 17) (("-") reduce 17) ((".") reduce 17) (("/") reduce 17) ((":") reduce 17) ((";") reduce 17) (("<") reduce 17) ((">") reduce 17) (("?") reduce 17) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_BOOLEAN_AND) reduce 17) ((T_BOOLEAN_OR) reduce 17) ((T_COALESCE) reduce 17) ((T_DOUBLE_ARROW) reduce 17) ((T_INSTANCEOF) reduce 17) ((T_IS_EQUAL) reduce 17) ((T_IS_GREATER_OR_EQUAL) reduce 17) ((T_IS_IDENTICAL) reduce 17) ((T_IS_NOT_EQUAL) reduce 17) ((T_IS_NOT_IDENTICAL) reduce 17) ((T_IS_SMALLER_OR_EQUAL) reduce 17) ((T_LOGICAL_AND) reduce 17) ((T_LOGICAL_OR) reduce 17) ((T_LOGICAL_XOR) reduce 17) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 17) ((T_OBJECT_OPERATOR) reduce 17) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 17) ((T_POW) reduce 17) ((T_SL) reduce 17) ((T_SPACESHIP) reduce 17) ((T_SR) reduce 17) (("[") reduce 17) (("^") reduce 17) (("{") reduce 17) (("|") reduce 17)) 22738 ((("%") reduce 15) (("(") reduce 15) (("*") reduce 15) (("+") reduce 15) (("-") reduce 15) ((".") reduce 15) (("/") reduce 15) ((":") reduce 15) ((";") reduce 15) (("<") reduce 15) ((">") reduce 15) (("?") reduce 15) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_BOOLEAN_AND) reduce 15) ((T_BOOLEAN_OR) reduce 15) ((T_COALESCE) reduce 15) ((T_DOUBLE_ARROW) reduce 15) ((T_INSTANCEOF) reduce 15) ((T_IS_EQUAL) reduce 15) ((T_IS_GREATER_OR_EQUAL) reduce 15) ((T_IS_IDENTICAL) reduce 15) ((T_IS_NOT_EQUAL) reduce 15) ((T_IS_NOT_IDENTICAL) reduce 15) ((T_IS_SMALLER_OR_EQUAL) reduce 15) ((T_LOGICAL_AND) reduce 15) ((T_LOGICAL_OR) reduce 15) ((T_LOGICAL_XOR) reduce 15) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 15) ((T_OBJECT_OPERATOR) reduce 15) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 15) ((T_POW) reduce 15) ((T_SL) reduce 15) ((T_SPACESHIP) reduce 15) ((T_SR) reduce 15) (("[") reduce 15) (("^") reduce 15) (("{") reduce 15) (("|") reduce 15)) 22739 ((("%") reduce 14) (("(") reduce 14) (("*") reduce 14) (("+") reduce 14) (("-") reduce 14) ((".") reduce 14) (("/") reduce 14) ((":") reduce 14) ((";") reduce 14) (("<") reduce 14) ((">") reduce 14) (("?") reduce 14) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_BOOLEAN_AND) reduce 14) ((T_BOOLEAN_OR) reduce 14) ((T_COALESCE) reduce 14) ((T_DOUBLE_ARROW) reduce 14) ((T_INSTANCEOF) reduce 14) ((T_IS_EQUAL) reduce 14) ((T_IS_GREATER_OR_EQUAL) reduce 14) ((T_IS_IDENTICAL) reduce 14) ((T_IS_NOT_EQUAL) reduce 14) ((T_IS_NOT_IDENTICAL) reduce 14) ((T_IS_SMALLER_OR_EQUAL) reduce 14) ((T_LOGICAL_AND) reduce 14) ((T_LOGICAL_OR) reduce 14) ((T_LOGICAL_XOR) reduce 14) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 14) ((T_OBJECT_OPERATOR) reduce 14) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 14) ((T_POW) reduce 14) ((T_SL) reduce 14) ((T_SPACESHIP) reduce 14) ((T_SR) reduce 14) (("[") reduce 14) (("^") reduce 14) (("{") reduce 14) (("|") reduce 14)) 22740 ((("%") reduce 38) (("(") reduce 38) (("*") reduce 38) (("+") reduce 38) (("-") reduce 38) ((".") reduce 38) (("/") reduce 38) ((":") reduce 38) ((";") reduce 38) (("<") reduce 38) ((">") reduce 38) (("?") reduce 38) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_BOOLEAN_AND) reduce 38) ((T_BOOLEAN_OR) reduce 38) ((T_COALESCE) reduce 38) ((T_DOUBLE_ARROW) reduce 38) ((T_INSTANCEOF) reduce 38) ((T_IS_EQUAL) reduce 38) ((T_IS_GREATER_OR_EQUAL) reduce 38) ((T_IS_IDENTICAL) reduce 38) ((T_IS_NOT_EQUAL) reduce 38) ((T_IS_NOT_IDENTICAL) reduce 38) ((T_IS_SMALLER_OR_EQUAL) reduce 38) ((T_LOGICAL_AND) reduce 38) ((T_LOGICAL_OR) reduce 38) ((T_LOGICAL_XOR) reduce 38) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 38) ((T_OBJECT_OPERATOR) reduce 38) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 38) ((T_POW) reduce 38) ((T_SL) reduce 38) ((T_SPACESHIP) reduce 38) ((T_SR) reduce 38) (("[") reduce 38) (("^") reduce 38) (("{") reduce 38) (("|") reduce 38)) 22741 ((("%") reduce 26) (("(") reduce 26) (("*") reduce 26) (("+") reduce 26) (("-") reduce 26) ((".") reduce 26) (("/") reduce 26) ((":") reduce 26) ((";") reduce 26) (("<") reduce 26) ((">") reduce 26) (("?") reduce 26) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_BOOLEAN_AND) reduce 26) ((T_BOOLEAN_OR) reduce 26) ((T_COALESCE) reduce 26) ((T_DOUBLE_ARROW) reduce 26) ((T_INSTANCEOF) reduce 26) ((T_IS_EQUAL) reduce 26) ((T_IS_GREATER_OR_EQUAL) reduce 26) ((T_IS_IDENTICAL) reduce 26) ((T_IS_NOT_EQUAL) reduce 26) ((T_IS_NOT_IDENTICAL) reduce 26) ((T_IS_SMALLER_OR_EQUAL) reduce 26) ((T_LOGICAL_AND) reduce 26) ((T_LOGICAL_OR) reduce 26) ((T_LOGICAL_XOR) reduce 26) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 26) ((T_OBJECT_OPERATOR) reduce 26) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 26) ((T_POW) reduce 26) ((T_SL) reduce 26) ((T_SPACESHIP) reduce 26) ((T_SR) reduce 26) (("[") reduce 26) (("^") reduce 26) (("{") reduce 26) (("|") reduce 26)) 22742 ((("%") reduce 22) (("(") reduce 22) (("*") reduce 22) (("+") reduce 22) (("-") reduce 22) ((".") reduce 22) (("/") reduce 22) ((":") reduce 22) ((";") reduce 22) (("<") reduce 22) ((">") reduce 22) (("?") reduce 22) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_BOOLEAN_AND) reduce 22) ((T_BOOLEAN_OR) reduce 22) ((T_COALESCE) reduce 22) ((T_DOUBLE_ARROW) reduce 22) ((T_INSTANCEOF) reduce 22) ((T_IS_EQUAL) reduce 22) ((T_IS_GREATER_OR_EQUAL) reduce 22) ((T_IS_IDENTICAL) reduce 22) ((T_IS_NOT_EQUAL) reduce 22) ((T_IS_NOT_IDENTICAL) reduce 22) ((T_IS_SMALLER_OR_EQUAL) reduce 22) ((T_LOGICAL_AND) reduce 22) ((T_LOGICAL_OR) reduce 22) ((T_LOGICAL_XOR) reduce 22) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 22) ((T_OBJECT_OPERATOR) reduce 22) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 22) ((T_POW) reduce 22) ((T_SL) reduce 22) ((T_SPACESHIP) reduce 22) ((T_SR) reduce 22) (("[") reduce 22) (("^") reduce 22) (("{") reduce 22) (("|") reduce 22)) 22743 ((("%") reduce 24) (("(") reduce 24) (("*") reduce 24) (("+") reduce 24) (("-") reduce 24) ((".") reduce 24) (("/") reduce 24) ((":") reduce 24) ((";") reduce 24) (("<") reduce 24) ((">") reduce 24) (("?") reduce 24) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_BOOLEAN_AND) reduce 24) ((T_BOOLEAN_OR) reduce 24) ((T_COALESCE) reduce 24) ((T_DOUBLE_ARROW) reduce 24) ((T_INSTANCEOF) reduce 24) ((T_IS_EQUAL) reduce 24) ((T_IS_GREATER_OR_EQUAL) reduce 24) ((T_IS_IDENTICAL) reduce 24) ((T_IS_NOT_EQUAL) reduce 24) ((T_IS_NOT_IDENTICAL) reduce 24) ((T_IS_SMALLER_OR_EQUAL) reduce 24) ((T_LOGICAL_AND) reduce 24) ((T_LOGICAL_OR) reduce 24) ((T_LOGICAL_XOR) reduce 24) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 24) ((T_OBJECT_OPERATOR) reduce 24) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 24) ((T_POW) reduce 24) ((T_SL) reduce 24) ((T_SPACESHIP) reduce 24) ((T_SR) reduce 24) (("[") reduce 24) (("^") reduce 24) (("{") reduce 24) (("|") reduce 24)) 22744 ((("%") reduce 16) (("(") reduce 16) (("*") reduce 16) (("+") reduce 16) (("-") reduce 16) ((".") reduce 16) (("/") reduce 16) ((":") reduce 16) ((";") reduce 16) (("<") reduce 16) ((">") reduce 16) (("?") reduce 16) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_BOOLEAN_AND) reduce 16) ((T_BOOLEAN_OR) reduce 16) ((T_COALESCE) reduce 16) ((T_DOUBLE_ARROW) reduce 16) ((T_INSTANCEOF) reduce 16) ((T_IS_EQUAL) reduce 16) ((T_IS_GREATER_OR_EQUAL) reduce 16) ((T_IS_IDENTICAL) reduce 16) ((T_IS_NOT_EQUAL) reduce 16) ((T_IS_NOT_IDENTICAL) reduce 16) ((T_IS_SMALLER_OR_EQUAL) reduce 16) ((T_LOGICAL_AND) reduce 16) ((T_LOGICAL_OR) reduce 16) ((T_LOGICAL_XOR) reduce 16) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 16) ((T_OBJECT_OPERATOR) reduce 16) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 16) ((T_POW) reduce 16) ((T_SL) reduce 16) ((T_SPACESHIP) reduce 16) ((T_SR) reduce 16) (("[") reduce 16) (("^") reduce 16) (("{") reduce 16) (("|") reduce 16)) 22745 ((("%") reduce 48) (("(") reduce 48) (("*") reduce 48) (("+") reduce 48) (("-") reduce 48) ((".") reduce 48) (("/") reduce 48) ((":") reduce 48) ((";") reduce 48) (("<") reduce 48) ((">") reduce 48) (("?") reduce 48) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_BOOLEAN_AND) reduce 48) ((T_BOOLEAN_OR) reduce 48) ((T_COALESCE) reduce 48) ((T_DOUBLE_ARROW) reduce 48) ((T_INSTANCEOF) reduce 48) ((T_IS_EQUAL) reduce 48) ((T_IS_GREATER_OR_EQUAL) reduce 48) ((T_IS_IDENTICAL) reduce 48) ((T_IS_NOT_EQUAL) reduce 48) ((T_IS_NOT_IDENTICAL) reduce 48) ((T_IS_SMALLER_OR_EQUAL) reduce 48) ((T_LOGICAL_AND) reduce 48) ((T_LOGICAL_OR) reduce 48) ((T_LOGICAL_XOR) reduce 48) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 48) ((T_OBJECT_OPERATOR) reduce 48) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 48) ((T_POW) reduce 48) ((T_SL) reduce 48) ((T_SPACESHIP) reduce 48) ((T_SR) reduce 48) (("[") reduce 48) (("^") reduce 48) (("{") reduce 48) (("|") reduce 48)) 22746 ((("%") reduce 20) (("(") reduce 20) (("*") reduce 20) (("+") reduce 20) (("-") reduce 20) ((".") reduce 20) (("/") reduce 20) ((":") reduce 20) ((";") reduce 20) (("<") reduce 20) ((">") reduce 20) (("?") reduce 20) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_BOOLEAN_AND) reduce 20) ((T_BOOLEAN_OR) reduce 20) ((T_COALESCE) reduce 20) ((T_DOUBLE_ARROW) reduce 20) ((T_INSTANCEOF) reduce 20) ((T_IS_EQUAL) reduce 20) ((T_IS_GREATER_OR_EQUAL) reduce 20) ((T_IS_IDENTICAL) reduce 20) ((T_IS_NOT_EQUAL) reduce 20) ((T_IS_NOT_IDENTICAL) reduce 20) ((T_IS_SMALLER_OR_EQUAL) reduce 20) ((T_LOGICAL_AND) reduce 20) ((T_LOGICAL_OR) reduce 20) ((T_LOGICAL_XOR) reduce 20) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 20) ((T_OBJECT_OPERATOR) reduce 20) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 20) ((T_POW) reduce 20) ((T_SL) reduce 20) ((T_SPACESHIP) reduce 20) ((T_SR) reduce 20) (("[") reduce 20) (("^") reduce 20) (("{") reduce 20) (("|") reduce 20)) 22747 ((("%") reduce 70) (("(") reduce 70) (("*") reduce 70) (("+") reduce 70) (("-") reduce 70) ((".") reduce 70) (("/") reduce 70) ((":") reduce 70) ((";") reduce 70) (("<") reduce 70) ((">") reduce 70) (("?") reduce 70) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_BOOLEAN_AND) reduce 70) ((T_BOOLEAN_OR) reduce 70) ((T_COALESCE) reduce 70) ((T_DOUBLE_ARROW) reduce 70) ((T_INSTANCEOF) reduce 70) ((T_IS_EQUAL) reduce 70) ((T_IS_GREATER_OR_EQUAL) reduce 70) ((T_IS_IDENTICAL) reduce 70) ((T_IS_NOT_EQUAL) reduce 70) ((T_IS_NOT_IDENTICAL) reduce 70) ((T_IS_SMALLER_OR_EQUAL) reduce 70) ((T_LOGICAL_AND) reduce 70) ((T_LOGICAL_OR) reduce 70) ((T_LOGICAL_XOR) reduce 70) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 70) ((T_OBJECT_OPERATOR) reduce 70) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 70) ((T_POW) reduce 70) ((T_SL) reduce 70) ((T_SPACESHIP) reduce 70) ((T_SR) reduce 70) (("[") reduce 70) (("^") reduce 70) (("{") reduce 70) (("|") reduce 70)) 22748 ((("%") reduce 3) (("(") reduce 3) (("*") reduce 3) (("+") reduce 3) (("-") reduce 3) ((".") reduce 3) (("/") reduce 3) ((":") reduce 3) ((";") reduce 3) (("<") reduce 3) ((">") reduce 3) (("?") reduce 3) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_BOOLEAN_AND) reduce 3) ((T_BOOLEAN_OR) reduce 3) ((T_COALESCE) reduce 3) ((T_DOUBLE_ARROW) reduce 3) ((T_INSTANCEOF) reduce 3) ((T_IS_EQUAL) reduce 3) ((T_IS_GREATER_OR_EQUAL) reduce 3) ((T_IS_IDENTICAL) reduce 3) ((T_IS_NOT_EQUAL) reduce 3) ((T_IS_NOT_IDENTICAL) reduce 3) ((T_IS_SMALLER_OR_EQUAL) reduce 3) ((T_LOGICAL_AND) reduce 3) ((T_LOGICAL_OR) reduce 3) ((T_LOGICAL_XOR) reduce 3) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 3) ((T_OBJECT_OPERATOR) reduce 3) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 3) ((T_POW) reduce 3) ((T_SL) reduce 3) ((T_SPACESHIP) reduce 3) ((T_SR) reduce 3) (("[") reduce 3) (("^") reduce 3) (("{") reduce 3) (("|") reduce 3)) 22749 ((("%") reduce 12) (("(") reduce 12) (("*") reduce 12) (("+") reduce 12) (("-") reduce 12) ((".") reduce 12) (("/") reduce 12) ((":") reduce 12) ((";") reduce 12) (("<") reduce 12) ((">") reduce 12) (("?") reduce 12) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_BOOLEAN_AND) reduce 12) ((T_BOOLEAN_OR) reduce 12) ((T_COALESCE) reduce 12) ((T_DOUBLE_ARROW) reduce 12) ((T_INSTANCEOF) reduce 12) ((T_IS_EQUAL) reduce 12) ((T_IS_GREATER_OR_EQUAL) reduce 12) ((T_IS_IDENTICAL) reduce 12) ((T_IS_NOT_EQUAL) reduce 12) ((T_IS_NOT_IDENTICAL) reduce 12) ((T_IS_SMALLER_OR_EQUAL) reduce 12) ((T_LOGICAL_AND) reduce 12) ((T_LOGICAL_OR) reduce 12) ((T_LOGICAL_XOR) reduce 12) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 12) ((T_OBJECT_OPERATOR) reduce 12) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 12) ((T_POW) reduce 12) ((T_SL) reduce 12) ((T_SPACESHIP) reduce 12) ((T_SR) reduce 12) (("[") reduce 12) (("^") reduce 12) (("{") reduce 12) (("|") reduce 12)) 22750 ((("%") reduce 54) (("(") reduce 54) (("*") reduce 54) (("+") reduce 54) (("-") reduce 54) ((".") reduce 54) (("/") reduce 54) ((":") reduce 54) ((";") reduce 54) (("<") reduce 54) ((">") reduce 54) (("?") reduce 54) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_BOOLEAN_AND) reduce 54) ((T_BOOLEAN_OR) reduce 54) ((T_COALESCE) reduce 54) ((T_DOUBLE_ARROW) reduce 54) ((T_INSTANCEOF) reduce 54) ((T_IS_EQUAL) reduce 54) ((T_IS_GREATER_OR_EQUAL) reduce 54) ((T_IS_IDENTICAL) reduce 54) ((T_IS_NOT_EQUAL) reduce 54) ((T_IS_NOT_IDENTICAL) reduce 54) ((T_IS_SMALLER_OR_EQUAL) reduce 54) ((T_LOGICAL_AND) reduce 54) ((T_LOGICAL_OR) reduce 54) ((T_LOGICAL_XOR) reduce 54) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 54) ((T_OBJECT_OPERATOR) reduce 54) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 54) ((T_POW) reduce 54) ((T_SL) reduce 54) ((T_SPACESHIP) reduce 54) ((T_SR) reduce 54) (("[") reduce 54) (("^") reduce 54) (("{") reduce 54) (("|") reduce 54)) 22751 ((("%") reduce 65) (("(") reduce 65) (("*") reduce 65) (("+") reduce 65) (("-") reduce 65) ((".") reduce 65) (("/") reduce 65) ((":") reduce 65) ((";") reduce 65) (("<") reduce 65) ((">") reduce 65) (("?") reduce 65) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_BOOLEAN_AND) reduce 65) ((T_BOOLEAN_OR) reduce 65) ((T_COALESCE) reduce 65) ((T_DOUBLE_ARROW) reduce 65) ((T_INSTANCEOF) reduce 65) ((T_IS_EQUAL) reduce 65) ((T_IS_GREATER_OR_EQUAL) reduce 65) ((T_IS_IDENTICAL) reduce 65) ((T_IS_NOT_EQUAL) reduce 65) ((T_IS_NOT_IDENTICAL) reduce 65) ((T_IS_SMALLER_OR_EQUAL) reduce 65) ((T_LOGICAL_AND) reduce 65) ((T_LOGICAL_OR) reduce 65) ((T_LOGICAL_XOR) reduce 65) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 65) ((T_OBJECT_OPERATOR) reduce 65) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 65) ((T_POW) reduce 65) ((T_SL) reduce 65) ((T_SPACESHIP) reduce 65) ((T_SR) reduce 65) (("[") reduce 65) (("^") reduce 65) (("{") reduce 65) (("|") reduce 65)) 22752 ((("%") reduce 74) (("(") reduce 74) (("*") reduce 74) (("+") reduce 74) (("-") reduce 74) ((".") reduce 74) (("/") reduce 74) ((":") reduce 74) ((";") reduce 74) (("<") reduce 74) ((">") reduce 74) (("?") reduce 74) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_BOOLEAN_AND) reduce 74) ((T_BOOLEAN_OR) reduce 74) ((T_COALESCE) reduce 74) ((T_DOUBLE_ARROW) reduce 74) ((T_INSTANCEOF) reduce 74) ((T_IS_EQUAL) reduce 74) ((T_IS_GREATER_OR_EQUAL) reduce 74) ((T_IS_IDENTICAL) reduce 74) ((T_IS_NOT_EQUAL) reduce 74) ((T_IS_NOT_IDENTICAL) reduce 74) ((T_IS_SMALLER_OR_EQUAL) reduce 74) ((T_LOGICAL_AND) reduce 74) ((T_LOGICAL_OR) reduce 74) ((T_LOGICAL_XOR) reduce 74) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 74) ((T_OBJECT_OPERATOR) reduce 74) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 74) ((T_POW) reduce 74) ((T_SL) reduce 74) ((T_SPACESHIP) reduce 74) ((T_SR) reduce 74) (("[") reduce 74) (("^") reduce 74) (("{") reduce 74) (("|") reduce 74)) 22753 ((("%") reduce 30) (("(") reduce 30) (("*") reduce 30) (("+") reduce 30) (("-") reduce 30) ((".") reduce 30) (("/") reduce 30) ((":") reduce 30) ((";") reduce 30) (("<") reduce 30) ((">") reduce 30) (("?") reduce 30) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_BOOLEAN_AND) reduce 30) ((T_BOOLEAN_OR) reduce 30) ((T_COALESCE) reduce 30) ((T_DOUBLE_ARROW) reduce 30) ((T_INSTANCEOF) reduce 30) ((T_IS_EQUAL) reduce 30) ((T_IS_GREATER_OR_EQUAL) reduce 30) ((T_IS_IDENTICAL) reduce 30) ((T_IS_NOT_EQUAL) reduce 30) ((T_IS_NOT_IDENTICAL) reduce 30) ((T_IS_SMALLER_OR_EQUAL) reduce 30) ((T_LOGICAL_AND) reduce 30) ((T_LOGICAL_OR) reduce 30) ((T_LOGICAL_XOR) reduce 30) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 30) ((T_OBJECT_OPERATOR) reduce 30) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 30) ((T_POW) reduce 30) ((T_SL) reduce 30) ((T_SPACESHIP) reduce 30) ((T_SR) reduce 30) (("[") reduce 30) (("^") reduce 30) (("{") reduce 30) (("|") reduce 30)) 22754 ((("%") reduce 68) (("(") reduce 68) (("*") reduce 68) (("+") reduce 68) (("-") reduce 68) ((".") reduce 68) (("/") reduce 68) ((":") reduce 68) ((";") reduce 68) (("<") reduce 68) ((">") reduce 68) (("?") reduce 68) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_BOOLEAN_AND) reduce 68) ((T_BOOLEAN_OR) reduce 68) ((T_COALESCE) reduce 68) ((T_DOUBLE_ARROW) reduce 68) ((T_INSTANCEOF) reduce 68) ((T_IS_EQUAL) reduce 68) ((T_IS_GREATER_OR_EQUAL) reduce 68) ((T_IS_IDENTICAL) reduce 68) ((T_IS_NOT_EQUAL) reduce 68) ((T_IS_NOT_IDENTICAL) reduce 68) ((T_IS_SMALLER_OR_EQUAL) reduce 68) ((T_LOGICAL_AND) reduce 68) ((T_LOGICAL_OR) reduce 68) ((T_LOGICAL_XOR) reduce 68) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 68) ((T_OBJECT_OPERATOR) reduce 68) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 68) ((T_POW) reduce 68) ((T_SL) reduce 68) ((T_SPACESHIP) reduce 68) ((T_SR) reduce 68) (("[") reduce 68) (("^") reduce 68) (("{") reduce 68) (("|") reduce 68)) 22755 ((("%") reduce 21) (("(") reduce 21) (("*") reduce 21) (("+") reduce 21) (("-") reduce 21) ((".") reduce 21) (("/") reduce 21) ((":") reduce 21) ((";") reduce 21) (("<") reduce 21) ((">") reduce 21) (("?") reduce 21) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_BOOLEAN_AND) reduce 21) ((T_BOOLEAN_OR) reduce 21) ((T_COALESCE) reduce 21) ((T_DOUBLE_ARROW) reduce 21) ((T_INSTANCEOF) reduce 21) ((T_IS_EQUAL) reduce 21) ((T_IS_GREATER_OR_EQUAL) reduce 21) ((T_IS_IDENTICAL) reduce 21) ((T_IS_NOT_EQUAL) reduce 21) ((T_IS_NOT_IDENTICAL) reduce 21) ((T_IS_SMALLER_OR_EQUAL) reduce 21) ((T_LOGICAL_AND) reduce 21) ((T_LOGICAL_OR) reduce 21) ((T_LOGICAL_XOR) reduce 21) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 21) ((T_OBJECT_OPERATOR) reduce 21) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 21) ((T_POW) reduce 21) ((T_SL) reduce 21) ((T_SPACESHIP) reduce 21) ((T_SR) reduce 21) (("[") reduce 21) (("^") reduce 21) (("{") reduce 21) (("|") reduce 21)) 22756 ((("%") reduce 23) (("(") reduce 23) (("*") reduce 23) (("+") reduce 23) (("-") reduce 23) ((".") reduce 23) (("/") reduce 23) ((":") reduce 23) ((";") reduce 23) (("<") reduce 23) ((">") reduce 23) (("?") reduce 23) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_BOOLEAN_AND) reduce 23) ((T_BOOLEAN_OR) reduce 23) ((T_COALESCE) reduce 23) ((T_DOUBLE_ARROW) reduce 23) ((T_INSTANCEOF) reduce 23) ((T_IS_EQUAL) reduce 23) ((T_IS_GREATER_OR_EQUAL) reduce 23) ((T_IS_IDENTICAL) reduce 23) ((T_IS_NOT_EQUAL) reduce 23) ((T_IS_NOT_IDENTICAL) reduce 23) ((T_IS_SMALLER_OR_EQUAL) reduce 23) ((T_LOGICAL_AND) reduce 23) ((T_LOGICAL_OR) reduce 23) ((T_LOGICAL_XOR) reduce 23) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 23) ((T_OBJECT_OPERATOR) reduce 23) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 23) ((T_POW) reduce 23) ((T_SL) reduce 23) ((T_SPACESHIP) reduce 23) ((T_SR) reduce 23) (("[") reduce 23) (("^") reduce 23) (("{") reduce 23) (("|") reduce 23)) 22757 ((("%") reduce 41) (("(") reduce 41) (("*") reduce 41) (("+") reduce 41) (("-") reduce 41) ((".") reduce 41) (("/") reduce 41) ((":") reduce 41) ((";") reduce 41) (("<") reduce 41) ((">") reduce 41) (("?") reduce 41) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_BOOLEAN_AND) reduce 41) ((T_BOOLEAN_OR) reduce 41) ((T_COALESCE) reduce 41) ((T_DOUBLE_ARROW) reduce 41) ((T_INSTANCEOF) reduce 41) ((T_IS_EQUAL) reduce 41) ((T_IS_GREATER_OR_EQUAL) reduce 41) ((T_IS_IDENTICAL) reduce 41) ((T_IS_NOT_EQUAL) reduce 41) ((T_IS_NOT_IDENTICAL) reduce 41) ((T_IS_SMALLER_OR_EQUAL) reduce 41) ((T_LOGICAL_AND) reduce 41) ((T_LOGICAL_OR) reduce 41) ((T_LOGICAL_XOR) reduce 41) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 41) ((T_OBJECT_OPERATOR) reduce 41) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 41) ((T_POW) reduce 41) ((T_SL) reduce 41) ((T_SPACESHIP) reduce 41) ((T_SR) reduce 41) (("[") reduce 41) (("^") reduce 41) (("{") reduce 41) (("|") reduce 41)) 22758 ((("%") reduce 62) (("(") reduce 62) (("*") reduce 62) (("+") reduce 62) (("-") reduce 62) ((".") reduce 62) (("/") reduce 62) ((":") reduce 62) ((";") reduce 62) (("<") reduce 62) ((">") reduce 62) (("?") reduce 62) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_BOOLEAN_AND) reduce 62) ((T_BOOLEAN_OR) reduce 62) ((T_COALESCE) reduce 62) ((T_DOUBLE_ARROW) reduce 62) ((T_INSTANCEOF) reduce 62) ((T_IS_EQUAL) reduce 62) ((T_IS_GREATER_OR_EQUAL) reduce 62) ((T_IS_IDENTICAL) reduce 62) ((T_IS_NOT_EQUAL) reduce 62) ((T_IS_NOT_IDENTICAL) reduce 62) ((T_IS_SMALLER_OR_EQUAL) reduce 62) ((T_LOGICAL_AND) reduce 62) ((T_LOGICAL_OR) reduce 62) ((T_LOGICAL_XOR) reduce 62) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 62) ((T_OBJECT_OPERATOR) reduce 62) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 62) ((T_POW) reduce 62) ((T_SL) reduce 62) ((T_SPACESHIP) reduce 62) ((T_SR) reduce 62) (("[") reduce 62) (("^") reduce 62) (("{") reduce 62) (("|") reduce 62)) 22759 ((("%") reduce 34) (("(") reduce 34) (("*") reduce 34) (("+") reduce 34) (("-") reduce 34) ((".") reduce 34) (("/") reduce 34) ((":") reduce 34) ((";") reduce 34) (("<") reduce 34) ((">") reduce 34) (("?") reduce 34) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_BOOLEAN_AND) reduce 34) ((T_BOOLEAN_OR) reduce 34) ((T_COALESCE) reduce 34) ((T_DOUBLE_ARROW) reduce 34) ((T_INSTANCEOF) reduce 34) ((T_IS_EQUAL) reduce 34) ((T_IS_GREATER_OR_EQUAL) reduce 34) ((T_IS_IDENTICAL) reduce 34) ((T_IS_NOT_EQUAL) reduce 34) ((T_IS_NOT_IDENTICAL) reduce 34) ((T_IS_SMALLER_OR_EQUAL) reduce 34) ((T_LOGICAL_AND) reduce 34) ((T_LOGICAL_OR) reduce 34) ((T_LOGICAL_XOR) reduce 34) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 34) ((T_OBJECT_OPERATOR) reduce 34) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 34) ((T_POW) reduce 34) ((T_SL) reduce 34) ((T_SPACESHIP) reduce 34) ((T_SR) reduce 34) (("[") reduce 34) (("^") reduce 34) (("{") reduce 34) (("|") reduce 34)) 22760 ((("%") reduce 40) (("(") reduce 40) (("*") reduce 40) (("+") reduce 40) (("-") reduce 40) ((".") reduce 40) (("/") reduce 40) ((":") reduce 40) ((";") reduce 40) (("<") reduce 40) ((">") reduce 40) (("?") reduce 40) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_BOOLEAN_AND) reduce 40) ((T_BOOLEAN_OR) reduce 40) ((T_COALESCE) reduce 40) ((T_DOUBLE_ARROW) reduce 40) ((T_INSTANCEOF) reduce 40) ((T_IS_EQUAL) reduce 40) ((T_IS_GREATER_OR_EQUAL) reduce 40) ((T_IS_IDENTICAL) reduce 40) ((T_IS_NOT_EQUAL) reduce 40) ((T_IS_NOT_IDENTICAL) reduce 40) ((T_IS_SMALLER_OR_EQUAL) reduce 40) ((T_LOGICAL_AND) reduce 40) ((T_LOGICAL_OR) reduce 40) ((T_LOGICAL_XOR) reduce 40) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 40) ((T_OBJECT_OPERATOR) reduce 40) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 40) ((T_POW) reduce 40) ((T_SL) reduce 40) ((T_SPACESHIP) reduce 40) ((T_SR) reduce 40) (("[") reduce 40) (("^") reduce 40) (("{") reduce 40) (("|") reduce 40)) 22761 ((("%") reduce 13) (("(") reduce 13) (("*") reduce 13) (("+") reduce 13) (("-") reduce 13) ((".") reduce 13) (("/") reduce 13) ((":") reduce 13) ((";") reduce 13) (("<") reduce 13) ((">") reduce 13) (("?") reduce 13) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_BOOLEAN_AND) reduce 13) ((T_BOOLEAN_OR) reduce 13) ((T_COALESCE) reduce 13) ((T_DOUBLE_ARROW) reduce 13) ((T_INSTANCEOF) reduce 13) ((T_IS_EQUAL) reduce 13) ((T_IS_GREATER_OR_EQUAL) reduce 13) ((T_IS_IDENTICAL) reduce 13) ((T_IS_NOT_EQUAL) reduce 13) ((T_IS_NOT_IDENTICAL) reduce 13) ((T_IS_SMALLER_OR_EQUAL) reduce 13) ((T_LOGICAL_AND) reduce 13) ((T_LOGICAL_OR) reduce 13) ((T_LOGICAL_XOR) reduce 13) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 13) ((T_OBJECT_OPERATOR) reduce 13) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 13) ((T_POW) reduce 13) ((T_SL) reduce 13) ((T_SPACESHIP) reduce 13) ((T_SR) reduce 13) (("[") reduce 13) (("^") reduce 13) (("{") reduce 13) (("|") reduce 13)) 22762 ((("%") reduce 55) (("(") reduce 55) (("*") reduce 55) (("+") reduce 55) (("-") reduce 55) ((".") reduce 55) (("/") reduce 55) ((":") reduce 55) ((";") reduce 55) (("<") reduce 55) ((">") reduce 55) (("?") reduce 55) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_BOOLEAN_AND) reduce 55) ((T_BOOLEAN_OR) reduce 55) ((T_COALESCE) reduce 55) ((T_DOUBLE_ARROW) reduce 55) ((T_INSTANCEOF) reduce 55) ((T_IS_EQUAL) reduce 55) ((T_IS_GREATER_OR_EQUAL) reduce 55) ((T_IS_IDENTICAL) reduce 55) ((T_IS_NOT_EQUAL) reduce 55) ((T_IS_NOT_IDENTICAL) reduce 55) ((T_IS_SMALLER_OR_EQUAL) reduce 55) ((T_LOGICAL_AND) reduce 55) ((T_LOGICAL_OR) reduce 55) ((T_LOGICAL_XOR) reduce 55) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 55) ((T_OBJECT_OPERATOR) reduce 55) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 55) ((T_POW) reduce 55) ((T_SL) reduce 55) ((T_SPACESHIP) reduce 55) ((T_SR) reduce 55) (("[") reduce 55) (("^") reduce 55) (("{") reduce 55) (("|") reduce 55)) 22763 ((("%") reduce 1) (("(") reduce 1) (("*") reduce 1) (("+") reduce 1) (("-") reduce 1) ((".") reduce 1) (("/") reduce 1) ((":") reduce 1) ((";") reduce 1) (("<") reduce 1) ((">") reduce 1) (("?") reduce 1) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_BOOLEAN_AND) reduce 1) ((T_BOOLEAN_OR) reduce 1) ((T_COALESCE) reduce 1) ((T_DOUBLE_ARROW) reduce 1) ((T_INSTANCEOF) reduce 1) ((T_IS_EQUAL) reduce 1) ((T_IS_GREATER_OR_EQUAL) reduce 1) ((T_IS_IDENTICAL) reduce 1) ((T_IS_NOT_EQUAL) reduce 1) ((T_IS_NOT_IDENTICAL) reduce 1) ((T_IS_SMALLER_OR_EQUAL) reduce 1) ((T_LOGICAL_AND) reduce 1) ((T_LOGICAL_OR) reduce 1) ((T_LOGICAL_XOR) reduce 1) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 1) ((T_OBJECT_OPERATOR) reduce 1) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 1) ((T_POW) reduce 1) ((T_SL) reduce 1) ((T_SPACESHIP) reduce 1) ((T_SR) reduce 1) (("[") reduce 1) (("^") reduce 1) (("{") reduce 1) (("|") reduce 1)) 22764 ((("%") reduce 2) (("(") reduce 2) (("*") reduce 2) (("+") reduce 2) (("-") reduce 2) ((".") reduce 2) (("/") reduce 2) ((":") reduce 2) ((";") reduce 2) (("<") reduce 2) ((">") reduce 2) (("?") reduce 2) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_BOOLEAN_AND) reduce 2) ((T_BOOLEAN_OR) reduce 2) ((T_COALESCE) reduce 2) ((T_DOUBLE_ARROW) reduce 2) ((T_INSTANCEOF) reduce 2) ((T_IS_EQUAL) reduce 2) ((T_IS_GREATER_OR_EQUAL) reduce 2) ((T_IS_IDENTICAL) reduce 2) ((T_IS_NOT_EQUAL) reduce 2) ((T_IS_NOT_IDENTICAL) reduce 2) ((T_IS_SMALLER_OR_EQUAL) reduce 2) ((T_LOGICAL_AND) reduce 2) ((T_LOGICAL_OR) reduce 2) ((T_LOGICAL_XOR) reduce 2) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 2) ((T_OBJECT_OPERATOR) reduce 2) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 2) ((T_POW) reduce 2) ((T_SL) reduce 2) ((T_SPACESHIP) reduce 2) ((T_SR) reduce 2) (("[") reduce 2) (("^") reduce 2) (("{") reduce 2) (("|") reduce 2)) 22765 ((("%") reduce 9) (("(") reduce 9) (("*") reduce 9) (("+") reduce 9) (("-") reduce 9) ((".") reduce 9) (("/") reduce 9) ((":") reduce 9) ((";") reduce 9) (("<") reduce 9) ((">") reduce 9) (("?") reduce 9) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_BOOLEAN_AND) reduce 9) ((T_BOOLEAN_OR) reduce 9) ((T_COALESCE) reduce 9) ((T_DOUBLE_ARROW) reduce 9) ((T_INSTANCEOF) reduce 9) ((T_IS_EQUAL) reduce 9) ((T_IS_GREATER_OR_EQUAL) reduce 9) ((T_IS_IDENTICAL) reduce 9) ((T_IS_NOT_EQUAL) reduce 9) ((T_IS_NOT_IDENTICAL) reduce 9) ((T_IS_SMALLER_OR_EQUAL) reduce 9) ((T_LOGICAL_AND) reduce 9) ((T_LOGICAL_OR) reduce 9) ((T_LOGICAL_XOR) reduce 9) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 9) ((T_OBJECT_OPERATOR) reduce 9) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 9) ((T_POW) reduce 9) ((T_SL) reduce 9) ((T_SPACESHIP) reduce 9) ((T_SR) reduce 9) (("[") reduce 9) (("^") reduce 9) (("{") reduce 9) (("|") reduce 9)) 22766 ((("%") reduce 33) (("(") reduce 33) (("*") reduce 33) (("+") reduce 33) (("-") reduce 33) ((".") reduce 33) (("/") reduce 33) ((":") reduce 33) ((";") reduce 33) (("<") reduce 33) ((">") reduce 33) (("?") reduce 33) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_BOOLEAN_AND) reduce 33) ((T_BOOLEAN_OR) reduce 33) ((T_COALESCE) reduce 33) ((T_DOUBLE_ARROW) reduce 33) ((T_INSTANCEOF) reduce 33) ((T_IS_EQUAL) reduce 33) ((T_IS_GREATER_OR_EQUAL) reduce 33) ((T_IS_IDENTICAL) reduce 33) ((T_IS_NOT_EQUAL) reduce 33) ((T_IS_NOT_IDENTICAL) reduce 33) ((T_IS_SMALLER_OR_EQUAL) reduce 33) ((T_LOGICAL_AND) reduce 33) ((T_LOGICAL_OR) reduce 33) ((T_LOGICAL_XOR) reduce 33) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 33) ((T_OBJECT_OPERATOR) reduce 33) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 33) ((T_POW) reduce 33) ((T_SL) reduce 33) ((T_SPACESHIP) reduce 33) ((T_SR) reduce 33) (("[") reduce 33) (("^") reduce 33) (("{") reduce 33) (("|") reduce 33)) 22767 ((("%") reduce 58) (("(") reduce 58) (("*") reduce 58) (("+") reduce 58) (("-") reduce 58) ((".") reduce 58) (("/") reduce 58) ((":") reduce 58) ((";") reduce 58) (("<") reduce 58) ((">") reduce 58) (("?") reduce 58) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_BOOLEAN_AND) reduce 58) ((T_BOOLEAN_OR) reduce 58) ((T_COALESCE) reduce 58) ((T_DOUBLE_ARROW) reduce 58) ((T_INSTANCEOF) reduce 58) ((T_IS_EQUAL) reduce 58) ((T_IS_GREATER_OR_EQUAL) reduce 58) ((T_IS_IDENTICAL) reduce 58) ((T_IS_NOT_EQUAL) reduce 58) ((T_IS_NOT_IDENTICAL) reduce 58) ((T_IS_SMALLER_OR_EQUAL) reduce 58) ((T_LOGICAL_AND) reduce 58) ((T_LOGICAL_OR) reduce 58) ((T_LOGICAL_XOR) reduce 58) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 58) ((T_OBJECT_OPERATOR) reduce 58) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 58) ((T_POW) reduce 58) ((T_SL) reduce 58) ((T_SPACESHIP) reduce 58) ((T_SR) reduce 58) (("[") reduce 58) (("^") reduce 58) (("{") reduce 58) (("|") reduce 58)) 22768 ((("%") reduce 37) (("(") reduce 37) (("*") reduce 37) (("+") reduce 37) (("-") reduce 37) ((".") reduce 37) (("/") reduce 37) ((":") reduce 37) ((";") reduce 37) (("<") reduce 37) ((">") reduce 37) (("?") reduce 37) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_BOOLEAN_AND) reduce 37) ((T_BOOLEAN_OR) reduce 37) ((T_COALESCE) reduce 37) ((T_DOUBLE_ARROW) reduce 37) ((T_INSTANCEOF) reduce 37) ((T_IS_EQUAL) reduce 37) ((T_IS_GREATER_OR_EQUAL) reduce 37) ((T_IS_IDENTICAL) reduce 37) ((T_IS_NOT_EQUAL) reduce 37) ((T_IS_NOT_IDENTICAL) reduce 37) ((T_IS_SMALLER_OR_EQUAL) reduce 37) ((T_LOGICAL_AND) reduce 37) ((T_LOGICAL_OR) reduce 37) ((T_LOGICAL_XOR) reduce 37) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 37) ((T_OBJECT_OPERATOR) reduce 37) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 37) ((T_POW) reduce 37) ((T_SL) reduce 37) ((T_SPACESHIP) reduce 37) ((T_SR) reduce 37) (("[") reduce 37) (("^") reduce 37) (("{") reduce 37) (("|") reduce 37)) 22769 ((("%") reduce 64) (("(") reduce 64) (("*") reduce 64) (("+") reduce 64) (("-") reduce 64) ((".") reduce 64) (("/") reduce 64) ((":") reduce 64) ((";") reduce 64) (("<") reduce 64) ((">") reduce 64) (("?") reduce 64) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_BOOLEAN_AND) reduce 64) ((T_BOOLEAN_OR) reduce 64) ((T_COALESCE) reduce 64) ((T_DOUBLE_ARROW) reduce 64) ((T_INSTANCEOF) reduce 64) ((T_IS_EQUAL) reduce 64) ((T_IS_GREATER_OR_EQUAL) reduce 64) ((T_IS_IDENTICAL) reduce 64) ((T_IS_NOT_EQUAL) reduce 64) ((T_IS_NOT_IDENTICAL) reduce 64) ((T_IS_SMALLER_OR_EQUAL) reduce 64) ((T_LOGICAL_AND) reduce 64) ((T_LOGICAL_OR) reduce 64) ((T_LOGICAL_XOR) reduce 64) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 64) ((T_OBJECT_OPERATOR) reduce 64) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 64) ((T_POW) reduce 64) ((T_SL) reduce 64) ((T_SPACESHIP) reduce 64) ((T_SR) reduce 64) (("[") reduce 64) (("^") reduce 64) (("{") reduce 64) (("|") reduce 64)) 22770 ((("%") reduce 46) (("(") reduce 46) (("*") reduce 46) (("+") reduce 46) (("-") reduce 46) ((".") reduce 46) (("/") reduce 46) ((":") reduce 46) ((";") reduce 46) (("<") reduce 46) ((">") reduce 46) (("?") reduce 46) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_BOOLEAN_AND) reduce 46) ((T_BOOLEAN_OR) reduce 46) ((T_COALESCE) reduce 46) ((T_DOUBLE_ARROW) reduce 46) ((T_INSTANCEOF) reduce 46) ((T_IS_EQUAL) reduce 46) ((T_IS_GREATER_OR_EQUAL) reduce 46) ((T_IS_IDENTICAL) reduce 46) ((T_IS_NOT_EQUAL) reduce 46) ((T_IS_NOT_IDENTICAL) reduce 46) ((T_IS_SMALLER_OR_EQUAL) reduce 46) ((T_LOGICAL_AND) reduce 46) ((T_LOGICAL_OR) reduce 46) ((T_LOGICAL_XOR) reduce 46) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 46) ((T_OBJECT_OPERATOR) reduce 46) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 46) ((T_POW) reduce 46) ((T_SL) reduce 46) ((T_SPACESHIP) reduce 46) ((T_SR) reduce 46) (("[") reduce 46) (("^") reduce 46) (("{") reduce 46) (("|") reduce 46)) 22771 ((("%") reduce 8) (("(") reduce 8) (("*") reduce 8) (("+") reduce 8) (("-") reduce 8) ((".") reduce 8) (("/") reduce 8) ((":") reduce 8) ((";") reduce 8) (("<") reduce 8) ((">") reduce 8) (("?") reduce 8) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_BOOLEAN_AND) reduce 8) ((T_BOOLEAN_OR) reduce 8) ((T_COALESCE) reduce 8) ((T_DOUBLE_ARROW) reduce 8) ((T_INSTANCEOF) reduce 8) ((T_IS_EQUAL) reduce 8) ((T_IS_GREATER_OR_EQUAL) reduce 8) ((T_IS_IDENTICAL) reduce 8) ((T_IS_NOT_EQUAL) reduce 8) ((T_IS_NOT_IDENTICAL) reduce 8) ((T_IS_SMALLER_OR_EQUAL) reduce 8) ((T_LOGICAL_AND) reduce 8) ((T_LOGICAL_OR) reduce 8) ((T_LOGICAL_XOR) reduce 8) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 8) ((T_OBJECT_OPERATOR) reduce 8) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 8) ((T_POW) reduce 8) ((T_SL) reduce 8) ((T_SPACESHIP) reduce 8) ((T_SR) reduce 8) (("[") reduce 8) (("^") reduce 8) (("{") reduce 8) (("|") reduce 8)) 22772 ((("%") reduce 6) (("(") reduce 6) (("*") reduce 6) (("+") reduce 6) (("-") reduce 6) ((".") reduce 6) (("/") reduce 6) ((":") reduce 6) ((";") reduce 6) (("<") reduce 6) ((">") reduce 6) (("?") reduce 6) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_BOOLEAN_AND) reduce 6) ((T_BOOLEAN_OR) reduce 6) ((T_COALESCE) reduce 6) ((T_DOUBLE_ARROW) reduce 6) ((T_INSTANCEOF) reduce 6) ((T_IS_EQUAL) reduce 6) ((T_IS_GREATER_OR_EQUAL) reduce 6) ((T_IS_IDENTICAL) reduce 6) ((T_IS_NOT_EQUAL) reduce 6) ((T_IS_NOT_IDENTICAL) reduce 6) ((T_IS_SMALLER_OR_EQUAL) reduce 6) ((T_LOGICAL_AND) reduce 6) ((T_LOGICAL_OR) reduce 6) ((T_LOGICAL_XOR) reduce 6) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 6) ((T_OBJECT_OPERATOR) reduce 6) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 6) ((T_POW) reduce 6) ((T_SL) reduce 6) ((T_SPACESHIP) reduce 6) ((T_SR) reduce 6) (("[") reduce 6) (("^") reduce 6) (("{") reduce 6) (("|") reduce 6)) 22773 ((("%") reduce 7) (("(") reduce 7) (("*") reduce 7) (("+") reduce 7) (("-") reduce 7) ((".") reduce 7) (("/") reduce 7) ((":") reduce 7) ((";") reduce 7) (("<") reduce 7) ((">") reduce 7) (("?") reduce 7) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_BOOLEAN_AND) reduce 7) ((T_BOOLEAN_OR) reduce 7) ((T_COALESCE) reduce 7) ((T_DOUBLE_ARROW) reduce 7) ((T_INSTANCEOF) reduce 7) ((T_IS_EQUAL) reduce 7) ((T_IS_GREATER_OR_EQUAL) reduce 7) ((T_IS_IDENTICAL) reduce 7) ((T_IS_NOT_EQUAL) reduce 7) ((T_IS_NOT_IDENTICAL) reduce 7) ((T_IS_SMALLER_OR_EQUAL) reduce 7) ((T_LOGICAL_AND) reduce 7) ((T_LOGICAL_OR) reduce 7) ((T_LOGICAL_XOR) reduce 7) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 7) ((T_OBJECT_OPERATOR) reduce 7) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 7) ((T_POW) reduce 7) ((T_SL) reduce 7) ((T_SPACESHIP) reduce 7) ((T_SR) reduce 7) (("[") reduce 7) (("^") reduce 7) (("{") reduce 7) (("|") reduce 7)) 22774 ((("%") reduce 69) (("(") reduce 69) (("*") reduce 69) (("+") reduce 69) (("-") reduce 69) ((".") reduce 69) (("/") reduce 69) ((":") reduce 69) ((";") reduce 69) (("<") reduce 69) ((">") reduce 69) (("?") reduce 69) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_BOOLEAN_AND) reduce 69) ((T_BOOLEAN_OR) reduce 69) ((T_COALESCE) reduce 69) ((T_DOUBLE_ARROW) reduce 69) ((T_INSTANCEOF) reduce 69) ((T_IS_EQUAL) reduce 69) ((T_IS_GREATER_OR_EQUAL) reduce 69) ((T_IS_IDENTICAL) reduce 69) ((T_IS_NOT_EQUAL) reduce 69) ((T_IS_NOT_IDENTICAL) reduce 69) ((T_IS_SMALLER_OR_EQUAL) reduce 69) ((T_LOGICAL_AND) reduce 69) ((T_LOGICAL_OR) reduce 69) ((T_LOGICAL_XOR) reduce 69) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 69) ((T_OBJECT_OPERATOR) reduce 69) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 69) ((T_POW) reduce 69) ((T_SL) reduce 69) ((T_SPACESHIP) reduce 69) ((T_SR) reduce 69) (("[") reduce 69) (("^") reduce 69) (("{") reduce 69) (("|") reduce 69)) 22775 ((("%") reduce 63) (("(") reduce 63) (("*") reduce 63) (("+") reduce 63) (("-") reduce 63) ((".") reduce 63) (("/") reduce 63) ((":") reduce 63) ((";") reduce 63) (("<") reduce 63) ((">") reduce 63) (("?") reduce 63) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_BOOLEAN_AND) reduce 63) ((T_BOOLEAN_OR) reduce 63) ((T_COALESCE) reduce 63) ((T_DOUBLE_ARROW) reduce 63) ((T_INSTANCEOF) reduce 63) ((T_IS_EQUAL) reduce 63) ((T_IS_GREATER_OR_EQUAL) reduce 63) ((T_IS_IDENTICAL) reduce 63) ((T_IS_NOT_EQUAL) reduce 63) ((T_IS_NOT_IDENTICAL) reduce 63) ((T_IS_SMALLER_OR_EQUAL) reduce 63) ((T_LOGICAL_AND) reduce 63) ((T_LOGICAL_OR) reduce 63) ((T_LOGICAL_XOR) reduce 63) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 63) ((T_OBJECT_OPERATOR) reduce 63) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 63) ((T_POW) reduce 63) ((T_SL) reduce 63) ((T_SPACESHIP) reduce 63) ((T_SR) reduce 63) (("[") reduce 63) (("^") reduce 63) (("{") reduce 63) (("|") reduce 63)) 22776 ((("%") reduce 56) (("(") reduce 56) (("*") reduce 56) (("+") reduce 56) (("-") reduce 56) ((".") reduce 56) (("/") reduce 56) ((":") reduce 56) ((";") reduce 56) (("<") reduce 56) ((">") reduce 56) (("?") reduce 56) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_BOOLEAN_AND) reduce 56) ((T_BOOLEAN_OR) reduce 56) ((T_COALESCE) reduce 56) ((T_DOUBLE_ARROW) reduce 56) ((T_INSTANCEOF) reduce 56) ((T_IS_EQUAL) reduce 56) ((T_IS_GREATER_OR_EQUAL) reduce 56) ((T_IS_IDENTICAL) reduce 56) ((T_IS_NOT_EQUAL) reduce 56) ((T_IS_NOT_IDENTICAL) reduce 56) ((T_IS_SMALLER_OR_EQUAL) reduce 56) ((T_LOGICAL_AND) reduce 56) ((T_LOGICAL_OR) reduce 56) ((T_LOGICAL_XOR) reduce 56) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 56) ((T_OBJECT_OPERATOR) reduce 56) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 56) ((T_POW) reduce 56) ((T_SL) reduce 56) ((T_SPACESHIP) reduce 56) ((T_SR) reduce 56) (("[") reduce 56) (("^") reduce 56) (("{") reduce 56) (("|") reduce 56)) 22777 ((("%") reduce 10) (("(") reduce 10) (("*") reduce 10) (("+") reduce 10) (("-") reduce 10) ((".") reduce 10) (("/") reduce 10) ((":") reduce 10) ((";") reduce 10) (("<") reduce 10) ((">") reduce 10) (("?") reduce 10) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_BOOLEAN_AND) reduce 10) ((T_BOOLEAN_OR) reduce 10) ((T_COALESCE) reduce 10) ((T_DOUBLE_ARROW) reduce 10) ((T_INSTANCEOF) reduce 10) ((T_IS_EQUAL) reduce 10) ((T_IS_GREATER_OR_EQUAL) reduce 10) ((T_IS_IDENTICAL) reduce 10) ((T_IS_NOT_EQUAL) reduce 10) ((T_IS_NOT_IDENTICAL) reduce 10) ((T_IS_SMALLER_OR_EQUAL) reduce 10) ((T_LOGICAL_AND) reduce 10) ((T_LOGICAL_OR) reduce 10) ((T_LOGICAL_XOR) reduce 10) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 10) ((T_OBJECT_OPERATOR) reduce 10) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 10) ((T_POW) reduce 10) ((T_SL) reduce 10) ((T_SPACESHIP) reduce 10) ((T_SR) reduce 10) (("[") reduce 10) (("^") reduce 10) (("{") reduce 10) (("|") reduce 10)) 22778 ((("%") reduce 67) (("(") reduce 67) (("*") reduce 67) (("+") reduce 67) (("-") reduce 67) ((".") reduce 67) (("/") reduce 67) ((":") reduce 67) ((";") reduce 67) (("<") reduce 67) ((">") reduce 67) (("?") reduce 67) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_BOOLEAN_AND) reduce 67) ((T_BOOLEAN_OR) reduce 67) ((T_COALESCE) reduce 67) ((T_DOUBLE_ARROW) reduce 67) ((T_INSTANCEOF) reduce 67) ((T_IS_EQUAL) reduce 67) ((T_IS_GREATER_OR_EQUAL) reduce 67) ((T_IS_IDENTICAL) reduce 67) ((T_IS_NOT_EQUAL) reduce 67) ((T_IS_NOT_IDENTICAL) reduce 67) ((T_IS_SMALLER_OR_EQUAL) reduce 67) ((T_LOGICAL_AND) reduce 67) ((T_LOGICAL_OR) reduce 67) ((T_LOGICAL_XOR) reduce 67) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 67) ((T_OBJECT_OPERATOR) reduce 67) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 67) ((T_POW) reduce 67) ((T_SL) reduce 67) ((T_SPACESHIP) reduce 67) ((T_SR) reduce 67) (("[") reduce 67) (("^") reduce 67) (("{") reduce 67) (("|") reduce 67)) 22779 ((("%") reduce 44) (("(") reduce 44) (("*") reduce 44) (("+") reduce 44) (("-") reduce 44) ((".") reduce 44) (("/") reduce 44) ((":") reduce 44) ((";") reduce 44) (("<") reduce 44) ((">") reduce 44) (("?") reduce 44) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_BOOLEAN_AND) reduce 44) ((T_BOOLEAN_OR) reduce 44) ((T_COALESCE) reduce 44) ((T_DOUBLE_ARROW) reduce 44) ((T_INSTANCEOF) reduce 44) ((T_IS_EQUAL) reduce 44) ((T_IS_GREATER_OR_EQUAL) reduce 44) ((T_IS_IDENTICAL) reduce 44) ((T_IS_NOT_EQUAL) reduce 44) ((T_IS_NOT_IDENTICAL) reduce 44) ((T_IS_SMALLER_OR_EQUAL) reduce 44) ((T_LOGICAL_AND) reduce 44) ((T_LOGICAL_OR) reduce 44) ((T_LOGICAL_XOR) reduce 44) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 44) ((T_OBJECT_OPERATOR) reduce 44) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 44) ((T_POW) reduce 44) ((T_SL) reduce 44) ((T_SPACESHIP) reduce 44) ((T_SR) reduce 44) (("[") reduce 44) (("^") reduce 44) (("{") reduce 44) (("|") reduce 44)) 22780 ((("%") reduce 75) (("(") reduce 75) (("*") reduce 75) (("+") reduce 75) (("-") reduce 75) ((".") reduce 75) (("/") reduce 75) ((":") reduce 75) ((";") reduce 75) (("<") reduce 75) ((">") reduce 75) (("?") reduce 75) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_BOOLEAN_AND) reduce 75) ((T_BOOLEAN_OR) reduce 75) ((T_COALESCE) reduce 75) ((T_DOUBLE_ARROW) reduce 75) ((T_INSTANCEOF) reduce 75) ((T_IS_EQUAL) reduce 75) ((T_IS_GREATER_OR_EQUAL) reduce 75) ((T_IS_IDENTICAL) reduce 75) ((T_IS_NOT_EQUAL) reduce 75) ((T_IS_NOT_IDENTICAL) reduce 75) ((T_IS_SMALLER_OR_EQUAL) reduce 75) ((T_LOGICAL_AND) reduce 75) ((T_LOGICAL_OR) reduce 75) ((T_LOGICAL_XOR) reduce 75) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 75) ((T_OBJECT_OPERATOR) reduce 75) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 75) ((T_POW) reduce 75) ((T_SL) reduce 75) ((T_SPACESHIP) reduce 75) ((T_SR) reduce 75) (("[") reduce 75) (("^") reduce 75) (("{") reduce 75) (("|") reduce 75)) 22781 ((("%") reduce 76) (("(") reduce 76) (("*") reduce 76) (("+") reduce 76) (("-") reduce 76) ((".") reduce 76) (("/") reduce 76) ((":") reduce 76) ((";") reduce 76) (("<") reduce 76) ((">") reduce 76) (("?") reduce 76) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_BOOLEAN_AND) reduce 76) ((T_BOOLEAN_OR) reduce 76) ((T_COALESCE) reduce 76) ((T_DOUBLE_ARROW) reduce 76) ((T_INSTANCEOF) reduce 76) ((T_IS_EQUAL) reduce 76) ((T_IS_GREATER_OR_EQUAL) reduce 76) ((T_IS_IDENTICAL) reduce 76) ((T_IS_NOT_EQUAL) reduce 76) ((T_IS_NOT_IDENTICAL) reduce 76) ((T_IS_SMALLER_OR_EQUAL) reduce 76) ((T_LOGICAL_AND) reduce 76) ((T_LOGICAL_OR) reduce 76) ((T_LOGICAL_XOR) reduce 76) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 76) ((T_OBJECT_OPERATOR) reduce 76) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 76) ((T_POW) reduce 76) ((T_SL) reduce 76) ((T_SPACESHIP) reduce 76) ((T_SR) reduce 76) (("[") reduce 76) (("^") reduce 76) (("{") reduce 76) (("|") reduce 76)) 22782 ((("%") reduce 77) (("(") reduce 77) (("*") reduce 77) (("+") reduce 77) (("-") reduce 77) ((".") reduce 77) (("/") reduce 77) ((":") reduce 77) ((";") reduce 77) (("<") reduce 77) ((">") reduce 77) (("?") reduce 77) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_BOOLEAN_AND) reduce 77) ((T_BOOLEAN_OR) reduce 77) ((T_COALESCE) reduce 77) ((T_DOUBLE_ARROW) reduce 77) ((T_INSTANCEOF) reduce 77) ((T_IS_EQUAL) reduce 77) ((T_IS_GREATER_OR_EQUAL) reduce 77) ((T_IS_IDENTICAL) reduce 77) ((T_IS_NOT_EQUAL) reduce 77) ((T_IS_NOT_IDENTICAL) reduce 77) ((T_IS_SMALLER_OR_EQUAL) reduce 77) ((T_LOGICAL_AND) reduce 77) ((T_LOGICAL_OR) reduce 77) ((T_LOGICAL_XOR) reduce 77) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 77) ((T_OBJECT_OPERATOR) reduce 77) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 77) ((T_POW) reduce 77) ((T_SL) reduce 77) ((T_SPACESHIP) reduce 77) ((T_SR) reduce 77) (("[") reduce 77) (("^") reduce 77) (("{") reduce 77) (("|") reduce 77)) 22783 ((("%") reduce 78) (("(") reduce 78) (("*") reduce 78) (("+") reduce 78) (("-") reduce 78) ((".") reduce 78) (("/") reduce 78) ((":") reduce 78) ((";") reduce 78) (("<") reduce 78) ((">") reduce 78) (("?") reduce 78) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_BOOLEAN_AND) reduce 78) ((T_BOOLEAN_OR) reduce 78) ((T_COALESCE) reduce 78) ((T_DOUBLE_ARROW) reduce 78) ((T_INSTANCEOF) reduce 78) ((T_IS_EQUAL) reduce 78) ((T_IS_GREATER_OR_EQUAL) reduce 78) ((T_IS_IDENTICAL) reduce 78) ((T_IS_NOT_EQUAL) reduce 78) ((T_IS_NOT_IDENTICAL) reduce 78) ((T_IS_SMALLER_OR_EQUAL) reduce 78) ((T_LOGICAL_AND) reduce 78) ((T_LOGICAL_OR) reduce 78) ((T_LOGICAL_XOR) reduce 78) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 78) ((T_OBJECT_OPERATOR) reduce 78) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 78) ((T_POW) reduce 78) ((T_SL) reduce 78) ((T_SPACESHIP) reduce 78) ((T_SR) reduce 78) (("[") reduce 78) (("^") reduce 78) (("{") reduce 78) (("|") reduce 78)) 22784 ((("%") reduce 4) (("(") reduce 4) (("*") reduce 4) (("+") reduce 4) (("-") reduce 4) ((".") reduce 4) (("/") reduce 4) ((":") reduce 4) ((";") reduce 4) (("<") reduce 4) ((">") reduce 4) (("?") reduce 4) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_BOOLEAN_AND) reduce 4) ((T_BOOLEAN_OR) reduce 4) ((T_COALESCE) reduce 4) ((T_DOUBLE_ARROW) reduce 4) ((T_INSTANCEOF) reduce 4) ((T_IS_EQUAL) reduce 4) ((T_IS_GREATER_OR_EQUAL) reduce 4) ((T_IS_IDENTICAL) reduce 4) ((T_IS_NOT_EQUAL) reduce 4) ((T_IS_NOT_IDENTICAL) reduce 4) ((T_IS_SMALLER_OR_EQUAL) reduce 4) ((T_LOGICAL_AND) reduce 4) ((T_LOGICAL_OR) reduce 4) ((T_LOGICAL_XOR) reduce 4) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 4) ((T_OBJECT_OPERATOR) reduce 4) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 4) ((T_POW) reduce 4) ((T_SL) reduce 4) ((T_SPACESHIP) reduce 4) ((T_SR) reduce 4) (("[") reduce 4) (("^") reduce 4) (("{") reduce 4) (("|") reduce 4)) 22785 ((("%") reduce 5) (("(") reduce 5) (("*") reduce 5) (("+") reduce 5) (("-") reduce 5) ((".") reduce 5) (("/") reduce 5) ((":") reduce 5) ((";") reduce 5) (("<") reduce 5) ((">") reduce 5) (("?") reduce 5) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_BOOLEAN_AND) reduce 5) ((T_BOOLEAN_OR) reduce 5) ((T_COALESCE) reduce 5) ((T_DOUBLE_ARROW) reduce 5) ((T_INSTANCEOF) reduce 5) ((T_IS_EQUAL) reduce 5) ((T_IS_GREATER_OR_EQUAL) reduce 5) ((T_IS_IDENTICAL) reduce 5) ((T_IS_NOT_EQUAL) reduce 5) ((T_IS_NOT_IDENTICAL) reduce 5) ((T_IS_SMALLER_OR_EQUAL) reduce 5) ((T_LOGICAL_AND) reduce 5) ((T_LOGICAL_OR) reduce 5) ((T_LOGICAL_XOR) reduce 5) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 5) ((T_OBJECT_OPERATOR) reduce 5) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 5) ((T_POW) reduce 5) ((T_SL) reduce 5) ((T_SPACESHIP) reduce 5) ((T_SR) reduce 5) (("[") reduce 5) (("^") reduce 5) (("{") reduce 5) (("|") reduce 5)) 22786 ((("%") reduce 43) (("(") reduce 43) (("*") reduce 43) (("+") reduce 43) (("-") reduce 43) ((".") reduce 43) (("/") reduce 43) ((":") reduce 43) ((";") reduce 43) (("<") reduce 43) ((">") reduce 43) (("?") reduce 43) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_BOOLEAN_AND) reduce 43) ((T_BOOLEAN_OR) reduce 43) ((T_COALESCE) reduce 43) ((T_DOUBLE_ARROW) reduce 43) ((T_INSTANCEOF) reduce 43) ((T_IS_EQUAL) reduce 43) ((T_IS_GREATER_OR_EQUAL) reduce 43) ((T_IS_IDENTICAL) reduce 43) ((T_IS_NOT_EQUAL) reduce 43) ((T_IS_NOT_IDENTICAL) reduce 43) ((T_IS_SMALLER_OR_EQUAL) reduce 43) ((T_LOGICAL_AND) reduce 43) ((T_LOGICAL_OR) reduce 43) ((T_LOGICAL_XOR) reduce 43) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 43) ((T_OBJECT_OPERATOR) reduce 43) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 43) ((T_POW) reduce 43) ((T_SL) reduce 43) ((T_SPACESHIP) reduce 43) ((T_SR) reduce 43) (("[") reduce 43) (("^") reduce 43) (("{") reduce 43) (("|") reduce 43)) 22787 ((("%") reduce 72) (("(") reduce 72) (("*") reduce 72) (("+") reduce 72) (("-") reduce 72) ((".") reduce 72) (("/") reduce 72) ((":") reduce 72) ((";") reduce 72) (("<") reduce 72) ((">") reduce 72) (("?") reduce 72) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_BOOLEAN_AND) reduce 72) ((T_BOOLEAN_OR) reduce 72) ((T_COALESCE) reduce 72) ((T_DOUBLE_ARROW) reduce 72) ((T_INSTANCEOF) reduce 72) ((T_IS_EQUAL) reduce 72) ((T_IS_GREATER_OR_EQUAL) reduce 72) ((T_IS_IDENTICAL) reduce 72) ((T_IS_NOT_EQUAL) reduce 72) ((T_IS_NOT_IDENTICAL) reduce 72) ((T_IS_SMALLER_OR_EQUAL) reduce 72) ((T_LOGICAL_AND) reduce 72) ((T_LOGICAL_OR) reduce 72) ((T_LOGICAL_XOR) reduce 72) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 72) ((T_OBJECT_OPERATOR) reduce 72) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 72) ((T_POW) reduce 72) ((T_SL) reduce 72) ((T_SPACESHIP) reduce 72) ((T_SR) reduce 72) (("[") reduce 72) (("^") reduce 72) (("{") reduce 72) (("|") reduce 72)) 22788 ((("%") reduce 81) (("(") reduce 81) (("*") reduce 81) (("+") reduce 81) (("-") reduce 81) ((".") reduce 81) (("/") reduce 81) ((":") reduce 81) ((";") reduce 81) (("<") reduce 81) ((">") reduce 81) (("?") reduce 81) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_BOOLEAN_AND) reduce 81) ((T_BOOLEAN_OR) reduce 81) ((T_COALESCE) reduce 81) ((T_DOUBLE_ARROW) reduce 81) ((T_INSTANCEOF) reduce 81) ((T_IS_EQUAL) reduce 81) ((T_IS_GREATER_OR_EQUAL) reduce 81) ((T_IS_IDENTICAL) reduce 81) ((T_IS_NOT_EQUAL) reduce 81) ((T_IS_NOT_IDENTICAL) reduce 81) ((T_IS_SMALLER_OR_EQUAL) reduce 81) ((T_LOGICAL_AND) reduce 81) ((T_LOGICAL_OR) reduce 81) ((T_LOGICAL_XOR) reduce 81) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 81) ((T_OBJECT_OPERATOR) reduce 81) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 81) ((T_POW) reduce 81) ((T_SL) reduce 81) ((T_SPACESHIP) reduce 81) ((T_SR) reduce 81) (("[") reduce 81) (("^") reduce 81) (("{") reduce 81) (("|") reduce 81)) 22789 ((("%") reduce 47) (("(") reduce 47) (("*") reduce 47) (("+") reduce 47) (("-") reduce 47) ((".") reduce 47) (("/") reduce 47) ((":") reduce 47) ((";") reduce 47) (("<") reduce 47) ((">") reduce 47) (("?") reduce 47) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_BOOLEAN_AND) reduce 47) ((T_BOOLEAN_OR) reduce 47) ((T_COALESCE) reduce 47) ((T_DOUBLE_ARROW) reduce 47) ((T_INSTANCEOF) reduce 47) ((T_IS_EQUAL) reduce 47) ((T_IS_GREATER_OR_EQUAL) reduce 47) ((T_IS_IDENTICAL) reduce 47) ((T_IS_NOT_EQUAL) reduce 47) ((T_IS_NOT_IDENTICAL) reduce 47) ((T_IS_SMALLER_OR_EQUAL) reduce 47) ((T_LOGICAL_AND) reduce 47) ((T_LOGICAL_OR) reduce 47) ((T_LOGICAL_XOR) reduce 47) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 47) ((T_OBJECT_OPERATOR) reduce 47) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 47) ((T_POW) reduce 47) ((T_SL) reduce 47) ((T_SPACESHIP) reduce 47) ((T_SR) reduce 47) (("[") reduce 47) (("^") reduce 47) (("{") reduce 47) (("|") reduce 47)) 22790 ((("%") reduce 31) (("(") reduce 31) (("*") reduce 31) (("+") reduce 31) (("-") reduce 31) ((".") reduce 31) (("/") reduce 31) ((":") reduce 31) ((";") reduce 31) (("<") reduce 31) ((">") reduce 31) (("?") reduce 31) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_BOOLEAN_AND) reduce 31) ((T_BOOLEAN_OR) reduce 31) ((T_COALESCE) reduce 31) ((T_DOUBLE_ARROW) reduce 31) ((T_INSTANCEOF) reduce 31) ((T_IS_EQUAL) reduce 31) ((T_IS_GREATER_OR_EQUAL) reduce 31) ((T_IS_IDENTICAL) reduce 31) ((T_IS_NOT_EQUAL) reduce 31) ((T_IS_NOT_IDENTICAL) reduce 31) ((T_IS_SMALLER_OR_EQUAL) reduce 31) ((T_LOGICAL_AND) reduce 31) ((T_LOGICAL_OR) reduce 31) ((T_LOGICAL_XOR) reduce 31) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 31) ((T_OBJECT_OPERATOR) reduce 31) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 31) ((T_POW) reduce 31) ((T_SL) reduce 31) ((T_SPACESHIP) reduce 31) ((T_SR) reduce 31) (("[") reduce 31) (("^") reduce 31) (("{") reduce 31) (("|") reduce 31)) 22791 ((("%") reduce 57) (("(") reduce 57) (("*") reduce 57) (("+") reduce 57) (("-") reduce 57) ((".") reduce 57) (("/") reduce 57) ((":") reduce 57) ((";") reduce 57) (("<") reduce 57) ((">") reduce 57) (("?") reduce 57) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_BOOLEAN_AND) reduce 57) ((T_BOOLEAN_OR) reduce 57) ((T_COALESCE) reduce 57) ((T_DOUBLE_ARROW) reduce 57) ((T_INSTANCEOF) reduce 57) ((T_IS_EQUAL) reduce 57) ((T_IS_GREATER_OR_EQUAL) reduce 57) ((T_IS_IDENTICAL) reduce 57) ((T_IS_NOT_EQUAL) reduce 57) ((T_IS_NOT_IDENTICAL) reduce 57) ((T_IS_SMALLER_OR_EQUAL) reduce 57) ((T_LOGICAL_AND) reduce 57) ((T_LOGICAL_OR) reduce 57) ((T_LOGICAL_XOR) reduce 57) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 57) ((T_OBJECT_OPERATOR) reduce 57) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 57) ((T_POW) reduce 57) ((T_SL) reduce 57) ((T_SPACESHIP) reduce 57) ((T_SR) reduce 57) (("[") reduce 57) (("^") reduce 57) (("{") reduce 57) (("|") reduce 57)) 22792 ((("%") reduce 61) (("(") reduce 61) (("*") reduce 61) (("+") reduce 61) (("-") reduce 61) ((".") reduce 61) (("/") reduce 61) ((":") reduce 61) ((";") reduce 61) (("<") reduce 61) ((">") reduce 61) (("?") reduce 61) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_BOOLEAN_AND) reduce 61) ((T_BOOLEAN_OR) reduce 61) ((T_COALESCE) reduce 61) ((T_DOUBLE_ARROW) reduce 61) ((T_INSTANCEOF) reduce 61) ((T_IS_EQUAL) reduce 61) ((T_IS_GREATER_OR_EQUAL) reduce 61) ((T_IS_IDENTICAL) reduce 61) ((T_IS_NOT_EQUAL) reduce 61) ((T_IS_NOT_IDENTICAL) reduce 61) ((T_IS_SMALLER_OR_EQUAL) reduce 61) ((T_LOGICAL_AND) reduce 61) ((T_LOGICAL_OR) reduce 61) ((T_LOGICAL_XOR) reduce 61) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 61) ((T_OBJECT_OPERATOR) reduce 61) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 61) ((T_POW) reduce 61) ((T_SL) reduce 61) ((T_SPACESHIP) reduce 61) ((T_SR) reduce 61) (("[") reduce 61) (("^") reduce 61) (("{") reduce 61) (("|") reduce 61)) 22793 ((("%") reduce 28) (("(") reduce 28) (("*") reduce 28) (("+") reduce 28) (("-") reduce 28) ((".") reduce 28) (("/") reduce 28) ((":") reduce 28) ((";") reduce 28) (("<") reduce 28) ((">") reduce 28) (("?") reduce 28) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_BOOLEAN_AND) reduce 28) ((T_BOOLEAN_OR) reduce 28) ((T_COALESCE) reduce 28) ((T_DOUBLE_ARROW) reduce 28) ((T_INSTANCEOF) reduce 28) ((T_IS_EQUAL) reduce 28) ((T_IS_GREATER_OR_EQUAL) reduce 28) ((T_IS_IDENTICAL) reduce 28) ((T_IS_NOT_EQUAL) reduce 28) ((T_IS_NOT_IDENTICAL) reduce 28) ((T_IS_SMALLER_OR_EQUAL) reduce 28) ((T_LOGICAL_AND) reduce 28) ((T_LOGICAL_OR) reduce 28) ((T_LOGICAL_XOR) reduce 28) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 28) ((T_OBJECT_OPERATOR) reduce 28) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 28) ((T_POW) reduce 28) ((T_SL) reduce 28) ((T_SPACESHIP) reduce 28) ((T_SR) reduce 28) (("[") reduce 28) (("^") reduce 28) (("{") reduce 28) (("|") reduce 28)) 22794 ((("%") reduce 36) (("(") reduce 36) (("*") reduce 36) (("+") reduce 36) (("-") reduce 36) ((".") reduce 36) (("/") reduce 36) ((":") reduce 36) ((";") reduce 36) (("<") reduce 36) ((">") reduce 36) (("?") reduce 36) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_BOOLEAN_AND) reduce 36) ((T_BOOLEAN_OR) reduce 36) ((T_COALESCE) reduce 36) ((T_DOUBLE_ARROW) reduce 36) ((T_INSTANCEOF) reduce 36) ((T_IS_EQUAL) reduce 36) ((T_IS_GREATER_OR_EQUAL) reduce 36) ((T_IS_IDENTICAL) reduce 36) ((T_IS_NOT_EQUAL) reduce 36) ((T_IS_NOT_IDENTICAL) reduce 36) ((T_IS_SMALLER_OR_EQUAL) reduce 36) ((T_LOGICAL_AND) reduce 36) ((T_LOGICAL_OR) reduce 36) ((T_LOGICAL_XOR) reduce 36) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 36) ((T_OBJECT_OPERATOR) reduce 36) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 36) ((T_POW) reduce 36) ((T_SL) reduce 36) ((T_SPACESHIP) reduce 36) ((T_SR) reduce 36) (("[") reduce 36) (("^") reduce 36) (("{") reduce 36) (("|") reduce 36)) 22795 ((("%") reduce 32) (("(") reduce 32) (("*") reduce 32) (("+") reduce 32) (("-") reduce 32) ((".") reduce 32) (("/") reduce 32) ((":") reduce 32) ((";") reduce 32) (("<") reduce 32) ((">") reduce 32) (("?") reduce 32) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_BOOLEAN_AND) reduce 32) ((T_BOOLEAN_OR) reduce 32) ((T_COALESCE) reduce 32) ((T_DOUBLE_ARROW) reduce 32) ((T_INSTANCEOF) reduce 32) ((T_IS_EQUAL) reduce 32) ((T_IS_GREATER_OR_EQUAL) reduce 32) ((T_IS_IDENTICAL) reduce 32) ((T_IS_NOT_EQUAL) reduce 32) ((T_IS_NOT_IDENTICAL) reduce 32) ((T_IS_SMALLER_OR_EQUAL) reduce 32) ((T_LOGICAL_AND) reduce 32) ((T_LOGICAL_OR) reduce 32) ((T_LOGICAL_XOR) reduce 32) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 32) ((T_OBJECT_OPERATOR) reduce 32) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 32) ((T_POW) reduce 32) ((T_SL) reduce 32) ((T_SPACESHIP) reduce 32) ((T_SR) reduce 32) (("[") reduce 32) (("^") reduce 32) (("{") reduce 32) (("|") reduce 32)) 22796 ((("%") reduce 35) (("(") reduce 35) (("*") reduce 35) (("+") reduce 35) (("-") reduce 35) ((".") reduce 35) (("/") reduce 35) ((":") reduce 35) ((";") reduce 35) (("<") reduce 35) ((">") reduce 35) (("?") reduce 35) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_BOOLEAN_AND) reduce 35) ((T_BOOLEAN_OR) reduce 35) ((T_COALESCE) reduce 35) ((T_DOUBLE_ARROW) reduce 35) ((T_INSTANCEOF) reduce 35) ((T_IS_EQUAL) reduce 35) ((T_IS_GREATER_OR_EQUAL) reduce 35) ((T_IS_IDENTICAL) reduce 35) ((T_IS_NOT_EQUAL) reduce 35) ((T_IS_NOT_IDENTICAL) reduce 35) ((T_IS_SMALLER_OR_EQUAL) reduce 35) ((T_LOGICAL_AND) reduce 35) ((T_LOGICAL_OR) reduce 35) ((T_LOGICAL_XOR) reduce 35) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 35) ((T_OBJECT_OPERATOR) reduce 35) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 35) ((T_POW) reduce 35) ((T_SL) reduce 35) ((T_SPACESHIP) reduce 35) ((T_SR) reduce 35) (("[") reduce 35) (("^") reduce 35) (("{") reduce 35) (("|") reduce 35)) 22797 ((("%") reduce 19) (("(") reduce 19) (("*") reduce 19) (("+") reduce 19) (("-") reduce 19) ((".") reduce 19) (("/") reduce 19) ((":") reduce 19) ((";") reduce 19) (("<") reduce 19) ((">") reduce 19) (("?") reduce 19) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_BOOLEAN_AND) reduce 19) ((T_BOOLEAN_OR) reduce 19) ((T_COALESCE) reduce 19) ((T_DOUBLE_ARROW) reduce 19) ((T_INSTANCEOF) reduce 19) ((T_IS_EQUAL) reduce 19) ((T_IS_GREATER_OR_EQUAL) reduce 19) ((T_IS_IDENTICAL) reduce 19) ((T_IS_NOT_EQUAL) reduce 19) ((T_IS_NOT_IDENTICAL) reduce 19) ((T_IS_SMALLER_OR_EQUAL) reduce 19) ((T_LOGICAL_AND) reduce 19) ((T_LOGICAL_OR) reduce 19) ((T_LOGICAL_XOR) reduce 19) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 19) ((T_OBJECT_OPERATOR) reduce 19) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 19) ((T_POW) reduce 19) ((T_SL) reduce 19) ((T_SPACESHIP) reduce 19) ((T_SR) reduce 19) (("[") reduce 19) (("^") reduce 19) (("{") reduce 19) (("|") reduce 19)) 22798 ((("%") reduce 45) (("(") reduce 45) (("*") reduce 45) (("+") reduce 45) (("-") reduce 45) ((".") reduce 45) (("/") reduce 45) ((":") reduce 45) ((";") reduce 45) (("<") reduce 45) ((">") reduce 45) (("?") reduce 45) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_BOOLEAN_AND) reduce 45) ((T_BOOLEAN_OR) reduce 45) ((T_COALESCE) reduce 45) ((T_DOUBLE_ARROW) reduce 45) ((T_INSTANCEOF) reduce 45) ((T_IS_EQUAL) reduce 45) ((T_IS_GREATER_OR_EQUAL) reduce 45) ((T_IS_IDENTICAL) reduce 45) ((T_IS_NOT_EQUAL) reduce 45) ((T_IS_NOT_IDENTICAL) reduce 45) ((T_IS_SMALLER_OR_EQUAL) reduce 45) ((T_LOGICAL_AND) reduce 45) ((T_LOGICAL_OR) reduce 45) ((T_LOGICAL_XOR) reduce 45) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 45) ((T_OBJECT_OPERATOR) reduce 45) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 45) ((T_POW) reduce 45) ((T_SL) reduce 45) ((T_SPACESHIP) reduce 45) ((T_SR) reduce 45) (("[") reduce 45) (("^") reduce 45) (("{") reduce 45) (("|") reduce 45)) 22799 ((("%") reduce 504) (("(") reduce 541) (("*") reduce 504) (("+") reduce 504) (("-") reduce 504) ((".") reduce 504) (("/") reduce 504) ((":") reduce 504) ((";") reduce 504) (("<") reduce 504) ((">") reduce 504) (("?") reduce 504) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_BOOLEAN_AND) reduce 504) ((T_BOOLEAN_OR) reduce 504) ((T_COALESCE) reduce 504) ((T_DOUBLE_ARROW) reduce 504) ((T_INSTANCEOF) reduce 504) ((T_IS_EQUAL) reduce 504) ((T_IS_GREATER_OR_EQUAL) reduce 504) ((T_IS_IDENTICAL) reduce 504) ((T_IS_NOT_EQUAL) reduce 504) ((T_IS_NOT_IDENTICAL) reduce 504) ((T_IS_SMALLER_OR_EQUAL) reduce 504) ((T_LOGICAL_AND) reduce 504) ((T_LOGICAL_OR) reduce 504) ((T_LOGICAL_XOR) reduce 504) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 504) ((T_OBJECT_OPERATOR) reduce 504) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 504) ((T_POW) reduce 504) ((T_SL) reduce 504) ((T_SPACESHIP) reduce 504) ((T_SR) reduce 504) (("[") reduce 504) (("^") reduce 504) (("{") reduce 504) (("|") reduce 504)) 22801 ((("%") reduce 71) (("(") reduce 71) (("*") reduce 71) (("+") reduce 71) (("-") reduce 71) ((".") reduce 71) (("/") reduce 71) ((":") reduce 71) ((";") reduce 71) (("<") reduce 71) ((">") reduce 71) (("?") reduce 71) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_BOOLEAN_AND) reduce 71) ((T_BOOLEAN_OR) reduce 71) ((T_COALESCE) reduce 71) ((T_DOUBLE_ARROW) reduce 71) ((T_INSTANCEOF) reduce 71) ((T_IS_EQUAL) reduce 71) ((T_IS_GREATER_OR_EQUAL) reduce 71) ((T_IS_IDENTICAL) reduce 71) ((T_IS_NOT_EQUAL) reduce 71) ((T_IS_NOT_IDENTICAL) reduce 71) ((T_IS_SMALLER_OR_EQUAL) reduce 71) ((T_LOGICAL_AND) reduce 71) ((T_LOGICAL_OR) reduce 71) ((T_LOGICAL_XOR) reduce 71) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 71) ((T_OBJECT_OPERATOR) reduce 71) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 71) ((T_POW) reduce 71) ((T_SL) reduce 71) ((T_SPACESHIP) reduce 71) ((T_SR) reduce 71) (("[") reduce 71) (("^") reduce 71) (("{") reduce 71) (("|") reduce 71)) 22802 ((("%") reduce 82) (("(") reduce 82) (("*") reduce 82) (("+") reduce 82) (("-") reduce 82) ((".") reduce 82) (("/") reduce 82) ((":") reduce 82) ((";") reduce 82) (("<") reduce 82) ((">") reduce 82) (("?") reduce 82) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_BOOLEAN_AND) reduce 82) ((T_BOOLEAN_OR) reduce 82) ((T_COALESCE) reduce 82) ((T_DOUBLE_ARROW) reduce 82) ((T_INSTANCEOF) reduce 82) ((T_IS_EQUAL) reduce 82) ((T_IS_GREATER_OR_EQUAL) reduce 82) ((T_IS_IDENTICAL) reduce 82) ((T_IS_NOT_EQUAL) reduce 82) ((T_IS_NOT_IDENTICAL) reduce 82) ((T_IS_SMALLER_OR_EQUAL) reduce 82) ((T_LOGICAL_AND) reduce 82) ((T_LOGICAL_OR) reduce 82) ((T_LOGICAL_XOR) reduce 82) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 82) ((T_OBJECT_OPERATOR) reduce 82) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 82) ((T_POW) reduce 82) ((T_SL) reduce 82) ((T_SPACESHIP) reduce 82) ((T_SR) reduce 82) (("[") reduce 82) (("^") reduce 82) (("{") reduce 82) (("|") reduce 82)) 22803 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) ((":") reduce 533) ((";") reduce 533) (("<") reduce 533) (("=") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AND_EQUAL) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_COALESCE_EQUAL) reduce 533) ((T_CONCAT_EQUAL) reduce 533) ((T_DEC) reduce 533) ((T_DIV_EQUAL) reduce 533) ((T_DOUBLE_ARROW) reduce 533) ((T_INC) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_MINUS_EQUAL) reduce 533) ((T_MOD_EQUAL) reduce 533) ((T_MUL_EQUAL) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_OR_EQUAL) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_PLUS_EQUAL) reduce 533) ((T_POW) reduce 533) ((T_POW_EQUAL) reduce 533) ((T_SL) reduce 533) ((T_SL_EQUAL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) ((T_SR_EQUAL) reduce 533) ((T_XOR_EQUAL) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 22806 ((("%") reduce 506) (("(") reduce 542) (("*") reduce 506) (("+") reduce 506) (("-") reduce 506) ((".") reduce 506) (("/") reduce 506) ((":") reduce 506) ((";") reduce 506) (("<") reduce 506) ((">") reduce 506) (("?") reduce 506) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_BOOLEAN_AND) reduce 506) ((T_BOOLEAN_OR) reduce 506) ((T_COALESCE) reduce 506) ((T_DOUBLE_ARROW) reduce 506) ((T_INSTANCEOF) reduce 506) ((T_IS_EQUAL) reduce 506) ((T_IS_GREATER_OR_EQUAL) reduce 506) ((T_IS_IDENTICAL) reduce 506) ((T_IS_NOT_EQUAL) reduce 506) ((T_IS_NOT_IDENTICAL) reduce 506) ((T_IS_SMALLER_OR_EQUAL) reduce 506) ((T_LOGICAL_AND) reduce 506) ((T_LOGICAL_OR) reduce 506) ((T_LOGICAL_XOR) reduce 506) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 506) ((T_OBJECT_OPERATOR) reduce 506) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 506) ((T_POW) reduce 506) ((T_SL) reduce 506) ((T_SPACESHIP) reduce 506) ((T_SR) reduce 506) (("[") reduce 506) (("^") reduce 506) (("{") reduce 506) (("|") reduce 506)) 22808 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) ((":") reduce 468) ((";") reduce 468) (("<") reduce 468) (("=") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AND_EQUAL) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_COALESCE_EQUAL) reduce 468) ((T_CONCAT_EQUAL) reduce 468) ((T_DEC) reduce 468) ((T_DIV_EQUAL) reduce 468) ((T_DOUBLE_ARROW) reduce 468) ((T_INC) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_MINUS_EQUAL) reduce 468) ((T_MOD_EQUAL) reduce 468) ((T_MUL_EQUAL) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_OR_EQUAL) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_PLUS_EQUAL) reduce 468) ((T_POW) reduce 468) ((T_POW_EQUAL) reduce 468) ((T_SL) reduce 468) ((T_SL_EQUAL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) ((T_SR_EQUAL) reduce 468) ((T_XOR_EQUAL) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 22809 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) ((":") reduce 288) ((";") reduce 288) (("<") reduce 288) (("=") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AND_EQUAL) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_COALESCE_EQUAL) reduce 288) ((T_CONCAT_EQUAL) reduce 288) ((T_DEC) reduce 288) ((T_DIV_EQUAL) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INC) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_MINUS_EQUAL) reduce 288) ((T_MOD_EQUAL) reduce 288) ((T_MUL_EQUAL) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_OR_EQUAL) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_PLUS_EQUAL) reduce 288) ((T_POW) reduce 288) ((T_POW_EQUAL) reduce 288) ((T_SL) reduce 288) ((T_SL_EQUAL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) ((T_SR_EQUAL) reduce 288) ((T_XOR_EQUAL) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 22813 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) ((":") reduce 289) ((";") reduce 289) (("<") reduce 289) (("=") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AND_EQUAL) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_COALESCE_EQUAL) reduce 289) ((T_CONCAT_EQUAL) reduce 289) ((T_DEC) reduce 289) ((T_DIV_EQUAL) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INC) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_MINUS_EQUAL) reduce 289) ((T_MOD_EQUAL) reduce 289) ((T_MUL_EQUAL) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_OR_EQUAL) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_PLUS_EQUAL) reduce 289) ((T_POW) reduce 289) ((T_POW_EQUAL) reduce 289) ((T_SL) reduce 289) ((T_SL_EQUAL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) ((T_SR_EQUAL) reduce 289) ((T_XOR_EQUAL) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 22814 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) ((":") reduce 290) ((";") reduce 290) (("<") reduce 290) (("=") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AND_EQUAL) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_COALESCE_EQUAL) reduce 290) ((T_CONCAT_EQUAL) reduce 290) ((T_DEC) reduce 290) ((T_DIV_EQUAL) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INC) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_MINUS_EQUAL) reduce 290) ((T_MOD_EQUAL) reduce 290) ((T_MUL_EQUAL) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_OR_EQUAL) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_PLUS_EQUAL) reduce 290) ((T_POW) reduce 290) ((T_POW_EQUAL) reduce 290) ((T_SL) reduce 290) ((T_SL_EQUAL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) ((T_SR_EQUAL) reduce 290) ((T_XOR_EQUAL) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 22819 ((("%") reduce 388) (("*") reduce 388) (("+") reduce 388) (("-") reduce 388) ((".") reduce 388) (("/") reduce 388) ((":") reduce 388) ((";") reduce 388) (("<") reduce 388) ((">") reduce 388) (("?") reduce 388) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_BOOLEAN_AND) reduce 388) ((T_BOOLEAN_OR) reduce 388) ((T_COALESCE) reduce 388) ((T_DOUBLE_ARROW) reduce 388) ((T_INSTANCEOF) reduce 388) ((T_IS_EQUAL) reduce 388) ((T_IS_GREATER_OR_EQUAL) reduce 388) ((T_IS_IDENTICAL) reduce 388) ((T_IS_NOT_EQUAL) reduce 388) ((T_IS_NOT_IDENTICAL) reduce 388) ((T_IS_SMALLER_OR_EQUAL) reduce 388) ((T_LOGICAL_AND) reduce 388) ((T_LOGICAL_OR) reduce 388) ((T_LOGICAL_XOR) reduce 388) ((T_POW) reduce 388) ((T_SL) reduce 388) ((T_SPACESHIP) reduce 388) ((T_SR) reduce 388) (("^") reduce 388) (("|") reduce 388)) 22821 ((("%") reduce 386) (("*") reduce 386) (("+") reduce 386) (("-") reduce 386) ((".") reduce 386) (("/") reduce 386) ((":") reduce 386) ((";") reduce 386) (("<") reduce 386) ((">") reduce 386) (("?") reduce 386) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_BOOLEAN_AND) reduce 386) ((T_BOOLEAN_OR) reduce 386) ((T_COALESCE) reduce 386) ((T_DOUBLE_ARROW) reduce 386) ((T_INSTANCEOF) reduce 386) ((T_IS_EQUAL) reduce 386) ((T_IS_GREATER_OR_EQUAL) reduce 386) ((T_IS_IDENTICAL) reduce 386) ((T_IS_NOT_EQUAL) reduce 386) ((T_IS_NOT_IDENTICAL) reduce 386) ((T_IS_SMALLER_OR_EQUAL) reduce 386) ((T_LOGICAL_AND) reduce 386) ((T_LOGICAL_OR) reduce 386) ((T_LOGICAL_XOR) reduce 386) ((T_POW) reduce 386) ((T_SL) reduce 386) ((T_SPACESHIP) reduce 386) ((T_SR) reduce 386) (("^") reduce 386) (("|") reduce 386)) 22831 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 382) ((";") reduce 382) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 382) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 382) ((T_LOGICAL_OR) reduce 382) ((T_LOGICAL_XOR) reduce 382) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22832 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 384) ((";") reduce 384) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 384) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 384) ((T_LOGICAL_OR) reduce 384) ((T_LOGICAL_XOR) reduce 384) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22833 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 383) ((";") reduce 383) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 383) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 383) ((T_LOGICAL_OR) reduce 383) ((T_LOGICAL_XOR) reduce 383) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22834 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 376) ((";") reduce 376) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 376) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 376) ((T_LOGICAL_OR) reduce 376) ((T_LOGICAL_XOR) reduce 376) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22835 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 373) ((";") reduce 373) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 373) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 373) ((T_LOGICAL_OR) reduce 373) ((T_LOGICAL_XOR) reduce 373) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22836 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 381) ((";") reduce 381) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 381) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 381) ((T_LOGICAL_OR) reduce 381) ((T_LOGICAL_XOR) reduce 381) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22837 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 375) ((";") reduce 375) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 375) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 375) ((T_LOGICAL_OR) reduce 375) ((T_LOGICAL_XOR) reduce 375) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22838 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 379) ((";") reduce 379) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 379) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 379) ((T_LOGICAL_OR) reduce 379) ((T_LOGICAL_XOR) reduce 379) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22839 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 374) ((";") reduce 374) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 374) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 374) ((T_LOGICAL_OR) reduce 374) ((T_LOGICAL_XOR) reduce 374) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22840 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 377) ((";") reduce 377) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 377) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 377) ((T_LOGICAL_OR) reduce 377) ((T_LOGICAL_XOR) reduce 377) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22841 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 378) ((";") reduce 378) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 378) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 378) ((T_LOGICAL_OR) reduce 378) ((T_LOGICAL_XOR) reduce 378) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22842 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 385) ((";") reduce 385) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 385) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 385) ((T_LOGICAL_OR) reduce 385) ((T_LOGICAL_XOR) reduce 385) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22843 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 380) ((";") reduce 380) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 380) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 380) ((T_LOGICAL_OR) reduce 380) ((T_LOGICAL_XOR) reduce 380) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22845 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 370) ((";") reduce 370) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 370) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 370) ((T_LOGICAL_OR) reduce 370) ((T_LOGICAL_XOR) reduce 370) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22848 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) ((":") reduce 529) ((";") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 22851 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) ((":") reduce 525) ((";") reduce 525) (("<") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_DOUBLE_ARROW) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_POW) reduce 525) ((T_SL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 22853 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) ((":") reduce 524) ((";") reduce 524) (("<") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_DOUBLE_ARROW) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_POW) reduce 524) ((T_SL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 22855 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) ((":") reduce 519) ((";") reduce 519) (("<") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_DOUBLE_ARROW) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_POW) reduce 519) ((T_SL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 22856 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) ((":") reduce 526) ((";") reduce 526) (("<") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_DOUBLE_ARROW) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_POW) reduce 526) ((T_SL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 22857 ((("%") reduce 371) (("*") reduce 371) (("+") reduce 371) (("-") reduce 371) ((".") reduce 371) (("/") reduce 371) ((":") reduce 371) ((";") reduce 371) (("<") reduce 371) ((">") reduce 371) (("?") reduce 371) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_BOOLEAN_AND) reduce 371) ((T_BOOLEAN_OR) reduce 371) ((T_COALESCE) reduce 371) ((T_DOUBLE_ARROW) reduce 371) ((T_INSTANCEOF) reduce 371) ((T_IS_EQUAL) reduce 371) ((T_IS_GREATER_OR_EQUAL) reduce 371) ((T_IS_IDENTICAL) reduce 371) ((T_IS_NOT_EQUAL) reduce 371) ((T_IS_NOT_IDENTICAL) reduce 371) ((T_IS_SMALLER_OR_EQUAL) reduce 371) ((T_LOGICAL_AND) reduce 371) ((T_LOGICAL_OR) reduce 371) ((T_LOGICAL_XOR) reduce 371) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 371) ((T_SL) reduce 371) ((T_SPACESHIP) reduce 371) ((T_SR) reduce 371) (("[") reduce 510) (("^") reduce 371) (("{") reduce 510) (("|") reduce 371)) 22861 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) ((":") reduce 533) ((";") reduce 533) (("<") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_DOUBLE_ARROW) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_POW) reduce 533) ((T_SL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 22863 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) ((":") reduce 468) ((";") reduce 468) (("<") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_DOUBLE_ARROW) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_POW) reduce 468) ((T_SL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 22864 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) ((":") reduce 288) ((";") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 22868 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) ((":") reduce 289) ((";") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 22869 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) ((":") reduce 290) ((";") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 22870 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) ((":") reduce 465) ((";") reduce 465) (("<") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_DOUBLE_ARROW) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_POW) reduce 465) ((T_SL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 22873 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) ((":") reduce 532) ((";") reduce 532) (("<") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_DOUBLE_ARROW) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_POW) reduce 532) ((T_SL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 22874 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) ((":") reduce 467) ((";") reduce 467) (("<") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_DOUBLE_ARROW) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_POW) reduce 467) ((T_SL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 22875 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) ((":") reduce 469) ((";") reduce 469) (("<") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_DOUBLE_ARROW) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_POW) reduce 469) ((T_SL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 22881 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) ((":") reduce 521) ((";") reduce 521) (("<") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_DOUBLE_ARROW) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_POW) reduce 521) ((T_SL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 22883 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) ((":") reduce 520) ((";") reduce 520) (("<") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_DOUBLE_ARROW) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_POW) reduce 520) ((T_SL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 22884 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) ((":") reduce 544) ((";") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 22885 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) ((":") reduce 527) ((";") reduce 527) (("<") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_DOUBLE_ARROW) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_POW) reduce 527) ((T_SL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 22886 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) ((":") reduce 546) ((";") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 22889 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) ((":") reduce 545) ((";") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 22890 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) ((":") reduce 522) ((";") reduce 522) (("<") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_DOUBLE_ARROW) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_POW) reduce 522) ((T_SL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 22891 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) ((":") reduce 528) ((";") reduce 528) (("<") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_DOUBLE_ARROW) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_POW) reduce 528) ((T_SL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 22892 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) ((":") reduce 523) ((";") reduce 523) (("<") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_DOUBLE_ARROW) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_POW) reduce 523) ((T_SL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 22893 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) ((":") reduce 466) ((";") reduce 466) (("<") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_DOUBLE_ARROW) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_POW) reduce 466) ((T_SL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 22894 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) ((":") reduce 531) ((";") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 22897 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) ((":") reduce 530) ((";") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 22898 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) ((":") reduce 465) ((";") reduce 465) (("<") reduce 465) (("=") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AND_EQUAL) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_COALESCE_EQUAL) reduce 465) ((T_CONCAT_EQUAL) reduce 465) ((T_DEC) reduce 465) ((T_DIV_EQUAL) reduce 465) ((T_DOUBLE_ARROW) reduce 465) ((T_INC) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_MINUS_EQUAL) reduce 465) ((T_MOD_EQUAL) reduce 465) ((T_MUL_EQUAL) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_OR_EQUAL) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_PLUS_EQUAL) reduce 465) ((T_POW) reduce 465) ((T_POW_EQUAL) reduce 465) ((T_SL) reduce 465) ((T_SL_EQUAL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) ((T_SR_EQUAL) reduce 465) ((T_XOR_EQUAL) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 22909 ((("%") reduce 455) (("*") reduce 455) (("+") reduce 455) (("-") reduce 455) ((".") reduce 455) (("/") reduce 455) ((":") reduce 455) ((";") reduce 455) (("<") reduce 455) ((">") reduce 455) (("?") reduce 455) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_BOOLEAN_AND) reduce 455) ((T_BOOLEAN_OR) reduce 455) ((T_COALESCE) reduce 455) ((T_DOUBLE_ARROW) reduce 455) ((T_INSTANCEOF) reduce 455) ((T_IS_EQUAL) reduce 455) ((T_IS_GREATER_OR_EQUAL) reduce 455) ((T_IS_IDENTICAL) reduce 455) ((T_IS_NOT_EQUAL) reduce 455) ((T_IS_NOT_IDENTICAL) reduce 455) ((T_IS_SMALLER_OR_EQUAL) reduce 455) ((T_LOGICAL_AND) reduce 455) ((T_LOGICAL_OR) reduce 455) ((T_LOGICAL_XOR) reduce 455) ((T_POW) reduce 455) ((T_SL) reduce 455) ((T_SPACESHIP) reduce 455) ((T_SR) reduce 455) (("^") reduce 455) (("|") reduce 455)) 22910 ((("%") reduce 450) (("*") reduce 450) (("+") reduce 450) (("-") reduce 450) ((".") reduce 450) (("/") reduce 450) ((":") reduce 450) ((";") reduce 450) (("<") reduce 450) ((">") reduce 450) (("?") reduce 450) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_BOOLEAN_AND) reduce 450) ((T_BOOLEAN_OR) reduce 450) ((T_COALESCE) reduce 450) ((T_DOUBLE_ARROW) reduce 450) ((T_INSTANCEOF) reduce 450) ((T_IS_EQUAL) reduce 450) ((T_IS_GREATER_OR_EQUAL) reduce 450) ((T_IS_IDENTICAL) reduce 450) ((T_IS_NOT_EQUAL) reduce 450) ((T_IS_NOT_IDENTICAL) reduce 450) ((T_IS_SMALLER_OR_EQUAL) reduce 450) ((T_LOGICAL_AND) reduce 450) ((T_LOGICAL_OR) reduce 450) ((T_LOGICAL_XOR) reduce 450) ((T_POW) reduce 450) ((T_SL) reduce 450) ((T_SPACESHIP) reduce 450) ((T_SR) reduce 450) (("^") reduce 450) (("|") reduce 450)) 22920 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 455) ((";") reduce 455) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 455) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22921 ((("%") reduce 451) (("*") reduce 451) (("+") reduce 451) (("-") reduce 451) ((".") reduce 451) (("/") reduce 451) ((":") reduce 451) ((";") reduce 451) (("<") reduce 451) ((">") reduce 451) (("?") reduce 451) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_BOOLEAN_AND) reduce 451) ((T_BOOLEAN_OR) reduce 451) ((T_COALESCE) reduce 451) ((T_DOUBLE_ARROW) reduce 451) ((T_INSTANCEOF) reduce 451) ((T_IS_EQUAL) reduce 451) ((T_IS_GREATER_OR_EQUAL) reduce 451) ((T_IS_IDENTICAL) reduce 451) ((T_IS_NOT_EQUAL) reduce 451) ((T_IS_NOT_IDENTICAL) reduce 451) ((T_IS_SMALLER_OR_EQUAL) reduce 451) ((T_LOGICAL_AND) reduce 451) ((T_LOGICAL_OR) reduce 451) ((T_LOGICAL_XOR) reduce 451) ((T_POW) reduce 451) ((T_SL) reduce 451) ((T_SPACESHIP) reduce 451) ((T_SR) reduce 451) (("^") reduce 451) (("|") reduce 451)) 22923 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 442) ((";") reduce 442) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 442) ((T_LOGICAL_OR) reduce 442) ((T_LOGICAL_XOR) reduce 442) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22925 ((("%") reduce 503) (("(") reduce 541) (("*") reduce 503) (("+") reduce 503) (("-") reduce 503) ((".") reduce 503) (("/") reduce 503) ((":") reduce 503) ((";") reduce 503) (("<") reduce 503) ((">") reduce 503) (("?") reduce 503) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_BOOLEAN_AND) reduce 503) ((T_BOOLEAN_OR) reduce 503) ((T_COALESCE) reduce 503) ((T_DOUBLE_ARROW) reduce 503) ((T_INSTANCEOF) reduce 503) ((T_IS_EQUAL) reduce 503) ((T_IS_GREATER_OR_EQUAL) reduce 503) ((T_IS_IDENTICAL) reduce 503) ((T_IS_NOT_EQUAL) reduce 503) ((T_IS_NOT_IDENTICAL) reduce 503) ((T_IS_SMALLER_OR_EQUAL) reduce 503) ((T_LOGICAL_AND) reduce 503) ((T_LOGICAL_OR) reduce 503) ((T_LOGICAL_XOR) reduce 503) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 503) ((T_OBJECT_OPERATOR) reduce 503) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 503) ((T_POW) reduce 503) ((T_SL) reduce 503) ((T_SPACESHIP) reduce 503) ((T_SR) reduce 503) (("[") reduce 503) (("^") reduce 503) (("{") reduce 503) (("|") reduce 503)) 22927 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) ((":") reduce 532) ((";") reduce 532) (("<") reduce 532) (("=") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AND_EQUAL) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_COALESCE_EQUAL) reduce 532) ((T_CONCAT_EQUAL) reduce 532) ((T_DEC) reduce 532) ((T_DIV_EQUAL) reduce 532) ((T_DOUBLE_ARROW) reduce 532) ((T_INC) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_MINUS_EQUAL) reduce 532) ((T_MOD_EQUAL) reduce 532) ((T_MUL_EQUAL) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_OR_EQUAL) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_PLUS_EQUAL) reduce 532) ((T_POW) reduce 532) ((T_POW_EQUAL) reduce 532) ((T_SL) reduce 532) ((T_SL_EQUAL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) ((T_SR_EQUAL) reduce 532) ((T_XOR_EQUAL) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 22930 ((("%") reduce 505) (("(") reduce 542) (("*") reduce 505) (("+") reduce 505) (("-") reduce 505) ((".") reduce 505) (("/") reduce 505) ((":") reduce 505) ((";") reduce 505) (("<") reduce 505) ((">") reduce 505) (("?") reduce 505) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_BOOLEAN_AND) reduce 505) ((T_BOOLEAN_OR) reduce 505) ((T_COALESCE) reduce 505) ((T_DOUBLE_ARROW) reduce 505) ((T_INSTANCEOF) reduce 505) ((T_IS_EQUAL) reduce 505) ((T_IS_GREATER_OR_EQUAL) reduce 505) ((T_IS_IDENTICAL) reduce 505) ((T_IS_NOT_EQUAL) reduce 505) ((T_IS_NOT_IDENTICAL) reduce 505) ((T_IS_SMALLER_OR_EQUAL) reduce 505) ((T_LOGICAL_AND) reduce 505) ((T_LOGICAL_OR) reduce 505) ((T_LOGICAL_XOR) reduce 505) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 505) ((T_OBJECT_OPERATOR) reduce 505) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 505) ((T_POW) reduce 505) ((T_SL) reduce 505) ((T_SPACESHIP) reduce 505) ((T_SR) reduce 505) (("[") reduce 505) (("^") reduce 505) (("{") reduce 505) (("|") reduce 505)) 22931 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) ((":") reduce 467) ((";") reduce 467) (("<") reduce 467) (("=") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AND_EQUAL) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_COALESCE_EQUAL) reduce 467) ((T_CONCAT_EQUAL) reduce 467) ((T_DEC) reduce 467) ((T_DIV_EQUAL) reduce 467) ((T_DOUBLE_ARROW) reduce 467) ((T_INC) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_MINUS_EQUAL) reduce 467) ((T_MOD_EQUAL) reduce 467) ((T_MUL_EQUAL) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_OR_EQUAL) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_PLUS_EQUAL) reduce 467) ((T_POW) reduce 467) ((T_POW_EQUAL) reduce 467) ((T_SL) reduce 467) ((T_SL_EQUAL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) ((T_SR_EQUAL) reduce 467) ((T_XOR_EQUAL) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 22932 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) ((":") reduce 469) ((";") reduce 469) (("<") reduce 469) (("=") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AND_EQUAL) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_COALESCE_EQUAL) reduce 469) ((T_CONCAT_EQUAL) reduce 469) ((T_DEC) reduce 469) ((T_DIV_EQUAL) reduce 469) ((T_DOUBLE_ARROW) reduce 469) ((T_INC) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_MINUS_EQUAL) reduce 469) ((T_MOD_EQUAL) reduce 469) ((T_MUL_EQUAL) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_OR_EQUAL) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_PLUS_EQUAL) reduce 469) ((T_POW) reduce 469) ((T_POW_EQUAL) reduce 469) ((T_SL) reduce 469) ((T_SL_EQUAL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) ((T_SR_EQUAL) reduce 469) ((T_XOR_EQUAL) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 22934 ((("%") reduce 446) (("*") reduce 446) (("+") reduce 446) (("-") reduce 446) ((".") reduce 446) (("/") reduce 446) ((":") reduce 446) ((";") reduce 446) (("<") reduce 446) ((">") reduce 446) (("?") reduce 446) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_BOOLEAN_AND) reduce 446) ((T_BOOLEAN_OR) reduce 446) ((T_COALESCE) reduce 446) ((T_DOUBLE_ARROW) reduce 446) ((T_INSTANCEOF) reduce 446) ((T_IS_EQUAL) reduce 446) ((T_IS_GREATER_OR_EQUAL) reduce 446) ((T_IS_IDENTICAL) reduce 446) ((T_IS_NOT_EQUAL) reduce 446) ((T_IS_NOT_IDENTICAL) reduce 446) ((T_IS_SMALLER_OR_EQUAL) reduce 446) ((T_LOGICAL_AND) reduce 446) ((T_LOGICAL_OR) reduce 446) ((T_LOGICAL_XOR) reduce 446) ((T_POW) reduce 446) ((T_SL) reduce 446) ((T_SPACESHIP) reduce 446) ((T_SR) reduce 446) (("^") reduce 446) (("|") reduce 446)) 22935 ((("%") reduce 448) (("*") reduce 448) (("+") reduce 448) (("-") reduce 448) ((".") reduce 448) (("/") reduce 448) ((":") reduce 448) ((";") reduce 448) (("<") reduce 448) ((">") reduce 448) (("?") reduce 448) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_BOOLEAN_AND) reduce 448) ((T_BOOLEAN_OR) reduce 448) ((T_COALESCE) reduce 448) ((T_DOUBLE_ARROW) reduce 448) ((T_INSTANCEOF) reduce 448) ((T_IS_EQUAL) reduce 448) ((T_IS_GREATER_OR_EQUAL) reduce 448) ((T_IS_IDENTICAL) reduce 448) ((T_IS_NOT_EQUAL) reduce 448) ((T_IS_NOT_IDENTICAL) reduce 448) ((T_IS_SMALLER_OR_EQUAL) reduce 448) ((T_LOGICAL_AND) reduce 448) ((T_LOGICAL_OR) reduce 448) ((T_LOGICAL_XOR) reduce 448) ((T_POW) reduce 448) ((T_SL) reduce 448) ((T_SPACESHIP) reduce 448) ((T_SR) reduce 448) (("^") reduce 448) (("|") reduce 448)) 22941 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) ((":") reduce 521) ((";") reduce 521) (("<") reduce 521) (("=") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AND_EQUAL) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_COALESCE_EQUAL) reduce 521) ((T_CONCAT_EQUAL) reduce 521) ((T_DEC) reduce 521) ((T_DIV_EQUAL) reduce 521) ((T_DOUBLE_ARROW) reduce 521) ((T_INC) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_MINUS_EQUAL) reduce 521) ((T_MOD_EQUAL) reduce 521) ((T_MUL_EQUAL) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_OR_EQUAL) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_PLUS_EQUAL) reduce 521) ((T_POW) reduce 521) ((T_POW_EQUAL) reduce 521) ((T_SL) reduce 521) ((T_SL_EQUAL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) ((T_SR_EQUAL) reduce 521) ((T_XOR_EQUAL) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 22943 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) ((":") reduce 520) ((";") reduce 520) (("<") reduce 520) (("=") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AND_EQUAL) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_COALESCE_EQUAL) reduce 520) ((T_CONCAT_EQUAL) reduce 520) ((T_DEC) reduce 520) ((T_DIV_EQUAL) reduce 520) ((T_DOUBLE_ARROW) reduce 520) ((T_INC) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_MINUS_EQUAL) reduce 520) ((T_MOD_EQUAL) reduce 520) ((T_MUL_EQUAL) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_OR_EQUAL) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_PLUS_EQUAL) reduce 520) ((T_POW) reduce 520) ((T_POW_EQUAL) reduce 520) ((T_SL) reduce 520) ((T_SL_EQUAL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) ((T_SR_EQUAL) reduce 520) ((T_XOR_EQUAL) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 22944 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) ((":") reduce 544) ((";") reduce 544) (("<") reduce 544) (("=") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AND_EQUAL) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_COALESCE_EQUAL) reduce 544) ((T_CONCAT_EQUAL) reduce 544) ((T_DEC) reduce 544) ((T_DIV_EQUAL) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INC) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_MINUS_EQUAL) reduce 544) ((T_MOD_EQUAL) reduce 544) ((T_MUL_EQUAL) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_OR_EQUAL) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_PLUS_EQUAL) reduce 544) ((T_POW) reduce 544) ((T_POW_EQUAL) reduce 544) ((T_SL) reduce 544) ((T_SL_EQUAL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) ((T_SR_EQUAL) reduce 544) ((T_XOR_EQUAL) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 22945 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) ((":") reduce 527) ((";") reduce 527) (("<") reduce 527) (("=") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AND_EQUAL) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_COALESCE_EQUAL) reduce 527) ((T_CONCAT_EQUAL) reduce 527) ((T_DEC) reduce 527) ((T_DIV_EQUAL) reduce 527) ((T_DOUBLE_ARROW) reduce 527) ((T_INC) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_MINUS_EQUAL) reduce 527) ((T_MOD_EQUAL) reduce 527) ((T_MUL_EQUAL) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_OR_EQUAL) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_PLUS_EQUAL) reduce 527) ((T_POW) reduce 527) ((T_POW_EQUAL) reduce 527) ((T_SL) reduce 527) ((T_SL_EQUAL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) ((T_SR_EQUAL) reduce 527) ((T_XOR_EQUAL) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 22946 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) ((":") reduce 546) ((";") reduce 546) (("<") reduce 546) (("=") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AND_EQUAL) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_COALESCE_EQUAL) reduce 546) ((T_CONCAT_EQUAL) reduce 546) ((T_DEC) reduce 546) ((T_DIV_EQUAL) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INC) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_MINUS_EQUAL) reduce 546) ((T_MOD_EQUAL) reduce 546) ((T_MUL_EQUAL) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_OR_EQUAL) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_PLUS_EQUAL) reduce 546) ((T_POW) reduce 546) ((T_POW_EQUAL) reduce 546) ((T_SL) reduce 546) ((T_SL_EQUAL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) ((T_SR_EQUAL) reduce 546) ((T_XOR_EQUAL) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 22949 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) ((":") reduce 545) ((";") reduce 545) (("<") reduce 545) (("=") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AND_EQUAL) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_COALESCE_EQUAL) reduce 545) ((T_CONCAT_EQUAL) reduce 545) ((T_DEC) reduce 545) ((T_DIV_EQUAL) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INC) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_MINUS_EQUAL) reduce 545) ((T_MOD_EQUAL) reduce 545) ((T_MUL_EQUAL) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_OR_EQUAL) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_PLUS_EQUAL) reduce 545) ((T_POW) reduce 545) ((T_POW_EQUAL) reduce 545) ((T_SL) reduce 545) ((T_SL_EQUAL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) ((T_SR_EQUAL) reduce 545) ((T_XOR_EQUAL) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 22950 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) ((":") reduce 522) ((";") reduce 522) (("<") reduce 522) (("=") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AND_EQUAL) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_COALESCE_EQUAL) reduce 522) ((T_CONCAT_EQUAL) reduce 522) ((T_DEC) reduce 522) ((T_DIV_EQUAL) reduce 522) ((T_DOUBLE_ARROW) reduce 522) ((T_INC) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_MINUS_EQUAL) reduce 522) ((T_MOD_EQUAL) reduce 522) ((T_MUL_EQUAL) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_OR_EQUAL) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_PLUS_EQUAL) reduce 522) ((T_POW) reduce 522) ((T_POW_EQUAL) reduce 522) ((T_SL) reduce 522) ((T_SL_EQUAL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) ((T_SR_EQUAL) reduce 522) ((T_XOR_EQUAL) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 22951 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) ((":") reduce 528) ((";") reduce 528) (("<") reduce 528) (("=") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AND_EQUAL) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_COALESCE_EQUAL) reduce 528) ((T_CONCAT_EQUAL) reduce 528) ((T_DEC) reduce 528) ((T_DIV_EQUAL) reduce 528) ((T_DOUBLE_ARROW) reduce 528) ((T_INC) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_MINUS_EQUAL) reduce 528) ((T_MOD_EQUAL) reduce 528) ((T_MUL_EQUAL) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_OR_EQUAL) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_PLUS_EQUAL) reduce 528) ((T_POW) reduce 528) ((T_POW_EQUAL) reduce 528) ((T_SL) reduce 528) ((T_SL_EQUAL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) ((T_SR_EQUAL) reduce 528) ((T_XOR_EQUAL) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 22952 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) ((":") reduce 523) ((";") reduce 523) (("<") reduce 523) (("=") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AND_EQUAL) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_COALESCE_EQUAL) reduce 523) ((T_CONCAT_EQUAL) reduce 523) ((T_DEC) reduce 523) ((T_DIV_EQUAL) reduce 523) ((T_DOUBLE_ARROW) reduce 523) ((T_INC) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_MINUS_EQUAL) reduce 523) ((T_MOD_EQUAL) reduce 523) ((T_MUL_EQUAL) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_OR_EQUAL) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_PLUS_EQUAL) reduce 523) ((T_POW) reduce 523) ((T_POW_EQUAL) reduce 523) ((T_SL) reduce 523) ((T_SL_EQUAL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) ((T_SR_EQUAL) reduce 523) ((T_XOR_EQUAL) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 22954 ((("%") reduce 438) (("*") reduce 438) (("+") reduce 438) (("-") reduce 438) ((".") reduce 438) (("/") reduce 438) ((":") reduce 438) ((";") reduce 438) (("<") reduce 438) ((">") reduce 438) (("?") reduce 438) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_BOOLEAN_AND) reduce 438) ((T_BOOLEAN_OR) reduce 438) ((T_COALESCE) reduce 438) ((T_DOUBLE_ARROW) reduce 438) ((T_INSTANCEOF) reduce 438) ((T_IS_EQUAL) reduce 438) ((T_IS_GREATER_OR_EQUAL) reduce 438) ((T_IS_IDENTICAL) reduce 438) ((T_IS_NOT_EQUAL) reduce 438) ((T_IS_NOT_IDENTICAL) reduce 438) ((T_IS_SMALLER_OR_EQUAL) reduce 438) ((T_LOGICAL_AND) reduce 438) ((T_LOGICAL_OR) reduce 438) ((T_LOGICAL_XOR) reduce 438) ((T_POW) reduce 438) ((T_SL) reduce 438) ((T_SPACESHIP) reduce 438) ((T_SR) reduce 438) (("^") reduce 438) (("|") reduce 438)) 22956 ((("%") reduce 483) (("(") reduce 483) (("*") reduce 483) (("+") reduce 483) (("-") reduce 483) ((".") reduce 483) (("/") reduce 483) ((":") reduce 483) ((";") reduce 483) (("<") reduce 483) (("=") shift) ((">") reduce 483) (("?") reduce 483) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_BOOLEAN_AND) reduce 483) ((T_BOOLEAN_OR) reduce 483) ((T_COALESCE) reduce 483) ((T_DOUBLE_ARROW) reduce 483) ((T_INSTANCEOF) reduce 483) ((T_IS_EQUAL) reduce 483) ((T_IS_GREATER_OR_EQUAL) reduce 483) ((T_IS_IDENTICAL) reduce 483) ((T_IS_NOT_EQUAL) reduce 483) ((T_IS_NOT_IDENTICAL) reduce 483) ((T_IS_SMALLER_OR_EQUAL) reduce 483) ((T_LOGICAL_AND) reduce 483) ((T_LOGICAL_OR) reduce 483) ((T_LOGICAL_XOR) reduce 483) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 483) ((T_OBJECT_OPERATOR) reduce 483) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 483) ((T_POW) reduce 483) ((T_SL) reduce 483) ((T_SPACESHIP) reduce 483) ((T_SR) reduce 483) (("[") reduce 483) (("^") reduce 483) (("{") reduce 483) (("|") reduce 483)) 22958 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 369) ((";") reduce 369) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 369) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 369) ((T_LOGICAL_OR) reduce 369) ((T_LOGICAL_XOR) reduce 369) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22959 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 443) ((";") reduce 443) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 443) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 443) ((T_LOGICAL_OR) reduce 443) ((T_LOGICAL_XOR) reduce 443) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22962 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 442) ((";") reduce 442) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 442) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 442) ((T_LOGICAL_OR) reduce 442) ((T_LOGICAL_XOR) reduce 442) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22963 ((("%") reduce 434) (("*") reduce 434) (("+") reduce 434) (("-") reduce 434) ((".") reduce 434) (("/") reduce 434) ((":") reduce 434) ((";") reduce 434) (("<") reduce 434) ((">") reduce 434) (("?") reduce 434) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_BOOLEAN_AND) reduce 434) ((T_BOOLEAN_OR) reduce 434) ((T_COALESCE) reduce 434) ((T_DOUBLE_ARROW) reduce 434) ((T_INSTANCEOF) reduce 434) ((T_IS_EQUAL) reduce 434) ((T_IS_GREATER_OR_EQUAL) reduce 434) ((T_IS_IDENTICAL) reduce 434) ((T_IS_NOT_EQUAL) reduce 434) ((T_IS_NOT_IDENTICAL) reduce 434) ((T_IS_SMALLER_OR_EQUAL) reduce 434) ((T_LOGICAL_AND) reduce 434) ((T_LOGICAL_OR) reduce 434) ((T_LOGICAL_XOR) reduce 434) ((T_POW) shift) ((T_SL) reduce 434) ((T_SPACESHIP) reduce 434) ((T_SR) reduce 434) (("^") reduce 434) (("|") reduce 434)) 22964 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 444) ((";") reduce 444) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 444) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22965 ((("%") reduce 430) (("*") reduce 430) (("+") reduce 430) (("-") reduce 430) ((".") reduce 430) (("/") reduce 430) ((":") reduce 430) ((";") reduce 430) (("<") reduce 430) ((">") reduce 430) (("?") reduce 430) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_BOOLEAN_AND) reduce 430) ((T_BOOLEAN_OR) reduce 430) ((T_COALESCE) reduce 430) ((T_DOUBLE_ARROW) reduce 430) ((T_INSTANCEOF) reduce 430) ((T_IS_EQUAL) reduce 430) ((T_IS_GREATER_OR_EQUAL) reduce 430) ((T_IS_IDENTICAL) reduce 430) ((T_IS_NOT_EQUAL) reduce 430) ((T_IS_NOT_IDENTICAL) reduce 430) ((T_IS_SMALLER_OR_EQUAL) reduce 430) ((T_LOGICAL_AND) reduce 430) ((T_LOGICAL_OR) reduce 430) ((T_LOGICAL_XOR) reduce 430) ((T_POW) shift) ((T_SL) reduce 430) ((T_SPACESHIP) reduce 430) ((T_SR) reduce 430) (("^") reduce 430) (("|") reduce 430)) 22966 ((("%") reduce 447) (("*") reduce 447) (("+") reduce 447) (("-") reduce 447) ((".") reduce 447) (("/") reduce 447) ((":") reduce 447) ((";") reduce 447) (("<") reduce 447) ((">") reduce 447) (("?") reduce 447) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_BOOLEAN_AND) reduce 447) ((T_BOOLEAN_OR) reduce 447) ((T_COALESCE) reduce 447) ((T_DOUBLE_ARROW) reduce 447) ((T_INSTANCEOF) reduce 447) ((T_IS_EQUAL) reduce 447) ((T_IS_GREATER_OR_EQUAL) reduce 447) ((T_IS_IDENTICAL) reduce 447) ((T_IS_NOT_EQUAL) reduce 447) ((T_IS_NOT_IDENTICAL) reduce 447) ((T_IS_SMALLER_OR_EQUAL) reduce 447) ((T_LOGICAL_AND) reduce 447) ((T_LOGICAL_OR) reduce 447) ((T_LOGICAL_XOR) reduce 447) ((T_POW) reduce 447) ((T_SL) reduce 447) ((T_SPACESHIP) reduce 447) ((T_SR) reduce 447) (("^") reduce 447) (("|") reduce 447)) 22968 ((("%") reduce 489) (("*") reduce 489) (("+") reduce 489) (("-") reduce 489) ((".") reduce 489) (("/") reduce 489) ((":") reduce 489) ((";") reduce 489) (("<") reduce 489) ((">") reduce 489) (("?") reduce 489) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_BOOLEAN_AND) reduce 489) ((T_BOOLEAN_OR) reduce 489) ((T_COALESCE) reduce 489) ((T_DOUBLE_ARROW) reduce 489) ((T_INSTANCEOF) reduce 489) ((T_IS_EQUAL) reduce 489) ((T_IS_GREATER_OR_EQUAL) reduce 489) ((T_IS_IDENTICAL) reduce 489) ((T_IS_NOT_EQUAL) reduce 489) ((T_IS_NOT_IDENTICAL) reduce 489) ((T_IS_SMALLER_OR_EQUAL) reduce 489) ((T_LOGICAL_AND) reduce 489) ((T_LOGICAL_OR) reduce 489) ((T_LOGICAL_XOR) reduce 489) ((T_POW) reduce 489) ((T_SL) reduce 489) ((T_SPACESHIP) reduce 489) ((T_SR) reduce 489) (("^") reduce 489) (("|") reduce 489)) 22970 ((("%") reduce 490) (("*") reduce 490) (("+") reduce 490) (("-") reduce 490) ((".") reduce 490) (("/") reduce 490) ((":") reduce 490) ((";") reduce 490) (("<") reduce 490) ((">") reduce 490) (("?") reduce 490) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_BOOLEAN_AND) reduce 490) ((T_BOOLEAN_OR) reduce 490) ((T_COALESCE) reduce 490) ((T_DOUBLE_ARROW) reduce 490) ((T_INSTANCEOF) reduce 490) ((T_IS_EQUAL) reduce 490) ((T_IS_GREATER_OR_EQUAL) reduce 490) ((T_IS_IDENTICAL) reduce 490) ((T_IS_NOT_EQUAL) reduce 490) ((T_IS_NOT_IDENTICAL) reduce 490) ((T_IS_SMALLER_OR_EQUAL) reduce 490) ((T_LOGICAL_AND) reduce 490) ((T_LOGICAL_OR) reduce 490) ((T_LOGICAL_XOR) reduce 490) ((T_POW) reduce 490) ((T_SL) reduce 490) ((T_SPACESHIP) reduce 490) ((T_SR) reduce 490) (("^") reduce 490) (("|") reduce 490)) 22971 ((("%") reduce 488) (("*") reduce 488) (("+") reduce 488) (("-") reduce 488) ((".") reduce 488) (("/") reduce 488) ((":") reduce 488) ((";") reduce 488) (("<") reduce 488) ((">") reduce 488) (("?") reduce 488) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_BOOLEAN_AND) reduce 488) ((T_BOOLEAN_OR) reduce 488) ((T_COALESCE) reduce 488) ((T_DOUBLE_ARROW) reduce 488) ((T_INSTANCEOF) reduce 488) ((T_IS_EQUAL) reduce 488) ((T_IS_GREATER_OR_EQUAL) reduce 488) ((T_IS_IDENTICAL) reduce 488) ((T_IS_NOT_EQUAL) reduce 488) ((T_IS_NOT_IDENTICAL) reduce 488) ((T_IS_SMALLER_OR_EQUAL) reduce 488) ((T_LOGICAL_AND) reduce 488) ((T_LOGICAL_OR) reduce 488) ((T_LOGICAL_XOR) reduce 488) ((T_POW) reduce 488) ((T_SL) reduce 488) ((T_SPACESHIP) reduce 488) ((T_SR) reduce 488) (("^") reduce 488) (("|") reduce 488)) 22972 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 581) ((";") reduce 581) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 581) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22973 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 580) ((";") reduce 580) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 580) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22974 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) ((":") reduce 466) ((";") reduce 466) (("<") reduce 466) (("=") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AND_EQUAL) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_COALESCE_EQUAL) reduce 466) ((T_CONCAT_EQUAL) reduce 466) ((T_DEC) reduce 466) ((T_DIV_EQUAL) reduce 466) ((T_DOUBLE_ARROW) reduce 466) ((T_INC) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_MINUS_EQUAL) reduce 466) ((T_MOD_EQUAL) reduce 466) ((T_MUL_EQUAL) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_OR_EQUAL) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_PLUS_EQUAL) reduce 466) ((T_POW) reduce 466) ((T_POW_EQUAL) reduce 466) ((T_SL) reduce 466) ((T_SL_EQUAL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) ((T_SR_EQUAL) reduce 466) ((T_XOR_EQUAL) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 22975 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 439) ((";") reduce 439) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 439) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 439) ((T_LOGICAL_OR) reduce 439) ((T_LOGICAL_XOR) reduce 439) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 22976 ((("%") reduce 432) (("*") reduce 432) (("+") reduce 432) (("-") reduce 432) ((".") reduce 432) (("/") reduce 432) ((":") reduce 432) ((";") reduce 432) (("<") reduce 432) ((">") reduce 432) (("?") reduce 432) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_BOOLEAN_AND) reduce 432) ((T_BOOLEAN_OR) reduce 432) ((T_COALESCE) reduce 432) ((T_DOUBLE_ARROW) reduce 432) ((T_INSTANCEOF) reduce 432) ((T_IS_EQUAL) reduce 432) ((T_IS_GREATER_OR_EQUAL) reduce 432) ((T_IS_IDENTICAL) reduce 432) ((T_IS_NOT_EQUAL) reduce 432) ((T_IS_NOT_IDENTICAL) reduce 432) ((T_IS_SMALLER_OR_EQUAL) reduce 432) ((T_LOGICAL_AND) reduce 432) ((T_LOGICAL_OR) reduce 432) ((T_LOGICAL_XOR) reduce 432) ((T_POW) shift) ((T_SL) reduce 432) ((T_SPACESHIP) reduce 432) ((T_SR) reduce 432) (("^") reduce 432) (("|") reduce 432)) 22978 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) ((":") reduce 93) ((";") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93)) 22979 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) ((":") reduce 92) ((";") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92)) 22980 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) ((":") reduce 94) ((";") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94)) 22981 ((("%") reduce 470) (("(") reduce 470) (("*") reduce 470) (("+") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) ((":") reduce 470) ((";") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_DOUBLE_ARROW) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470)) 22982 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) ((":") reduce 91) ((";") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91)) 22983 ((("%") reduce 365) (("*") reduce 365) (("+") reduce 365) (("-") reduce 365) ((".") reduce 365) (("/") reduce 365) ((":") reduce 365) ((";") reduce 365) (("<") reduce 365) ((">") reduce 365) (("?") reduce 365) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_BOOLEAN_AND) reduce 365) ((T_BOOLEAN_OR) reduce 365) ((T_COALESCE) reduce 365) ((T_DOUBLE_ARROW) reduce 365) ((T_INSTANCEOF) reduce 365) ((T_IS_EQUAL) reduce 365) ((T_IS_GREATER_OR_EQUAL) reduce 365) ((T_IS_IDENTICAL) reduce 365) ((T_IS_NOT_EQUAL) reduce 365) ((T_IS_NOT_IDENTICAL) reduce 365) ((T_IS_SMALLER_OR_EQUAL) reduce 365) ((T_LOGICAL_AND) reduce 365) ((T_LOGICAL_OR) reduce 365) ((T_LOGICAL_XOR) reduce 365) ((T_POW) reduce 365) ((T_SL) reduce 365) ((T_SPACESHIP) reduce 365) ((T_SR) reduce 365) (("^") reduce 365) (("|") reduce 365)) 22986 ((("%") reduce 472) (("(") reduce 472) (("*") reduce 472) (("+") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) ((":") reduce 472) ((";") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_DOUBLE_ARROW) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472)) 22987 ((("%") reduce 480) (("(") shift) (("*") reduce 480) (("+") reduce 480) (("-") reduce 480) ((".") reduce 480) (("/") reduce 480) ((":") reduce 480) ((";") reduce 480) (("<") reduce 480) ((">") reduce 480) (("?") reduce 480) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_BOOLEAN_AND) reduce 480) ((T_BOOLEAN_OR) reduce 480) ((T_COALESCE) reduce 480) ((T_DOUBLE_ARROW) reduce 480) ((T_INSTANCEOF) reduce 480) ((T_IS_EQUAL) reduce 480) ((T_IS_GREATER_OR_EQUAL) reduce 480) ((T_IS_IDENTICAL) reduce 480) ((T_IS_NOT_EQUAL) reduce 480) ((T_IS_NOT_IDENTICAL) reduce 480) ((T_IS_SMALLER_OR_EQUAL) reduce 480) ((T_LOGICAL_AND) reduce 480) ((T_LOGICAL_OR) reduce 480) ((T_LOGICAL_XOR) reduce 480) ((T_POW) reduce 480) ((T_SL) reduce 480) ((T_SPACESHIP) reduce 480) ((T_SR) reduce 480) (("^") reduce 480) (("|") reduce 480)) 22988 ((("%") reduce 471) (("(") reduce 471) (("*") reduce 471) (("+") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) ((":") reduce 471) ((";") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_DOUBLE_ARROW) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471)) 22989 ((("%") reduce 473) (("(") reduce 473) (("*") reduce 473) (("+") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) ((":") reduce 473) ((";") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_DOUBLE_ARROW) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 22990 ((("%") reduce 534) (("(") reduce 534) (("*") reduce 534) (("+") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) ((":") reduce 534) ((";") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_DOUBLE_ARROW) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 22997 ((("%") reduce 536) (("(") reduce 536) (("*") reduce 536) (("+") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) ((":") reduce 536) ((";") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_DOUBLE_ARROW) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 22999 ((("%") reduce 535) (("(") reduce 535) (("*") reduce 535) (("+") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) ((":") reduce 535) ((";") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_DOUBLE_ARROW) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 23000 ((("%") reduce 540) (("(") reduce 540) (("*") reduce 540) (("+") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) ((":") reduce 540) ((";") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_DOUBLE_ARROW) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 23001 ((("%") reduce 537) (("(") reduce 537) (("*") reduce 537) (("+") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) ((":") reduce 537) ((";") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_DOUBLE_ARROW) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 23002 ((("%") reduce 538) (("(") reduce 538) (("*") reduce 538) (("+") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) ((":") reduce 538) ((";") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_DOUBLE_ARROW) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 23004 ((("%") reduce 481) (("*") reduce 481) (("+") reduce 481) (("-") reduce 481) ((".") reduce 481) (("/") reduce 481) ((":") reduce 481) ((";") reduce 481) (("<") reduce 481) ((">") reduce 481) (("?") reduce 481) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_BOOLEAN_AND) reduce 481) ((T_BOOLEAN_OR) reduce 481) ((T_COALESCE) reduce 481) ((T_DOUBLE_ARROW) reduce 481) ((T_INSTANCEOF) reduce 481) ((T_IS_EQUAL) reduce 481) ((T_IS_GREATER_OR_EQUAL) reduce 481) ((T_IS_IDENTICAL) reduce 481) ((T_IS_NOT_EQUAL) reduce 481) ((T_IS_NOT_IDENTICAL) reduce 481) ((T_IS_SMALLER_OR_EQUAL) reduce 481) ((T_LOGICAL_AND) reduce 481) ((T_LOGICAL_OR) reduce 481) ((T_LOGICAL_XOR) reduce 481) ((T_POW) reduce 481) ((T_SL) reduce 481) ((T_SPACESHIP) reduce 481) ((T_SR) reduce 481) (("^") reduce 481) (("|") reduce 481)) 23005 ((("%") reduce 364) (("*") reduce 364) (("+") reduce 364) (("-") reduce 364) ((".") reduce 364) (("/") reduce 364) ((":") reduce 364) ((";") reduce 364) (("<") reduce 364) ((">") reduce 364) (("?") reduce 364) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_BOOLEAN_AND) reduce 364) ((T_BOOLEAN_OR) reduce 364) ((T_COALESCE) reduce 364) ((T_DOUBLE_ARROW) reduce 364) ((T_INSTANCEOF) reduce 364) ((T_IS_EQUAL) reduce 364) ((T_IS_GREATER_OR_EQUAL) reduce 364) ((T_IS_IDENTICAL) reduce 364) ((T_IS_NOT_EQUAL) reduce 364) ((T_IS_NOT_IDENTICAL) reduce 364) ((T_IS_SMALLER_OR_EQUAL) reduce 364) ((T_LOGICAL_AND) reduce 364) ((T_LOGICAL_OR) reduce 364) ((T_LOGICAL_XOR) reduce 364) ((T_POW) reduce 364) ((T_SL) reduce 364) ((T_SPACESHIP) reduce 364) ((T_SR) reduce 364) (("^") reduce 364) (("|") reduce 364)) 23006 ((("%") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) ((":") reduce 288) ((";") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("^") reduce 288) (("|") reduce 288)) 23010 ((("%") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) ((":") reduce 289) ((";") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("^") reduce 289) (("|") reduce 289)) 23011 ((("%") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) ((":") reduce 290) ((";") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("^") reduce 290) (("|") reduce 290)) 23013 ((("%") reduce 539) (("(") reduce 539) (("*") reduce 539) (("+") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) ((":") reduce 539) ((";") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_DOUBLE_ARROW) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 23014 ((("%") reduce 366) (("*") reduce 366) (("+") reduce 366) (("-") reduce 366) ((".") reduce 366) (("/") reduce 366) ((":") reduce 366) ((";") reduce 366) (("<") reduce 366) ((">") reduce 366) (("?") reduce 366) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_BOOLEAN_AND) reduce 366) ((T_BOOLEAN_OR) reduce 366) ((T_COALESCE) reduce 366) ((T_DOUBLE_ARROW) reduce 366) ((T_INSTANCEOF) reduce 366) ((T_IS_EQUAL) reduce 366) ((T_IS_GREATER_OR_EQUAL) reduce 366) ((T_IS_IDENTICAL) reduce 366) ((T_IS_NOT_EQUAL) reduce 366) ((T_IS_NOT_IDENTICAL) reduce 366) ((T_IS_SMALLER_OR_EQUAL) reduce 366) ((T_LOGICAL_AND) reduce 366) ((T_LOGICAL_OR) reduce 366) ((T_LOGICAL_XOR) reduce 366) ((T_POW) reduce 366) ((T_SL) reduce 366) ((T_SPACESHIP) reduce 366) ((T_SR) reduce 366) (("^") reduce 366) (("|") reduce 366)) 23022 ((("%") reduce 363) (("*") reduce 363) (("+") reduce 363) (("-") reduce 363) ((".") reduce 363) (("/") reduce 363) ((":") reduce 363) ((";") reduce 363) (("<") reduce 363) ((">") reduce 363) (("?") reduce 363) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_BOOLEAN_AND) reduce 363) ((T_BOOLEAN_OR) reduce 363) ((T_COALESCE) reduce 363) ((T_DOUBLE_ARROW) reduce 363) ((T_INSTANCEOF) reduce 363) ((T_IS_EQUAL) reduce 363) ((T_IS_GREATER_OR_EQUAL) reduce 363) ((T_IS_IDENTICAL) reduce 363) ((T_IS_NOT_EQUAL) reduce 363) ((T_IS_NOT_IDENTICAL) reduce 363) ((T_IS_SMALLER_OR_EQUAL) reduce 363) ((T_LOGICAL_AND) reduce 363) ((T_LOGICAL_OR) reduce 363) ((T_LOGICAL_XOR) reduce 363) ((T_POW) reduce 363) ((T_SL) reduce 363) ((T_SPACESHIP) reduce 363) ((T_SR) reduce 363) (("^") reduce 363) (("|") reduce 363)) 23024 ((("%") reduce 474) (("(") reduce 474) (("*") reduce 474) (("+") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) ((":") reduce 474) ((";") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_DOUBLE_ARROW) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474)) 23030 ((("%") reduce 230) (("*") reduce 230) (("+") reduce 230) (("-") reduce 230) ((".") reduce 230) (("/") reduce 230) ((":") reduce 230) ((";") reduce 230) (("<") reduce 230) ((">") reduce 230) (("?") reduce 230) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_BOOLEAN_AND) reduce 230) ((T_BOOLEAN_OR) reduce 230) ((T_COALESCE) reduce 230) ((T_DOUBLE_ARROW) reduce 230) ((T_INSTANCEOF) reduce 230) ((T_IS_EQUAL) reduce 230) ((T_IS_GREATER_OR_EQUAL) reduce 230) ((T_IS_IDENTICAL) reduce 230) ((T_IS_NOT_EQUAL) reduce 230) ((T_IS_NOT_IDENTICAL) reduce 230) ((T_IS_SMALLER_OR_EQUAL) reduce 230) ((T_LOGICAL_AND) reduce 230) ((T_LOGICAL_OR) reduce 230) ((T_LOGICAL_XOR) reduce 230) ((T_POW) reduce 230) ((T_SL) reduce 230) ((T_SPACESHIP) reduce 230) ((T_SR) reduce 230) (("^") reduce 230) (("|") reduce 230)) 23035 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 368) ((";") reduce 368) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 368) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 368) ((T_LOGICAL_OR) reduce 368) ((T_LOGICAL_XOR) reduce 368) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 23039 ((("%") reduce 575) (("*") reduce 575) (("+") reduce 575) (("-") reduce 575) ((".") reduce 575) (("/") reduce 575) ((":") reduce 575) ((";") reduce 575) (("<") reduce 575) ((">") reduce 575) (("?") reduce 575) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_BOOLEAN_AND) reduce 575) ((T_BOOLEAN_OR) reduce 575) ((T_COALESCE) reduce 575) ((T_DOUBLE_ARROW) reduce 575) ((T_INSTANCEOF) reduce 575) ((T_IS_EQUAL) reduce 575) ((T_IS_GREATER_OR_EQUAL) reduce 575) ((T_IS_IDENTICAL) reduce 575) ((T_IS_NOT_EQUAL) reduce 575) ((T_IS_NOT_IDENTICAL) reduce 575) ((T_IS_SMALLER_OR_EQUAL) reduce 575) ((T_LOGICAL_AND) reduce 575) ((T_LOGICAL_OR) reduce 575) ((T_LOGICAL_XOR) reduce 575) ((T_POW) reduce 575) ((T_SL) reduce 575) ((T_SPACESHIP) reduce 575) ((T_SR) reduce 575) (("^") reduce 575) (("|") reduce 575)) 23040 ((("%") reduce 428) (("*") reduce 428) (("+") reduce 428) (("-") reduce 428) ((".") reduce 428) (("/") reduce 428) ((":") reduce 428) ((";") reduce 428) (("<") reduce 428) ((">") reduce 428) (("?") reduce 428) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_BOOLEAN_AND) reduce 428) ((T_BOOLEAN_OR) reduce 428) ((T_COALESCE) reduce 428) ((T_DOUBLE_ARROW) reduce 428) ((T_INSTANCEOF) reduce 428) ((T_IS_EQUAL) reduce 428) ((T_IS_GREATER_OR_EQUAL) reduce 428) ((T_IS_IDENTICAL) reduce 428) ((T_IS_NOT_EQUAL) reduce 428) ((T_IS_NOT_IDENTICAL) reduce 428) ((T_IS_SMALLER_OR_EQUAL) reduce 428) ((T_LOGICAL_AND) reduce 428) ((T_LOGICAL_OR) reduce 428) ((T_LOGICAL_XOR) reduce 428) ((T_POW) shift) ((T_SL) reduce 428) ((T_SPACESHIP) reduce 428) ((T_SR) reduce 428) (("^") reduce 428) (("|") reduce 428)) 23041 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 578) ((";") reduce 578) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 578) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 23042 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 577) ((";") reduce 577) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 577) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 23043 ((("%") reduce 387) (("*") reduce 387) (("+") reduce 387) (("-") reduce 387) ((".") reduce 387) (("/") reduce 387) ((":") reduce 387) ((";") reduce 387) (("<") reduce 387) ((">") reduce 387) (("?") reduce 387) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_BOOLEAN_AND) reduce 387) ((T_BOOLEAN_OR) reduce 387) ((T_COALESCE) reduce 387) ((T_DOUBLE_ARROW) reduce 387) ((T_INSTANCEOF) reduce 387) ((T_IS_EQUAL) reduce 387) ((T_IS_GREATER_OR_EQUAL) reduce 387) ((T_IS_IDENTICAL) reduce 387) ((T_IS_NOT_EQUAL) reduce 387) ((T_IS_NOT_IDENTICAL) reduce 387) ((T_IS_SMALLER_OR_EQUAL) reduce 387) ((T_LOGICAL_AND) reduce 387) ((T_LOGICAL_OR) reduce 387) ((T_LOGICAL_XOR) reduce 387) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 387) ((T_SL) reduce 387) ((T_SPACESHIP) reduce 387) ((T_SR) reduce 387) (("[") reduce 510) (("^") reduce 387) (("{") reduce 510) (("|") reduce 387)) 23045 ((("%") reduce 435) (("*") reduce 435) (("+") reduce 435) (("-") reduce 435) ((".") reduce 435) (("/") reduce 435) ((":") reduce 435) ((";") reduce 435) (("<") reduce 435) ((">") reduce 435) (("?") reduce 435) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_BOOLEAN_AND) reduce 435) ((T_BOOLEAN_OR) reduce 435) ((T_COALESCE) reduce 435) ((T_DOUBLE_ARROW) reduce 435) ((T_INSTANCEOF) reduce 435) ((T_IS_EQUAL) reduce 435) ((T_IS_GREATER_OR_EQUAL) reduce 435) ((T_IS_IDENTICAL) reduce 435) ((T_IS_NOT_EQUAL) reduce 435) ((T_IS_NOT_IDENTICAL) reduce 435) ((T_IS_SMALLER_OR_EQUAL) reduce 435) ((T_LOGICAL_AND) reduce 435) ((T_LOGICAL_OR) reduce 435) ((T_LOGICAL_XOR) reduce 435) ((T_POW) reduce 435) ((T_SL) reduce 435) ((T_SPACESHIP) reduce 435) ((T_SR) reduce 435) (("^") reduce 435) (("|") reduce 435)) 23047 ((("%") reduce 476) (("*") reduce 476) (("+") reduce 476) (("-") reduce 476) ((".") reduce 476) (("/") reduce 476) ((":") reduce 476) ((";") reduce 476) (("<") reduce 476) ((">") reduce 476) (("?") reduce 476) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_BOOLEAN_AND) reduce 476) ((T_BOOLEAN_OR) reduce 476) ((T_COALESCE) reduce 476) ((T_DOUBLE_ARROW) reduce 476) ((T_INSTANCEOF) reduce 476) ((T_IS_EQUAL) reduce 476) ((T_IS_GREATER_OR_EQUAL) reduce 476) ((T_IS_IDENTICAL) reduce 476) ((T_IS_NOT_EQUAL) reduce 476) ((T_IS_NOT_IDENTICAL) reduce 476) ((T_IS_SMALLER_OR_EQUAL) reduce 476) ((T_LOGICAL_AND) reduce 476) ((T_LOGICAL_OR) reduce 476) ((T_LOGICAL_XOR) reduce 476) ((T_POW) reduce 476) ((T_SL) reduce 476) ((T_SPACESHIP) reduce 476) ((T_SR) reduce 476) (("^") reduce 476) (("|") reduce 476)) 23050 ((("%") reduce 579) (("*") reduce 579) (("+") reduce 579) (("-") reduce 579) ((".") reduce 579) (("/") reduce 579) ((":") reduce 579) ((";") reduce 579) (("<") reduce 579) ((">") reduce 579) (("?") reduce 579) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_BOOLEAN_AND) reduce 579) ((T_BOOLEAN_OR) reduce 579) ((T_COALESCE) reduce 579) ((T_DOUBLE_ARROW) reduce 579) ((T_INSTANCEOF) reduce 579) ((T_IS_EQUAL) reduce 579) ((T_IS_GREATER_OR_EQUAL) reduce 579) ((T_IS_IDENTICAL) reduce 579) ((T_IS_NOT_EQUAL) reduce 579) ((T_IS_NOT_IDENTICAL) reduce 579) ((T_IS_SMALLER_OR_EQUAL) reduce 579) ((T_LOGICAL_AND) reduce 579) ((T_LOGICAL_OR) reduce 579) ((T_LOGICAL_XOR) reduce 579) ((T_POW) reduce 579) ((T_SL) reduce 579) ((T_SPACESHIP) reduce 579) ((T_SR) reduce 579) (("^") reduce 579) (("|") reduce 579)) 23053 ((("%") reduce 576) (("*") reduce 576) (("+") reduce 576) (("-") reduce 576) ((".") reduce 576) (("/") reduce 576) ((":") reduce 576) ((";") reduce 576) (("<") reduce 576) ((">") reduce 576) (("?") reduce 576) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_BOOLEAN_AND) reduce 576) ((T_BOOLEAN_OR) reduce 576) ((T_COALESCE) reduce 576) ((T_DOUBLE_ARROW) reduce 576) ((T_INSTANCEOF) reduce 576) ((T_IS_EQUAL) reduce 576) ((T_IS_GREATER_OR_EQUAL) reduce 576) ((T_IS_IDENTICAL) reduce 576) ((T_IS_NOT_EQUAL) reduce 576) ((T_IS_NOT_IDENTICAL) reduce 576) ((T_IS_SMALLER_OR_EQUAL) reduce 576) ((T_LOGICAL_AND) reduce 576) ((T_LOGICAL_OR) reduce 576) ((T_LOGICAL_XOR) reduce 576) ((T_POW) reduce 576) ((T_SL) reduce 576) ((T_SPACESHIP) reduce 576) ((T_SR) reduce 576) (("^") reduce 576) (("|") reduce 576)) 23054 ((("%") reduce 429) (("*") reduce 429) (("+") reduce 429) (("-") reduce 429) ((".") reduce 429) (("/") reduce 429) ((":") reduce 429) ((";") reduce 429) (("<") reduce 429) ((">") reduce 429) (("?") reduce 429) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_BOOLEAN_AND) reduce 429) ((T_BOOLEAN_OR) reduce 429) ((T_COALESCE) reduce 429) ((T_DOUBLE_ARROW) reduce 429) ((T_INSTANCEOF) reduce 429) ((T_IS_EQUAL) reduce 429) ((T_IS_GREATER_OR_EQUAL) reduce 429) ((T_IS_IDENTICAL) reduce 429) ((T_IS_NOT_EQUAL) reduce 429) ((T_IS_NOT_IDENTICAL) reduce 429) ((T_IS_SMALLER_OR_EQUAL) reduce 429) ((T_LOGICAL_AND) reduce 429) ((T_LOGICAL_OR) reduce 429) ((T_LOGICAL_XOR) reduce 429) ((T_POW) shift) ((T_SL) reduce 429) ((T_SPACESHIP) reduce 429) ((T_SR) reduce 429) (("^") reduce 429) (("|") reduce 429)) 23055 ((("%") reduce 389) (("*") reduce 389) (("+") reduce 389) (("-") reduce 389) ((".") reduce 389) (("/") reduce 389) ((":") reduce 389) ((";") reduce 389) (("<") reduce 389) ((">") reduce 389) (("?") reduce 389) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_BOOLEAN_AND) reduce 389) ((T_BOOLEAN_OR) reduce 389) ((T_COALESCE) reduce 389) ((T_DOUBLE_ARROW) reduce 389) ((T_INSTANCEOF) reduce 389) ((T_IS_EQUAL) reduce 389) ((T_IS_GREATER_OR_EQUAL) reduce 389) ((T_IS_IDENTICAL) reduce 389) ((T_IS_NOT_EQUAL) reduce 389) ((T_IS_NOT_IDENTICAL) reduce 389) ((T_IS_SMALLER_OR_EQUAL) reduce 389) ((T_LOGICAL_AND) reduce 389) ((T_LOGICAL_OR) reduce 389) ((T_LOGICAL_XOR) reduce 389) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 389) ((T_SL) reduce 389) ((T_SPACESHIP) reduce 389) ((T_SR) reduce 389) (("[") reduce 510) (("^") reduce 389) (("{") reduce 510) (("|") reduce 389)) 23056 ((("%") reduce 372) (("*") reduce 372) (("+") reduce 372) (("-") reduce 372) ((".") reduce 372) (("/") reduce 372) ((":") reduce 372) ((";") reduce 372) (("<") reduce 372) ((">") reduce 372) (("?") reduce 372) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_BOOLEAN_AND) reduce 372) ((T_BOOLEAN_OR) reduce 372) ((T_COALESCE) reduce 372) ((T_DOUBLE_ARROW) reduce 372) ((T_INSTANCEOF) reduce 372) ((T_IS_EQUAL) reduce 372) ((T_IS_GREATER_OR_EQUAL) reduce 372) ((T_IS_IDENTICAL) reduce 372) ((T_IS_NOT_EQUAL) reduce 372) ((T_IS_NOT_IDENTICAL) reduce 372) ((T_IS_SMALLER_OR_EQUAL) reduce 372) ((T_LOGICAL_AND) reduce 372) ((T_LOGICAL_OR) reduce 372) ((T_LOGICAL_XOR) reduce 372) ((T_POW) reduce 372) ((T_SL) reduce 372) ((T_SPACESHIP) reduce 372) ((T_SR) reduce 372) (("^") reduce 372) (("|") reduce 372)) 23057 ((("%") reduce 433) (("*") reduce 433) (("+") reduce 433) (("-") reduce 433) ((".") reduce 433) (("/") reduce 433) ((":") reduce 433) ((";") reduce 433) (("<") reduce 433) ((">") reduce 433) (("?") reduce 433) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_BOOLEAN_AND) reduce 433) ((T_BOOLEAN_OR) reduce 433) ((T_COALESCE) reduce 433) ((T_DOUBLE_ARROW) reduce 433) ((T_INSTANCEOF) reduce 433) ((T_IS_EQUAL) reduce 433) ((T_IS_GREATER_OR_EQUAL) reduce 433) ((T_IS_IDENTICAL) reduce 433) ((T_IS_NOT_EQUAL) reduce 433) ((T_IS_NOT_IDENTICAL) reduce 433) ((T_IS_SMALLER_OR_EQUAL) reduce 433) ((T_LOGICAL_AND) reduce 433) ((T_LOGICAL_OR) reduce 433) ((T_LOGICAL_XOR) reduce 433) ((T_POW) shift) ((T_SL) reduce 433) ((T_SPACESHIP) reduce 433) ((T_SR) reduce 433) (("^") reduce 433) (("|") reduce 433)) 23058 ((("%") reduce 431) (("*") reduce 431) (("+") reduce 431) (("-") reduce 431) ((".") reduce 431) (("/") reduce 431) ((":") reduce 431) ((";") reduce 431) (("<") reduce 431) ((">") reduce 431) (("?") reduce 431) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_BOOLEAN_AND) reduce 431) ((T_BOOLEAN_OR) reduce 431) ((T_COALESCE) reduce 431) ((T_DOUBLE_ARROW) reduce 431) ((T_INSTANCEOF) reduce 431) ((T_IS_EQUAL) reduce 431) ((T_IS_GREATER_OR_EQUAL) reduce 431) ((T_IS_IDENTICAL) reduce 431) ((T_IS_NOT_EQUAL) reduce 431) ((T_IS_NOT_IDENTICAL) reduce 431) ((T_IS_SMALLER_OR_EQUAL) reduce 431) ((T_LOGICAL_AND) reduce 431) ((T_LOGICAL_OR) reduce 431) ((T_LOGICAL_XOR) reduce 431) ((T_POW) shift) ((T_SL) reduce 431) ((T_SPACESHIP) reduce 431) ((T_SR) reduce 431) (("^") reduce 431) (("|") reduce 431)) 23061 ((("%") reduce 482) (("(") reduce 482) (("*") reduce 482) (("+") reduce 482) (("-") reduce 482) ((".") reduce 482) (("/") reduce 482) ((":") reduce 482) ((";") reduce 482) (("<") reduce 482) ((">") reduce 482) (("?") reduce 482) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_BOOLEAN_AND) reduce 482) ((T_BOOLEAN_OR) reduce 482) ((T_COALESCE) reduce 482) ((T_DOUBLE_ARROW) reduce 482) ((T_INSTANCEOF) reduce 482) ((T_IS_EQUAL) reduce 482) ((T_IS_GREATER_OR_EQUAL) reduce 482) ((T_IS_IDENTICAL) reduce 482) ((T_IS_NOT_EQUAL) reduce 482) ((T_IS_NOT_IDENTICAL) reduce 482) ((T_IS_SMALLER_OR_EQUAL) reduce 482) ((T_LOGICAL_AND) reduce 482) ((T_LOGICAL_OR) reduce 482) ((T_LOGICAL_XOR) reduce 482) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 482) ((T_OBJECT_OPERATOR) reduce 482) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 482) ((T_POW) reduce 482) ((T_SL) reduce 482) ((T_SPACESHIP) reduce 482) ((T_SR) reduce 482) (("[") reduce 482) (("^") reduce 482) (("{") reduce 482) (("|") reduce 482)) 23062 ((("%") reduce 436) (("*") reduce 436) (("+") reduce 436) (("-") reduce 436) ((".") reduce 436) (("/") reduce 436) ((":") reduce 436) ((";") reduce 436) (("<") reduce 436) ((">") reduce 436) (("?") reduce 436) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_BOOLEAN_AND) reduce 436) ((T_BOOLEAN_OR) reduce 436) ((T_COALESCE) reduce 436) ((T_DOUBLE_ARROW) reduce 436) ((T_INSTANCEOF) reduce 436) ((T_IS_EQUAL) reduce 436) ((T_IS_GREATER_OR_EQUAL) reduce 436) ((T_IS_IDENTICAL) reduce 436) ((T_IS_NOT_EQUAL) reduce 436) ((T_IS_NOT_IDENTICAL) reduce 436) ((T_IS_SMALLER_OR_EQUAL) reduce 436) ((T_LOGICAL_AND) reduce 436) ((T_LOGICAL_OR) reduce 436) ((T_LOGICAL_XOR) reduce 436) ((T_POW) shift) ((T_SL) reduce 436) ((T_SPACESHIP) reduce 436) ((T_SR) reduce 436) (("^") reduce 436) (("|") reduce 436)) 23063 ((("%") reduce 409) (("*") reduce 409) (("+") reduce 409) (("-") reduce 409) ((".") reduce 409) (("/") reduce 409) ((":") reduce 409) ((";") reduce 409) (("<") reduce 409) ((">") reduce 409) (("?") reduce 409) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_BOOLEAN_AND) reduce 409) ((T_BOOLEAN_OR) reduce 409) ((T_COALESCE) reduce 409) ((T_DOUBLE_ARROW) reduce 409) ((T_INSTANCEOF) reduce 409) ((T_IS_EQUAL) reduce 409) ((T_IS_GREATER_OR_EQUAL) reduce 409) ((T_IS_IDENTICAL) reduce 409) ((T_IS_NOT_EQUAL) reduce 409) ((T_IS_NOT_IDENTICAL) reduce 409) ((T_IS_SMALLER_OR_EQUAL) reduce 409) ((T_LOGICAL_AND) reduce 409) ((T_LOGICAL_OR) reduce 409) ((T_LOGICAL_XOR) reduce 409) ((T_POW) shift) ((T_SL) reduce 409) ((T_SPACESHIP) reduce 409) ((T_SR) reduce 409) (("^") reduce 409) (("|") reduce 409)) 23064 ((("%") reduce 408) (("*") reduce 408) (("+") reduce 408) (("-") reduce 408) ((".") reduce 408) (("/") reduce 408) ((":") reduce 408) ((";") reduce 408) (("<") reduce 408) ((">") reduce 408) (("?") reduce 408) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_BOOLEAN_AND) reduce 408) ((T_BOOLEAN_OR) reduce 408) ((T_COALESCE) reduce 408) ((T_DOUBLE_ARROW) reduce 408) ((T_INSTANCEOF) reduce 408) ((T_IS_EQUAL) reduce 408) ((T_IS_GREATER_OR_EQUAL) reduce 408) ((T_IS_IDENTICAL) reduce 408) ((T_IS_NOT_EQUAL) reduce 408) ((T_IS_NOT_IDENTICAL) reduce 408) ((T_IS_SMALLER_OR_EQUAL) reduce 408) ((T_LOGICAL_AND) reduce 408) ((T_LOGICAL_OR) reduce 408) ((T_LOGICAL_XOR) reduce 408) ((T_POW) shift) ((T_SL) reduce 408) ((T_SPACESHIP) reduce 408) ((T_SR) reduce 408) (("^") reduce 408) (("|") reduce 408)) 23066 ((("%") reduce 422) (("(") reduce 517) (("*") reduce 422) (("+") reduce 422) (("-") reduce 422) ((".") reduce 422) (("/") reduce 422) ((":") reduce 422) ((";") reduce 422) (("<") reduce 422) ((">") reduce 422) (("?") reduce 422) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_BOOLEAN_AND) reduce 422) ((T_BOOLEAN_OR) reduce 422) ((T_COALESCE) reduce 422) ((T_DOUBLE_ARROW) reduce 422) ((T_INSTANCEOF) reduce 422) ((T_IS_EQUAL) reduce 422) ((T_IS_GREATER_OR_EQUAL) reduce 422) ((T_IS_IDENTICAL) reduce 422) ((T_IS_NOT_EQUAL) reduce 422) ((T_IS_NOT_IDENTICAL) reduce 422) ((T_IS_SMALLER_OR_EQUAL) reduce 422) ((T_LOGICAL_AND) reduce 422) ((T_LOGICAL_OR) reduce 422) ((T_LOGICAL_XOR) reduce 422) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 511) ((T_OBJECT_OPERATOR) reduce 511) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 511) ((T_POW) reduce 422) ((T_SL) reduce 422) ((T_SPACESHIP) reduce 422) ((T_SR) reduce 422) (("[") reduce 511) (("^") reduce 422) (("{") reduce 511) (("|") reduce 422)) 23067 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) ((":") reduce 531) ((";") reduce 531) (("<") reduce 531) (("=") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AND_EQUAL) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_COALESCE_EQUAL) reduce 531) ((T_CONCAT_EQUAL) reduce 531) ((T_DEC) reduce 531) ((T_DIV_EQUAL) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INC) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_MINUS_EQUAL) reduce 531) ((T_MOD_EQUAL) reduce 531) ((T_MUL_EQUAL) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_OR_EQUAL) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_PLUS_EQUAL) reduce 531) ((T_POW) reduce 531) ((T_POW_EQUAL) reduce 531) ((T_SL) reduce 531) ((T_SL_EQUAL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) ((T_SR_EQUAL) reduce 531) ((T_XOR_EQUAL) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 23070 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) ((":") reduce 530) ((";") reduce 530) (("<") reduce 530) (("=") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AND_EQUAL) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_COALESCE_EQUAL) reduce 530) ((T_CONCAT_EQUAL) reduce 530) ((T_DEC) reduce 530) ((T_DIV_EQUAL) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INC) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_MINUS_EQUAL) reduce 530) ((T_MOD_EQUAL) reduce 530) ((T_MUL_EQUAL) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_OR_EQUAL) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_PLUS_EQUAL) reduce 530) ((T_POW) reduce 530) ((T_POW_EQUAL) reduce 530) ((T_SL) reduce 530) ((T_SL_EQUAL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) ((T_SR_EQUAL) reduce 530) ((T_XOR_EQUAL) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 23072 ((("%") reduce 485) (("(") reduce 485) (("*") reduce 485) (("+") reduce 485) (("-") reduce 485) ((".") reduce 485) (("/") reduce 485) ((":") reduce 485) ((";") reduce 485) (("<") reduce 485) ((">") reduce 485) (("?") reduce 485) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_BOOLEAN_AND) reduce 485) ((T_BOOLEAN_OR) reduce 485) ((T_COALESCE) reduce 485) ((T_DOUBLE_ARROW) reduce 485) ((T_INSTANCEOF) reduce 485) ((T_IS_EQUAL) reduce 485) ((T_IS_GREATER_OR_EQUAL) reduce 485) ((T_IS_IDENTICAL) reduce 485) ((T_IS_NOT_EQUAL) reduce 485) ((T_IS_NOT_IDENTICAL) reduce 485) ((T_IS_SMALLER_OR_EQUAL) reduce 485) ((T_LOGICAL_AND) reduce 485) ((T_LOGICAL_OR) reduce 485) ((T_LOGICAL_XOR) reduce 485) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 485) ((T_OBJECT_OPERATOR) reduce 485) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 485) ((T_POW) reduce 485) ((T_SL) reduce 485) ((T_SPACESHIP) reduce 485) ((T_SR) reduce 485) (("[") reduce 485) (("^") reduce 485) (("{") reduce 485) (("|") reduce 485)) 23073 ((("%") reduce 410) (("*") reduce 410) (("+") reduce 410) (("-") reduce 410) ((".") reduce 410) (("/") reduce 410) ((":") reduce 410) ((";") reduce 410) (("<") reduce 410) ((">") reduce 410) (("?") reduce 410) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_BOOLEAN_AND) reduce 410) ((T_BOOLEAN_OR) reduce 410) ((T_COALESCE) reduce 410) ((T_DOUBLE_ARROW) reduce 410) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 410) ((T_IS_GREATER_OR_EQUAL) reduce 410) ((T_IS_IDENTICAL) reduce 410) ((T_IS_NOT_EQUAL) reduce 410) ((T_IS_NOT_IDENTICAL) reduce 410) ((T_IS_SMALLER_OR_EQUAL) reduce 410) ((T_LOGICAL_AND) reduce 410) ((T_LOGICAL_OR) reduce 410) ((T_LOGICAL_XOR) reduce 410) ((T_POW) shift) ((T_SL) reduce 410) ((T_SPACESHIP) reduce 410) ((T_SR) reduce 410) (("^") reduce 410) (("|") reduce 410)) 23074 ((("%") reduce 434) (("*") reduce 434) (("+") reduce 434) (("-") reduce 434) ((".") reduce 434) (("/") reduce 434) ((":") reduce 434) ((";") reduce 434) (("<") reduce 434) ((">") reduce 434) (("?") reduce 434) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_BOOLEAN_AND) reduce 434) ((T_BOOLEAN_OR) reduce 434) ((T_COALESCE) reduce 434) ((T_INSTANCEOF) reduce 434) ((T_IS_EQUAL) reduce 434) ((T_IS_GREATER_OR_EQUAL) reduce 434) ((T_IS_IDENTICAL) reduce 434) ((T_IS_NOT_EQUAL) reduce 434) ((T_IS_NOT_IDENTICAL) reduce 434) ((T_IS_SMALLER_OR_EQUAL) reduce 434) ((T_LOGICAL_AND) reduce 434) ((T_LOGICAL_OR) reduce 434) ((T_LOGICAL_XOR) reduce 434) ((T_POW) shift) ((T_SL) reduce 434) ((T_SPACESHIP) reduce 434) ((T_SR) reduce 434) (("^") reduce 434) (("|") reduce 434)) 23075 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 444) ((";") reduce 444) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 23076 ((("%") reduce 430) (("*") reduce 430) (("+") reduce 430) (("-") reduce 430) ((".") reduce 430) (("/") reduce 430) ((":") reduce 430) ((";") reduce 430) (("<") reduce 430) ((">") reduce 430) (("?") reduce 430) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_BOOLEAN_AND) reduce 430) ((T_BOOLEAN_OR) reduce 430) ((T_COALESCE) reduce 430) ((T_INSTANCEOF) reduce 430) ((T_IS_EQUAL) reduce 430) ((T_IS_GREATER_OR_EQUAL) reduce 430) ((T_IS_IDENTICAL) reduce 430) ((T_IS_NOT_EQUAL) reduce 430) ((T_IS_NOT_IDENTICAL) reduce 430) ((T_IS_SMALLER_OR_EQUAL) reduce 430) ((T_LOGICAL_AND) reduce 430) ((T_LOGICAL_OR) reduce 430) ((T_LOGICAL_XOR) reduce 430) ((T_POW) shift) ((T_SL) reduce 430) ((T_SPACESHIP) reduce 430) ((T_SR) reduce 430) (("^") reduce 430) (("|") reduce 430)) 23077 ((("%") reduce 447) (("*") reduce 447) (("+") reduce 447) (("-") reduce 447) ((".") reduce 447) (("/") reduce 447) ((":") reduce 447) ((";") reduce 447) (("<") reduce 447) ((">") reduce 447) (("?") reduce 447) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_BOOLEAN_AND) reduce 447) ((T_BOOLEAN_OR) reduce 447) ((T_COALESCE) reduce 447) ((T_INSTANCEOF) reduce 447) ((T_IS_EQUAL) reduce 447) ((T_IS_GREATER_OR_EQUAL) reduce 447) ((T_IS_IDENTICAL) reduce 447) ((T_IS_NOT_EQUAL) reduce 447) ((T_IS_NOT_IDENTICAL) reduce 447) ((T_IS_SMALLER_OR_EQUAL) reduce 447) ((T_LOGICAL_AND) reduce 447) ((T_LOGICAL_OR) reduce 447) ((T_LOGICAL_XOR) reduce 447) ((T_POW) reduce 447) ((T_SL) reduce 447) ((T_SPACESHIP) reduce 447) ((T_SR) reduce 447) (("^") reduce 447) (("|") reduce 447)) 23079 ((("%") reduce 489) (("*") reduce 489) (("+") reduce 489) (("-") reduce 489) ((".") reduce 489) (("/") reduce 489) ((":") reduce 489) ((";") reduce 489) (("<") reduce 489) ((">") reduce 489) (("?") reduce 489) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_BOOLEAN_AND) reduce 489) ((T_BOOLEAN_OR) reduce 489) ((T_COALESCE) reduce 489) ((T_INSTANCEOF) reduce 489) ((T_IS_EQUAL) reduce 489) ((T_IS_GREATER_OR_EQUAL) reduce 489) ((T_IS_IDENTICAL) reduce 489) ((T_IS_NOT_EQUAL) reduce 489) ((T_IS_NOT_IDENTICAL) reduce 489) ((T_IS_SMALLER_OR_EQUAL) reduce 489) ((T_LOGICAL_AND) reduce 489) ((T_LOGICAL_OR) reduce 489) ((T_LOGICAL_XOR) reduce 489) ((T_POW) reduce 489) ((T_SL) reduce 489) ((T_SPACESHIP) reduce 489) ((T_SR) reduce 489) (("^") reduce 489) (("|") reduce 489)) 23081 ((("%") reduce 490) (("*") reduce 490) (("+") reduce 490) (("-") reduce 490) ((".") reduce 490) (("/") reduce 490) ((":") reduce 490) ((";") reduce 490) (("<") reduce 490) ((">") reduce 490) (("?") reduce 490) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_BOOLEAN_AND) reduce 490) ((T_BOOLEAN_OR) reduce 490) ((T_COALESCE) reduce 490) ((T_INSTANCEOF) reduce 490) ((T_IS_EQUAL) reduce 490) ((T_IS_GREATER_OR_EQUAL) reduce 490) ((T_IS_IDENTICAL) reduce 490) ((T_IS_NOT_EQUAL) reduce 490) ((T_IS_NOT_IDENTICAL) reduce 490) ((T_IS_SMALLER_OR_EQUAL) reduce 490) ((T_LOGICAL_AND) reduce 490) ((T_LOGICAL_OR) reduce 490) ((T_LOGICAL_XOR) reduce 490) ((T_POW) reduce 490) ((T_SL) reduce 490) ((T_SPACESHIP) reduce 490) ((T_SR) reduce 490) (("^") reduce 490) (("|") reduce 490)) 23082 ((("%") reduce 488) (("*") reduce 488) (("+") reduce 488) (("-") reduce 488) ((".") reduce 488) (("/") reduce 488) ((":") reduce 488) ((";") reduce 488) (("<") reduce 488) ((">") reduce 488) (("?") reduce 488) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_BOOLEAN_AND) reduce 488) ((T_BOOLEAN_OR) reduce 488) ((T_COALESCE) reduce 488) ((T_INSTANCEOF) reduce 488) ((T_IS_EQUAL) reduce 488) ((T_IS_GREATER_OR_EQUAL) reduce 488) ((T_IS_IDENTICAL) reduce 488) ((T_IS_NOT_EQUAL) reduce 488) ((T_IS_NOT_IDENTICAL) reduce 488) ((T_IS_SMALLER_OR_EQUAL) reduce 488) ((T_LOGICAL_AND) reduce 488) ((T_LOGICAL_OR) reduce 488) ((T_LOGICAL_XOR) reduce 488) ((T_POW) reduce 488) ((T_SL) reduce 488) ((T_SPACESHIP) reduce 488) ((T_SR) reduce 488) (("^") reduce 488) (("|") reduce 488)) 23083 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 581) ((";") reduce 581) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 23084 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 580) ((";") reduce 580) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 23085 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) ((":") reduce 466) ((";") reduce 466) (("<") reduce 466) (("=") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AND_EQUAL) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_COALESCE_EQUAL) reduce 466) ((T_CONCAT_EQUAL) reduce 466) ((T_DEC) reduce 466) ((T_DIV_EQUAL) reduce 466) ((T_INC) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_MINUS_EQUAL) reduce 466) ((T_MOD_EQUAL) reduce 466) ((T_MUL_EQUAL) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_OR_EQUAL) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_PLUS_EQUAL) reduce 466) ((T_POW) reduce 466) ((T_POW_EQUAL) reduce 466) ((T_SL) reduce 466) ((T_SL_EQUAL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) ((T_SR_EQUAL) reduce 466) ((T_XOR_EQUAL) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 23086 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 439) ((";") reduce 439) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 439) ((T_LOGICAL_OR) reduce 439) ((T_LOGICAL_XOR) reduce 439) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 23087 ((("%") reduce 432) (("*") reduce 432) (("+") reduce 432) (("-") reduce 432) ((".") reduce 432) (("/") reduce 432) ((":") reduce 432) ((";") reduce 432) (("<") reduce 432) ((">") reduce 432) (("?") reduce 432) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_BOOLEAN_AND) reduce 432) ((T_BOOLEAN_OR) reduce 432) ((T_COALESCE) reduce 432) ((T_INSTANCEOF) reduce 432) ((T_IS_EQUAL) reduce 432) ((T_IS_GREATER_OR_EQUAL) reduce 432) ((T_IS_IDENTICAL) reduce 432) ((T_IS_NOT_EQUAL) reduce 432) ((T_IS_NOT_IDENTICAL) reduce 432) ((T_IS_SMALLER_OR_EQUAL) reduce 432) ((T_LOGICAL_AND) reduce 432) ((T_LOGICAL_OR) reduce 432) ((T_LOGICAL_XOR) reduce 432) ((T_POW) shift) ((T_SL) reduce 432) ((T_SPACESHIP) reduce 432) ((T_SR) reduce 432) (("^") reduce 432) (("|") reduce 432)) 23089 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) ((":") reduce 93) ((";") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93)) 23090 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) ((":") reduce 92) ((";") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92)) 23091 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) ((":") reduce 94) ((";") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94)) 23092 ((("%") reduce 470) (("(") reduce 470) (("*") reduce 470) (("+") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) ((":") reduce 470) ((";") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470)) 23093 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) ((":") reduce 91) ((";") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91)) 23094 ((("%") reduce 365) (("*") reduce 365) (("+") reduce 365) (("-") reduce 365) ((".") reduce 365) (("/") reduce 365) ((":") reduce 365) ((";") reduce 365) (("<") reduce 365) ((">") reduce 365) (("?") reduce 365) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_BOOLEAN_AND) reduce 365) ((T_BOOLEAN_OR) reduce 365) ((T_COALESCE) reduce 365) ((T_INSTANCEOF) reduce 365) ((T_IS_EQUAL) reduce 365) ((T_IS_GREATER_OR_EQUAL) reduce 365) ((T_IS_IDENTICAL) reduce 365) ((T_IS_NOT_EQUAL) reduce 365) ((T_IS_NOT_IDENTICAL) reduce 365) ((T_IS_SMALLER_OR_EQUAL) reduce 365) ((T_LOGICAL_AND) reduce 365) ((T_LOGICAL_OR) reduce 365) ((T_LOGICAL_XOR) reduce 365) ((T_POW) reduce 365) ((T_SL) reduce 365) ((T_SPACESHIP) reduce 365) ((T_SR) reduce 365) (("^") reduce 365) (("|") reduce 365)) 23097 ((("%") reduce 472) (("(") reduce 472) (("*") reduce 472) (("+") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) ((":") reduce 472) ((";") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472)) 23098 ((("%") reduce 480) (("(") shift) (("*") reduce 480) (("+") reduce 480) (("-") reduce 480) ((".") reduce 480) (("/") reduce 480) ((":") reduce 480) ((";") reduce 480) (("<") reduce 480) ((">") reduce 480) (("?") reduce 480) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_BOOLEAN_AND) reduce 480) ((T_BOOLEAN_OR) reduce 480) ((T_COALESCE) reduce 480) ((T_INSTANCEOF) reduce 480) ((T_IS_EQUAL) reduce 480) ((T_IS_GREATER_OR_EQUAL) reduce 480) ((T_IS_IDENTICAL) reduce 480) ((T_IS_NOT_EQUAL) reduce 480) ((T_IS_NOT_IDENTICAL) reduce 480) ((T_IS_SMALLER_OR_EQUAL) reduce 480) ((T_LOGICAL_AND) reduce 480) ((T_LOGICAL_OR) reduce 480) ((T_LOGICAL_XOR) reduce 480) ((T_POW) reduce 480) ((T_SL) reduce 480) ((T_SPACESHIP) reduce 480) ((T_SR) reduce 480) (("^") reduce 480) (("|") reduce 480)) 23099 ((("%") reduce 471) (("(") reduce 471) (("*") reduce 471) (("+") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) ((":") reduce 471) ((";") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471)) 23100 ((("%") reduce 473) (("(") reduce 473) (("*") reduce 473) (("+") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) ((":") reduce 473) ((";") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 23101 ((("%") reduce 534) (("(") reduce 534) (("*") reduce 534) (("+") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) ((":") reduce 534) ((";") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 23108 ((("%") reduce 536) (("(") reduce 536) (("*") reduce 536) (("+") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) ((":") reduce 536) ((";") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 23110 ((("%") reduce 535) (("(") reduce 535) (("*") reduce 535) (("+") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) ((":") reduce 535) ((";") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 23111 ((("%") reduce 540) (("(") reduce 540) (("*") reduce 540) (("+") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) ((":") reduce 540) ((";") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 23112 ((("%") reduce 537) (("(") reduce 537) (("*") reduce 537) (("+") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) ((":") reduce 537) ((";") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 23113 ((("%") reduce 538) (("(") reduce 538) (("*") reduce 538) (("+") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) ((":") reduce 538) ((";") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 23115 ((("%") reduce 481) (("*") reduce 481) (("+") reduce 481) (("-") reduce 481) ((".") reduce 481) (("/") reduce 481) ((":") reduce 481) ((";") reduce 481) (("<") reduce 481) ((">") reduce 481) (("?") reduce 481) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_BOOLEAN_AND) reduce 481) ((T_BOOLEAN_OR) reduce 481) ((T_COALESCE) reduce 481) ((T_INSTANCEOF) reduce 481) ((T_IS_EQUAL) reduce 481) ((T_IS_GREATER_OR_EQUAL) reduce 481) ((T_IS_IDENTICAL) reduce 481) ((T_IS_NOT_EQUAL) reduce 481) ((T_IS_NOT_IDENTICAL) reduce 481) ((T_IS_SMALLER_OR_EQUAL) reduce 481) ((T_LOGICAL_AND) reduce 481) ((T_LOGICAL_OR) reduce 481) ((T_LOGICAL_XOR) reduce 481) ((T_POW) reduce 481) ((T_SL) reduce 481) ((T_SPACESHIP) reduce 481) ((T_SR) reduce 481) (("^") reduce 481) (("|") reduce 481)) 23116 ((("%") reduce 364) (("*") reduce 364) (("+") reduce 364) (("-") reduce 364) ((".") reduce 364) (("/") reduce 364) ((":") reduce 364) ((";") reduce 364) (("<") reduce 364) ((">") reduce 364) (("?") reduce 364) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_BOOLEAN_AND) reduce 364) ((T_BOOLEAN_OR) reduce 364) ((T_COALESCE) reduce 364) ((T_INSTANCEOF) reduce 364) ((T_IS_EQUAL) reduce 364) ((T_IS_GREATER_OR_EQUAL) reduce 364) ((T_IS_IDENTICAL) reduce 364) ((T_IS_NOT_EQUAL) reduce 364) ((T_IS_NOT_IDENTICAL) reduce 364) ((T_IS_SMALLER_OR_EQUAL) reduce 364) ((T_LOGICAL_AND) reduce 364) ((T_LOGICAL_OR) reduce 364) ((T_LOGICAL_XOR) reduce 364) ((T_POW) reduce 364) ((T_SL) reduce 364) ((T_SPACESHIP) reduce 364) ((T_SR) reduce 364) (("^") reduce 364) (("|") reduce 364)) 23117 ((("%") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) ((":") reduce 288) ((";") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("^") reduce 288) (("|") reduce 288)) 23121 ((("%") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) ((":") reduce 289) ((";") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("^") reduce 289) (("|") reduce 289)) 23122 ((("%") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) ((":") reduce 290) ((";") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("^") reduce 290) (("|") reduce 290)) 23124 ((("%") reduce 539) (("(") reduce 539) (("*") reduce 539) (("+") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) ((":") reduce 539) ((";") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 23125 ((("%") reduce 366) (("*") reduce 366) (("+") reduce 366) (("-") reduce 366) ((".") reduce 366) (("/") reduce 366) ((":") reduce 366) ((";") reduce 366) (("<") reduce 366) ((">") reduce 366) (("?") reduce 366) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_BOOLEAN_AND) reduce 366) ((T_BOOLEAN_OR) reduce 366) ((T_COALESCE) reduce 366) ((T_INSTANCEOF) reduce 366) ((T_IS_EQUAL) reduce 366) ((T_IS_GREATER_OR_EQUAL) reduce 366) ((T_IS_IDENTICAL) reduce 366) ((T_IS_NOT_EQUAL) reduce 366) ((T_IS_NOT_IDENTICAL) reduce 366) ((T_IS_SMALLER_OR_EQUAL) reduce 366) ((T_LOGICAL_AND) reduce 366) ((T_LOGICAL_OR) reduce 366) ((T_LOGICAL_XOR) reduce 366) ((T_POW) reduce 366) ((T_SL) reduce 366) ((T_SPACESHIP) reduce 366) ((T_SR) reduce 366) (("^") reduce 366) (("|") reduce 366)) 23133 ((("%") reduce 363) (("*") reduce 363) (("+") reduce 363) (("-") reduce 363) ((".") reduce 363) (("/") reduce 363) ((":") reduce 363) ((";") reduce 363) (("<") reduce 363) ((">") reduce 363) (("?") reduce 363) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_BOOLEAN_AND) reduce 363) ((T_BOOLEAN_OR) reduce 363) ((T_COALESCE) reduce 363) ((T_INSTANCEOF) reduce 363) ((T_IS_EQUAL) reduce 363) ((T_IS_GREATER_OR_EQUAL) reduce 363) ((T_IS_IDENTICAL) reduce 363) ((T_IS_NOT_EQUAL) reduce 363) ((T_IS_NOT_IDENTICAL) reduce 363) ((T_IS_SMALLER_OR_EQUAL) reduce 363) ((T_LOGICAL_AND) reduce 363) ((T_LOGICAL_OR) reduce 363) ((T_LOGICAL_XOR) reduce 363) ((T_POW) reduce 363) ((T_SL) reduce 363) ((T_SPACESHIP) reduce 363) ((T_SR) reduce 363) (("^") reduce 363) (("|") reduce 363)) 23135 ((("%") reduce 474) (("(") reduce 474) (("*") reduce 474) (("+") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) ((":") reduce 474) ((";") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474)) 23141 ((("%") reduce 230) (("*") reduce 230) (("+") reduce 230) (("-") reduce 230) ((".") reduce 230) (("/") reduce 230) ((":") reduce 230) ((";") reduce 230) (("<") reduce 230) ((">") reduce 230) (("?") reduce 230) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_BOOLEAN_AND) reduce 230) ((T_BOOLEAN_OR) reduce 230) ((T_COALESCE) reduce 230) ((T_INSTANCEOF) reduce 230) ((T_IS_EQUAL) reduce 230) ((T_IS_GREATER_OR_EQUAL) reduce 230) ((T_IS_IDENTICAL) reduce 230) ((T_IS_NOT_EQUAL) reduce 230) ((T_IS_NOT_IDENTICAL) reduce 230) ((T_IS_SMALLER_OR_EQUAL) reduce 230) ((T_LOGICAL_AND) reduce 230) ((T_LOGICAL_OR) reduce 230) ((T_LOGICAL_XOR) reduce 230) ((T_POW) reduce 230) ((T_SL) reduce 230) ((T_SPACESHIP) reduce 230) ((T_SR) reduce 230) (("^") reduce 230) (("|") reduce 230)) 23146 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 368) ((";") reduce 368) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 368) ((T_LOGICAL_OR) reduce 368) ((T_LOGICAL_XOR) reduce 368) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 23150 ((("%") reduce 575) (("*") reduce 575) (("+") reduce 575) (("-") reduce 575) ((".") reduce 575) (("/") reduce 575) ((":") reduce 575) ((";") reduce 575) (("<") reduce 575) ((">") reduce 575) (("?") reduce 575) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_BOOLEAN_AND) reduce 575) ((T_BOOLEAN_OR) reduce 575) ((T_COALESCE) reduce 575) ((T_INSTANCEOF) reduce 575) ((T_IS_EQUAL) reduce 575) ((T_IS_GREATER_OR_EQUAL) reduce 575) ((T_IS_IDENTICAL) reduce 575) ((T_IS_NOT_EQUAL) reduce 575) ((T_IS_NOT_IDENTICAL) reduce 575) ((T_IS_SMALLER_OR_EQUAL) reduce 575) ((T_LOGICAL_AND) reduce 575) ((T_LOGICAL_OR) reduce 575) ((T_LOGICAL_XOR) reduce 575) ((T_POW) reduce 575) ((T_SL) reduce 575) ((T_SPACESHIP) reduce 575) ((T_SR) reduce 575) (("^") reduce 575) (("|") reduce 575)) 23151 ((("%") reduce 428) (("*") reduce 428) (("+") reduce 428) (("-") reduce 428) ((".") reduce 428) (("/") reduce 428) ((":") reduce 428) ((";") reduce 428) (("<") reduce 428) ((">") reduce 428) (("?") reduce 428) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_BOOLEAN_AND) reduce 428) ((T_BOOLEAN_OR) reduce 428) ((T_COALESCE) reduce 428) ((T_INSTANCEOF) reduce 428) ((T_IS_EQUAL) reduce 428) ((T_IS_GREATER_OR_EQUAL) reduce 428) ((T_IS_IDENTICAL) reduce 428) ((T_IS_NOT_EQUAL) reduce 428) ((T_IS_NOT_IDENTICAL) reduce 428) ((T_IS_SMALLER_OR_EQUAL) reduce 428) ((T_LOGICAL_AND) reduce 428) ((T_LOGICAL_OR) reduce 428) ((T_LOGICAL_XOR) reduce 428) ((T_POW) shift) ((T_SL) reduce 428) ((T_SPACESHIP) reduce 428) ((T_SR) reduce 428) (("^") reduce 428) (("|") reduce 428)) 23152 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 578) ((";") reduce 578) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 23153 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((":") reduce 577) ((";") reduce 577) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 23154 ((("%") reduce 387) (("*") reduce 387) (("+") reduce 387) (("-") reduce 387) ((".") reduce 387) (("/") reduce 387) ((":") reduce 387) ((";") reduce 387) (("<") reduce 387) ((">") reduce 387) (("?") reduce 387) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_BOOLEAN_AND) reduce 387) ((T_BOOLEAN_OR) reduce 387) ((T_COALESCE) reduce 387) ((T_INSTANCEOF) reduce 387) ((T_IS_EQUAL) reduce 387) ((T_IS_GREATER_OR_EQUAL) reduce 387) ((T_IS_IDENTICAL) reduce 387) ((T_IS_NOT_EQUAL) reduce 387) ((T_IS_NOT_IDENTICAL) reduce 387) ((T_IS_SMALLER_OR_EQUAL) reduce 387) ((T_LOGICAL_AND) reduce 387) ((T_LOGICAL_OR) reduce 387) ((T_LOGICAL_XOR) reduce 387) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 387) ((T_SL) reduce 387) ((T_SPACESHIP) reduce 387) ((T_SR) reduce 387) (("[") reduce 510) (("^") reduce 387) (("{") reduce 510) (("|") reduce 387)) 23156 ((("%") reduce 435) (("*") reduce 435) (("+") reduce 435) (("-") reduce 435) ((".") reduce 435) (("/") reduce 435) ((":") reduce 435) ((";") reduce 435) (("<") reduce 435) ((">") reduce 435) (("?") reduce 435) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_BOOLEAN_AND) reduce 435) ((T_BOOLEAN_OR) reduce 435) ((T_COALESCE) reduce 435) ((T_INSTANCEOF) reduce 435) ((T_IS_EQUAL) reduce 435) ((T_IS_GREATER_OR_EQUAL) reduce 435) ((T_IS_IDENTICAL) reduce 435) ((T_IS_NOT_EQUAL) reduce 435) ((T_IS_NOT_IDENTICAL) reduce 435) ((T_IS_SMALLER_OR_EQUAL) reduce 435) ((T_LOGICAL_AND) reduce 435) ((T_LOGICAL_OR) reduce 435) ((T_LOGICAL_XOR) reduce 435) ((T_POW) reduce 435) ((T_SL) reduce 435) ((T_SPACESHIP) reduce 435) ((T_SR) reduce 435) (("^") reduce 435) (("|") reduce 435)) 23158 ((("%") reduce 476) (("*") reduce 476) (("+") reduce 476) (("-") reduce 476) ((".") reduce 476) (("/") reduce 476) ((":") reduce 476) ((";") reduce 476) (("<") reduce 476) ((">") reduce 476) (("?") reduce 476) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_BOOLEAN_AND) reduce 476) ((T_BOOLEAN_OR) reduce 476) ((T_COALESCE) reduce 476) ((T_INSTANCEOF) reduce 476) ((T_IS_EQUAL) reduce 476) ((T_IS_GREATER_OR_EQUAL) reduce 476) ((T_IS_IDENTICAL) reduce 476) ((T_IS_NOT_EQUAL) reduce 476) ((T_IS_NOT_IDENTICAL) reduce 476) ((T_IS_SMALLER_OR_EQUAL) reduce 476) ((T_LOGICAL_AND) reduce 476) ((T_LOGICAL_OR) reduce 476) ((T_LOGICAL_XOR) reduce 476) ((T_POW) reduce 476) ((T_SL) reduce 476) ((T_SPACESHIP) reduce 476) ((T_SR) reduce 476) (("^") reduce 476) (("|") reduce 476)) 23161 ((("%") reduce 579) (("*") reduce 579) (("+") reduce 579) (("-") reduce 579) ((".") reduce 579) (("/") reduce 579) ((":") reduce 579) ((";") reduce 579) (("<") reduce 579) ((">") reduce 579) (("?") reduce 579) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_BOOLEAN_AND) reduce 579) ((T_BOOLEAN_OR) reduce 579) ((T_COALESCE) reduce 579) ((T_INSTANCEOF) reduce 579) ((T_IS_EQUAL) reduce 579) ((T_IS_GREATER_OR_EQUAL) reduce 579) ((T_IS_IDENTICAL) reduce 579) ((T_IS_NOT_EQUAL) reduce 579) ((T_IS_NOT_IDENTICAL) reduce 579) ((T_IS_SMALLER_OR_EQUAL) reduce 579) ((T_LOGICAL_AND) reduce 579) ((T_LOGICAL_OR) reduce 579) ((T_LOGICAL_XOR) reduce 579) ((T_POW) reduce 579) ((T_SL) reduce 579) ((T_SPACESHIP) reduce 579) ((T_SR) reduce 579) (("^") reduce 579) (("|") reduce 579)) 23164 ((("%") reduce 576) (("*") reduce 576) (("+") reduce 576) (("-") reduce 576) ((".") reduce 576) (("/") reduce 576) ((":") reduce 576) ((";") reduce 576) (("<") reduce 576) ((">") reduce 576) (("?") reduce 576) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_BOOLEAN_AND) reduce 576) ((T_BOOLEAN_OR) reduce 576) ((T_COALESCE) reduce 576) ((T_INSTANCEOF) reduce 576) ((T_IS_EQUAL) reduce 576) ((T_IS_GREATER_OR_EQUAL) reduce 576) ((T_IS_IDENTICAL) reduce 576) ((T_IS_NOT_EQUAL) reduce 576) ((T_IS_NOT_IDENTICAL) reduce 576) ((T_IS_SMALLER_OR_EQUAL) reduce 576) ((T_LOGICAL_AND) reduce 576) ((T_LOGICAL_OR) reduce 576) ((T_LOGICAL_XOR) reduce 576) ((T_POW) reduce 576) ((T_SL) reduce 576) ((T_SPACESHIP) reduce 576) ((T_SR) reduce 576) (("^") reduce 576) (("|") reduce 576)) 23165 ((("%") reduce 429) (("*") reduce 429) (("+") reduce 429) (("-") reduce 429) ((".") reduce 429) (("/") reduce 429) ((":") reduce 429) ((";") reduce 429) (("<") reduce 429) ((">") reduce 429) (("?") reduce 429) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_BOOLEAN_AND) reduce 429) ((T_BOOLEAN_OR) reduce 429) ((T_COALESCE) reduce 429) ((T_INSTANCEOF) reduce 429) ((T_IS_EQUAL) reduce 429) ((T_IS_GREATER_OR_EQUAL) reduce 429) ((T_IS_IDENTICAL) reduce 429) ((T_IS_NOT_EQUAL) reduce 429) ((T_IS_NOT_IDENTICAL) reduce 429) ((T_IS_SMALLER_OR_EQUAL) reduce 429) ((T_LOGICAL_AND) reduce 429) ((T_LOGICAL_OR) reduce 429) ((T_LOGICAL_XOR) reduce 429) ((T_POW) shift) ((T_SL) reduce 429) ((T_SPACESHIP) reduce 429) ((T_SR) reduce 429) (("^") reduce 429) (("|") reduce 429)) 23166 ((("%") reduce 389) (("*") reduce 389) (("+") reduce 389) (("-") reduce 389) ((".") reduce 389) (("/") reduce 389) ((":") reduce 389) ((";") reduce 389) (("<") reduce 389) ((">") reduce 389) (("?") reduce 389) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_BOOLEAN_AND) reduce 389) ((T_BOOLEAN_OR) reduce 389) ((T_COALESCE) reduce 389) ((T_INSTANCEOF) reduce 389) ((T_IS_EQUAL) reduce 389) ((T_IS_GREATER_OR_EQUAL) reduce 389) ((T_IS_IDENTICAL) reduce 389) ((T_IS_NOT_EQUAL) reduce 389) ((T_IS_NOT_IDENTICAL) reduce 389) ((T_IS_SMALLER_OR_EQUAL) reduce 389) ((T_LOGICAL_AND) reduce 389) ((T_LOGICAL_OR) reduce 389) ((T_LOGICAL_XOR) reduce 389) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 389) ((T_SL) reduce 389) ((T_SPACESHIP) reduce 389) ((T_SR) reduce 389) (("[") reduce 510) (("^") reduce 389) (("{") reduce 510) (("|") reduce 389)) 23167 ((("%") reduce 372) (("*") reduce 372) (("+") reduce 372) (("-") reduce 372) ((".") reduce 372) (("/") reduce 372) ((":") reduce 372) ((";") reduce 372) (("<") reduce 372) ((">") reduce 372) (("?") reduce 372) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_BOOLEAN_AND) reduce 372) ((T_BOOLEAN_OR) reduce 372) ((T_COALESCE) reduce 372) ((T_INSTANCEOF) reduce 372) ((T_IS_EQUAL) reduce 372) ((T_IS_GREATER_OR_EQUAL) reduce 372) ((T_IS_IDENTICAL) reduce 372) ((T_IS_NOT_EQUAL) reduce 372) ((T_IS_NOT_IDENTICAL) reduce 372) ((T_IS_SMALLER_OR_EQUAL) reduce 372) ((T_LOGICAL_AND) reduce 372) ((T_LOGICAL_OR) reduce 372) ((T_LOGICAL_XOR) reduce 372) ((T_POW) reduce 372) ((T_SL) reduce 372) ((T_SPACESHIP) reduce 372) ((T_SR) reduce 372) (("^") reduce 372) (("|") reduce 372)) 23168 ((("%") reduce 433) (("*") reduce 433) (("+") reduce 433) (("-") reduce 433) ((".") reduce 433) (("/") reduce 433) ((":") reduce 433) ((";") reduce 433) (("<") reduce 433) ((">") reduce 433) (("?") reduce 433) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_BOOLEAN_AND) reduce 433) ((T_BOOLEAN_OR) reduce 433) ((T_COALESCE) reduce 433) ((T_INSTANCEOF) reduce 433) ((T_IS_EQUAL) reduce 433) ((T_IS_GREATER_OR_EQUAL) reduce 433) ((T_IS_IDENTICAL) reduce 433) ((T_IS_NOT_EQUAL) reduce 433) ((T_IS_NOT_IDENTICAL) reduce 433) ((T_IS_SMALLER_OR_EQUAL) reduce 433) ((T_LOGICAL_AND) reduce 433) ((T_LOGICAL_OR) reduce 433) ((T_LOGICAL_XOR) reduce 433) ((T_POW) shift) ((T_SL) reduce 433) ((T_SPACESHIP) reduce 433) ((T_SR) reduce 433) (("^") reduce 433) (("|") reduce 433)) 23169 ((("%") reduce 431) (("*") reduce 431) (("+") reduce 431) (("-") reduce 431) ((".") reduce 431) (("/") reduce 431) ((":") reduce 431) ((";") reduce 431) (("<") reduce 431) ((">") reduce 431) (("?") reduce 431) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_BOOLEAN_AND) reduce 431) ((T_BOOLEAN_OR) reduce 431) ((T_COALESCE) reduce 431) ((T_INSTANCEOF) reduce 431) ((T_IS_EQUAL) reduce 431) ((T_IS_GREATER_OR_EQUAL) reduce 431) ((T_IS_IDENTICAL) reduce 431) ((T_IS_NOT_EQUAL) reduce 431) ((T_IS_NOT_IDENTICAL) reduce 431) ((T_IS_SMALLER_OR_EQUAL) reduce 431) ((T_LOGICAL_AND) reduce 431) ((T_LOGICAL_OR) reduce 431) ((T_LOGICAL_XOR) reduce 431) ((T_POW) shift) ((T_SL) reduce 431) ((T_SPACESHIP) reduce 431) ((T_SR) reduce 431) (("^") reduce 431) (("|") reduce 431)) 23172 ((("%") reduce 482) (("(") reduce 482) (("*") reduce 482) (("+") reduce 482) (("-") reduce 482) ((".") reduce 482) (("/") reduce 482) ((":") reduce 482) ((";") reduce 482) (("<") reduce 482) ((">") reduce 482) (("?") reduce 482) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_BOOLEAN_AND) reduce 482) ((T_BOOLEAN_OR) reduce 482) ((T_COALESCE) reduce 482) ((T_INSTANCEOF) reduce 482) ((T_IS_EQUAL) reduce 482) ((T_IS_GREATER_OR_EQUAL) reduce 482) ((T_IS_IDENTICAL) reduce 482) ((T_IS_NOT_EQUAL) reduce 482) ((T_IS_NOT_IDENTICAL) reduce 482) ((T_IS_SMALLER_OR_EQUAL) reduce 482) ((T_LOGICAL_AND) reduce 482) ((T_LOGICAL_OR) reduce 482) ((T_LOGICAL_XOR) reduce 482) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 482) ((T_OBJECT_OPERATOR) reduce 482) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 482) ((T_POW) reduce 482) ((T_SL) reduce 482) ((T_SPACESHIP) reduce 482) ((T_SR) reduce 482) (("[") reduce 482) (("^") reduce 482) (("{") reduce 482) (("|") reduce 482)) 23173 ((("%") reduce 436) (("*") reduce 436) (("+") reduce 436) (("-") reduce 436) ((".") reduce 436) (("/") reduce 436) ((":") reduce 436) ((";") reduce 436) (("<") reduce 436) ((">") reduce 436) (("?") reduce 436) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_BOOLEAN_AND) reduce 436) ((T_BOOLEAN_OR) reduce 436) ((T_COALESCE) reduce 436) ((T_INSTANCEOF) reduce 436) ((T_IS_EQUAL) reduce 436) ((T_IS_GREATER_OR_EQUAL) reduce 436) ((T_IS_IDENTICAL) reduce 436) ((T_IS_NOT_EQUAL) reduce 436) ((T_IS_NOT_IDENTICAL) reduce 436) ((T_IS_SMALLER_OR_EQUAL) reduce 436) ((T_LOGICAL_AND) reduce 436) ((T_LOGICAL_OR) reduce 436) ((T_LOGICAL_XOR) reduce 436) ((T_POW) shift) ((T_SL) reduce 436) ((T_SPACESHIP) reduce 436) ((T_SR) reduce 436) (("^") reduce 436) (("|") reduce 436)) 23174 ((("%") reduce 409) (("*") reduce 409) (("+") reduce 409) (("-") reduce 409) ((".") reduce 409) (("/") reduce 409) ((":") reduce 409) ((";") reduce 409) (("<") reduce 409) ((">") reduce 409) (("?") reduce 409) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_BOOLEAN_AND) reduce 409) ((T_BOOLEAN_OR) reduce 409) ((T_COALESCE) reduce 409) ((T_INSTANCEOF) reduce 409) ((T_IS_EQUAL) reduce 409) ((T_IS_GREATER_OR_EQUAL) reduce 409) ((T_IS_IDENTICAL) reduce 409) ((T_IS_NOT_EQUAL) reduce 409) ((T_IS_NOT_IDENTICAL) reduce 409) ((T_IS_SMALLER_OR_EQUAL) reduce 409) ((T_LOGICAL_AND) reduce 409) ((T_LOGICAL_OR) reduce 409) ((T_LOGICAL_XOR) reduce 409) ((T_POW) shift) ((T_SL) reduce 409) ((T_SPACESHIP) reduce 409) ((T_SR) reduce 409) (("^") reduce 409) (("|") reduce 409)) 23175 ((("%") reduce 408) (("*") reduce 408) (("+") reduce 408) (("-") reduce 408) ((".") reduce 408) (("/") reduce 408) ((":") reduce 408) ((";") reduce 408) (("<") reduce 408) ((">") reduce 408) (("?") reduce 408) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_BOOLEAN_AND) reduce 408) ((T_BOOLEAN_OR) reduce 408) ((T_COALESCE) reduce 408) ((T_INSTANCEOF) reduce 408) ((T_IS_EQUAL) reduce 408) ((T_IS_GREATER_OR_EQUAL) reduce 408) ((T_IS_IDENTICAL) reduce 408) ((T_IS_NOT_EQUAL) reduce 408) ((T_IS_NOT_IDENTICAL) reduce 408) ((T_IS_SMALLER_OR_EQUAL) reduce 408) ((T_LOGICAL_AND) reduce 408) ((T_LOGICAL_OR) reduce 408) ((T_LOGICAL_XOR) reduce 408) ((T_POW) shift) ((T_SL) reduce 408) ((T_SPACESHIP) reduce 408) ((T_SR) reduce 408) (("^") reduce 408) (("|") reduce 408)) 23177 ((("%") reduce 422) (("(") reduce 517) (("*") reduce 422) (("+") reduce 422) (("-") reduce 422) ((".") reduce 422) (("/") reduce 422) ((":") reduce 422) ((";") reduce 422) (("<") reduce 422) ((">") reduce 422) (("?") reduce 422) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_BOOLEAN_AND) reduce 422) ((T_BOOLEAN_OR) reduce 422) ((T_COALESCE) reduce 422) ((T_INSTANCEOF) reduce 422) ((T_IS_EQUAL) reduce 422) ((T_IS_GREATER_OR_EQUAL) reduce 422) ((T_IS_IDENTICAL) reduce 422) ((T_IS_NOT_EQUAL) reduce 422) ((T_IS_NOT_IDENTICAL) reduce 422) ((T_IS_SMALLER_OR_EQUAL) reduce 422) ((T_LOGICAL_AND) reduce 422) ((T_LOGICAL_OR) reduce 422) ((T_LOGICAL_XOR) reduce 422) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 511) ((T_OBJECT_OPERATOR) reduce 511) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 511) ((T_POW) reduce 422) ((T_SL) reduce 422) ((T_SPACESHIP) reduce 422) ((T_SR) reduce 422) (("[") reduce 511) (("^") reduce 422) (("{") reduce 511) (("|") reduce 422)) 23178 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) ((":") reduce 531) ((";") reduce 531) (("<") reduce 531) (("=") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AND_EQUAL) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_COALESCE_EQUAL) reduce 531) ((T_CONCAT_EQUAL) reduce 531) ((T_DEC) reduce 531) ((T_DIV_EQUAL) reduce 531) ((T_INC) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_MINUS_EQUAL) reduce 531) ((T_MOD_EQUAL) reduce 531) ((T_MUL_EQUAL) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_OR_EQUAL) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_PLUS_EQUAL) reduce 531) ((T_POW) reduce 531) ((T_POW_EQUAL) reduce 531) ((T_SL) reduce 531) ((T_SL_EQUAL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) ((T_SR_EQUAL) reduce 531) ((T_XOR_EQUAL) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 23181 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) ((":") reduce 530) ((";") reduce 530) (("<") reduce 530) (("=") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AND_EQUAL) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_COALESCE_EQUAL) reduce 530) ((T_CONCAT_EQUAL) reduce 530) ((T_DEC) reduce 530) ((T_DIV_EQUAL) reduce 530) ((T_INC) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_MINUS_EQUAL) reduce 530) ((T_MOD_EQUAL) reduce 530) ((T_MUL_EQUAL) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_OR_EQUAL) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_PLUS_EQUAL) reduce 530) ((T_POW) reduce 530) ((T_POW_EQUAL) reduce 530) ((T_SL) reduce 530) ((T_SL_EQUAL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) ((T_SR_EQUAL) reduce 530) ((T_XOR_EQUAL) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 23183 ((("%") reduce 485) (("(") reduce 485) (("*") reduce 485) (("+") reduce 485) (("-") reduce 485) ((".") reduce 485) (("/") reduce 485) ((":") reduce 485) ((";") reduce 485) (("<") reduce 485) ((">") reduce 485) (("?") reduce 485) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_BOOLEAN_AND) reduce 485) ((T_BOOLEAN_OR) reduce 485) ((T_COALESCE) reduce 485) ((T_INSTANCEOF) reduce 485) ((T_IS_EQUAL) reduce 485) ((T_IS_GREATER_OR_EQUAL) reduce 485) ((T_IS_IDENTICAL) reduce 485) ((T_IS_NOT_EQUAL) reduce 485) ((T_IS_NOT_IDENTICAL) reduce 485) ((T_IS_SMALLER_OR_EQUAL) reduce 485) ((T_LOGICAL_AND) reduce 485) ((T_LOGICAL_OR) reduce 485) ((T_LOGICAL_XOR) reduce 485) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 485) ((T_OBJECT_OPERATOR) reduce 485) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 485) ((T_POW) reduce 485) ((T_SL) reduce 485) ((T_SPACESHIP) reduce 485) ((T_SR) reduce 485) (("[") reduce 485) (("^") reduce 485) (("{") reduce 485) (("|") reduce 485)) 23184 ((("%") reduce 410) (("*") reduce 410) (("+") reduce 410) (("-") reduce 410) ((".") reduce 410) (("/") reduce 410) ((":") reduce 410) ((";") reduce 410) (("<") reduce 410) ((">") reduce 410) (("?") reduce 410) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_BOOLEAN_AND) reduce 410) ((T_BOOLEAN_OR) reduce 410) ((T_COALESCE) reduce 410) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 410) ((T_IS_GREATER_OR_EQUAL) reduce 410) ((T_IS_IDENTICAL) reduce 410) ((T_IS_NOT_EQUAL) reduce 410) ((T_IS_NOT_IDENTICAL) reduce 410) ((T_IS_SMALLER_OR_EQUAL) reduce 410) ((T_LOGICAL_AND) reduce 410) ((T_LOGICAL_OR) reduce 410) ((T_LOGICAL_XOR) reduce 410) ((T_POW) shift) ((T_SL) reduce 410) ((T_SPACESHIP) reduce 410) ((T_SR) reduce 410) (("^") reduce 410) (("|") reduce 410)) 23186 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) (("+") shift) (("-") shift) ((";") shift) (("@") shift) ((T_ABSTRACT) shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_BREAK) shift) ((T_CASE) reduce 226) ((T_CLASS) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_CONTINUE) shift) ((T_DEC) shift) ((T_DECLARE) shift) ((T_DEFAULT) reduce 226) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DO) shift) ((T_DOUBLE_CAST) shift) ((T_ECHO) shift) ((T_EMPTY) shift) ((T_ENDSWITCH) reduce 226) ((T_ENUM) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FINAL) shift) ((T_FN) shift) ((T_FOR) shift) ((T_FOREACH) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_GLOBAL) shift) ((T_GOTO) shift) ((T_HALT_COMPILER) shift) ((T_IF) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INLINE_HTML) shift) ((T_INTERFACE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_RETURN) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_SWITCH) shift) ((T_THROW) shift) ((T_TRAIT) shift) ((T_TRAIT_C) shift) ((T_TRY) shift) ((T_UNSET) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_WHILE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("{") shift) (("~") shift)) 23817 ((("!") reduce 224) (("\"") reduce 224) (("$") reduce 224) (("(") reduce 224) (("+") reduce 224) (("-") reduce 224) ((";") reduce 224) (("@") reduce 224) ((T_ABSTRACT) reduce 224) ((T_ARRAY) reduce 224) ((T_ARRAY_CAST) reduce 224) ((T_ATTRIBUTE) reduce 224) ((T_BOOL_CAST) reduce 224) ((T_BREAK) reduce 224) ((T_CASE) reduce 224) ((T_CLASS) reduce 224) ((T_CLASS_C) reduce 224) ((T_CLONE) reduce 224) ((T_CONSTANT_ENCAPSED_STRING) reduce 224) ((T_CONTINUE) reduce 224) ((T_DEC) reduce 224) ((T_DECLARE) reduce 224) ((T_DEFAULT) reduce 224) ((T_DIR) reduce 224) ((T_DNUMBER) reduce 224) ((T_DO) reduce 224) ((T_DOUBLE_CAST) reduce 224) ((T_ECHO) reduce 224) ((T_ELSE) reduce 224) ((T_ELSEIF) reduce 224) ((T_EMPTY) reduce 224) ((T_ENUM) reduce 224) ((T_EVAL) reduce 224) ((T_EXIT) reduce 224) ((T_FILE) reduce 224) ((T_FINAL) reduce 224) ((T_FN) reduce 224) ((T_FOR) reduce 224) ((T_FOREACH) reduce 224) ((T_FUNCTION) reduce 224) ((T_FUNC_C) reduce 224) ((T_GLOBAL) reduce 224) ((T_GOTO) reduce 224) ((T_HALT_COMPILER) reduce 224) ((T_IF) reduce 224) ((T_INC) reduce 224) ((T_INCLUDE) reduce 224) ((T_INCLUDE_ONCE) reduce 224) ((T_INLINE_HTML) reduce 224) ((T_INTERFACE) reduce 224) ((T_INT_CAST) reduce 224) ((T_ISSET) reduce 224) ((T_LINE) reduce 224) ((T_LIST) reduce 224) ((T_LNUMBER) reduce 224) ((T_MATCH) reduce 224) ((T_METHOD_C) reduce 224) ((T_NAME_FULLY_QUALIFIED) reduce 224) ((T_NAME_QUALIFIED) reduce 224) ((T_NAME_RELATIVE) reduce 224) ((T_NEW) reduce 224) ((T_NS_C) reduce 224) ((T_OBJECT_CAST) reduce 224) ((T_PRINT) reduce 224) ((T_READONLY) reduce 224) ((T_REQUIRE) reduce 224) ((T_REQUIRE_ONCE) reduce 224) ((T_RETURN) reduce 224) ((T_START_HEREDOC) reduce 224) ((T_STATIC) reduce 224) ((T_STRING) reduce 224) ((T_STRING_CAST) reduce 224) ((T_SWITCH) reduce 224) ((T_THROW) reduce 224) ((T_TRAIT) reduce 224) ((T_TRAIT_C) reduce 224) ((T_TRY) reduce 224) ((T_UNSET) reduce 224) ((T_UNSET_CAST) reduce 224) ((T_VARIABLE) reduce 224) ((T_WHILE) reduce 224) ((T_YIELD) reduce 224) ((T_YIELD_FROM) reduce 224) (("[") reduce 224) (("`") reduce 224) (("{") reduce 224) (("}") reduce 224) (("~") reduce 224)) 23818 ((("!") reduce 167) (("\"") reduce 167) (("$") reduce 167) (("(") reduce 167) (("+") reduce 167) (("-") reduce 167) ((";") reduce 167) (("@") reduce 167) ((T_ABSTRACT) reduce 167) ((T_ARRAY) reduce 167) ((T_ARRAY_CAST) reduce 167) ((T_ATTRIBUTE) reduce 167) ((T_BOOL_CAST) reduce 167) ((T_BREAK) reduce 167) ((T_CASE) reduce 167) ((T_CLASS) reduce 167) ((T_CLASS_C) reduce 167) ((T_CLONE) reduce 167) ((T_CONSTANT_ENCAPSED_STRING) reduce 167) ((T_CONTINUE) reduce 167) ((T_DEC) reduce 167) ((T_DECLARE) reduce 167) ((T_DEFAULT) reduce 167) ((T_DIR) reduce 167) ((T_DNUMBER) reduce 167) ((T_DO) reduce 167) ((T_DOUBLE_CAST) reduce 167) ((T_ECHO) reduce 167) ((T_ELSE) reduce 167) ((T_ELSEIF) reduce 167) ((T_EMPTY) reduce 167) ((T_ENUM) reduce 167) ((T_EVAL) reduce 167) ((T_EXIT) reduce 167) ((T_FILE) reduce 167) ((T_FINAL) reduce 167) ((T_FN) reduce 167) ((T_FOR) reduce 167) ((T_FOREACH) reduce 167) ((T_FUNCTION) reduce 167) ((T_FUNC_C) reduce 167) ((T_GLOBAL) reduce 167) ((T_GOTO) reduce 167) ((T_HALT_COMPILER) reduce 167) ((T_IF) reduce 167) ((T_INC) reduce 167) ((T_INCLUDE) reduce 167) ((T_INCLUDE_ONCE) reduce 167) ((T_INLINE_HTML) reduce 167) ((T_INTERFACE) reduce 167) ((T_INT_CAST) reduce 167) ((T_ISSET) reduce 167) ((T_LINE) reduce 167) ((T_LIST) reduce 167) ((T_LNUMBER) reduce 167) ((T_MATCH) reduce 167) ((T_METHOD_C) reduce 167) ((T_NAME_FULLY_QUALIFIED) reduce 167) ((T_NAME_QUALIFIED) reduce 167) ((T_NAME_RELATIVE) reduce 167) ((T_NEW) reduce 167) ((T_NS_C) reduce 167) ((T_OBJECT_CAST) reduce 167) ((T_PRINT) reduce 167) ((T_READONLY) reduce 167) ((T_REQUIRE) reduce 167) ((T_REQUIRE_ONCE) reduce 167) ((T_RETURN) reduce 167) ((T_START_HEREDOC) reduce 167) ((T_STATIC) reduce 167) ((T_STRING) reduce 167) ((T_STRING_CAST) reduce 167) ((T_SWITCH) reduce 167) ((T_THROW) reduce 167) ((T_TRAIT) reduce 167) ((T_TRAIT_C) reduce 167) ((T_TRY) reduce 167) ((T_UNSET) reduce 167) ((T_UNSET_CAST) reduce 167) ((T_VARIABLE) reduce 167) ((T_WHILE) reduce 167) ((T_YIELD) reduce 167) ((T_YIELD_FROM) reduce 167) (("[") reduce 167) (("`") reduce 167) (("{") reduce 167) (("}") reduce 167) (("~") reduce 167)) 23820 ((("!") reduce 156) (("\"") reduce 156) (("$") reduce 156) (("(") reduce 156) (("+") reduce 156) (("-") reduce 156) ((";") reduce 156) (("@") reduce 156) ((T_ABSTRACT) reduce 156) ((T_ARRAY) reduce 156) ((T_ARRAY_CAST) reduce 156) ((T_ATTRIBUTE) reduce 156) ((T_BOOL_CAST) reduce 156) ((T_BREAK) reduce 156) ((T_CASE) reduce 156) ((T_CLASS) reduce 156) ((T_CLASS_C) reduce 156) ((T_CLONE) reduce 156) ((T_CONSTANT_ENCAPSED_STRING) reduce 156) ((T_CONTINUE) reduce 156) ((T_DEC) reduce 156) ((T_DECLARE) reduce 156) ((T_DEFAULT) reduce 156) ((T_DIR) reduce 156) ((T_DNUMBER) reduce 156) ((T_DO) reduce 156) ((T_DOUBLE_CAST) reduce 156) ((T_ECHO) reduce 156) ((T_ELSE) reduce 156) ((T_ELSEIF) reduce 156) ((T_EMPTY) reduce 156) ((T_ENUM) reduce 156) ((T_EVAL) reduce 156) ((T_EXIT) reduce 156) ((T_FILE) reduce 156) ((T_FINAL) reduce 156) ((T_FN) reduce 156) ((T_FOR) reduce 156) ((T_FOREACH) reduce 156) ((T_FUNCTION) reduce 156) ((T_FUNC_C) reduce 156) ((T_GLOBAL) reduce 156) ((T_GOTO) reduce 156) ((T_HALT_COMPILER) reduce 156) ((T_IF) reduce 156) ((T_INC) reduce 156) ((T_INCLUDE) reduce 156) ((T_INCLUDE_ONCE) reduce 156) ((T_INLINE_HTML) reduce 156) ((T_INTERFACE) reduce 156) ((T_INT_CAST) reduce 156) ((T_ISSET) reduce 156) ((T_LINE) reduce 156) ((T_LIST) reduce 156) ((T_LNUMBER) reduce 156) ((T_MATCH) reduce 156) ((T_METHOD_C) reduce 156) ((T_NAME_FULLY_QUALIFIED) reduce 156) ((T_NAME_QUALIFIED) reduce 156) ((T_NAME_RELATIVE) reduce 156) ((T_NEW) reduce 156) ((T_NS_C) reduce 156) ((T_OBJECT_CAST) reduce 156) ((T_PRINT) reduce 156) ((T_READONLY) reduce 156) ((T_REQUIRE) reduce 156) ((T_REQUIRE_ONCE) reduce 156) ((T_RETURN) reduce 156) ((T_START_HEREDOC) reduce 156) ((T_STATIC) reduce 156) ((T_STRING) reduce 156) ((T_STRING_CAST) reduce 156) ((T_SWITCH) reduce 156) ((T_THROW) reduce 156) ((T_TRAIT) reduce 156) ((T_TRAIT_C) reduce 156) ((T_TRY) reduce 156) ((T_UNSET) reduce 156) ((T_UNSET_CAST) reduce 156) ((T_VARIABLE) reduce 156) ((T_WHILE) reduce 156) ((T_YIELD) reduce 156) ((T_YIELD_FROM) reduce 156) (("[") reduce 156) (("`") reduce 156) (("{") reduce 156) (("}") reduce 156) (("~") reduce 156)) 23822 ((("!") reduce 154) (("\"") reduce 154) (("$") reduce 154) (("(") reduce 154) (("+") reduce 154) (("-") reduce 154) ((";") reduce 154) (("@") reduce 154) ((T_ABSTRACT) reduce 154) ((T_ARRAY) reduce 154) ((T_ARRAY_CAST) reduce 154) ((T_ATTRIBUTE) reduce 154) ((T_BOOL_CAST) reduce 154) ((T_BREAK) reduce 154) ((T_CASE) reduce 154) ((T_CLASS) reduce 154) ((T_CLASS_C) reduce 154) ((T_CLONE) reduce 154) ((T_CONSTANT_ENCAPSED_STRING) reduce 154) ((T_CONTINUE) reduce 154) ((T_DEC) reduce 154) ((T_DECLARE) reduce 154) ((T_DEFAULT) reduce 154) ((T_DIR) reduce 154) ((T_DNUMBER) reduce 154) ((T_DO) reduce 154) ((T_DOUBLE_CAST) reduce 154) ((T_ECHO) reduce 154) ((T_ELSE) reduce 154) ((T_ELSEIF) reduce 154) ((T_EMPTY) reduce 154) ((T_ENUM) reduce 154) ((T_EVAL) reduce 154) ((T_EXIT) reduce 154) ((T_FILE) reduce 154) ((T_FINAL) reduce 154) ((T_FN) reduce 154) ((T_FOR) reduce 154) ((T_FOREACH) reduce 154) ((T_FUNCTION) reduce 154) ((T_FUNC_C) reduce 154) ((T_GLOBAL) reduce 154) ((T_GOTO) reduce 154) ((T_HALT_COMPILER) reduce 154) ((T_IF) reduce 154) ((T_INC) reduce 154) ((T_INCLUDE) reduce 154) ((T_INCLUDE_ONCE) reduce 154) ((T_INLINE_HTML) reduce 154) ((T_INTERFACE) reduce 154) ((T_INT_CAST) reduce 154) ((T_ISSET) reduce 154) ((T_LINE) reduce 154) ((T_LIST) reduce 154) ((T_LNUMBER) reduce 154) ((T_MATCH) reduce 154) ((T_METHOD_C) reduce 154) ((T_NAME_FULLY_QUALIFIED) reduce 154) ((T_NAME_QUALIFIED) reduce 154) ((T_NAME_RELATIVE) reduce 154) ((T_NEW) reduce 154) ((T_NS_C) reduce 154) ((T_OBJECT_CAST) reduce 154) ((T_PRINT) reduce 154) ((T_READONLY) reduce 154) ((T_REQUIRE) reduce 154) ((T_REQUIRE_ONCE) reduce 154) ((T_RETURN) reduce 154) ((T_START_HEREDOC) reduce 154) ((T_STATIC) reduce 154) ((T_STRING) reduce 154) ((T_STRING_CAST) reduce 154) ((T_SWITCH) reduce 154) ((T_THROW) reduce 154) ((T_TRAIT) reduce 154) ((T_TRAIT_C) reduce 154) ((T_TRY) reduce 154) ((T_UNSET) reduce 154) ((T_UNSET_CAST) reduce 154) ((T_VARIABLE) reduce 154) ((T_WHILE) reduce 154) ((T_YIELD) reduce 154) ((T_YIELD_FROM) reduce 154) (("[") reduce 154) (("`") reduce 154) (("{") reduce 154) (("}") reduce 154) (("~") reduce 154)) 23824 ((("!") reduce 166) (("\"") reduce 166) (("$") reduce 166) (("(") reduce 166) (("+") reduce 166) (("-") reduce 166) ((";") reduce 166) (("@") reduce 166) ((T_ABSTRACT) reduce 166) ((T_ARRAY) reduce 166) ((T_ARRAY_CAST) reduce 166) ((T_ATTRIBUTE) reduce 166) ((T_BOOL_CAST) reduce 166) ((T_BREAK) reduce 166) ((T_CASE) reduce 166) ((T_CLASS) reduce 166) ((T_CLASS_C) reduce 166) ((T_CLONE) reduce 166) ((T_CONSTANT_ENCAPSED_STRING) reduce 166) ((T_CONTINUE) reduce 166) ((T_DEC) reduce 166) ((T_DECLARE) reduce 166) ((T_DEFAULT) reduce 166) ((T_DIR) reduce 166) ((T_DNUMBER) reduce 166) ((T_DO) reduce 166) ((T_DOUBLE_CAST) reduce 166) ((T_ECHO) reduce 166) ((T_ELSE) reduce 166) ((T_ELSEIF) reduce 166) ((T_EMPTY) reduce 166) ((T_ENUM) reduce 166) ((T_EVAL) reduce 166) ((T_EXIT) reduce 166) ((T_FILE) reduce 166) ((T_FINAL) reduce 166) ((T_FN) reduce 166) ((T_FOR) reduce 166) ((T_FOREACH) reduce 166) ((T_FUNCTION) reduce 166) ((T_FUNC_C) reduce 166) ((T_GLOBAL) reduce 166) ((T_GOTO) reduce 166) ((T_HALT_COMPILER) reduce 166) ((T_IF) reduce 166) ((T_INC) reduce 166) ((T_INCLUDE) reduce 166) ((T_INCLUDE_ONCE) reduce 166) ((T_INLINE_HTML) reduce 166) ((T_INTERFACE) reduce 166) ((T_INT_CAST) reduce 166) ((T_ISSET) reduce 166) ((T_LINE) reduce 166) ((T_LIST) reduce 166) ((T_LNUMBER) reduce 166) ((T_MATCH) reduce 166) ((T_METHOD_C) reduce 166) ((T_NAME_FULLY_QUALIFIED) reduce 166) ((T_NAME_QUALIFIED) reduce 166) ((T_NAME_RELATIVE) reduce 166) ((T_NEW) reduce 166) ((T_NS_C) reduce 166) ((T_OBJECT_CAST) reduce 166) ((T_PRINT) reduce 166) ((T_READONLY) reduce 166) ((T_REQUIRE) reduce 166) ((T_REQUIRE_ONCE) reduce 166) ((T_RETURN) reduce 166) ((T_START_HEREDOC) reduce 166) ((T_STATIC) reduce 166) ((T_STRING) reduce 166) ((T_STRING_CAST) reduce 166) ((T_SWITCH) reduce 166) ((T_THROW) reduce 166) ((T_TRAIT) reduce 166) ((T_TRAIT_C) reduce 166) ((T_TRY) reduce 166) ((T_UNSET) reduce 166) ((T_UNSET_CAST) reduce 166) ((T_VARIABLE) reduce 166) ((T_WHILE) reduce 166) ((T_YIELD) reduce 166) ((T_YIELD_FROM) reduce 166) (("[") reduce 166) (("`") reduce 166) (("{") reduce 166) (("}") reduce 166) (("~") reduce 166)) 23826 ((("!") reduce 155) (("\"") reduce 155) (("$") reduce 155) (("(") reduce 155) (("+") reduce 155) (("-") reduce 155) ((";") reduce 155) (("@") reduce 155) ((T_ABSTRACT) reduce 155) ((T_ARRAY) reduce 155) ((T_ARRAY_CAST) reduce 155) ((T_ATTRIBUTE) reduce 155) ((T_BOOL_CAST) reduce 155) ((T_BREAK) reduce 155) ((T_CASE) reduce 155) ((T_CLASS) reduce 155) ((T_CLASS_C) reduce 155) ((T_CLONE) reduce 155) ((T_CONSTANT_ENCAPSED_STRING) reduce 155) ((T_CONTINUE) reduce 155) ((T_DEC) reduce 155) ((T_DECLARE) reduce 155) ((T_DEFAULT) reduce 155) ((T_DIR) reduce 155) ((T_DNUMBER) reduce 155) ((T_DO) reduce 155) ((T_DOUBLE_CAST) reduce 155) ((T_ECHO) reduce 155) ((T_ELSE) reduce 155) ((T_ELSEIF) reduce 155) ((T_EMPTY) reduce 155) ((T_ENUM) reduce 155) ((T_EVAL) reduce 155) ((T_EXIT) reduce 155) ((T_FILE) reduce 155) ((T_FINAL) reduce 155) ((T_FN) reduce 155) ((T_FOR) reduce 155) ((T_FOREACH) reduce 155) ((T_FUNCTION) reduce 155) ((T_FUNC_C) reduce 155) ((T_GLOBAL) reduce 155) ((T_GOTO) reduce 155) ((T_HALT_COMPILER) reduce 155) ((T_IF) reduce 155) ((T_INC) reduce 155) ((T_INCLUDE) reduce 155) ((T_INCLUDE_ONCE) reduce 155) ((T_INLINE_HTML) reduce 155) ((T_INTERFACE) reduce 155) ((T_INT_CAST) reduce 155) ((T_ISSET) reduce 155) ((T_LINE) reduce 155) ((T_LIST) reduce 155) ((T_LNUMBER) reduce 155) ((T_MATCH) reduce 155) ((T_METHOD_C) reduce 155) ((T_NAME_FULLY_QUALIFIED) reduce 155) ((T_NAME_QUALIFIED) reduce 155) ((T_NAME_RELATIVE) reduce 155) ((T_NEW) reduce 155) ((T_NS_C) reduce 155) ((T_OBJECT_CAST) reduce 155) ((T_PRINT) reduce 155) ((T_READONLY) reduce 155) ((T_REQUIRE) reduce 155) ((T_REQUIRE_ONCE) reduce 155) ((T_RETURN) reduce 155) ((T_START_HEREDOC) reduce 155) ((T_STATIC) reduce 155) ((T_STRING) reduce 155) ((T_STRING_CAST) reduce 155) ((T_SWITCH) reduce 155) ((T_THROW) reduce 155) ((T_TRAIT) reduce 155) ((T_TRAIT_C) reduce 155) ((T_TRY) reduce 155) ((T_UNSET) reduce 155) ((T_UNSET_CAST) reduce 155) ((T_VARIABLE) reduce 155) ((T_WHILE) reduce 155) ((T_YIELD) reduce 155) ((T_YIELD_FROM) reduce 155) (("[") reduce 155) (("`") reduce 155) (("{") reduce 155) (("}") reduce 155) (("~") reduce 155)) 23836 ((("!") reduce 162) (("\"") reduce 162) (("$") reduce 162) (("(") reduce 162) (("+") reduce 162) (("-") reduce 162) ((";") reduce 162) (("@") reduce 162) ((T_ABSTRACT) reduce 162) ((T_ARRAY) reduce 162) ((T_ARRAY_CAST) reduce 162) ((T_ATTRIBUTE) reduce 162) ((T_BOOL_CAST) reduce 162) ((T_BREAK) reduce 162) ((T_CASE) reduce 162) ((T_CLASS) reduce 162) ((T_CLASS_C) reduce 162) ((T_CLONE) reduce 162) ((T_CONSTANT_ENCAPSED_STRING) reduce 162) ((T_CONTINUE) reduce 162) ((T_DEC) reduce 162) ((T_DECLARE) reduce 162) ((T_DEFAULT) reduce 162) ((T_DIR) reduce 162) ((T_DNUMBER) reduce 162) ((T_DO) reduce 162) ((T_DOUBLE_CAST) reduce 162) ((T_ECHO) reduce 162) ((T_ELSE) reduce 162) ((T_ELSEIF) reduce 162) ((T_EMPTY) reduce 162) ((T_ENUM) reduce 162) ((T_EVAL) reduce 162) ((T_EXIT) reduce 162) ((T_FILE) reduce 162) ((T_FINAL) reduce 162) ((T_FN) reduce 162) ((T_FOR) reduce 162) ((T_FOREACH) reduce 162) ((T_FUNCTION) reduce 162) ((T_FUNC_C) reduce 162) ((T_GLOBAL) reduce 162) ((T_GOTO) reduce 162) ((T_HALT_COMPILER) reduce 162) ((T_IF) reduce 162) ((T_INC) reduce 162) ((T_INCLUDE) reduce 162) ((T_INCLUDE_ONCE) reduce 162) ((T_INLINE_HTML) reduce 162) ((T_INTERFACE) reduce 162) ((T_INT_CAST) reduce 162) ((T_ISSET) reduce 162) ((T_LINE) reduce 162) ((T_LIST) reduce 162) ((T_LNUMBER) reduce 162) ((T_MATCH) reduce 162) ((T_METHOD_C) reduce 162) ((T_NAME_FULLY_QUALIFIED) reduce 162) ((T_NAME_QUALIFIED) reduce 162) ((T_NAME_RELATIVE) reduce 162) ((T_NEW) reduce 162) ((T_NS_C) reduce 162) ((T_OBJECT_CAST) reduce 162) ((T_PRINT) reduce 162) ((T_READONLY) reduce 162) ((T_REQUIRE) reduce 162) ((T_REQUIRE_ONCE) reduce 162) ((T_RETURN) reduce 162) ((T_START_HEREDOC) reduce 162) ((T_STATIC) reduce 162) ((T_STRING) reduce 162) ((T_STRING_CAST) reduce 162) ((T_SWITCH) reduce 162) ((T_THROW) reduce 162) ((T_TRAIT) reduce 162) ((T_TRAIT_C) reduce 162) ((T_TRY) reduce 162) ((T_UNSET) reduce 162) ((T_UNSET_CAST) reduce 162) ((T_VARIABLE) reduce 162) ((T_WHILE) reduce 162) ((T_YIELD) reduce 162) ((T_YIELD_FROM) reduce 162) (("[") reduce 162) (("`") reduce 162) (("{") reduce 162) (("}") reduce 162) (("~") reduce 162)) 23837 ((("!") reduce 217) (("\"") reduce 217) (("$") reduce 217) (("(") reduce 217) (("+") reduce 217) (("-") reduce 217) ((";") reduce 217) (("@") reduce 217) ((T_ABSTRACT) reduce 217) ((T_ARRAY) reduce 217) ((T_ARRAY_CAST) reduce 217) ((T_ATTRIBUTE) reduce 217) ((T_BOOL_CAST) reduce 217) ((T_BREAK) reduce 217) ((T_CASE) reduce 217) ((T_CLASS) reduce 217) ((T_CLASS_C) reduce 217) ((T_CLONE) reduce 217) ((T_CONSTANT_ENCAPSED_STRING) reduce 217) ((T_CONTINUE) reduce 217) ((T_DEC) reduce 217) ((T_DECLARE) reduce 217) ((T_DEFAULT) reduce 217) ((T_DIR) reduce 217) ((T_DNUMBER) reduce 217) ((T_DO) reduce 217) ((T_DOUBLE_CAST) reduce 217) ((T_ECHO) reduce 217) ((T_ELSE) reduce 217) ((T_ELSEIF) reduce 217) ((T_EMPTY) reduce 217) ((T_ENUM) reduce 217) ((T_EVAL) reduce 217) ((T_EXIT) reduce 217) ((T_FILE) reduce 217) ((T_FINAL) reduce 217) ((T_FN) reduce 217) ((T_FOR) reduce 217) ((T_FOREACH) reduce 217) ((T_FUNCTION) reduce 217) ((T_FUNC_C) reduce 217) ((T_GLOBAL) reduce 217) ((T_GOTO) reduce 217) ((T_HALT_COMPILER) reduce 217) ((T_IF) reduce 217) ((T_INC) reduce 217) ((T_INCLUDE) reduce 217) ((T_INCLUDE_ONCE) reduce 217) ((T_INLINE_HTML) reduce 217) ((T_INTERFACE) reduce 217) ((T_INT_CAST) reduce 217) ((T_ISSET) reduce 217) ((T_LINE) reduce 217) ((T_LIST) reduce 217) ((T_LNUMBER) reduce 217) ((T_MATCH) reduce 217) ((T_METHOD_C) reduce 217) ((T_NAME_FULLY_QUALIFIED) reduce 217) ((T_NAME_QUALIFIED) reduce 217) ((T_NAME_RELATIVE) reduce 217) ((T_NEW) reduce 217) ((T_NS_C) reduce 217) ((T_OBJECT_CAST) reduce 217) ((T_PRINT) reduce 217) ((T_READONLY) reduce 217) ((T_REQUIRE) reduce 217) ((T_REQUIRE_ONCE) reduce 217) ((T_RETURN) reduce 217) ((T_START_HEREDOC) reduce 217) ((T_STATIC) reduce 217) ((T_STRING) reduce 217) ((T_STRING_CAST) reduce 217) ((T_SWITCH) reduce 217) ((T_THROW) reduce 217) ((T_TRAIT) reduce 217) ((T_TRAIT_C) reduce 217) ((T_TRY) reduce 217) ((T_UNSET) reduce 217) ((T_UNSET_CAST) reduce 217) ((T_VARIABLE) reduce 217) ((T_WHILE) reduce 217) ((T_YIELD) reduce 217) ((T_YIELD_FROM) reduce 217) (("[") reduce 217) (("`") reduce 217) (("{") reduce 217) (("}") reduce 217) (("~") reduce 217)) 23840 ((("!") reduce 218) (("\"") reduce 218) (("$") reduce 218) (("(") reduce 218) (("+") reduce 218) (("-") reduce 218) ((";") reduce 218) (("@") reduce 218) ((T_ABSTRACT) reduce 218) ((T_ARRAY) reduce 218) ((T_ARRAY_CAST) reduce 218) ((T_ATTRIBUTE) reduce 218) ((T_BOOL_CAST) reduce 218) ((T_BREAK) reduce 218) ((T_CASE) reduce 218) ((T_CLASS) reduce 218) ((T_CLASS_C) reduce 218) ((T_CLONE) reduce 218) ((T_CONSTANT_ENCAPSED_STRING) reduce 218) ((T_CONTINUE) reduce 218) ((T_DEC) reduce 218) ((T_DECLARE) reduce 218) ((T_DEFAULT) reduce 218) ((T_DIR) reduce 218) ((T_DNUMBER) reduce 218) ((T_DO) reduce 218) ((T_DOUBLE_CAST) reduce 218) ((T_ECHO) reduce 218) ((T_ELSE) reduce 218) ((T_ELSEIF) reduce 218) ((T_EMPTY) reduce 218) ((T_ENUM) reduce 218) ((T_EVAL) reduce 218) ((T_EXIT) reduce 218) ((T_FILE) reduce 218) ((T_FINAL) reduce 218) ((T_FN) reduce 218) ((T_FOR) reduce 218) ((T_FOREACH) reduce 218) ((T_FUNCTION) reduce 218) ((T_FUNC_C) reduce 218) ((T_GLOBAL) reduce 218) ((T_GOTO) reduce 218) ((T_HALT_COMPILER) reduce 218) ((T_IF) reduce 218) ((T_INC) reduce 218) ((T_INCLUDE) reduce 218) ((T_INCLUDE_ONCE) reduce 218) ((T_INLINE_HTML) reduce 218) ((T_INTERFACE) reduce 218) ((T_INT_CAST) reduce 218) ((T_ISSET) reduce 218) ((T_LINE) reduce 218) ((T_LIST) reduce 218) ((T_LNUMBER) reduce 218) ((T_MATCH) reduce 218) ((T_METHOD_C) reduce 218) ((T_NAME_FULLY_QUALIFIED) reduce 218) ((T_NAME_QUALIFIED) reduce 218) ((T_NAME_RELATIVE) reduce 218) ((T_NEW) reduce 218) ((T_NS_C) reduce 218) ((T_OBJECT_CAST) reduce 218) ((T_PRINT) reduce 218) ((T_READONLY) reduce 218) ((T_REQUIRE) reduce 218) ((T_REQUIRE_ONCE) reduce 218) ((T_RETURN) reduce 218) ((T_START_HEREDOC) reduce 218) ((T_STATIC) reduce 218) ((T_STRING) reduce 218) ((T_STRING_CAST) reduce 218) ((T_SWITCH) reduce 218) ((T_THROW) reduce 218) ((T_TRAIT) reduce 218) ((T_TRAIT_C) reduce 218) ((T_TRY) reduce 218) ((T_UNSET) reduce 218) ((T_UNSET_CAST) reduce 218) ((T_VARIABLE) reduce 218) ((T_WHILE) reduce 218) ((T_YIELD) reduce 218) ((T_YIELD_FROM) reduce 218) (("[") reduce 218) (("`") reduce 218) (("{") reduce 218) (("}") reduce 218) (("~") reduce 218)) 23841 ((("!") reduce 161) (("\"") reduce 161) (("$") reduce 161) (("(") reduce 161) (("+") reduce 161) (("-") reduce 161) ((";") reduce 161) (("@") reduce 161) ((T_ABSTRACT) reduce 161) ((T_ARRAY) reduce 161) ((T_ARRAY_CAST) reduce 161) ((T_ATTRIBUTE) reduce 161) ((T_BOOL_CAST) reduce 161) ((T_BREAK) reduce 161) ((T_CASE) reduce 161) ((T_CLASS) reduce 161) ((T_CLASS_C) reduce 161) ((T_CLONE) reduce 161) ((T_CONSTANT_ENCAPSED_STRING) reduce 161) ((T_CONTINUE) reduce 161) ((T_DEC) reduce 161) ((T_DECLARE) reduce 161) ((T_DEFAULT) reduce 161) ((T_DIR) reduce 161) ((T_DNUMBER) reduce 161) ((T_DO) reduce 161) ((T_DOUBLE_CAST) reduce 161) ((T_ECHO) reduce 161) ((T_ELSE) reduce 161) ((T_ELSEIF) reduce 161) ((T_EMPTY) reduce 161) ((T_ENUM) reduce 161) ((T_EVAL) reduce 161) ((T_EXIT) reduce 161) ((T_FILE) reduce 161) ((T_FINAL) reduce 161) ((T_FN) reduce 161) ((T_FOR) reduce 161) ((T_FOREACH) reduce 161) ((T_FUNCTION) reduce 161) ((T_FUNC_C) reduce 161) ((T_GLOBAL) reduce 161) ((T_GOTO) reduce 161) ((T_HALT_COMPILER) reduce 161) ((T_IF) reduce 161) ((T_INC) reduce 161) ((T_INCLUDE) reduce 161) ((T_INCLUDE_ONCE) reduce 161) ((T_INLINE_HTML) reduce 161) ((T_INTERFACE) reduce 161) ((T_INT_CAST) reduce 161) ((T_ISSET) reduce 161) ((T_LINE) reduce 161) ((T_LIST) reduce 161) ((T_LNUMBER) reduce 161) ((T_MATCH) reduce 161) ((T_METHOD_C) reduce 161) ((T_NAME_FULLY_QUALIFIED) reduce 161) ((T_NAME_QUALIFIED) reduce 161) ((T_NAME_RELATIVE) reduce 161) ((T_NEW) reduce 161) ((T_NS_C) reduce 161) ((T_OBJECT_CAST) reduce 161) ((T_PRINT) reduce 161) ((T_READONLY) reduce 161) ((T_REQUIRE) reduce 161) ((T_REQUIRE_ONCE) reduce 161) ((T_RETURN) reduce 161) ((T_START_HEREDOC) reduce 161) ((T_STATIC) reduce 161) ((T_STRING) reduce 161) ((T_STRING_CAST) reduce 161) ((T_SWITCH) reduce 161) ((T_THROW) reduce 161) ((T_TRAIT) reduce 161) ((T_TRAIT_C) reduce 161) ((T_TRY) reduce 161) ((T_UNSET) reduce 161) ((T_UNSET_CAST) reduce 161) ((T_VARIABLE) reduce 161) ((T_WHILE) reduce 161) ((T_YIELD) reduce 161) ((T_YIELD_FROM) reduce 161) (("[") reduce 161) (("`") reduce 161) (("{") reduce 161) (("}") reduce 161) (("~") reduce 161)) 23850 ((("!") reduce 150) (("\"") reduce 150) (("$") reduce 150) (("(") reduce 150) (("+") reduce 150) (("-") reduce 150) ((";") reduce 150) (("@") reduce 150) ((T_ABSTRACT) reduce 150) ((T_ARRAY) reduce 150) ((T_ARRAY_CAST) reduce 150) ((T_ATTRIBUTE) reduce 150) ((T_BOOL_CAST) reduce 150) ((T_BREAK) reduce 150) ((T_CASE) reduce 150) ((T_CLASS) reduce 150) ((T_CLASS_C) reduce 150) ((T_CLONE) reduce 150) ((T_CONSTANT_ENCAPSED_STRING) reduce 150) ((T_CONTINUE) reduce 150) ((T_DEC) reduce 150) ((T_DECLARE) reduce 150) ((T_DEFAULT) reduce 150) ((T_DIR) reduce 150) ((T_DNUMBER) reduce 150) ((T_DO) reduce 150) ((T_DOUBLE_CAST) reduce 150) ((T_ECHO) reduce 150) ((T_ELSE) reduce 150) ((T_ELSEIF) reduce 150) ((T_EMPTY) reduce 150) ((T_ENUM) reduce 150) ((T_EVAL) reduce 150) ((T_EXIT) reduce 150) ((T_FILE) reduce 150) ((T_FINAL) reduce 150) ((T_FN) reduce 150) ((T_FOR) reduce 150) ((T_FOREACH) reduce 150) ((T_FUNCTION) reduce 150) ((T_FUNC_C) reduce 150) ((T_GLOBAL) reduce 150) ((T_GOTO) reduce 150) ((T_HALT_COMPILER) reduce 150) ((T_IF) reduce 150) ((T_INC) reduce 150) ((T_INCLUDE) reduce 150) ((T_INCLUDE_ONCE) reduce 150) ((T_INLINE_HTML) reduce 150) ((T_INTERFACE) reduce 150) ((T_INT_CAST) reduce 150) ((T_ISSET) reduce 150) ((T_LINE) reduce 150) ((T_LIST) reduce 150) ((T_LNUMBER) reduce 150) ((T_MATCH) reduce 150) ((T_METHOD_C) reduce 150) ((T_NAME_FULLY_QUALIFIED) reduce 150) ((T_NAME_QUALIFIED) reduce 150) ((T_NAME_RELATIVE) reduce 150) ((T_NEW) reduce 150) ((T_NS_C) reduce 150) ((T_OBJECT_CAST) reduce 150) ((T_PRINT) reduce 150) ((T_READONLY) reduce 150) ((T_REQUIRE) reduce 150) ((T_REQUIRE_ONCE) reduce 150) ((T_RETURN) reduce 150) ((T_START_HEREDOC) reduce 150) ((T_STATIC) reduce 150) ((T_STRING) reduce 150) ((T_STRING_CAST) reduce 150) ((T_SWITCH) reduce 150) ((T_THROW) reduce 150) ((T_TRAIT) reduce 150) ((T_TRAIT_C) reduce 150) ((T_TRY) reduce 150) ((T_UNSET) reduce 150) ((T_UNSET_CAST) reduce 150) ((T_VARIABLE) reduce 150) ((T_WHILE) reduce 150) ((T_YIELD) reduce 150) ((T_YIELD_FROM) reduce 150) (("[") reduce 150) (("`") reduce 150) (("{") reduce 150) (("}") reduce 150) (("~") reduce 150)) 23851 ((("!") reduce 215) (("\"") reduce 215) (("$") reduce 215) (("(") reduce 215) (("+") reduce 215) (("-") reduce 215) ((";") reduce 215) (("@") reduce 215) ((T_ABSTRACT) reduce 215) ((T_ARRAY) reduce 215) ((T_ARRAY_CAST) reduce 215) ((T_ATTRIBUTE) reduce 215) ((T_BOOL_CAST) reduce 215) ((T_BREAK) reduce 215) ((T_CASE) reduce 215) ((T_CLASS) reduce 215) ((T_CLASS_C) reduce 215) ((T_CLONE) reduce 215) ((T_CONSTANT_ENCAPSED_STRING) reduce 215) ((T_CONTINUE) reduce 215) ((T_DEC) reduce 215) ((T_DECLARE) reduce 215) ((T_DEFAULT) reduce 215) ((T_DIR) reduce 215) ((T_DNUMBER) reduce 215) ((T_DO) reduce 215) ((T_DOUBLE_CAST) reduce 215) ((T_ECHO) reduce 215) ((T_ELSE) reduce 215) ((T_ELSEIF) reduce 215) ((T_EMPTY) reduce 215) ((T_ENUM) reduce 215) ((T_EVAL) reduce 215) ((T_EXIT) reduce 215) ((T_FILE) reduce 215) ((T_FINAL) reduce 215) ((T_FN) reduce 215) ((T_FOR) reduce 215) ((T_FOREACH) reduce 215) ((T_FUNCTION) reduce 215) ((T_FUNC_C) reduce 215) ((T_GLOBAL) reduce 215) ((T_GOTO) reduce 215) ((T_HALT_COMPILER) reduce 215) ((T_IF) reduce 215) ((T_INC) reduce 215) ((T_INCLUDE) reduce 215) ((T_INCLUDE_ONCE) reduce 215) ((T_INLINE_HTML) reduce 215) ((T_INTERFACE) reduce 215) ((T_INT_CAST) reduce 215) ((T_ISSET) reduce 215) ((T_LINE) reduce 215) ((T_LIST) reduce 215) ((T_LNUMBER) reduce 215) ((T_MATCH) reduce 215) ((T_METHOD_C) reduce 215) ((T_NAME_FULLY_QUALIFIED) reduce 215) ((T_NAME_QUALIFIED) reduce 215) ((T_NAME_RELATIVE) reduce 215) ((T_NEW) reduce 215) ((T_NS_C) reduce 215) ((T_OBJECT_CAST) reduce 215) ((T_PRINT) reduce 215) ((T_READONLY) reduce 215) ((T_REQUIRE) reduce 215) ((T_REQUIRE_ONCE) reduce 215) ((T_RETURN) reduce 215) ((T_START_HEREDOC) reduce 215) ((T_STATIC) reduce 215) ((T_STRING) reduce 215) ((T_STRING_CAST) reduce 215) ((T_SWITCH) reduce 215) ((T_THROW) reduce 215) ((T_TRAIT) reduce 215) ((T_TRAIT_C) reduce 215) ((T_TRY) reduce 215) ((T_UNSET) reduce 215) ((T_UNSET_CAST) reduce 215) ((T_VARIABLE) reduce 215) ((T_WHILE) reduce 215) ((T_YIELD) reduce 215) ((T_YIELD_FROM) reduce 215) (("[") reduce 215) (("`") reduce 215) (("{") reduce 215) (("}") reduce 215) (("~") reduce 215)) 23854 ((("!") reduce 216) (("\"") reduce 216) (("$") reduce 216) (("(") reduce 216) (("+") reduce 216) (("-") reduce 216) ((";") reduce 216) (("@") reduce 216) ((T_ABSTRACT) reduce 216) ((T_ARRAY) reduce 216) ((T_ARRAY_CAST) reduce 216) ((T_ATTRIBUTE) reduce 216) ((T_BOOL_CAST) reduce 216) ((T_BREAK) reduce 216) ((T_CASE) reduce 216) ((T_CLASS) reduce 216) ((T_CLASS_C) reduce 216) ((T_CLONE) reduce 216) ((T_CONSTANT_ENCAPSED_STRING) reduce 216) ((T_CONTINUE) reduce 216) ((T_DEC) reduce 216) ((T_DECLARE) reduce 216) ((T_DEFAULT) reduce 216) ((T_DIR) reduce 216) ((T_DNUMBER) reduce 216) ((T_DO) reduce 216) ((T_DOUBLE_CAST) reduce 216) ((T_ECHO) reduce 216) ((T_ELSE) reduce 216) ((T_ELSEIF) reduce 216) ((T_EMPTY) reduce 216) ((T_ENUM) reduce 216) ((T_EVAL) reduce 216) ((T_EXIT) reduce 216) ((T_FILE) reduce 216) ((T_FINAL) reduce 216) ((T_FN) reduce 216) ((T_FOR) reduce 216) ((T_FOREACH) reduce 216) ((T_FUNCTION) reduce 216) ((T_FUNC_C) reduce 216) ((T_GLOBAL) reduce 216) ((T_GOTO) reduce 216) ((T_HALT_COMPILER) reduce 216) ((T_IF) reduce 216) ((T_INC) reduce 216) ((T_INCLUDE) reduce 216) ((T_INCLUDE_ONCE) reduce 216) ((T_INLINE_HTML) reduce 216) ((T_INTERFACE) reduce 216) ((T_INT_CAST) reduce 216) ((T_ISSET) reduce 216) ((T_LINE) reduce 216) ((T_LIST) reduce 216) ((T_LNUMBER) reduce 216) ((T_MATCH) reduce 216) ((T_METHOD_C) reduce 216) ((T_NAME_FULLY_QUALIFIED) reduce 216) ((T_NAME_QUALIFIED) reduce 216) ((T_NAME_RELATIVE) reduce 216) ((T_NEW) reduce 216) ((T_NS_C) reduce 216) ((T_OBJECT_CAST) reduce 216) ((T_PRINT) reduce 216) ((T_READONLY) reduce 216) ((T_REQUIRE) reduce 216) ((T_REQUIRE_ONCE) reduce 216) ((T_RETURN) reduce 216) ((T_START_HEREDOC) reduce 216) ((T_STATIC) reduce 216) ((T_STRING) reduce 216) ((T_STRING_CAST) reduce 216) ((T_SWITCH) reduce 216) ((T_THROW) reduce 216) ((T_TRAIT) reduce 216) ((T_TRAIT_C) reduce 216) ((T_TRY) reduce 216) ((T_UNSET) reduce 216) ((T_UNSET_CAST) reduce 216) ((T_VARIABLE) reduce 216) ((T_WHILE) reduce 216) ((T_YIELD) reduce 216) ((T_YIELD_FROM) reduce 216) (("[") reduce 216) (("`") reduce 216) (("{") reduce 216) (("}") reduce 216) (("~") reduce 216)) 23856 ((("!") reduce 157) (("\"") reduce 157) (("$") reduce 157) (("(") reduce 157) (("+") reduce 157) (("-") reduce 157) ((";") reduce 157) (("@") reduce 157) ((T_ABSTRACT) reduce 157) ((T_ARRAY) reduce 157) ((T_ARRAY_CAST) reduce 157) ((T_ATTRIBUTE) reduce 157) ((T_BOOL_CAST) reduce 157) ((T_BREAK) reduce 157) ((T_CASE) reduce 157) ((T_CLASS) reduce 157) ((T_CLASS_C) reduce 157) ((T_CLONE) reduce 157) ((T_CONSTANT_ENCAPSED_STRING) reduce 157) ((T_CONTINUE) reduce 157) ((T_DEC) reduce 157) ((T_DECLARE) reduce 157) ((T_DEFAULT) reduce 157) ((T_DIR) reduce 157) ((T_DNUMBER) reduce 157) ((T_DO) reduce 157) ((T_DOUBLE_CAST) reduce 157) ((T_ECHO) reduce 157) ((T_ELSE) reduce 157) ((T_ELSEIF) reduce 157) ((T_EMPTY) reduce 157) ((T_ENUM) reduce 157) ((T_EVAL) reduce 157) ((T_EXIT) reduce 157) ((T_FILE) reduce 157) ((T_FINAL) reduce 157) ((T_FN) reduce 157) ((T_FOR) reduce 157) ((T_FOREACH) reduce 157) ((T_FUNCTION) reduce 157) ((T_FUNC_C) reduce 157) ((T_GLOBAL) reduce 157) ((T_GOTO) reduce 157) ((T_HALT_COMPILER) reduce 157) ((T_IF) reduce 157) ((T_INC) reduce 157) ((T_INCLUDE) reduce 157) ((T_INCLUDE_ONCE) reduce 157) ((T_INLINE_HTML) reduce 157) ((T_INTERFACE) reduce 157) ((T_INT_CAST) reduce 157) ((T_ISSET) reduce 157) ((T_LINE) reduce 157) ((T_LIST) reduce 157) ((T_LNUMBER) reduce 157) ((T_MATCH) reduce 157) ((T_METHOD_C) reduce 157) ((T_NAME_FULLY_QUALIFIED) reduce 157) ((T_NAME_QUALIFIED) reduce 157) ((T_NAME_RELATIVE) reduce 157) ((T_NEW) reduce 157) ((T_NS_C) reduce 157) ((T_OBJECT_CAST) reduce 157) ((T_PRINT) reduce 157) ((T_READONLY) reduce 157) ((T_REQUIRE) reduce 157) ((T_REQUIRE_ONCE) reduce 157) ((T_RETURN) reduce 157) ((T_START_HEREDOC) reduce 157) ((T_STATIC) reduce 157) ((T_STRING) reduce 157) ((T_STRING_CAST) reduce 157) ((T_SWITCH) reduce 157) ((T_THROW) reduce 157) ((T_TRAIT) reduce 157) ((T_TRAIT_C) reduce 157) ((T_TRY) reduce 157) ((T_UNSET) reduce 157) ((T_UNSET_CAST) reduce 157) ((T_VARIABLE) reduce 157) ((T_WHILE) reduce 157) ((T_YIELD) reduce 157) ((T_YIELD_FROM) reduce 157) (("[") reduce 157) (("`") reduce 157) (("{") reduce 157) (("}") reduce 157) (("~") reduce 157)) 23862 ((("!") reduce 149) (("\"") reduce 149) (("$") reduce 149) (("(") reduce 149) (("+") reduce 149) (("-") reduce 149) ((";") reduce 149) (("@") reduce 149) ((T_ABSTRACT) reduce 149) ((T_ARRAY) reduce 149) ((T_ARRAY_CAST) reduce 149) ((T_ATTRIBUTE) reduce 149) ((T_BOOL_CAST) reduce 149) ((T_BREAK) reduce 149) ((T_CASE) reduce 149) ((T_CLASS) reduce 149) ((T_CLASS_C) reduce 149) ((T_CLONE) reduce 149) ((T_CONSTANT_ENCAPSED_STRING) reduce 149) ((T_CONTINUE) reduce 149) ((T_DEC) reduce 149) ((T_DECLARE) reduce 149) ((T_DEFAULT) reduce 149) ((T_DIR) reduce 149) ((T_DNUMBER) reduce 149) ((T_DO) reduce 149) ((T_DOUBLE_CAST) reduce 149) ((T_ECHO) reduce 149) ((T_ELSE) reduce 149) ((T_ELSEIF) reduce 149) ((T_EMPTY) reduce 149) ((T_ENUM) reduce 149) ((T_EVAL) reduce 149) ((T_EXIT) reduce 149) ((T_FILE) reduce 149) ((T_FINAL) reduce 149) ((T_FN) reduce 149) ((T_FOR) reduce 149) ((T_FOREACH) reduce 149) ((T_FUNCTION) reduce 149) ((T_FUNC_C) reduce 149) ((T_GLOBAL) reduce 149) ((T_GOTO) reduce 149) ((T_HALT_COMPILER) reduce 149) ((T_IF) reduce 149) ((T_INC) reduce 149) ((T_INCLUDE) reduce 149) ((T_INCLUDE_ONCE) reduce 149) ((T_INLINE_HTML) reduce 149) ((T_INTERFACE) reduce 149) ((T_INT_CAST) reduce 149) ((T_ISSET) reduce 149) ((T_LINE) reduce 149) ((T_LIST) reduce 149) ((T_LNUMBER) reduce 149) ((T_MATCH) reduce 149) ((T_METHOD_C) reduce 149) ((T_NAME_FULLY_QUALIFIED) reduce 149) ((T_NAME_QUALIFIED) reduce 149) ((T_NAME_RELATIVE) reduce 149) ((T_NEW) reduce 149) ((T_NS_C) reduce 149) ((T_OBJECT_CAST) reduce 149) ((T_PRINT) reduce 149) ((T_READONLY) reduce 149) ((T_REQUIRE) reduce 149) ((T_REQUIRE_ONCE) reduce 149) ((T_RETURN) reduce 149) ((T_START_HEREDOC) reduce 149) ((T_STATIC) reduce 149) ((T_STRING) reduce 149) ((T_STRING_CAST) reduce 149) ((T_SWITCH) reduce 149) ((T_THROW) reduce 149) ((T_TRAIT) reduce 149) ((T_TRAIT_C) reduce 149) ((T_TRY) reduce 149) ((T_UNSET) reduce 149) ((T_UNSET_CAST) reduce 149) ((T_VARIABLE) reduce 149) ((T_WHILE) reduce 149) ((T_YIELD) reduce 149) ((T_YIELD_FROM) reduce 149) (("[") reduce 149) (("`") reduce 149) (("{") reduce 149) (("}") reduce 149) (("~") reduce 149)) 23867 ((("!") reduce 163) (("\"") reduce 163) (("$") reduce 163) (("(") reduce 163) (("+") reduce 163) (("-") reduce 163) ((";") reduce 163) (("@") reduce 163) ((T_ABSTRACT) reduce 163) ((T_ARRAY) reduce 163) ((T_ARRAY_CAST) reduce 163) ((T_ATTRIBUTE) reduce 163) ((T_BOOL_CAST) reduce 163) ((T_BREAK) reduce 163) ((T_CASE) reduce 163) ((T_CLASS) reduce 163) ((T_CLASS_C) reduce 163) ((T_CLONE) reduce 163) ((T_CONSTANT_ENCAPSED_STRING) reduce 163) ((T_CONTINUE) reduce 163) ((T_DEC) reduce 163) ((T_DECLARE) reduce 163) ((T_DEFAULT) reduce 163) ((T_DIR) reduce 163) ((T_DNUMBER) reduce 163) ((T_DO) reduce 163) ((T_DOUBLE_CAST) reduce 163) ((T_ECHO) reduce 163) ((T_ELSE) reduce 163) ((T_ELSEIF) reduce 163) ((T_EMPTY) reduce 163) ((T_ENUM) reduce 163) ((T_EVAL) reduce 163) ((T_EXIT) reduce 163) ((T_FILE) reduce 163) ((T_FINAL) reduce 163) ((T_FN) reduce 163) ((T_FOR) reduce 163) ((T_FOREACH) reduce 163) ((T_FUNCTION) reduce 163) ((T_FUNC_C) reduce 163) ((T_GLOBAL) reduce 163) ((T_GOTO) reduce 163) ((T_HALT_COMPILER) reduce 163) ((T_IF) reduce 163) ((T_INC) reduce 163) ((T_INCLUDE) reduce 163) ((T_INCLUDE_ONCE) reduce 163) ((T_INLINE_HTML) reduce 163) ((T_INTERFACE) reduce 163) ((T_INT_CAST) reduce 163) ((T_ISSET) reduce 163) ((T_LINE) reduce 163) ((T_LIST) reduce 163) ((T_LNUMBER) reduce 163) ((T_MATCH) reduce 163) ((T_METHOD_C) reduce 163) ((T_NAME_FULLY_QUALIFIED) reduce 163) ((T_NAME_QUALIFIED) reduce 163) ((T_NAME_RELATIVE) reduce 163) ((T_NEW) reduce 163) ((T_NS_C) reduce 163) ((T_OBJECT_CAST) reduce 163) ((T_PRINT) reduce 163) ((T_READONLY) reduce 163) ((T_REQUIRE) reduce 163) ((T_REQUIRE_ONCE) reduce 163) ((T_RETURN) reduce 163) ((T_START_HEREDOC) reduce 163) ((T_STATIC) reduce 163) ((T_STRING) reduce 163) ((T_STRING_CAST) reduce 163) ((T_SWITCH) reduce 163) ((T_THROW) reduce 163) ((T_TRAIT) reduce 163) ((T_TRAIT_C) reduce 163) ((T_TRY) reduce 163) ((T_UNSET) reduce 163) ((T_UNSET_CAST) reduce 163) ((T_VARIABLE) reduce 163) ((T_WHILE) reduce 163) ((T_YIELD) reduce 163) ((T_YIELD_FROM) reduce 163) (("[") reduce 163) (("`") reduce 163) (("{") reduce 163) (("}") reduce 163) (("~") reduce 163)) 23868 ((("!") reduce 219) (("\"") reduce 219) (("$") reduce 219) (("(") reduce 219) (("+") reduce 219) (("-") reduce 219) ((";") reduce 219) (("@") reduce 219) ((T_ABSTRACT) reduce 219) ((T_ARRAY) reduce 219) ((T_ARRAY_CAST) reduce 219) ((T_ATTRIBUTE) reduce 219) ((T_BOOL_CAST) reduce 219) ((T_BREAK) reduce 219) ((T_CASE) reduce 219) ((T_CLASS) reduce 219) ((T_CLASS_C) reduce 219) ((T_CLONE) reduce 219) ((T_CONSTANT_ENCAPSED_STRING) reduce 219) ((T_CONTINUE) reduce 219) ((T_DEC) reduce 219) ((T_DECLARE) reduce 219) ((T_DEFAULT) reduce 219) ((T_DIR) reduce 219) ((T_DNUMBER) reduce 219) ((T_DO) reduce 219) ((T_DOUBLE_CAST) reduce 219) ((T_ECHO) reduce 219) ((T_ELSE) reduce 219) ((T_ELSEIF) reduce 219) ((T_EMPTY) reduce 219) ((T_ENUM) reduce 219) ((T_EVAL) reduce 219) ((T_EXIT) reduce 219) ((T_FILE) reduce 219) ((T_FINAL) reduce 219) ((T_FN) reduce 219) ((T_FOR) reduce 219) ((T_FOREACH) reduce 219) ((T_FUNCTION) reduce 219) ((T_FUNC_C) reduce 219) ((T_GLOBAL) reduce 219) ((T_GOTO) reduce 219) ((T_HALT_COMPILER) reduce 219) ((T_IF) reduce 219) ((T_INC) reduce 219) ((T_INCLUDE) reduce 219) ((T_INCLUDE_ONCE) reduce 219) ((T_INLINE_HTML) reduce 219) ((T_INTERFACE) reduce 219) ((T_INT_CAST) reduce 219) ((T_ISSET) reduce 219) ((T_LINE) reduce 219) ((T_LIST) reduce 219) ((T_LNUMBER) reduce 219) ((T_MATCH) reduce 219) ((T_METHOD_C) reduce 219) ((T_NAME_FULLY_QUALIFIED) reduce 219) ((T_NAME_QUALIFIED) reduce 219) ((T_NAME_RELATIVE) reduce 219) ((T_NEW) reduce 219) ((T_NS_C) reduce 219) ((T_OBJECT_CAST) reduce 219) ((T_PRINT) reduce 219) ((T_READONLY) reduce 219) ((T_REQUIRE) reduce 219) ((T_REQUIRE_ONCE) reduce 219) ((T_RETURN) reduce 219) ((T_START_HEREDOC) reduce 219) ((T_STATIC) reduce 219) ((T_STRING) reduce 219) ((T_STRING_CAST) reduce 219) ((T_SWITCH) reduce 219) ((T_THROW) reduce 219) ((T_TRAIT) reduce 219) ((T_TRAIT_C) reduce 219) ((T_TRY) reduce 219) ((T_UNSET) reduce 219) ((T_UNSET_CAST) reduce 219) ((T_VARIABLE) reduce 219) ((T_WHILE) reduce 219) ((T_YIELD) reduce 219) ((T_YIELD_FROM) reduce 219) (("[") reduce 219) (("`") reduce 219) (("{") reduce 219) (("}") reduce 219) (("~") reduce 219)) 23871 ((("!") reduce 220) (("\"") reduce 220) (("$") reduce 220) (("(") reduce 220) (("+") reduce 220) (("-") reduce 220) ((";") reduce 220) (("@") reduce 220) ((T_ABSTRACT) reduce 220) ((T_ARRAY) reduce 220) ((T_ARRAY_CAST) reduce 220) ((T_ATTRIBUTE) reduce 220) ((T_BOOL_CAST) reduce 220) ((T_BREAK) reduce 220) ((T_CASE) reduce 220) ((T_CLASS) reduce 220) ((T_CLASS_C) reduce 220) ((T_CLONE) reduce 220) ((T_CONSTANT_ENCAPSED_STRING) reduce 220) ((T_CONTINUE) reduce 220) ((T_DEC) reduce 220) ((T_DECLARE) reduce 220) ((T_DEFAULT) reduce 220) ((T_DIR) reduce 220) ((T_DNUMBER) reduce 220) ((T_DO) reduce 220) ((T_DOUBLE_CAST) reduce 220) ((T_ECHO) reduce 220) ((T_ELSE) reduce 220) ((T_ELSEIF) reduce 220) ((T_EMPTY) reduce 220) ((T_ENUM) reduce 220) ((T_EVAL) reduce 220) ((T_EXIT) reduce 220) ((T_FILE) reduce 220) ((T_FINAL) reduce 220) ((T_FN) reduce 220) ((T_FOR) reduce 220) ((T_FOREACH) reduce 220) ((T_FUNCTION) reduce 220) ((T_FUNC_C) reduce 220) ((T_GLOBAL) reduce 220) ((T_GOTO) reduce 220) ((T_HALT_COMPILER) reduce 220) ((T_IF) reduce 220) ((T_INC) reduce 220) ((T_INCLUDE) reduce 220) ((T_INCLUDE_ONCE) reduce 220) ((T_INLINE_HTML) reduce 220) ((T_INTERFACE) reduce 220) ((T_INT_CAST) reduce 220) ((T_ISSET) reduce 220) ((T_LINE) reduce 220) ((T_LIST) reduce 220) ((T_LNUMBER) reduce 220) ((T_MATCH) reduce 220) ((T_METHOD_C) reduce 220) ((T_NAME_FULLY_QUALIFIED) reduce 220) ((T_NAME_QUALIFIED) reduce 220) ((T_NAME_RELATIVE) reduce 220) ((T_NEW) reduce 220) ((T_NS_C) reduce 220) ((T_OBJECT_CAST) reduce 220) ((T_PRINT) reduce 220) ((T_READONLY) reduce 220) ((T_REQUIRE) reduce 220) ((T_REQUIRE_ONCE) reduce 220) ((T_RETURN) reduce 220) ((T_START_HEREDOC) reduce 220) ((T_STATIC) reduce 220) ((T_STRING) reduce 220) ((T_STRING_CAST) reduce 220) ((T_SWITCH) reduce 220) ((T_THROW) reduce 220) ((T_TRAIT) reduce 220) ((T_TRAIT_C) reduce 220) ((T_TRY) reduce 220) ((T_UNSET) reduce 220) ((T_UNSET_CAST) reduce 220) ((T_VARIABLE) reduce 220) ((T_WHILE) reduce 220) ((T_YIELD) reduce 220) ((T_YIELD_FROM) reduce 220) (("[") reduce 220) (("`") reduce 220) (("{") reduce 220) (("}") reduce 220) (("~") reduce 220)) 23873 ((("!") reduce 153) (("\"") reduce 153) (("$") reduce 153) (("(") reduce 153) (("+") reduce 153) (("-") reduce 153) ((";") reduce 153) (("@") reduce 153) ((T_ABSTRACT) reduce 153) ((T_ARRAY) reduce 153) ((T_ARRAY_CAST) reduce 153) ((T_ATTRIBUTE) reduce 153) ((T_BOOL_CAST) reduce 153) ((T_BREAK) reduce 153) ((T_CASE) reduce 153) ((T_CLASS) reduce 153) ((T_CLASS_C) reduce 153) ((T_CLONE) reduce 153) ((T_CONSTANT_ENCAPSED_STRING) reduce 153) ((T_CONTINUE) reduce 153) ((T_DEC) reduce 153) ((T_DECLARE) reduce 153) ((T_DEFAULT) reduce 153) ((T_DIR) reduce 153) ((T_DNUMBER) reduce 153) ((T_DO) reduce 153) ((T_DOUBLE_CAST) reduce 153) ((T_ECHO) reduce 153) ((T_ELSE) reduce 153) ((T_ELSEIF) reduce 153) ((T_EMPTY) reduce 153) ((T_ENUM) reduce 153) ((T_EVAL) reduce 153) ((T_EXIT) reduce 153) ((T_FILE) reduce 153) ((T_FINAL) reduce 153) ((T_FN) reduce 153) ((T_FOR) reduce 153) ((T_FOREACH) reduce 153) ((T_FUNCTION) reduce 153) ((T_FUNC_C) reduce 153) ((T_GLOBAL) reduce 153) ((T_GOTO) reduce 153) ((T_HALT_COMPILER) reduce 153) ((T_IF) reduce 153) ((T_INC) reduce 153) ((T_INCLUDE) reduce 153) ((T_INCLUDE_ONCE) reduce 153) ((T_INLINE_HTML) reduce 153) ((T_INTERFACE) reduce 153) ((T_INT_CAST) reduce 153) ((T_ISSET) reduce 153) ((T_LINE) reduce 153) ((T_LIST) reduce 153) ((T_LNUMBER) reduce 153) ((T_MATCH) reduce 153) ((T_METHOD_C) reduce 153) ((T_NAME_FULLY_QUALIFIED) reduce 153) ((T_NAME_QUALIFIED) reduce 153) ((T_NAME_RELATIVE) reduce 153) ((T_NEW) reduce 153) ((T_NS_C) reduce 153) ((T_OBJECT_CAST) reduce 153) ((T_PRINT) reduce 153) ((T_READONLY) reduce 153) ((T_REQUIRE) reduce 153) ((T_REQUIRE_ONCE) reduce 153) ((T_RETURN) reduce 153) ((T_START_HEREDOC) reduce 153) ((T_STATIC) reduce 153) ((T_STRING) reduce 153) ((T_STRING_CAST) reduce 153) ((T_SWITCH) reduce 153) ((T_THROW) reduce 153) ((T_TRAIT) reduce 153) ((T_TRAIT_C) reduce 153) ((T_TRY) reduce 153) ((T_UNSET) reduce 153) ((T_UNSET_CAST) reduce 153) ((T_VARIABLE) reduce 153) ((T_WHILE) reduce 153) ((T_YIELD) reduce 153) ((T_YIELD_FROM) reduce 153) (("[") reduce 153) (("`") reduce 153) (("{") reduce 153) (("}") reduce 153) (("~") reduce 153)) 23875 ((("!") reduce 152) (("\"") reduce 152) (("$") reduce 152) (("(") reduce 152) (("+") reduce 152) (("-") reduce 152) ((";") reduce 152) (("@") reduce 152) ((T_ABSTRACT) reduce 152) ((T_ARRAY) reduce 152) ((T_ARRAY_CAST) reduce 152) ((T_ATTRIBUTE) reduce 152) ((T_BOOL_CAST) reduce 152) ((T_BREAK) reduce 152) ((T_CASE) reduce 152) ((T_CLASS) reduce 152) ((T_CLASS_C) reduce 152) ((T_CLONE) reduce 152) ((T_CONSTANT_ENCAPSED_STRING) reduce 152) ((T_CONTINUE) reduce 152) ((T_DEC) reduce 152) ((T_DECLARE) reduce 152) ((T_DEFAULT) reduce 152) ((T_DIR) reduce 152) ((T_DNUMBER) reduce 152) ((T_DO) reduce 152) ((T_DOUBLE_CAST) reduce 152) ((T_ECHO) reduce 152) ((T_ELSE) reduce 152) ((T_ELSEIF) reduce 152) ((T_EMPTY) reduce 152) ((T_ENUM) reduce 152) ((T_EVAL) reduce 152) ((T_EXIT) reduce 152) ((T_FILE) reduce 152) ((T_FINAL) reduce 152) ((T_FN) reduce 152) ((T_FOR) reduce 152) ((T_FOREACH) reduce 152) ((T_FUNCTION) reduce 152) ((T_FUNC_C) reduce 152) ((T_GLOBAL) reduce 152) ((T_GOTO) reduce 152) ((T_HALT_COMPILER) reduce 152) ((T_IF) reduce 152) ((T_INC) reduce 152) ((T_INCLUDE) reduce 152) ((T_INCLUDE_ONCE) reduce 152) ((T_INLINE_HTML) reduce 152) ((T_INTERFACE) reduce 152) ((T_INT_CAST) reduce 152) ((T_ISSET) reduce 152) ((T_LINE) reduce 152) ((T_LIST) reduce 152) ((T_LNUMBER) reduce 152) ((T_MATCH) reduce 152) ((T_METHOD_C) reduce 152) ((T_NAME_FULLY_QUALIFIED) reduce 152) ((T_NAME_QUALIFIED) reduce 152) ((T_NAME_RELATIVE) reduce 152) ((T_NEW) reduce 152) ((T_NS_C) reduce 152) ((T_OBJECT_CAST) reduce 152) ((T_PRINT) reduce 152) ((T_READONLY) reduce 152) ((T_REQUIRE) reduce 152) ((T_REQUIRE_ONCE) reduce 152) ((T_RETURN) reduce 152) ((T_START_HEREDOC) reduce 152) ((T_STATIC) reduce 152) ((T_STRING) reduce 152) ((T_STRING_CAST) reduce 152) ((T_SWITCH) reduce 152) ((T_THROW) reduce 152) ((T_TRAIT) reduce 152) ((T_TRAIT_C) reduce 152) ((T_TRY) reduce 152) ((T_UNSET) reduce 152) ((T_UNSET_CAST) reduce 152) ((T_VARIABLE) reduce 152) ((T_WHILE) reduce 152) ((T_YIELD) reduce 152) ((T_YIELD_FROM) reduce 152) (("[") reduce 152) (("`") reduce 152) (("{") reduce 152) (("}") reduce 152) (("~") reduce 152)) 23876 ((("!") reduce 244) (("\"") reduce 244) (("$") reduce 244) (("(") reduce 244) (("+") reduce 244) (("-") reduce 244) ((";") reduce 244) (("@") reduce 244) ((T_ABSTRACT) reduce 244) ((T_ARRAY) reduce 244) ((T_ARRAY_CAST) reduce 244) ((T_ATTRIBUTE) reduce 244) ((T_BOOL_CAST) reduce 244) ((T_BREAK) reduce 244) ((T_CASE) reduce 244) ((T_CLASS) reduce 244) ((T_CLASS_C) reduce 244) ((T_CLONE) reduce 244) ((T_CONSTANT_ENCAPSED_STRING) reduce 244) ((T_CONTINUE) reduce 244) ((T_DEC) reduce 244) ((T_DECLARE) reduce 244) ((T_DEFAULT) reduce 244) ((T_DIR) reduce 244) ((T_DNUMBER) reduce 244) ((T_DO) reduce 244) ((T_DOUBLE_CAST) reduce 244) ((T_ECHO) reduce 244) ((T_EMPTY) reduce 244) ((T_ENUM) reduce 244) ((T_EVAL) reduce 244) ((T_EXIT) reduce 244) ((T_FILE) reduce 244) ((T_FINAL) reduce 244) ((T_FN) reduce 244) ((T_FOR) reduce 244) ((T_FOREACH) reduce 244) ((T_FUNCTION) reduce 244) ((T_FUNC_C) reduce 244) ((T_GLOBAL) reduce 244) ((T_GOTO) reduce 244) ((T_HALT_COMPILER) reduce 244) ((T_IF) reduce 244) ((T_INC) reduce 244) ((T_INCLUDE) reduce 244) ((T_INCLUDE_ONCE) reduce 244) ((T_INLINE_HTML) reduce 244) ((T_INTERFACE) reduce 244) ((T_INT_CAST) reduce 244) ((T_ISSET) reduce 244) ((T_LINE) reduce 244) ((T_LIST) reduce 244) ((T_LNUMBER) reduce 244) ((T_MATCH) reduce 244) ((T_METHOD_C) reduce 244) ((T_NAME_FULLY_QUALIFIED) reduce 244) ((T_NAME_QUALIFIED) reduce 244) ((T_NAME_RELATIVE) reduce 244) ((T_NEW) reduce 244) ((T_NS_C) reduce 244) ((T_OBJECT_CAST) reduce 244) ((T_PRINT) reduce 244) ((T_READONLY) reduce 244) ((T_REQUIRE) reduce 244) ((T_REQUIRE_ONCE) reduce 244) ((T_RETURN) reduce 244) ((T_START_HEREDOC) reduce 244) ((T_STATIC) reduce 244) ((T_STRING) reduce 244) ((T_STRING_CAST) reduce 244) ((T_SWITCH) reduce 244) ((T_THROW) reduce 244) ((T_TRAIT) reduce 244) ((T_TRAIT_C) reduce 244) ((T_TRY) reduce 244) ((T_UNSET) reduce 244) ((T_UNSET_CAST) reduce 244) ((T_VARIABLE) reduce 244) ((T_WHILE) reduce 244) ((T_YIELD) reduce 244) ((T_YIELD_FROM) reduce 244) (("[") reduce 244) (("`") reduce 244) (("{") reduce 244) (("}") reduce 244) (("~") reduce 244)) 23887 ((("!") reduce 455) (("\"") reduce 455) (("$") reduce 455) (("(") reduce 455) (("+") reduce 455) (("-") reduce 455) ((";") reduce 455) (("@") reduce 455) ((T_ABSTRACT) reduce 455) ((T_ARRAY) reduce 455) ((T_ARRAY_CAST) reduce 455) ((T_ATTRIBUTE) reduce 455) ((T_BOOL_CAST) reduce 455) ((T_BREAK) reduce 455) ((T_CASE) reduce 455) ((T_CLASS) reduce 455) ((T_CLASS_C) reduce 455) ((T_CLONE) reduce 455) ((T_CONSTANT_ENCAPSED_STRING) reduce 455) ((T_CONTINUE) reduce 455) ((T_DEC) reduce 455) ((T_DECLARE) reduce 455) ((T_DEFAULT) reduce 455) ((T_DIR) reduce 455) ((T_DNUMBER) reduce 455) ((T_DO) reduce 455) ((T_DOUBLE_CAST) reduce 455) ((T_ECHO) reduce 455) ((T_EMPTY) reduce 455) ((T_ENUM) reduce 455) ((T_EVAL) reduce 455) ((T_EXIT) reduce 455) ((T_FILE) reduce 455) ((T_FINAL) reduce 455) ((T_FN) reduce 455) ((T_FOR) reduce 455) ((T_FOREACH) reduce 455) ((T_FUNCTION) reduce 455) ((T_FUNC_C) reduce 455) ((T_GLOBAL) reduce 455) ((T_GOTO) reduce 455) ((T_HALT_COMPILER) reduce 455) ((T_IF) reduce 455) ((T_INC) reduce 455) ((T_INCLUDE) reduce 455) ((T_INCLUDE_ONCE) reduce 455) ((T_INLINE_HTML) reduce 455) ((T_INTERFACE) reduce 455) ((T_INT_CAST) reduce 455) ((T_ISSET) reduce 455) ((T_LINE) reduce 455) ((T_LIST) reduce 455) ((T_LNUMBER) reduce 455) ((T_MATCH) reduce 455) ((T_METHOD_C) reduce 455) ((T_NAME_FULLY_QUALIFIED) reduce 455) ((T_NAME_QUALIFIED) reduce 455) ((T_NAME_RELATIVE) reduce 455) ((T_NEW) reduce 455) ((T_NS_C) reduce 455) ((T_OBJECT_CAST) reduce 455) ((T_PRINT) reduce 455) ((T_READONLY) reduce 455) ((T_REQUIRE) reduce 455) ((T_REQUIRE_ONCE) reduce 455) ((T_RETURN) reduce 455) ((T_START_HEREDOC) reduce 455) ((T_STATIC) reduce 455) ((T_STRING) reduce 455) ((T_STRING_CAST) reduce 455) ((T_SWITCH) reduce 455) ((T_THROW) reduce 455) ((T_TRAIT) reduce 455) ((T_TRAIT_C) reduce 455) ((T_TRY) reduce 455) ((T_UNSET) reduce 455) ((T_UNSET_CAST) reduce 455) ((T_VARIABLE) reduce 455) ((T_WHILE) reduce 455) ((T_YIELD) reduce 455) ((T_YIELD_FROM) reduce 455) (("[") reduce 455) (("`") reduce 455) (("{") reduce 455) (("}") reduce 455) (("~") reduce 455)) 23888 ((("!") reduce 181) (("\"") reduce 181) (("$") reduce 181) (("(") reduce 181) (("+") reduce 181) (("-") reduce 181) ((";") reduce 181) (("@") reduce 181) ((T_ABSTRACT) reduce 181) ((T_ARRAY) reduce 181) ((T_ARRAY_CAST) reduce 181) ((T_ATTRIBUTE) reduce 181) ((T_BOOL_CAST) reduce 181) ((T_BREAK) reduce 181) ((T_CASE) reduce 181) ((T_CLASS) reduce 181) ((T_CLASS_C) reduce 181) ((T_CLONE) reduce 181) ((T_CONSTANT_ENCAPSED_STRING) reduce 181) ((T_CONTINUE) reduce 181) ((T_DEC) reduce 181) ((T_DECLARE) reduce 181) ((T_DEFAULT) reduce 181) ((T_DIR) reduce 181) ((T_DNUMBER) reduce 181) ((T_DO) reduce 181) ((T_DOUBLE_CAST) reduce 181) ((T_ECHO) reduce 181) ((T_EMPTY) reduce 181) ((T_ENUM) reduce 181) ((T_EVAL) reduce 181) ((T_EXIT) reduce 181) ((T_FILE) reduce 181) ((T_FINAL) reduce 181) ((T_FN) reduce 181) ((T_FOR) reduce 181) ((T_FOREACH) reduce 181) ((T_FUNCTION) reduce 181) ((T_FUNC_C) reduce 181) ((T_GLOBAL) reduce 181) ((T_GOTO) reduce 181) ((T_HALT_COMPILER) reduce 181) ((T_IF) reduce 181) ((T_INC) reduce 181) ((T_INCLUDE) reduce 181) ((T_INCLUDE_ONCE) reduce 181) ((T_INLINE_HTML) reduce 181) ((T_INTERFACE) reduce 181) ((T_INT_CAST) reduce 181) ((T_ISSET) reduce 181) ((T_LINE) reduce 181) ((T_LIST) reduce 181) ((T_LNUMBER) reduce 181) ((T_MATCH) reduce 181) ((T_METHOD_C) reduce 181) ((T_NAME_FULLY_QUALIFIED) reduce 181) ((T_NAME_QUALIFIED) reduce 181) ((T_NAME_RELATIVE) reduce 181) ((T_NEW) reduce 181) ((T_NS_C) reduce 181) ((T_OBJECT_CAST) reduce 181) ((T_PRINT) reduce 181) ((T_READONLY) reduce 181) ((T_REQUIRE) reduce 181) ((T_REQUIRE_ONCE) reduce 181) ((T_RETURN) reduce 181) ((T_START_HEREDOC) reduce 181) ((T_STATIC) reduce 181) ((T_STRING) reduce 181) ((T_STRING_CAST) reduce 181) ((T_SWITCH) reduce 181) ((T_THROW) reduce 181) ((T_TRAIT) reduce 181) ((T_TRAIT_C) reduce 181) ((T_TRY) reduce 181) ((T_UNSET) reduce 181) ((T_UNSET_CAST) reduce 181) ((T_VARIABLE) reduce 181) ((T_WHILE) reduce 181) ((T_YIELD) reduce 181) ((T_YIELD_FROM) reduce 181) (("[") reduce 181) (("`") reduce 181) (("{") reduce 181) (("}") reduce 181) (("~") reduce 181)) 23889 ((("!") reduce 159) (("\"") reduce 159) (("$") reduce 159) (("(") reduce 159) (("+") reduce 159) (("-") reduce 159) ((";") reduce 159) (("@") reduce 159) ((T_ABSTRACT) reduce 159) ((T_ARRAY) reduce 159) ((T_ARRAY_CAST) reduce 159) ((T_ATTRIBUTE) reduce 159) ((T_BOOL_CAST) reduce 159) ((T_BREAK) reduce 159) ((T_CASE) reduce 159) ((T_CLASS) reduce 159) ((T_CLASS_C) reduce 159) ((T_CLONE) reduce 159) ((T_CONSTANT_ENCAPSED_STRING) reduce 159) ((T_CONTINUE) reduce 159) ((T_DEC) reduce 159) ((T_DECLARE) reduce 159) ((T_DEFAULT) reduce 159) ((T_DIR) reduce 159) ((T_DNUMBER) reduce 159) ((T_DO) reduce 159) ((T_DOUBLE_CAST) reduce 159) ((T_ECHO) reduce 159) ((T_EMPTY) reduce 159) ((T_ENUM) reduce 159) ((T_EVAL) reduce 159) ((T_EXIT) reduce 159) ((T_FILE) reduce 159) ((T_FINAL) reduce 159) ((T_FN) reduce 159) ((T_FOR) reduce 159) ((T_FOREACH) reduce 159) ((T_FUNCTION) reduce 159) ((T_FUNC_C) reduce 159) ((T_GLOBAL) reduce 159) ((T_GOTO) reduce 159) ((T_HALT_COMPILER) reduce 159) ((T_IF) reduce 159) ((T_INC) reduce 159) ((T_INCLUDE) reduce 159) ((T_INCLUDE_ONCE) reduce 159) ((T_INLINE_HTML) reduce 159) ((T_INTERFACE) reduce 159) ((T_INT_CAST) reduce 159) ((T_ISSET) reduce 159) ((T_LINE) reduce 159) ((T_LIST) reduce 159) ((T_LNUMBER) reduce 159) ((T_MATCH) reduce 159) ((T_METHOD_C) reduce 159) ((T_NAME_FULLY_QUALIFIED) reduce 159) ((T_NAME_QUALIFIED) reduce 159) ((T_NAME_RELATIVE) reduce 159) ((T_NEW) reduce 159) ((T_NS_C) reduce 159) ((T_OBJECT_CAST) reduce 159) ((T_PRINT) reduce 159) ((T_READONLY) reduce 159) ((T_REQUIRE) reduce 159) ((T_REQUIRE_ONCE) reduce 159) ((T_RETURN) reduce 159) ((T_START_HEREDOC) reduce 159) ((T_STATIC) reduce 159) ((T_STRING) reduce 159) ((T_STRING_CAST) reduce 159) ((T_SWITCH) reduce 159) ((T_THROW) reduce 159) ((T_TRAIT) reduce 159) ((T_TRAIT_C) reduce 159) ((T_TRY) reduce 159) ((T_UNSET) reduce 159) ((T_UNSET_CAST) reduce 159) ((T_VARIABLE) reduce 159) ((T_WHILE) reduce 159) ((T_YIELD) reduce 159) ((T_YIELD_FROM) reduce 159) (("[") reduce 159) (("`") reduce 159) (("{") reduce 159) (("}") reduce 159) (("~") reduce 159)) 23897 ((("!") reduce 186) (("\"") reduce 186) (("$") reduce 186) (("(") reduce 186) (("+") reduce 186) (("-") reduce 186) ((";") reduce 186) (("@") reduce 186) ((T_ABSTRACT) reduce 186) ((T_ARRAY) reduce 186) ((T_ARRAY_CAST) reduce 186) ((T_ATTRIBUTE) reduce 186) ((T_BOOL_CAST) reduce 186) ((T_BREAK) reduce 186) ((T_CASE) reduce 186) ((T_CLASS) reduce 186) ((T_CLASS_C) reduce 186) ((T_CLONE) reduce 186) ((T_CONSTANT_ENCAPSED_STRING) reduce 186) ((T_CONTINUE) reduce 186) ((T_DEC) reduce 186) ((T_DECLARE) reduce 186) ((T_DEFAULT) reduce 186) ((T_DIR) reduce 186) ((T_DNUMBER) reduce 186) ((T_DO) reduce 186) ((T_DOUBLE_CAST) reduce 186) ((T_ECHO) reduce 186) ((T_EMPTY) reduce 186) ((T_ENUM) reduce 186) ((T_EVAL) reduce 186) ((T_EXIT) reduce 186) ((T_FILE) reduce 186) ((T_FINAL) reduce 186) ((T_FN) reduce 186) ((T_FOR) reduce 186) ((T_FOREACH) reduce 186) ((T_FUNCTION) reduce 186) ((T_FUNC_C) reduce 186) ((T_GLOBAL) reduce 186) ((T_GOTO) reduce 186) ((T_HALT_COMPILER) reduce 186) ((T_IF) reduce 186) ((T_INC) reduce 186) ((T_INCLUDE) reduce 186) ((T_INCLUDE_ONCE) reduce 186) ((T_INLINE_HTML) reduce 186) ((T_INTERFACE) reduce 186) ((T_INT_CAST) reduce 186) ((T_ISSET) reduce 186) ((T_LINE) reduce 186) ((T_LIST) reduce 186) ((T_LNUMBER) reduce 186) ((T_MATCH) reduce 186) ((T_METHOD_C) reduce 186) ((T_NAME_FULLY_QUALIFIED) reduce 186) ((T_NAME_QUALIFIED) reduce 186) ((T_NAME_RELATIVE) reduce 186) ((T_NEW) reduce 186) ((T_NS_C) reduce 186) ((T_OBJECT_CAST) reduce 186) ((T_PRINT) reduce 186) ((T_READONLY) reduce 186) ((T_REQUIRE) reduce 186) ((T_REQUIRE_ONCE) reduce 186) ((T_RETURN) reduce 186) ((T_START_HEREDOC) reduce 186) ((T_STATIC) reduce 186) ((T_STRING) reduce 186) ((T_STRING_CAST) reduce 186) ((T_SWITCH) reduce 186) ((T_THROW) reduce 186) ((T_TRAIT) reduce 186) ((T_TRAIT_C) reduce 186) ((T_TRY) reduce 186) ((T_UNSET) reduce 186) ((T_UNSET_CAST) reduce 186) ((T_VARIABLE) reduce 186) ((T_WHILE) reduce 186) ((T_YIELD) reduce 186) ((T_YIELD_FROM) reduce 186) (("[") reduce 186) (("`") reduce 186) (("{") reduce 186) (("}") reduce 186) (("~") reduce 186)) 23898 ((("!") reduce 143) (("\"") reduce 143) (("$") reduce 143) (("(") reduce 143) (("+") reduce 143) (("-") reduce 143) ((";") reduce 143) (("@") reduce 143) ((T_ABSTRACT) reduce 143) ((T_ARRAY) reduce 143) ((T_ARRAY_CAST) reduce 143) ((T_ATTRIBUTE) reduce 143) ((T_BOOL_CAST) reduce 143) ((T_BREAK) reduce 143) ((T_CASE) reduce 143) ((T_CLASS) reduce 143) ((T_CLASS_C) reduce 143) ((T_CLONE) reduce 143) ((T_CONSTANT_ENCAPSED_STRING) reduce 143) ((T_CONTINUE) reduce 143) ((T_DEC) reduce 143) ((T_DECLARE) reduce 143) ((T_DEFAULT) reduce 143) ((T_DIR) reduce 143) ((T_DNUMBER) reduce 143) ((T_DO) reduce 143) ((T_DOUBLE_CAST) reduce 143) ((T_ECHO) reduce 143) ((T_EMPTY) reduce 143) ((T_ENUM) reduce 143) ((T_EVAL) reduce 143) ((T_EXIT) reduce 143) ((T_FILE) reduce 143) ((T_FINAL) reduce 143) ((T_FN) reduce 143) ((T_FOR) reduce 143) ((T_FOREACH) reduce 143) ((T_FUNCTION) reduce 143) ((T_FUNC_C) reduce 143) ((T_GLOBAL) reduce 143) ((T_GOTO) reduce 143) ((T_HALT_COMPILER) reduce 143) ((T_IF) reduce 143) ((T_INC) reduce 143) ((T_INCLUDE) reduce 143) ((T_INCLUDE_ONCE) reduce 143) ((T_INLINE_HTML) reduce 143) ((T_INTERFACE) reduce 143) ((T_INT_CAST) reduce 143) ((T_ISSET) reduce 143) ((T_LINE) reduce 143) ((T_LIST) reduce 143) ((T_LNUMBER) reduce 143) ((T_MATCH) reduce 143) ((T_METHOD_C) reduce 143) ((T_NAME_FULLY_QUALIFIED) reduce 143) ((T_NAME_QUALIFIED) reduce 143) ((T_NAME_RELATIVE) reduce 143) ((T_NEW) reduce 143) ((T_NS_C) reduce 143) ((T_OBJECT_CAST) reduce 143) ((T_PRINT) reduce 143) ((T_READONLY) reduce 143) ((T_REQUIRE) reduce 143) ((T_REQUIRE_ONCE) reduce 143) ((T_RETURN) reduce 143) ((T_START_HEREDOC) reduce 143) ((T_STATIC) reduce 143) ((T_STRING) reduce 143) ((T_STRING_CAST) reduce 143) ((T_SWITCH) reduce 143) ((T_THROW) reduce 143) ((T_TRAIT) reduce 143) ((T_TRAIT_C) reduce 143) ((T_TRY) reduce 143) ((T_UNSET) reduce 143) ((T_UNSET_CAST) reduce 143) ((T_VARIABLE) reduce 143) ((T_WHILE) reduce 143) ((T_YIELD) reduce 143) ((T_YIELD_FROM) reduce 143) (("[") reduce 143) (("`") reduce 143) (("{") reduce 143) (("}") reduce 143) (("~") reduce 143)) 23901 ((("!") reduce 247) (("\"") reduce 247) (("$") reduce 247) (("(") reduce 247) (("+") reduce 247) (("-") reduce 247) ((";") reduce 247) (("@") reduce 247) ((T_ABSTRACT) reduce 247) ((T_ARRAY) reduce 247) ((T_ARRAY_CAST) reduce 247) ((T_ATTRIBUTE) reduce 247) ((T_BOOL_CAST) reduce 247) ((T_BREAK) reduce 247) ((T_CASE) reduce 247) ((T_CLASS) reduce 247) ((T_CLASS_C) reduce 247) ((T_CLONE) reduce 247) ((T_CONSTANT_ENCAPSED_STRING) reduce 247) ((T_CONTINUE) reduce 247) ((T_DEC) reduce 247) ((T_DECLARE) reduce 247) ((T_DEFAULT) reduce 247) ((T_DIR) reduce 247) ((T_DNUMBER) reduce 247) ((T_DO) reduce 247) ((T_DOUBLE_CAST) reduce 247) ((T_ECHO) reduce 247) ((T_EMPTY) reduce 247) ((T_ENUM) reduce 247) ((T_EVAL) reduce 247) ((T_EXIT) reduce 247) ((T_FILE) reduce 247) ((T_FINAL) reduce 247) ((T_FN) reduce 247) ((T_FOR) reduce 247) ((T_FOREACH) reduce 247) ((T_FUNCTION) reduce 247) ((T_FUNC_C) reduce 247) ((T_GLOBAL) reduce 247) ((T_GOTO) reduce 247) ((T_HALT_COMPILER) reduce 247) ((T_IF) reduce 247) ((T_INC) reduce 247) ((T_INCLUDE) reduce 247) ((T_INCLUDE_ONCE) reduce 247) ((T_INLINE_HTML) reduce 247) ((T_INTERFACE) reduce 247) ((T_INT_CAST) reduce 247) ((T_ISSET) reduce 247) ((T_LINE) reduce 247) ((T_LIST) reduce 247) ((T_LNUMBER) reduce 247) ((T_MATCH) reduce 247) ((T_METHOD_C) reduce 247) ((T_NAME_FULLY_QUALIFIED) reduce 247) ((T_NAME_QUALIFIED) reduce 247) ((T_NAME_RELATIVE) reduce 247) ((T_NEW) reduce 247) ((T_NS_C) reduce 247) ((T_OBJECT_CAST) reduce 247) ((T_PRINT) reduce 247) ((T_READONLY) reduce 247) ((T_REQUIRE) reduce 247) ((T_REQUIRE_ONCE) reduce 247) ((T_RETURN) reduce 247) ((T_START_HEREDOC) reduce 247) ((T_STATIC) reduce 247) ((T_STRING) reduce 247) ((T_STRING_CAST) reduce 247) ((T_SWITCH) reduce 247) ((T_THROW) reduce 247) ((T_TRAIT) reduce 247) ((T_TRAIT_C) reduce 247) ((T_TRY) reduce 247) ((T_UNSET) reduce 247) ((T_UNSET_CAST) reduce 247) ((T_VARIABLE) reduce 247) ((T_WHILE) reduce 247) ((T_YIELD) reduce 247) ((T_YIELD_FROM) reduce 247) (("[") reduce 247) (("`") reduce 247) (("{") reduce 247) (("}") reduce 247) (("~") reduce 247)) 23905 ((("!") reduce 248) (("\"") reduce 248) (("$") reduce 248) (("(") reduce 248) (("+") reduce 248) (("-") reduce 248) ((";") reduce 248) (("@") reduce 248) ((T_ABSTRACT) reduce 248) ((T_ARRAY) reduce 248) ((T_ARRAY_CAST) reduce 248) ((T_ATTRIBUTE) reduce 248) ((T_BOOL_CAST) reduce 248) ((T_BREAK) reduce 248) ((T_CASE) reduce 248) ((T_CLASS) reduce 248) ((T_CLASS_C) reduce 248) ((T_CLONE) reduce 248) ((T_CONSTANT_ENCAPSED_STRING) reduce 248) ((T_CONTINUE) reduce 248) ((T_DEC) reduce 248) ((T_DECLARE) reduce 248) ((T_DEFAULT) reduce 248) ((T_DIR) reduce 248) ((T_DNUMBER) reduce 248) ((T_DO) reduce 248) ((T_DOUBLE_CAST) reduce 248) ((T_ECHO) reduce 248) ((T_EMPTY) reduce 248) ((T_ENUM) reduce 248) ((T_EVAL) reduce 248) ((T_EXIT) reduce 248) ((T_FILE) reduce 248) ((T_FINAL) reduce 248) ((T_FN) reduce 248) ((T_FOR) reduce 248) ((T_FOREACH) reduce 248) ((T_FUNCTION) reduce 248) ((T_FUNC_C) reduce 248) ((T_GLOBAL) reduce 248) ((T_GOTO) reduce 248) ((T_HALT_COMPILER) reduce 248) ((T_IF) reduce 248) ((T_INC) reduce 248) ((T_INCLUDE) reduce 248) ((T_INCLUDE_ONCE) reduce 248) ((T_INLINE_HTML) reduce 248) ((T_INTERFACE) reduce 248) ((T_INT_CAST) reduce 248) ((T_ISSET) reduce 248) ((T_LINE) reduce 248) ((T_LIST) reduce 248) ((T_LNUMBER) reduce 248) ((T_MATCH) reduce 248) ((T_METHOD_C) reduce 248) ((T_NAME_FULLY_QUALIFIED) reduce 248) ((T_NAME_QUALIFIED) reduce 248) ((T_NAME_RELATIVE) reduce 248) ((T_NEW) reduce 248) ((T_NS_C) reduce 248) ((T_OBJECT_CAST) reduce 248) ((T_PRINT) reduce 248) ((T_READONLY) reduce 248) ((T_REQUIRE) reduce 248) ((T_REQUIRE_ONCE) reduce 248) ((T_RETURN) reduce 248) ((T_START_HEREDOC) reduce 248) ((T_STATIC) reduce 248) ((T_STRING) reduce 248) ((T_STRING_CAST) reduce 248) ((T_SWITCH) reduce 248) ((T_THROW) reduce 248) ((T_TRAIT) reduce 248) ((T_TRAIT_C) reduce 248) ((T_TRY) reduce 248) ((T_UNSET) reduce 248) ((T_UNSET_CAST) reduce 248) ((T_VARIABLE) reduce 248) ((T_WHILE) reduce 248) ((T_YIELD) reduce 248) ((T_YIELD_FROM) reduce 248) (("[") reduce 248) (("`") reduce 248) (("{") reduce 248) (("}") reduce 248) (("~") reduce 248)) 23910 ((("!") reduce 239) (("\"") reduce 239) (("$") reduce 239) (("(") reduce 239) (("+") reduce 239) (("-") reduce 239) ((";") reduce 239) (("@") reduce 239) ((T_ABSTRACT) reduce 239) ((T_ARRAY) reduce 239) ((T_ARRAY_CAST) reduce 239) ((T_ATTRIBUTE) reduce 239) ((T_BOOL_CAST) reduce 239) ((T_BREAK) reduce 239) ((T_CASE) reduce 239) ((T_CLASS) reduce 239) ((T_CLASS_C) reduce 239) ((T_CLONE) reduce 239) ((T_CONSTANT_ENCAPSED_STRING) reduce 239) ((T_CONTINUE) reduce 239) ((T_DEC) reduce 239) ((T_DECLARE) reduce 239) ((T_DEFAULT) reduce 239) ((T_DIR) reduce 239) ((T_DNUMBER) reduce 239) ((T_DO) reduce 239) ((T_DOUBLE_CAST) reduce 239) ((T_ECHO) reduce 239) ((T_EMPTY) reduce 239) ((T_ENUM) reduce 239) ((T_EVAL) reduce 239) ((T_EXIT) reduce 239) ((T_FILE) reduce 239) ((T_FINAL) reduce 239) ((T_FN) reduce 239) ((T_FOR) reduce 239) ((T_FOREACH) reduce 239) ((T_FUNCTION) reduce 239) ((T_FUNC_C) reduce 239) ((T_GLOBAL) reduce 239) ((T_GOTO) reduce 239) ((T_HALT_COMPILER) reduce 239) ((T_IF) reduce 239) ((T_INC) reduce 239) ((T_INCLUDE) reduce 239) ((T_INCLUDE_ONCE) reduce 239) ((T_INLINE_HTML) reduce 239) ((T_INTERFACE) reduce 239) ((T_INT_CAST) reduce 239) ((T_ISSET) reduce 239) ((T_LINE) reduce 239) ((T_LIST) reduce 239) ((T_LNUMBER) reduce 239) ((T_MATCH) reduce 239) ((T_METHOD_C) reduce 239) ((T_NAME_FULLY_QUALIFIED) reduce 239) ((T_NAME_QUALIFIED) reduce 239) ((T_NAME_RELATIVE) reduce 239) ((T_NEW) reduce 239) ((T_NS_C) reduce 239) ((T_OBJECT_CAST) reduce 239) ((T_PRINT) reduce 239) ((T_READONLY) reduce 239) ((T_REQUIRE) reduce 239) ((T_REQUIRE_ONCE) reduce 239) ((T_RETURN) reduce 239) ((T_START_HEREDOC) reduce 239) ((T_STATIC) reduce 239) ((T_STRING) reduce 239) ((T_STRING_CAST) reduce 239) ((T_SWITCH) reduce 239) ((T_THROW) reduce 239) ((T_TRAIT) reduce 239) ((T_TRAIT_C) reduce 239) ((T_TRY) reduce 239) ((T_UNSET) reduce 239) ((T_UNSET_CAST) reduce 239) ((T_VARIABLE) reduce 239) ((T_WHILE) reduce 239) ((T_YIELD) reduce 239) ((T_YIELD_FROM) reduce 239) (("[") reduce 239) (("`") reduce 239) (("{") reduce 239) (("}") reduce 239) (("~") reduce 239)) 23911 ((("!") reduce 148) (("\"") reduce 148) (("$") reduce 148) (("(") reduce 148) (("+") reduce 148) (("-") reduce 148) ((";") reduce 148) (("@") reduce 148) ((T_ABSTRACT) reduce 148) ((T_ARRAY) reduce 148) ((T_ARRAY_CAST) reduce 148) ((T_ATTRIBUTE) reduce 148) ((T_BOOL_CAST) reduce 148) ((T_BREAK) reduce 148) ((T_CASE) reduce 148) ((T_CLASS) reduce 148) ((T_CLASS_C) reduce 148) ((T_CLONE) reduce 148) ((T_CONSTANT_ENCAPSED_STRING) reduce 148) ((T_CONTINUE) reduce 148) ((T_DEC) reduce 148) ((T_DECLARE) reduce 148) ((T_DEFAULT) reduce 148) ((T_DIR) reduce 148) ((T_DNUMBER) reduce 148) ((T_DO) reduce 148) ((T_DOUBLE_CAST) reduce 148) ((T_ECHO) reduce 148) ((T_EMPTY) reduce 148) ((T_ENUM) reduce 148) ((T_EVAL) reduce 148) ((T_EXIT) reduce 148) ((T_FILE) reduce 148) ((T_FINAL) reduce 148) ((T_FN) reduce 148) ((T_FOR) reduce 148) ((T_FOREACH) reduce 148) ((T_FUNCTION) reduce 148) ((T_FUNC_C) reduce 148) ((T_GLOBAL) reduce 148) ((T_GOTO) reduce 148) ((T_HALT_COMPILER) reduce 148) ((T_IF) reduce 148) ((T_INC) reduce 148) ((T_INCLUDE) reduce 148) ((T_INCLUDE_ONCE) reduce 148) ((T_INLINE_HTML) reduce 148) ((T_INTERFACE) reduce 148) ((T_INT_CAST) reduce 148) ((T_ISSET) reduce 148) ((T_LINE) reduce 148) ((T_LIST) reduce 148) ((T_LNUMBER) reduce 148) ((T_MATCH) reduce 148) ((T_METHOD_C) reduce 148) ((T_NAME_FULLY_QUALIFIED) reduce 148) ((T_NAME_QUALIFIED) reduce 148) ((T_NAME_RELATIVE) reduce 148) ((T_NEW) reduce 148) ((T_NS_C) reduce 148) ((T_OBJECT_CAST) reduce 148) ((T_PRINT) reduce 148) ((T_READONLY) reduce 148) ((T_REQUIRE) reduce 148) ((T_REQUIRE_ONCE) reduce 148) ((T_RETURN) reduce 148) ((T_START_HEREDOC) reduce 148) ((T_STATIC) reduce 148) ((T_STRING) reduce 148) ((T_STRING_CAST) reduce 148) ((T_SWITCH) reduce 148) ((T_THROW) reduce 148) ((T_TRAIT) reduce 148) ((T_TRAIT_C) reduce 148) ((T_TRY) reduce 148) ((T_UNSET) reduce 148) ((T_UNSET_CAST) reduce 148) ((T_VARIABLE) reduce 148) ((T_WHILE) reduce 148) ((T_YIELD) reduce 148) ((T_YIELD_FROM) reduce 148) (("[") reduce 148) (("`") reduce 148) (("{") reduce 148) (("}") reduce 148) (("~") reduce 148)) 23914 ((("!") reduce 240) (("\"") reduce 240) (("$") reduce 240) (("(") reduce 240) (("+") reduce 240) (("-") reduce 240) ((";") reduce 240) (("@") reduce 240) ((T_ABSTRACT) reduce 240) ((T_ARRAY) reduce 240) ((T_ARRAY_CAST) reduce 240) ((T_ATTRIBUTE) reduce 240) ((T_BOOL_CAST) reduce 240) ((T_BREAK) reduce 240) ((T_CASE) reduce 240) ((T_CLASS) reduce 240) ((T_CLASS_C) reduce 240) ((T_CLONE) reduce 240) ((T_CONSTANT_ENCAPSED_STRING) reduce 240) ((T_CONTINUE) reduce 240) ((T_DEC) reduce 240) ((T_DECLARE) reduce 240) ((T_DEFAULT) reduce 240) ((T_DIR) reduce 240) ((T_DNUMBER) reduce 240) ((T_DO) reduce 240) ((T_DOUBLE_CAST) reduce 240) ((T_ECHO) reduce 240) ((T_EMPTY) reduce 240) ((T_ENUM) reduce 240) ((T_EVAL) reduce 240) ((T_EXIT) reduce 240) ((T_FILE) reduce 240) ((T_FINAL) reduce 240) ((T_FN) reduce 240) ((T_FOR) reduce 240) ((T_FOREACH) reduce 240) ((T_FUNCTION) reduce 240) ((T_FUNC_C) reduce 240) ((T_GLOBAL) reduce 240) ((T_GOTO) reduce 240) ((T_HALT_COMPILER) reduce 240) ((T_IF) reduce 240) ((T_INC) reduce 240) ((T_INCLUDE) reduce 240) ((T_INCLUDE_ONCE) reduce 240) ((T_INLINE_HTML) reduce 240) ((T_INTERFACE) reduce 240) ((T_INT_CAST) reduce 240) ((T_ISSET) reduce 240) ((T_LINE) reduce 240) ((T_LIST) reduce 240) ((T_LNUMBER) reduce 240) ((T_MATCH) reduce 240) ((T_METHOD_C) reduce 240) ((T_NAME_FULLY_QUALIFIED) reduce 240) ((T_NAME_QUALIFIED) reduce 240) ((T_NAME_RELATIVE) reduce 240) ((T_NEW) reduce 240) ((T_NS_C) reduce 240) ((T_OBJECT_CAST) reduce 240) ((T_PRINT) reduce 240) ((T_READONLY) reduce 240) ((T_REQUIRE) reduce 240) ((T_REQUIRE_ONCE) reduce 240) ((T_RETURN) reduce 240) ((T_START_HEREDOC) reduce 240) ((T_STATIC) reduce 240) ((T_STRING) reduce 240) ((T_STRING_CAST) reduce 240) ((T_SWITCH) reduce 240) ((T_THROW) reduce 240) ((T_TRAIT) reduce 240) ((T_TRAIT_C) reduce 240) ((T_TRY) reduce 240) ((T_UNSET) reduce 240) ((T_UNSET_CAST) reduce 240) ((T_VARIABLE) reduce 240) ((T_WHILE) reduce 240) ((T_YIELD) reduce 240) ((T_YIELD_FROM) reduce 240) (("[") reduce 240) (("`") reduce 240) (("{") reduce 240) (("}") reduce 240) (("~") reduce 240)) 23919 ((("!") reduce 160) (("\"") reduce 160) (("$") reduce 160) (("(") reduce 160) (("+") reduce 160) (("-") reduce 160) ((";") reduce 160) (("@") reduce 160) ((T_ABSTRACT) reduce 160) ((T_ARRAY) reduce 160) ((T_ARRAY_CAST) reduce 160) ((T_ATTRIBUTE) reduce 160) ((T_BOOL_CAST) reduce 160) ((T_BREAK) reduce 160) ((T_CASE) reduce 160) ((T_CLASS) reduce 160) ((T_CLASS_C) reduce 160) ((T_CLONE) reduce 160) ((T_CONSTANT_ENCAPSED_STRING) reduce 160) ((T_CONTINUE) reduce 160) ((T_DEC) reduce 160) ((T_DECLARE) reduce 160) ((T_DEFAULT) reduce 160) ((T_DIR) reduce 160) ((T_DNUMBER) reduce 160) ((T_DO) reduce 160) ((T_DOUBLE_CAST) reduce 160) ((T_ECHO) reduce 160) ((T_EMPTY) reduce 160) ((T_ENUM) reduce 160) ((T_EVAL) reduce 160) ((T_EXIT) reduce 160) ((T_FILE) reduce 160) ((T_FINAL) reduce 160) ((T_FN) reduce 160) ((T_FOR) reduce 160) ((T_FOREACH) reduce 160) ((T_FUNCTION) reduce 160) ((T_FUNC_C) reduce 160) ((T_GLOBAL) reduce 160) ((T_GOTO) reduce 160) ((T_HALT_COMPILER) reduce 160) ((T_IF) reduce 160) ((T_INC) reduce 160) ((T_INCLUDE) reduce 160) ((T_INCLUDE_ONCE) reduce 160) ((T_INLINE_HTML) reduce 160) ((T_INTERFACE) reduce 160) ((T_INT_CAST) reduce 160) ((T_ISSET) reduce 160) ((T_LINE) reduce 160) ((T_LIST) reduce 160) ((T_LNUMBER) reduce 160) ((T_MATCH) reduce 160) ((T_METHOD_C) reduce 160) ((T_NAME_FULLY_QUALIFIED) reduce 160) ((T_NAME_QUALIFIED) reduce 160) ((T_NAME_RELATIVE) reduce 160) ((T_NEW) reduce 160) ((T_NS_C) reduce 160) ((T_OBJECT_CAST) reduce 160) ((T_PRINT) reduce 160) ((T_READONLY) reduce 160) ((T_REQUIRE) reduce 160) ((T_REQUIRE_ONCE) reduce 160) ((T_RETURN) reduce 160) ((T_START_HEREDOC) reduce 160) ((T_STATIC) reduce 160) ((T_STRING) reduce 160) ((T_STRING_CAST) reduce 160) ((T_SWITCH) reduce 160) ((T_THROW) reduce 160) ((T_TRAIT) reduce 160) ((T_TRAIT_C) reduce 160) ((T_TRY) reduce 160) ((T_UNSET) reduce 160) ((T_UNSET_CAST) reduce 160) ((T_VARIABLE) reduce 160) ((T_WHILE) reduce 160) ((T_YIELD) reduce 160) ((T_YIELD_FROM) reduce 160) (("[") reduce 160) (("`") reduce 160) (("{") reduce 160) (("}") reduce 160) (("~") reduce 160)) 23922 ((("!") reduce 168) (("\"") reduce 168) (("$") reduce 168) (("(") reduce 168) (("+") reduce 168) (("-") reduce 168) ((";") reduce 168) (("@") reduce 168) ((T_ABSTRACT) reduce 168) ((T_ARRAY) reduce 168) ((T_ARRAY_CAST) reduce 168) ((T_ATTRIBUTE) reduce 168) ((T_BOOL_CAST) reduce 168) ((T_BREAK) reduce 168) ((T_CASE) reduce 168) ((T_CATCH) reduce 168) ((T_CLASS) reduce 168) ((T_CLASS_C) reduce 168) ((T_CLONE) reduce 168) ((T_CONSTANT_ENCAPSED_STRING) reduce 168) ((T_CONTINUE) reduce 168) ((T_DEC) reduce 168) ((T_DECLARE) reduce 168) ((T_DEFAULT) reduce 168) ((T_DIR) reduce 168) ((T_DNUMBER) reduce 168) ((T_DO) reduce 168) ((T_DOUBLE_CAST) reduce 168) ((T_ECHO) reduce 168) ((T_EMPTY) reduce 168) ((T_ENUM) reduce 168) ((T_EVAL) reduce 168) ((T_EXIT) reduce 168) ((T_FILE) reduce 168) ((T_FINAL) reduce 168) ((T_FINALLY) reduce 168) ((T_FN) reduce 168) ((T_FOR) reduce 168) ((T_FOREACH) reduce 168) ((T_FUNCTION) reduce 168) ((T_FUNC_C) reduce 168) ((T_GLOBAL) reduce 168) ((T_GOTO) reduce 168) ((T_HALT_COMPILER) reduce 168) ((T_IF) reduce 168) ((T_INC) reduce 168) ((T_INCLUDE) reduce 168) ((T_INCLUDE_ONCE) reduce 168) ((T_INLINE_HTML) reduce 168) ((T_INTERFACE) reduce 168) ((T_INT_CAST) reduce 168) ((T_ISSET) reduce 168) ((T_LINE) reduce 168) ((T_LIST) reduce 168) ((T_LNUMBER) reduce 168) ((T_MATCH) reduce 168) ((T_METHOD_C) reduce 168) ((T_NAME_FULLY_QUALIFIED) reduce 168) ((T_NAME_QUALIFIED) reduce 168) ((T_NAME_RELATIVE) reduce 168) ((T_NEW) reduce 168) ((T_NS_C) reduce 168) ((T_OBJECT_CAST) reduce 168) ((T_PRINT) reduce 168) ((T_READONLY) reduce 168) ((T_REQUIRE) reduce 168) ((T_REQUIRE_ONCE) reduce 168) ((T_RETURN) reduce 168) ((T_START_HEREDOC) reduce 168) ((T_STATIC) reduce 168) ((T_STRING) reduce 168) ((T_STRING_CAST) reduce 168) ((T_SWITCH) reduce 168) ((T_THROW) reduce 168) ((T_TRAIT) reduce 168) ((T_TRAIT_C) reduce 168) ((T_TRY) reduce 168) ((T_UNSET) reduce 168) ((T_UNSET_CAST) reduce 168) ((T_VARIABLE) reduce 168) ((T_WHILE) reduce 168) ((T_YIELD) reduce 168) ((T_YIELD_FROM) reduce 168) (("[") reduce 168) (("`") reduce 168) (("{") reduce 168) (("}") reduce 168) (("~") reduce 168)) 23923 ((("!") reduce 174) (("\"") reduce 174) (("$") reduce 174) (("(") reduce 174) (("+") reduce 174) (("-") reduce 174) ((";") reduce 174) (("@") reduce 174) ((T_ABSTRACT) reduce 174) ((T_ARRAY) reduce 174) ((T_ARRAY_CAST) reduce 174) ((T_ATTRIBUTE) reduce 174) ((T_BOOL_CAST) reduce 174) ((T_BREAK) reduce 174) ((T_CASE) reduce 174) ((T_CATCH) shift) ((T_CLASS) reduce 174) ((T_CLASS_C) reduce 174) ((T_CLONE) reduce 174) ((T_CONSTANT_ENCAPSED_STRING) reduce 174) ((T_CONTINUE) reduce 174) ((T_DEC) reduce 174) ((T_DECLARE) reduce 174) ((T_DEFAULT) reduce 174) ((T_DIR) reduce 174) ((T_DNUMBER) reduce 174) ((T_DO) reduce 174) ((T_DOUBLE_CAST) reduce 174) ((T_ECHO) reduce 174) ((T_EMPTY) reduce 174) ((T_ENUM) reduce 174) ((T_EVAL) reduce 174) ((T_EXIT) reduce 174) ((T_FILE) reduce 174) ((T_FINAL) reduce 174) ((T_FINALLY) shift) ((T_FN) reduce 174) ((T_FOR) reduce 174) ((T_FOREACH) reduce 174) ((T_FUNCTION) reduce 174) ((T_FUNC_C) reduce 174) ((T_GLOBAL) reduce 174) ((T_GOTO) reduce 174) ((T_HALT_COMPILER) reduce 174) ((T_IF) reduce 174) ((T_INC) reduce 174) ((T_INCLUDE) reduce 174) ((T_INCLUDE_ONCE) reduce 174) ((T_INLINE_HTML) reduce 174) ((T_INTERFACE) reduce 174) ((T_INT_CAST) reduce 174) ((T_ISSET) reduce 174) ((T_LINE) reduce 174) ((T_LIST) reduce 174) ((T_LNUMBER) reduce 174) ((T_MATCH) reduce 174) ((T_METHOD_C) reduce 174) ((T_NAME_FULLY_QUALIFIED) reduce 174) ((T_NAME_QUALIFIED) reduce 174) ((T_NAME_RELATIVE) reduce 174) ((T_NEW) reduce 174) ((T_NS_C) reduce 174) ((T_OBJECT_CAST) reduce 174) ((T_PRINT) reduce 174) ((T_READONLY) reduce 174) ((T_REQUIRE) reduce 174) ((T_REQUIRE_ONCE) reduce 174) ((T_RETURN) reduce 174) ((T_START_HEREDOC) reduce 174) ((T_STATIC) reduce 174) ((T_STRING) reduce 174) ((T_STRING_CAST) reduce 174) ((T_SWITCH) reduce 174) ((T_THROW) reduce 174) ((T_TRAIT) reduce 174) ((T_TRAIT_C) reduce 174) ((T_TRY) reduce 174) ((T_UNSET) reduce 174) ((T_UNSET_CAST) reduce 174) ((T_VARIABLE) reduce 174) ((T_WHILE) reduce 174) ((T_YIELD) reduce 174) ((T_YIELD_FROM) reduce 174) (("[") reduce 174) (("`") reduce 174) (("{") reduce 174) (("}") reduce 174) (("~") reduce 174)) 23926 ((("!") reduce 165) (("\"") reduce 165) (("$") reduce 165) (("(") reduce 165) (("+") reduce 165) (("-") reduce 165) ((";") reduce 165) (("@") reduce 165) ((T_ABSTRACT) reduce 165) ((T_ARRAY) reduce 165) ((T_ARRAY_CAST) reduce 165) ((T_ATTRIBUTE) reduce 165) ((T_BOOL_CAST) reduce 165) ((T_BREAK) reduce 165) ((T_CASE) reduce 165) ((T_CLASS) reduce 165) ((T_CLASS_C) reduce 165) ((T_CLONE) reduce 165) ((T_CONSTANT_ENCAPSED_STRING) reduce 165) ((T_CONTINUE) reduce 165) ((T_DEC) reduce 165) ((T_DECLARE) reduce 165) ((T_DEFAULT) reduce 165) ((T_DIR) reduce 165) ((T_DNUMBER) reduce 165) ((T_DO) reduce 165) ((T_DOUBLE_CAST) reduce 165) ((T_ECHO) reduce 165) ((T_EMPTY) reduce 165) ((T_ENUM) reduce 165) ((T_EVAL) reduce 165) ((T_EXIT) reduce 165) ((T_FILE) reduce 165) ((T_FINAL) reduce 165) ((T_FN) reduce 165) ((T_FOR) reduce 165) ((T_FOREACH) reduce 165) ((T_FUNCTION) reduce 165) ((T_FUNC_C) reduce 165) ((T_GLOBAL) reduce 165) ((T_GOTO) reduce 165) ((T_HALT_COMPILER) reduce 165) ((T_IF) reduce 165) ((T_INC) reduce 165) ((T_INCLUDE) reduce 165) ((T_INCLUDE_ONCE) reduce 165) ((T_INLINE_HTML) reduce 165) ((T_INTERFACE) reduce 165) ((T_INT_CAST) reduce 165) ((T_ISSET) reduce 165) ((T_LINE) reduce 165) ((T_LIST) reduce 165) ((T_LNUMBER) reduce 165) ((T_MATCH) reduce 165) ((T_METHOD_C) reduce 165) ((T_NAME_FULLY_QUALIFIED) reduce 165) ((T_NAME_QUALIFIED) reduce 165) ((T_NAME_RELATIVE) reduce 165) ((T_NEW) reduce 165) ((T_NS_C) reduce 165) ((T_OBJECT_CAST) reduce 165) ((T_PRINT) reduce 165) ((T_READONLY) reduce 165) ((T_REQUIRE) reduce 165) ((T_REQUIRE_ONCE) reduce 165) ((T_RETURN) reduce 165) ((T_START_HEREDOC) reduce 165) ((T_STATIC) reduce 165) ((T_STRING) reduce 165) ((T_STRING_CAST) reduce 165) ((T_SWITCH) reduce 165) ((T_THROW) reduce 165) ((T_TRAIT) reduce 165) ((T_TRAIT_C) reduce 165) ((T_TRY) reduce 165) ((T_UNSET) reduce 165) ((T_UNSET_CAST) reduce 165) ((T_VARIABLE) reduce 165) ((T_WHILE) reduce 165) ((T_YIELD) reduce 165) ((T_YIELD_FROM) reduce 165) (("[") reduce 165) (("`") reduce 165) (("{") reduce 165) (("}") reduce 165) (("~") reduce 165)) 23929 ((("!") reduce 175) (("\"") reduce 175) (("$") reduce 175) (("(") reduce 175) (("+") reduce 175) (("-") reduce 175) ((";") reduce 175) (("@") reduce 175) ((T_ABSTRACT) reduce 175) ((T_ARRAY) reduce 175) ((T_ARRAY_CAST) reduce 175) ((T_ATTRIBUTE) reduce 175) ((T_BOOL_CAST) reduce 175) ((T_BREAK) reduce 175) ((T_CASE) reduce 175) ((T_CLASS) reduce 175) ((T_CLASS_C) reduce 175) ((T_CLONE) reduce 175) ((T_CONSTANT_ENCAPSED_STRING) reduce 175) ((T_CONTINUE) reduce 175) ((T_DEC) reduce 175) ((T_DECLARE) reduce 175) ((T_DEFAULT) reduce 175) ((T_DIR) reduce 175) ((T_DNUMBER) reduce 175) ((T_DO) reduce 175) ((T_DOUBLE_CAST) reduce 175) ((T_ECHO) reduce 175) ((T_EMPTY) reduce 175) ((T_ENUM) reduce 175) ((T_EVAL) reduce 175) ((T_EXIT) reduce 175) ((T_FILE) reduce 175) ((T_FINAL) reduce 175) ((T_FN) reduce 175) ((T_FOR) reduce 175) ((T_FOREACH) reduce 175) ((T_FUNCTION) reduce 175) ((T_FUNC_C) reduce 175) ((T_GLOBAL) reduce 175) ((T_GOTO) reduce 175) ((T_HALT_COMPILER) reduce 175) ((T_IF) reduce 175) ((T_INC) reduce 175) ((T_INCLUDE) reduce 175) ((T_INCLUDE_ONCE) reduce 175) ((T_INLINE_HTML) reduce 175) ((T_INTERFACE) reduce 175) ((T_INT_CAST) reduce 175) ((T_ISSET) reduce 175) ((T_LINE) reduce 175) ((T_LIST) reduce 175) ((T_LNUMBER) reduce 175) ((T_MATCH) reduce 175) ((T_METHOD_C) reduce 175) ((T_NAME_FULLY_QUALIFIED) reduce 175) ((T_NAME_QUALIFIED) reduce 175) ((T_NAME_RELATIVE) reduce 175) ((T_NEW) reduce 175) ((T_NS_C) reduce 175) ((T_OBJECT_CAST) reduce 175) ((T_PRINT) reduce 175) ((T_READONLY) reduce 175) ((T_REQUIRE) reduce 175) ((T_REQUIRE_ONCE) reduce 175) ((T_RETURN) reduce 175) ((T_START_HEREDOC) reduce 175) ((T_STATIC) reduce 175) ((T_STRING) reduce 175) ((T_STRING_CAST) reduce 175) ((T_SWITCH) reduce 175) ((T_THROW) reduce 175) ((T_TRAIT) reduce 175) ((T_TRAIT_C) reduce 175) ((T_TRY) reduce 175) ((T_UNSET) reduce 175) ((T_UNSET_CAST) reduce 175) ((T_VARIABLE) reduce 175) ((T_WHILE) reduce 175) ((T_YIELD) reduce 175) ((T_YIELD_FROM) reduce 175) (("[") reduce 175) (("`") reduce 175) (("{") reduce 175) (("}") reduce 175) (("~") reduce 175)) 23936 ((("!") reduce 169) (("\"") reduce 169) (("$") reduce 169) (("(") reduce 169) (("+") reduce 169) (("-") reduce 169) ((";") reduce 169) (("@") reduce 169) ((T_ABSTRACT) reduce 169) ((T_ARRAY) reduce 169) ((T_ARRAY_CAST) reduce 169) ((T_ATTRIBUTE) reduce 169) ((T_BOOL_CAST) reduce 169) ((T_BREAK) reduce 169) ((T_CASE) reduce 169) ((T_CATCH) reduce 169) ((T_CLASS) reduce 169) ((T_CLASS_C) reduce 169) ((T_CLONE) reduce 169) ((T_CONSTANT_ENCAPSED_STRING) reduce 169) ((T_CONTINUE) reduce 169) ((T_DEC) reduce 169) ((T_DECLARE) reduce 169) ((T_DEFAULT) reduce 169) ((T_DIR) reduce 169) ((T_DNUMBER) reduce 169) ((T_DO) reduce 169) ((T_DOUBLE_CAST) reduce 169) ((T_ECHO) reduce 169) ((T_EMPTY) reduce 169) ((T_ENUM) reduce 169) ((T_EVAL) reduce 169) ((T_EXIT) reduce 169) ((T_FILE) reduce 169) ((T_FINAL) reduce 169) ((T_FINALLY) reduce 169) ((T_FN) reduce 169) ((T_FOR) reduce 169) ((T_FOREACH) reduce 169) ((T_FUNCTION) reduce 169) ((T_FUNC_C) reduce 169) ((T_GLOBAL) reduce 169) ((T_GOTO) reduce 169) ((T_HALT_COMPILER) reduce 169) ((T_IF) reduce 169) ((T_INC) reduce 169) ((T_INCLUDE) reduce 169) ((T_INCLUDE_ONCE) reduce 169) ((T_INLINE_HTML) reduce 169) ((T_INTERFACE) reduce 169) ((T_INT_CAST) reduce 169) ((T_ISSET) reduce 169) ((T_LINE) reduce 169) ((T_LIST) reduce 169) ((T_LNUMBER) reduce 169) ((T_MATCH) reduce 169) ((T_METHOD_C) reduce 169) ((T_NAME_FULLY_QUALIFIED) reduce 169) ((T_NAME_QUALIFIED) reduce 169) ((T_NAME_RELATIVE) reduce 169) ((T_NEW) reduce 169) ((T_NS_C) reduce 169) ((T_OBJECT_CAST) reduce 169) ((T_PRINT) reduce 169) ((T_READONLY) reduce 169) ((T_REQUIRE) reduce 169) ((T_REQUIRE_ONCE) reduce 169) ((T_RETURN) reduce 169) ((T_START_HEREDOC) reduce 169) ((T_STATIC) reduce 169) ((T_STRING) reduce 169) ((T_STRING_CAST) reduce 169) ((T_SWITCH) reduce 169) ((T_THROW) reduce 169) ((T_TRAIT) reduce 169) ((T_TRAIT_C) reduce 169) ((T_TRY) reduce 169) ((T_UNSET) reduce 169) ((T_UNSET_CAST) reduce 169) ((T_VARIABLE) reduce 169) ((T_WHILE) reduce 169) ((T_YIELD) reduce 169) ((T_YIELD_FROM) reduce 169) (("[") reduce 169) (("`") reduce 169) (("{") reduce 169) (("}") reduce 169) (("~") reduce 169)) 23941 ((("!") reduce 197) (("\"") reduce 197) (("$") reduce 197) (("(") reduce 197) (("+") reduce 197) (("-") reduce 197) ((";") reduce 197) (("@") reduce 197) ((T_ABSTRACT) reduce 197) ((T_ARRAY) reduce 197) ((T_ARRAY_CAST) reduce 197) ((T_ATTRIBUTE) reduce 197) ((T_BOOL_CAST) reduce 197) ((T_BREAK) reduce 197) ((T_CASE) reduce 197) ((T_CLASS) reduce 197) ((T_CLASS_C) reduce 197) ((T_CLONE) reduce 197) ((T_CONSTANT_ENCAPSED_STRING) reduce 197) ((T_CONTINUE) reduce 197) ((T_DEC) reduce 197) ((T_DECLARE) reduce 197) ((T_DEFAULT) reduce 197) ((T_DIR) reduce 197) ((T_DNUMBER) reduce 197) ((T_DO) reduce 197) ((T_DOUBLE_CAST) reduce 197) ((T_ECHO) reduce 197) ((T_EMPTY) reduce 197) ((T_ENUM) reduce 197) ((T_EVAL) reduce 197) ((T_EXIT) reduce 197) ((T_FILE) reduce 197) ((T_FINAL) reduce 197) ((T_FN) reduce 197) ((T_FOR) reduce 197) ((T_FOREACH) reduce 197) ((T_FUNCTION) reduce 197) ((T_FUNC_C) reduce 197) ((T_GLOBAL) reduce 197) ((T_GOTO) reduce 197) ((T_HALT_COMPILER) reduce 197) ((T_IF) reduce 197) ((T_INC) reduce 197) ((T_INCLUDE) reduce 197) ((T_INCLUDE_ONCE) reduce 197) ((T_INLINE_HTML) reduce 197) ((T_INTERFACE) reduce 197) ((T_INT_CAST) reduce 197) ((T_ISSET) reduce 197) ((T_LINE) reduce 197) ((T_LIST) reduce 197) ((T_LNUMBER) reduce 197) ((T_MATCH) reduce 197) ((T_METHOD_C) reduce 197) ((T_NAME_FULLY_QUALIFIED) reduce 197) ((T_NAME_QUALIFIED) reduce 197) ((T_NAME_RELATIVE) reduce 197) ((T_NEW) reduce 197) ((T_NS_C) reduce 197) ((T_OBJECT_CAST) reduce 197) ((T_PRINT) reduce 197) ((T_READONLY) reduce 197) ((T_REQUIRE) reduce 197) ((T_REQUIRE_ONCE) reduce 197) ((T_RETURN) reduce 197) ((T_START_HEREDOC) reduce 197) ((T_STATIC) reduce 197) ((T_STRING) reduce 197) ((T_STRING_CAST) reduce 197) ((T_SWITCH) reduce 197) ((T_THROW) reduce 197) ((T_TRAIT) reduce 197) ((T_TRAIT_C) reduce 197) ((T_TRY) reduce 197) ((T_UNSET) reduce 197) ((T_UNSET_CAST) reduce 197) ((T_VARIABLE) reduce 197) ((T_WHILE) reduce 197) ((T_YIELD) reduce 197) ((T_YIELD_FROM) reduce 197) (("[") reduce 197) (("`") reduce 197) (("{") reduce 197) (("}") reduce 197) (("~") reduce 197)) 23946 ((("!") reduce 151) (("\"") reduce 151) (("$") reduce 151) (("(") reduce 151) (("+") reduce 151) (("-") reduce 151) ((";") reduce 151) (("@") reduce 151) ((T_ABSTRACT) reduce 151) ((T_ARRAY) reduce 151) ((T_ARRAY_CAST) reduce 151) ((T_ATTRIBUTE) reduce 151) ((T_BOOL_CAST) reduce 151) ((T_BREAK) reduce 151) ((T_CASE) reduce 151) ((T_CLASS) reduce 151) ((T_CLASS_C) reduce 151) ((T_CLONE) reduce 151) ((T_CONSTANT_ENCAPSED_STRING) reduce 151) ((T_CONTINUE) reduce 151) ((T_DEC) reduce 151) ((T_DECLARE) reduce 151) ((T_DEFAULT) reduce 151) ((T_DIR) reduce 151) ((T_DNUMBER) reduce 151) ((T_DO) reduce 151) ((T_DOUBLE_CAST) reduce 151) ((T_ECHO) reduce 151) ((T_EMPTY) reduce 151) ((T_ENUM) reduce 151) ((T_EVAL) reduce 151) ((T_EXIT) reduce 151) ((T_FILE) reduce 151) ((T_FINAL) reduce 151) ((T_FN) reduce 151) ((T_FOR) reduce 151) ((T_FOREACH) reduce 151) ((T_FUNCTION) reduce 151) ((T_FUNC_C) reduce 151) ((T_GLOBAL) reduce 151) ((T_GOTO) reduce 151) ((T_HALT_COMPILER) reduce 151) ((T_IF) reduce 151) ((T_INC) reduce 151) ((T_INCLUDE) reduce 151) ((T_INCLUDE_ONCE) reduce 151) ((T_INLINE_HTML) reduce 151) ((T_INTERFACE) reduce 151) ((T_INT_CAST) reduce 151) ((T_ISSET) reduce 151) ((T_LINE) reduce 151) ((T_LIST) reduce 151) ((T_LNUMBER) reduce 151) ((T_MATCH) reduce 151) ((T_METHOD_C) reduce 151) ((T_NAME_FULLY_QUALIFIED) reduce 151) ((T_NAME_QUALIFIED) reduce 151) ((T_NAME_RELATIVE) reduce 151) ((T_NEW) reduce 151) ((T_NS_C) reduce 151) ((T_OBJECT_CAST) reduce 151) ((T_PRINT) reduce 151) ((T_READONLY) reduce 151) ((T_REQUIRE) reduce 151) ((T_REQUIRE_ONCE) reduce 151) ((T_RETURN) reduce 151) ((T_START_HEREDOC) reduce 151) ((T_STATIC) reduce 151) ((T_STRING) reduce 151) ((T_STRING_CAST) reduce 151) ((T_SWITCH) reduce 151) ((T_THROW) reduce 151) ((T_TRAIT) reduce 151) ((T_TRAIT_C) reduce 151) ((T_TRY) reduce 151) ((T_UNSET) reduce 151) ((T_UNSET_CAST) reduce 151) ((T_VARIABLE) reduce 151) ((T_WHILE) reduce 151) ((T_YIELD) reduce 151) ((T_YIELD_FROM) reduce 151) (("[") reduce 151) (("`") reduce 151) (("{") reduce 151) (("}") reduce 151) (("~") reduce 151)) 23950 ((("!") reduce 221) (("\"") reduce 221) (("$") reduce 221) (("(") reduce 221) (("+") reduce 221) (("-") reduce 221) ((";") reduce 221) (("@") reduce 221) ((T_ABSTRACT) reduce 221) ((T_ARRAY) reduce 221) ((T_ARRAY_CAST) reduce 221) ((T_ATTRIBUTE) reduce 221) ((T_BOOL_CAST) reduce 221) ((T_BREAK) reduce 221) ((T_CASE) reduce 221) ((T_CLASS) reduce 221) ((T_CLASS_C) reduce 221) ((T_CLONE) reduce 221) ((T_CONSTANT_ENCAPSED_STRING) reduce 221) ((T_CONTINUE) reduce 221) ((T_DEC) reduce 221) ((T_DECLARE) reduce 221) ((T_DEFAULT) reduce 221) ((T_DIR) reduce 221) ((T_DNUMBER) reduce 221) ((T_DO) reduce 221) ((T_DOUBLE_CAST) reduce 221) ((T_ECHO) reduce 221) ((T_EMPTY) reduce 221) ((T_ENUM) reduce 221) ((T_EVAL) reduce 221) ((T_EXIT) reduce 221) ((T_FILE) reduce 221) ((T_FINAL) reduce 221) ((T_FN) reduce 221) ((T_FOR) reduce 221) ((T_FOREACH) reduce 221) ((T_FUNCTION) reduce 221) ((T_FUNC_C) reduce 221) ((T_GLOBAL) reduce 221) ((T_GOTO) reduce 221) ((T_HALT_COMPILER) reduce 221) ((T_IF) reduce 221) ((T_INC) reduce 221) ((T_INCLUDE) reduce 221) ((T_INCLUDE_ONCE) reduce 221) ((T_INLINE_HTML) reduce 221) ((T_INTERFACE) reduce 221) ((T_INT_CAST) reduce 221) ((T_ISSET) reduce 221) ((T_LINE) reduce 221) ((T_LIST) reduce 221) ((T_LNUMBER) reduce 221) ((T_MATCH) reduce 221) ((T_METHOD_C) reduce 221) ((T_NAME_FULLY_QUALIFIED) reduce 221) ((T_NAME_QUALIFIED) reduce 221) ((T_NAME_RELATIVE) reduce 221) ((T_NEW) reduce 221) ((T_NS_C) reduce 221) ((T_OBJECT_CAST) reduce 221) ((T_PRINT) reduce 221) ((T_READONLY) reduce 221) ((T_REQUIRE) reduce 221) ((T_REQUIRE_ONCE) reduce 221) ((T_RETURN) reduce 221) ((T_START_HEREDOC) reduce 221) ((T_STATIC) reduce 221) ((T_STRING) reduce 221) ((T_STRING_CAST) reduce 221) ((T_SWITCH) reduce 221) ((T_THROW) reduce 221) ((T_TRAIT) reduce 221) ((T_TRAIT_C) reduce 221) ((T_TRY) reduce 221) ((T_UNSET) reduce 221) ((T_UNSET_CAST) reduce 221) ((T_VARIABLE) reduce 221) ((T_WHILE) reduce 221) ((T_YIELD) reduce 221) ((T_YIELD_FROM) reduce 221) (("[") reduce 221) (("`") reduce 221) (("{") reduce 221) (("}") reduce 221) (("~") reduce 221)) 23952 ((("!") reduce 222) (("\"") reduce 222) (("$") reduce 222) (("(") reduce 222) (("+") reduce 222) (("-") reduce 222) ((";") reduce 222) (("@") reduce 222) ((T_ABSTRACT) reduce 222) ((T_ARRAY) reduce 222) ((T_ARRAY_CAST) reduce 222) ((T_ATTRIBUTE) reduce 222) ((T_BOOL_CAST) reduce 222) ((T_BREAK) reduce 222) ((T_CASE) reduce 222) ((T_CLASS) reduce 222) ((T_CLASS_C) reduce 222) ((T_CLONE) reduce 222) ((T_CONSTANT_ENCAPSED_STRING) reduce 222) ((T_CONTINUE) reduce 222) ((T_DEC) reduce 222) ((T_DECLARE) reduce 222) ((T_DEFAULT) reduce 222) ((T_DIR) reduce 222) ((T_DNUMBER) reduce 222) ((T_DO) reduce 222) ((T_DOUBLE_CAST) reduce 222) ((T_ECHO) reduce 222) ((T_EMPTY) reduce 222) ((T_ENUM) reduce 222) ((T_EVAL) reduce 222) ((T_EXIT) reduce 222) ((T_FILE) reduce 222) ((T_FINAL) reduce 222) ((T_FN) reduce 222) ((T_FOR) reduce 222) ((T_FOREACH) reduce 222) ((T_FUNCTION) reduce 222) ((T_FUNC_C) reduce 222) ((T_GLOBAL) reduce 222) ((T_GOTO) reduce 222) ((T_HALT_COMPILER) reduce 222) ((T_IF) reduce 222) ((T_INC) reduce 222) ((T_INCLUDE) reduce 222) ((T_INCLUDE_ONCE) reduce 222) ((T_INLINE_HTML) reduce 222) ((T_INTERFACE) reduce 222) ((T_INT_CAST) reduce 222) ((T_ISSET) reduce 222) ((T_LINE) reduce 222) ((T_LIST) reduce 222) ((T_LNUMBER) reduce 222) ((T_MATCH) reduce 222) ((T_METHOD_C) reduce 222) ((T_NAME_FULLY_QUALIFIED) reduce 222) ((T_NAME_QUALIFIED) reduce 222) ((T_NAME_RELATIVE) reduce 222) ((T_NEW) reduce 222) ((T_NS_C) reduce 222) ((T_OBJECT_CAST) reduce 222) ((T_PRINT) reduce 222) ((T_READONLY) reduce 222) ((T_REQUIRE) reduce 222) ((T_REQUIRE_ONCE) reduce 222) ((T_RETURN) reduce 222) ((T_START_HEREDOC) reduce 222) ((T_STATIC) reduce 222) ((T_STRING) reduce 222) ((T_STRING_CAST) reduce 222) ((T_SWITCH) reduce 222) ((T_THROW) reduce 222) ((T_TRAIT) reduce 222) ((T_TRAIT_C) reduce 222) ((T_TRY) reduce 222) ((T_UNSET) reduce 222) ((T_UNSET_CAST) reduce 222) ((T_VARIABLE) reduce 222) ((T_WHILE) reduce 222) ((T_YIELD) reduce 222) ((T_YIELD_FROM) reduce 222) (("[") reduce 222) (("`") reduce 222) (("{") reduce 222) (("}") reduce 222) (("~") reduce 222)) 23956 ((("!") reduce 223) (("\"") reduce 223) (("$") reduce 223) (("(") reduce 223) (("+") reduce 223) (("-") reduce 223) ((";") reduce 223) (("@") reduce 223) ((T_ABSTRACT) reduce 223) ((T_ARRAY) reduce 223) ((T_ARRAY_CAST) reduce 223) ((T_ATTRIBUTE) reduce 223) ((T_BOOL_CAST) reduce 223) ((T_BREAK) reduce 223) ((T_CASE) reduce 223) ((T_CLASS) reduce 223) ((T_CLASS_C) reduce 223) ((T_CLONE) reduce 223) ((T_CONSTANT_ENCAPSED_STRING) reduce 223) ((T_CONTINUE) reduce 223) ((T_DEC) reduce 223) ((T_DECLARE) reduce 223) ((T_DEFAULT) reduce 223) ((T_DIR) reduce 223) ((T_DNUMBER) reduce 223) ((T_DO) reduce 223) ((T_DOUBLE_CAST) reduce 223) ((T_ECHO) reduce 223) ((T_EMPTY) reduce 223) ((T_ENUM) reduce 223) ((T_EVAL) reduce 223) ((T_EXIT) reduce 223) ((T_FILE) reduce 223) ((T_FINAL) reduce 223) ((T_FN) reduce 223) ((T_FOR) reduce 223) ((T_FOREACH) reduce 223) ((T_FUNCTION) reduce 223) ((T_FUNC_C) reduce 223) ((T_GLOBAL) reduce 223) ((T_GOTO) reduce 223) ((T_HALT_COMPILER) reduce 223) ((T_IF) reduce 223) ((T_INC) reduce 223) ((T_INCLUDE) reduce 223) ((T_INCLUDE_ONCE) reduce 223) ((T_INLINE_HTML) reduce 223) ((T_INTERFACE) reduce 223) ((T_INT_CAST) reduce 223) ((T_ISSET) reduce 223) ((T_LINE) reduce 223) ((T_LIST) reduce 223) ((T_LNUMBER) reduce 223) ((T_MATCH) reduce 223) ((T_METHOD_C) reduce 223) ((T_NAME_FULLY_QUALIFIED) reduce 223) ((T_NAME_QUALIFIED) reduce 223) ((T_NAME_RELATIVE) reduce 223) ((T_NEW) reduce 223) ((T_NS_C) reduce 223) ((T_OBJECT_CAST) reduce 223) ((T_PRINT) reduce 223) ((T_READONLY) reduce 223) ((T_REQUIRE) reduce 223) ((T_REQUIRE_ONCE) reduce 223) ((T_RETURN) reduce 223) ((T_START_HEREDOC) reduce 223) ((T_STATIC) reduce 223) ((T_STRING) reduce 223) ((T_STRING_CAST) reduce 223) ((T_SWITCH) reduce 223) ((T_THROW) reduce 223) ((T_TRAIT) reduce 223) ((T_TRAIT_C) reduce 223) ((T_TRY) reduce 223) ((T_UNSET) reduce 223) ((T_UNSET_CAST) reduce 223) ((T_VARIABLE) reduce 223) ((T_WHILE) reduce 223) ((T_YIELD) reduce 223) ((T_YIELD_FROM) reduce 223) (("[") reduce 223) (("`") reduce 223) (("{") reduce 223) (("}") reduce 223) (("~") reduce 223)) 23959 ((("!") reduce 224) (("\"") reduce 224) (("$") reduce 224) (("(") reduce 224) (("+") reduce 224) (("-") reduce 224) ((";") reduce 224) (("@") reduce 224) ((T_ABSTRACT) reduce 224) ((T_ARRAY) reduce 224) ((T_ARRAY_CAST) reduce 224) ((T_ATTRIBUTE) reduce 224) ((T_BOOL_CAST) reduce 224) ((T_BREAK) reduce 224) ((T_CASE) reduce 224) ((T_CLASS) reduce 224) ((T_CLASS_C) reduce 224) ((T_CLONE) reduce 224) ((T_CONSTANT_ENCAPSED_STRING) reduce 224) ((T_CONTINUE) reduce 224) ((T_DEC) reduce 224) ((T_DECLARE) reduce 224) ((T_DEFAULT) reduce 224) ((T_DIR) reduce 224) ((T_DNUMBER) reduce 224) ((T_DO) reduce 224) ((T_DOUBLE_CAST) reduce 224) ((T_ECHO) reduce 224) ((T_EMPTY) reduce 224) ((T_ENUM) reduce 224) ((T_EVAL) reduce 224) ((T_EXIT) reduce 224) ((T_FILE) reduce 224) ((T_FINAL) reduce 224) ((T_FN) reduce 224) ((T_FOR) reduce 224) ((T_FOREACH) reduce 224) ((T_FUNCTION) reduce 224) ((T_FUNC_C) reduce 224) ((T_GLOBAL) reduce 224) ((T_GOTO) reduce 224) ((T_HALT_COMPILER) reduce 224) ((T_IF) reduce 224) ((T_INC) reduce 224) ((T_INCLUDE) reduce 224) ((T_INCLUDE_ONCE) reduce 224) ((T_INLINE_HTML) reduce 224) ((T_INTERFACE) reduce 224) ((T_INT_CAST) reduce 224) ((T_ISSET) reduce 224) ((T_LINE) reduce 224) ((T_LIST) reduce 224) ((T_LNUMBER) reduce 224) ((T_MATCH) reduce 224) ((T_METHOD_C) reduce 224) ((T_NAME_FULLY_QUALIFIED) reduce 224) ((T_NAME_QUALIFIED) reduce 224) ((T_NAME_RELATIVE) reduce 224) ((T_NEW) reduce 224) ((T_NS_C) reduce 224) ((T_OBJECT_CAST) reduce 224) ((T_PRINT) reduce 224) ((T_READONLY) reduce 224) ((T_REQUIRE) reduce 224) ((T_REQUIRE_ONCE) reduce 224) ((T_RETURN) reduce 224) ((T_START_HEREDOC) reduce 224) ((T_STATIC) reduce 224) ((T_STRING) reduce 224) ((T_STRING_CAST) reduce 224) ((T_SWITCH) reduce 224) ((T_THROW) reduce 224) ((T_TRAIT) reduce 224) ((T_TRAIT_C) reduce 224) ((T_TRY) reduce 224) ((T_UNSET) reduce 224) ((T_UNSET_CAST) reduce 224) ((T_VARIABLE) reduce 224) ((T_WHILE) reduce 224) ((T_YIELD) reduce 224) ((T_YIELD_FROM) reduce 224) (("[") reduce 224) (("`") reduce 224) (("{") reduce 224) (("}") reduce 224) (("~") reduce 224)) 23960 ((("!") reduce 167) (("\"") reduce 167) (("$") reduce 167) (("(") reduce 167) (("+") reduce 167) (("-") reduce 167) ((";") reduce 167) (("@") reduce 167) ((T_ABSTRACT) reduce 167) ((T_ARRAY) reduce 167) ((T_ARRAY_CAST) reduce 167) ((T_ATTRIBUTE) reduce 167) ((T_BOOL_CAST) reduce 167) ((T_BREAK) reduce 167) ((T_CASE) reduce 167) ((T_CLASS) reduce 167) ((T_CLASS_C) reduce 167) ((T_CLONE) reduce 167) ((T_CONSTANT_ENCAPSED_STRING) reduce 167) ((T_CONTINUE) reduce 167) ((T_DEC) reduce 167) ((T_DECLARE) reduce 167) ((T_DEFAULT) reduce 167) ((T_DIR) reduce 167) ((T_DNUMBER) reduce 167) ((T_DO) reduce 167) ((T_DOUBLE_CAST) reduce 167) ((T_ECHO) reduce 167) ((T_EMPTY) reduce 167) ((T_ENUM) reduce 167) ((T_EVAL) reduce 167) ((T_EXIT) reduce 167) ((T_FILE) reduce 167) ((T_FINAL) reduce 167) ((T_FN) reduce 167) ((T_FOR) reduce 167) ((T_FOREACH) reduce 167) ((T_FUNCTION) reduce 167) ((T_FUNC_C) reduce 167) ((T_GLOBAL) reduce 167) ((T_GOTO) reduce 167) ((T_HALT_COMPILER) reduce 167) ((T_IF) reduce 167) ((T_INC) reduce 167) ((T_INCLUDE) reduce 167) ((T_INCLUDE_ONCE) reduce 167) ((T_INLINE_HTML) reduce 167) ((T_INTERFACE) reduce 167) ((T_INT_CAST) reduce 167) ((T_ISSET) reduce 167) ((T_LINE) reduce 167) ((T_LIST) reduce 167) ((T_LNUMBER) reduce 167) ((T_MATCH) reduce 167) ((T_METHOD_C) reduce 167) ((T_NAME_FULLY_QUALIFIED) reduce 167) ((T_NAME_QUALIFIED) reduce 167) ((T_NAME_RELATIVE) reduce 167) ((T_NEW) reduce 167) ((T_NS_C) reduce 167) ((T_OBJECT_CAST) reduce 167) ((T_PRINT) reduce 167) ((T_READONLY) reduce 167) ((T_REQUIRE) reduce 167) ((T_REQUIRE_ONCE) reduce 167) ((T_RETURN) reduce 167) ((T_START_HEREDOC) reduce 167) ((T_STATIC) reduce 167) ((T_STRING) reduce 167) ((T_STRING_CAST) reduce 167) ((T_SWITCH) reduce 167) ((T_THROW) reduce 167) ((T_TRAIT) reduce 167) ((T_TRAIT_C) reduce 167) ((T_TRY) reduce 167) ((T_UNSET) reduce 167) ((T_UNSET_CAST) reduce 167) ((T_VARIABLE) reduce 167) ((T_WHILE) reduce 167) ((T_YIELD) reduce 167) ((T_YIELD_FROM) reduce 167) (("[") reduce 167) (("`") reduce 167) (("{") reduce 167) (("}") reduce 167) (("~") reduce 167)) 23962 ((("!") reduce 156) (("\"") reduce 156) (("$") reduce 156) (("(") reduce 156) (("+") reduce 156) (("-") reduce 156) ((";") reduce 156) (("@") reduce 156) ((T_ABSTRACT) reduce 156) ((T_ARRAY) reduce 156) ((T_ARRAY_CAST) reduce 156) ((T_ATTRIBUTE) reduce 156) ((T_BOOL_CAST) reduce 156) ((T_BREAK) reduce 156) ((T_CASE) reduce 156) ((T_CLASS) reduce 156) ((T_CLASS_C) reduce 156) ((T_CLONE) reduce 156) ((T_CONSTANT_ENCAPSED_STRING) reduce 156) ((T_CONTINUE) reduce 156) ((T_DEC) reduce 156) ((T_DECLARE) reduce 156) ((T_DEFAULT) reduce 156) ((T_DIR) reduce 156) ((T_DNUMBER) reduce 156) ((T_DO) reduce 156) ((T_DOUBLE_CAST) reduce 156) ((T_ECHO) reduce 156) ((T_EMPTY) reduce 156) ((T_ENUM) reduce 156) ((T_EVAL) reduce 156) ((T_EXIT) reduce 156) ((T_FILE) reduce 156) ((T_FINAL) reduce 156) ((T_FN) reduce 156) ((T_FOR) reduce 156) ((T_FOREACH) reduce 156) ((T_FUNCTION) reduce 156) ((T_FUNC_C) reduce 156) ((T_GLOBAL) reduce 156) ((T_GOTO) reduce 156) ((T_HALT_COMPILER) reduce 156) ((T_IF) reduce 156) ((T_INC) reduce 156) ((T_INCLUDE) reduce 156) ((T_INCLUDE_ONCE) reduce 156) ((T_INLINE_HTML) reduce 156) ((T_INTERFACE) reduce 156) ((T_INT_CAST) reduce 156) ((T_ISSET) reduce 156) ((T_LINE) reduce 156) ((T_LIST) reduce 156) ((T_LNUMBER) reduce 156) ((T_MATCH) reduce 156) ((T_METHOD_C) reduce 156) ((T_NAME_FULLY_QUALIFIED) reduce 156) ((T_NAME_QUALIFIED) reduce 156) ((T_NAME_RELATIVE) reduce 156) ((T_NEW) reduce 156) ((T_NS_C) reduce 156) ((T_OBJECT_CAST) reduce 156) ((T_PRINT) reduce 156) ((T_READONLY) reduce 156) ((T_REQUIRE) reduce 156) ((T_REQUIRE_ONCE) reduce 156) ((T_RETURN) reduce 156) ((T_START_HEREDOC) reduce 156) ((T_STATIC) reduce 156) ((T_STRING) reduce 156) ((T_STRING_CAST) reduce 156) ((T_SWITCH) reduce 156) ((T_THROW) reduce 156) ((T_TRAIT) reduce 156) ((T_TRAIT_C) reduce 156) ((T_TRY) reduce 156) ((T_UNSET) reduce 156) ((T_UNSET_CAST) reduce 156) ((T_VARIABLE) reduce 156) ((T_WHILE) reduce 156) ((T_YIELD) reduce 156) ((T_YIELD_FROM) reduce 156) (("[") reduce 156) (("`") reduce 156) (("{") reduce 156) (("}") reduce 156) (("~") reduce 156)) 23964 ((("!") reduce 154) (("\"") reduce 154) (("$") reduce 154) (("(") reduce 154) (("+") reduce 154) (("-") reduce 154) ((";") reduce 154) (("@") reduce 154) ((T_ABSTRACT) reduce 154) ((T_ARRAY) reduce 154) ((T_ARRAY_CAST) reduce 154) ((T_ATTRIBUTE) reduce 154) ((T_BOOL_CAST) reduce 154) ((T_BREAK) reduce 154) ((T_CASE) reduce 154) ((T_CLASS) reduce 154) ((T_CLASS_C) reduce 154) ((T_CLONE) reduce 154) ((T_CONSTANT_ENCAPSED_STRING) reduce 154) ((T_CONTINUE) reduce 154) ((T_DEC) reduce 154) ((T_DECLARE) reduce 154) ((T_DEFAULT) reduce 154) ((T_DIR) reduce 154) ((T_DNUMBER) reduce 154) ((T_DO) reduce 154) ((T_DOUBLE_CAST) reduce 154) ((T_ECHO) reduce 154) ((T_EMPTY) reduce 154) ((T_ENUM) reduce 154) ((T_EVAL) reduce 154) ((T_EXIT) reduce 154) ((T_FILE) reduce 154) ((T_FINAL) reduce 154) ((T_FN) reduce 154) ((T_FOR) reduce 154) ((T_FOREACH) reduce 154) ((T_FUNCTION) reduce 154) ((T_FUNC_C) reduce 154) ((T_GLOBAL) reduce 154) ((T_GOTO) reduce 154) ((T_HALT_COMPILER) reduce 154) ((T_IF) reduce 154) ((T_INC) reduce 154) ((T_INCLUDE) reduce 154) ((T_INCLUDE_ONCE) reduce 154) ((T_INLINE_HTML) reduce 154) ((T_INTERFACE) reduce 154) ((T_INT_CAST) reduce 154) ((T_ISSET) reduce 154) ((T_LINE) reduce 154) ((T_LIST) reduce 154) ((T_LNUMBER) reduce 154) ((T_MATCH) reduce 154) ((T_METHOD_C) reduce 154) ((T_NAME_FULLY_QUALIFIED) reduce 154) ((T_NAME_QUALIFIED) reduce 154) ((T_NAME_RELATIVE) reduce 154) ((T_NEW) reduce 154) ((T_NS_C) reduce 154) ((T_OBJECT_CAST) reduce 154) ((T_PRINT) reduce 154) ((T_READONLY) reduce 154) ((T_REQUIRE) reduce 154) ((T_REQUIRE_ONCE) reduce 154) ((T_RETURN) reduce 154) ((T_START_HEREDOC) reduce 154) ((T_STATIC) reduce 154) ((T_STRING) reduce 154) ((T_STRING_CAST) reduce 154) ((T_SWITCH) reduce 154) ((T_THROW) reduce 154) ((T_TRAIT) reduce 154) ((T_TRAIT_C) reduce 154) ((T_TRY) reduce 154) ((T_UNSET) reduce 154) ((T_UNSET_CAST) reduce 154) ((T_VARIABLE) reduce 154) ((T_WHILE) reduce 154) ((T_YIELD) reduce 154) ((T_YIELD_FROM) reduce 154) (("[") reduce 154) (("`") reduce 154) (("{") reduce 154) (("}") reduce 154) (("~") reduce 154)) 23970 ((("!") reduce 198) (("\"") reduce 198) (("$") reduce 198) (("(") reduce 198) (("+") reduce 198) (("-") reduce 198) ((";") reduce 198) (("@") reduce 198) ((T_ABSTRACT) reduce 198) ((T_ARRAY) reduce 198) ((T_ARRAY_CAST) reduce 198) ((T_ATTRIBUTE) reduce 198) ((T_BOOL_CAST) reduce 198) ((T_BREAK) reduce 198) ((T_CASE) reduce 198) ((T_CLASS) reduce 198) ((T_CLASS_C) reduce 198) ((T_CLONE) reduce 198) ((T_CONSTANT_ENCAPSED_STRING) reduce 198) ((T_CONTINUE) reduce 198) ((T_DEC) reduce 198) ((T_DECLARE) reduce 198) ((T_DEFAULT) reduce 198) ((T_DIR) reduce 198) ((T_DNUMBER) reduce 198) ((T_DO) reduce 198) ((T_DOUBLE_CAST) reduce 198) ((T_ECHO) reduce 198) ((T_EMPTY) reduce 198) ((T_ENUM) reduce 198) ((T_EVAL) reduce 198) ((T_EXIT) reduce 198) ((T_FILE) reduce 198) ((T_FINAL) reduce 198) ((T_FN) reduce 198) ((T_FOR) reduce 198) ((T_FOREACH) reduce 198) ((T_FUNCTION) reduce 198) ((T_FUNC_C) reduce 198) ((T_GLOBAL) reduce 198) ((T_GOTO) reduce 198) ((T_HALT_COMPILER) reduce 198) ((T_IF) reduce 198) ((T_INC) reduce 198) ((T_INCLUDE) reduce 198) ((T_INCLUDE_ONCE) reduce 198) ((T_INLINE_HTML) reduce 198) ((T_INTERFACE) reduce 198) ((T_INT_CAST) reduce 198) ((T_ISSET) reduce 198) ((T_LINE) reduce 198) ((T_LIST) reduce 198) ((T_LNUMBER) reduce 198) ((T_MATCH) reduce 198) ((T_METHOD_C) reduce 198) ((T_NAME_FULLY_QUALIFIED) reduce 198) ((T_NAME_QUALIFIED) reduce 198) ((T_NAME_RELATIVE) reduce 198) ((T_NEW) reduce 198) ((T_NS_C) reduce 198) ((T_OBJECT_CAST) reduce 198) ((T_PRINT) reduce 198) ((T_READONLY) reduce 198) ((T_REQUIRE) reduce 198) ((T_REQUIRE_ONCE) reduce 198) ((T_RETURN) reduce 198) ((T_START_HEREDOC) reduce 198) ((T_STATIC) reduce 198) ((T_STRING) reduce 198) ((T_STRING_CAST) reduce 198) ((T_SWITCH) reduce 198) ((T_THROW) reduce 198) ((T_TRAIT) reduce 198) ((T_TRAIT_C) reduce 198) ((T_TRY) reduce 198) ((T_UNSET) reduce 198) ((T_UNSET_CAST) reduce 198) ((T_VARIABLE) reduce 198) ((T_WHILE) reduce 198) ((T_YIELD) reduce 198) ((T_YIELD_FROM) reduce 198) (("[") reduce 198) (("`") reduce 198) (("{") reduce 198) (("}") reduce 198) (("~") reduce 198)) 23974 ((("!") reduce 241) (("\"") reduce 241) (("$") reduce 241) (("(") reduce 241) (("+") reduce 241) (("-") reduce 241) ((";") reduce 241) (("@") reduce 241) ((T_ABSTRACT) reduce 241) ((T_ARRAY) reduce 241) ((T_ARRAY_CAST) reduce 241) ((T_ATTRIBUTE) reduce 241) ((T_BOOL_CAST) reduce 241) ((T_BREAK) reduce 241) ((T_CASE) reduce 241) ((T_CLASS) reduce 241) ((T_CLASS_C) reduce 241) ((T_CLONE) reduce 241) ((T_CONSTANT_ENCAPSED_STRING) reduce 241) ((T_CONTINUE) reduce 241) ((T_DEC) reduce 241) ((T_DECLARE) reduce 241) ((T_DEFAULT) reduce 241) ((T_DIR) reduce 241) ((T_DNUMBER) reduce 241) ((T_DO) reduce 241) ((T_DOUBLE_CAST) reduce 241) ((T_ECHO) reduce 241) ((T_ELSE) reduce 241) ((T_ELSEIF) reduce 241) ((T_EMPTY) reduce 241) ((T_ENUM) reduce 241) ((T_EVAL) reduce 241) ((T_EXIT) reduce 241) ((T_FILE) reduce 241) ((T_FINAL) reduce 241) ((T_FN) reduce 241) ((T_FOR) reduce 241) ((T_FOREACH) reduce 241) ((T_FUNCTION) reduce 241) ((T_FUNC_C) reduce 241) ((T_GLOBAL) reduce 241) ((T_GOTO) reduce 241) ((T_HALT_COMPILER) reduce 241) ((T_IF) reduce 241) ((T_INC) reduce 241) ((T_INCLUDE) reduce 241) ((T_INCLUDE_ONCE) reduce 241) ((T_INLINE_HTML) reduce 241) ((T_INTERFACE) reduce 241) ((T_INT_CAST) reduce 241) ((T_ISSET) reduce 241) ((T_LINE) reduce 241) ((T_LIST) reduce 241) ((T_LNUMBER) reduce 241) ((T_MATCH) reduce 241) ((T_METHOD_C) reduce 241) ((T_NAME_FULLY_QUALIFIED) reduce 241) ((T_NAME_QUALIFIED) reduce 241) ((T_NAME_RELATIVE) reduce 241) ((T_NEW) reduce 241) ((T_NS_C) reduce 241) ((T_OBJECT_CAST) reduce 241) ((T_PRINT) reduce 241) ((T_READONLY) reduce 241) ((T_REQUIRE) reduce 241) ((T_REQUIRE_ONCE) reduce 241) ((T_RETURN) reduce 241) ((T_START_HEREDOC) reduce 241) ((T_STATIC) reduce 241) ((T_STRING) reduce 241) ((T_STRING_CAST) reduce 241) ((T_SWITCH) reduce 241) ((T_THROW) reduce 241) ((T_TRAIT) reduce 241) ((T_TRAIT_C) reduce 241) ((T_TRY) reduce 241) ((T_UNSET) reduce 241) ((T_UNSET_CAST) reduce 241) ((T_VARIABLE) reduce 241) ((T_WHILE) reduce 241) ((T_YIELD) reduce 241) ((T_YIELD_FROM) reduce 241) (("[") reduce 241) (("`") reduce 241) (("{") reduce 241) (("}") reduce 241) (("~") reduce 241)) 23977 ((("!") reduce 144) (("\"") reduce 144) (("$") reduce 144) (("(") reduce 144) (("+") reduce 144) (("-") reduce 144) ((";") reduce 144) (("@") reduce 144) ((T_ABSTRACT) reduce 144) ((T_ARRAY) reduce 144) ((T_ARRAY_CAST) reduce 144) ((T_ATTRIBUTE) reduce 144) ((T_BOOL_CAST) reduce 144) ((T_BREAK) reduce 144) ((T_CASE) reduce 144) ((T_CLASS) reduce 144) ((T_CLASS_C) reduce 144) ((T_CLONE) reduce 144) ((T_CONSTANT_ENCAPSED_STRING) reduce 144) ((T_CONTINUE) reduce 144) ((T_DEC) reduce 144) ((T_DECLARE) reduce 144) ((T_DEFAULT) reduce 144) ((T_DIR) reduce 144) ((T_DNUMBER) reduce 144) ((T_DO) reduce 144) ((T_DOUBLE_CAST) reduce 144) ((T_ECHO) reduce 144) ((T_EMPTY) reduce 144) ((T_ENUM) reduce 144) ((T_EVAL) reduce 144) ((T_EXIT) reduce 144) ((T_FILE) reduce 144) ((T_FINAL) reduce 144) ((T_FN) reduce 144) ((T_FOR) reduce 144) ((T_FOREACH) reduce 144) ((T_FUNCTION) reduce 144) ((T_FUNC_C) reduce 144) ((T_GLOBAL) reduce 144) ((T_GOTO) reduce 144) ((T_HALT_COMPILER) reduce 144) ((T_IF) reduce 144) ((T_INC) reduce 144) ((T_INCLUDE) reduce 144) ((T_INCLUDE_ONCE) reduce 144) ((T_INLINE_HTML) reduce 144) ((T_INTERFACE) reduce 144) ((T_INT_CAST) reduce 144) ((T_ISSET) reduce 144) ((T_LINE) reduce 144) ((T_LIST) reduce 144) ((T_LNUMBER) reduce 144) ((T_MATCH) reduce 144) ((T_METHOD_C) reduce 144) ((T_NAME_FULLY_QUALIFIED) reduce 144) ((T_NAME_QUALIFIED) reduce 144) ((T_NAME_RELATIVE) reduce 144) ((T_NEW) reduce 144) ((T_NS_C) reduce 144) ((T_OBJECT_CAST) reduce 144) ((T_PRINT) reduce 144) ((T_READONLY) reduce 144) ((T_REQUIRE) reduce 144) ((T_REQUIRE_ONCE) reduce 144) ((T_RETURN) reduce 144) ((T_START_HEREDOC) reduce 144) ((T_STATIC) reduce 144) ((T_STRING) reduce 144) ((T_STRING_CAST) reduce 144) ((T_SWITCH) reduce 144) ((T_THROW) reduce 144) ((T_TRAIT) reduce 144) ((T_TRAIT_C) reduce 144) ((T_TRY) reduce 144) ((T_UNSET) reduce 144) ((T_UNSET_CAST) reduce 144) ((T_VARIABLE) reduce 144) ((T_WHILE) reduce 144) ((T_YIELD) reduce 144) ((T_YIELD_FROM) reduce 144) (("[") reduce 144) (("`") reduce 144) (("{") reduce 144) (("}") reduce 144) (("~") reduce 144)) 23979 ((("!") reduce 166) (("\"") reduce 166) (("$") reduce 166) (("(") reduce 166) (("+") reduce 166) (("-") reduce 166) ((";") reduce 166) (("@") reduce 166) ((T_ABSTRACT) reduce 166) ((T_ARRAY) reduce 166) ((T_ARRAY_CAST) reduce 166) ((T_ATTRIBUTE) reduce 166) ((T_BOOL_CAST) reduce 166) ((T_BREAK) reduce 166) ((T_CASE) reduce 166) ((T_CLASS) reduce 166) ((T_CLASS_C) reduce 166) ((T_CLONE) reduce 166) ((T_CONSTANT_ENCAPSED_STRING) reduce 166) ((T_CONTINUE) reduce 166) ((T_DEC) reduce 166) ((T_DECLARE) reduce 166) ((T_DEFAULT) reduce 166) ((T_DIR) reduce 166) ((T_DNUMBER) reduce 166) ((T_DO) reduce 166) ((T_DOUBLE_CAST) reduce 166) ((T_ECHO) reduce 166) ((T_EMPTY) reduce 166) ((T_ENUM) reduce 166) ((T_EVAL) reduce 166) ((T_EXIT) reduce 166) ((T_FILE) reduce 166) ((T_FINAL) reduce 166) ((T_FN) reduce 166) ((T_FOR) reduce 166) ((T_FOREACH) reduce 166) ((T_FUNCTION) reduce 166) ((T_FUNC_C) reduce 166) ((T_GLOBAL) reduce 166) ((T_GOTO) reduce 166) ((T_HALT_COMPILER) reduce 166) ((T_IF) reduce 166) ((T_INC) reduce 166) ((T_INCLUDE) reduce 166) ((T_INCLUDE_ONCE) reduce 166) ((T_INLINE_HTML) reduce 166) ((T_INTERFACE) reduce 166) ((T_INT_CAST) reduce 166) ((T_ISSET) reduce 166) ((T_LINE) reduce 166) ((T_LIST) reduce 166) ((T_LNUMBER) reduce 166) ((T_MATCH) reduce 166) ((T_METHOD_C) reduce 166) ((T_NAME_FULLY_QUALIFIED) reduce 166) ((T_NAME_QUALIFIED) reduce 166) ((T_NAME_RELATIVE) reduce 166) ((T_NEW) reduce 166) ((T_NS_C) reduce 166) ((T_OBJECT_CAST) reduce 166) ((T_PRINT) reduce 166) ((T_READONLY) reduce 166) ((T_REQUIRE) reduce 166) ((T_REQUIRE_ONCE) reduce 166) ((T_RETURN) reduce 166) ((T_START_HEREDOC) reduce 166) ((T_STATIC) reduce 166) ((T_STRING) reduce 166) ((T_STRING_CAST) reduce 166) ((T_SWITCH) reduce 166) ((T_THROW) reduce 166) ((T_TRAIT) reduce 166) ((T_TRAIT_C) reduce 166) ((T_TRY) reduce 166) ((T_UNSET) reduce 166) ((T_UNSET_CAST) reduce 166) ((T_VARIABLE) reduce 166) ((T_WHILE) reduce 166) ((T_YIELD) reduce 166) ((T_YIELD_FROM) reduce 166) (("[") reduce 166) (("`") reduce 166) (("{") reduce 166) (("}") reduce 166) (("~") reduce 166)) 23981 ((("!") reduce 155) (("\"") reduce 155) (("$") reduce 155) (("(") reduce 155) (("+") reduce 155) (("-") reduce 155) ((";") reduce 155) (("@") reduce 155) ((T_ABSTRACT) reduce 155) ((T_ARRAY) reduce 155) ((T_ARRAY_CAST) reduce 155) ((T_ATTRIBUTE) reduce 155) ((T_BOOL_CAST) reduce 155) ((T_BREAK) reduce 155) ((T_CASE) reduce 155) ((T_CLASS) reduce 155) ((T_CLASS_C) reduce 155) ((T_CLONE) reduce 155) ((T_CONSTANT_ENCAPSED_STRING) reduce 155) ((T_CONTINUE) reduce 155) ((T_DEC) reduce 155) ((T_DECLARE) reduce 155) ((T_DEFAULT) reduce 155) ((T_DIR) reduce 155) ((T_DNUMBER) reduce 155) ((T_DO) reduce 155) ((T_DOUBLE_CAST) reduce 155) ((T_ECHO) reduce 155) ((T_EMPTY) reduce 155) ((T_ENUM) reduce 155) ((T_EVAL) reduce 155) ((T_EXIT) reduce 155) ((T_FILE) reduce 155) ((T_FINAL) reduce 155) ((T_FN) reduce 155) ((T_FOR) reduce 155) ((T_FOREACH) reduce 155) ((T_FUNCTION) reduce 155) ((T_FUNC_C) reduce 155) ((T_GLOBAL) reduce 155) ((T_GOTO) reduce 155) ((T_HALT_COMPILER) reduce 155) ((T_IF) reduce 155) ((T_INC) reduce 155) ((T_INCLUDE) reduce 155) ((T_INCLUDE_ONCE) reduce 155) ((T_INLINE_HTML) reduce 155) ((T_INTERFACE) reduce 155) ((T_INT_CAST) reduce 155) ((T_ISSET) reduce 155) ((T_LINE) reduce 155) ((T_LIST) reduce 155) ((T_LNUMBER) reduce 155) ((T_MATCH) reduce 155) ((T_METHOD_C) reduce 155) ((T_NAME_FULLY_QUALIFIED) reduce 155) ((T_NAME_QUALIFIED) reduce 155) ((T_NAME_RELATIVE) reduce 155) ((T_NEW) reduce 155) ((T_NS_C) reduce 155) ((T_OBJECT_CAST) reduce 155) ((T_PRINT) reduce 155) ((T_READONLY) reduce 155) ((T_REQUIRE) reduce 155) ((T_REQUIRE_ONCE) reduce 155) ((T_RETURN) reduce 155) ((T_START_HEREDOC) reduce 155) ((T_STATIC) reduce 155) ((T_STRING) reduce 155) ((T_STRING_CAST) reduce 155) ((T_SWITCH) reduce 155) ((T_THROW) reduce 155) ((T_TRAIT) reduce 155) ((T_TRAIT_C) reduce 155) ((T_TRY) reduce 155) ((T_UNSET) reduce 155) ((T_UNSET_CAST) reduce 155) ((T_VARIABLE) reduce 155) ((T_WHILE) reduce 155) ((T_YIELD) reduce 155) ((T_YIELD_FROM) reduce 155) (("[") reduce 155) (("`") reduce 155) (("{") reduce 155) (("}") reduce 155) (("~") reduce 155)) 23991 ((("!") reduce 162) (("\"") reduce 162) (("$") reduce 162) (("(") reduce 162) (("+") reduce 162) (("-") reduce 162) ((";") reduce 162) (("@") reduce 162) ((T_ABSTRACT) reduce 162) ((T_ARRAY) reduce 162) ((T_ARRAY_CAST) reduce 162) ((T_ATTRIBUTE) reduce 162) ((T_BOOL_CAST) reduce 162) ((T_BREAK) reduce 162) ((T_CASE) reduce 162) ((T_CLASS) reduce 162) ((T_CLASS_C) reduce 162) ((T_CLONE) reduce 162) ((T_CONSTANT_ENCAPSED_STRING) reduce 162) ((T_CONTINUE) reduce 162) ((T_DEC) reduce 162) ((T_DECLARE) reduce 162) ((T_DEFAULT) reduce 162) ((T_DIR) reduce 162) ((T_DNUMBER) reduce 162) ((T_DO) reduce 162) ((T_DOUBLE_CAST) reduce 162) ((T_ECHO) reduce 162) ((T_EMPTY) reduce 162) ((T_ENUM) reduce 162) ((T_EVAL) reduce 162) ((T_EXIT) reduce 162) ((T_FILE) reduce 162) ((T_FINAL) reduce 162) ((T_FN) reduce 162) ((T_FOR) reduce 162) ((T_FOREACH) reduce 162) ((T_FUNCTION) reduce 162) ((T_FUNC_C) reduce 162) ((T_GLOBAL) reduce 162) ((T_GOTO) reduce 162) ((T_HALT_COMPILER) reduce 162) ((T_IF) reduce 162) ((T_INC) reduce 162) ((T_INCLUDE) reduce 162) ((T_INCLUDE_ONCE) reduce 162) ((T_INLINE_HTML) reduce 162) ((T_INTERFACE) reduce 162) ((T_INT_CAST) reduce 162) ((T_ISSET) reduce 162) ((T_LINE) reduce 162) ((T_LIST) reduce 162) ((T_LNUMBER) reduce 162) ((T_MATCH) reduce 162) ((T_METHOD_C) reduce 162) ((T_NAME_FULLY_QUALIFIED) reduce 162) ((T_NAME_QUALIFIED) reduce 162) ((T_NAME_RELATIVE) reduce 162) ((T_NEW) reduce 162) ((T_NS_C) reduce 162) ((T_OBJECT_CAST) reduce 162) ((T_PRINT) reduce 162) ((T_READONLY) reduce 162) ((T_REQUIRE) reduce 162) ((T_REQUIRE_ONCE) reduce 162) ((T_RETURN) reduce 162) ((T_START_HEREDOC) reduce 162) ((T_STATIC) reduce 162) ((T_STRING) reduce 162) ((T_STRING_CAST) reduce 162) ((T_SWITCH) reduce 162) ((T_THROW) reduce 162) ((T_TRAIT) reduce 162) ((T_TRAIT_C) reduce 162) ((T_TRY) reduce 162) ((T_UNSET) reduce 162) ((T_UNSET_CAST) reduce 162) ((T_VARIABLE) reduce 162) ((T_WHILE) reduce 162) ((T_YIELD) reduce 162) ((T_YIELD_FROM) reduce 162) (("[") reduce 162) (("`") reduce 162) (("{") reduce 162) (("}") reduce 162) (("~") reduce 162)) 23992 ((("!") reduce 217) (("\"") reduce 217) (("$") reduce 217) (("(") reduce 217) (("+") reduce 217) (("-") reduce 217) ((";") reduce 217) (("@") reduce 217) ((T_ABSTRACT) reduce 217) ((T_ARRAY) reduce 217) ((T_ARRAY_CAST) reduce 217) ((T_ATTRIBUTE) reduce 217) ((T_BOOL_CAST) reduce 217) ((T_BREAK) reduce 217) ((T_CASE) reduce 217) ((T_CLASS) reduce 217) ((T_CLASS_C) reduce 217) ((T_CLONE) reduce 217) ((T_CONSTANT_ENCAPSED_STRING) reduce 217) ((T_CONTINUE) reduce 217) ((T_DEC) reduce 217) ((T_DECLARE) reduce 217) ((T_DEFAULT) reduce 217) ((T_DIR) reduce 217) ((T_DNUMBER) reduce 217) ((T_DO) reduce 217) ((T_DOUBLE_CAST) reduce 217) ((T_ECHO) reduce 217) ((T_EMPTY) reduce 217) ((T_ENUM) reduce 217) ((T_EVAL) reduce 217) ((T_EXIT) reduce 217) ((T_FILE) reduce 217) ((T_FINAL) reduce 217) ((T_FN) reduce 217) ((T_FOR) reduce 217) ((T_FOREACH) reduce 217) ((T_FUNCTION) reduce 217) ((T_FUNC_C) reduce 217) ((T_GLOBAL) reduce 217) ((T_GOTO) reduce 217) ((T_HALT_COMPILER) reduce 217) ((T_IF) reduce 217) ((T_INC) reduce 217) ((T_INCLUDE) reduce 217) ((T_INCLUDE_ONCE) reduce 217) ((T_INLINE_HTML) reduce 217) ((T_INTERFACE) reduce 217) ((T_INT_CAST) reduce 217) ((T_ISSET) reduce 217) ((T_LINE) reduce 217) ((T_LIST) reduce 217) ((T_LNUMBER) reduce 217) ((T_MATCH) reduce 217) ((T_METHOD_C) reduce 217) ((T_NAME_FULLY_QUALIFIED) reduce 217) ((T_NAME_QUALIFIED) reduce 217) ((T_NAME_RELATIVE) reduce 217) ((T_NEW) reduce 217) ((T_NS_C) reduce 217) ((T_OBJECT_CAST) reduce 217) ((T_PRINT) reduce 217) ((T_READONLY) reduce 217) ((T_REQUIRE) reduce 217) ((T_REQUIRE_ONCE) reduce 217) ((T_RETURN) reduce 217) ((T_START_HEREDOC) reduce 217) ((T_STATIC) reduce 217) ((T_STRING) reduce 217) ((T_STRING_CAST) reduce 217) ((T_SWITCH) reduce 217) ((T_THROW) reduce 217) ((T_TRAIT) reduce 217) ((T_TRAIT_C) reduce 217) ((T_TRY) reduce 217) ((T_UNSET) reduce 217) ((T_UNSET_CAST) reduce 217) ((T_VARIABLE) reduce 217) ((T_WHILE) reduce 217) ((T_YIELD) reduce 217) ((T_YIELD_FROM) reduce 217) (("[") reduce 217) (("`") reduce 217) (("{") reduce 217) (("}") reduce 217) (("~") reduce 217)) 23995 ((("!") reduce 218) (("\"") reduce 218) (("$") reduce 218) (("(") reduce 218) (("+") reduce 218) (("-") reduce 218) ((";") reduce 218) (("@") reduce 218) ((T_ABSTRACT) reduce 218) ((T_ARRAY) reduce 218) ((T_ARRAY_CAST) reduce 218) ((T_ATTRIBUTE) reduce 218) ((T_BOOL_CAST) reduce 218) ((T_BREAK) reduce 218) ((T_CASE) reduce 218) ((T_CLASS) reduce 218) ((T_CLASS_C) reduce 218) ((T_CLONE) reduce 218) ((T_CONSTANT_ENCAPSED_STRING) reduce 218) ((T_CONTINUE) reduce 218) ((T_DEC) reduce 218) ((T_DECLARE) reduce 218) ((T_DEFAULT) reduce 218) ((T_DIR) reduce 218) ((T_DNUMBER) reduce 218) ((T_DO) reduce 218) ((T_DOUBLE_CAST) reduce 218) ((T_ECHO) reduce 218) ((T_EMPTY) reduce 218) ((T_ENUM) reduce 218) ((T_EVAL) reduce 218) ((T_EXIT) reduce 218) ((T_FILE) reduce 218) ((T_FINAL) reduce 218) ((T_FN) reduce 218) ((T_FOR) reduce 218) ((T_FOREACH) reduce 218) ((T_FUNCTION) reduce 218) ((T_FUNC_C) reduce 218) ((T_GLOBAL) reduce 218) ((T_GOTO) reduce 218) ((T_HALT_COMPILER) reduce 218) ((T_IF) reduce 218) ((T_INC) reduce 218) ((T_INCLUDE) reduce 218) ((T_INCLUDE_ONCE) reduce 218) ((T_INLINE_HTML) reduce 218) ((T_INTERFACE) reduce 218) ((T_INT_CAST) reduce 218) ((T_ISSET) reduce 218) ((T_LINE) reduce 218) ((T_LIST) reduce 218) ((T_LNUMBER) reduce 218) ((T_MATCH) reduce 218) ((T_METHOD_C) reduce 218) ((T_NAME_FULLY_QUALIFIED) reduce 218) ((T_NAME_QUALIFIED) reduce 218) ((T_NAME_RELATIVE) reduce 218) ((T_NEW) reduce 218) ((T_NS_C) reduce 218) ((T_OBJECT_CAST) reduce 218) ((T_PRINT) reduce 218) ((T_READONLY) reduce 218) ((T_REQUIRE) reduce 218) ((T_REQUIRE_ONCE) reduce 218) ((T_RETURN) reduce 218) ((T_START_HEREDOC) reduce 218) ((T_STATIC) reduce 218) ((T_STRING) reduce 218) ((T_STRING_CAST) reduce 218) ((T_SWITCH) reduce 218) ((T_THROW) reduce 218) ((T_TRAIT) reduce 218) ((T_TRAIT_C) reduce 218) ((T_TRY) reduce 218) ((T_UNSET) reduce 218) ((T_UNSET_CAST) reduce 218) ((T_VARIABLE) reduce 218) ((T_WHILE) reduce 218) ((T_YIELD) reduce 218) ((T_YIELD_FROM) reduce 218) (("[") reduce 218) (("`") reduce 218) (("{") reduce 218) (("}") reduce 218) (("~") reduce 218)) 23996 ((("!") reduce 161) (("\"") reduce 161) (("$") reduce 161) (("(") reduce 161) (("+") reduce 161) (("-") reduce 161) ((";") reduce 161) (("@") reduce 161) ((T_ABSTRACT) reduce 161) ((T_ARRAY) reduce 161) ((T_ARRAY_CAST) reduce 161) ((T_ATTRIBUTE) reduce 161) ((T_BOOL_CAST) reduce 161) ((T_BREAK) reduce 161) ((T_CASE) reduce 161) ((T_CLASS) reduce 161) ((T_CLASS_C) reduce 161) ((T_CLONE) reduce 161) ((T_CONSTANT_ENCAPSED_STRING) reduce 161) ((T_CONTINUE) reduce 161) ((T_DEC) reduce 161) ((T_DECLARE) reduce 161) ((T_DEFAULT) reduce 161) ((T_DIR) reduce 161) ((T_DNUMBER) reduce 161) ((T_DO) reduce 161) ((T_DOUBLE_CAST) reduce 161) ((T_ECHO) reduce 161) ((T_EMPTY) reduce 161) ((T_ENUM) reduce 161) ((T_EVAL) reduce 161) ((T_EXIT) reduce 161) ((T_FILE) reduce 161) ((T_FINAL) reduce 161) ((T_FN) reduce 161) ((T_FOR) reduce 161) ((T_FOREACH) reduce 161) ((T_FUNCTION) reduce 161) ((T_FUNC_C) reduce 161) ((T_GLOBAL) reduce 161) ((T_GOTO) reduce 161) ((T_HALT_COMPILER) reduce 161) ((T_IF) reduce 161) ((T_INC) reduce 161) ((T_INCLUDE) reduce 161) ((T_INCLUDE_ONCE) reduce 161) ((T_INLINE_HTML) reduce 161) ((T_INTERFACE) reduce 161) ((T_INT_CAST) reduce 161) ((T_ISSET) reduce 161) ((T_LINE) reduce 161) ((T_LIST) reduce 161) ((T_LNUMBER) reduce 161) ((T_MATCH) reduce 161) ((T_METHOD_C) reduce 161) ((T_NAME_FULLY_QUALIFIED) reduce 161) ((T_NAME_QUALIFIED) reduce 161) ((T_NAME_RELATIVE) reduce 161) ((T_NEW) reduce 161) ((T_NS_C) reduce 161) ((T_OBJECT_CAST) reduce 161) ((T_PRINT) reduce 161) ((T_READONLY) reduce 161) ((T_REQUIRE) reduce 161) ((T_REQUIRE_ONCE) reduce 161) ((T_RETURN) reduce 161) ((T_START_HEREDOC) reduce 161) ((T_STATIC) reduce 161) ((T_STRING) reduce 161) ((T_STRING_CAST) reduce 161) ((T_SWITCH) reduce 161) ((T_THROW) reduce 161) ((T_TRAIT) reduce 161) ((T_TRAIT_C) reduce 161) ((T_TRY) reduce 161) ((T_UNSET) reduce 161) ((T_UNSET_CAST) reduce 161) ((T_VARIABLE) reduce 161) ((T_WHILE) reduce 161) ((T_YIELD) reduce 161) ((T_YIELD_FROM) reduce 161) (("[") reduce 161) (("`") reduce 161) (("{") reduce 161) (("}") reduce 161) (("~") reduce 161)) 24005 ((("!") reduce 150) (("\"") reduce 150) (("$") reduce 150) (("(") reduce 150) (("+") reduce 150) (("-") reduce 150) ((";") reduce 150) (("@") reduce 150) ((T_ABSTRACT) reduce 150) ((T_ARRAY) reduce 150) ((T_ARRAY_CAST) reduce 150) ((T_ATTRIBUTE) reduce 150) ((T_BOOL_CAST) reduce 150) ((T_BREAK) reduce 150) ((T_CASE) reduce 150) ((T_CLASS) reduce 150) ((T_CLASS_C) reduce 150) ((T_CLONE) reduce 150) ((T_CONSTANT_ENCAPSED_STRING) reduce 150) ((T_CONTINUE) reduce 150) ((T_DEC) reduce 150) ((T_DECLARE) reduce 150) ((T_DEFAULT) reduce 150) ((T_DIR) reduce 150) ((T_DNUMBER) reduce 150) ((T_DO) reduce 150) ((T_DOUBLE_CAST) reduce 150) ((T_ECHO) reduce 150) ((T_EMPTY) reduce 150) ((T_ENUM) reduce 150) ((T_EVAL) reduce 150) ((T_EXIT) reduce 150) ((T_FILE) reduce 150) ((T_FINAL) reduce 150) ((T_FN) reduce 150) ((T_FOR) reduce 150) ((T_FOREACH) reduce 150) ((T_FUNCTION) reduce 150) ((T_FUNC_C) reduce 150) ((T_GLOBAL) reduce 150) ((T_GOTO) reduce 150) ((T_HALT_COMPILER) reduce 150) ((T_IF) reduce 150) ((T_INC) reduce 150) ((T_INCLUDE) reduce 150) ((T_INCLUDE_ONCE) reduce 150) ((T_INLINE_HTML) reduce 150) ((T_INTERFACE) reduce 150) ((T_INT_CAST) reduce 150) ((T_ISSET) reduce 150) ((T_LINE) reduce 150) ((T_LIST) reduce 150) ((T_LNUMBER) reduce 150) ((T_MATCH) reduce 150) ((T_METHOD_C) reduce 150) ((T_NAME_FULLY_QUALIFIED) reduce 150) ((T_NAME_QUALIFIED) reduce 150) ((T_NAME_RELATIVE) reduce 150) ((T_NEW) reduce 150) ((T_NS_C) reduce 150) ((T_OBJECT_CAST) reduce 150) ((T_PRINT) reduce 150) ((T_READONLY) reduce 150) ((T_REQUIRE) reduce 150) ((T_REQUIRE_ONCE) reduce 150) ((T_RETURN) reduce 150) ((T_START_HEREDOC) reduce 150) ((T_STATIC) reduce 150) ((T_STRING) reduce 150) ((T_STRING_CAST) reduce 150) ((T_SWITCH) reduce 150) ((T_THROW) reduce 150) ((T_TRAIT) reduce 150) ((T_TRAIT_C) reduce 150) ((T_TRY) reduce 150) ((T_UNSET) reduce 150) ((T_UNSET_CAST) reduce 150) ((T_VARIABLE) reduce 150) ((T_WHILE) reduce 150) ((T_YIELD) reduce 150) ((T_YIELD_FROM) reduce 150) (("[") reduce 150) (("`") reduce 150) (("{") reduce 150) (("}") reduce 150) (("~") reduce 150)) 24006 ((("!") reduce 215) (("\"") reduce 215) (("$") reduce 215) (("(") reduce 215) (("+") reduce 215) (("-") reduce 215) ((";") reduce 215) (("@") reduce 215) ((T_ABSTRACT) reduce 215) ((T_ARRAY) reduce 215) ((T_ARRAY_CAST) reduce 215) ((T_ATTRIBUTE) reduce 215) ((T_BOOL_CAST) reduce 215) ((T_BREAK) reduce 215) ((T_CASE) reduce 215) ((T_CLASS) reduce 215) ((T_CLASS_C) reduce 215) ((T_CLONE) reduce 215) ((T_CONSTANT_ENCAPSED_STRING) reduce 215) ((T_CONTINUE) reduce 215) ((T_DEC) reduce 215) ((T_DECLARE) reduce 215) ((T_DEFAULT) reduce 215) ((T_DIR) reduce 215) ((T_DNUMBER) reduce 215) ((T_DO) reduce 215) ((T_DOUBLE_CAST) reduce 215) ((T_ECHO) reduce 215) ((T_EMPTY) reduce 215) ((T_ENUM) reduce 215) ((T_EVAL) reduce 215) ((T_EXIT) reduce 215) ((T_FILE) reduce 215) ((T_FINAL) reduce 215) ((T_FN) reduce 215) ((T_FOR) reduce 215) ((T_FOREACH) reduce 215) ((T_FUNCTION) reduce 215) ((T_FUNC_C) reduce 215) ((T_GLOBAL) reduce 215) ((T_GOTO) reduce 215) ((T_HALT_COMPILER) reduce 215) ((T_IF) reduce 215) ((T_INC) reduce 215) ((T_INCLUDE) reduce 215) ((T_INCLUDE_ONCE) reduce 215) ((T_INLINE_HTML) reduce 215) ((T_INTERFACE) reduce 215) ((T_INT_CAST) reduce 215) ((T_ISSET) reduce 215) ((T_LINE) reduce 215) ((T_LIST) reduce 215) ((T_LNUMBER) reduce 215) ((T_MATCH) reduce 215) ((T_METHOD_C) reduce 215) ((T_NAME_FULLY_QUALIFIED) reduce 215) ((T_NAME_QUALIFIED) reduce 215) ((T_NAME_RELATIVE) reduce 215) ((T_NEW) reduce 215) ((T_NS_C) reduce 215) ((T_OBJECT_CAST) reduce 215) ((T_PRINT) reduce 215) ((T_READONLY) reduce 215) ((T_REQUIRE) reduce 215) ((T_REQUIRE_ONCE) reduce 215) ((T_RETURN) reduce 215) ((T_START_HEREDOC) reduce 215) ((T_STATIC) reduce 215) ((T_STRING) reduce 215) ((T_STRING_CAST) reduce 215) ((T_SWITCH) reduce 215) ((T_THROW) reduce 215) ((T_TRAIT) reduce 215) ((T_TRAIT_C) reduce 215) ((T_TRY) reduce 215) ((T_UNSET) reduce 215) ((T_UNSET_CAST) reduce 215) ((T_VARIABLE) reduce 215) ((T_WHILE) reduce 215) ((T_YIELD) reduce 215) ((T_YIELD_FROM) reduce 215) (("[") reduce 215) (("`") reduce 215) (("{") reduce 215) (("}") reduce 215) (("~") reduce 215)) 24009 ((("!") reduce 216) (("\"") reduce 216) (("$") reduce 216) (("(") reduce 216) (("+") reduce 216) (("-") reduce 216) ((";") reduce 216) (("@") reduce 216) ((T_ABSTRACT) reduce 216) ((T_ARRAY) reduce 216) ((T_ARRAY_CAST) reduce 216) ((T_ATTRIBUTE) reduce 216) ((T_BOOL_CAST) reduce 216) ((T_BREAK) reduce 216) ((T_CASE) reduce 216) ((T_CLASS) reduce 216) ((T_CLASS_C) reduce 216) ((T_CLONE) reduce 216) ((T_CONSTANT_ENCAPSED_STRING) reduce 216) ((T_CONTINUE) reduce 216) ((T_DEC) reduce 216) ((T_DECLARE) reduce 216) ((T_DEFAULT) reduce 216) ((T_DIR) reduce 216) ((T_DNUMBER) reduce 216) ((T_DO) reduce 216) ((T_DOUBLE_CAST) reduce 216) ((T_ECHO) reduce 216) ((T_EMPTY) reduce 216) ((T_ENUM) reduce 216) ((T_EVAL) reduce 216) ((T_EXIT) reduce 216) ((T_FILE) reduce 216) ((T_FINAL) reduce 216) ((T_FN) reduce 216) ((T_FOR) reduce 216) ((T_FOREACH) reduce 216) ((T_FUNCTION) reduce 216) ((T_FUNC_C) reduce 216) ((T_GLOBAL) reduce 216) ((T_GOTO) reduce 216) ((T_HALT_COMPILER) reduce 216) ((T_IF) reduce 216) ((T_INC) reduce 216) ((T_INCLUDE) reduce 216) ((T_INCLUDE_ONCE) reduce 216) ((T_INLINE_HTML) reduce 216) ((T_INTERFACE) reduce 216) ((T_INT_CAST) reduce 216) ((T_ISSET) reduce 216) ((T_LINE) reduce 216) ((T_LIST) reduce 216) ((T_LNUMBER) reduce 216) ((T_MATCH) reduce 216) ((T_METHOD_C) reduce 216) ((T_NAME_FULLY_QUALIFIED) reduce 216) ((T_NAME_QUALIFIED) reduce 216) ((T_NAME_RELATIVE) reduce 216) ((T_NEW) reduce 216) ((T_NS_C) reduce 216) ((T_OBJECT_CAST) reduce 216) ((T_PRINT) reduce 216) ((T_READONLY) reduce 216) ((T_REQUIRE) reduce 216) ((T_REQUIRE_ONCE) reduce 216) ((T_RETURN) reduce 216) ((T_START_HEREDOC) reduce 216) ((T_STATIC) reduce 216) ((T_STRING) reduce 216) ((T_STRING_CAST) reduce 216) ((T_SWITCH) reduce 216) ((T_THROW) reduce 216) ((T_TRAIT) reduce 216) ((T_TRAIT_C) reduce 216) ((T_TRY) reduce 216) ((T_UNSET) reduce 216) ((T_UNSET_CAST) reduce 216) ((T_VARIABLE) reduce 216) ((T_WHILE) reduce 216) ((T_YIELD) reduce 216) ((T_YIELD_FROM) reduce 216) (("[") reduce 216) (("`") reduce 216) (("{") reduce 216) (("}") reduce 216) (("~") reduce 216)) 24016 ((("!") reduce 199) (("\"") reduce 199) (("$") reduce 199) (("(") reduce 199) (("+") reduce 199) (("-") reduce 199) ((";") reduce 199) (("@") reduce 199) ((T_ABSTRACT) reduce 199) ((T_ARRAY) reduce 199) ((T_ARRAY_CAST) reduce 199) ((T_ATTRIBUTE) reduce 199) ((T_BOOL_CAST) reduce 199) ((T_BREAK) reduce 199) ((T_CASE) reduce 199) ((T_CLASS) reduce 199) ((T_CLASS_C) reduce 199) ((T_CLONE) reduce 199) ((T_CONSTANT_ENCAPSED_STRING) reduce 199) ((T_CONTINUE) reduce 199) ((T_DEC) reduce 199) ((T_DECLARE) reduce 199) ((T_DEFAULT) reduce 199) ((T_DIR) reduce 199) ((T_DNUMBER) reduce 199) ((T_DO) reduce 199) ((T_DOUBLE_CAST) reduce 199) ((T_ECHO) reduce 199) ((T_EMPTY) reduce 199) ((T_ENUM) reduce 199) ((T_EVAL) reduce 199) ((T_EXIT) reduce 199) ((T_FILE) reduce 199) ((T_FINAL) reduce 199) ((T_FN) reduce 199) ((T_FOR) reduce 199) ((T_FOREACH) reduce 199) ((T_FUNCTION) reduce 199) ((T_FUNC_C) reduce 199) ((T_GLOBAL) reduce 199) ((T_GOTO) reduce 199) ((T_HALT_COMPILER) reduce 199) ((T_IF) reduce 199) ((T_INC) reduce 199) ((T_INCLUDE) reduce 199) ((T_INCLUDE_ONCE) reduce 199) ((T_INLINE_HTML) reduce 199) ((T_INTERFACE) reduce 199) ((T_INT_CAST) reduce 199) ((T_ISSET) reduce 199) ((T_LINE) reduce 199) ((T_LIST) reduce 199) ((T_LNUMBER) reduce 199) ((T_MATCH) reduce 199) ((T_METHOD_C) reduce 199) ((T_NAME_FULLY_QUALIFIED) reduce 199) ((T_NAME_QUALIFIED) reduce 199) ((T_NAME_RELATIVE) reduce 199) ((T_NEW) reduce 199) ((T_NS_C) reduce 199) ((T_OBJECT_CAST) reduce 199) ((T_PRINT) reduce 199) ((T_READONLY) reduce 199) ((T_REQUIRE) reduce 199) ((T_REQUIRE_ONCE) reduce 199) ((T_RETURN) reduce 199) ((T_START_HEREDOC) reduce 199) ((T_STATIC) reduce 199) ((T_STRING) reduce 199) ((T_STRING_CAST) reduce 199) ((T_SWITCH) reduce 199) ((T_THROW) reduce 199) ((T_TRAIT) reduce 199) ((T_TRAIT_C) reduce 199) ((T_TRY) reduce 199) ((T_UNSET) reduce 199) ((T_UNSET_CAST) reduce 199) ((T_VARIABLE) reduce 199) ((T_WHILE) reduce 199) ((T_YIELD) reduce 199) ((T_YIELD_FROM) reduce 199) (("[") reduce 199) (("`") reduce 199) (("{") reduce 199) (("}") reduce 199) (("~") reduce 199)) 24018 ((("!") reduce 157) (("\"") reduce 157) (("$") reduce 157) (("(") reduce 157) (("+") reduce 157) (("-") reduce 157) ((";") reduce 157) (("@") reduce 157) ((T_ABSTRACT) reduce 157) ((T_ARRAY) reduce 157) ((T_ARRAY_CAST) reduce 157) ((T_ATTRIBUTE) reduce 157) ((T_BOOL_CAST) reduce 157) ((T_BREAK) reduce 157) ((T_CASE) reduce 157) ((T_CLASS) reduce 157) ((T_CLASS_C) reduce 157) ((T_CLONE) reduce 157) ((T_CONSTANT_ENCAPSED_STRING) reduce 157) ((T_CONTINUE) reduce 157) ((T_DEC) reduce 157) ((T_DECLARE) reduce 157) ((T_DEFAULT) reduce 157) ((T_DIR) reduce 157) ((T_DNUMBER) reduce 157) ((T_DO) reduce 157) ((T_DOUBLE_CAST) reduce 157) ((T_ECHO) reduce 157) ((T_EMPTY) reduce 157) ((T_ENUM) reduce 157) ((T_EVAL) reduce 157) ((T_EXIT) reduce 157) ((T_FILE) reduce 157) ((T_FINAL) reduce 157) ((T_FN) reduce 157) ((T_FOR) reduce 157) ((T_FOREACH) reduce 157) ((T_FUNCTION) reduce 157) ((T_FUNC_C) reduce 157) ((T_GLOBAL) reduce 157) ((T_GOTO) reduce 157) ((T_HALT_COMPILER) reduce 157) ((T_IF) reduce 157) ((T_INC) reduce 157) ((T_INCLUDE) reduce 157) ((T_INCLUDE_ONCE) reduce 157) ((T_INLINE_HTML) reduce 157) ((T_INTERFACE) reduce 157) ((T_INT_CAST) reduce 157) ((T_ISSET) reduce 157) ((T_LINE) reduce 157) ((T_LIST) reduce 157) ((T_LNUMBER) reduce 157) ((T_MATCH) reduce 157) ((T_METHOD_C) reduce 157) ((T_NAME_FULLY_QUALIFIED) reduce 157) ((T_NAME_QUALIFIED) reduce 157) ((T_NAME_RELATIVE) reduce 157) ((T_NEW) reduce 157) ((T_NS_C) reduce 157) ((T_OBJECT_CAST) reduce 157) ((T_PRINT) reduce 157) ((T_READONLY) reduce 157) ((T_REQUIRE) reduce 157) ((T_REQUIRE_ONCE) reduce 157) ((T_RETURN) reduce 157) ((T_START_HEREDOC) reduce 157) ((T_STATIC) reduce 157) ((T_STRING) reduce 157) ((T_STRING_CAST) reduce 157) ((T_SWITCH) reduce 157) ((T_THROW) reduce 157) ((T_TRAIT) reduce 157) ((T_TRAIT_C) reduce 157) ((T_TRY) reduce 157) ((T_UNSET) reduce 157) ((T_UNSET_CAST) reduce 157) ((T_VARIABLE) reduce 157) ((T_WHILE) reduce 157) ((T_YIELD) reduce 157) ((T_YIELD_FROM) reduce 157) (("[") reduce 157) (("`") reduce 157) (("{") reduce 157) (("}") reduce 157) (("~") reduce 157)) 24024 ((("!") reduce 149) (("\"") reduce 149) (("$") reduce 149) (("(") reduce 149) (("+") reduce 149) (("-") reduce 149) ((";") reduce 149) (("@") reduce 149) ((T_ABSTRACT) reduce 149) ((T_ARRAY) reduce 149) ((T_ARRAY_CAST) reduce 149) ((T_ATTRIBUTE) reduce 149) ((T_BOOL_CAST) reduce 149) ((T_BREAK) reduce 149) ((T_CASE) reduce 149) ((T_CLASS) reduce 149) ((T_CLASS_C) reduce 149) ((T_CLONE) reduce 149) ((T_CONSTANT_ENCAPSED_STRING) reduce 149) ((T_CONTINUE) reduce 149) ((T_DEC) reduce 149) ((T_DECLARE) reduce 149) ((T_DEFAULT) reduce 149) ((T_DIR) reduce 149) ((T_DNUMBER) reduce 149) ((T_DO) reduce 149) ((T_DOUBLE_CAST) reduce 149) ((T_ECHO) reduce 149) ((T_EMPTY) reduce 149) ((T_ENUM) reduce 149) ((T_EVAL) reduce 149) ((T_EXIT) reduce 149) ((T_FILE) reduce 149) ((T_FINAL) reduce 149) ((T_FN) reduce 149) ((T_FOR) reduce 149) ((T_FOREACH) reduce 149) ((T_FUNCTION) reduce 149) ((T_FUNC_C) reduce 149) ((T_GLOBAL) reduce 149) ((T_GOTO) reduce 149) ((T_HALT_COMPILER) reduce 149) ((T_IF) reduce 149) ((T_INC) reduce 149) ((T_INCLUDE) reduce 149) ((T_INCLUDE_ONCE) reduce 149) ((T_INLINE_HTML) reduce 149) ((T_INTERFACE) reduce 149) ((T_INT_CAST) reduce 149) ((T_ISSET) reduce 149) ((T_LINE) reduce 149) ((T_LIST) reduce 149) ((T_LNUMBER) reduce 149) ((T_MATCH) reduce 149) ((T_METHOD_C) reduce 149) ((T_NAME_FULLY_QUALIFIED) reduce 149) ((T_NAME_QUALIFIED) reduce 149) ((T_NAME_RELATIVE) reduce 149) ((T_NEW) reduce 149) ((T_NS_C) reduce 149) ((T_OBJECT_CAST) reduce 149) ((T_PRINT) reduce 149) ((T_READONLY) reduce 149) ((T_REQUIRE) reduce 149) ((T_REQUIRE_ONCE) reduce 149) ((T_RETURN) reduce 149) ((T_START_HEREDOC) reduce 149) ((T_STATIC) reduce 149) ((T_STRING) reduce 149) ((T_STRING_CAST) reduce 149) ((T_SWITCH) reduce 149) ((T_THROW) reduce 149) ((T_TRAIT) reduce 149) ((T_TRAIT_C) reduce 149) ((T_TRY) reduce 149) ((T_UNSET) reduce 149) ((T_UNSET_CAST) reduce 149) ((T_VARIABLE) reduce 149) ((T_WHILE) reduce 149) ((T_YIELD) reduce 149) ((T_YIELD_FROM) reduce 149) (("[") reduce 149) (("`") reduce 149) (("{") reduce 149) (("}") reduce 149) (("~") reduce 149)) 24029 ((("!") reduce 163) (("\"") reduce 163) (("$") reduce 163) (("(") reduce 163) (("+") reduce 163) (("-") reduce 163) ((";") reduce 163) (("@") reduce 163) ((T_ABSTRACT) reduce 163) ((T_ARRAY) reduce 163) ((T_ARRAY_CAST) reduce 163) ((T_ATTRIBUTE) reduce 163) ((T_BOOL_CAST) reduce 163) ((T_BREAK) reduce 163) ((T_CASE) reduce 163) ((T_CLASS) reduce 163) ((T_CLASS_C) reduce 163) ((T_CLONE) reduce 163) ((T_CONSTANT_ENCAPSED_STRING) reduce 163) ((T_CONTINUE) reduce 163) ((T_DEC) reduce 163) ((T_DECLARE) reduce 163) ((T_DEFAULT) reduce 163) ((T_DIR) reduce 163) ((T_DNUMBER) reduce 163) ((T_DO) reduce 163) ((T_DOUBLE_CAST) reduce 163) ((T_ECHO) reduce 163) ((T_EMPTY) reduce 163) ((T_ENUM) reduce 163) ((T_EVAL) reduce 163) ((T_EXIT) reduce 163) ((T_FILE) reduce 163) ((T_FINAL) reduce 163) ((T_FN) reduce 163) ((T_FOR) reduce 163) ((T_FOREACH) reduce 163) ((T_FUNCTION) reduce 163) ((T_FUNC_C) reduce 163) ((T_GLOBAL) reduce 163) ((T_GOTO) reduce 163) ((T_HALT_COMPILER) reduce 163) ((T_IF) reduce 163) ((T_INC) reduce 163) ((T_INCLUDE) reduce 163) ((T_INCLUDE_ONCE) reduce 163) ((T_INLINE_HTML) reduce 163) ((T_INTERFACE) reduce 163) ((T_INT_CAST) reduce 163) ((T_ISSET) reduce 163) ((T_LINE) reduce 163) ((T_LIST) reduce 163) ((T_LNUMBER) reduce 163) ((T_MATCH) reduce 163) ((T_METHOD_C) reduce 163) ((T_NAME_FULLY_QUALIFIED) reduce 163) ((T_NAME_QUALIFIED) reduce 163) ((T_NAME_RELATIVE) reduce 163) ((T_NEW) reduce 163) ((T_NS_C) reduce 163) ((T_OBJECT_CAST) reduce 163) ((T_PRINT) reduce 163) ((T_READONLY) reduce 163) ((T_REQUIRE) reduce 163) ((T_REQUIRE_ONCE) reduce 163) ((T_RETURN) reduce 163) ((T_START_HEREDOC) reduce 163) ((T_STATIC) reduce 163) ((T_STRING) reduce 163) ((T_STRING_CAST) reduce 163) ((T_SWITCH) reduce 163) ((T_THROW) reduce 163) ((T_TRAIT) reduce 163) ((T_TRAIT_C) reduce 163) ((T_TRY) reduce 163) ((T_UNSET) reduce 163) ((T_UNSET_CAST) reduce 163) ((T_VARIABLE) reduce 163) ((T_WHILE) reduce 163) ((T_YIELD) reduce 163) ((T_YIELD_FROM) reduce 163) (("[") reduce 163) (("`") reduce 163) (("{") reduce 163) (("}") reduce 163) (("~") reduce 163)) 24030 ((("!") reduce 219) (("\"") reduce 219) (("$") reduce 219) (("(") reduce 219) (("+") reduce 219) (("-") reduce 219) ((";") reduce 219) (("@") reduce 219) ((T_ABSTRACT) reduce 219) ((T_ARRAY) reduce 219) ((T_ARRAY_CAST) reduce 219) ((T_ATTRIBUTE) reduce 219) ((T_BOOL_CAST) reduce 219) ((T_BREAK) reduce 219) ((T_CASE) reduce 219) ((T_CLASS) reduce 219) ((T_CLASS_C) reduce 219) ((T_CLONE) reduce 219) ((T_CONSTANT_ENCAPSED_STRING) reduce 219) ((T_CONTINUE) reduce 219) ((T_DEC) reduce 219) ((T_DECLARE) reduce 219) ((T_DEFAULT) reduce 219) ((T_DIR) reduce 219) ((T_DNUMBER) reduce 219) ((T_DO) reduce 219) ((T_DOUBLE_CAST) reduce 219) ((T_ECHO) reduce 219) ((T_EMPTY) reduce 219) ((T_ENUM) reduce 219) ((T_EVAL) reduce 219) ((T_EXIT) reduce 219) ((T_FILE) reduce 219) ((T_FINAL) reduce 219) ((T_FN) reduce 219) ((T_FOR) reduce 219) ((T_FOREACH) reduce 219) ((T_FUNCTION) reduce 219) ((T_FUNC_C) reduce 219) ((T_GLOBAL) reduce 219) ((T_GOTO) reduce 219) ((T_HALT_COMPILER) reduce 219) ((T_IF) reduce 219) ((T_INC) reduce 219) ((T_INCLUDE) reduce 219) ((T_INCLUDE_ONCE) reduce 219) ((T_INLINE_HTML) reduce 219) ((T_INTERFACE) reduce 219) ((T_INT_CAST) reduce 219) ((T_ISSET) reduce 219) ((T_LINE) reduce 219) ((T_LIST) reduce 219) ((T_LNUMBER) reduce 219) ((T_MATCH) reduce 219) ((T_METHOD_C) reduce 219) ((T_NAME_FULLY_QUALIFIED) reduce 219) ((T_NAME_QUALIFIED) reduce 219) ((T_NAME_RELATIVE) reduce 219) ((T_NEW) reduce 219) ((T_NS_C) reduce 219) ((T_OBJECT_CAST) reduce 219) ((T_PRINT) reduce 219) ((T_READONLY) reduce 219) ((T_REQUIRE) reduce 219) ((T_REQUIRE_ONCE) reduce 219) ((T_RETURN) reduce 219) ((T_START_HEREDOC) reduce 219) ((T_STATIC) reduce 219) ((T_STRING) reduce 219) ((T_STRING_CAST) reduce 219) ((T_SWITCH) reduce 219) ((T_THROW) reduce 219) ((T_TRAIT) reduce 219) ((T_TRAIT_C) reduce 219) ((T_TRY) reduce 219) ((T_UNSET) reduce 219) ((T_UNSET_CAST) reduce 219) ((T_VARIABLE) reduce 219) ((T_WHILE) reduce 219) ((T_YIELD) reduce 219) ((T_YIELD_FROM) reduce 219) (("[") reduce 219) (("`") reduce 219) (("{") reduce 219) (("}") reduce 219) (("~") reduce 219)) 24033 ((("!") reduce 220) (("\"") reduce 220) (("$") reduce 220) (("(") reduce 220) (("+") reduce 220) (("-") reduce 220) ((";") reduce 220) (("@") reduce 220) ((T_ABSTRACT) reduce 220) ((T_ARRAY) reduce 220) ((T_ARRAY_CAST) reduce 220) ((T_ATTRIBUTE) reduce 220) ((T_BOOL_CAST) reduce 220) ((T_BREAK) reduce 220) ((T_CASE) reduce 220) ((T_CLASS) reduce 220) ((T_CLASS_C) reduce 220) ((T_CLONE) reduce 220) ((T_CONSTANT_ENCAPSED_STRING) reduce 220) ((T_CONTINUE) reduce 220) ((T_DEC) reduce 220) ((T_DECLARE) reduce 220) ((T_DEFAULT) reduce 220) ((T_DIR) reduce 220) ((T_DNUMBER) reduce 220) ((T_DO) reduce 220) ((T_DOUBLE_CAST) reduce 220) ((T_ECHO) reduce 220) ((T_EMPTY) reduce 220) ((T_ENUM) reduce 220) ((T_EVAL) reduce 220) ((T_EXIT) reduce 220) ((T_FILE) reduce 220) ((T_FINAL) reduce 220) ((T_FN) reduce 220) ((T_FOR) reduce 220) ((T_FOREACH) reduce 220) ((T_FUNCTION) reduce 220) ((T_FUNC_C) reduce 220) ((T_GLOBAL) reduce 220) ((T_GOTO) reduce 220) ((T_HALT_COMPILER) reduce 220) ((T_IF) reduce 220) ((T_INC) reduce 220) ((T_INCLUDE) reduce 220) ((T_INCLUDE_ONCE) reduce 220) ((T_INLINE_HTML) reduce 220) ((T_INTERFACE) reduce 220) ((T_INT_CAST) reduce 220) ((T_ISSET) reduce 220) ((T_LINE) reduce 220) ((T_LIST) reduce 220) ((T_LNUMBER) reduce 220) ((T_MATCH) reduce 220) ((T_METHOD_C) reduce 220) ((T_NAME_FULLY_QUALIFIED) reduce 220) ((T_NAME_QUALIFIED) reduce 220) ((T_NAME_RELATIVE) reduce 220) ((T_NEW) reduce 220) ((T_NS_C) reduce 220) ((T_OBJECT_CAST) reduce 220) ((T_PRINT) reduce 220) ((T_READONLY) reduce 220) ((T_REQUIRE) reduce 220) ((T_REQUIRE_ONCE) reduce 220) ((T_RETURN) reduce 220) ((T_START_HEREDOC) reduce 220) ((T_STATIC) reduce 220) ((T_STRING) reduce 220) ((T_STRING_CAST) reduce 220) ((T_SWITCH) reduce 220) ((T_THROW) reduce 220) ((T_TRAIT) reduce 220) ((T_TRAIT_C) reduce 220) ((T_TRY) reduce 220) ((T_UNSET) reduce 220) ((T_UNSET_CAST) reduce 220) ((T_VARIABLE) reduce 220) ((T_WHILE) reduce 220) ((T_YIELD) reduce 220) ((T_YIELD_FROM) reduce 220) (("[") reduce 220) (("`") reduce 220) (("{") reduce 220) (("}") reduce 220) (("~") reduce 220)) 24035 ((("!") reduce 153) (("\"") reduce 153) (("$") reduce 153) (("(") reduce 153) (("+") reduce 153) (("-") reduce 153) ((";") reduce 153) (("@") reduce 153) ((T_ABSTRACT) reduce 153) ((T_ARRAY) reduce 153) ((T_ARRAY_CAST) reduce 153) ((T_ATTRIBUTE) reduce 153) ((T_BOOL_CAST) reduce 153) ((T_BREAK) reduce 153) ((T_CASE) reduce 153) ((T_CLASS) reduce 153) ((T_CLASS_C) reduce 153) ((T_CLONE) reduce 153) ((T_CONSTANT_ENCAPSED_STRING) reduce 153) ((T_CONTINUE) reduce 153) ((T_DEC) reduce 153) ((T_DECLARE) reduce 153) ((T_DEFAULT) reduce 153) ((T_DIR) reduce 153) ((T_DNUMBER) reduce 153) ((T_DO) reduce 153) ((T_DOUBLE_CAST) reduce 153) ((T_ECHO) reduce 153) ((T_EMPTY) reduce 153) ((T_ENUM) reduce 153) ((T_EVAL) reduce 153) ((T_EXIT) reduce 153) ((T_FILE) reduce 153) ((T_FINAL) reduce 153) ((T_FN) reduce 153) ((T_FOR) reduce 153) ((T_FOREACH) reduce 153) ((T_FUNCTION) reduce 153) ((T_FUNC_C) reduce 153) ((T_GLOBAL) reduce 153) ((T_GOTO) reduce 153) ((T_HALT_COMPILER) reduce 153) ((T_IF) reduce 153) ((T_INC) reduce 153) ((T_INCLUDE) reduce 153) ((T_INCLUDE_ONCE) reduce 153) ((T_INLINE_HTML) reduce 153) ((T_INTERFACE) reduce 153) ((T_INT_CAST) reduce 153) ((T_ISSET) reduce 153) ((T_LINE) reduce 153) ((T_LIST) reduce 153) ((T_LNUMBER) reduce 153) ((T_MATCH) reduce 153) ((T_METHOD_C) reduce 153) ((T_NAME_FULLY_QUALIFIED) reduce 153) ((T_NAME_QUALIFIED) reduce 153) ((T_NAME_RELATIVE) reduce 153) ((T_NEW) reduce 153) ((T_NS_C) reduce 153) ((T_OBJECT_CAST) reduce 153) ((T_PRINT) reduce 153) ((T_READONLY) reduce 153) ((T_REQUIRE) reduce 153) ((T_REQUIRE_ONCE) reduce 153) ((T_RETURN) reduce 153) ((T_START_HEREDOC) reduce 153) ((T_STATIC) reduce 153) ((T_STRING) reduce 153) ((T_STRING_CAST) reduce 153) ((T_SWITCH) reduce 153) ((T_THROW) reduce 153) ((T_TRAIT) reduce 153) ((T_TRAIT_C) reduce 153) ((T_TRY) reduce 153) ((T_UNSET) reduce 153) ((T_UNSET_CAST) reduce 153) ((T_VARIABLE) reduce 153) ((T_WHILE) reduce 153) ((T_YIELD) reduce 153) ((T_YIELD_FROM) reduce 153) (("[") reduce 153) (("`") reduce 153) (("{") reduce 153) (("}") reduce 153) (("~") reduce 153)) 24042 ((("!") reduce 187) (("\"") reduce 187) (("$") reduce 187) (("(") reduce 187) (("+") reduce 187) (("-") reduce 187) ((";") reduce 187) (("@") reduce 187) ((T_ABSTRACT) reduce 187) ((T_ARRAY) reduce 187) ((T_ARRAY_CAST) reduce 187) ((T_ATTRIBUTE) reduce 187) ((T_BOOL_CAST) reduce 187) ((T_BREAK) reduce 187) ((T_CASE) reduce 187) ((T_CLASS) reduce 187) ((T_CLASS_C) reduce 187) ((T_CLONE) reduce 187) ((T_CONSTANT_ENCAPSED_STRING) reduce 187) ((T_CONTINUE) reduce 187) ((T_DEC) reduce 187) ((T_DECLARE) reduce 187) ((T_DEFAULT) reduce 187) ((T_DIR) reduce 187) ((T_DNUMBER) reduce 187) ((T_DO) reduce 187) ((T_DOUBLE_CAST) reduce 187) ((T_ECHO) reduce 187) ((T_EMPTY) reduce 187) ((T_ENUM) reduce 187) ((T_EVAL) reduce 187) ((T_EXIT) reduce 187) ((T_FILE) reduce 187) ((T_FINAL) reduce 187) ((T_FN) reduce 187) ((T_FOR) reduce 187) ((T_FOREACH) reduce 187) ((T_FUNCTION) reduce 187) ((T_FUNC_C) reduce 187) ((T_GLOBAL) reduce 187) ((T_GOTO) reduce 187) ((T_HALT_COMPILER) reduce 187) ((T_IF) reduce 187) ((T_INC) reduce 187) ((T_INCLUDE) reduce 187) ((T_INCLUDE_ONCE) reduce 187) ((T_INLINE_HTML) reduce 187) ((T_INTERFACE) reduce 187) ((T_INT_CAST) reduce 187) ((T_ISSET) reduce 187) ((T_LINE) reduce 187) ((T_LIST) reduce 187) ((T_LNUMBER) reduce 187) ((T_MATCH) reduce 187) ((T_METHOD_C) reduce 187) ((T_NAME_FULLY_QUALIFIED) reduce 187) ((T_NAME_QUALIFIED) reduce 187) ((T_NAME_RELATIVE) reduce 187) ((T_NEW) reduce 187) ((T_NS_C) reduce 187) ((T_OBJECT_CAST) reduce 187) ((T_PRINT) reduce 187) ((T_READONLY) reduce 187) ((T_REQUIRE) reduce 187) ((T_REQUIRE_ONCE) reduce 187) ((T_RETURN) reduce 187) ((T_START_HEREDOC) reduce 187) ((T_STATIC) reduce 187) ((T_STRING) reduce 187) ((T_STRING_CAST) reduce 187) ((T_SWITCH) reduce 187) ((T_THROW) reduce 187) ((T_TRAIT) reduce 187) ((T_TRAIT_C) reduce 187) ((T_TRY) reduce 187) ((T_UNSET) reduce 187) ((T_UNSET_CAST) reduce 187) ((T_VARIABLE) reduce 187) ((T_WHILE) reduce 187) ((T_YIELD) reduce 187) ((T_YIELD_FROM) reduce 187) (("[") reduce 187) (("`") reduce 187) (("{") reduce 187) (("}") reduce 187) (("~") reduce 187)) 24044 ((("!") reduce 152) (("\"") reduce 152) (("$") reduce 152) (("(") reduce 152) (("+") reduce 152) (("-") reduce 152) ((";") reduce 152) (("@") reduce 152) ((T_ABSTRACT) reduce 152) ((T_ARRAY) reduce 152) ((T_ARRAY_CAST) reduce 152) ((T_ATTRIBUTE) reduce 152) ((T_BOOL_CAST) reduce 152) ((T_BREAK) reduce 152) ((T_CASE) reduce 152) ((T_CLASS) reduce 152) ((T_CLASS_C) reduce 152) ((T_CLONE) reduce 152) ((T_CONSTANT_ENCAPSED_STRING) reduce 152) ((T_CONTINUE) reduce 152) ((T_DEC) reduce 152) ((T_DECLARE) reduce 152) ((T_DEFAULT) reduce 152) ((T_DIR) reduce 152) ((T_DNUMBER) reduce 152) ((T_DO) reduce 152) ((T_DOUBLE_CAST) reduce 152) ((T_ECHO) reduce 152) ((T_EMPTY) reduce 152) ((T_ENUM) reduce 152) ((T_EVAL) reduce 152) ((T_EXIT) reduce 152) ((T_FILE) reduce 152) ((T_FINAL) reduce 152) ((T_FN) reduce 152) ((T_FOR) reduce 152) ((T_FOREACH) reduce 152) ((T_FUNCTION) reduce 152) ((T_FUNC_C) reduce 152) ((T_GLOBAL) reduce 152) ((T_GOTO) reduce 152) ((T_HALT_COMPILER) reduce 152) ((T_IF) reduce 152) ((T_INC) reduce 152) ((T_INCLUDE) reduce 152) ((T_INCLUDE_ONCE) reduce 152) ((T_INLINE_HTML) reduce 152) ((T_INTERFACE) reduce 152) ((T_INT_CAST) reduce 152) ((T_ISSET) reduce 152) ((T_LINE) reduce 152) ((T_LIST) reduce 152) ((T_LNUMBER) reduce 152) ((T_MATCH) reduce 152) ((T_METHOD_C) reduce 152) ((T_NAME_FULLY_QUALIFIED) reduce 152) ((T_NAME_QUALIFIED) reduce 152) ((T_NAME_RELATIVE) reduce 152) ((T_NEW) reduce 152) ((T_NS_C) reduce 152) ((T_OBJECT_CAST) reduce 152) ((T_PRINT) reduce 152) ((T_READONLY) reduce 152) ((T_REQUIRE) reduce 152) ((T_REQUIRE_ONCE) reduce 152) ((T_RETURN) reduce 152) ((T_START_HEREDOC) reduce 152) ((T_STATIC) reduce 152) ((T_STRING) reduce 152) ((T_STRING_CAST) reduce 152) ((T_SWITCH) reduce 152) ((T_THROW) reduce 152) ((T_TRAIT) reduce 152) ((T_TRAIT_C) reduce 152) ((T_TRY) reduce 152) ((T_UNSET) reduce 152) ((T_UNSET_CAST) reduce 152) ((T_VARIABLE) reduce 152) ((T_WHILE) reduce 152) ((T_YIELD) reduce 152) ((T_YIELD_FROM) reduce 152) (("[") reduce 152) (("`") reduce 152) (("{") reduce 152) (("}") reduce 152) (("~") reduce 152)) 24047 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) (("+") shift) (("-") shift) ((";") shift) (("@") shift) ((T_ABSTRACT) shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_BREAK) shift) ((T_CASE) reduce 226) ((T_CLASS) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_CONTINUE) shift) ((T_DEC) shift) ((T_DECLARE) shift) ((T_DEFAULT) reduce 226) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DO) shift) ((T_DOUBLE_CAST) shift) ((T_ECHO) shift) ((T_EMPTY) shift) ((T_ENUM) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FINAL) shift) ((T_FN) shift) ((T_FOR) shift) ((T_FOREACH) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_GLOBAL) shift) ((T_GOTO) shift) ((T_HALT_COMPILER) shift) ((T_IF) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INLINE_HTML) shift) ((T_INTERFACE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_RETURN) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_SWITCH) shift) ((T_THROW) shift) ((T_TRAIT) shift) ((T_TRAIT_C) shift) ((T_TRY) shift) ((T_UNSET) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_WHILE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("{") shift) (("}") reduce 226) (("~") shift)) 24049 ((("!") reduce 222) (("\"") reduce 222) (("$") reduce 222) (("(") reduce 222) (("+") reduce 222) (("-") reduce 222) ((";") reduce 222) (("@") reduce 222) ((T_ABSTRACT) reduce 222) ((T_ARRAY) reduce 222) ((T_ARRAY_CAST) reduce 222) ((T_ATTRIBUTE) reduce 222) ((T_BOOL_CAST) reduce 222) ((T_BREAK) reduce 222) ((T_CLASS) reduce 222) ((T_CLASS_C) reduce 222) ((T_CLONE) reduce 222) ((T_CONSTANT_ENCAPSED_STRING) reduce 222) ((T_CONTINUE) reduce 222) ((T_DEC) reduce 222) ((T_DECLARE) reduce 222) ((T_DIR) reduce 222) ((T_DNUMBER) reduce 222) ((T_DO) reduce 222) ((T_DOUBLE_CAST) reduce 222) ((T_ECHO) reduce 222) ((T_ELSE) reduce 222) ((T_ELSEIF) reduce 222) ((T_EMPTY) reduce 222) ((T_ENDWHILE) reduce 222) ((T_ENUM) reduce 222) ((T_EVAL) reduce 222) ((T_EXIT) reduce 222) ((T_FILE) reduce 222) ((T_FINAL) reduce 222) ((T_FN) reduce 222) ((T_FOR) reduce 222) ((T_FOREACH) reduce 222) ((T_FUNCTION) reduce 222) ((T_FUNC_C) reduce 222) ((T_GLOBAL) reduce 222) ((T_GOTO) reduce 222) ((T_HALT_COMPILER) reduce 222) ((T_IF) reduce 222) ((T_INC) reduce 222) ((T_INCLUDE) reduce 222) ((T_INCLUDE_ONCE) reduce 222) ((T_INLINE_HTML) reduce 222) ((T_INTERFACE) reduce 222) ((T_INT_CAST) reduce 222) ((T_ISSET) reduce 222) ((T_LINE) reduce 222) ((T_LIST) reduce 222) ((T_LNUMBER) reduce 222) ((T_MATCH) reduce 222) ((T_METHOD_C) reduce 222) ((T_NAME_FULLY_QUALIFIED) reduce 222) ((T_NAME_QUALIFIED) reduce 222) ((T_NAME_RELATIVE) reduce 222) ((T_NEW) reduce 222) ((T_NS_C) reduce 222) ((T_OBJECT_CAST) reduce 222) ((T_PRINT) reduce 222) ((T_READONLY) reduce 222) ((T_REQUIRE) reduce 222) ((T_REQUIRE_ONCE) reduce 222) ((T_RETURN) reduce 222) ((T_START_HEREDOC) reduce 222) ((T_STATIC) reduce 222) ((T_STRING) reduce 222) ((T_STRING_CAST) reduce 222) ((T_SWITCH) reduce 222) ((T_THROW) reduce 222) ((T_TRAIT) reduce 222) ((T_TRAIT_C) reduce 222) ((T_TRY) reduce 222) ((T_UNSET) reduce 222) ((T_UNSET_CAST) reduce 222) ((T_VARIABLE) reduce 222) ((T_WHILE) reduce 222) ((T_YIELD) reduce 222) ((T_YIELD_FROM) reduce 222) (("[") reduce 222) (("`") reduce 222) (("{") reduce 222) (("~") reduce 222)) 24053 ((("!") reduce 223) (("\"") reduce 223) (("$") reduce 223) (("(") reduce 223) (("+") reduce 223) (("-") reduce 223) ((";") reduce 223) (("@") reduce 223) ((T_ABSTRACT) reduce 223) ((T_ARRAY) reduce 223) ((T_ARRAY_CAST) reduce 223) ((T_ATTRIBUTE) reduce 223) ((T_BOOL_CAST) reduce 223) ((T_BREAK) reduce 223) ((T_CLASS) reduce 223) ((T_CLASS_C) reduce 223) ((T_CLONE) reduce 223) ((T_CONSTANT_ENCAPSED_STRING) reduce 223) ((T_CONTINUE) reduce 223) ((T_DEC) reduce 223) ((T_DECLARE) reduce 223) ((T_DIR) reduce 223) ((T_DNUMBER) reduce 223) ((T_DO) reduce 223) ((T_DOUBLE_CAST) reduce 223) ((T_ECHO) reduce 223) ((T_ELSE) reduce 223) ((T_ELSEIF) reduce 223) ((T_EMPTY) reduce 223) ((T_ENDWHILE) reduce 223) ((T_ENUM) reduce 223) ((T_EVAL) reduce 223) ((T_EXIT) reduce 223) ((T_FILE) reduce 223) ((T_FINAL) reduce 223) ((T_FN) reduce 223) ((T_FOR) reduce 223) ((T_FOREACH) reduce 223) ((T_FUNCTION) reduce 223) ((T_FUNC_C) reduce 223) ((T_GLOBAL) reduce 223) ((T_GOTO) reduce 223) ((T_HALT_COMPILER) reduce 223) ((T_IF) reduce 223) ((T_INC) reduce 223) ((T_INCLUDE) reduce 223) ((T_INCLUDE_ONCE) reduce 223) ((T_INLINE_HTML) reduce 223) ((T_INTERFACE) reduce 223) ((T_INT_CAST) reduce 223) ((T_ISSET) reduce 223) ((T_LINE) reduce 223) ((T_LIST) reduce 223) ((T_LNUMBER) reduce 223) ((T_MATCH) reduce 223) ((T_METHOD_C) reduce 223) ((T_NAME_FULLY_QUALIFIED) reduce 223) ((T_NAME_QUALIFIED) reduce 223) ((T_NAME_RELATIVE) reduce 223) ((T_NEW) reduce 223) ((T_NS_C) reduce 223) ((T_OBJECT_CAST) reduce 223) ((T_PRINT) reduce 223) ((T_READONLY) reduce 223) ((T_REQUIRE) reduce 223) ((T_REQUIRE_ONCE) reduce 223) ((T_RETURN) reduce 223) ((T_START_HEREDOC) reduce 223) ((T_STATIC) reduce 223) ((T_STRING) reduce 223) ((T_STRING_CAST) reduce 223) ((T_SWITCH) reduce 223) ((T_THROW) reduce 223) ((T_TRAIT) reduce 223) ((T_TRAIT_C) reduce 223) ((T_TRY) reduce 223) ((T_UNSET) reduce 223) ((T_UNSET_CAST) reduce 223) ((T_VARIABLE) reduce 223) ((T_WHILE) reduce 223) ((T_YIELD) reduce 223) ((T_YIELD_FROM) reduce 223) (("[") reduce 223) (("`") reduce 223) (("{") reduce 223) (("~") reduce 223)) 24056 ((("!") reduce 224) (("\"") reduce 224) (("$") reduce 224) (("(") reduce 224) (("+") reduce 224) (("-") reduce 224) ((";") reduce 224) (("@") reduce 224) ((T_ABSTRACT) reduce 224) ((T_ARRAY) reduce 224) ((T_ARRAY_CAST) reduce 224) ((T_ATTRIBUTE) reduce 224) ((T_BOOL_CAST) reduce 224) ((T_BREAK) reduce 224) ((T_CLASS) reduce 224) ((T_CLASS_C) reduce 224) ((T_CLONE) reduce 224) ((T_CONSTANT_ENCAPSED_STRING) reduce 224) ((T_CONTINUE) reduce 224) ((T_DEC) reduce 224) ((T_DECLARE) reduce 224) ((T_DIR) reduce 224) ((T_DNUMBER) reduce 224) ((T_DO) reduce 224) ((T_DOUBLE_CAST) reduce 224) ((T_ECHO) reduce 224) ((T_ELSE) reduce 224) ((T_ELSEIF) reduce 224) ((T_EMPTY) reduce 224) ((T_ENDWHILE) reduce 224) ((T_ENUM) reduce 224) ((T_EVAL) reduce 224) ((T_EXIT) reduce 224) ((T_FILE) reduce 224) ((T_FINAL) reduce 224) ((T_FN) reduce 224) ((T_FOR) reduce 224) ((T_FOREACH) reduce 224) ((T_FUNCTION) reduce 224) ((T_FUNC_C) reduce 224) ((T_GLOBAL) reduce 224) ((T_GOTO) reduce 224) ((T_HALT_COMPILER) reduce 224) ((T_IF) reduce 224) ((T_INC) reduce 224) ((T_INCLUDE) reduce 224) ((T_INCLUDE_ONCE) reduce 224) ((T_INLINE_HTML) reduce 224) ((T_INTERFACE) reduce 224) ((T_INT_CAST) reduce 224) ((T_ISSET) reduce 224) ((T_LINE) reduce 224) ((T_LIST) reduce 224) ((T_LNUMBER) reduce 224) ((T_MATCH) reduce 224) ((T_METHOD_C) reduce 224) ((T_NAME_FULLY_QUALIFIED) reduce 224) ((T_NAME_QUALIFIED) reduce 224) ((T_NAME_RELATIVE) reduce 224) ((T_NEW) reduce 224) ((T_NS_C) reduce 224) ((T_OBJECT_CAST) reduce 224) ((T_PRINT) reduce 224) ((T_READONLY) reduce 224) ((T_REQUIRE) reduce 224) ((T_REQUIRE_ONCE) reduce 224) ((T_RETURN) reduce 224) ((T_START_HEREDOC) reduce 224) ((T_STATIC) reduce 224) ((T_STRING) reduce 224) ((T_STRING_CAST) reduce 224) ((T_SWITCH) reduce 224) ((T_THROW) reduce 224) ((T_TRAIT) reduce 224) ((T_TRAIT_C) reduce 224) ((T_TRY) reduce 224) ((T_UNSET) reduce 224) ((T_UNSET_CAST) reduce 224) ((T_VARIABLE) reduce 224) ((T_WHILE) reduce 224) ((T_YIELD) reduce 224) ((T_YIELD_FROM) reduce 224) (("[") reduce 224) (("`") reduce 224) (("{") reduce 224) (("~") reduce 224)) 24057 ((("!") reduce 167) (("\"") reduce 167) (("$") reduce 167) (("(") reduce 167) (("+") reduce 167) (("-") reduce 167) ((";") reduce 167) (("@") reduce 167) ((T_ABSTRACT) reduce 167) ((T_ARRAY) reduce 167) ((T_ARRAY_CAST) reduce 167) ((T_ATTRIBUTE) reduce 167) ((T_BOOL_CAST) reduce 167) ((T_BREAK) reduce 167) ((T_CLASS) reduce 167) ((T_CLASS_C) reduce 167) ((T_CLONE) reduce 167) ((T_CONSTANT_ENCAPSED_STRING) reduce 167) ((T_CONTINUE) reduce 167) ((T_DEC) reduce 167) ((T_DECLARE) reduce 167) ((T_DIR) reduce 167) ((T_DNUMBER) reduce 167) ((T_DO) reduce 167) ((T_DOUBLE_CAST) reduce 167) ((T_ECHO) reduce 167) ((T_ELSE) reduce 167) ((T_ELSEIF) reduce 167) ((T_EMPTY) reduce 167) ((T_ENDWHILE) reduce 167) ((T_ENUM) reduce 167) ((T_EVAL) reduce 167) ((T_EXIT) reduce 167) ((T_FILE) reduce 167) ((T_FINAL) reduce 167) ((T_FN) reduce 167) ((T_FOR) reduce 167) ((T_FOREACH) reduce 167) ((T_FUNCTION) reduce 167) ((T_FUNC_C) reduce 167) ((T_GLOBAL) reduce 167) ((T_GOTO) reduce 167) ((T_HALT_COMPILER) reduce 167) ((T_IF) reduce 167) ((T_INC) reduce 167) ((T_INCLUDE) reduce 167) ((T_INCLUDE_ONCE) reduce 167) ((T_INLINE_HTML) reduce 167) ((T_INTERFACE) reduce 167) ((T_INT_CAST) reduce 167) ((T_ISSET) reduce 167) ((T_LINE) reduce 167) ((T_LIST) reduce 167) ((T_LNUMBER) reduce 167) ((T_MATCH) reduce 167) ((T_METHOD_C) reduce 167) ((T_NAME_FULLY_QUALIFIED) reduce 167) ((T_NAME_QUALIFIED) reduce 167) ((T_NAME_RELATIVE) reduce 167) ((T_NEW) reduce 167) ((T_NS_C) reduce 167) ((T_OBJECT_CAST) reduce 167) ((T_PRINT) reduce 167) ((T_READONLY) reduce 167) ((T_REQUIRE) reduce 167) ((T_REQUIRE_ONCE) reduce 167) ((T_RETURN) reduce 167) ((T_START_HEREDOC) reduce 167) ((T_STATIC) reduce 167) ((T_STRING) reduce 167) ((T_STRING_CAST) reduce 167) ((T_SWITCH) reduce 167) ((T_THROW) reduce 167) ((T_TRAIT) reduce 167) ((T_TRAIT_C) reduce 167) ((T_TRY) reduce 167) ((T_UNSET) reduce 167) ((T_UNSET_CAST) reduce 167) ((T_VARIABLE) reduce 167) ((T_WHILE) reduce 167) ((T_YIELD) reduce 167) ((T_YIELD_FROM) reduce 167) (("[") reduce 167) (("`") reduce 167) (("{") reduce 167) (("~") reduce 167)) 24059 ((("!") reduce 156) (("\"") reduce 156) (("$") reduce 156) (("(") reduce 156) (("+") reduce 156) (("-") reduce 156) ((";") reduce 156) (("@") reduce 156) ((T_ABSTRACT) reduce 156) ((T_ARRAY) reduce 156) ((T_ARRAY_CAST) reduce 156) ((T_ATTRIBUTE) reduce 156) ((T_BOOL_CAST) reduce 156) ((T_BREAK) reduce 156) ((T_CLASS) reduce 156) ((T_CLASS_C) reduce 156) ((T_CLONE) reduce 156) ((T_CONSTANT_ENCAPSED_STRING) reduce 156) ((T_CONTINUE) reduce 156) ((T_DEC) reduce 156) ((T_DECLARE) reduce 156) ((T_DIR) reduce 156) ((T_DNUMBER) reduce 156) ((T_DO) reduce 156) ((T_DOUBLE_CAST) reduce 156) ((T_ECHO) reduce 156) ((T_ELSE) reduce 156) ((T_ELSEIF) reduce 156) ((T_EMPTY) reduce 156) ((T_ENDWHILE) reduce 156) ((T_ENUM) reduce 156) ((T_EVAL) reduce 156) ((T_EXIT) reduce 156) ((T_FILE) reduce 156) ((T_FINAL) reduce 156) ((T_FN) reduce 156) ((T_FOR) reduce 156) ((T_FOREACH) reduce 156) ((T_FUNCTION) reduce 156) ((T_FUNC_C) reduce 156) ((T_GLOBAL) reduce 156) ((T_GOTO) reduce 156) ((T_HALT_COMPILER) reduce 156) ((T_IF) reduce 156) ((T_INC) reduce 156) ((T_INCLUDE) reduce 156) ((T_INCLUDE_ONCE) reduce 156) ((T_INLINE_HTML) reduce 156) ((T_INTERFACE) reduce 156) ((T_INT_CAST) reduce 156) ((T_ISSET) reduce 156) ((T_LINE) reduce 156) ((T_LIST) reduce 156) ((T_LNUMBER) reduce 156) ((T_MATCH) reduce 156) ((T_METHOD_C) reduce 156) ((T_NAME_FULLY_QUALIFIED) reduce 156) ((T_NAME_QUALIFIED) reduce 156) ((T_NAME_RELATIVE) reduce 156) ((T_NEW) reduce 156) ((T_NS_C) reduce 156) ((T_OBJECT_CAST) reduce 156) ((T_PRINT) reduce 156) ((T_READONLY) reduce 156) ((T_REQUIRE) reduce 156) ((T_REQUIRE_ONCE) reduce 156) ((T_RETURN) reduce 156) ((T_START_HEREDOC) reduce 156) ((T_STATIC) reduce 156) ((T_STRING) reduce 156) ((T_STRING_CAST) reduce 156) ((T_SWITCH) reduce 156) ((T_THROW) reduce 156) ((T_TRAIT) reduce 156) ((T_TRAIT_C) reduce 156) ((T_TRY) reduce 156) ((T_UNSET) reduce 156) ((T_UNSET_CAST) reduce 156) ((T_VARIABLE) reduce 156) ((T_WHILE) reduce 156) ((T_YIELD) reduce 156) ((T_YIELD_FROM) reduce 156) (("[") reduce 156) (("`") reduce 156) (("{") reduce 156) (("~") reduce 156)) 24061 ((("!") reduce 154) (("\"") reduce 154) (("$") reduce 154) (("(") reduce 154) (("+") reduce 154) (("-") reduce 154) ((";") reduce 154) (("@") reduce 154) ((T_ABSTRACT) reduce 154) ((T_ARRAY) reduce 154) ((T_ARRAY_CAST) reduce 154) ((T_ATTRIBUTE) reduce 154) ((T_BOOL_CAST) reduce 154) ((T_BREAK) reduce 154) ((T_CLASS) reduce 154) ((T_CLASS_C) reduce 154) ((T_CLONE) reduce 154) ((T_CONSTANT_ENCAPSED_STRING) reduce 154) ((T_CONTINUE) reduce 154) ((T_DEC) reduce 154) ((T_DECLARE) reduce 154) ((T_DIR) reduce 154) ((T_DNUMBER) reduce 154) ((T_DO) reduce 154) ((T_DOUBLE_CAST) reduce 154) ((T_ECHO) reduce 154) ((T_ELSE) reduce 154) ((T_ELSEIF) reduce 154) ((T_EMPTY) reduce 154) ((T_ENDWHILE) reduce 154) ((T_ENUM) reduce 154) ((T_EVAL) reduce 154) ((T_EXIT) reduce 154) ((T_FILE) reduce 154) ((T_FINAL) reduce 154) ((T_FN) reduce 154) ((T_FOR) reduce 154) ((T_FOREACH) reduce 154) ((T_FUNCTION) reduce 154) ((T_FUNC_C) reduce 154) ((T_GLOBAL) reduce 154) ((T_GOTO) reduce 154) ((T_HALT_COMPILER) reduce 154) ((T_IF) reduce 154) ((T_INC) reduce 154) ((T_INCLUDE) reduce 154) ((T_INCLUDE_ONCE) reduce 154) ((T_INLINE_HTML) reduce 154) ((T_INTERFACE) reduce 154) ((T_INT_CAST) reduce 154) ((T_ISSET) reduce 154) ((T_LINE) reduce 154) ((T_LIST) reduce 154) ((T_LNUMBER) reduce 154) ((T_MATCH) reduce 154) ((T_METHOD_C) reduce 154) ((T_NAME_FULLY_QUALIFIED) reduce 154) ((T_NAME_QUALIFIED) reduce 154) ((T_NAME_RELATIVE) reduce 154) ((T_NEW) reduce 154) ((T_NS_C) reduce 154) ((T_OBJECT_CAST) reduce 154) ((T_PRINT) reduce 154) ((T_READONLY) reduce 154) ((T_REQUIRE) reduce 154) ((T_REQUIRE_ONCE) reduce 154) ((T_RETURN) reduce 154) ((T_START_HEREDOC) reduce 154) ((T_STATIC) reduce 154) ((T_STRING) reduce 154) ((T_STRING_CAST) reduce 154) ((T_SWITCH) reduce 154) ((T_THROW) reduce 154) ((T_TRAIT) reduce 154) ((T_TRAIT_C) reduce 154) ((T_TRY) reduce 154) ((T_UNSET) reduce 154) ((T_UNSET_CAST) reduce 154) ((T_VARIABLE) reduce 154) ((T_WHILE) reduce 154) ((T_YIELD) reduce 154) ((T_YIELD_FROM) reduce 154) (("[") reduce 154) (("`") reduce 154) (("{") reduce 154) (("~") reduce 154)) 24063 ((("!") reduce 166) (("\"") reduce 166) (("$") reduce 166) (("(") reduce 166) (("+") reduce 166) (("-") reduce 166) ((";") reduce 166) (("@") reduce 166) ((T_ABSTRACT) reduce 166) ((T_ARRAY) reduce 166) ((T_ARRAY_CAST) reduce 166) ((T_ATTRIBUTE) reduce 166) ((T_BOOL_CAST) reduce 166) ((T_BREAK) reduce 166) ((T_CLASS) reduce 166) ((T_CLASS_C) reduce 166) ((T_CLONE) reduce 166) ((T_CONSTANT_ENCAPSED_STRING) reduce 166) ((T_CONTINUE) reduce 166) ((T_DEC) reduce 166) ((T_DECLARE) reduce 166) ((T_DIR) reduce 166) ((T_DNUMBER) reduce 166) ((T_DO) reduce 166) ((T_DOUBLE_CAST) reduce 166) ((T_ECHO) reduce 166) ((T_ELSE) reduce 166) ((T_ELSEIF) reduce 166) ((T_EMPTY) reduce 166) ((T_ENDWHILE) reduce 166) ((T_ENUM) reduce 166) ((T_EVAL) reduce 166) ((T_EXIT) reduce 166) ((T_FILE) reduce 166) ((T_FINAL) reduce 166) ((T_FN) reduce 166) ((T_FOR) reduce 166) ((T_FOREACH) reduce 166) ((T_FUNCTION) reduce 166) ((T_FUNC_C) reduce 166) ((T_GLOBAL) reduce 166) ((T_GOTO) reduce 166) ((T_HALT_COMPILER) reduce 166) ((T_IF) reduce 166) ((T_INC) reduce 166) ((T_INCLUDE) reduce 166) ((T_INCLUDE_ONCE) reduce 166) ((T_INLINE_HTML) reduce 166) ((T_INTERFACE) reduce 166) ((T_INT_CAST) reduce 166) ((T_ISSET) reduce 166) ((T_LINE) reduce 166) ((T_LIST) reduce 166) ((T_LNUMBER) reduce 166) ((T_MATCH) reduce 166) ((T_METHOD_C) reduce 166) ((T_NAME_FULLY_QUALIFIED) reduce 166) ((T_NAME_QUALIFIED) reduce 166) ((T_NAME_RELATIVE) reduce 166) ((T_NEW) reduce 166) ((T_NS_C) reduce 166) ((T_OBJECT_CAST) reduce 166) ((T_PRINT) reduce 166) ((T_READONLY) reduce 166) ((T_REQUIRE) reduce 166) ((T_REQUIRE_ONCE) reduce 166) ((T_RETURN) reduce 166) ((T_START_HEREDOC) reduce 166) ((T_STATIC) reduce 166) ((T_STRING) reduce 166) ((T_STRING_CAST) reduce 166) ((T_SWITCH) reduce 166) ((T_THROW) reduce 166) ((T_TRAIT) reduce 166) ((T_TRAIT_C) reduce 166) ((T_TRY) reduce 166) ((T_UNSET) reduce 166) ((T_UNSET_CAST) reduce 166) ((T_VARIABLE) reduce 166) ((T_WHILE) reduce 166) ((T_YIELD) reduce 166) ((T_YIELD_FROM) reduce 166) (("[") reduce 166) (("`") reduce 166) (("{") reduce 166) (("~") reduce 166)) 24065 ((("!") reduce 155) (("\"") reduce 155) (("$") reduce 155) (("(") reduce 155) (("+") reduce 155) (("-") reduce 155) ((";") reduce 155) (("@") reduce 155) ((T_ABSTRACT) reduce 155) ((T_ARRAY) reduce 155) ((T_ARRAY_CAST) reduce 155) ((T_ATTRIBUTE) reduce 155) ((T_BOOL_CAST) reduce 155) ((T_BREAK) reduce 155) ((T_CLASS) reduce 155) ((T_CLASS_C) reduce 155) ((T_CLONE) reduce 155) ((T_CONSTANT_ENCAPSED_STRING) reduce 155) ((T_CONTINUE) reduce 155) ((T_DEC) reduce 155) ((T_DECLARE) reduce 155) ((T_DIR) reduce 155) ((T_DNUMBER) reduce 155) ((T_DO) reduce 155) ((T_DOUBLE_CAST) reduce 155) ((T_ECHO) reduce 155) ((T_ELSE) reduce 155) ((T_ELSEIF) reduce 155) ((T_EMPTY) reduce 155) ((T_ENDWHILE) reduce 155) ((T_ENUM) reduce 155) ((T_EVAL) reduce 155) ((T_EXIT) reduce 155) ((T_FILE) reduce 155) ((T_FINAL) reduce 155) ((T_FN) reduce 155) ((T_FOR) reduce 155) ((T_FOREACH) reduce 155) ((T_FUNCTION) reduce 155) ((T_FUNC_C) reduce 155) ((T_GLOBAL) reduce 155) ((T_GOTO) reduce 155) ((T_HALT_COMPILER) reduce 155) ((T_IF) reduce 155) ((T_INC) reduce 155) ((T_INCLUDE) reduce 155) ((T_INCLUDE_ONCE) reduce 155) ((T_INLINE_HTML) reduce 155) ((T_INTERFACE) reduce 155) ((T_INT_CAST) reduce 155) ((T_ISSET) reduce 155) ((T_LINE) reduce 155) ((T_LIST) reduce 155) ((T_LNUMBER) reduce 155) ((T_MATCH) reduce 155) ((T_METHOD_C) reduce 155) ((T_NAME_FULLY_QUALIFIED) reduce 155) ((T_NAME_QUALIFIED) reduce 155) ((T_NAME_RELATIVE) reduce 155) ((T_NEW) reduce 155) ((T_NS_C) reduce 155) ((T_OBJECT_CAST) reduce 155) ((T_PRINT) reduce 155) ((T_READONLY) reduce 155) ((T_REQUIRE) reduce 155) ((T_REQUIRE_ONCE) reduce 155) ((T_RETURN) reduce 155) ((T_START_HEREDOC) reduce 155) ((T_STATIC) reduce 155) ((T_STRING) reduce 155) ((T_STRING_CAST) reduce 155) ((T_SWITCH) reduce 155) ((T_THROW) reduce 155) ((T_TRAIT) reduce 155) ((T_TRAIT_C) reduce 155) ((T_TRY) reduce 155) ((T_UNSET) reduce 155) ((T_UNSET_CAST) reduce 155) ((T_VARIABLE) reduce 155) ((T_WHILE) reduce 155) ((T_YIELD) reduce 155) ((T_YIELD_FROM) reduce 155) (("[") reduce 155) (("`") reduce 155) (("{") reduce 155) (("~") reduce 155)) 24075 ((("!") reduce 162) (("\"") reduce 162) (("$") reduce 162) (("(") reduce 162) (("+") reduce 162) (("-") reduce 162) ((";") reduce 162) (("@") reduce 162) ((T_ABSTRACT) reduce 162) ((T_ARRAY) reduce 162) ((T_ARRAY_CAST) reduce 162) ((T_ATTRIBUTE) reduce 162) ((T_BOOL_CAST) reduce 162) ((T_BREAK) reduce 162) ((T_CLASS) reduce 162) ((T_CLASS_C) reduce 162) ((T_CLONE) reduce 162) ((T_CONSTANT_ENCAPSED_STRING) reduce 162) ((T_CONTINUE) reduce 162) ((T_DEC) reduce 162) ((T_DECLARE) reduce 162) ((T_DIR) reduce 162) ((T_DNUMBER) reduce 162) ((T_DO) reduce 162) ((T_DOUBLE_CAST) reduce 162) ((T_ECHO) reduce 162) ((T_ELSE) reduce 162) ((T_ELSEIF) reduce 162) ((T_EMPTY) reduce 162) ((T_ENDWHILE) reduce 162) ((T_ENUM) reduce 162) ((T_EVAL) reduce 162) ((T_EXIT) reduce 162) ((T_FILE) reduce 162) ((T_FINAL) reduce 162) ((T_FN) reduce 162) ((T_FOR) reduce 162) ((T_FOREACH) reduce 162) ((T_FUNCTION) reduce 162) ((T_FUNC_C) reduce 162) ((T_GLOBAL) reduce 162) ((T_GOTO) reduce 162) ((T_HALT_COMPILER) reduce 162) ((T_IF) reduce 162) ((T_INC) reduce 162) ((T_INCLUDE) reduce 162) ((T_INCLUDE_ONCE) reduce 162) ((T_INLINE_HTML) reduce 162) ((T_INTERFACE) reduce 162) ((T_INT_CAST) reduce 162) ((T_ISSET) reduce 162) ((T_LINE) reduce 162) ((T_LIST) reduce 162) ((T_LNUMBER) reduce 162) ((T_MATCH) reduce 162) ((T_METHOD_C) reduce 162) ((T_NAME_FULLY_QUALIFIED) reduce 162) ((T_NAME_QUALIFIED) reduce 162) ((T_NAME_RELATIVE) reduce 162) ((T_NEW) reduce 162) ((T_NS_C) reduce 162) ((T_OBJECT_CAST) reduce 162) ((T_PRINT) reduce 162) ((T_READONLY) reduce 162) ((T_REQUIRE) reduce 162) ((T_REQUIRE_ONCE) reduce 162) ((T_RETURN) reduce 162) ((T_START_HEREDOC) reduce 162) ((T_STATIC) reduce 162) ((T_STRING) reduce 162) ((T_STRING_CAST) reduce 162) ((T_SWITCH) reduce 162) ((T_THROW) reduce 162) ((T_TRAIT) reduce 162) ((T_TRAIT_C) reduce 162) ((T_TRY) reduce 162) ((T_UNSET) reduce 162) ((T_UNSET_CAST) reduce 162) ((T_VARIABLE) reduce 162) ((T_WHILE) reduce 162) ((T_YIELD) reduce 162) ((T_YIELD_FROM) reduce 162) (("[") reduce 162) (("`") reduce 162) (("{") reduce 162) (("~") reduce 162)) 24076 ((("!") reduce 217) (("\"") reduce 217) (("$") reduce 217) (("(") reduce 217) (("+") reduce 217) (("-") reduce 217) ((";") reduce 217) (("@") reduce 217) ((T_ABSTRACT) reduce 217) ((T_ARRAY) reduce 217) ((T_ARRAY_CAST) reduce 217) ((T_ATTRIBUTE) reduce 217) ((T_BOOL_CAST) reduce 217) ((T_BREAK) reduce 217) ((T_CLASS) reduce 217) ((T_CLASS_C) reduce 217) ((T_CLONE) reduce 217) ((T_CONSTANT_ENCAPSED_STRING) reduce 217) ((T_CONTINUE) reduce 217) ((T_DEC) reduce 217) ((T_DECLARE) reduce 217) ((T_DIR) reduce 217) ((T_DNUMBER) reduce 217) ((T_DO) reduce 217) ((T_DOUBLE_CAST) reduce 217) ((T_ECHO) reduce 217) ((T_ELSE) reduce 217) ((T_ELSEIF) reduce 217) ((T_EMPTY) reduce 217) ((T_ENDWHILE) reduce 217) ((T_ENUM) reduce 217) ((T_EVAL) reduce 217) ((T_EXIT) reduce 217) ((T_FILE) reduce 217) ((T_FINAL) reduce 217) ((T_FN) reduce 217) ((T_FOR) reduce 217) ((T_FOREACH) reduce 217) ((T_FUNCTION) reduce 217) ((T_FUNC_C) reduce 217) ((T_GLOBAL) reduce 217) ((T_GOTO) reduce 217) ((T_HALT_COMPILER) reduce 217) ((T_IF) reduce 217) ((T_INC) reduce 217) ((T_INCLUDE) reduce 217) ((T_INCLUDE_ONCE) reduce 217) ((T_INLINE_HTML) reduce 217) ((T_INTERFACE) reduce 217) ((T_INT_CAST) reduce 217) ((T_ISSET) reduce 217) ((T_LINE) reduce 217) ((T_LIST) reduce 217) ((T_LNUMBER) reduce 217) ((T_MATCH) reduce 217) ((T_METHOD_C) reduce 217) ((T_NAME_FULLY_QUALIFIED) reduce 217) ((T_NAME_QUALIFIED) reduce 217) ((T_NAME_RELATIVE) reduce 217) ((T_NEW) reduce 217) ((T_NS_C) reduce 217) ((T_OBJECT_CAST) reduce 217) ((T_PRINT) reduce 217) ((T_READONLY) reduce 217) ((T_REQUIRE) reduce 217) ((T_REQUIRE_ONCE) reduce 217) ((T_RETURN) reduce 217) ((T_START_HEREDOC) reduce 217) ((T_STATIC) reduce 217) ((T_STRING) reduce 217) ((T_STRING_CAST) reduce 217) ((T_SWITCH) reduce 217) ((T_THROW) reduce 217) ((T_TRAIT) reduce 217) ((T_TRAIT_C) reduce 217) ((T_TRY) reduce 217) ((T_UNSET) reduce 217) ((T_UNSET_CAST) reduce 217) ((T_VARIABLE) reduce 217) ((T_WHILE) reduce 217) ((T_YIELD) reduce 217) ((T_YIELD_FROM) reduce 217) (("[") reduce 217) (("`") reduce 217) (("{") reduce 217) (("~") reduce 217)) 24079 ((("!") reduce 218) (("\"") reduce 218) (("$") reduce 218) (("(") reduce 218) (("+") reduce 218) (("-") reduce 218) ((";") reduce 218) (("@") reduce 218) ((T_ABSTRACT) reduce 218) ((T_ARRAY) reduce 218) ((T_ARRAY_CAST) reduce 218) ((T_ATTRIBUTE) reduce 218) ((T_BOOL_CAST) reduce 218) ((T_BREAK) reduce 218) ((T_CLASS) reduce 218) ((T_CLASS_C) reduce 218) ((T_CLONE) reduce 218) ((T_CONSTANT_ENCAPSED_STRING) reduce 218) ((T_CONTINUE) reduce 218) ((T_DEC) reduce 218) ((T_DECLARE) reduce 218) ((T_DIR) reduce 218) ((T_DNUMBER) reduce 218) ((T_DO) reduce 218) ((T_DOUBLE_CAST) reduce 218) ((T_ECHO) reduce 218) ((T_ELSE) reduce 218) ((T_ELSEIF) reduce 218) ((T_EMPTY) reduce 218) ((T_ENDWHILE) reduce 218) ((T_ENUM) reduce 218) ((T_EVAL) reduce 218) ((T_EXIT) reduce 218) ((T_FILE) reduce 218) ((T_FINAL) reduce 218) ((T_FN) reduce 218) ((T_FOR) reduce 218) ((T_FOREACH) reduce 218) ((T_FUNCTION) reduce 218) ((T_FUNC_C) reduce 218) ((T_GLOBAL) reduce 218) ((T_GOTO) reduce 218) ((T_HALT_COMPILER) reduce 218) ((T_IF) reduce 218) ((T_INC) reduce 218) ((T_INCLUDE) reduce 218) ((T_INCLUDE_ONCE) reduce 218) ((T_INLINE_HTML) reduce 218) ((T_INTERFACE) reduce 218) ((T_INT_CAST) reduce 218) ((T_ISSET) reduce 218) ((T_LINE) reduce 218) ((T_LIST) reduce 218) ((T_LNUMBER) reduce 218) ((T_MATCH) reduce 218) ((T_METHOD_C) reduce 218) ((T_NAME_FULLY_QUALIFIED) reduce 218) ((T_NAME_QUALIFIED) reduce 218) ((T_NAME_RELATIVE) reduce 218) ((T_NEW) reduce 218) ((T_NS_C) reduce 218) ((T_OBJECT_CAST) reduce 218) ((T_PRINT) reduce 218) ((T_READONLY) reduce 218) ((T_REQUIRE) reduce 218) ((T_REQUIRE_ONCE) reduce 218) ((T_RETURN) reduce 218) ((T_START_HEREDOC) reduce 218) ((T_STATIC) reduce 218) ((T_STRING) reduce 218) ((T_STRING_CAST) reduce 218) ((T_SWITCH) reduce 218) ((T_THROW) reduce 218) ((T_TRAIT) reduce 218) ((T_TRAIT_C) reduce 218) ((T_TRY) reduce 218) ((T_UNSET) reduce 218) ((T_UNSET_CAST) reduce 218) ((T_VARIABLE) reduce 218) ((T_WHILE) reduce 218) ((T_YIELD) reduce 218) ((T_YIELD_FROM) reduce 218) (("[") reduce 218) (("`") reduce 218) (("{") reduce 218) (("~") reduce 218)) 24080 ((("!") reduce 161) (("\"") reduce 161) (("$") reduce 161) (("(") reduce 161) (("+") reduce 161) (("-") reduce 161) ((";") reduce 161) (("@") reduce 161) ((T_ABSTRACT) reduce 161) ((T_ARRAY) reduce 161) ((T_ARRAY_CAST) reduce 161) ((T_ATTRIBUTE) reduce 161) ((T_BOOL_CAST) reduce 161) ((T_BREAK) reduce 161) ((T_CLASS) reduce 161) ((T_CLASS_C) reduce 161) ((T_CLONE) reduce 161) ((T_CONSTANT_ENCAPSED_STRING) reduce 161) ((T_CONTINUE) reduce 161) ((T_DEC) reduce 161) ((T_DECLARE) reduce 161) ((T_DIR) reduce 161) ((T_DNUMBER) reduce 161) ((T_DO) reduce 161) ((T_DOUBLE_CAST) reduce 161) ((T_ECHO) reduce 161) ((T_ELSE) reduce 161) ((T_ELSEIF) reduce 161) ((T_EMPTY) reduce 161) ((T_ENDWHILE) reduce 161) ((T_ENUM) reduce 161) ((T_EVAL) reduce 161) ((T_EXIT) reduce 161) ((T_FILE) reduce 161) ((T_FINAL) reduce 161) ((T_FN) reduce 161) ((T_FOR) reduce 161) ((T_FOREACH) reduce 161) ((T_FUNCTION) reduce 161) ((T_FUNC_C) reduce 161) ((T_GLOBAL) reduce 161) ((T_GOTO) reduce 161) ((T_HALT_COMPILER) reduce 161) ((T_IF) reduce 161) ((T_INC) reduce 161) ((T_INCLUDE) reduce 161) ((T_INCLUDE_ONCE) reduce 161) ((T_INLINE_HTML) reduce 161) ((T_INTERFACE) reduce 161) ((T_INT_CAST) reduce 161) ((T_ISSET) reduce 161) ((T_LINE) reduce 161) ((T_LIST) reduce 161) ((T_LNUMBER) reduce 161) ((T_MATCH) reduce 161) ((T_METHOD_C) reduce 161) ((T_NAME_FULLY_QUALIFIED) reduce 161) ((T_NAME_QUALIFIED) reduce 161) ((T_NAME_RELATIVE) reduce 161) ((T_NEW) reduce 161) ((T_NS_C) reduce 161) ((T_OBJECT_CAST) reduce 161) ((T_PRINT) reduce 161) ((T_READONLY) reduce 161) ((T_REQUIRE) reduce 161) ((T_REQUIRE_ONCE) reduce 161) ((T_RETURN) reduce 161) ((T_START_HEREDOC) reduce 161) ((T_STATIC) reduce 161) ((T_STRING) reduce 161) ((T_STRING_CAST) reduce 161) ((T_SWITCH) reduce 161) ((T_THROW) reduce 161) ((T_TRAIT) reduce 161) ((T_TRAIT_C) reduce 161) ((T_TRY) reduce 161) ((T_UNSET) reduce 161) ((T_UNSET_CAST) reduce 161) ((T_VARIABLE) reduce 161) ((T_WHILE) reduce 161) ((T_YIELD) reduce 161) ((T_YIELD_FROM) reduce 161) (("[") reduce 161) (("`") reduce 161) (("{") reduce 161) (("~") reduce 161)) 24089 ((("!") reduce 150) (("\"") reduce 150) (("$") reduce 150) (("(") reduce 150) (("+") reduce 150) (("-") reduce 150) ((";") reduce 150) (("@") reduce 150) ((T_ABSTRACT) reduce 150) ((T_ARRAY) reduce 150) ((T_ARRAY_CAST) reduce 150) ((T_ATTRIBUTE) reduce 150) ((T_BOOL_CAST) reduce 150) ((T_BREAK) reduce 150) ((T_CLASS) reduce 150) ((T_CLASS_C) reduce 150) ((T_CLONE) reduce 150) ((T_CONSTANT_ENCAPSED_STRING) reduce 150) ((T_CONTINUE) reduce 150) ((T_DEC) reduce 150) ((T_DECLARE) reduce 150) ((T_DIR) reduce 150) ((T_DNUMBER) reduce 150) ((T_DO) reduce 150) ((T_DOUBLE_CAST) reduce 150) ((T_ECHO) reduce 150) ((T_ELSE) reduce 150) ((T_ELSEIF) reduce 150) ((T_EMPTY) reduce 150) ((T_ENDWHILE) reduce 150) ((T_ENUM) reduce 150) ((T_EVAL) reduce 150) ((T_EXIT) reduce 150) ((T_FILE) reduce 150) ((T_FINAL) reduce 150) ((T_FN) reduce 150) ((T_FOR) reduce 150) ((T_FOREACH) reduce 150) ((T_FUNCTION) reduce 150) ((T_FUNC_C) reduce 150) ((T_GLOBAL) reduce 150) ((T_GOTO) reduce 150) ((T_HALT_COMPILER) reduce 150) ((T_IF) reduce 150) ((T_INC) reduce 150) ((T_INCLUDE) reduce 150) ((T_INCLUDE_ONCE) reduce 150) ((T_INLINE_HTML) reduce 150) ((T_INTERFACE) reduce 150) ((T_INT_CAST) reduce 150) ((T_ISSET) reduce 150) ((T_LINE) reduce 150) ((T_LIST) reduce 150) ((T_LNUMBER) reduce 150) ((T_MATCH) reduce 150) ((T_METHOD_C) reduce 150) ((T_NAME_FULLY_QUALIFIED) reduce 150) ((T_NAME_QUALIFIED) reduce 150) ((T_NAME_RELATIVE) reduce 150) ((T_NEW) reduce 150) ((T_NS_C) reduce 150) ((T_OBJECT_CAST) reduce 150) ((T_PRINT) reduce 150) ((T_READONLY) reduce 150) ((T_REQUIRE) reduce 150) ((T_REQUIRE_ONCE) reduce 150) ((T_RETURN) reduce 150) ((T_START_HEREDOC) reduce 150) ((T_STATIC) reduce 150) ((T_STRING) reduce 150) ((T_STRING_CAST) reduce 150) ((T_SWITCH) reduce 150) ((T_THROW) reduce 150) ((T_TRAIT) reduce 150) ((T_TRAIT_C) reduce 150) ((T_TRY) reduce 150) ((T_UNSET) reduce 150) ((T_UNSET_CAST) reduce 150) ((T_VARIABLE) reduce 150) ((T_WHILE) reduce 150) ((T_YIELD) reduce 150) ((T_YIELD_FROM) reduce 150) (("[") reduce 150) (("`") reduce 150) (("{") reduce 150) (("~") reduce 150)) 24090 ((("!") reduce 215) (("\"") reduce 215) (("$") reduce 215) (("(") reduce 215) (("+") reduce 215) (("-") reduce 215) ((";") reduce 215) (("@") reduce 215) ((T_ABSTRACT) reduce 215) ((T_ARRAY) reduce 215) ((T_ARRAY_CAST) reduce 215) ((T_ATTRIBUTE) reduce 215) ((T_BOOL_CAST) reduce 215) ((T_BREAK) reduce 215) ((T_CLASS) reduce 215) ((T_CLASS_C) reduce 215) ((T_CLONE) reduce 215) ((T_CONSTANT_ENCAPSED_STRING) reduce 215) ((T_CONTINUE) reduce 215) ((T_DEC) reduce 215) ((T_DECLARE) reduce 215) ((T_DIR) reduce 215) ((T_DNUMBER) reduce 215) ((T_DO) reduce 215) ((T_DOUBLE_CAST) reduce 215) ((T_ECHO) reduce 215) ((T_ELSE) reduce 215) ((T_ELSEIF) reduce 215) ((T_EMPTY) reduce 215) ((T_ENDWHILE) reduce 215) ((T_ENUM) reduce 215) ((T_EVAL) reduce 215) ((T_EXIT) reduce 215) ((T_FILE) reduce 215) ((T_FINAL) reduce 215) ((T_FN) reduce 215) ((T_FOR) reduce 215) ((T_FOREACH) reduce 215) ((T_FUNCTION) reduce 215) ((T_FUNC_C) reduce 215) ((T_GLOBAL) reduce 215) ((T_GOTO) reduce 215) ((T_HALT_COMPILER) reduce 215) ((T_IF) reduce 215) ((T_INC) reduce 215) ((T_INCLUDE) reduce 215) ((T_INCLUDE_ONCE) reduce 215) ((T_INLINE_HTML) reduce 215) ((T_INTERFACE) reduce 215) ((T_INT_CAST) reduce 215) ((T_ISSET) reduce 215) ((T_LINE) reduce 215) ((T_LIST) reduce 215) ((T_LNUMBER) reduce 215) ((T_MATCH) reduce 215) ((T_METHOD_C) reduce 215) ((T_NAME_FULLY_QUALIFIED) reduce 215) ((T_NAME_QUALIFIED) reduce 215) ((T_NAME_RELATIVE) reduce 215) ((T_NEW) reduce 215) ((T_NS_C) reduce 215) ((T_OBJECT_CAST) reduce 215) ((T_PRINT) reduce 215) ((T_READONLY) reduce 215) ((T_REQUIRE) reduce 215) ((T_REQUIRE_ONCE) reduce 215) ((T_RETURN) reduce 215) ((T_START_HEREDOC) reduce 215) ((T_STATIC) reduce 215) ((T_STRING) reduce 215) ((T_STRING_CAST) reduce 215) ((T_SWITCH) reduce 215) ((T_THROW) reduce 215) ((T_TRAIT) reduce 215) ((T_TRAIT_C) reduce 215) ((T_TRY) reduce 215) ((T_UNSET) reduce 215) ((T_UNSET_CAST) reduce 215) ((T_VARIABLE) reduce 215) ((T_WHILE) reduce 215) ((T_YIELD) reduce 215) ((T_YIELD_FROM) reduce 215) (("[") reduce 215) (("`") reduce 215) (("{") reduce 215) (("~") reduce 215)) 24093 ((("!") reduce 216) (("\"") reduce 216) (("$") reduce 216) (("(") reduce 216) (("+") reduce 216) (("-") reduce 216) ((";") reduce 216) (("@") reduce 216) ((T_ABSTRACT) reduce 216) ((T_ARRAY) reduce 216) ((T_ARRAY_CAST) reduce 216) ((T_ATTRIBUTE) reduce 216) ((T_BOOL_CAST) reduce 216) ((T_BREAK) reduce 216) ((T_CLASS) reduce 216) ((T_CLASS_C) reduce 216) ((T_CLONE) reduce 216) ((T_CONSTANT_ENCAPSED_STRING) reduce 216) ((T_CONTINUE) reduce 216) ((T_DEC) reduce 216) ((T_DECLARE) reduce 216) ((T_DIR) reduce 216) ((T_DNUMBER) reduce 216) ((T_DO) reduce 216) ((T_DOUBLE_CAST) reduce 216) ((T_ECHO) reduce 216) ((T_ELSE) reduce 216) ((T_ELSEIF) reduce 216) ((T_EMPTY) reduce 216) ((T_ENDWHILE) reduce 216) ((T_ENUM) reduce 216) ((T_EVAL) reduce 216) ((T_EXIT) reduce 216) ((T_FILE) reduce 216) ((T_FINAL) reduce 216) ((T_FN) reduce 216) ((T_FOR) reduce 216) ((T_FOREACH) reduce 216) ((T_FUNCTION) reduce 216) ((T_FUNC_C) reduce 216) ((T_GLOBAL) reduce 216) ((T_GOTO) reduce 216) ((T_HALT_COMPILER) reduce 216) ((T_IF) reduce 216) ((T_INC) reduce 216) ((T_INCLUDE) reduce 216) ((T_INCLUDE_ONCE) reduce 216) ((T_INLINE_HTML) reduce 216) ((T_INTERFACE) reduce 216) ((T_INT_CAST) reduce 216) ((T_ISSET) reduce 216) ((T_LINE) reduce 216) ((T_LIST) reduce 216) ((T_LNUMBER) reduce 216) ((T_MATCH) reduce 216) ((T_METHOD_C) reduce 216) ((T_NAME_FULLY_QUALIFIED) reduce 216) ((T_NAME_QUALIFIED) reduce 216) ((T_NAME_RELATIVE) reduce 216) ((T_NEW) reduce 216) ((T_NS_C) reduce 216) ((T_OBJECT_CAST) reduce 216) ((T_PRINT) reduce 216) ((T_READONLY) reduce 216) ((T_REQUIRE) reduce 216) ((T_REQUIRE_ONCE) reduce 216) ((T_RETURN) reduce 216) ((T_START_HEREDOC) reduce 216) ((T_STATIC) reduce 216) ((T_STRING) reduce 216) ((T_STRING_CAST) reduce 216) ((T_SWITCH) reduce 216) ((T_THROW) reduce 216) ((T_TRAIT) reduce 216) ((T_TRAIT_C) reduce 216) ((T_TRY) reduce 216) ((T_UNSET) reduce 216) ((T_UNSET_CAST) reduce 216) ((T_VARIABLE) reduce 216) ((T_WHILE) reduce 216) ((T_YIELD) reduce 216) ((T_YIELD_FROM) reduce 216) (("[") reduce 216) (("`") reduce 216) (("{") reduce 216) (("~") reduce 216)) 24095 ((("!") reduce 157) (("\"") reduce 157) (("$") reduce 157) (("(") reduce 157) (("+") reduce 157) (("-") reduce 157) ((";") reduce 157) (("@") reduce 157) ((T_ABSTRACT) reduce 157) ((T_ARRAY) reduce 157) ((T_ARRAY_CAST) reduce 157) ((T_ATTRIBUTE) reduce 157) ((T_BOOL_CAST) reduce 157) ((T_BREAK) reduce 157) ((T_CLASS) reduce 157) ((T_CLASS_C) reduce 157) ((T_CLONE) reduce 157) ((T_CONSTANT_ENCAPSED_STRING) reduce 157) ((T_CONTINUE) reduce 157) ((T_DEC) reduce 157) ((T_DECLARE) reduce 157) ((T_DIR) reduce 157) ((T_DNUMBER) reduce 157) ((T_DO) reduce 157) ((T_DOUBLE_CAST) reduce 157) ((T_ECHO) reduce 157) ((T_ELSE) reduce 157) ((T_ELSEIF) reduce 157) ((T_EMPTY) reduce 157) ((T_ENDWHILE) reduce 157) ((T_ENUM) reduce 157) ((T_EVAL) reduce 157) ((T_EXIT) reduce 157) ((T_FILE) reduce 157) ((T_FINAL) reduce 157) ((T_FN) reduce 157) ((T_FOR) reduce 157) ((T_FOREACH) reduce 157) ((T_FUNCTION) reduce 157) ((T_FUNC_C) reduce 157) ((T_GLOBAL) reduce 157) ((T_GOTO) reduce 157) ((T_HALT_COMPILER) reduce 157) ((T_IF) reduce 157) ((T_INC) reduce 157) ((T_INCLUDE) reduce 157) ((T_INCLUDE_ONCE) reduce 157) ((T_INLINE_HTML) reduce 157) ((T_INTERFACE) reduce 157) ((T_INT_CAST) reduce 157) ((T_ISSET) reduce 157) ((T_LINE) reduce 157) ((T_LIST) reduce 157) ((T_LNUMBER) reduce 157) ((T_MATCH) reduce 157) ((T_METHOD_C) reduce 157) ((T_NAME_FULLY_QUALIFIED) reduce 157) ((T_NAME_QUALIFIED) reduce 157) ((T_NAME_RELATIVE) reduce 157) ((T_NEW) reduce 157) ((T_NS_C) reduce 157) ((T_OBJECT_CAST) reduce 157) ((T_PRINT) reduce 157) ((T_READONLY) reduce 157) ((T_REQUIRE) reduce 157) ((T_REQUIRE_ONCE) reduce 157) ((T_RETURN) reduce 157) ((T_START_HEREDOC) reduce 157) ((T_STATIC) reduce 157) ((T_STRING) reduce 157) ((T_STRING_CAST) reduce 157) ((T_SWITCH) reduce 157) ((T_THROW) reduce 157) ((T_TRAIT) reduce 157) ((T_TRAIT_C) reduce 157) ((T_TRY) reduce 157) ((T_UNSET) reduce 157) ((T_UNSET_CAST) reduce 157) ((T_VARIABLE) reduce 157) ((T_WHILE) reduce 157) ((T_YIELD) reduce 157) ((T_YIELD_FROM) reduce 157) (("[") reduce 157) (("`") reduce 157) (("{") reduce 157) (("~") reduce 157)) 24101 ((("!") reduce 149) (("\"") reduce 149) (("$") reduce 149) (("(") reduce 149) (("+") reduce 149) (("-") reduce 149) ((";") reduce 149) (("@") reduce 149) ((T_ABSTRACT) reduce 149) ((T_ARRAY) reduce 149) ((T_ARRAY_CAST) reduce 149) ((T_ATTRIBUTE) reduce 149) ((T_BOOL_CAST) reduce 149) ((T_BREAK) reduce 149) ((T_CLASS) reduce 149) ((T_CLASS_C) reduce 149) ((T_CLONE) reduce 149) ((T_CONSTANT_ENCAPSED_STRING) reduce 149) ((T_CONTINUE) reduce 149) ((T_DEC) reduce 149) ((T_DECLARE) reduce 149) ((T_DIR) reduce 149) ((T_DNUMBER) reduce 149) ((T_DO) reduce 149) ((T_DOUBLE_CAST) reduce 149) ((T_ECHO) reduce 149) ((T_ELSE) reduce 149) ((T_ELSEIF) reduce 149) ((T_EMPTY) reduce 149) ((T_ENDWHILE) reduce 149) ((T_ENUM) reduce 149) ((T_EVAL) reduce 149) ((T_EXIT) reduce 149) ((T_FILE) reduce 149) ((T_FINAL) reduce 149) ((T_FN) reduce 149) ((T_FOR) reduce 149) ((T_FOREACH) reduce 149) ((T_FUNCTION) reduce 149) ((T_FUNC_C) reduce 149) ((T_GLOBAL) reduce 149) ((T_GOTO) reduce 149) ((T_HALT_COMPILER) reduce 149) ((T_IF) reduce 149) ((T_INC) reduce 149) ((T_INCLUDE) reduce 149) ((T_INCLUDE_ONCE) reduce 149) ((T_INLINE_HTML) reduce 149) ((T_INTERFACE) reduce 149) ((T_INT_CAST) reduce 149) ((T_ISSET) reduce 149) ((T_LINE) reduce 149) ((T_LIST) reduce 149) ((T_LNUMBER) reduce 149) ((T_MATCH) reduce 149) ((T_METHOD_C) reduce 149) ((T_NAME_FULLY_QUALIFIED) reduce 149) ((T_NAME_QUALIFIED) reduce 149) ((T_NAME_RELATIVE) reduce 149) ((T_NEW) reduce 149) ((T_NS_C) reduce 149) ((T_OBJECT_CAST) reduce 149) ((T_PRINT) reduce 149) ((T_READONLY) reduce 149) ((T_REQUIRE) reduce 149) ((T_REQUIRE_ONCE) reduce 149) ((T_RETURN) reduce 149) ((T_START_HEREDOC) reduce 149) ((T_STATIC) reduce 149) ((T_STRING) reduce 149) ((T_STRING_CAST) reduce 149) ((T_SWITCH) reduce 149) ((T_THROW) reduce 149) ((T_TRAIT) reduce 149) ((T_TRAIT_C) reduce 149) ((T_TRY) reduce 149) ((T_UNSET) reduce 149) ((T_UNSET_CAST) reduce 149) ((T_VARIABLE) reduce 149) ((T_WHILE) reduce 149) ((T_YIELD) reduce 149) ((T_YIELD_FROM) reduce 149) (("[") reduce 149) (("`") reduce 149) (("{") reduce 149) (("~") reduce 149)) 24106 ((("!") reduce 163) (("\"") reduce 163) (("$") reduce 163) (("(") reduce 163) (("+") reduce 163) (("-") reduce 163) ((";") reduce 163) (("@") reduce 163) ((T_ABSTRACT) reduce 163) ((T_ARRAY) reduce 163) ((T_ARRAY_CAST) reduce 163) ((T_ATTRIBUTE) reduce 163) ((T_BOOL_CAST) reduce 163) ((T_BREAK) reduce 163) ((T_CLASS) reduce 163) ((T_CLASS_C) reduce 163) ((T_CLONE) reduce 163) ((T_CONSTANT_ENCAPSED_STRING) reduce 163) ((T_CONTINUE) reduce 163) ((T_DEC) reduce 163) ((T_DECLARE) reduce 163) ((T_DIR) reduce 163) ((T_DNUMBER) reduce 163) ((T_DO) reduce 163) ((T_DOUBLE_CAST) reduce 163) ((T_ECHO) reduce 163) ((T_ELSE) reduce 163) ((T_ELSEIF) reduce 163) ((T_EMPTY) reduce 163) ((T_ENDWHILE) reduce 163) ((T_ENUM) reduce 163) ((T_EVAL) reduce 163) ((T_EXIT) reduce 163) ((T_FILE) reduce 163) ((T_FINAL) reduce 163) ((T_FN) reduce 163) ((T_FOR) reduce 163) ((T_FOREACH) reduce 163) ((T_FUNCTION) reduce 163) ((T_FUNC_C) reduce 163) ((T_GLOBAL) reduce 163) ((T_GOTO) reduce 163) ((T_HALT_COMPILER) reduce 163) ((T_IF) reduce 163) ((T_INC) reduce 163) ((T_INCLUDE) reduce 163) ((T_INCLUDE_ONCE) reduce 163) ((T_INLINE_HTML) reduce 163) ((T_INTERFACE) reduce 163) ((T_INT_CAST) reduce 163) ((T_ISSET) reduce 163) ((T_LINE) reduce 163) ((T_LIST) reduce 163) ((T_LNUMBER) reduce 163) ((T_MATCH) reduce 163) ((T_METHOD_C) reduce 163) ((T_NAME_FULLY_QUALIFIED) reduce 163) ((T_NAME_QUALIFIED) reduce 163) ((T_NAME_RELATIVE) reduce 163) ((T_NEW) reduce 163) ((T_NS_C) reduce 163) ((T_OBJECT_CAST) reduce 163) ((T_PRINT) reduce 163) ((T_READONLY) reduce 163) ((T_REQUIRE) reduce 163) ((T_REQUIRE_ONCE) reduce 163) ((T_RETURN) reduce 163) ((T_START_HEREDOC) reduce 163) ((T_STATIC) reduce 163) ((T_STRING) reduce 163) ((T_STRING_CAST) reduce 163) ((T_SWITCH) reduce 163) ((T_THROW) reduce 163) ((T_TRAIT) reduce 163) ((T_TRAIT_C) reduce 163) ((T_TRY) reduce 163) ((T_UNSET) reduce 163) ((T_UNSET_CAST) reduce 163) ((T_VARIABLE) reduce 163) ((T_WHILE) reduce 163) ((T_YIELD) reduce 163) ((T_YIELD_FROM) reduce 163) (("[") reduce 163) (("`") reduce 163) (("{") reduce 163) (("~") reduce 163)) 24107 ((("!") reduce 219) (("\"") reduce 219) (("$") reduce 219) (("(") reduce 219) (("+") reduce 219) (("-") reduce 219) ((";") reduce 219) (("@") reduce 219) ((T_ABSTRACT) reduce 219) ((T_ARRAY) reduce 219) ((T_ARRAY_CAST) reduce 219) ((T_ATTRIBUTE) reduce 219) ((T_BOOL_CAST) reduce 219) ((T_BREAK) reduce 219) ((T_CLASS) reduce 219) ((T_CLASS_C) reduce 219) ((T_CLONE) reduce 219) ((T_CONSTANT_ENCAPSED_STRING) reduce 219) ((T_CONTINUE) reduce 219) ((T_DEC) reduce 219) ((T_DECLARE) reduce 219) ((T_DIR) reduce 219) ((T_DNUMBER) reduce 219) ((T_DO) reduce 219) ((T_DOUBLE_CAST) reduce 219) ((T_ECHO) reduce 219) ((T_ELSE) reduce 219) ((T_ELSEIF) reduce 219) ((T_EMPTY) reduce 219) ((T_ENDWHILE) reduce 219) ((T_ENUM) reduce 219) ((T_EVAL) reduce 219) ((T_EXIT) reduce 219) ((T_FILE) reduce 219) ((T_FINAL) reduce 219) ((T_FN) reduce 219) ((T_FOR) reduce 219) ((T_FOREACH) reduce 219) ((T_FUNCTION) reduce 219) ((T_FUNC_C) reduce 219) ((T_GLOBAL) reduce 219) ((T_GOTO) reduce 219) ((T_HALT_COMPILER) reduce 219) ((T_IF) reduce 219) ((T_INC) reduce 219) ((T_INCLUDE) reduce 219) ((T_INCLUDE_ONCE) reduce 219) ((T_INLINE_HTML) reduce 219) ((T_INTERFACE) reduce 219) ((T_INT_CAST) reduce 219) ((T_ISSET) reduce 219) ((T_LINE) reduce 219) ((T_LIST) reduce 219) ((T_LNUMBER) reduce 219) ((T_MATCH) reduce 219) ((T_METHOD_C) reduce 219) ((T_NAME_FULLY_QUALIFIED) reduce 219) ((T_NAME_QUALIFIED) reduce 219) ((T_NAME_RELATIVE) reduce 219) ((T_NEW) reduce 219) ((T_NS_C) reduce 219) ((T_OBJECT_CAST) reduce 219) ((T_PRINT) reduce 219) ((T_READONLY) reduce 219) ((T_REQUIRE) reduce 219) ((T_REQUIRE_ONCE) reduce 219) ((T_RETURN) reduce 219) ((T_START_HEREDOC) reduce 219) ((T_STATIC) reduce 219) ((T_STRING) reduce 219) ((T_STRING_CAST) reduce 219) ((T_SWITCH) reduce 219) ((T_THROW) reduce 219) ((T_TRAIT) reduce 219) ((T_TRAIT_C) reduce 219) ((T_TRY) reduce 219) ((T_UNSET) reduce 219) ((T_UNSET_CAST) reduce 219) ((T_VARIABLE) reduce 219) ((T_WHILE) reduce 219) ((T_YIELD) reduce 219) ((T_YIELD_FROM) reduce 219) (("[") reduce 219) (("`") reduce 219) (("{") reduce 219) (("~") reduce 219)) 24110 ((("!") reduce 220) (("\"") reduce 220) (("$") reduce 220) (("(") reduce 220) (("+") reduce 220) (("-") reduce 220) ((";") reduce 220) (("@") reduce 220) ((T_ABSTRACT) reduce 220) ((T_ARRAY) reduce 220) ((T_ARRAY_CAST) reduce 220) ((T_ATTRIBUTE) reduce 220) ((T_BOOL_CAST) reduce 220) ((T_BREAK) reduce 220) ((T_CLASS) reduce 220) ((T_CLASS_C) reduce 220) ((T_CLONE) reduce 220) ((T_CONSTANT_ENCAPSED_STRING) reduce 220) ((T_CONTINUE) reduce 220) ((T_DEC) reduce 220) ((T_DECLARE) reduce 220) ((T_DIR) reduce 220) ((T_DNUMBER) reduce 220) ((T_DO) reduce 220) ((T_DOUBLE_CAST) reduce 220) ((T_ECHO) reduce 220) ((T_ELSE) reduce 220) ((T_ELSEIF) reduce 220) ((T_EMPTY) reduce 220) ((T_ENDWHILE) reduce 220) ((T_ENUM) reduce 220) ((T_EVAL) reduce 220) ((T_EXIT) reduce 220) ((T_FILE) reduce 220) ((T_FINAL) reduce 220) ((T_FN) reduce 220) ((T_FOR) reduce 220) ((T_FOREACH) reduce 220) ((T_FUNCTION) reduce 220) ((T_FUNC_C) reduce 220) ((T_GLOBAL) reduce 220) ((T_GOTO) reduce 220) ((T_HALT_COMPILER) reduce 220) ((T_IF) reduce 220) ((T_INC) reduce 220) ((T_INCLUDE) reduce 220) ((T_INCLUDE_ONCE) reduce 220) ((T_INLINE_HTML) reduce 220) ((T_INTERFACE) reduce 220) ((T_INT_CAST) reduce 220) ((T_ISSET) reduce 220) ((T_LINE) reduce 220) ((T_LIST) reduce 220) ((T_LNUMBER) reduce 220) ((T_MATCH) reduce 220) ((T_METHOD_C) reduce 220) ((T_NAME_FULLY_QUALIFIED) reduce 220) ((T_NAME_QUALIFIED) reduce 220) ((T_NAME_RELATIVE) reduce 220) ((T_NEW) reduce 220) ((T_NS_C) reduce 220) ((T_OBJECT_CAST) reduce 220) ((T_PRINT) reduce 220) ((T_READONLY) reduce 220) ((T_REQUIRE) reduce 220) ((T_REQUIRE_ONCE) reduce 220) ((T_RETURN) reduce 220) ((T_START_HEREDOC) reduce 220) ((T_STATIC) reduce 220) ((T_STRING) reduce 220) ((T_STRING_CAST) reduce 220) ((T_SWITCH) reduce 220) ((T_THROW) reduce 220) ((T_TRAIT) reduce 220) ((T_TRAIT_C) reduce 220) ((T_TRY) reduce 220) ((T_UNSET) reduce 220) ((T_UNSET_CAST) reduce 220) ((T_VARIABLE) reduce 220) ((T_WHILE) reduce 220) ((T_YIELD) reduce 220) ((T_YIELD_FROM) reduce 220) (("[") reduce 220) (("`") reduce 220) (("{") reduce 220) (("~") reduce 220)) 24112 ((("!") reduce 153) (("\"") reduce 153) (("$") reduce 153) (("(") reduce 153) (("+") reduce 153) (("-") reduce 153) ((";") reduce 153) (("@") reduce 153) ((T_ABSTRACT) reduce 153) ((T_ARRAY) reduce 153) ((T_ARRAY_CAST) reduce 153) ((T_ATTRIBUTE) reduce 153) ((T_BOOL_CAST) reduce 153) ((T_BREAK) reduce 153) ((T_CLASS) reduce 153) ((T_CLASS_C) reduce 153) ((T_CLONE) reduce 153) ((T_CONSTANT_ENCAPSED_STRING) reduce 153) ((T_CONTINUE) reduce 153) ((T_DEC) reduce 153) ((T_DECLARE) reduce 153) ((T_DIR) reduce 153) ((T_DNUMBER) reduce 153) ((T_DO) reduce 153) ((T_DOUBLE_CAST) reduce 153) ((T_ECHO) reduce 153) ((T_ELSE) reduce 153) ((T_ELSEIF) reduce 153) ((T_EMPTY) reduce 153) ((T_ENDWHILE) reduce 153) ((T_ENUM) reduce 153) ((T_EVAL) reduce 153) ((T_EXIT) reduce 153) ((T_FILE) reduce 153) ((T_FINAL) reduce 153) ((T_FN) reduce 153) ((T_FOR) reduce 153) ((T_FOREACH) reduce 153) ((T_FUNCTION) reduce 153) ((T_FUNC_C) reduce 153) ((T_GLOBAL) reduce 153) ((T_GOTO) reduce 153) ((T_HALT_COMPILER) reduce 153) ((T_IF) reduce 153) ((T_INC) reduce 153) ((T_INCLUDE) reduce 153) ((T_INCLUDE_ONCE) reduce 153) ((T_INLINE_HTML) reduce 153) ((T_INTERFACE) reduce 153) ((T_INT_CAST) reduce 153) ((T_ISSET) reduce 153) ((T_LINE) reduce 153) ((T_LIST) reduce 153) ((T_LNUMBER) reduce 153) ((T_MATCH) reduce 153) ((T_METHOD_C) reduce 153) ((T_NAME_FULLY_QUALIFIED) reduce 153) ((T_NAME_QUALIFIED) reduce 153) ((T_NAME_RELATIVE) reduce 153) ((T_NEW) reduce 153) ((T_NS_C) reduce 153) ((T_OBJECT_CAST) reduce 153) ((T_PRINT) reduce 153) ((T_READONLY) reduce 153) ((T_REQUIRE) reduce 153) ((T_REQUIRE_ONCE) reduce 153) ((T_RETURN) reduce 153) ((T_START_HEREDOC) reduce 153) ((T_STATIC) reduce 153) ((T_STRING) reduce 153) ((T_STRING_CAST) reduce 153) ((T_SWITCH) reduce 153) ((T_THROW) reduce 153) ((T_TRAIT) reduce 153) ((T_TRAIT_C) reduce 153) ((T_TRY) reduce 153) ((T_UNSET) reduce 153) ((T_UNSET_CAST) reduce 153) ((T_VARIABLE) reduce 153) ((T_WHILE) reduce 153) ((T_YIELD) reduce 153) ((T_YIELD_FROM) reduce 153) (("[") reduce 153) (("`") reduce 153) (("{") reduce 153) (("~") reduce 153)) 24114 ((("!") reduce 152) (("\"") reduce 152) (("$") reduce 152) (("(") reduce 152) (("+") reduce 152) (("-") reduce 152) ((";") reduce 152) (("@") reduce 152) ((T_ABSTRACT) reduce 152) ((T_ARRAY) reduce 152) ((T_ARRAY_CAST) reduce 152) ((T_ATTRIBUTE) reduce 152) ((T_BOOL_CAST) reduce 152) ((T_BREAK) reduce 152) ((T_CLASS) reduce 152) ((T_CLASS_C) reduce 152) ((T_CLONE) reduce 152) ((T_CONSTANT_ENCAPSED_STRING) reduce 152) ((T_CONTINUE) reduce 152) ((T_DEC) reduce 152) ((T_DECLARE) reduce 152) ((T_DIR) reduce 152) ((T_DNUMBER) reduce 152) ((T_DO) reduce 152) ((T_DOUBLE_CAST) reduce 152) ((T_ECHO) reduce 152) ((T_ELSE) reduce 152) ((T_ELSEIF) reduce 152) ((T_EMPTY) reduce 152) ((T_ENDWHILE) reduce 152) ((T_ENUM) reduce 152) ((T_EVAL) reduce 152) ((T_EXIT) reduce 152) ((T_FILE) reduce 152) ((T_FINAL) reduce 152) ((T_FN) reduce 152) ((T_FOR) reduce 152) ((T_FOREACH) reduce 152) ((T_FUNCTION) reduce 152) ((T_FUNC_C) reduce 152) ((T_GLOBAL) reduce 152) ((T_GOTO) reduce 152) ((T_HALT_COMPILER) reduce 152) ((T_IF) reduce 152) ((T_INC) reduce 152) ((T_INCLUDE) reduce 152) ((T_INCLUDE_ONCE) reduce 152) ((T_INLINE_HTML) reduce 152) ((T_INTERFACE) reduce 152) ((T_INT_CAST) reduce 152) ((T_ISSET) reduce 152) ((T_LINE) reduce 152) ((T_LIST) reduce 152) ((T_LNUMBER) reduce 152) ((T_MATCH) reduce 152) ((T_METHOD_C) reduce 152) ((T_NAME_FULLY_QUALIFIED) reduce 152) ((T_NAME_QUALIFIED) reduce 152) ((T_NAME_RELATIVE) reduce 152) ((T_NEW) reduce 152) ((T_NS_C) reduce 152) ((T_OBJECT_CAST) reduce 152) ((T_PRINT) reduce 152) ((T_READONLY) reduce 152) ((T_REQUIRE) reduce 152) ((T_REQUIRE_ONCE) reduce 152) ((T_RETURN) reduce 152) ((T_START_HEREDOC) reduce 152) ((T_STATIC) reduce 152) ((T_STRING) reduce 152) ((T_STRING_CAST) reduce 152) ((T_SWITCH) reduce 152) ((T_THROW) reduce 152) ((T_TRAIT) reduce 152) ((T_TRAIT_C) reduce 152) ((T_TRY) reduce 152) ((T_UNSET) reduce 152) ((T_UNSET_CAST) reduce 152) ((T_VARIABLE) reduce 152) ((T_WHILE) reduce 152) ((T_YIELD) reduce 152) ((T_YIELD_FROM) reduce 152) (("[") reduce 152) (("`") reduce 152) (("{") reduce 152) (("~") reduce 152)) 24115 ((("!") reduce 244) (("\"") reduce 244) (("$") reduce 244) (("(") reduce 244) (("+") reduce 244) (("-") reduce 244) ((";") reduce 244) (("@") reduce 244) ((T_ABSTRACT) reduce 244) ((T_ARRAY) reduce 244) ((T_ARRAY_CAST) reduce 244) ((T_ATTRIBUTE) reduce 244) ((T_BOOL_CAST) reduce 244) ((T_BREAK) reduce 244) ((T_CLASS) reduce 244) ((T_CLASS_C) reduce 244) ((T_CLONE) reduce 244) ((T_CONSTANT_ENCAPSED_STRING) reduce 244) ((T_CONTINUE) reduce 244) ((T_DEC) reduce 244) ((T_DECLARE) reduce 244) ((T_DIR) reduce 244) ((T_DNUMBER) reduce 244) ((T_DO) reduce 244) ((T_DOUBLE_CAST) reduce 244) ((T_ECHO) reduce 244) ((T_EMPTY) reduce 244) ((T_ENDWHILE) reduce 244) ((T_ENUM) reduce 244) ((T_EVAL) reduce 244) ((T_EXIT) reduce 244) ((T_FILE) reduce 244) ((T_FINAL) reduce 244) ((T_FN) reduce 244) ((T_FOR) reduce 244) ((T_FOREACH) reduce 244) ((T_FUNCTION) reduce 244) ((T_FUNC_C) reduce 244) ((T_GLOBAL) reduce 244) ((T_GOTO) reduce 244) ((T_HALT_COMPILER) reduce 244) ((T_IF) reduce 244) ((T_INC) reduce 244) ((T_INCLUDE) reduce 244) ((T_INCLUDE_ONCE) reduce 244) ((T_INLINE_HTML) reduce 244) ((T_INTERFACE) reduce 244) ((T_INT_CAST) reduce 244) ((T_ISSET) reduce 244) ((T_LINE) reduce 244) ((T_LIST) reduce 244) ((T_LNUMBER) reduce 244) ((T_MATCH) reduce 244) ((T_METHOD_C) reduce 244) ((T_NAME_FULLY_QUALIFIED) reduce 244) ((T_NAME_QUALIFIED) reduce 244) ((T_NAME_RELATIVE) reduce 244) ((T_NEW) reduce 244) ((T_NS_C) reduce 244) ((T_OBJECT_CAST) reduce 244) ((T_PRINT) reduce 244) ((T_READONLY) reduce 244) ((T_REQUIRE) reduce 244) ((T_REQUIRE_ONCE) reduce 244) ((T_RETURN) reduce 244) ((T_START_HEREDOC) reduce 244) ((T_STATIC) reduce 244) ((T_STRING) reduce 244) ((T_STRING_CAST) reduce 244) ((T_SWITCH) reduce 244) ((T_THROW) reduce 244) ((T_TRAIT) reduce 244) ((T_TRAIT_C) reduce 244) ((T_TRY) reduce 244) ((T_UNSET) reduce 244) ((T_UNSET_CAST) reduce 244) ((T_VARIABLE) reduce 244) ((T_WHILE) reduce 244) ((T_YIELD) reduce 244) ((T_YIELD_FROM) reduce 244) (("[") reduce 244) (("`") reduce 244) (("{") reduce 244) (("~") reduce 244)) 24126 ((("!") reduce 455) (("\"") reduce 455) (("$") reduce 455) (("(") reduce 455) (("+") reduce 455) (("-") reduce 455) ((";") reduce 455) (("@") reduce 455) ((T_ABSTRACT) reduce 455) ((T_ARRAY) reduce 455) ((T_ARRAY_CAST) reduce 455) ((T_ATTRIBUTE) reduce 455) ((T_BOOL_CAST) reduce 455) ((T_BREAK) reduce 455) ((T_CLASS) reduce 455) ((T_CLASS_C) reduce 455) ((T_CLONE) reduce 455) ((T_CONSTANT_ENCAPSED_STRING) reduce 455) ((T_CONTINUE) reduce 455) ((T_DEC) reduce 455) ((T_DECLARE) reduce 455) ((T_DIR) reduce 455) ((T_DNUMBER) reduce 455) ((T_DO) reduce 455) ((T_DOUBLE_CAST) reduce 455) ((T_ECHO) reduce 455) ((T_EMPTY) reduce 455) ((T_ENDWHILE) reduce 455) ((T_ENUM) reduce 455) ((T_EVAL) reduce 455) ((T_EXIT) reduce 455) ((T_FILE) reduce 455) ((T_FINAL) reduce 455) ((T_FN) reduce 455) ((T_FOR) reduce 455) ((T_FOREACH) reduce 455) ((T_FUNCTION) reduce 455) ((T_FUNC_C) reduce 455) ((T_GLOBAL) reduce 455) ((T_GOTO) reduce 455) ((T_HALT_COMPILER) reduce 455) ((T_IF) reduce 455) ((T_INC) reduce 455) ((T_INCLUDE) reduce 455) ((T_INCLUDE_ONCE) reduce 455) ((T_INLINE_HTML) reduce 455) ((T_INTERFACE) reduce 455) ((T_INT_CAST) reduce 455) ((T_ISSET) reduce 455) ((T_LINE) reduce 455) ((T_LIST) reduce 455) ((T_LNUMBER) reduce 455) ((T_MATCH) reduce 455) ((T_METHOD_C) reduce 455) ((T_NAME_FULLY_QUALIFIED) reduce 455) ((T_NAME_QUALIFIED) reduce 455) ((T_NAME_RELATIVE) reduce 455) ((T_NEW) reduce 455) ((T_NS_C) reduce 455) ((T_OBJECT_CAST) reduce 455) ((T_PRINT) reduce 455) ((T_READONLY) reduce 455) ((T_REQUIRE) reduce 455) ((T_REQUIRE_ONCE) reduce 455) ((T_RETURN) reduce 455) ((T_START_HEREDOC) reduce 455) ((T_STATIC) reduce 455) ((T_STRING) reduce 455) ((T_STRING_CAST) reduce 455) ((T_SWITCH) reduce 455) ((T_THROW) reduce 455) ((T_TRAIT) reduce 455) ((T_TRAIT_C) reduce 455) ((T_TRY) reduce 455) ((T_UNSET) reduce 455) ((T_UNSET_CAST) reduce 455) ((T_VARIABLE) reduce 455) ((T_WHILE) reduce 455) ((T_YIELD) reduce 455) ((T_YIELD_FROM) reduce 455) (("[") reduce 455) (("`") reduce 455) (("{") reduce 455) (("~") reduce 455)) 24127 ((("!") reduce 181) (("\"") reduce 181) (("$") reduce 181) (("(") reduce 181) (("+") reduce 181) (("-") reduce 181) ((";") reduce 181) (("@") reduce 181) ((T_ABSTRACT) reduce 181) ((T_ARRAY) reduce 181) ((T_ARRAY_CAST) reduce 181) ((T_ATTRIBUTE) reduce 181) ((T_BOOL_CAST) reduce 181) ((T_BREAK) reduce 181) ((T_CLASS) reduce 181) ((T_CLASS_C) reduce 181) ((T_CLONE) reduce 181) ((T_CONSTANT_ENCAPSED_STRING) reduce 181) ((T_CONTINUE) reduce 181) ((T_DEC) reduce 181) ((T_DECLARE) reduce 181) ((T_DIR) reduce 181) ((T_DNUMBER) reduce 181) ((T_DO) reduce 181) ((T_DOUBLE_CAST) reduce 181) ((T_ECHO) reduce 181) ((T_EMPTY) reduce 181) ((T_ENDWHILE) reduce 181) ((T_ENUM) reduce 181) ((T_EVAL) reduce 181) ((T_EXIT) reduce 181) ((T_FILE) reduce 181) ((T_FINAL) reduce 181) ((T_FN) reduce 181) ((T_FOR) reduce 181) ((T_FOREACH) reduce 181) ((T_FUNCTION) reduce 181) ((T_FUNC_C) reduce 181) ((T_GLOBAL) reduce 181) ((T_GOTO) reduce 181) ((T_HALT_COMPILER) reduce 181) ((T_IF) reduce 181) ((T_INC) reduce 181) ((T_INCLUDE) reduce 181) ((T_INCLUDE_ONCE) reduce 181) ((T_INLINE_HTML) reduce 181) ((T_INTERFACE) reduce 181) ((T_INT_CAST) reduce 181) ((T_ISSET) reduce 181) ((T_LINE) reduce 181) ((T_LIST) reduce 181) ((T_LNUMBER) reduce 181) ((T_MATCH) reduce 181) ((T_METHOD_C) reduce 181) ((T_NAME_FULLY_QUALIFIED) reduce 181) ((T_NAME_QUALIFIED) reduce 181) ((T_NAME_RELATIVE) reduce 181) ((T_NEW) reduce 181) ((T_NS_C) reduce 181) ((T_OBJECT_CAST) reduce 181) ((T_PRINT) reduce 181) ((T_READONLY) reduce 181) ((T_REQUIRE) reduce 181) ((T_REQUIRE_ONCE) reduce 181) ((T_RETURN) reduce 181) ((T_START_HEREDOC) reduce 181) ((T_STATIC) reduce 181) ((T_STRING) reduce 181) ((T_STRING_CAST) reduce 181) ((T_SWITCH) reduce 181) ((T_THROW) reduce 181) ((T_TRAIT) reduce 181) ((T_TRAIT_C) reduce 181) ((T_TRY) reduce 181) ((T_UNSET) reduce 181) ((T_UNSET_CAST) reduce 181) ((T_VARIABLE) reduce 181) ((T_WHILE) reduce 181) ((T_YIELD) reduce 181) ((T_YIELD_FROM) reduce 181) (("[") reduce 181) (("`") reduce 181) (("{") reduce 181) (("~") reduce 181)) 24128 ((("!") reduce 159) (("\"") reduce 159) (("$") reduce 159) (("(") reduce 159) (("+") reduce 159) (("-") reduce 159) ((";") reduce 159) (("@") reduce 159) ((T_ABSTRACT) reduce 159) ((T_ARRAY) reduce 159) ((T_ARRAY_CAST) reduce 159) ((T_ATTRIBUTE) reduce 159) ((T_BOOL_CAST) reduce 159) ((T_BREAK) reduce 159) ((T_CLASS) reduce 159) ((T_CLASS_C) reduce 159) ((T_CLONE) reduce 159) ((T_CONSTANT_ENCAPSED_STRING) reduce 159) ((T_CONTINUE) reduce 159) ((T_DEC) reduce 159) ((T_DECLARE) reduce 159) ((T_DIR) reduce 159) ((T_DNUMBER) reduce 159) ((T_DO) reduce 159) ((T_DOUBLE_CAST) reduce 159) ((T_ECHO) reduce 159) ((T_EMPTY) reduce 159) ((T_ENDWHILE) reduce 159) ((T_ENUM) reduce 159) ((T_EVAL) reduce 159) ((T_EXIT) reduce 159) ((T_FILE) reduce 159) ((T_FINAL) reduce 159) ((T_FN) reduce 159) ((T_FOR) reduce 159) ((T_FOREACH) reduce 159) ((T_FUNCTION) reduce 159) ((T_FUNC_C) reduce 159) ((T_GLOBAL) reduce 159) ((T_GOTO) reduce 159) ((T_HALT_COMPILER) reduce 159) ((T_IF) reduce 159) ((T_INC) reduce 159) ((T_INCLUDE) reduce 159) ((T_INCLUDE_ONCE) reduce 159) ((T_INLINE_HTML) reduce 159) ((T_INTERFACE) reduce 159) ((T_INT_CAST) reduce 159) ((T_ISSET) reduce 159) ((T_LINE) reduce 159) ((T_LIST) reduce 159) ((T_LNUMBER) reduce 159) ((T_MATCH) reduce 159) ((T_METHOD_C) reduce 159) ((T_NAME_FULLY_QUALIFIED) reduce 159) ((T_NAME_QUALIFIED) reduce 159) ((T_NAME_RELATIVE) reduce 159) ((T_NEW) reduce 159) ((T_NS_C) reduce 159) ((T_OBJECT_CAST) reduce 159) ((T_PRINT) reduce 159) ((T_READONLY) reduce 159) ((T_REQUIRE) reduce 159) ((T_REQUIRE_ONCE) reduce 159) ((T_RETURN) reduce 159) ((T_START_HEREDOC) reduce 159) ((T_STATIC) reduce 159) ((T_STRING) reduce 159) ((T_STRING_CAST) reduce 159) ((T_SWITCH) reduce 159) ((T_THROW) reduce 159) ((T_TRAIT) reduce 159) ((T_TRAIT_C) reduce 159) ((T_TRY) reduce 159) ((T_UNSET) reduce 159) ((T_UNSET_CAST) reduce 159) ((T_VARIABLE) reduce 159) ((T_WHILE) reduce 159) ((T_YIELD) reduce 159) ((T_YIELD_FROM) reduce 159) (("[") reduce 159) (("`") reduce 159) (("{") reduce 159) (("~") reduce 159)) 24136 ((("!") reduce 186) (("\"") reduce 186) (("$") reduce 186) (("(") reduce 186) (("+") reduce 186) (("-") reduce 186) ((";") reduce 186) (("@") reduce 186) ((T_ABSTRACT) reduce 186) ((T_ARRAY) reduce 186) ((T_ARRAY_CAST) reduce 186) ((T_ATTRIBUTE) reduce 186) ((T_BOOL_CAST) reduce 186) ((T_BREAK) reduce 186) ((T_CLASS) reduce 186) ((T_CLASS_C) reduce 186) ((T_CLONE) reduce 186) ((T_CONSTANT_ENCAPSED_STRING) reduce 186) ((T_CONTINUE) reduce 186) ((T_DEC) reduce 186) ((T_DECLARE) reduce 186) ((T_DIR) reduce 186) ((T_DNUMBER) reduce 186) ((T_DO) reduce 186) ((T_DOUBLE_CAST) reduce 186) ((T_ECHO) reduce 186) ((T_EMPTY) reduce 186) ((T_ENDWHILE) reduce 186) ((T_ENUM) reduce 186) ((T_EVAL) reduce 186) ((T_EXIT) reduce 186) ((T_FILE) reduce 186) ((T_FINAL) reduce 186) ((T_FN) reduce 186) ((T_FOR) reduce 186) ((T_FOREACH) reduce 186) ((T_FUNCTION) reduce 186) ((T_FUNC_C) reduce 186) ((T_GLOBAL) reduce 186) ((T_GOTO) reduce 186) ((T_HALT_COMPILER) reduce 186) ((T_IF) reduce 186) ((T_INC) reduce 186) ((T_INCLUDE) reduce 186) ((T_INCLUDE_ONCE) reduce 186) ((T_INLINE_HTML) reduce 186) ((T_INTERFACE) reduce 186) ((T_INT_CAST) reduce 186) ((T_ISSET) reduce 186) ((T_LINE) reduce 186) ((T_LIST) reduce 186) ((T_LNUMBER) reduce 186) ((T_MATCH) reduce 186) ((T_METHOD_C) reduce 186) ((T_NAME_FULLY_QUALIFIED) reduce 186) ((T_NAME_QUALIFIED) reduce 186) ((T_NAME_RELATIVE) reduce 186) ((T_NEW) reduce 186) ((T_NS_C) reduce 186) ((T_OBJECT_CAST) reduce 186) ((T_PRINT) reduce 186) ((T_READONLY) reduce 186) ((T_REQUIRE) reduce 186) ((T_REQUIRE_ONCE) reduce 186) ((T_RETURN) reduce 186) ((T_START_HEREDOC) reduce 186) ((T_STATIC) reduce 186) ((T_STRING) reduce 186) ((T_STRING_CAST) reduce 186) ((T_SWITCH) reduce 186) ((T_THROW) reduce 186) ((T_TRAIT) reduce 186) ((T_TRAIT_C) reduce 186) ((T_TRY) reduce 186) ((T_UNSET) reduce 186) ((T_UNSET_CAST) reduce 186) ((T_VARIABLE) reduce 186) ((T_WHILE) reduce 186) ((T_YIELD) reduce 186) ((T_YIELD_FROM) reduce 186) (("[") reduce 186) (("`") reduce 186) (("{") reduce 186) (("~") reduce 186)) 24137 ((("!") reduce 143) (("\"") reduce 143) (("$") reduce 143) (("(") reduce 143) (("+") reduce 143) (("-") reduce 143) ((";") reduce 143) (("@") reduce 143) ((T_ABSTRACT) reduce 143) ((T_ARRAY) reduce 143) ((T_ARRAY_CAST) reduce 143) ((T_ATTRIBUTE) reduce 143) ((T_BOOL_CAST) reduce 143) ((T_BREAK) reduce 143) ((T_CLASS) reduce 143) ((T_CLASS_C) reduce 143) ((T_CLONE) reduce 143) ((T_CONSTANT_ENCAPSED_STRING) reduce 143) ((T_CONTINUE) reduce 143) ((T_DEC) reduce 143) ((T_DECLARE) reduce 143) ((T_DIR) reduce 143) ((T_DNUMBER) reduce 143) ((T_DO) reduce 143) ((T_DOUBLE_CAST) reduce 143) ((T_ECHO) reduce 143) ((T_EMPTY) reduce 143) ((T_ENDWHILE) reduce 143) ((T_ENUM) reduce 143) ((T_EVAL) reduce 143) ((T_EXIT) reduce 143) ((T_FILE) reduce 143) ((T_FINAL) reduce 143) ((T_FN) reduce 143) ((T_FOR) reduce 143) ((T_FOREACH) reduce 143) ((T_FUNCTION) reduce 143) ((T_FUNC_C) reduce 143) ((T_GLOBAL) reduce 143) ((T_GOTO) reduce 143) ((T_HALT_COMPILER) reduce 143) ((T_IF) reduce 143) ((T_INC) reduce 143) ((T_INCLUDE) reduce 143) ((T_INCLUDE_ONCE) reduce 143) ((T_INLINE_HTML) reduce 143) ((T_INTERFACE) reduce 143) ((T_INT_CAST) reduce 143) ((T_ISSET) reduce 143) ((T_LINE) reduce 143) ((T_LIST) reduce 143) ((T_LNUMBER) reduce 143) ((T_MATCH) reduce 143) ((T_METHOD_C) reduce 143) ((T_NAME_FULLY_QUALIFIED) reduce 143) ((T_NAME_QUALIFIED) reduce 143) ((T_NAME_RELATIVE) reduce 143) ((T_NEW) reduce 143) ((T_NS_C) reduce 143) ((T_OBJECT_CAST) reduce 143) ((T_PRINT) reduce 143) ((T_READONLY) reduce 143) ((T_REQUIRE) reduce 143) ((T_REQUIRE_ONCE) reduce 143) ((T_RETURN) reduce 143) ((T_START_HEREDOC) reduce 143) ((T_STATIC) reduce 143) ((T_STRING) reduce 143) ((T_STRING_CAST) reduce 143) ((T_SWITCH) reduce 143) ((T_THROW) reduce 143) ((T_TRAIT) reduce 143) ((T_TRAIT_C) reduce 143) ((T_TRY) reduce 143) ((T_UNSET) reduce 143) ((T_UNSET_CAST) reduce 143) ((T_VARIABLE) reduce 143) ((T_WHILE) reduce 143) ((T_YIELD) reduce 143) ((T_YIELD_FROM) reduce 143) (("[") reduce 143) (("`") reduce 143) (("{") reduce 143) (("~") reduce 143)) 24140 ((("!") reduce 247) (("\"") reduce 247) (("$") reduce 247) (("(") reduce 247) (("+") reduce 247) (("-") reduce 247) ((";") reduce 247) (("@") reduce 247) ((T_ABSTRACT) reduce 247) ((T_ARRAY) reduce 247) ((T_ARRAY_CAST) reduce 247) ((T_ATTRIBUTE) reduce 247) ((T_BOOL_CAST) reduce 247) ((T_BREAK) reduce 247) ((T_CLASS) reduce 247) ((T_CLASS_C) reduce 247) ((T_CLONE) reduce 247) ((T_CONSTANT_ENCAPSED_STRING) reduce 247) ((T_CONTINUE) reduce 247) ((T_DEC) reduce 247) ((T_DECLARE) reduce 247) ((T_DIR) reduce 247) ((T_DNUMBER) reduce 247) ((T_DO) reduce 247) ((T_DOUBLE_CAST) reduce 247) ((T_ECHO) reduce 247) ((T_EMPTY) reduce 247) ((T_ENDWHILE) reduce 247) ((T_ENUM) reduce 247) ((T_EVAL) reduce 247) ((T_EXIT) reduce 247) ((T_FILE) reduce 247) ((T_FINAL) reduce 247) ((T_FN) reduce 247) ((T_FOR) reduce 247) ((T_FOREACH) reduce 247) ((T_FUNCTION) reduce 247) ((T_FUNC_C) reduce 247) ((T_GLOBAL) reduce 247) ((T_GOTO) reduce 247) ((T_HALT_COMPILER) reduce 247) ((T_IF) reduce 247) ((T_INC) reduce 247) ((T_INCLUDE) reduce 247) ((T_INCLUDE_ONCE) reduce 247) ((T_INLINE_HTML) reduce 247) ((T_INTERFACE) reduce 247) ((T_INT_CAST) reduce 247) ((T_ISSET) reduce 247) ((T_LINE) reduce 247) ((T_LIST) reduce 247) ((T_LNUMBER) reduce 247) ((T_MATCH) reduce 247) ((T_METHOD_C) reduce 247) ((T_NAME_FULLY_QUALIFIED) reduce 247) ((T_NAME_QUALIFIED) reduce 247) ((T_NAME_RELATIVE) reduce 247) ((T_NEW) reduce 247) ((T_NS_C) reduce 247) ((T_OBJECT_CAST) reduce 247) ((T_PRINT) reduce 247) ((T_READONLY) reduce 247) ((T_REQUIRE) reduce 247) ((T_REQUIRE_ONCE) reduce 247) ((T_RETURN) reduce 247) ((T_START_HEREDOC) reduce 247) ((T_STATIC) reduce 247) ((T_STRING) reduce 247) ((T_STRING_CAST) reduce 247) ((T_SWITCH) reduce 247) ((T_THROW) reduce 247) ((T_TRAIT) reduce 247) ((T_TRAIT_C) reduce 247) ((T_TRY) reduce 247) ((T_UNSET) reduce 247) ((T_UNSET_CAST) reduce 247) ((T_VARIABLE) reduce 247) ((T_WHILE) reduce 247) ((T_YIELD) reduce 247) ((T_YIELD_FROM) reduce 247) (("[") reduce 247) (("`") reduce 247) (("{") reduce 247) (("~") reduce 247)) 24144 ((("!") reduce 248) (("\"") reduce 248) (("$") reduce 248) (("(") reduce 248) (("+") reduce 248) (("-") reduce 248) ((";") reduce 248) (("@") reduce 248) ((T_ABSTRACT) reduce 248) ((T_ARRAY) reduce 248) ((T_ARRAY_CAST) reduce 248) ((T_ATTRIBUTE) reduce 248) ((T_BOOL_CAST) reduce 248) ((T_BREAK) reduce 248) ((T_CLASS) reduce 248) ((T_CLASS_C) reduce 248) ((T_CLONE) reduce 248) ((T_CONSTANT_ENCAPSED_STRING) reduce 248) ((T_CONTINUE) reduce 248) ((T_DEC) reduce 248) ((T_DECLARE) reduce 248) ((T_DIR) reduce 248) ((T_DNUMBER) reduce 248) ((T_DO) reduce 248) ((T_DOUBLE_CAST) reduce 248) ((T_ECHO) reduce 248) ((T_EMPTY) reduce 248) ((T_ENDWHILE) reduce 248) ((T_ENUM) reduce 248) ((T_EVAL) reduce 248) ((T_EXIT) reduce 248) ((T_FILE) reduce 248) ((T_FINAL) reduce 248) ((T_FN) reduce 248) ((T_FOR) reduce 248) ((T_FOREACH) reduce 248) ((T_FUNCTION) reduce 248) ((T_FUNC_C) reduce 248) ((T_GLOBAL) reduce 248) ((T_GOTO) reduce 248) ((T_HALT_COMPILER) reduce 248) ((T_IF) reduce 248) ((T_INC) reduce 248) ((T_INCLUDE) reduce 248) ((T_INCLUDE_ONCE) reduce 248) ((T_INLINE_HTML) reduce 248) ((T_INTERFACE) reduce 248) ((T_INT_CAST) reduce 248) ((T_ISSET) reduce 248) ((T_LINE) reduce 248) ((T_LIST) reduce 248) ((T_LNUMBER) reduce 248) ((T_MATCH) reduce 248) ((T_METHOD_C) reduce 248) ((T_NAME_FULLY_QUALIFIED) reduce 248) ((T_NAME_QUALIFIED) reduce 248) ((T_NAME_RELATIVE) reduce 248) ((T_NEW) reduce 248) ((T_NS_C) reduce 248) ((T_OBJECT_CAST) reduce 248) ((T_PRINT) reduce 248) ((T_READONLY) reduce 248) ((T_REQUIRE) reduce 248) ((T_REQUIRE_ONCE) reduce 248) ((T_RETURN) reduce 248) ((T_START_HEREDOC) reduce 248) ((T_STATIC) reduce 248) ((T_STRING) reduce 248) ((T_STRING_CAST) reduce 248) ((T_SWITCH) reduce 248) ((T_THROW) reduce 248) ((T_TRAIT) reduce 248) ((T_TRAIT_C) reduce 248) ((T_TRY) reduce 248) ((T_UNSET) reduce 248) ((T_UNSET_CAST) reduce 248) ((T_VARIABLE) reduce 248) ((T_WHILE) reduce 248) ((T_YIELD) reduce 248) ((T_YIELD_FROM) reduce 248) (("[") reduce 248) (("`") reduce 248) (("{") reduce 248) (("~") reduce 248)) 24149 ((("!") reduce 239) (("\"") reduce 239) (("$") reduce 239) (("(") reduce 239) (("+") reduce 239) (("-") reduce 239) ((";") reduce 239) (("@") reduce 239) ((T_ABSTRACT) reduce 239) ((T_ARRAY) reduce 239) ((T_ARRAY_CAST) reduce 239) ((T_ATTRIBUTE) reduce 239) ((T_BOOL_CAST) reduce 239) ((T_BREAK) reduce 239) ((T_CLASS) reduce 239) ((T_CLASS_C) reduce 239) ((T_CLONE) reduce 239) ((T_CONSTANT_ENCAPSED_STRING) reduce 239) ((T_CONTINUE) reduce 239) ((T_DEC) reduce 239) ((T_DECLARE) reduce 239) ((T_DIR) reduce 239) ((T_DNUMBER) reduce 239) ((T_DO) reduce 239) ((T_DOUBLE_CAST) reduce 239) ((T_ECHO) reduce 239) ((T_EMPTY) reduce 239) ((T_ENDWHILE) reduce 239) ((T_ENUM) reduce 239) ((T_EVAL) reduce 239) ((T_EXIT) reduce 239) ((T_FILE) reduce 239) ((T_FINAL) reduce 239) ((T_FN) reduce 239) ((T_FOR) reduce 239) ((T_FOREACH) reduce 239) ((T_FUNCTION) reduce 239) ((T_FUNC_C) reduce 239) ((T_GLOBAL) reduce 239) ((T_GOTO) reduce 239) ((T_HALT_COMPILER) reduce 239) ((T_IF) reduce 239) ((T_INC) reduce 239) ((T_INCLUDE) reduce 239) ((T_INCLUDE_ONCE) reduce 239) ((T_INLINE_HTML) reduce 239) ((T_INTERFACE) reduce 239) ((T_INT_CAST) reduce 239) ((T_ISSET) reduce 239) ((T_LINE) reduce 239) ((T_LIST) reduce 239) ((T_LNUMBER) reduce 239) ((T_MATCH) reduce 239) ((T_METHOD_C) reduce 239) ((T_NAME_FULLY_QUALIFIED) reduce 239) ((T_NAME_QUALIFIED) reduce 239) ((T_NAME_RELATIVE) reduce 239) ((T_NEW) reduce 239) ((T_NS_C) reduce 239) ((T_OBJECT_CAST) reduce 239) ((T_PRINT) reduce 239) ((T_READONLY) reduce 239) ((T_REQUIRE) reduce 239) ((T_REQUIRE_ONCE) reduce 239) ((T_RETURN) reduce 239) ((T_START_HEREDOC) reduce 239) ((T_STATIC) reduce 239) ((T_STRING) reduce 239) ((T_STRING_CAST) reduce 239) ((T_SWITCH) reduce 239) ((T_THROW) reduce 239) ((T_TRAIT) reduce 239) ((T_TRAIT_C) reduce 239) ((T_TRY) reduce 239) ((T_UNSET) reduce 239) ((T_UNSET_CAST) reduce 239) ((T_VARIABLE) reduce 239) ((T_WHILE) reduce 239) ((T_YIELD) reduce 239) ((T_YIELD_FROM) reduce 239) (("[") reduce 239) (("`") reduce 239) (("{") reduce 239) (("~") reduce 239)) 24150 ((("!") reduce 148) (("\"") reduce 148) (("$") reduce 148) (("(") reduce 148) (("+") reduce 148) (("-") reduce 148) ((";") reduce 148) (("@") reduce 148) ((T_ABSTRACT) reduce 148) ((T_ARRAY) reduce 148) ((T_ARRAY_CAST) reduce 148) ((T_ATTRIBUTE) reduce 148) ((T_BOOL_CAST) reduce 148) ((T_BREAK) reduce 148) ((T_CLASS) reduce 148) ((T_CLASS_C) reduce 148) ((T_CLONE) reduce 148) ((T_CONSTANT_ENCAPSED_STRING) reduce 148) ((T_CONTINUE) reduce 148) ((T_DEC) reduce 148) ((T_DECLARE) reduce 148) ((T_DIR) reduce 148) ((T_DNUMBER) reduce 148) ((T_DO) reduce 148) ((T_DOUBLE_CAST) reduce 148) ((T_ECHO) reduce 148) ((T_EMPTY) reduce 148) ((T_ENDWHILE) reduce 148) ((T_ENUM) reduce 148) ((T_EVAL) reduce 148) ((T_EXIT) reduce 148) ((T_FILE) reduce 148) ((T_FINAL) reduce 148) ((T_FN) reduce 148) ((T_FOR) reduce 148) ((T_FOREACH) reduce 148) ((T_FUNCTION) reduce 148) ((T_FUNC_C) reduce 148) ((T_GLOBAL) reduce 148) ((T_GOTO) reduce 148) ((T_HALT_COMPILER) reduce 148) ((T_IF) reduce 148) ((T_INC) reduce 148) ((T_INCLUDE) reduce 148) ((T_INCLUDE_ONCE) reduce 148) ((T_INLINE_HTML) reduce 148) ((T_INTERFACE) reduce 148) ((T_INT_CAST) reduce 148) ((T_ISSET) reduce 148) ((T_LINE) reduce 148) ((T_LIST) reduce 148) ((T_LNUMBER) reduce 148) ((T_MATCH) reduce 148) ((T_METHOD_C) reduce 148) ((T_NAME_FULLY_QUALIFIED) reduce 148) ((T_NAME_QUALIFIED) reduce 148) ((T_NAME_RELATIVE) reduce 148) ((T_NEW) reduce 148) ((T_NS_C) reduce 148) ((T_OBJECT_CAST) reduce 148) ((T_PRINT) reduce 148) ((T_READONLY) reduce 148) ((T_REQUIRE) reduce 148) ((T_REQUIRE_ONCE) reduce 148) ((T_RETURN) reduce 148) ((T_START_HEREDOC) reduce 148) ((T_STATIC) reduce 148) ((T_STRING) reduce 148) ((T_STRING_CAST) reduce 148) ((T_SWITCH) reduce 148) ((T_THROW) reduce 148) ((T_TRAIT) reduce 148) ((T_TRAIT_C) reduce 148) ((T_TRY) reduce 148) ((T_UNSET) reduce 148) ((T_UNSET_CAST) reduce 148) ((T_VARIABLE) reduce 148) ((T_WHILE) reduce 148) ((T_YIELD) reduce 148) ((T_YIELD_FROM) reduce 148) (("[") reduce 148) (("`") reduce 148) (("{") reduce 148) (("~") reduce 148)) 24153 ((("!") reduce 240) (("\"") reduce 240) (("$") reduce 240) (("(") reduce 240) (("+") reduce 240) (("-") reduce 240) ((";") reduce 240) (("@") reduce 240) ((T_ABSTRACT) reduce 240) ((T_ARRAY) reduce 240) ((T_ARRAY_CAST) reduce 240) ((T_ATTRIBUTE) reduce 240) ((T_BOOL_CAST) reduce 240) ((T_BREAK) reduce 240) ((T_CLASS) reduce 240) ((T_CLASS_C) reduce 240) ((T_CLONE) reduce 240) ((T_CONSTANT_ENCAPSED_STRING) reduce 240) ((T_CONTINUE) reduce 240) ((T_DEC) reduce 240) ((T_DECLARE) reduce 240) ((T_DIR) reduce 240) ((T_DNUMBER) reduce 240) ((T_DO) reduce 240) ((T_DOUBLE_CAST) reduce 240) ((T_ECHO) reduce 240) ((T_EMPTY) reduce 240) ((T_ENDWHILE) reduce 240) ((T_ENUM) reduce 240) ((T_EVAL) reduce 240) ((T_EXIT) reduce 240) ((T_FILE) reduce 240) ((T_FINAL) reduce 240) ((T_FN) reduce 240) ((T_FOR) reduce 240) ((T_FOREACH) reduce 240) ((T_FUNCTION) reduce 240) ((T_FUNC_C) reduce 240) ((T_GLOBAL) reduce 240) ((T_GOTO) reduce 240) ((T_HALT_COMPILER) reduce 240) ((T_IF) reduce 240) ((T_INC) reduce 240) ((T_INCLUDE) reduce 240) ((T_INCLUDE_ONCE) reduce 240) ((T_INLINE_HTML) reduce 240) ((T_INTERFACE) reduce 240) ((T_INT_CAST) reduce 240) ((T_ISSET) reduce 240) ((T_LINE) reduce 240) ((T_LIST) reduce 240) ((T_LNUMBER) reduce 240) ((T_MATCH) reduce 240) ((T_METHOD_C) reduce 240) ((T_NAME_FULLY_QUALIFIED) reduce 240) ((T_NAME_QUALIFIED) reduce 240) ((T_NAME_RELATIVE) reduce 240) ((T_NEW) reduce 240) ((T_NS_C) reduce 240) ((T_OBJECT_CAST) reduce 240) ((T_PRINT) reduce 240) ((T_READONLY) reduce 240) ((T_REQUIRE) reduce 240) ((T_REQUIRE_ONCE) reduce 240) ((T_RETURN) reduce 240) ((T_START_HEREDOC) reduce 240) ((T_STATIC) reduce 240) ((T_STRING) reduce 240) ((T_STRING_CAST) reduce 240) ((T_SWITCH) reduce 240) ((T_THROW) reduce 240) ((T_TRAIT) reduce 240) ((T_TRAIT_C) reduce 240) ((T_TRY) reduce 240) ((T_UNSET) reduce 240) ((T_UNSET_CAST) reduce 240) ((T_VARIABLE) reduce 240) ((T_WHILE) reduce 240) ((T_YIELD) reduce 240) ((T_YIELD_FROM) reduce 240) (("[") reduce 240) (("`") reduce 240) (("{") reduce 240) (("~") reduce 240)) 24158 ((("!") reduce 160) (("\"") reduce 160) (("$") reduce 160) (("(") reduce 160) (("+") reduce 160) (("-") reduce 160) ((";") reduce 160) (("@") reduce 160) ((T_ABSTRACT) reduce 160) ((T_ARRAY) reduce 160) ((T_ARRAY_CAST) reduce 160) ((T_ATTRIBUTE) reduce 160) ((T_BOOL_CAST) reduce 160) ((T_BREAK) reduce 160) ((T_CLASS) reduce 160) ((T_CLASS_C) reduce 160) ((T_CLONE) reduce 160) ((T_CONSTANT_ENCAPSED_STRING) reduce 160) ((T_CONTINUE) reduce 160) ((T_DEC) reduce 160) ((T_DECLARE) reduce 160) ((T_DIR) reduce 160) ((T_DNUMBER) reduce 160) ((T_DO) reduce 160) ((T_DOUBLE_CAST) reduce 160) ((T_ECHO) reduce 160) ((T_EMPTY) reduce 160) ((T_ENDWHILE) reduce 160) ((T_ENUM) reduce 160) ((T_EVAL) reduce 160) ((T_EXIT) reduce 160) ((T_FILE) reduce 160) ((T_FINAL) reduce 160) ((T_FN) reduce 160) ((T_FOR) reduce 160) ((T_FOREACH) reduce 160) ((T_FUNCTION) reduce 160) ((T_FUNC_C) reduce 160) ((T_GLOBAL) reduce 160) ((T_GOTO) reduce 160) ((T_HALT_COMPILER) reduce 160) ((T_IF) reduce 160) ((T_INC) reduce 160) ((T_INCLUDE) reduce 160) ((T_INCLUDE_ONCE) reduce 160) ((T_INLINE_HTML) reduce 160) ((T_INTERFACE) reduce 160) ((T_INT_CAST) reduce 160) ((T_ISSET) reduce 160) ((T_LINE) reduce 160) ((T_LIST) reduce 160) ((T_LNUMBER) reduce 160) ((T_MATCH) reduce 160) ((T_METHOD_C) reduce 160) ((T_NAME_FULLY_QUALIFIED) reduce 160) ((T_NAME_QUALIFIED) reduce 160) ((T_NAME_RELATIVE) reduce 160) ((T_NEW) reduce 160) ((T_NS_C) reduce 160) ((T_OBJECT_CAST) reduce 160) ((T_PRINT) reduce 160) ((T_READONLY) reduce 160) ((T_REQUIRE) reduce 160) ((T_REQUIRE_ONCE) reduce 160) ((T_RETURN) reduce 160) ((T_START_HEREDOC) reduce 160) ((T_STATIC) reduce 160) ((T_STRING) reduce 160) ((T_STRING_CAST) reduce 160) ((T_SWITCH) reduce 160) ((T_THROW) reduce 160) ((T_TRAIT) reduce 160) ((T_TRAIT_C) reduce 160) ((T_TRY) reduce 160) ((T_UNSET) reduce 160) ((T_UNSET_CAST) reduce 160) ((T_VARIABLE) reduce 160) ((T_WHILE) reduce 160) ((T_YIELD) reduce 160) ((T_YIELD_FROM) reduce 160) (("[") reduce 160) (("`") reduce 160) (("{") reduce 160) (("~") reduce 160)) 24161 ((("!") reduce 168) (("\"") reduce 168) (("$") reduce 168) (("(") reduce 168) (("+") reduce 168) (("-") reduce 168) ((";") reduce 168) (("@") reduce 168) ((T_ABSTRACT) reduce 168) ((T_ARRAY) reduce 168) ((T_ARRAY_CAST) reduce 168) ((T_ATTRIBUTE) reduce 168) ((T_BOOL_CAST) reduce 168) ((T_BREAK) reduce 168) ((T_CATCH) reduce 168) ((T_CLASS) reduce 168) ((T_CLASS_C) reduce 168) ((T_CLONE) reduce 168) ((T_CONSTANT_ENCAPSED_STRING) reduce 168) ((T_CONTINUE) reduce 168) ((T_DEC) reduce 168) ((T_DECLARE) reduce 168) ((T_DIR) reduce 168) ((T_DNUMBER) reduce 168) ((T_DO) reduce 168) ((T_DOUBLE_CAST) reduce 168) ((T_ECHO) reduce 168) ((T_EMPTY) reduce 168) ((T_ENDWHILE) reduce 168) ((T_ENUM) reduce 168) ((T_EVAL) reduce 168) ((T_EXIT) reduce 168) ((T_FILE) reduce 168) ((T_FINAL) reduce 168) ((T_FINALLY) reduce 168) ((T_FN) reduce 168) ((T_FOR) reduce 168) ((T_FOREACH) reduce 168) ((T_FUNCTION) reduce 168) ((T_FUNC_C) reduce 168) ((T_GLOBAL) reduce 168) ((T_GOTO) reduce 168) ((T_HALT_COMPILER) reduce 168) ((T_IF) reduce 168) ((T_INC) reduce 168) ((T_INCLUDE) reduce 168) ((T_INCLUDE_ONCE) reduce 168) ((T_INLINE_HTML) reduce 168) ((T_INTERFACE) reduce 168) ((T_INT_CAST) reduce 168) ((T_ISSET) reduce 168) ((T_LINE) reduce 168) ((T_LIST) reduce 168) ((T_LNUMBER) reduce 168) ((T_MATCH) reduce 168) ((T_METHOD_C) reduce 168) ((T_NAME_FULLY_QUALIFIED) reduce 168) ((T_NAME_QUALIFIED) reduce 168) ((T_NAME_RELATIVE) reduce 168) ((T_NEW) reduce 168) ((T_NS_C) reduce 168) ((T_OBJECT_CAST) reduce 168) ((T_PRINT) reduce 168) ((T_READONLY) reduce 168) ((T_REQUIRE) reduce 168) ((T_REQUIRE_ONCE) reduce 168) ((T_RETURN) reduce 168) ((T_START_HEREDOC) reduce 168) ((T_STATIC) reduce 168) ((T_STRING) reduce 168) ((T_STRING_CAST) reduce 168) ((T_SWITCH) reduce 168) ((T_THROW) reduce 168) ((T_TRAIT) reduce 168) ((T_TRAIT_C) reduce 168) ((T_TRY) reduce 168) ((T_UNSET) reduce 168) ((T_UNSET_CAST) reduce 168) ((T_VARIABLE) reduce 168) ((T_WHILE) reduce 168) ((T_YIELD) reduce 168) ((T_YIELD_FROM) reduce 168) (("[") reduce 168) (("`") reduce 168) (("{") reduce 168) (("~") reduce 168)) 24162 ((("!") reduce 174) (("\"") reduce 174) (("$") reduce 174) (("(") reduce 174) (("+") reduce 174) (("-") reduce 174) ((";") reduce 174) (("@") reduce 174) ((T_ABSTRACT) reduce 174) ((T_ARRAY) reduce 174) ((T_ARRAY_CAST) reduce 174) ((T_ATTRIBUTE) reduce 174) ((T_BOOL_CAST) reduce 174) ((T_BREAK) reduce 174) ((T_CATCH) shift) ((T_CLASS) reduce 174) ((T_CLASS_C) reduce 174) ((T_CLONE) reduce 174) ((T_CONSTANT_ENCAPSED_STRING) reduce 174) ((T_CONTINUE) reduce 174) ((T_DEC) reduce 174) ((T_DECLARE) reduce 174) ((T_DIR) reduce 174) ((T_DNUMBER) reduce 174) ((T_DO) reduce 174) ((T_DOUBLE_CAST) reduce 174) ((T_ECHO) reduce 174) ((T_EMPTY) reduce 174) ((T_ENDWHILE) reduce 174) ((T_ENUM) reduce 174) ((T_EVAL) reduce 174) ((T_EXIT) reduce 174) ((T_FILE) reduce 174) ((T_FINAL) reduce 174) ((T_FINALLY) shift) ((T_FN) reduce 174) ((T_FOR) reduce 174) ((T_FOREACH) reduce 174) ((T_FUNCTION) reduce 174) ((T_FUNC_C) reduce 174) ((T_GLOBAL) reduce 174) ((T_GOTO) reduce 174) ((T_HALT_COMPILER) reduce 174) ((T_IF) reduce 174) ((T_INC) reduce 174) ((T_INCLUDE) reduce 174) ((T_INCLUDE_ONCE) reduce 174) ((T_INLINE_HTML) reduce 174) ((T_INTERFACE) reduce 174) ((T_INT_CAST) reduce 174) ((T_ISSET) reduce 174) ((T_LINE) reduce 174) ((T_LIST) reduce 174) ((T_LNUMBER) reduce 174) ((T_MATCH) reduce 174) ((T_METHOD_C) reduce 174) ((T_NAME_FULLY_QUALIFIED) reduce 174) ((T_NAME_QUALIFIED) reduce 174) ((T_NAME_RELATIVE) reduce 174) ((T_NEW) reduce 174) ((T_NS_C) reduce 174) ((T_OBJECT_CAST) reduce 174) ((T_PRINT) reduce 174) ((T_READONLY) reduce 174) ((T_REQUIRE) reduce 174) ((T_REQUIRE_ONCE) reduce 174) ((T_RETURN) reduce 174) ((T_START_HEREDOC) reduce 174) ((T_STATIC) reduce 174) ((T_STRING) reduce 174) ((T_STRING_CAST) reduce 174) ((T_SWITCH) reduce 174) ((T_THROW) reduce 174) ((T_TRAIT) reduce 174) ((T_TRAIT_C) reduce 174) ((T_TRY) reduce 174) ((T_UNSET) reduce 174) ((T_UNSET_CAST) reduce 174) ((T_VARIABLE) reduce 174) ((T_WHILE) reduce 174) ((T_YIELD) reduce 174) ((T_YIELD_FROM) reduce 174) (("[") reduce 174) (("`") reduce 174) (("{") reduce 174) (("~") reduce 174)) 24165 ((("!") reduce 165) (("\"") reduce 165) (("$") reduce 165) (("(") reduce 165) (("+") reduce 165) (("-") reduce 165) ((";") reduce 165) (("@") reduce 165) ((T_ABSTRACT) reduce 165) ((T_ARRAY) reduce 165) ((T_ARRAY_CAST) reduce 165) ((T_ATTRIBUTE) reduce 165) ((T_BOOL_CAST) reduce 165) ((T_BREAK) reduce 165) ((T_CLASS) reduce 165) ((T_CLASS_C) reduce 165) ((T_CLONE) reduce 165) ((T_CONSTANT_ENCAPSED_STRING) reduce 165) ((T_CONTINUE) reduce 165) ((T_DEC) reduce 165) ((T_DECLARE) reduce 165) ((T_DIR) reduce 165) ((T_DNUMBER) reduce 165) ((T_DO) reduce 165) ((T_DOUBLE_CAST) reduce 165) ((T_ECHO) reduce 165) ((T_EMPTY) reduce 165) ((T_ENDWHILE) reduce 165) ((T_ENUM) reduce 165) ((T_EVAL) reduce 165) ((T_EXIT) reduce 165) ((T_FILE) reduce 165) ((T_FINAL) reduce 165) ((T_FN) reduce 165) ((T_FOR) reduce 165) ((T_FOREACH) reduce 165) ((T_FUNCTION) reduce 165) ((T_FUNC_C) reduce 165) ((T_GLOBAL) reduce 165) ((T_GOTO) reduce 165) ((T_HALT_COMPILER) reduce 165) ((T_IF) reduce 165) ((T_INC) reduce 165) ((T_INCLUDE) reduce 165) ((T_INCLUDE_ONCE) reduce 165) ((T_INLINE_HTML) reduce 165) ((T_INTERFACE) reduce 165) ((T_INT_CAST) reduce 165) ((T_ISSET) reduce 165) ((T_LINE) reduce 165) ((T_LIST) reduce 165) ((T_LNUMBER) reduce 165) ((T_MATCH) reduce 165) ((T_METHOD_C) reduce 165) ((T_NAME_FULLY_QUALIFIED) reduce 165) ((T_NAME_QUALIFIED) reduce 165) ((T_NAME_RELATIVE) reduce 165) ((T_NEW) reduce 165) ((T_NS_C) reduce 165) ((T_OBJECT_CAST) reduce 165) ((T_PRINT) reduce 165) ((T_READONLY) reduce 165) ((T_REQUIRE) reduce 165) ((T_REQUIRE_ONCE) reduce 165) ((T_RETURN) reduce 165) ((T_START_HEREDOC) reduce 165) ((T_STATIC) reduce 165) ((T_STRING) reduce 165) ((T_STRING_CAST) reduce 165) ((T_SWITCH) reduce 165) ((T_THROW) reduce 165) ((T_TRAIT) reduce 165) ((T_TRAIT_C) reduce 165) ((T_TRY) reduce 165) ((T_UNSET) reduce 165) ((T_UNSET_CAST) reduce 165) ((T_VARIABLE) reduce 165) ((T_WHILE) reduce 165) ((T_YIELD) reduce 165) ((T_YIELD_FROM) reduce 165) (("[") reduce 165) (("`") reduce 165) (("{") reduce 165) (("~") reduce 165)) 24168 ((("!") reduce 175) (("\"") reduce 175) (("$") reduce 175) (("(") reduce 175) (("+") reduce 175) (("-") reduce 175) ((";") reduce 175) (("@") reduce 175) ((T_ABSTRACT) reduce 175) ((T_ARRAY) reduce 175) ((T_ARRAY_CAST) reduce 175) ((T_ATTRIBUTE) reduce 175) ((T_BOOL_CAST) reduce 175) ((T_BREAK) reduce 175) ((T_CLASS) reduce 175) ((T_CLASS_C) reduce 175) ((T_CLONE) reduce 175) ((T_CONSTANT_ENCAPSED_STRING) reduce 175) ((T_CONTINUE) reduce 175) ((T_DEC) reduce 175) ((T_DECLARE) reduce 175) ((T_DIR) reduce 175) ((T_DNUMBER) reduce 175) ((T_DO) reduce 175) ((T_DOUBLE_CAST) reduce 175) ((T_ECHO) reduce 175) ((T_EMPTY) reduce 175) ((T_ENDWHILE) reduce 175) ((T_ENUM) reduce 175) ((T_EVAL) reduce 175) ((T_EXIT) reduce 175) ((T_FILE) reduce 175) ((T_FINAL) reduce 175) ((T_FN) reduce 175) ((T_FOR) reduce 175) ((T_FOREACH) reduce 175) ((T_FUNCTION) reduce 175) ((T_FUNC_C) reduce 175) ((T_GLOBAL) reduce 175) ((T_GOTO) reduce 175) ((T_HALT_COMPILER) reduce 175) ((T_IF) reduce 175) ((T_INC) reduce 175) ((T_INCLUDE) reduce 175) ((T_INCLUDE_ONCE) reduce 175) ((T_INLINE_HTML) reduce 175) ((T_INTERFACE) reduce 175) ((T_INT_CAST) reduce 175) ((T_ISSET) reduce 175) ((T_LINE) reduce 175) ((T_LIST) reduce 175) ((T_LNUMBER) reduce 175) ((T_MATCH) reduce 175) ((T_METHOD_C) reduce 175) ((T_NAME_FULLY_QUALIFIED) reduce 175) ((T_NAME_QUALIFIED) reduce 175) ((T_NAME_RELATIVE) reduce 175) ((T_NEW) reduce 175) ((T_NS_C) reduce 175) ((T_OBJECT_CAST) reduce 175) ((T_PRINT) reduce 175) ((T_READONLY) reduce 175) ((T_REQUIRE) reduce 175) ((T_REQUIRE_ONCE) reduce 175) ((T_RETURN) reduce 175) ((T_START_HEREDOC) reduce 175) ((T_STATIC) reduce 175) ((T_STRING) reduce 175) ((T_STRING_CAST) reduce 175) ((T_SWITCH) reduce 175) ((T_THROW) reduce 175) ((T_TRAIT) reduce 175) ((T_TRAIT_C) reduce 175) ((T_TRY) reduce 175) ((T_UNSET) reduce 175) ((T_UNSET_CAST) reduce 175) ((T_VARIABLE) reduce 175) ((T_WHILE) reduce 175) ((T_YIELD) reduce 175) ((T_YIELD_FROM) reduce 175) (("[") reduce 175) (("`") reduce 175) (("{") reduce 175) (("~") reduce 175)) 24175 ((("!") reduce 169) (("\"") reduce 169) (("$") reduce 169) (("(") reduce 169) (("+") reduce 169) (("-") reduce 169) ((";") reduce 169) (("@") reduce 169) ((T_ABSTRACT) reduce 169) ((T_ARRAY) reduce 169) ((T_ARRAY_CAST) reduce 169) ((T_ATTRIBUTE) reduce 169) ((T_BOOL_CAST) reduce 169) ((T_BREAK) reduce 169) ((T_CATCH) reduce 169) ((T_CLASS) reduce 169) ((T_CLASS_C) reduce 169) ((T_CLONE) reduce 169) ((T_CONSTANT_ENCAPSED_STRING) reduce 169) ((T_CONTINUE) reduce 169) ((T_DEC) reduce 169) ((T_DECLARE) reduce 169) ((T_DIR) reduce 169) ((T_DNUMBER) reduce 169) ((T_DO) reduce 169) ((T_DOUBLE_CAST) reduce 169) ((T_ECHO) reduce 169) ((T_EMPTY) reduce 169) ((T_ENDWHILE) reduce 169) ((T_ENUM) reduce 169) ((T_EVAL) reduce 169) ((T_EXIT) reduce 169) ((T_FILE) reduce 169) ((T_FINAL) reduce 169) ((T_FINALLY) reduce 169) ((T_FN) reduce 169) ((T_FOR) reduce 169) ((T_FOREACH) reduce 169) ((T_FUNCTION) reduce 169) ((T_FUNC_C) reduce 169) ((T_GLOBAL) reduce 169) ((T_GOTO) reduce 169) ((T_HALT_COMPILER) reduce 169) ((T_IF) reduce 169) ((T_INC) reduce 169) ((T_INCLUDE) reduce 169) ((T_INCLUDE_ONCE) reduce 169) ((T_INLINE_HTML) reduce 169) ((T_INTERFACE) reduce 169) ((T_INT_CAST) reduce 169) ((T_ISSET) reduce 169) ((T_LINE) reduce 169) ((T_LIST) reduce 169) ((T_LNUMBER) reduce 169) ((T_MATCH) reduce 169) ((T_METHOD_C) reduce 169) ((T_NAME_FULLY_QUALIFIED) reduce 169) ((T_NAME_QUALIFIED) reduce 169) ((T_NAME_RELATIVE) reduce 169) ((T_NEW) reduce 169) ((T_NS_C) reduce 169) ((T_OBJECT_CAST) reduce 169) ((T_PRINT) reduce 169) ((T_READONLY) reduce 169) ((T_REQUIRE) reduce 169) ((T_REQUIRE_ONCE) reduce 169) ((T_RETURN) reduce 169) ((T_START_HEREDOC) reduce 169) ((T_STATIC) reduce 169) ((T_STRING) reduce 169) ((T_STRING_CAST) reduce 169) ((T_SWITCH) reduce 169) ((T_THROW) reduce 169) ((T_TRAIT) reduce 169) ((T_TRAIT_C) reduce 169) ((T_TRY) reduce 169) ((T_UNSET) reduce 169) ((T_UNSET_CAST) reduce 169) ((T_VARIABLE) reduce 169) ((T_WHILE) reduce 169) ((T_YIELD) reduce 169) ((T_YIELD_FROM) reduce 169) (("[") reduce 169) (("`") reduce 169) (("{") reduce 169) (("~") reduce 169)) 24180 ((("!") reduce 197) (("\"") reduce 197) (("$") reduce 197) (("(") reduce 197) (("+") reduce 197) (("-") reduce 197) ((";") reduce 197) (("@") reduce 197) ((T_ABSTRACT) reduce 197) ((T_ARRAY) reduce 197) ((T_ARRAY_CAST) reduce 197) ((T_ATTRIBUTE) reduce 197) ((T_BOOL_CAST) reduce 197) ((T_BREAK) reduce 197) ((T_CLASS) reduce 197) ((T_CLASS_C) reduce 197) ((T_CLONE) reduce 197) ((T_CONSTANT_ENCAPSED_STRING) reduce 197) ((T_CONTINUE) reduce 197) ((T_DEC) reduce 197) ((T_DECLARE) reduce 197) ((T_DIR) reduce 197) ((T_DNUMBER) reduce 197) ((T_DO) reduce 197) ((T_DOUBLE_CAST) reduce 197) ((T_ECHO) reduce 197) ((T_EMPTY) reduce 197) ((T_ENDWHILE) reduce 197) ((T_ENUM) reduce 197) ((T_EVAL) reduce 197) ((T_EXIT) reduce 197) ((T_FILE) reduce 197) ((T_FINAL) reduce 197) ((T_FN) reduce 197) ((T_FOR) reduce 197) ((T_FOREACH) reduce 197) ((T_FUNCTION) reduce 197) ((T_FUNC_C) reduce 197) ((T_GLOBAL) reduce 197) ((T_GOTO) reduce 197) ((T_HALT_COMPILER) reduce 197) ((T_IF) reduce 197) ((T_INC) reduce 197) ((T_INCLUDE) reduce 197) ((T_INCLUDE_ONCE) reduce 197) ((T_INLINE_HTML) reduce 197) ((T_INTERFACE) reduce 197) ((T_INT_CAST) reduce 197) ((T_ISSET) reduce 197) ((T_LINE) reduce 197) ((T_LIST) reduce 197) ((T_LNUMBER) reduce 197) ((T_MATCH) reduce 197) ((T_METHOD_C) reduce 197) ((T_NAME_FULLY_QUALIFIED) reduce 197) ((T_NAME_QUALIFIED) reduce 197) ((T_NAME_RELATIVE) reduce 197) ((T_NEW) reduce 197) ((T_NS_C) reduce 197) ((T_OBJECT_CAST) reduce 197) ((T_PRINT) reduce 197) ((T_READONLY) reduce 197) ((T_REQUIRE) reduce 197) ((T_REQUIRE_ONCE) reduce 197) ((T_RETURN) reduce 197) ((T_START_HEREDOC) reduce 197) ((T_STATIC) reduce 197) ((T_STRING) reduce 197) ((T_STRING_CAST) reduce 197) ((T_SWITCH) reduce 197) ((T_THROW) reduce 197) ((T_TRAIT) reduce 197) ((T_TRAIT_C) reduce 197) ((T_TRY) reduce 197) ((T_UNSET) reduce 197) ((T_UNSET_CAST) reduce 197) ((T_VARIABLE) reduce 197) ((T_WHILE) reduce 197) ((T_YIELD) reduce 197) ((T_YIELD_FROM) reduce 197) (("[") reduce 197) (("`") reduce 197) (("{") reduce 197) (("~") reduce 197)) 24185 ((("!") reduce 151) (("\"") reduce 151) (("$") reduce 151) (("(") reduce 151) (("+") reduce 151) (("-") reduce 151) ((";") reduce 151) (("@") reduce 151) ((T_ABSTRACT) reduce 151) ((T_ARRAY) reduce 151) ((T_ARRAY_CAST) reduce 151) ((T_ATTRIBUTE) reduce 151) ((T_BOOL_CAST) reduce 151) ((T_BREAK) reduce 151) ((T_CLASS) reduce 151) ((T_CLASS_C) reduce 151) ((T_CLONE) reduce 151) ((T_CONSTANT_ENCAPSED_STRING) reduce 151) ((T_CONTINUE) reduce 151) ((T_DEC) reduce 151) ((T_DECLARE) reduce 151) ((T_DIR) reduce 151) ((T_DNUMBER) reduce 151) ((T_DO) reduce 151) ((T_DOUBLE_CAST) reduce 151) ((T_ECHO) reduce 151) ((T_EMPTY) reduce 151) ((T_ENDWHILE) reduce 151) ((T_ENUM) reduce 151) ((T_EVAL) reduce 151) ((T_EXIT) reduce 151) ((T_FILE) reduce 151) ((T_FINAL) reduce 151) ((T_FN) reduce 151) ((T_FOR) reduce 151) ((T_FOREACH) reduce 151) ((T_FUNCTION) reduce 151) ((T_FUNC_C) reduce 151) ((T_GLOBAL) reduce 151) ((T_GOTO) reduce 151) ((T_HALT_COMPILER) reduce 151) ((T_IF) reduce 151) ((T_INC) reduce 151) ((T_INCLUDE) reduce 151) ((T_INCLUDE_ONCE) reduce 151) ((T_INLINE_HTML) reduce 151) ((T_INTERFACE) reduce 151) ((T_INT_CAST) reduce 151) ((T_ISSET) reduce 151) ((T_LINE) reduce 151) ((T_LIST) reduce 151) ((T_LNUMBER) reduce 151) ((T_MATCH) reduce 151) ((T_METHOD_C) reduce 151) ((T_NAME_FULLY_QUALIFIED) reduce 151) ((T_NAME_QUALIFIED) reduce 151) ((T_NAME_RELATIVE) reduce 151) ((T_NEW) reduce 151) ((T_NS_C) reduce 151) ((T_OBJECT_CAST) reduce 151) ((T_PRINT) reduce 151) ((T_READONLY) reduce 151) ((T_REQUIRE) reduce 151) ((T_REQUIRE_ONCE) reduce 151) ((T_RETURN) reduce 151) ((T_START_HEREDOC) reduce 151) ((T_STATIC) reduce 151) ((T_STRING) reduce 151) ((T_STRING_CAST) reduce 151) ((T_SWITCH) reduce 151) ((T_THROW) reduce 151) ((T_TRAIT) reduce 151) ((T_TRAIT_C) reduce 151) ((T_TRY) reduce 151) ((T_UNSET) reduce 151) ((T_UNSET_CAST) reduce 151) ((T_VARIABLE) reduce 151) ((T_WHILE) reduce 151) ((T_YIELD) reduce 151) ((T_YIELD_FROM) reduce 151) (("[") reduce 151) (("`") reduce 151) (("{") reduce 151) (("~") reduce 151)) 24189 ((("!") reduce 221) (("\"") reduce 221) (("$") reduce 221) (("(") reduce 221) (("+") reduce 221) (("-") reduce 221) ((";") reduce 221) (("@") reduce 221) ((T_ABSTRACT) reduce 221) ((T_ARRAY) reduce 221) ((T_ARRAY_CAST) reduce 221) ((T_ATTRIBUTE) reduce 221) ((T_BOOL_CAST) reduce 221) ((T_BREAK) reduce 221) ((T_CLASS) reduce 221) ((T_CLASS_C) reduce 221) ((T_CLONE) reduce 221) ((T_CONSTANT_ENCAPSED_STRING) reduce 221) ((T_CONTINUE) reduce 221) ((T_DEC) reduce 221) ((T_DECLARE) reduce 221) ((T_DIR) reduce 221) ((T_DNUMBER) reduce 221) ((T_DO) reduce 221) ((T_DOUBLE_CAST) reduce 221) ((T_ECHO) reduce 221) ((T_EMPTY) reduce 221) ((T_ENDWHILE) reduce 221) ((T_ENUM) reduce 221) ((T_EVAL) reduce 221) ((T_EXIT) reduce 221) ((T_FILE) reduce 221) ((T_FINAL) reduce 221) ((T_FN) reduce 221) ((T_FOR) reduce 221) ((T_FOREACH) reduce 221) ((T_FUNCTION) reduce 221) ((T_FUNC_C) reduce 221) ((T_GLOBAL) reduce 221) ((T_GOTO) reduce 221) ((T_HALT_COMPILER) reduce 221) ((T_IF) reduce 221) ((T_INC) reduce 221) ((T_INCLUDE) reduce 221) ((T_INCLUDE_ONCE) reduce 221) ((T_INLINE_HTML) reduce 221) ((T_INTERFACE) reduce 221) ((T_INT_CAST) reduce 221) ((T_ISSET) reduce 221) ((T_LINE) reduce 221) ((T_LIST) reduce 221) ((T_LNUMBER) reduce 221) ((T_MATCH) reduce 221) ((T_METHOD_C) reduce 221) ((T_NAME_FULLY_QUALIFIED) reduce 221) ((T_NAME_QUALIFIED) reduce 221) ((T_NAME_RELATIVE) reduce 221) ((T_NEW) reduce 221) ((T_NS_C) reduce 221) ((T_OBJECT_CAST) reduce 221) ((T_PRINT) reduce 221) ((T_READONLY) reduce 221) ((T_REQUIRE) reduce 221) ((T_REQUIRE_ONCE) reduce 221) ((T_RETURN) reduce 221) ((T_START_HEREDOC) reduce 221) ((T_STATIC) reduce 221) ((T_STRING) reduce 221) ((T_STRING_CAST) reduce 221) ((T_SWITCH) reduce 221) ((T_THROW) reduce 221) ((T_TRAIT) reduce 221) ((T_TRAIT_C) reduce 221) ((T_TRY) reduce 221) ((T_UNSET) reduce 221) ((T_UNSET_CAST) reduce 221) ((T_VARIABLE) reduce 221) ((T_WHILE) reduce 221) ((T_YIELD) reduce 221) ((T_YIELD_FROM) reduce 221) (("[") reduce 221) (("`") reduce 221) (("{") reduce 221) (("~") reduce 221)) 24191 ((("!") reduce 222) (("\"") reduce 222) (("$") reduce 222) (("(") reduce 222) (("+") reduce 222) (("-") reduce 222) ((";") reduce 222) (("@") reduce 222) ((T_ABSTRACT) reduce 222) ((T_ARRAY) reduce 222) ((T_ARRAY_CAST) reduce 222) ((T_ATTRIBUTE) reduce 222) ((T_BOOL_CAST) reduce 222) ((T_BREAK) reduce 222) ((T_CLASS) reduce 222) ((T_CLASS_C) reduce 222) ((T_CLONE) reduce 222) ((T_CONSTANT_ENCAPSED_STRING) reduce 222) ((T_CONTINUE) reduce 222) ((T_DEC) reduce 222) ((T_DECLARE) reduce 222) ((T_DIR) reduce 222) ((T_DNUMBER) reduce 222) ((T_DO) reduce 222) ((T_DOUBLE_CAST) reduce 222) ((T_ECHO) reduce 222) ((T_EMPTY) reduce 222) ((T_ENDWHILE) reduce 222) ((T_ENUM) reduce 222) ((T_EVAL) reduce 222) ((T_EXIT) reduce 222) ((T_FILE) reduce 222) ((T_FINAL) reduce 222) ((T_FN) reduce 222) ((T_FOR) reduce 222) ((T_FOREACH) reduce 222) ((T_FUNCTION) reduce 222) ((T_FUNC_C) reduce 222) ((T_GLOBAL) reduce 222) ((T_GOTO) reduce 222) ((T_HALT_COMPILER) reduce 222) ((T_IF) reduce 222) ((T_INC) reduce 222) ((T_INCLUDE) reduce 222) ((T_INCLUDE_ONCE) reduce 222) ((T_INLINE_HTML) reduce 222) ((T_INTERFACE) reduce 222) ((T_INT_CAST) reduce 222) ((T_ISSET) reduce 222) ((T_LINE) reduce 222) ((T_LIST) reduce 222) ((T_LNUMBER) reduce 222) ((T_MATCH) reduce 222) ((T_METHOD_C) reduce 222) ((T_NAME_FULLY_QUALIFIED) reduce 222) ((T_NAME_QUALIFIED) reduce 222) ((T_NAME_RELATIVE) reduce 222) ((T_NEW) reduce 222) ((T_NS_C) reduce 222) ((T_OBJECT_CAST) reduce 222) ((T_PRINT) reduce 222) ((T_READONLY) reduce 222) ((T_REQUIRE) reduce 222) ((T_REQUIRE_ONCE) reduce 222) ((T_RETURN) reduce 222) ((T_START_HEREDOC) reduce 222) ((T_STATIC) reduce 222) ((T_STRING) reduce 222) ((T_STRING_CAST) reduce 222) ((T_SWITCH) reduce 222) ((T_THROW) reduce 222) ((T_TRAIT) reduce 222) ((T_TRAIT_C) reduce 222) ((T_TRY) reduce 222) ((T_UNSET) reduce 222) ((T_UNSET_CAST) reduce 222) ((T_VARIABLE) reduce 222) ((T_WHILE) reduce 222) ((T_YIELD) reduce 222) ((T_YIELD_FROM) reduce 222) (("[") reduce 222) (("`") reduce 222) (("{") reduce 222) (("~") reduce 222)) 24195 ((("!") reduce 223) (("\"") reduce 223) (("$") reduce 223) (("(") reduce 223) (("+") reduce 223) (("-") reduce 223) ((";") reduce 223) (("@") reduce 223) ((T_ABSTRACT) reduce 223) ((T_ARRAY) reduce 223) ((T_ARRAY_CAST) reduce 223) ((T_ATTRIBUTE) reduce 223) ((T_BOOL_CAST) reduce 223) ((T_BREAK) reduce 223) ((T_CLASS) reduce 223) ((T_CLASS_C) reduce 223) ((T_CLONE) reduce 223) ((T_CONSTANT_ENCAPSED_STRING) reduce 223) ((T_CONTINUE) reduce 223) ((T_DEC) reduce 223) ((T_DECLARE) reduce 223) ((T_DIR) reduce 223) ((T_DNUMBER) reduce 223) ((T_DO) reduce 223) ((T_DOUBLE_CAST) reduce 223) ((T_ECHO) reduce 223) ((T_EMPTY) reduce 223) ((T_ENDWHILE) reduce 223) ((T_ENUM) reduce 223) ((T_EVAL) reduce 223) ((T_EXIT) reduce 223) ((T_FILE) reduce 223) ((T_FINAL) reduce 223) ((T_FN) reduce 223) ((T_FOR) reduce 223) ((T_FOREACH) reduce 223) ((T_FUNCTION) reduce 223) ((T_FUNC_C) reduce 223) ((T_GLOBAL) reduce 223) ((T_GOTO) reduce 223) ((T_HALT_COMPILER) reduce 223) ((T_IF) reduce 223) ((T_INC) reduce 223) ((T_INCLUDE) reduce 223) ((T_INCLUDE_ONCE) reduce 223) ((T_INLINE_HTML) reduce 223) ((T_INTERFACE) reduce 223) ((T_INT_CAST) reduce 223) ((T_ISSET) reduce 223) ((T_LINE) reduce 223) ((T_LIST) reduce 223) ((T_LNUMBER) reduce 223) ((T_MATCH) reduce 223) ((T_METHOD_C) reduce 223) ((T_NAME_FULLY_QUALIFIED) reduce 223) ((T_NAME_QUALIFIED) reduce 223) ((T_NAME_RELATIVE) reduce 223) ((T_NEW) reduce 223) ((T_NS_C) reduce 223) ((T_OBJECT_CAST) reduce 223) ((T_PRINT) reduce 223) ((T_READONLY) reduce 223) ((T_REQUIRE) reduce 223) ((T_REQUIRE_ONCE) reduce 223) ((T_RETURN) reduce 223) ((T_START_HEREDOC) reduce 223) ((T_STATIC) reduce 223) ((T_STRING) reduce 223) ((T_STRING_CAST) reduce 223) ((T_SWITCH) reduce 223) ((T_THROW) reduce 223) ((T_TRAIT) reduce 223) ((T_TRAIT_C) reduce 223) ((T_TRY) reduce 223) ((T_UNSET) reduce 223) ((T_UNSET_CAST) reduce 223) ((T_VARIABLE) reduce 223) ((T_WHILE) reduce 223) ((T_YIELD) reduce 223) ((T_YIELD_FROM) reduce 223) (("[") reduce 223) (("`") reduce 223) (("{") reduce 223) (("~") reduce 223)) 24198 ((("!") reduce 224) (("\"") reduce 224) (("$") reduce 224) (("(") reduce 224) (("+") reduce 224) (("-") reduce 224) ((";") reduce 224) (("@") reduce 224) ((T_ABSTRACT) reduce 224) ((T_ARRAY) reduce 224) ((T_ARRAY_CAST) reduce 224) ((T_ATTRIBUTE) reduce 224) ((T_BOOL_CAST) reduce 224) ((T_BREAK) reduce 224) ((T_CLASS) reduce 224) ((T_CLASS_C) reduce 224) ((T_CLONE) reduce 224) ((T_CONSTANT_ENCAPSED_STRING) reduce 224) ((T_CONTINUE) reduce 224) ((T_DEC) reduce 224) ((T_DECLARE) reduce 224) ((T_DIR) reduce 224) ((T_DNUMBER) reduce 224) ((T_DO) reduce 224) ((T_DOUBLE_CAST) reduce 224) ((T_ECHO) reduce 224) ((T_EMPTY) reduce 224) ((T_ENDWHILE) reduce 224) ((T_ENUM) reduce 224) ((T_EVAL) reduce 224) ((T_EXIT) reduce 224) ((T_FILE) reduce 224) ((T_FINAL) reduce 224) ((T_FN) reduce 224) ((T_FOR) reduce 224) ((T_FOREACH) reduce 224) ((T_FUNCTION) reduce 224) ((T_FUNC_C) reduce 224) ((T_GLOBAL) reduce 224) ((T_GOTO) reduce 224) ((T_HALT_COMPILER) reduce 224) ((T_IF) reduce 224) ((T_INC) reduce 224) ((T_INCLUDE) reduce 224) ((T_INCLUDE_ONCE) reduce 224) ((T_INLINE_HTML) reduce 224) ((T_INTERFACE) reduce 224) ((T_INT_CAST) reduce 224) ((T_ISSET) reduce 224) ((T_LINE) reduce 224) ((T_LIST) reduce 224) ((T_LNUMBER) reduce 224) ((T_MATCH) reduce 224) ((T_METHOD_C) reduce 224) ((T_NAME_FULLY_QUALIFIED) reduce 224) ((T_NAME_QUALIFIED) reduce 224) ((T_NAME_RELATIVE) reduce 224) ((T_NEW) reduce 224) ((T_NS_C) reduce 224) ((T_OBJECT_CAST) reduce 224) ((T_PRINT) reduce 224) ((T_READONLY) reduce 224) ((T_REQUIRE) reduce 224) ((T_REQUIRE_ONCE) reduce 224) ((T_RETURN) reduce 224) ((T_START_HEREDOC) reduce 224) ((T_STATIC) reduce 224) ((T_STRING) reduce 224) ((T_STRING_CAST) reduce 224) ((T_SWITCH) reduce 224) ((T_THROW) reduce 224) ((T_TRAIT) reduce 224) ((T_TRAIT_C) reduce 224) ((T_TRY) reduce 224) ((T_UNSET) reduce 224) ((T_UNSET_CAST) reduce 224) ((T_VARIABLE) reduce 224) ((T_WHILE) reduce 224) ((T_YIELD) reduce 224) ((T_YIELD_FROM) reduce 224) (("[") reduce 224) (("`") reduce 224) (("{") reduce 224) (("~") reduce 224)) 24199 ((("!") reduce 167) (("\"") reduce 167) (("$") reduce 167) (("(") reduce 167) (("+") reduce 167) (("-") reduce 167) ((";") reduce 167) (("@") reduce 167) ((T_ABSTRACT) reduce 167) ((T_ARRAY) reduce 167) ((T_ARRAY_CAST) reduce 167) ((T_ATTRIBUTE) reduce 167) ((T_BOOL_CAST) reduce 167) ((T_BREAK) reduce 167) ((T_CLASS) reduce 167) ((T_CLASS_C) reduce 167) ((T_CLONE) reduce 167) ((T_CONSTANT_ENCAPSED_STRING) reduce 167) ((T_CONTINUE) reduce 167) ((T_DEC) reduce 167) ((T_DECLARE) reduce 167) ((T_DIR) reduce 167) ((T_DNUMBER) reduce 167) ((T_DO) reduce 167) ((T_DOUBLE_CAST) reduce 167) ((T_ECHO) reduce 167) ((T_EMPTY) reduce 167) ((T_ENDWHILE) reduce 167) ((T_ENUM) reduce 167) ((T_EVAL) reduce 167) ((T_EXIT) reduce 167) ((T_FILE) reduce 167) ((T_FINAL) reduce 167) ((T_FN) reduce 167) ((T_FOR) reduce 167) ((T_FOREACH) reduce 167) ((T_FUNCTION) reduce 167) ((T_FUNC_C) reduce 167) ((T_GLOBAL) reduce 167) ((T_GOTO) reduce 167) ((T_HALT_COMPILER) reduce 167) ((T_IF) reduce 167) ((T_INC) reduce 167) ((T_INCLUDE) reduce 167) ((T_INCLUDE_ONCE) reduce 167) ((T_INLINE_HTML) reduce 167) ((T_INTERFACE) reduce 167) ((T_INT_CAST) reduce 167) ((T_ISSET) reduce 167) ((T_LINE) reduce 167) ((T_LIST) reduce 167) ((T_LNUMBER) reduce 167) ((T_MATCH) reduce 167) ((T_METHOD_C) reduce 167) ((T_NAME_FULLY_QUALIFIED) reduce 167) ((T_NAME_QUALIFIED) reduce 167) ((T_NAME_RELATIVE) reduce 167) ((T_NEW) reduce 167) ((T_NS_C) reduce 167) ((T_OBJECT_CAST) reduce 167) ((T_PRINT) reduce 167) ((T_READONLY) reduce 167) ((T_REQUIRE) reduce 167) ((T_REQUIRE_ONCE) reduce 167) ((T_RETURN) reduce 167) ((T_START_HEREDOC) reduce 167) ((T_STATIC) reduce 167) ((T_STRING) reduce 167) ((T_STRING_CAST) reduce 167) ((T_SWITCH) reduce 167) ((T_THROW) reduce 167) ((T_TRAIT) reduce 167) ((T_TRAIT_C) reduce 167) ((T_TRY) reduce 167) ((T_UNSET) reduce 167) ((T_UNSET_CAST) reduce 167) ((T_VARIABLE) reduce 167) ((T_WHILE) reduce 167) ((T_YIELD) reduce 167) ((T_YIELD_FROM) reduce 167) (("[") reduce 167) (("`") reduce 167) (("{") reduce 167) (("~") reduce 167)) 24201 ((("!") reduce 156) (("\"") reduce 156) (("$") reduce 156) (("(") reduce 156) (("+") reduce 156) (("-") reduce 156) ((";") reduce 156) (("@") reduce 156) ((T_ABSTRACT) reduce 156) ((T_ARRAY) reduce 156) ((T_ARRAY_CAST) reduce 156) ((T_ATTRIBUTE) reduce 156) ((T_BOOL_CAST) reduce 156) ((T_BREAK) reduce 156) ((T_CLASS) reduce 156) ((T_CLASS_C) reduce 156) ((T_CLONE) reduce 156) ((T_CONSTANT_ENCAPSED_STRING) reduce 156) ((T_CONTINUE) reduce 156) ((T_DEC) reduce 156) ((T_DECLARE) reduce 156) ((T_DIR) reduce 156) ((T_DNUMBER) reduce 156) ((T_DO) reduce 156) ((T_DOUBLE_CAST) reduce 156) ((T_ECHO) reduce 156) ((T_EMPTY) reduce 156) ((T_ENDWHILE) reduce 156) ((T_ENUM) reduce 156) ((T_EVAL) reduce 156) ((T_EXIT) reduce 156) ((T_FILE) reduce 156) ((T_FINAL) reduce 156) ((T_FN) reduce 156) ((T_FOR) reduce 156) ((T_FOREACH) reduce 156) ((T_FUNCTION) reduce 156) ((T_FUNC_C) reduce 156) ((T_GLOBAL) reduce 156) ((T_GOTO) reduce 156) ((T_HALT_COMPILER) reduce 156) ((T_IF) reduce 156) ((T_INC) reduce 156) ((T_INCLUDE) reduce 156) ((T_INCLUDE_ONCE) reduce 156) ((T_INLINE_HTML) reduce 156) ((T_INTERFACE) reduce 156) ((T_INT_CAST) reduce 156) ((T_ISSET) reduce 156) ((T_LINE) reduce 156) ((T_LIST) reduce 156) ((T_LNUMBER) reduce 156) ((T_MATCH) reduce 156) ((T_METHOD_C) reduce 156) ((T_NAME_FULLY_QUALIFIED) reduce 156) ((T_NAME_QUALIFIED) reduce 156) ((T_NAME_RELATIVE) reduce 156) ((T_NEW) reduce 156) ((T_NS_C) reduce 156) ((T_OBJECT_CAST) reduce 156) ((T_PRINT) reduce 156) ((T_READONLY) reduce 156) ((T_REQUIRE) reduce 156) ((T_REQUIRE_ONCE) reduce 156) ((T_RETURN) reduce 156) ((T_START_HEREDOC) reduce 156) ((T_STATIC) reduce 156) ((T_STRING) reduce 156) ((T_STRING_CAST) reduce 156) ((T_SWITCH) reduce 156) ((T_THROW) reduce 156) ((T_TRAIT) reduce 156) ((T_TRAIT_C) reduce 156) ((T_TRY) reduce 156) ((T_UNSET) reduce 156) ((T_UNSET_CAST) reduce 156) ((T_VARIABLE) reduce 156) ((T_WHILE) reduce 156) ((T_YIELD) reduce 156) ((T_YIELD_FROM) reduce 156) (("[") reduce 156) (("`") reduce 156) (("{") reduce 156) (("~") reduce 156)) 24203 ((("!") reduce 154) (("\"") reduce 154) (("$") reduce 154) (("(") reduce 154) (("+") reduce 154) (("-") reduce 154) ((";") reduce 154) (("@") reduce 154) ((T_ABSTRACT) reduce 154) ((T_ARRAY) reduce 154) ((T_ARRAY_CAST) reduce 154) ((T_ATTRIBUTE) reduce 154) ((T_BOOL_CAST) reduce 154) ((T_BREAK) reduce 154) ((T_CLASS) reduce 154) ((T_CLASS_C) reduce 154) ((T_CLONE) reduce 154) ((T_CONSTANT_ENCAPSED_STRING) reduce 154) ((T_CONTINUE) reduce 154) ((T_DEC) reduce 154) ((T_DECLARE) reduce 154) ((T_DIR) reduce 154) ((T_DNUMBER) reduce 154) ((T_DO) reduce 154) ((T_DOUBLE_CAST) reduce 154) ((T_ECHO) reduce 154) ((T_EMPTY) reduce 154) ((T_ENDWHILE) reduce 154) ((T_ENUM) reduce 154) ((T_EVAL) reduce 154) ((T_EXIT) reduce 154) ((T_FILE) reduce 154) ((T_FINAL) reduce 154) ((T_FN) reduce 154) ((T_FOR) reduce 154) ((T_FOREACH) reduce 154) ((T_FUNCTION) reduce 154) ((T_FUNC_C) reduce 154) ((T_GLOBAL) reduce 154) ((T_GOTO) reduce 154) ((T_HALT_COMPILER) reduce 154) ((T_IF) reduce 154) ((T_INC) reduce 154) ((T_INCLUDE) reduce 154) ((T_INCLUDE_ONCE) reduce 154) ((T_INLINE_HTML) reduce 154) ((T_INTERFACE) reduce 154) ((T_INT_CAST) reduce 154) ((T_ISSET) reduce 154) ((T_LINE) reduce 154) ((T_LIST) reduce 154) ((T_LNUMBER) reduce 154) ((T_MATCH) reduce 154) ((T_METHOD_C) reduce 154) ((T_NAME_FULLY_QUALIFIED) reduce 154) ((T_NAME_QUALIFIED) reduce 154) ((T_NAME_RELATIVE) reduce 154) ((T_NEW) reduce 154) ((T_NS_C) reduce 154) ((T_OBJECT_CAST) reduce 154) ((T_PRINT) reduce 154) ((T_READONLY) reduce 154) ((T_REQUIRE) reduce 154) ((T_REQUIRE_ONCE) reduce 154) ((T_RETURN) reduce 154) ((T_START_HEREDOC) reduce 154) ((T_STATIC) reduce 154) ((T_STRING) reduce 154) ((T_STRING_CAST) reduce 154) ((T_SWITCH) reduce 154) ((T_THROW) reduce 154) ((T_TRAIT) reduce 154) ((T_TRAIT_C) reduce 154) ((T_TRY) reduce 154) ((T_UNSET) reduce 154) ((T_UNSET_CAST) reduce 154) ((T_VARIABLE) reduce 154) ((T_WHILE) reduce 154) ((T_YIELD) reduce 154) ((T_YIELD_FROM) reduce 154) (("[") reduce 154) (("`") reduce 154) (("{") reduce 154) (("~") reduce 154)) 24209 ((("!") reduce 198) (("\"") reduce 198) (("$") reduce 198) (("(") reduce 198) (("+") reduce 198) (("-") reduce 198) ((";") reduce 198) (("@") reduce 198) ((T_ABSTRACT) reduce 198) ((T_ARRAY) reduce 198) ((T_ARRAY_CAST) reduce 198) ((T_ATTRIBUTE) reduce 198) ((T_BOOL_CAST) reduce 198) ((T_BREAK) reduce 198) ((T_CLASS) reduce 198) ((T_CLASS_C) reduce 198) ((T_CLONE) reduce 198) ((T_CONSTANT_ENCAPSED_STRING) reduce 198) ((T_CONTINUE) reduce 198) ((T_DEC) reduce 198) ((T_DECLARE) reduce 198) ((T_DIR) reduce 198) ((T_DNUMBER) reduce 198) ((T_DO) reduce 198) ((T_DOUBLE_CAST) reduce 198) ((T_ECHO) reduce 198) ((T_EMPTY) reduce 198) ((T_ENDWHILE) reduce 198) ((T_ENUM) reduce 198) ((T_EVAL) reduce 198) ((T_EXIT) reduce 198) ((T_FILE) reduce 198) ((T_FINAL) reduce 198) ((T_FN) reduce 198) ((T_FOR) reduce 198) ((T_FOREACH) reduce 198) ((T_FUNCTION) reduce 198) ((T_FUNC_C) reduce 198) ((T_GLOBAL) reduce 198) ((T_GOTO) reduce 198) ((T_HALT_COMPILER) reduce 198) ((T_IF) reduce 198) ((T_INC) reduce 198) ((T_INCLUDE) reduce 198) ((T_INCLUDE_ONCE) reduce 198) ((T_INLINE_HTML) reduce 198) ((T_INTERFACE) reduce 198) ((T_INT_CAST) reduce 198) ((T_ISSET) reduce 198) ((T_LINE) reduce 198) ((T_LIST) reduce 198) ((T_LNUMBER) reduce 198) ((T_MATCH) reduce 198) ((T_METHOD_C) reduce 198) ((T_NAME_FULLY_QUALIFIED) reduce 198) ((T_NAME_QUALIFIED) reduce 198) ((T_NAME_RELATIVE) reduce 198) ((T_NEW) reduce 198) ((T_NS_C) reduce 198) ((T_OBJECT_CAST) reduce 198) ((T_PRINT) reduce 198) ((T_READONLY) reduce 198) ((T_REQUIRE) reduce 198) ((T_REQUIRE_ONCE) reduce 198) ((T_RETURN) reduce 198) ((T_START_HEREDOC) reduce 198) ((T_STATIC) reduce 198) ((T_STRING) reduce 198) ((T_STRING_CAST) reduce 198) ((T_SWITCH) reduce 198) ((T_THROW) reduce 198) ((T_TRAIT) reduce 198) ((T_TRAIT_C) reduce 198) ((T_TRY) reduce 198) ((T_UNSET) reduce 198) ((T_UNSET_CAST) reduce 198) ((T_VARIABLE) reduce 198) ((T_WHILE) reduce 198) ((T_YIELD) reduce 198) ((T_YIELD_FROM) reduce 198) (("[") reduce 198) (("`") reduce 198) (("{") reduce 198) (("~") reduce 198)) 24213 ((("!") reduce 241) (("\"") reduce 241) (("$") reduce 241) (("(") reduce 241) (("+") reduce 241) (("-") reduce 241) ((";") reduce 241) (("@") reduce 241) ((T_ABSTRACT) reduce 241) ((T_ARRAY) reduce 241) ((T_ARRAY_CAST) reduce 241) ((T_ATTRIBUTE) reduce 241) ((T_BOOL_CAST) reduce 241) ((T_BREAK) reduce 241) ((T_CLASS) reduce 241) ((T_CLASS_C) reduce 241) ((T_CLONE) reduce 241) ((T_CONSTANT_ENCAPSED_STRING) reduce 241) ((T_CONTINUE) reduce 241) ((T_DEC) reduce 241) ((T_DECLARE) reduce 241) ((T_DIR) reduce 241) ((T_DNUMBER) reduce 241) ((T_DO) reduce 241) ((T_DOUBLE_CAST) reduce 241) ((T_ECHO) reduce 241) ((T_ELSE) reduce 241) ((T_ELSEIF) reduce 241) ((T_EMPTY) reduce 241) ((T_ENDWHILE) reduce 241) ((T_ENUM) reduce 241) ((T_EVAL) reduce 241) ((T_EXIT) reduce 241) ((T_FILE) reduce 241) ((T_FINAL) reduce 241) ((T_FN) reduce 241) ((T_FOR) reduce 241) ((T_FOREACH) reduce 241) ((T_FUNCTION) reduce 241) ((T_FUNC_C) reduce 241) ((T_GLOBAL) reduce 241) ((T_GOTO) reduce 241) ((T_HALT_COMPILER) reduce 241) ((T_IF) reduce 241) ((T_INC) reduce 241) ((T_INCLUDE) reduce 241) ((T_INCLUDE_ONCE) reduce 241) ((T_INLINE_HTML) reduce 241) ((T_INTERFACE) reduce 241) ((T_INT_CAST) reduce 241) ((T_ISSET) reduce 241) ((T_LINE) reduce 241) ((T_LIST) reduce 241) ((T_LNUMBER) reduce 241) ((T_MATCH) reduce 241) ((T_METHOD_C) reduce 241) ((T_NAME_FULLY_QUALIFIED) reduce 241) ((T_NAME_QUALIFIED) reduce 241) ((T_NAME_RELATIVE) reduce 241) ((T_NEW) reduce 241) ((T_NS_C) reduce 241) ((T_OBJECT_CAST) reduce 241) ((T_PRINT) reduce 241) ((T_READONLY) reduce 241) ((T_REQUIRE) reduce 241) ((T_REQUIRE_ONCE) reduce 241) ((T_RETURN) reduce 241) ((T_START_HEREDOC) reduce 241) ((T_STATIC) reduce 241) ((T_STRING) reduce 241) ((T_STRING_CAST) reduce 241) ((T_SWITCH) reduce 241) ((T_THROW) reduce 241) ((T_TRAIT) reduce 241) ((T_TRAIT_C) reduce 241) ((T_TRY) reduce 241) ((T_UNSET) reduce 241) ((T_UNSET_CAST) reduce 241) ((T_VARIABLE) reduce 241) ((T_WHILE) reduce 241) ((T_YIELD) reduce 241) ((T_YIELD_FROM) reduce 241) (("[") reduce 241) (("`") reduce 241) (("{") reduce 241) (("~") reduce 241)) 24216 ((("!") reduce 144) (("\"") reduce 144) (("$") reduce 144) (("(") reduce 144) (("+") reduce 144) (("-") reduce 144) ((";") reduce 144) (("@") reduce 144) ((T_ABSTRACT) reduce 144) ((T_ARRAY) reduce 144) ((T_ARRAY_CAST) reduce 144) ((T_ATTRIBUTE) reduce 144) ((T_BOOL_CAST) reduce 144) ((T_BREAK) reduce 144) ((T_CLASS) reduce 144) ((T_CLASS_C) reduce 144) ((T_CLONE) reduce 144) ((T_CONSTANT_ENCAPSED_STRING) reduce 144) ((T_CONTINUE) reduce 144) ((T_DEC) reduce 144) ((T_DECLARE) reduce 144) ((T_DIR) reduce 144) ((T_DNUMBER) reduce 144) ((T_DO) reduce 144) ((T_DOUBLE_CAST) reduce 144) ((T_ECHO) reduce 144) ((T_EMPTY) reduce 144) ((T_ENDWHILE) reduce 144) ((T_ENUM) reduce 144) ((T_EVAL) reduce 144) ((T_EXIT) reduce 144) ((T_FILE) reduce 144) ((T_FINAL) reduce 144) ((T_FN) reduce 144) ((T_FOR) reduce 144) ((T_FOREACH) reduce 144) ((T_FUNCTION) reduce 144) ((T_FUNC_C) reduce 144) ((T_GLOBAL) reduce 144) ((T_GOTO) reduce 144) ((T_HALT_COMPILER) reduce 144) ((T_IF) reduce 144) ((T_INC) reduce 144) ((T_INCLUDE) reduce 144) ((T_INCLUDE_ONCE) reduce 144) ((T_INLINE_HTML) reduce 144) ((T_INTERFACE) reduce 144) ((T_INT_CAST) reduce 144) ((T_ISSET) reduce 144) ((T_LINE) reduce 144) ((T_LIST) reduce 144) ((T_LNUMBER) reduce 144) ((T_MATCH) reduce 144) ((T_METHOD_C) reduce 144) ((T_NAME_FULLY_QUALIFIED) reduce 144) ((T_NAME_QUALIFIED) reduce 144) ((T_NAME_RELATIVE) reduce 144) ((T_NEW) reduce 144) ((T_NS_C) reduce 144) ((T_OBJECT_CAST) reduce 144) ((T_PRINT) reduce 144) ((T_READONLY) reduce 144) ((T_REQUIRE) reduce 144) ((T_REQUIRE_ONCE) reduce 144) ((T_RETURN) reduce 144) ((T_START_HEREDOC) reduce 144) ((T_STATIC) reduce 144) ((T_STRING) reduce 144) ((T_STRING_CAST) reduce 144) ((T_SWITCH) reduce 144) ((T_THROW) reduce 144) ((T_TRAIT) reduce 144) ((T_TRAIT_C) reduce 144) ((T_TRY) reduce 144) ((T_UNSET) reduce 144) ((T_UNSET_CAST) reduce 144) ((T_VARIABLE) reduce 144) ((T_WHILE) reduce 144) ((T_YIELD) reduce 144) ((T_YIELD_FROM) reduce 144) (("[") reduce 144) (("`") reduce 144) (("{") reduce 144) (("~") reduce 144)) 24218 ((("!") reduce 166) (("\"") reduce 166) (("$") reduce 166) (("(") reduce 166) (("+") reduce 166) (("-") reduce 166) ((";") reduce 166) (("@") reduce 166) ((T_ABSTRACT) reduce 166) ((T_ARRAY) reduce 166) ((T_ARRAY_CAST) reduce 166) ((T_ATTRIBUTE) reduce 166) ((T_BOOL_CAST) reduce 166) ((T_BREAK) reduce 166) ((T_CLASS) reduce 166) ((T_CLASS_C) reduce 166) ((T_CLONE) reduce 166) ((T_CONSTANT_ENCAPSED_STRING) reduce 166) ((T_CONTINUE) reduce 166) ((T_DEC) reduce 166) ((T_DECLARE) reduce 166) ((T_DIR) reduce 166) ((T_DNUMBER) reduce 166) ((T_DO) reduce 166) ((T_DOUBLE_CAST) reduce 166) ((T_ECHO) reduce 166) ((T_EMPTY) reduce 166) ((T_ENDWHILE) reduce 166) ((T_ENUM) reduce 166) ((T_EVAL) reduce 166) ((T_EXIT) reduce 166) ((T_FILE) reduce 166) ((T_FINAL) reduce 166) ((T_FN) reduce 166) ((T_FOR) reduce 166) ((T_FOREACH) reduce 166) ((T_FUNCTION) reduce 166) ((T_FUNC_C) reduce 166) ((T_GLOBAL) reduce 166) ((T_GOTO) reduce 166) ((T_HALT_COMPILER) reduce 166) ((T_IF) reduce 166) ((T_INC) reduce 166) ((T_INCLUDE) reduce 166) ((T_INCLUDE_ONCE) reduce 166) ((T_INLINE_HTML) reduce 166) ((T_INTERFACE) reduce 166) ((T_INT_CAST) reduce 166) ((T_ISSET) reduce 166) ((T_LINE) reduce 166) ((T_LIST) reduce 166) ((T_LNUMBER) reduce 166) ((T_MATCH) reduce 166) ((T_METHOD_C) reduce 166) ((T_NAME_FULLY_QUALIFIED) reduce 166) ((T_NAME_QUALIFIED) reduce 166) ((T_NAME_RELATIVE) reduce 166) ((T_NEW) reduce 166) ((T_NS_C) reduce 166) ((T_OBJECT_CAST) reduce 166) ((T_PRINT) reduce 166) ((T_READONLY) reduce 166) ((T_REQUIRE) reduce 166) ((T_REQUIRE_ONCE) reduce 166) ((T_RETURN) reduce 166) ((T_START_HEREDOC) reduce 166) ((T_STATIC) reduce 166) ((T_STRING) reduce 166) ((T_STRING_CAST) reduce 166) ((T_SWITCH) reduce 166) ((T_THROW) reduce 166) ((T_TRAIT) reduce 166) ((T_TRAIT_C) reduce 166) ((T_TRY) reduce 166) ((T_UNSET) reduce 166) ((T_UNSET_CAST) reduce 166) ((T_VARIABLE) reduce 166) ((T_WHILE) reduce 166) ((T_YIELD) reduce 166) ((T_YIELD_FROM) reduce 166) (("[") reduce 166) (("`") reduce 166) (("{") reduce 166) (("~") reduce 166)) 24220 ((("!") reduce 155) (("\"") reduce 155) (("$") reduce 155) (("(") reduce 155) (("+") reduce 155) (("-") reduce 155) ((";") reduce 155) (("@") reduce 155) ((T_ABSTRACT) reduce 155) ((T_ARRAY) reduce 155) ((T_ARRAY_CAST) reduce 155) ((T_ATTRIBUTE) reduce 155) ((T_BOOL_CAST) reduce 155) ((T_BREAK) reduce 155) ((T_CLASS) reduce 155) ((T_CLASS_C) reduce 155) ((T_CLONE) reduce 155) ((T_CONSTANT_ENCAPSED_STRING) reduce 155) ((T_CONTINUE) reduce 155) ((T_DEC) reduce 155) ((T_DECLARE) reduce 155) ((T_DIR) reduce 155) ((T_DNUMBER) reduce 155) ((T_DO) reduce 155) ((T_DOUBLE_CAST) reduce 155) ((T_ECHO) reduce 155) ((T_EMPTY) reduce 155) ((T_ENDWHILE) reduce 155) ((T_ENUM) reduce 155) ((T_EVAL) reduce 155) ((T_EXIT) reduce 155) ((T_FILE) reduce 155) ((T_FINAL) reduce 155) ((T_FN) reduce 155) ((T_FOR) reduce 155) ((T_FOREACH) reduce 155) ((T_FUNCTION) reduce 155) ((T_FUNC_C) reduce 155) ((T_GLOBAL) reduce 155) ((T_GOTO) reduce 155) ((T_HALT_COMPILER) reduce 155) ((T_IF) reduce 155) ((T_INC) reduce 155) ((T_INCLUDE) reduce 155) ((T_INCLUDE_ONCE) reduce 155) ((T_INLINE_HTML) reduce 155) ((T_INTERFACE) reduce 155) ((T_INT_CAST) reduce 155) ((T_ISSET) reduce 155) ((T_LINE) reduce 155) ((T_LIST) reduce 155) ((T_LNUMBER) reduce 155) ((T_MATCH) reduce 155) ((T_METHOD_C) reduce 155) ((T_NAME_FULLY_QUALIFIED) reduce 155) ((T_NAME_QUALIFIED) reduce 155) ((T_NAME_RELATIVE) reduce 155) ((T_NEW) reduce 155) ((T_NS_C) reduce 155) ((T_OBJECT_CAST) reduce 155) ((T_PRINT) reduce 155) ((T_READONLY) reduce 155) ((T_REQUIRE) reduce 155) ((T_REQUIRE_ONCE) reduce 155) ((T_RETURN) reduce 155) ((T_START_HEREDOC) reduce 155) ((T_STATIC) reduce 155) ((T_STRING) reduce 155) ((T_STRING_CAST) reduce 155) ((T_SWITCH) reduce 155) ((T_THROW) reduce 155) ((T_TRAIT) reduce 155) ((T_TRAIT_C) reduce 155) ((T_TRY) reduce 155) ((T_UNSET) reduce 155) ((T_UNSET_CAST) reduce 155) ((T_VARIABLE) reduce 155) ((T_WHILE) reduce 155) ((T_YIELD) reduce 155) ((T_YIELD_FROM) reduce 155) (("[") reduce 155) (("`") reduce 155) (("{") reduce 155) (("~") reduce 155)) 24230 ((("!") reduce 162) (("\"") reduce 162) (("$") reduce 162) (("(") reduce 162) (("+") reduce 162) (("-") reduce 162) ((";") reduce 162) (("@") reduce 162) ((T_ABSTRACT) reduce 162) ((T_ARRAY) reduce 162) ((T_ARRAY_CAST) reduce 162) ((T_ATTRIBUTE) reduce 162) ((T_BOOL_CAST) reduce 162) ((T_BREAK) reduce 162) ((T_CLASS) reduce 162) ((T_CLASS_C) reduce 162) ((T_CLONE) reduce 162) ((T_CONSTANT_ENCAPSED_STRING) reduce 162) ((T_CONTINUE) reduce 162) ((T_DEC) reduce 162) ((T_DECLARE) reduce 162) ((T_DIR) reduce 162) ((T_DNUMBER) reduce 162) ((T_DO) reduce 162) ((T_DOUBLE_CAST) reduce 162) ((T_ECHO) reduce 162) ((T_EMPTY) reduce 162) ((T_ENDWHILE) reduce 162) ((T_ENUM) reduce 162) ((T_EVAL) reduce 162) ((T_EXIT) reduce 162) ((T_FILE) reduce 162) ((T_FINAL) reduce 162) ((T_FN) reduce 162) ((T_FOR) reduce 162) ((T_FOREACH) reduce 162) ((T_FUNCTION) reduce 162) ((T_FUNC_C) reduce 162) ((T_GLOBAL) reduce 162) ((T_GOTO) reduce 162) ((T_HALT_COMPILER) reduce 162) ((T_IF) reduce 162) ((T_INC) reduce 162) ((T_INCLUDE) reduce 162) ((T_INCLUDE_ONCE) reduce 162) ((T_INLINE_HTML) reduce 162) ((T_INTERFACE) reduce 162) ((T_INT_CAST) reduce 162) ((T_ISSET) reduce 162) ((T_LINE) reduce 162) ((T_LIST) reduce 162) ((T_LNUMBER) reduce 162) ((T_MATCH) reduce 162) ((T_METHOD_C) reduce 162) ((T_NAME_FULLY_QUALIFIED) reduce 162) ((T_NAME_QUALIFIED) reduce 162) ((T_NAME_RELATIVE) reduce 162) ((T_NEW) reduce 162) ((T_NS_C) reduce 162) ((T_OBJECT_CAST) reduce 162) ((T_PRINT) reduce 162) ((T_READONLY) reduce 162) ((T_REQUIRE) reduce 162) ((T_REQUIRE_ONCE) reduce 162) ((T_RETURN) reduce 162) ((T_START_HEREDOC) reduce 162) ((T_STATIC) reduce 162) ((T_STRING) reduce 162) ((T_STRING_CAST) reduce 162) ((T_SWITCH) reduce 162) ((T_THROW) reduce 162) ((T_TRAIT) reduce 162) ((T_TRAIT_C) reduce 162) ((T_TRY) reduce 162) ((T_UNSET) reduce 162) ((T_UNSET_CAST) reduce 162) ((T_VARIABLE) reduce 162) ((T_WHILE) reduce 162) ((T_YIELD) reduce 162) ((T_YIELD_FROM) reduce 162) (("[") reduce 162) (("`") reduce 162) (("{") reduce 162) (("~") reduce 162)) 24231 ((("!") reduce 217) (("\"") reduce 217) (("$") reduce 217) (("(") reduce 217) (("+") reduce 217) (("-") reduce 217) ((";") reduce 217) (("@") reduce 217) ((T_ABSTRACT) reduce 217) ((T_ARRAY) reduce 217) ((T_ARRAY_CAST) reduce 217) ((T_ATTRIBUTE) reduce 217) ((T_BOOL_CAST) reduce 217) ((T_BREAK) reduce 217) ((T_CLASS) reduce 217) ((T_CLASS_C) reduce 217) ((T_CLONE) reduce 217) ((T_CONSTANT_ENCAPSED_STRING) reduce 217) ((T_CONTINUE) reduce 217) ((T_DEC) reduce 217) ((T_DECLARE) reduce 217) ((T_DIR) reduce 217) ((T_DNUMBER) reduce 217) ((T_DO) reduce 217) ((T_DOUBLE_CAST) reduce 217) ((T_ECHO) reduce 217) ((T_EMPTY) reduce 217) ((T_ENDWHILE) reduce 217) ((T_ENUM) reduce 217) ((T_EVAL) reduce 217) ((T_EXIT) reduce 217) ((T_FILE) reduce 217) ((T_FINAL) reduce 217) ((T_FN) reduce 217) ((T_FOR) reduce 217) ((T_FOREACH) reduce 217) ((T_FUNCTION) reduce 217) ((T_FUNC_C) reduce 217) ((T_GLOBAL) reduce 217) ((T_GOTO) reduce 217) ((T_HALT_COMPILER) reduce 217) ((T_IF) reduce 217) ((T_INC) reduce 217) ((T_INCLUDE) reduce 217) ((T_INCLUDE_ONCE) reduce 217) ((T_INLINE_HTML) reduce 217) ((T_INTERFACE) reduce 217) ((T_INT_CAST) reduce 217) ((T_ISSET) reduce 217) ((T_LINE) reduce 217) ((T_LIST) reduce 217) ((T_LNUMBER) reduce 217) ((T_MATCH) reduce 217) ((T_METHOD_C) reduce 217) ((T_NAME_FULLY_QUALIFIED) reduce 217) ((T_NAME_QUALIFIED) reduce 217) ((T_NAME_RELATIVE) reduce 217) ((T_NEW) reduce 217) ((T_NS_C) reduce 217) ((T_OBJECT_CAST) reduce 217) ((T_PRINT) reduce 217) ((T_READONLY) reduce 217) ((T_REQUIRE) reduce 217) ((T_REQUIRE_ONCE) reduce 217) ((T_RETURN) reduce 217) ((T_START_HEREDOC) reduce 217) ((T_STATIC) reduce 217) ((T_STRING) reduce 217) ((T_STRING_CAST) reduce 217) ((T_SWITCH) reduce 217) ((T_THROW) reduce 217) ((T_TRAIT) reduce 217) ((T_TRAIT_C) reduce 217) ((T_TRY) reduce 217) ((T_UNSET) reduce 217) ((T_UNSET_CAST) reduce 217) ((T_VARIABLE) reduce 217) ((T_WHILE) reduce 217) ((T_YIELD) reduce 217) ((T_YIELD_FROM) reduce 217) (("[") reduce 217) (("`") reduce 217) (("{") reduce 217) (("~") reduce 217)) 24234 ((("!") reduce 218) (("\"") reduce 218) (("$") reduce 218) (("(") reduce 218) (("+") reduce 218) (("-") reduce 218) ((";") reduce 218) (("@") reduce 218) ((T_ABSTRACT) reduce 218) ((T_ARRAY) reduce 218) ((T_ARRAY_CAST) reduce 218) ((T_ATTRIBUTE) reduce 218) ((T_BOOL_CAST) reduce 218) ((T_BREAK) reduce 218) ((T_CLASS) reduce 218) ((T_CLASS_C) reduce 218) ((T_CLONE) reduce 218) ((T_CONSTANT_ENCAPSED_STRING) reduce 218) ((T_CONTINUE) reduce 218) ((T_DEC) reduce 218) ((T_DECLARE) reduce 218) ((T_DIR) reduce 218) ((T_DNUMBER) reduce 218) ((T_DO) reduce 218) ((T_DOUBLE_CAST) reduce 218) ((T_ECHO) reduce 218) ((T_EMPTY) reduce 218) ((T_ENDWHILE) reduce 218) ((T_ENUM) reduce 218) ((T_EVAL) reduce 218) ((T_EXIT) reduce 218) ((T_FILE) reduce 218) ((T_FINAL) reduce 218) ((T_FN) reduce 218) ((T_FOR) reduce 218) ((T_FOREACH) reduce 218) ((T_FUNCTION) reduce 218) ((T_FUNC_C) reduce 218) ((T_GLOBAL) reduce 218) ((T_GOTO) reduce 218) ((T_HALT_COMPILER) reduce 218) ((T_IF) reduce 218) ((T_INC) reduce 218) ((T_INCLUDE) reduce 218) ((T_INCLUDE_ONCE) reduce 218) ((T_INLINE_HTML) reduce 218) ((T_INTERFACE) reduce 218) ((T_INT_CAST) reduce 218) ((T_ISSET) reduce 218) ((T_LINE) reduce 218) ((T_LIST) reduce 218) ((T_LNUMBER) reduce 218) ((T_MATCH) reduce 218) ((T_METHOD_C) reduce 218) ((T_NAME_FULLY_QUALIFIED) reduce 218) ((T_NAME_QUALIFIED) reduce 218) ((T_NAME_RELATIVE) reduce 218) ((T_NEW) reduce 218) ((T_NS_C) reduce 218) ((T_OBJECT_CAST) reduce 218) ((T_PRINT) reduce 218) ((T_READONLY) reduce 218) ((T_REQUIRE) reduce 218) ((T_REQUIRE_ONCE) reduce 218) ((T_RETURN) reduce 218) ((T_START_HEREDOC) reduce 218) ((T_STATIC) reduce 218) ((T_STRING) reduce 218) ((T_STRING_CAST) reduce 218) ((T_SWITCH) reduce 218) ((T_THROW) reduce 218) ((T_TRAIT) reduce 218) ((T_TRAIT_C) reduce 218) ((T_TRY) reduce 218) ((T_UNSET) reduce 218) ((T_UNSET_CAST) reduce 218) ((T_VARIABLE) reduce 218) ((T_WHILE) reduce 218) ((T_YIELD) reduce 218) ((T_YIELD_FROM) reduce 218) (("[") reduce 218) (("`") reduce 218) (("{") reduce 218) (("~") reduce 218)) 24235 ((("!") reduce 161) (("\"") reduce 161) (("$") reduce 161) (("(") reduce 161) (("+") reduce 161) (("-") reduce 161) ((";") reduce 161) (("@") reduce 161) ((T_ABSTRACT) reduce 161) ((T_ARRAY) reduce 161) ((T_ARRAY_CAST) reduce 161) ((T_ATTRIBUTE) reduce 161) ((T_BOOL_CAST) reduce 161) ((T_BREAK) reduce 161) ((T_CLASS) reduce 161) ((T_CLASS_C) reduce 161) ((T_CLONE) reduce 161) ((T_CONSTANT_ENCAPSED_STRING) reduce 161) ((T_CONTINUE) reduce 161) ((T_DEC) reduce 161) ((T_DECLARE) reduce 161) ((T_DIR) reduce 161) ((T_DNUMBER) reduce 161) ((T_DO) reduce 161) ((T_DOUBLE_CAST) reduce 161) ((T_ECHO) reduce 161) ((T_EMPTY) reduce 161) ((T_ENDWHILE) reduce 161) ((T_ENUM) reduce 161) ((T_EVAL) reduce 161) ((T_EXIT) reduce 161) ((T_FILE) reduce 161) ((T_FINAL) reduce 161) ((T_FN) reduce 161) ((T_FOR) reduce 161) ((T_FOREACH) reduce 161) ((T_FUNCTION) reduce 161) ((T_FUNC_C) reduce 161) ((T_GLOBAL) reduce 161) ((T_GOTO) reduce 161) ((T_HALT_COMPILER) reduce 161) ((T_IF) reduce 161) ((T_INC) reduce 161) ((T_INCLUDE) reduce 161) ((T_INCLUDE_ONCE) reduce 161) ((T_INLINE_HTML) reduce 161) ((T_INTERFACE) reduce 161) ((T_INT_CAST) reduce 161) ((T_ISSET) reduce 161) ((T_LINE) reduce 161) ((T_LIST) reduce 161) ((T_LNUMBER) reduce 161) ((T_MATCH) reduce 161) ((T_METHOD_C) reduce 161) ((T_NAME_FULLY_QUALIFIED) reduce 161) ((T_NAME_QUALIFIED) reduce 161) ((T_NAME_RELATIVE) reduce 161) ((T_NEW) reduce 161) ((T_NS_C) reduce 161) ((T_OBJECT_CAST) reduce 161) ((T_PRINT) reduce 161) ((T_READONLY) reduce 161) ((T_REQUIRE) reduce 161) ((T_REQUIRE_ONCE) reduce 161) ((T_RETURN) reduce 161) ((T_START_HEREDOC) reduce 161) ((T_STATIC) reduce 161) ((T_STRING) reduce 161) ((T_STRING_CAST) reduce 161) ((T_SWITCH) reduce 161) ((T_THROW) reduce 161) ((T_TRAIT) reduce 161) ((T_TRAIT_C) reduce 161) ((T_TRY) reduce 161) ((T_UNSET) reduce 161) ((T_UNSET_CAST) reduce 161) ((T_VARIABLE) reduce 161) ((T_WHILE) reduce 161) ((T_YIELD) reduce 161) ((T_YIELD_FROM) reduce 161) (("[") reduce 161) (("`") reduce 161) (("{") reduce 161) (("~") reduce 161)) 24244 ((("!") reduce 150) (("\"") reduce 150) (("$") reduce 150) (("(") reduce 150) (("+") reduce 150) (("-") reduce 150) ((";") reduce 150) (("@") reduce 150) ((T_ABSTRACT) reduce 150) ((T_ARRAY) reduce 150) ((T_ARRAY_CAST) reduce 150) ((T_ATTRIBUTE) reduce 150) ((T_BOOL_CAST) reduce 150) ((T_BREAK) reduce 150) ((T_CLASS) reduce 150) ((T_CLASS_C) reduce 150) ((T_CLONE) reduce 150) ((T_CONSTANT_ENCAPSED_STRING) reduce 150) ((T_CONTINUE) reduce 150) ((T_DEC) reduce 150) ((T_DECLARE) reduce 150) ((T_DIR) reduce 150) ((T_DNUMBER) reduce 150) ((T_DO) reduce 150) ((T_DOUBLE_CAST) reduce 150) ((T_ECHO) reduce 150) ((T_EMPTY) reduce 150) ((T_ENDWHILE) reduce 150) ((T_ENUM) reduce 150) ((T_EVAL) reduce 150) ((T_EXIT) reduce 150) ((T_FILE) reduce 150) ((T_FINAL) reduce 150) ((T_FN) reduce 150) ((T_FOR) reduce 150) ((T_FOREACH) reduce 150) ((T_FUNCTION) reduce 150) ((T_FUNC_C) reduce 150) ((T_GLOBAL) reduce 150) ((T_GOTO) reduce 150) ((T_HALT_COMPILER) reduce 150) ((T_IF) reduce 150) ((T_INC) reduce 150) ((T_INCLUDE) reduce 150) ((T_INCLUDE_ONCE) reduce 150) ((T_INLINE_HTML) reduce 150) ((T_INTERFACE) reduce 150) ((T_INT_CAST) reduce 150) ((T_ISSET) reduce 150) ((T_LINE) reduce 150) ((T_LIST) reduce 150) ((T_LNUMBER) reduce 150) ((T_MATCH) reduce 150) ((T_METHOD_C) reduce 150) ((T_NAME_FULLY_QUALIFIED) reduce 150) ((T_NAME_QUALIFIED) reduce 150) ((T_NAME_RELATIVE) reduce 150) ((T_NEW) reduce 150) ((T_NS_C) reduce 150) ((T_OBJECT_CAST) reduce 150) ((T_PRINT) reduce 150) ((T_READONLY) reduce 150) ((T_REQUIRE) reduce 150) ((T_REQUIRE_ONCE) reduce 150) ((T_RETURN) reduce 150) ((T_START_HEREDOC) reduce 150) ((T_STATIC) reduce 150) ((T_STRING) reduce 150) ((T_STRING_CAST) reduce 150) ((T_SWITCH) reduce 150) ((T_THROW) reduce 150) ((T_TRAIT) reduce 150) ((T_TRAIT_C) reduce 150) ((T_TRY) reduce 150) ((T_UNSET) reduce 150) ((T_UNSET_CAST) reduce 150) ((T_VARIABLE) reduce 150) ((T_WHILE) reduce 150) ((T_YIELD) reduce 150) ((T_YIELD_FROM) reduce 150) (("[") reduce 150) (("`") reduce 150) (("{") reduce 150) (("~") reduce 150)) 24245 ((("!") reduce 215) (("\"") reduce 215) (("$") reduce 215) (("(") reduce 215) (("+") reduce 215) (("-") reduce 215) ((";") reduce 215) (("@") reduce 215) ((T_ABSTRACT) reduce 215) ((T_ARRAY) reduce 215) ((T_ARRAY_CAST) reduce 215) ((T_ATTRIBUTE) reduce 215) ((T_BOOL_CAST) reduce 215) ((T_BREAK) reduce 215) ((T_CLASS) reduce 215) ((T_CLASS_C) reduce 215) ((T_CLONE) reduce 215) ((T_CONSTANT_ENCAPSED_STRING) reduce 215) ((T_CONTINUE) reduce 215) ((T_DEC) reduce 215) ((T_DECLARE) reduce 215) ((T_DIR) reduce 215) ((T_DNUMBER) reduce 215) ((T_DO) reduce 215) ((T_DOUBLE_CAST) reduce 215) ((T_ECHO) reduce 215) ((T_EMPTY) reduce 215) ((T_ENDWHILE) reduce 215) ((T_ENUM) reduce 215) ((T_EVAL) reduce 215) ((T_EXIT) reduce 215) ((T_FILE) reduce 215) ((T_FINAL) reduce 215) ((T_FN) reduce 215) ((T_FOR) reduce 215) ((T_FOREACH) reduce 215) ((T_FUNCTION) reduce 215) ((T_FUNC_C) reduce 215) ((T_GLOBAL) reduce 215) ((T_GOTO) reduce 215) ((T_HALT_COMPILER) reduce 215) ((T_IF) reduce 215) ((T_INC) reduce 215) ((T_INCLUDE) reduce 215) ((T_INCLUDE_ONCE) reduce 215) ((T_INLINE_HTML) reduce 215) ((T_INTERFACE) reduce 215) ((T_INT_CAST) reduce 215) ((T_ISSET) reduce 215) ((T_LINE) reduce 215) ((T_LIST) reduce 215) ((T_LNUMBER) reduce 215) ((T_MATCH) reduce 215) ((T_METHOD_C) reduce 215) ((T_NAME_FULLY_QUALIFIED) reduce 215) ((T_NAME_QUALIFIED) reduce 215) ((T_NAME_RELATIVE) reduce 215) ((T_NEW) reduce 215) ((T_NS_C) reduce 215) ((T_OBJECT_CAST) reduce 215) ((T_PRINT) reduce 215) ((T_READONLY) reduce 215) ((T_REQUIRE) reduce 215) ((T_REQUIRE_ONCE) reduce 215) ((T_RETURN) reduce 215) ((T_START_HEREDOC) reduce 215) ((T_STATIC) reduce 215) ((T_STRING) reduce 215) ((T_STRING_CAST) reduce 215) ((T_SWITCH) reduce 215) ((T_THROW) reduce 215) ((T_TRAIT) reduce 215) ((T_TRAIT_C) reduce 215) ((T_TRY) reduce 215) ((T_UNSET) reduce 215) ((T_UNSET_CAST) reduce 215) ((T_VARIABLE) reduce 215) ((T_WHILE) reduce 215) ((T_YIELD) reduce 215) ((T_YIELD_FROM) reduce 215) (("[") reduce 215) (("`") reduce 215) (("{") reduce 215) (("~") reduce 215)) 24248 ((("!") reduce 216) (("\"") reduce 216) (("$") reduce 216) (("(") reduce 216) (("+") reduce 216) (("-") reduce 216) ((";") reduce 216) (("@") reduce 216) ((T_ABSTRACT) reduce 216) ((T_ARRAY) reduce 216) ((T_ARRAY_CAST) reduce 216) ((T_ATTRIBUTE) reduce 216) ((T_BOOL_CAST) reduce 216) ((T_BREAK) reduce 216) ((T_CLASS) reduce 216) ((T_CLASS_C) reduce 216) ((T_CLONE) reduce 216) ((T_CONSTANT_ENCAPSED_STRING) reduce 216) ((T_CONTINUE) reduce 216) ((T_DEC) reduce 216) ((T_DECLARE) reduce 216) ((T_DIR) reduce 216) ((T_DNUMBER) reduce 216) ((T_DO) reduce 216) ((T_DOUBLE_CAST) reduce 216) ((T_ECHO) reduce 216) ((T_EMPTY) reduce 216) ((T_ENDWHILE) reduce 216) ((T_ENUM) reduce 216) ((T_EVAL) reduce 216) ((T_EXIT) reduce 216) ((T_FILE) reduce 216) ((T_FINAL) reduce 216) ((T_FN) reduce 216) ((T_FOR) reduce 216) ((T_FOREACH) reduce 216) ((T_FUNCTION) reduce 216) ((T_FUNC_C) reduce 216) ((T_GLOBAL) reduce 216) ((T_GOTO) reduce 216) ((T_HALT_COMPILER) reduce 216) ((T_IF) reduce 216) ((T_INC) reduce 216) ((T_INCLUDE) reduce 216) ((T_INCLUDE_ONCE) reduce 216) ((T_INLINE_HTML) reduce 216) ((T_INTERFACE) reduce 216) ((T_INT_CAST) reduce 216) ((T_ISSET) reduce 216) ((T_LINE) reduce 216) ((T_LIST) reduce 216) ((T_LNUMBER) reduce 216) ((T_MATCH) reduce 216) ((T_METHOD_C) reduce 216) ((T_NAME_FULLY_QUALIFIED) reduce 216) ((T_NAME_QUALIFIED) reduce 216) ((T_NAME_RELATIVE) reduce 216) ((T_NEW) reduce 216) ((T_NS_C) reduce 216) ((T_OBJECT_CAST) reduce 216) ((T_PRINT) reduce 216) ((T_READONLY) reduce 216) ((T_REQUIRE) reduce 216) ((T_REQUIRE_ONCE) reduce 216) ((T_RETURN) reduce 216) ((T_START_HEREDOC) reduce 216) ((T_STATIC) reduce 216) ((T_STRING) reduce 216) ((T_STRING_CAST) reduce 216) ((T_SWITCH) reduce 216) ((T_THROW) reduce 216) ((T_TRAIT) reduce 216) ((T_TRAIT_C) reduce 216) ((T_TRY) reduce 216) ((T_UNSET) reduce 216) ((T_UNSET_CAST) reduce 216) ((T_VARIABLE) reduce 216) ((T_WHILE) reduce 216) ((T_YIELD) reduce 216) ((T_YIELD_FROM) reduce 216) (("[") reduce 216) (("`") reduce 216) (("{") reduce 216) (("~") reduce 216)) 24255 ((("!") reduce 199) (("\"") reduce 199) (("$") reduce 199) (("(") reduce 199) (("+") reduce 199) (("-") reduce 199) ((";") reduce 199) (("@") reduce 199) ((T_ABSTRACT) reduce 199) ((T_ARRAY) reduce 199) ((T_ARRAY_CAST) reduce 199) ((T_ATTRIBUTE) reduce 199) ((T_BOOL_CAST) reduce 199) ((T_BREAK) reduce 199) ((T_CLASS) reduce 199) ((T_CLASS_C) reduce 199) ((T_CLONE) reduce 199) ((T_CONSTANT_ENCAPSED_STRING) reduce 199) ((T_CONTINUE) reduce 199) ((T_DEC) reduce 199) ((T_DECLARE) reduce 199) ((T_DIR) reduce 199) ((T_DNUMBER) reduce 199) ((T_DO) reduce 199) ((T_DOUBLE_CAST) reduce 199) ((T_ECHO) reduce 199) ((T_EMPTY) reduce 199) ((T_ENDWHILE) reduce 199) ((T_ENUM) reduce 199) ((T_EVAL) reduce 199) ((T_EXIT) reduce 199) ((T_FILE) reduce 199) ((T_FINAL) reduce 199) ((T_FN) reduce 199) ((T_FOR) reduce 199) ((T_FOREACH) reduce 199) ((T_FUNCTION) reduce 199) ((T_FUNC_C) reduce 199) ((T_GLOBAL) reduce 199) ((T_GOTO) reduce 199) ((T_HALT_COMPILER) reduce 199) ((T_IF) reduce 199) ((T_INC) reduce 199) ((T_INCLUDE) reduce 199) ((T_INCLUDE_ONCE) reduce 199) ((T_INLINE_HTML) reduce 199) ((T_INTERFACE) reduce 199) ((T_INT_CAST) reduce 199) ((T_ISSET) reduce 199) ((T_LINE) reduce 199) ((T_LIST) reduce 199) ((T_LNUMBER) reduce 199) ((T_MATCH) reduce 199) ((T_METHOD_C) reduce 199) ((T_NAME_FULLY_QUALIFIED) reduce 199) ((T_NAME_QUALIFIED) reduce 199) ((T_NAME_RELATIVE) reduce 199) ((T_NEW) reduce 199) ((T_NS_C) reduce 199) ((T_OBJECT_CAST) reduce 199) ((T_PRINT) reduce 199) ((T_READONLY) reduce 199) ((T_REQUIRE) reduce 199) ((T_REQUIRE_ONCE) reduce 199) ((T_RETURN) reduce 199) ((T_START_HEREDOC) reduce 199) ((T_STATIC) reduce 199) ((T_STRING) reduce 199) ((T_STRING_CAST) reduce 199) ((T_SWITCH) reduce 199) ((T_THROW) reduce 199) ((T_TRAIT) reduce 199) ((T_TRAIT_C) reduce 199) ((T_TRY) reduce 199) ((T_UNSET) reduce 199) ((T_UNSET_CAST) reduce 199) ((T_VARIABLE) reduce 199) ((T_WHILE) reduce 199) ((T_YIELD) reduce 199) ((T_YIELD_FROM) reduce 199) (("[") reduce 199) (("`") reduce 199) (("{") reduce 199) (("~") reduce 199)) 24256 ((("!") reduce 240) (("\"") reduce 240) (("$") reduce 240) (("(") reduce 240) (("+") reduce 240) (("-") reduce 240) ((";") reduce 240) (("@") reduce 240) ((T_ABSTRACT) reduce 240) ((T_ARRAY) reduce 240) ((T_ARRAY_CAST) reduce 240) ((T_ATTRIBUTE) reduce 240) ((T_BOOL_CAST) reduce 240) ((T_BREAK) reduce 240) ((T_CLASS) reduce 240) ((T_CLASS_C) reduce 240) ((T_CLONE) reduce 240) ((T_CONSTANT_ENCAPSED_STRING) reduce 240) ((T_CONTINUE) reduce 240) ((T_DEC) reduce 240) ((T_DECLARE) reduce 240) ((T_DIR) reduce 240) ((T_DNUMBER) reduce 240) ((T_DO) reduce 240) ((T_DOUBLE_CAST) reduce 240) ((T_ECHO) reduce 240) ((T_EMPTY) reduce 240) ((T_ENDIF) reduce 240) ((T_ENUM) reduce 240) ((T_EVAL) reduce 240) ((T_EXIT) reduce 240) ((T_FILE) reduce 240) ((T_FINAL) reduce 240) ((T_FN) reduce 240) ((T_FOR) reduce 240) ((T_FOREACH) reduce 240) ((T_FUNCTION) reduce 240) ((T_FUNC_C) reduce 240) ((T_GLOBAL) reduce 240) ((T_GOTO) reduce 240) ((T_HALT_COMPILER) reduce 240) ((T_IF) reduce 240) ((T_INC) reduce 240) ((T_INCLUDE) reduce 240) ((T_INCLUDE_ONCE) reduce 240) ((T_INLINE_HTML) reduce 240) ((T_INTERFACE) reduce 240) ((T_INT_CAST) reduce 240) ((T_ISSET) reduce 240) ((T_LINE) reduce 240) ((T_LIST) reduce 240) ((T_LNUMBER) reduce 240) ((T_MATCH) reduce 240) ((T_METHOD_C) reduce 240) ((T_NAME_FULLY_QUALIFIED) reduce 240) ((T_NAME_QUALIFIED) reduce 240) ((T_NAME_RELATIVE) reduce 240) ((T_NEW) reduce 240) ((T_NS_C) reduce 240) ((T_OBJECT_CAST) reduce 240) ((T_PRINT) reduce 240) ((T_READONLY) reduce 240) ((T_REQUIRE) reduce 240) ((T_REQUIRE_ONCE) reduce 240) ((T_RETURN) reduce 240) ((T_START_HEREDOC) reduce 240) ((T_STATIC) reduce 240) ((T_STRING) reduce 240) ((T_STRING_CAST) reduce 240) ((T_SWITCH) reduce 240) ((T_THROW) reduce 240) ((T_TRAIT) reduce 240) ((T_TRAIT_C) reduce 240) ((T_TRY) reduce 240) ((T_UNSET) reduce 240) ((T_UNSET_CAST) reduce 240) ((T_VARIABLE) reduce 240) ((T_WHILE) reduce 240) ((T_YIELD) reduce 240) ((T_YIELD_FROM) reduce 240) (("[") reduce 240) (("`") reduce 240) (("{") reduce 240) (("~") reduce 240)) 24258 ((("!") reduce 157) (("\"") reduce 157) (("$") reduce 157) (("(") reduce 157) (("+") reduce 157) (("-") reduce 157) ((";") reduce 157) (("@") reduce 157) ((T_ABSTRACT) reduce 157) ((T_ARRAY) reduce 157) ((T_ARRAY_CAST) reduce 157) ((T_ATTRIBUTE) reduce 157) ((T_BOOL_CAST) reduce 157) ((T_BREAK) reduce 157) ((T_CLASS) reduce 157) ((T_CLASS_C) reduce 157) ((T_CLONE) reduce 157) ((T_CONSTANT_ENCAPSED_STRING) reduce 157) ((T_CONTINUE) reduce 157) ((T_DEC) reduce 157) ((T_DECLARE) reduce 157) ((T_DIR) reduce 157) ((T_DNUMBER) reduce 157) ((T_DO) reduce 157) ((T_DOUBLE_CAST) reduce 157) ((T_ECHO) reduce 157) ((T_EMPTY) reduce 157) ((T_ENDWHILE) reduce 157) ((T_ENUM) reduce 157) ((T_EVAL) reduce 157) ((T_EXIT) reduce 157) ((T_FILE) reduce 157) ((T_FINAL) reduce 157) ((T_FN) reduce 157) ((T_FOR) reduce 157) ((T_FOREACH) reduce 157) ((T_FUNCTION) reduce 157) ((T_FUNC_C) reduce 157) ((T_GLOBAL) reduce 157) ((T_GOTO) reduce 157) ((T_HALT_COMPILER) reduce 157) ((T_IF) reduce 157) ((T_INC) reduce 157) ((T_INCLUDE) reduce 157) ((T_INCLUDE_ONCE) reduce 157) ((T_INLINE_HTML) reduce 157) ((T_INTERFACE) reduce 157) ((T_INT_CAST) reduce 157) ((T_ISSET) reduce 157) ((T_LINE) reduce 157) ((T_LIST) reduce 157) ((T_LNUMBER) reduce 157) ((T_MATCH) reduce 157) ((T_METHOD_C) reduce 157) ((T_NAME_FULLY_QUALIFIED) reduce 157) ((T_NAME_QUALIFIED) reduce 157) ((T_NAME_RELATIVE) reduce 157) ((T_NEW) reduce 157) ((T_NS_C) reduce 157) ((T_OBJECT_CAST) reduce 157) ((T_PRINT) reduce 157) ((T_READONLY) reduce 157) ((T_REQUIRE) reduce 157) ((T_REQUIRE_ONCE) reduce 157) ((T_RETURN) reduce 157) ((T_START_HEREDOC) reduce 157) ((T_STATIC) reduce 157) ((T_STRING) reduce 157) ((T_STRING_CAST) reduce 157) ((T_SWITCH) reduce 157) ((T_THROW) reduce 157) ((T_TRAIT) reduce 157) ((T_TRAIT_C) reduce 157) ((T_TRY) reduce 157) ((T_UNSET) reduce 157) ((T_UNSET_CAST) reduce 157) ((T_VARIABLE) reduce 157) ((T_WHILE) reduce 157) ((T_YIELD) reduce 157) ((T_YIELD_FROM) reduce 157) (("[") reduce 157) (("`") reduce 157) (("{") reduce 157) (("~") reduce 157)) 24264 ((("!") reduce 149) (("\"") reduce 149) (("$") reduce 149) (("(") reduce 149) (("+") reduce 149) (("-") reduce 149) ((";") reduce 149) (("@") reduce 149) ((T_ABSTRACT) reduce 149) ((T_ARRAY) reduce 149) ((T_ARRAY_CAST) reduce 149) ((T_ATTRIBUTE) reduce 149) ((T_BOOL_CAST) reduce 149) ((T_BREAK) reduce 149) ((T_CLASS) reduce 149) ((T_CLASS_C) reduce 149) ((T_CLONE) reduce 149) ((T_CONSTANT_ENCAPSED_STRING) reduce 149) ((T_CONTINUE) reduce 149) ((T_DEC) reduce 149) ((T_DECLARE) reduce 149) ((T_DIR) reduce 149) ((T_DNUMBER) reduce 149) ((T_DO) reduce 149) ((T_DOUBLE_CAST) reduce 149) ((T_ECHO) reduce 149) ((T_EMPTY) reduce 149) ((T_ENDWHILE) reduce 149) ((T_ENUM) reduce 149) ((T_EVAL) reduce 149) ((T_EXIT) reduce 149) ((T_FILE) reduce 149) ((T_FINAL) reduce 149) ((T_FN) reduce 149) ((T_FOR) reduce 149) ((T_FOREACH) reduce 149) ((T_FUNCTION) reduce 149) ((T_FUNC_C) reduce 149) ((T_GLOBAL) reduce 149) ((T_GOTO) reduce 149) ((T_HALT_COMPILER) reduce 149) ((T_IF) reduce 149) ((T_INC) reduce 149) ((T_INCLUDE) reduce 149) ((T_INCLUDE_ONCE) reduce 149) ((T_INLINE_HTML) reduce 149) ((T_INTERFACE) reduce 149) ((T_INT_CAST) reduce 149) ((T_ISSET) reduce 149) ((T_LINE) reduce 149) ((T_LIST) reduce 149) ((T_LNUMBER) reduce 149) ((T_MATCH) reduce 149) ((T_METHOD_C) reduce 149) ((T_NAME_FULLY_QUALIFIED) reduce 149) ((T_NAME_QUALIFIED) reduce 149) ((T_NAME_RELATIVE) reduce 149) ((T_NEW) reduce 149) ((T_NS_C) reduce 149) ((T_OBJECT_CAST) reduce 149) ((T_PRINT) reduce 149) ((T_READONLY) reduce 149) ((T_REQUIRE) reduce 149) ((T_REQUIRE_ONCE) reduce 149) ((T_RETURN) reduce 149) ((T_START_HEREDOC) reduce 149) ((T_STATIC) reduce 149) ((T_STRING) reduce 149) ((T_STRING_CAST) reduce 149) ((T_SWITCH) reduce 149) ((T_THROW) reduce 149) ((T_TRAIT) reduce 149) ((T_TRAIT_C) reduce 149) ((T_TRY) reduce 149) ((T_UNSET) reduce 149) ((T_UNSET_CAST) reduce 149) ((T_VARIABLE) reduce 149) ((T_WHILE) reduce 149) ((T_YIELD) reduce 149) ((T_YIELD_FROM) reduce 149) (("[") reduce 149) (("`") reduce 149) (("{") reduce 149) (("~") reduce 149)) 24269 ((("!") reduce 163) (("\"") reduce 163) (("$") reduce 163) (("(") reduce 163) (("+") reduce 163) (("-") reduce 163) ((";") reduce 163) (("@") reduce 163) ((T_ABSTRACT) reduce 163) ((T_ARRAY) reduce 163) ((T_ARRAY_CAST) reduce 163) ((T_ATTRIBUTE) reduce 163) ((T_BOOL_CAST) reduce 163) ((T_BREAK) reduce 163) ((T_CLASS) reduce 163) ((T_CLASS_C) reduce 163) ((T_CLONE) reduce 163) ((T_CONSTANT_ENCAPSED_STRING) reduce 163) ((T_CONTINUE) reduce 163) ((T_DEC) reduce 163) ((T_DECLARE) reduce 163) ((T_DIR) reduce 163) ((T_DNUMBER) reduce 163) ((T_DO) reduce 163) ((T_DOUBLE_CAST) reduce 163) ((T_ECHO) reduce 163) ((T_EMPTY) reduce 163) ((T_ENDWHILE) reduce 163) ((T_ENUM) reduce 163) ((T_EVAL) reduce 163) ((T_EXIT) reduce 163) ((T_FILE) reduce 163) ((T_FINAL) reduce 163) ((T_FN) reduce 163) ((T_FOR) reduce 163) ((T_FOREACH) reduce 163) ((T_FUNCTION) reduce 163) ((T_FUNC_C) reduce 163) ((T_GLOBAL) reduce 163) ((T_GOTO) reduce 163) ((T_HALT_COMPILER) reduce 163) ((T_IF) reduce 163) ((T_INC) reduce 163) ((T_INCLUDE) reduce 163) ((T_INCLUDE_ONCE) reduce 163) ((T_INLINE_HTML) reduce 163) ((T_INTERFACE) reduce 163) ((T_INT_CAST) reduce 163) ((T_ISSET) reduce 163) ((T_LINE) reduce 163) ((T_LIST) reduce 163) ((T_LNUMBER) reduce 163) ((T_MATCH) reduce 163) ((T_METHOD_C) reduce 163) ((T_NAME_FULLY_QUALIFIED) reduce 163) ((T_NAME_QUALIFIED) reduce 163) ((T_NAME_RELATIVE) reduce 163) ((T_NEW) reduce 163) ((T_NS_C) reduce 163) ((T_OBJECT_CAST) reduce 163) ((T_PRINT) reduce 163) ((T_READONLY) reduce 163) ((T_REQUIRE) reduce 163) ((T_REQUIRE_ONCE) reduce 163) ((T_RETURN) reduce 163) ((T_START_HEREDOC) reduce 163) ((T_STATIC) reduce 163) ((T_STRING) reduce 163) ((T_STRING_CAST) reduce 163) ((T_SWITCH) reduce 163) ((T_THROW) reduce 163) ((T_TRAIT) reduce 163) ((T_TRAIT_C) reduce 163) ((T_TRY) reduce 163) ((T_UNSET) reduce 163) ((T_UNSET_CAST) reduce 163) ((T_VARIABLE) reduce 163) ((T_WHILE) reduce 163) ((T_YIELD) reduce 163) ((T_YIELD_FROM) reduce 163) (("[") reduce 163) (("`") reduce 163) (("{") reduce 163) (("~") reduce 163)) 24270 ((("!") reduce 219) (("\"") reduce 219) (("$") reduce 219) (("(") reduce 219) (("+") reduce 219) (("-") reduce 219) ((";") reduce 219) (("@") reduce 219) ((T_ABSTRACT) reduce 219) ((T_ARRAY) reduce 219) ((T_ARRAY_CAST) reduce 219) ((T_ATTRIBUTE) reduce 219) ((T_BOOL_CAST) reduce 219) ((T_BREAK) reduce 219) ((T_CLASS) reduce 219) ((T_CLASS_C) reduce 219) ((T_CLONE) reduce 219) ((T_CONSTANT_ENCAPSED_STRING) reduce 219) ((T_CONTINUE) reduce 219) ((T_DEC) reduce 219) ((T_DECLARE) reduce 219) ((T_DIR) reduce 219) ((T_DNUMBER) reduce 219) ((T_DO) reduce 219) ((T_DOUBLE_CAST) reduce 219) ((T_ECHO) reduce 219) ((T_EMPTY) reduce 219) ((T_ENDWHILE) reduce 219) ((T_ENUM) reduce 219) ((T_EVAL) reduce 219) ((T_EXIT) reduce 219) ((T_FILE) reduce 219) ((T_FINAL) reduce 219) ((T_FN) reduce 219) ((T_FOR) reduce 219) ((T_FOREACH) reduce 219) ((T_FUNCTION) reduce 219) ((T_FUNC_C) reduce 219) ((T_GLOBAL) reduce 219) ((T_GOTO) reduce 219) ((T_HALT_COMPILER) reduce 219) ((T_IF) reduce 219) ((T_INC) reduce 219) ((T_INCLUDE) reduce 219) ((T_INCLUDE_ONCE) reduce 219) ((T_INLINE_HTML) reduce 219) ((T_INTERFACE) reduce 219) ((T_INT_CAST) reduce 219) ((T_ISSET) reduce 219) ((T_LINE) reduce 219) ((T_LIST) reduce 219) ((T_LNUMBER) reduce 219) ((T_MATCH) reduce 219) ((T_METHOD_C) reduce 219) ((T_NAME_FULLY_QUALIFIED) reduce 219) ((T_NAME_QUALIFIED) reduce 219) ((T_NAME_RELATIVE) reduce 219) ((T_NEW) reduce 219) ((T_NS_C) reduce 219) ((T_OBJECT_CAST) reduce 219) ((T_PRINT) reduce 219) ((T_READONLY) reduce 219) ((T_REQUIRE) reduce 219) ((T_REQUIRE_ONCE) reduce 219) ((T_RETURN) reduce 219) ((T_START_HEREDOC) reduce 219) ((T_STATIC) reduce 219) ((T_STRING) reduce 219) ((T_STRING_CAST) reduce 219) ((T_SWITCH) reduce 219) ((T_THROW) reduce 219) ((T_TRAIT) reduce 219) ((T_TRAIT_C) reduce 219) ((T_TRY) reduce 219) ((T_UNSET) reduce 219) ((T_UNSET_CAST) reduce 219) ((T_VARIABLE) reduce 219) ((T_WHILE) reduce 219) ((T_YIELD) reduce 219) ((T_YIELD_FROM) reduce 219) (("[") reduce 219) (("`") reduce 219) (("{") reduce 219) (("~") reduce 219)) 24273 ((("!") reduce 220) (("\"") reduce 220) (("$") reduce 220) (("(") reduce 220) (("+") reduce 220) (("-") reduce 220) ((";") reduce 220) (("@") reduce 220) ((T_ABSTRACT) reduce 220) ((T_ARRAY) reduce 220) ((T_ARRAY_CAST) reduce 220) ((T_ATTRIBUTE) reduce 220) ((T_BOOL_CAST) reduce 220) ((T_BREAK) reduce 220) ((T_CLASS) reduce 220) ((T_CLASS_C) reduce 220) ((T_CLONE) reduce 220) ((T_CONSTANT_ENCAPSED_STRING) reduce 220) ((T_CONTINUE) reduce 220) ((T_DEC) reduce 220) ((T_DECLARE) reduce 220) ((T_DIR) reduce 220) ((T_DNUMBER) reduce 220) ((T_DO) reduce 220) ((T_DOUBLE_CAST) reduce 220) ((T_ECHO) reduce 220) ((T_EMPTY) reduce 220) ((T_ENDWHILE) reduce 220) ((T_ENUM) reduce 220) ((T_EVAL) reduce 220) ((T_EXIT) reduce 220) ((T_FILE) reduce 220) ((T_FINAL) reduce 220) ((T_FN) reduce 220) ((T_FOR) reduce 220) ((T_FOREACH) reduce 220) ((T_FUNCTION) reduce 220) ((T_FUNC_C) reduce 220) ((T_GLOBAL) reduce 220) ((T_GOTO) reduce 220) ((T_HALT_COMPILER) reduce 220) ((T_IF) reduce 220) ((T_INC) reduce 220) ((T_INCLUDE) reduce 220) ((T_INCLUDE_ONCE) reduce 220) ((T_INLINE_HTML) reduce 220) ((T_INTERFACE) reduce 220) ((T_INT_CAST) reduce 220) ((T_ISSET) reduce 220) ((T_LINE) reduce 220) ((T_LIST) reduce 220) ((T_LNUMBER) reduce 220) ((T_MATCH) reduce 220) ((T_METHOD_C) reduce 220) ((T_NAME_FULLY_QUALIFIED) reduce 220) ((T_NAME_QUALIFIED) reduce 220) ((T_NAME_RELATIVE) reduce 220) ((T_NEW) reduce 220) ((T_NS_C) reduce 220) ((T_OBJECT_CAST) reduce 220) ((T_PRINT) reduce 220) ((T_READONLY) reduce 220) ((T_REQUIRE) reduce 220) ((T_REQUIRE_ONCE) reduce 220) ((T_RETURN) reduce 220) ((T_START_HEREDOC) reduce 220) ((T_STATIC) reduce 220) ((T_STRING) reduce 220) ((T_STRING_CAST) reduce 220) ((T_SWITCH) reduce 220) ((T_THROW) reduce 220) ((T_TRAIT) reduce 220) ((T_TRAIT_C) reduce 220) ((T_TRY) reduce 220) ((T_UNSET) reduce 220) ((T_UNSET_CAST) reduce 220) ((T_VARIABLE) reduce 220) ((T_WHILE) reduce 220) ((T_YIELD) reduce 220) ((T_YIELD_FROM) reduce 220) (("[") reduce 220) (("`") reduce 220) (("{") reduce 220) (("~") reduce 220)) 24275 ((("!") reduce 153) (("\"") reduce 153) (("$") reduce 153) (("(") reduce 153) (("+") reduce 153) (("-") reduce 153) ((";") reduce 153) (("@") reduce 153) ((T_ABSTRACT) reduce 153) ((T_ARRAY) reduce 153) ((T_ARRAY_CAST) reduce 153) ((T_ATTRIBUTE) reduce 153) ((T_BOOL_CAST) reduce 153) ((T_BREAK) reduce 153) ((T_CLASS) reduce 153) ((T_CLASS_C) reduce 153) ((T_CLONE) reduce 153) ((T_CONSTANT_ENCAPSED_STRING) reduce 153) ((T_CONTINUE) reduce 153) ((T_DEC) reduce 153) ((T_DECLARE) reduce 153) ((T_DIR) reduce 153) ((T_DNUMBER) reduce 153) ((T_DO) reduce 153) ((T_DOUBLE_CAST) reduce 153) ((T_ECHO) reduce 153) ((T_EMPTY) reduce 153) ((T_ENDWHILE) reduce 153) ((T_ENUM) reduce 153) ((T_EVAL) reduce 153) ((T_EXIT) reduce 153) ((T_FILE) reduce 153) ((T_FINAL) reduce 153) ((T_FN) reduce 153) ((T_FOR) reduce 153) ((T_FOREACH) reduce 153) ((T_FUNCTION) reduce 153) ((T_FUNC_C) reduce 153) ((T_GLOBAL) reduce 153) ((T_GOTO) reduce 153) ((T_HALT_COMPILER) reduce 153) ((T_IF) reduce 153) ((T_INC) reduce 153) ((T_INCLUDE) reduce 153) ((T_INCLUDE_ONCE) reduce 153) ((T_INLINE_HTML) reduce 153) ((T_INTERFACE) reduce 153) ((T_INT_CAST) reduce 153) ((T_ISSET) reduce 153) ((T_LINE) reduce 153) ((T_LIST) reduce 153) ((T_LNUMBER) reduce 153) ((T_MATCH) reduce 153) ((T_METHOD_C) reduce 153) ((T_NAME_FULLY_QUALIFIED) reduce 153) ((T_NAME_QUALIFIED) reduce 153) ((T_NAME_RELATIVE) reduce 153) ((T_NEW) reduce 153) ((T_NS_C) reduce 153) ((T_OBJECT_CAST) reduce 153) ((T_PRINT) reduce 153) ((T_READONLY) reduce 153) ((T_REQUIRE) reduce 153) ((T_REQUIRE_ONCE) reduce 153) ((T_RETURN) reduce 153) ((T_START_HEREDOC) reduce 153) ((T_STATIC) reduce 153) ((T_STRING) reduce 153) ((T_STRING_CAST) reduce 153) ((T_SWITCH) reduce 153) ((T_THROW) reduce 153) ((T_TRAIT) reduce 153) ((T_TRAIT_C) reduce 153) ((T_TRY) reduce 153) ((T_UNSET) reduce 153) ((T_UNSET_CAST) reduce 153) ((T_VARIABLE) reduce 153) ((T_WHILE) reduce 153) ((T_YIELD) reduce 153) ((T_YIELD_FROM) reduce 153) (("[") reduce 153) (("`") reduce 153) (("{") reduce 153) (("~") reduce 153)) 24282 ((("!") reduce 187) (("\"") reduce 187) (("$") reduce 187) (("(") reduce 187) (("+") reduce 187) (("-") reduce 187) ((";") reduce 187) (("@") reduce 187) ((T_ABSTRACT) reduce 187) ((T_ARRAY) reduce 187) ((T_ARRAY_CAST) reduce 187) ((T_ATTRIBUTE) reduce 187) ((T_BOOL_CAST) reduce 187) ((T_BREAK) reduce 187) ((T_CLASS) reduce 187) ((T_CLASS_C) reduce 187) ((T_CLONE) reduce 187) ((T_CONSTANT_ENCAPSED_STRING) reduce 187) ((T_CONTINUE) reduce 187) ((T_DEC) reduce 187) ((T_DECLARE) reduce 187) ((T_DIR) reduce 187) ((T_DNUMBER) reduce 187) ((T_DO) reduce 187) ((T_DOUBLE_CAST) reduce 187) ((T_ECHO) reduce 187) ((T_EMPTY) reduce 187) ((T_ENDWHILE) reduce 187) ((T_ENUM) reduce 187) ((T_EVAL) reduce 187) ((T_EXIT) reduce 187) ((T_FILE) reduce 187) ((T_FINAL) reduce 187) ((T_FN) reduce 187) ((T_FOR) reduce 187) ((T_FOREACH) reduce 187) ((T_FUNCTION) reduce 187) ((T_FUNC_C) reduce 187) ((T_GLOBAL) reduce 187) ((T_GOTO) reduce 187) ((T_HALT_COMPILER) reduce 187) ((T_IF) reduce 187) ((T_INC) reduce 187) ((T_INCLUDE) reduce 187) ((T_INCLUDE_ONCE) reduce 187) ((T_INLINE_HTML) reduce 187) ((T_INTERFACE) reduce 187) ((T_INT_CAST) reduce 187) ((T_ISSET) reduce 187) ((T_LINE) reduce 187) ((T_LIST) reduce 187) ((T_LNUMBER) reduce 187) ((T_MATCH) reduce 187) ((T_METHOD_C) reduce 187) ((T_NAME_FULLY_QUALIFIED) reduce 187) ((T_NAME_QUALIFIED) reduce 187) ((T_NAME_RELATIVE) reduce 187) ((T_NEW) reduce 187) ((T_NS_C) reduce 187) ((T_OBJECT_CAST) reduce 187) ((T_PRINT) reduce 187) ((T_READONLY) reduce 187) ((T_REQUIRE) reduce 187) ((T_REQUIRE_ONCE) reduce 187) ((T_RETURN) reduce 187) ((T_START_HEREDOC) reduce 187) ((T_STATIC) reduce 187) ((T_STRING) reduce 187) ((T_STRING_CAST) reduce 187) ((T_SWITCH) reduce 187) ((T_THROW) reduce 187) ((T_TRAIT) reduce 187) ((T_TRAIT_C) reduce 187) ((T_TRY) reduce 187) ((T_UNSET) reduce 187) ((T_UNSET_CAST) reduce 187) ((T_VARIABLE) reduce 187) ((T_WHILE) reduce 187) ((T_YIELD) reduce 187) ((T_YIELD_FROM) reduce 187) (("[") reduce 187) (("`") reduce 187) (("{") reduce 187) (("~") reduce 187)) 24284 ((("!") reduce 152) (("\"") reduce 152) (("$") reduce 152) (("(") reduce 152) (("+") reduce 152) (("-") reduce 152) ((";") reduce 152) (("@") reduce 152) ((T_ABSTRACT) reduce 152) ((T_ARRAY) reduce 152) ((T_ARRAY_CAST) reduce 152) ((T_ATTRIBUTE) reduce 152) ((T_BOOL_CAST) reduce 152) ((T_BREAK) reduce 152) ((T_CLASS) reduce 152) ((T_CLASS_C) reduce 152) ((T_CLONE) reduce 152) ((T_CONSTANT_ENCAPSED_STRING) reduce 152) ((T_CONTINUE) reduce 152) ((T_DEC) reduce 152) ((T_DECLARE) reduce 152) ((T_DIR) reduce 152) ((T_DNUMBER) reduce 152) ((T_DO) reduce 152) ((T_DOUBLE_CAST) reduce 152) ((T_ECHO) reduce 152) ((T_EMPTY) reduce 152) ((T_ENDWHILE) reduce 152) ((T_ENUM) reduce 152) ((T_EVAL) reduce 152) ((T_EXIT) reduce 152) ((T_FILE) reduce 152) ((T_FINAL) reduce 152) ((T_FN) reduce 152) ((T_FOR) reduce 152) ((T_FOREACH) reduce 152) ((T_FUNCTION) reduce 152) ((T_FUNC_C) reduce 152) ((T_GLOBAL) reduce 152) ((T_GOTO) reduce 152) ((T_HALT_COMPILER) reduce 152) ((T_IF) reduce 152) ((T_INC) reduce 152) ((T_INCLUDE) reduce 152) ((T_INCLUDE_ONCE) reduce 152) ((T_INLINE_HTML) reduce 152) ((T_INTERFACE) reduce 152) ((T_INT_CAST) reduce 152) ((T_ISSET) reduce 152) ((T_LINE) reduce 152) ((T_LIST) reduce 152) ((T_LNUMBER) reduce 152) ((T_MATCH) reduce 152) ((T_METHOD_C) reduce 152) ((T_NAME_FULLY_QUALIFIED) reduce 152) ((T_NAME_QUALIFIED) reduce 152) ((T_NAME_RELATIVE) reduce 152) ((T_NEW) reduce 152) ((T_NS_C) reduce 152) ((T_OBJECT_CAST) reduce 152) ((T_PRINT) reduce 152) ((T_READONLY) reduce 152) ((T_REQUIRE) reduce 152) ((T_REQUIRE_ONCE) reduce 152) ((T_RETURN) reduce 152) ((T_START_HEREDOC) reduce 152) ((T_STATIC) reduce 152) ((T_STRING) reduce 152) ((T_STRING_CAST) reduce 152) ((T_SWITCH) reduce 152) ((T_THROW) reduce 152) ((T_TRAIT) reduce 152) ((T_TRAIT_C) reduce 152) ((T_TRY) reduce 152) ((T_UNSET) reduce 152) ((T_UNSET_CAST) reduce 152) ((T_VARIABLE) reduce 152) ((T_WHILE) reduce 152) ((T_YIELD) reduce 152) ((T_YIELD_FROM) reduce 152) (("[") reduce 152) (("`") reduce 152) (("{") reduce 152) (("~") reduce 152)) 24289 ((("!") reduce 160) (("\"") reduce 160) (("$") reduce 160) (("(") reduce 160) (("+") reduce 160) (("-") reduce 160) ((";") reduce 160) (("@") reduce 160) ((T_ABSTRACT) reduce 160) ((T_ARRAY) reduce 160) ((T_ARRAY_CAST) reduce 160) ((T_ATTRIBUTE) reduce 160) ((T_BOOL_CAST) reduce 160) ((T_BREAK) reduce 160) ((T_CLASS) reduce 160) ((T_CLASS_C) reduce 160) ((T_CLONE) reduce 160) ((T_CONSTANT_ENCAPSED_STRING) reduce 160) ((T_CONTINUE) reduce 160) ((T_DEC) reduce 160) ((T_DECLARE) reduce 160) ((T_DIR) reduce 160) ((T_DNUMBER) reduce 160) ((T_DO) reduce 160) ((T_DOUBLE_CAST) reduce 160) ((T_ECHO) reduce 160) ((T_EMPTY) reduce 160) ((T_ENDIF) reduce 160) ((T_ENUM) reduce 160) ((T_EVAL) reduce 160) ((T_EXIT) reduce 160) ((T_FILE) reduce 160) ((T_FINAL) reduce 160) ((T_FN) reduce 160) ((T_FOR) reduce 160) ((T_FOREACH) reduce 160) ((T_FUNCTION) reduce 160) ((T_FUNC_C) reduce 160) ((T_GLOBAL) reduce 160) ((T_GOTO) reduce 160) ((T_HALT_COMPILER) reduce 160) ((T_IF) reduce 160) ((T_INC) reduce 160) ((T_INCLUDE) reduce 160) ((T_INCLUDE_ONCE) reduce 160) ((T_INLINE_HTML) reduce 160) ((T_INTERFACE) reduce 160) ((T_INT_CAST) reduce 160) ((T_ISSET) reduce 160) ((T_LINE) reduce 160) ((T_LIST) reduce 160) ((T_LNUMBER) reduce 160) ((T_MATCH) reduce 160) ((T_METHOD_C) reduce 160) ((T_NAME_FULLY_QUALIFIED) reduce 160) ((T_NAME_QUALIFIED) reduce 160) ((T_NAME_RELATIVE) reduce 160) ((T_NEW) reduce 160) ((T_NS_C) reduce 160) ((T_OBJECT_CAST) reduce 160) ((T_PRINT) reduce 160) ((T_READONLY) reduce 160) ((T_REQUIRE) reduce 160) ((T_REQUIRE_ONCE) reduce 160) ((T_RETURN) reduce 160) ((T_START_HEREDOC) reduce 160) ((T_STATIC) reduce 160) ((T_STRING) reduce 160) ((T_STRING_CAST) reduce 160) ((T_SWITCH) reduce 160) ((T_THROW) reduce 160) ((T_TRAIT) reduce 160) ((T_TRAIT_C) reduce 160) ((T_TRY) reduce 160) ((T_UNSET) reduce 160) ((T_UNSET_CAST) reduce 160) ((T_VARIABLE) reduce 160) ((T_WHILE) reduce 160) ((T_YIELD) reduce 160) ((T_YIELD_FROM) reduce 160) (("[") reduce 160) (("`") reduce 160) (("{") reduce 160) (("~") reduce 160)) 24292 ((("!") reduce 168) (("\"") reduce 168) (("$") reduce 168) (("(") reduce 168) (("+") reduce 168) (("-") reduce 168) ((";") reduce 168) (("@") reduce 168) ((T_ABSTRACT) reduce 168) ((T_ARRAY) reduce 168) ((T_ARRAY_CAST) reduce 168) ((T_ATTRIBUTE) reduce 168) ((T_BOOL_CAST) reduce 168) ((T_BREAK) reduce 168) ((T_CATCH) reduce 168) ((T_CLASS) reduce 168) ((T_CLASS_C) reduce 168) ((T_CLONE) reduce 168) ((T_CONSTANT_ENCAPSED_STRING) reduce 168) ((T_CONTINUE) reduce 168) ((T_DEC) reduce 168) ((T_DECLARE) reduce 168) ((T_DIR) reduce 168) ((T_DNUMBER) reduce 168) ((T_DO) reduce 168) ((T_DOUBLE_CAST) reduce 168) ((T_ECHO) reduce 168) ((T_EMPTY) reduce 168) ((T_ENDIF) reduce 168) ((T_ENUM) reduce 168) ((T_EVAL) reduce 168) ((T_EXIT) reduce 168) ((T_FILE) reduce 168) ((T_FINAL) reduce 168) ((T_FINALLY) reduce 168) ((T_FN) reduce 168) ((T_FOR) reduce 168) ((T_FOREACH) reduce 168) ((T_FUNCTION) reduce 168) ((T_FUNC_C) reduce 168) ((T_GLOBAL) reduce 168) ((T_GOTO) reduce 168) ((T_HALT_COMPILER) reduce 168) ((T_IF) reduce 168) ((T_INC) reduce 168) ((T_INCLUDE) reduce 168) ((T_INCLUDE_ONCE) reduce 168) ((T_INLINE_HTML) reduce 168) ((T_INTERFACE) reduce 168) ((T_INT_CAST) reduce 168) ((T_ISSET) reduce 168) ((T_LINE) reduce 168) ((T_LIST) reduce 168) ((T_LNUMBER) reduce 168) ((T_MATCH) reduce 168) ((T_METHOD_C) reduce 168) ((T_NAME_FULLY_QUALIFIED) reduce 168) ((T_NAME_QUALIFIED) reduce 168) ((T_NAME_RELATIVE) reduce 168) ((T_NEW) reduce 168) ((T_NS_C) reduce 168) ((T_OBJECT_CAST) reduce 168) ((T_PRINT) reduce 168) ((T_READONLY) reduce 168) ((T_REQUIRE) reduce 168) ((T_REQUIRE_ONCE) reduce 168) ((T_RETURN) reduce 168) ((T_START_HEREDOC) reduce 168) ((T_STATIC) reduce 168) ((T_STRING) reduce 168) ((T_STRING_CAST) reduce 168) ((T_SWITCH) reduce 168) ((T_THROW) reduce 168) ((T_TRAIT) reduce 168) ((T_TRAIT_C) reduce 168) ((T_TRY) reduce 168) ((T_UNSET) reduce 168) ((T_UNSET_CAST) reduce 168) ((T_VARIABLE) reduce 168) ((T_WHILE) reduce 168) ((T_YIELD) reduce 168) ((T_YIELD_FROM) reduce 168) (("[") reduce 168) (("`") reduce 168) (("{") reduce 168) (("~") reduce 168)) 24293 ((("!") reduce 174) (("\"") reduce 174) (("$") reduce 174) (("(") reduce 174) (("+") reduce 174) (("-") reduce 174) ((";") reduce 174) (("@") reduce 174) ((T_ABSTRACT) reduce 174) ((T_ARRAY) reduce 174) ((T_ARRAY_CAST) reduce 174) ((T_ATTRIBUTE) reduce 174) ((T_BOOL_CAST) reduce 174) ((T_BREAK) reduce 174) ((T_CATCH) shift) ((T_CLASS) reduce 174) ((T_CLASS_C) reduce 174) ((T_CLONE) reduce 174) ((T_CONSTANT_ENCAPSED_STRING) reduce 174) ((T_CONTINUE) reduce 174) ((T_DEC) reduce 174) ((T_DECLARE) reduce 174) ((T_DIR) reduce 174) ((T_DNUMBER) reduce 174) ((T_DO) reduce 174) ((T_DOUBLE_CAST) reduce 174) ((T_ECHO) reduce 174) ((T_EMPTY) reduce 174) ((T_ENDIF) reduce 174) ((T_ENUM) reduce 174) ((T_EVAL) reduce 174) ((T_EXIT) reduce 174) ((T_FILE) reduce 174) ((T_FINAL) reduce 174) ((T_FINALLY) shift) ((T_FN) reduce 174) ((T_FOR) reduce 174) ((T_FOREACH) reduce 174) ((T_FUNCTION) reduce 174) ((T_FUNC_C) reduce 174) ((T_GLOBAL) reduce 174) ((T_GOTO) reduce 174) ((T_HALT_COMPILER) reduce 174) ((T_IF) reduce 174) ((T_INC) reduce 174) ((T_INCLUDE) reduce 174) ((T_INCLUDE_ONCE) reduce 174) ((T_INLINE_HTML) reduce 174) ((T_INTERFACE) reduce 174) ((T_INT_CAST) reduce 174) ((T_ISSET) reduce 174) ((T_LINE) reduce 174) ((T_LIST) reduce 174) ((T_LNUMBER) reduce 174) ((T_MATCH) reduce 174) ((T_METHOD_C) reduce 174) ((T_NAME_FULLY_QUALIFIED) reduce 174) ((T_NAME_QUALIFIED) reduce 174) ((T_NAME_RELATIVE) reduce 174) ((T_NEW) reduce 174) ((T_NS_C) reduce 174) ((T_OBJECT_CAST) reduce 174) ((T_PRINT) reduce 174) ((T_READONLY) reduce 174) ((T_REQUIRE) reduce 174) ((T_REQUIRE_ONCE) reduce 174) ((T_RETURN) reduce 174) ((T_START_HEREDOC) reduce 174) ((T_STATIC) reduce 174) ((T_STRING) reduce 174) ((T_STRING_CAST) reduce 174) ((T_SWITCH) reduce 174) ((T_THROW) reduce 174) ((T_TRAIT) reduce 174) ((T_TRAIT_C) reduce 174) ((T_TRY) reduce 174) ((T_UNSET) reduce 174) ((T_UNSET_CAST) reduce 174) ((T_VARIABLE) reduce 174) ((T_WHILE) reduce 174) ((T_YIELD) reduce 174) ((T_YIELD_FROM) reduce 174) (("[") reduce 174) (("`") reduce 174) (("{") reduce 174) (("~") reduce 174)) 24296 ((("!") reduce 165) (("\"") reduce 165) (("$") reduce 165) (("(") reduce 165) (("+") reduce 165) (("-") reduce 165) ((";") reduce 165) (("@") reduce 165) ((T_ABSTRACT) reduce 165) ((T_ARRAY) reduce 165) ((T_ARRAY_CAST) reduce 165) ((T_ATTRIBUTE) reduce 165) ((T_BOOL_CAST) reduce 165) ((T_BREAK) reduce 165) ((T_CLASS) reduce 165) ((T_CLASS_C) reduce 165) ((T_CLONE) reduce 165) ((T_CONSTANT_ENCAPSED_STRING) reduce 165) ((T_CONTINUE) reduce 165) ((T_DEC) reduce 165) ((T_DECLARE) reduce 165) ((T_DIR) reduce 165) ((T_DNUMBER) reduce 165) ((T_DO) reduce 165) ((T_DOUBLE_CAST) reduce 165) ((T_ECHO) reduce 165) ((T_EMPTY) reduce 165) ((T_ENDIF) reduce 165) ((T_ENUM) reduce 165) ((T_EVAL) reduce 165) ((T_EXIT) reduce 165) ((T_FILE) reduce 165) ((T_FINAL) reduce 165) ((T_FN) reduce 165) ((T_FOR) reduce 165) ((T_FOREACH) reduce 165) ((T_FUNCTION) reduce 165) ((T_FUNC_C) reduce 165) ((T_GLOBAL) reduce 165) ((T_GOTO) reduce 165) ((T_HALT_COMPILER) reduce 165) ((T_IF) reduce 165) ((T_INC) reduce 165) ((T_INCLUDE) reduce 165) ((T_INCLUDE_ONCE) reduce 165) ((T_INLINE_HTML) reduce 165) ((T_INTERFACE) reduce 165) ((T_INT_CAST) reduce 165) ((T_ISSET) reduce 165) ((T_LINE) reduce 165) ((T_LIST) reduce 165) ((T_LNUMBER) reduce 165) ((T_MATCH) reduce 165) ((T_METHOD_C) reduce 165) ((T_NAME_FULLY_QUALIFIED) reduce 165) ((T_NAME_QUALIFIED) reduce 165) ((T_NAME_RELATIVE) reduce 165) ((T_NEW) reduce 165) ((T_NS_C) reduce 165) ((T_OBJECT_CAST) reduce 165) ((T_PRINT) reduce 165) ((T_READONLY) reduce 165) ((T_REQUIRE) reduce 165) ((T_REQUIRE_ONCE) reduce 165) ((T_RETURN) reduce 165) ((T_START_HEREDOC) reduce 165) ((T_STATIC) reduce 165) ((T_STRING) reduce 165) ((T_STRING_CAST) reduce 165) ((T_SWITCH) reduce 165) ((T_THROW) reduce 165) ((T_TRAIT) reduce 165) ((T_TRAIT_C) reduce 165) ((T_TRY) reduce 165) ((T_UNSET) reduce 165) ((T_UNSET_CAST) reduce 165) ((T_VARIABLE) reduce 165) ((T_WHILE) reduce 165) ((T_YIELD) reduce 165) ((T_YIELD_FROM) reduce 165) (("[") reduce 165) (("`") reduce 165) (("{") reduce 165) (("~") reduce 165)) 24299 ((("!") reduce 175) (("\"") reduce 175) (("$") reduce 175) (("(") reduce 175) (("+") reduce 175) (("-") reduce 175) ((";") reduce 175) (("@") reduce 175) ((T_ABSTRACT) reduce 175) ((T_ARRAY) reduce 175) ((T_ARRAY_CAST) reduce 175) ((T_ATTRIBUTE) reduce 175) ((T_BOOL_CAST) reduce 175) ((T_BREAK) reduce 175) ((T_CLASS) reduce 175) ((T_CLASS_C) reduce 175) ((T_CLONE) reduce 175) ((T_CONSTANT_ENCAPSED_STRING) reduce 175) ((T_CONTINUE) reduce 175) ((T_DEC) reduce 175) ((T_DECLARE) reduce 175) ((T_DIR) reduce 175) ((T_DNUMBER) reduce 175) ((T_DO) reduce 175) ((T_DOUBLE_CAST) reduce 175) ((T_ECHO) reduce 175) ((T_EMPTY) reduce 175) ((T_ENDIF) reduce 175) ((T_ENUM) reduce 175) ((T_EVAL) reduce 175) ((T_EXIT) reduce 175) ((T_FILE) reduce 175) ((T_FINAL) reduce 175) ((T_FN) reduce 175) ((T_FOR) reduce 175) ((T_FOREACH) reduce 175) ((T_FUNCTION) reduce 175) ((T_FUNC_C) reduce 175) ((T_GLOBAL) reduce 175) ((T_GOTO) reduce 175) ((T_HALT_COMPILER) reduce 175) ((T_IF) reduce 175) ((T_INC) reduce 175) ((T_INCLUDE) reduce 175) ((T_INCLUDE_ONCE) reduce 175) ((T_INLINE_HTML) reduce 175) ((T_INTERFACE) reduce 175) ((T_INT_CAST) reduce 175) ((T_ISSET) reduce 175) ((T_LINE) reduce 175) ((T_LIST) reduce 175) ((T_LNUMBER) reduce 175) ((T_MATCH) reduce 175) ((T_METHOD_C) reduce 175) ((T_NAME_FULLY_QUALIFIED) reduce 175) ((T_NAME_QUALIFIED) reduce 175) ((T_NAME_RELATIVE) reduce 175) ((T_NEW) reduce 175) ((T_NS_C) reduce 175) ((T_OBJECT_CAST) reduce 175) ((T_PRINT) reduce 175) ((T_READONLY) reduce 175) ((T_REQUIRE) reduce 175) ((T_REQUIRE_ONCE) reduce 175) ((T_RETURN) reduce 175) ((T_START_HEREDOC) reduce 175) ((T_STATIC) reduce 175) ((T_STRING) reduce 175) ((T_STRING_CAST) reduce 175) ((T_SWITCH) reduce 175) ((T_THROW) reduce 175) ((T_TRAIT) reduce 175) ((T_TRAIT_C) reduce 175) ((T_TRY) reduce 175) ((T_UNSET) reduce 175) ((T_UNSET_CAST) reduce 175) ((T_VARIABLE) reduce 175) ((T_WHILE) reduce 175) ((T_YIELD) reduce 175) ((T_YIELD_FROM) reduce 175) (("[") reduce 175) (("`") reduce 175) (("{") reduce 175) (("~") reduce 175)) 24306 ((("!") reduce 169) (("\"") reduce 169) (("$") reduce 169) (("(") reduce 169) (("+") reduce 169) (("-") reduce 169) ((";") reduce 169) (("@") reduce 169) ((T_ABSTRACT) reduce 169) ((T_ARRAY) reduce 169) ((T_ARRAY_CAST) reduce 169) ((T_ATTRIBUTE) reduce 169) ((T_BOOL_CAST) reduce 169) ((T_BREAK) reduce 169) ((T_CATCH) reduce 169) ((T_CLASS) reduce 169) ((T_CLASS_C) reduce 169) ((T_CLONE) reduce 169) ((T_CONSTANT_ENCAPSED_STRING) reduce 169) ((T_CONTINUE) reduce 169) ((T_DEC) reduce 169) ((T_DECLARE) reduce 169) ((T_DIR) reduce 169) ((T_DNUMBER) reduce 169) ((T_DO) reduce 169) ((T_DOUBLE_CAST) reduce 169) ((T_ECHO) reduce 169) ((T_EMPTY) reduce 169) ((T_ENDIF) reduce 169) ((T_ENUM) reduce 169) ((T_EVAL) reduce 169) ((T_EXIT) reduce 169) ((T_FILE) reduce 169) ((T_FINAL) reduce 169) ((T_FINALLY) reduce 169) ((T_FN) reduce 169) ((T_FOR) reduce 169) ((T_FOREACH) reduce 169) ((T_FUNCTION) reduce 169) ((T_FUNC_C) reduce 169) ((T_GLOBAL) reduce 169) ((T_GOTO) reduce 169) ((T_HALT_COMPILER) reduce 169) ((T_IF) reduce 169) ((T_INC) reduce 169) ((T_INCLUDE) reduce 169) ((T_INCLUDE_ONCE) reduce 169) ((T_INLINE_HTML) reduce 169) ((T_INTERFACE) reduce 169) ((T_INT_CAST) reduce 169) ((T_ISSET) reduce 169) ((T_LINE) reduce 169) ((T_LIST) reduce 169) ((T_LNUMBER) reduce 169) ((T_MATCH) reduce 169) ((T_METHOD_C) reduce 169) ((T_NAME_FULLY_QUALIFIED) reduce 169) ((T_NAME_QUALIFIED) reduce 169) ((T_NAME_RELATIVE) reduce 169) ((T_NEW) reduce 169) ((T_NS_C) reduce 169) ((T_OBJECT_CAST) reduce 169) ((T_PRINT) reduce 169) ((T_READONLY) reduce 169) ((T_REQUIRE) reduce 169) ((T_REQUIRE_ONCE) reduce 169) ((T_RETURN) reduce 169) ((T_START_HEREDOC) reduce 169) ((T_STATIC) reduce 169) ((T_STRING) reduce 169) ((T_STRING_CAST) reduce 169) ((T_SWITCH) reduce 169) ((T_THROW) reduce 169) ((T_TRAIT) reduce 169) ((T_TRAIT_C) reduce 169) ((T_TRY) reduce 169) ((T_UNSET) reduce 169) ((T_UNSET_CAST) reduce 169) ((T_VARIABLE) reduce 169) ((T_WHILE) reduce 169) ((T_YIELD) reduce 169) ((T_YIELD_FROM) reduce 169) (("[") reduce 169) (("`") reduce 169) (("{") reduce 169) (("~") reduce 169)) 24311 ((("!") reduce 197) (("\"") reduce 197) (("$") reduce 197) (("(") reduce 197) (("+") reduce 197) (("-") reduce 197) ((";") reduce 197) (("@") reduce 197) ((T_ABSTRACT) reduce 197) ((T_ARRAY) reduce 197) ((T_ARRAY_CAST) reduce 197) ((T_ATTRIBUTE) reduce 197) ((T_BOOL_CAST) reduce 197) ((T_BREAK) reduce 197) ((T_CLASS) reduce 197) ((T_CLASS_C) reduce 197) ((T_CLONE) reduce 197) ((T_CONSTANT_ENCAPSED_STRING) reduce 197) ((T_CONTINUE) reduce 197) ((T_DEC) reduce 197) ((T_DECLARE) reduce 197) ((T_DIR) reduce 197) ((T_DNUMBER) reduce 197) ((T_DO) reduce 197) ((T_DOUBLE_CAST) reduce 197) ((T_ECHO) reduce 197) ((T_EMPTY) reduce 197) ((T_ENDIF) reduce 197) ((T_ENUM) reduce 197) ((T_EVAL) reduce 197) ((T_EXIT) reduce 197) ((T_FILE) reduce 197) ((T_FINAL) reduce 197) ((T_FN) reduce 197) ((T_FOR) reduce 197) ((T_FOREACH) reduce 197) ((T_FUNCTION) reduce 197) ((T_FUNC_C) reduce 197) ((T_GLOBAL) reduce 197) ((T_GOTO) reduce 197) ((T_HALT_COMPILER) reduce 197) ((T_IF) reduce 197) ((T_INC) reduce 197) ((T_INCLUDE) reduce 197) ((T_INCLUDE_ONCE) reduce 197) ((T_INLINE_HTML) reduce 197) ((T_INTERFACE) reduce 197) ((T_INT_CAST) reduce 197) ((T_ISSET) reduce 197) ((T_LINE) reduce 197) ((T_LIST) reduce 197) ((T_LNUMBER) reduce 197) ((T_MATCH) reduce 197) ((T_METHOD_C) reduce 197) ((T_NAME_FULLY_QUALIFIED) reduce 197) ((T_NAME_QUALIFIED) reduce 197) ((T_NAME_RELATIVE) reduce 197) ((T_NEW) reduce 197) ((T_NS_C) reduce 197) ((T_OBJECT_CAST) reduce 197) ((T_PRINT) reduce 197) ((T_READONLY) reduce 197) ((T_REQUIRE) reduce 197) ((T_REQUIRE_ONCE) reduce 197) ((T_RETURN) reduce 197) ((T_START_HEREDOC) reduce 197) ((T_STATIC) reduce 197) ((T_STRING) reduce 197) ((T_STRING_CAST) reduce 197) ((T_SWITCH) reduce 197) ((T_THROW) reduce 197) ((T_TRAIT) reduce 197) ((T_TRAIT_C) reduce 197) ((T_TRY) reduce 197) ((T_UNSET) reduce 197) ((T_UNSET_CAST) reduce 197) ((T_VARIABLE) reduce 197) ((T_WHILE) reduce 197) ((T_YIELD) reduce 197) ((T_YIELD_FROM) reduce 197) (("[") reduce 197) (("`") reduce 197) (("{") reduce 197) (("~") reduce 197)) 24316 ((("!") reduce 151) (("\"") reduce 151) (("$") reduce 151) (("(") reduce 151) (("+") reduce 151) (("-") reduce 151) ((";") reduce 151) (("@") reduce 151) ((T_ABSTRACT) reduce 151) ((T_ARRAY) reduce 151) ((T_ARRAY_CAST) reduce 151) ((T_ATTRIBUTE) reduce 151) ((T_BOOL_CAST) reduce 151) ((T_BREAK) reduce 151) ((T_CLASS) reduce 151) ((T_CLASS_C) reduce 151) ((T_CLONE) reduce 151) ((T_CONSTANT_ENCAPSED_STRING) reduce 151) ((T_CONTINUE) reduce 151) ((T_DEC) reduce 151) ((T_DECLARE) reduce 151) ((T_DIR) reduce 151) ((T_DNUMBER) reduce 151) ((T_DO) reduce 151) ((T_DOUBLE_CAST) reduce 151) ((T_ECHO) reduce 151) ((T_EMPTY) reduce 151) ((T_ENDIF) reduce 151) ((T_ENUM) reduce 151) ((T_EVAL) reduce 151) ((T_EXIT) reduce 151) ((T_FILE) reduce 151) ((T_FINAL) reduce 151) ((T_FN) reduce 151) ((T_FOR) reduce 151) ((T_FOREACH) reduce 151) ((T_FUNCTION) reduce 151) ((T_FUNC_C) reduce 151) ((T_GLOBAL) reduce 151) ((T_GOTO) reduce 151) ((T_HALT_COMPILER) reduce 151) ((T_IF) reduce 151) ((T_INC) reduce 151) ((T_INCLUDE) reduce 151) ((T_INCLUDE_ONCE) reduce 151) ((T_INLINE_HTML) reduce 151) ((T_INTERFACE) reduce 151) ((T_INT_CAST) reduce 151) ((T_ISSET) reduce 151) ((T_LINE) reduce 151) ((T_LIST) reduce 151) ((T_LNUMBER) reduce 151) ((T_MATCH) reduce 151) ((T_METHOD_C) reduce 151) ((T_NAME_FULLY_QUALIFIED) reduce 151) ((T_NAME_QUALIFIED) reduce 151) ((T_NAME_RELATIVE) reduce 151) ((T_NEW) reduce 151) ((T_NS_C) reduce 151) ((T_OBJECT_CAST) reduce 151) ((T_PRINT) reduce 151) ((T_READONLY) reduce 151) ((T_REQUIRE) reduce 151) ((T_REQUIRE_ONCE) reduce 151) ((T_RETURN) reduce 151) ((T_START_HEREDOC) reduce 151) ((T_STATIC) reduce 151) ((T_STRING) reduce 151) ((T_STRING_CAST) reduce 151) ((T_SWITCH) reduce 151) ((T_THROW) reduce 151) ((T_TRAIT) reduce 151) ((T_TRAIT_C) reduce 151) ((T_TRY) reduce 151) ((T_UNSET) reduce 151) ((T_UNSET_CAST) reduce 151) ((T_VARIABLE) reduce 151) ((T_WHILE) reduce 151) ((T_YIELD) reduce 151) ((T_YIELD_FROM) reduce 151) (("[") reduce 151) (("`") reduce 151) (("{") reduce 151) (("~") reduce 151)) 24320 ((("!") reduce 221) (("\"") reduce 221) (("$") reduce 221) (("(") reduce 221) (("+") reduce 221) (("-") reduce 221) ((";") reduce 221) (("@") reduce 221) ((T_ABSTRACT) reduce 221) ((T_ARRAY) reduce 221) ((T_ARRAY_CAST) reduce 221) ((T_ATTRIBUTE) reduce 221) ((T_BOOL_CAST) reduce 221) ((T_BREAK) reduce 221) ((T_CLASS) reduce 221) ((T_CLASS_C) reduce 221) ((T_CLONE) reduce 221) ((T_CONSTANT_ENCAPSED_STRING) reduce 221) ((T_CONTINUE) reduce 221) ((T_DEC) reduce 221) ((T_DECLARE) reduce 221) ((T_DIR) reduce 221) ((T_DNUMBER) reduce 221) ((T_DO) reduce 221) ((T_DOUBLE_CAST) reduce 221) ((T_ECHO) reduce 221) ((T_EMPTY) reduce 221) ((T_ENDIF) reduce 221) ((T_ENUM) reduce 221) ((T_EVAL) reduce 221) ((T_EXIT) reduce 221) ((T_FILE) reduce 221) ((T_FINAL) reduce 221) ((T_FN) reduce 221) ((T_FOR) reduce 221) ((T_FOREACH) reduce 221) ((T_FUNCTION) reduce 221) ((T_FUNC_C) reduce 221) ((T_GLOBAL) reduce 221) ((T_GOTO) reduce 221) ((T_HALT_COMPILER) reduce 221) ((T_IF) reduce 221) ((T_INC) reduce 221) ((T_INCLUDE) reduce 221) ((T_INCLUDE_ONCE) reduce 221) ((T_INLINE_HTML) reduce 221) ((T_INTERFACE) reduce 221) ((T_INT_CAST) reduce 221) ((T_ISSET) reduce 221) ((T_LINE) reduce 221) ((T_LIST) reduce 221) ((T_LNUMBER) reduce 221) ((T_MATCH) reduce 221) ((T_METHOD_C) reduce 221) ((T_NAME_FULLY_QUALIFIED) reduce 221) ((T_NAME_QUALIFIED) reduce 221) ((T_NAME_RELATIVE) reduce 221) ((T_NEW) reduce 221) ((T_NS_C) reduce 221) ((T_OBJECT_CAST) reduce 221) ((T_PRINT) reduce 221) ((T_READONLY) reduce 221) ((T_REQUIRE) reduce 221) ((T_REQUIRE_ONCE) reduce 221) ((T_RETURN) reduce 221) ((T_START_HEREDOC) reduce 221) ((T_STATIC) reduce 221) ((T_STRING) reduce 221) ((T_STRING_CAST) reduce 221) ((T_SWITCH) reduce 221) ((T_THROW) reduce 221) ((T_TRAIT) reduce 221) ((T_TRAIT_C) reduce 221) ((T_TRY) reduce 221) ((T_UNSET) reduce 221) ((T_UNSET_CAST) reduce 221) ((T_VARIABLE) reduce 221) ((T_WHILE) reduce 221) ((T_YIELD) reduce 221) ((T_YIELD_FROM) reduce 221) (("[") reduce 221) (("`") reduce 221) (("{") reduce 221) (("~") reduce 221)) 24322 ((("!") reduce 222) (("\"") reduce 222) (("$") reduce 222) (("(") reduce 222) (("+") reduce 222) (("-") reduce 222) ((";") reduce 222) (("@") reduce 222) ((T_ABSTRACT) reduce 222) ((T_ARRAY) reduce 222) ((T_ARRAY_CAST) reduce 222) ((T_ATTRIBUTE) reduce 222) ((T_BOOL_CAST) reduce 222) ((T_BREAK) reduce 222) ((T_CLASS) reduce 222) ((T_CLASS_C) reduce 222) ((T_CLONE) reduce 222) ((T_CONSTANT_ENCAPSED_STRING) reduce 222) ((T_CONTINUE) reduce 222) ((T_DEC) reduce 222) ((T_DECLARE) reduce 222) ((T_DIR) reduce 222) ((T_DNUMBER) reduce 222) ((T_DO) reduce 222) ((T_DOUBLE_CAST) reduce 222) ((T_ECHO) reduce 222) ((T_EMPTY) reduce 222) ((T_ENDIF) reduce 222) ((T_ENUM) reduce 222) ((T_EVAL) reduce 222) ((T_EXIT) reduce 222) ((T_FILE) reduce 222) ((T_FINAL) reduce 222) ((T_FN) reduce 222) ((T_FOR) reduce 222) ((T_FOREACH) reduce 222) ((T_FUNCTION) reduce 222) ((T_FUNC_C) reduce 222) ((T_GLOBAL) reduce 222) ((T_GOTO) reduce 222) ((T_HALT_COMPILER) reduce 222) ((T_IF) reduce 222) ((T_INC) reduce 222) ((T_INCLUDE) reduce 222) ((T_INCLUDE_ONCE) reduce 222) ((T_INLINE_HTML) reduce 222) ((T_INTERFACE) reduce 222) ((T_INT_CAST) reduce 222) ((T_ISSET) reduce 222) ((T_LINE) reduce 222) ((T_LIST) reduce 222) ((T_LNUMBER) reduce 222) ((T_MATCH) reduce 222) ((T_METHOD_C) reduce 222) ((T_NAME_FULLY_QUALIFIED) reduce 222) ((T_NAME_QUALIFIED) reduce 222) ((T_NAME_RELATIVE) reduce 222) ((T_NEW) reduce 222) ((T_NS_C) reduce 222) ((T_OBJECT_CAST) reduce 222) ((T_PRINT) reduce 222) ((T_READONLY) reduce 222) ((T_REQUIRE) reduce 222) ((T_REQUIRE_ONCE) reduce 222) ((T_RETURN) reduce 222) ((T_START_HEREDOC) reduce 222) ((T_STATIC) reduce 222) ((T_STRING) reduce 222) ((T_STRING_CAST) reduce 222) ((T_SWITCH) reduce 222) ((T_THROW) reduce 222) ((T_TRAIT) reduce 222) ((T_TRAIT_C) reduce 222) ((T_TRY) reduce 222) ((T_UNSET) reduce 222) ((T_UNSET_CAST) reduce 222) ((T_VARIABLE) reduce 222) ((T_WHILE) reduce 222) ((T_YIELD) reduce 222) ((T_YIELD_FROM) reduce 222) (("[") reduce 222) (("`") reduce 222) (("{") reduce 222) (("~") reduce 222)) 24326 ((("!") reduce 223) (("\"") reduce 223) (("$") reduce 223) (("(") reduce 223) (("+") reduce 223) (("-") reduce 223) ((";") reduce 223) (("@") reduce 223) ((T_ABSTRACT) reduce 223) ((T_ARRAY) reduce 223) ((T_ARRAY_CAST) reduce 223) ((T_ATTRIBUTE) reduce 223) ((T_BOOL_CAST) reduce 223) ((T_BREAK) reduce 223) ((T_CLASS) reduce 223) ((T_CLASS_C) reduce 223) ((T_CLONE) reduce 223) ((T_CONSTANT_ENCAPSED_STRING) reduce 223) ((T_CONTINUE) reduce 223) ((T_DEC) reduce 223) ((T_DECLARE) reduce 223) ((T_DIR) reduce 223) ((T_DNUMBER) reduce 223) ((T_DO) reduce 223) ((T_DOUBLE_CAST) reduce 223) ((T_ECHO) reduce 223) ((T_EMPTY) reduce 223) ((T_ENDIF) reduce 223) ((T_ENUM) reduce 223) ((T_EVAL) reduce 223) ((T_EXIT) reduce 223) ((T_FILE) reduce 223) ((T_FINAL) reduce 223) ((T_FN) reduce 223) ((T_FOR) reduce 223) ((T_FOREACH) reduce 223) ((T_FUNCTION) reduce 223) ((T_FUNC_C) reduce 223) ((T_GLOBAL) reduce 223) ((T_GOTO) reduce 223) ((T_HALT_COMPILER) reduce 223) ((T_IF) reduce 223) ((T_INC) reduce 223) ((T_INCLUDE) reduce 223) ((T_INCLUDE_ONCE) reduce 223) ((T_INLINE_HTML) reduce 223) ((T_INTERFACE) reduce 223) ((T_INT_CAST) reduce 223) ((T_ISSET) reduce 223) ((T_LINE) reduce 223) ((T_LIST) reduce 223) ((T_LNUMBER) reduce 223) ((T_MATCH) reduce 223) ((T_METHOD_C) reduce 223) ((T_NAME_FULLY_QUALIFIED) reduce 223) ((T_NAME_QUALIFIED) reduce 223) ((T_NAME_RELATIVE) reduce 223) ((T_NEW) reduce 223) ((T_NS_C) reduce 223) ((T_OBJECT_CAST) reduce 223) ((T_PRINT) reduce 223) ((T_READONLY) reduce 223) ((T_REQUIRE) reduce 223) ((T_REQUIRE_ONCE) reduce 223) ((T_RETURN) reduce 223) ((T_START_HEREDOC) reduce 223) ((T_STATIC) reduce 223) ((T_STRING) reduce 223) ((T_STRING_CAST) reduce 223) ((T_SWITCH) reduce 223) ((T_THROW) reduce 223) ((T_TRAIT) reduce 223) ((T_TRAIT_C) reduce 223) ((T_TRY) reduce 223) ((T_UNSET) reduce 223) ((T_UNSET_CAST) reduce 223) ((T_VARIABLE) reduce 223) ((T_WHILE) reduce 223) ((T_YIELD) reduce 223) ((T_YIELD_FROM) reduce 223) (("[") reduce 223) (("`") reduce 223) (("{") reduce 223) (("~") reduce 223)) 24329 ((("!") reduce 224) (("\"") reduce 224) (("$") reduce 224) (("(") reduce 224) (("+") reduce 224) (("-") reduce 224) ((";") reduce 224) (("@") reduce 224) ((T_ABSTRACT) reduce 224) ((T_ARRAY) reduce 224) ((T_ARRAY_CAST) reduce 224) ((T_ATTRIBUTE) reduce 224) ((T_BOOL_CAST) reduce 224) ((T_BREAK) reduce 224) ((T_CLASS) reduce 224) ((T_CLASS_C) reduce 224) ((T_CLONE) reduce 224) ((T_CONSTANT_ENCAPSED_STRING) reduce 224) ((T_CONTINUE) reduce 224) ((T_DEC) reduce 224) ((T_DECLARE) reduce 224) ((T_DIR) reduce 224) ((T_DNUMBER) reduce 224) ((T_DO) reduce 224) ((T_DOUBLE_CAST) reduce 224) ((T_ECHO) reduce 224) ((T_EMPTY) reduce 224) ((T_ENDIF) reduce 224) ((T_ENUM) reduce 224) ((T_EVAL) reduce 224) ((T_EXIT) reduce 224) ((T_FILE) reduce 224) ((T_FINAL) reduce 224) ((T_FN) reduce 224) ((T_FOR) reduce 224) ((T_FOREACH) reduce 224) ((T_FUNCTION) reduce 224) ((T_FUNC_C) reduce 224) ((T_GLOBAL) reduce 224) ((T_GOTO) reduce 224) ((T_HALT_COMPILER) reduce 224) ((T_IF) reduce 224) ((T_INC) reduce 224) ((T_INCLUDE) reduce 224) ((T_INCLUDE_ONCE) reduce 224) ((T_INLINE_HTML) reduce 224) ((T_INTERFACE) reduce 224) ((T_INT_CAST) reduce 224) ((T_ISSET) reduce 224) ((T_LINE) reduce 224) ((T_LIST) reduce 224) ((T_LNUMBER) reduce 224) ((T_MATCH) reduce 224) ((T_METHOD_C) reduce 224) ((T_NAME_FULLY_QUALIFIED) reduce 224) ((T_NAME_QUALIFIED) reduce 224) ((T_NAME_RELATIVE) reduce 224) ((T_NEW) reduce 224) ((T_NS_C) reduce 224) ((T_OBJECT_CAST) reduce 224) ((T_PRINT) reduce 224) ((T_READONLY) reduce 224) ((T_REQUIRE) reduce 224) ((T_REQUIRE_ONCE) reduce 224) ((T_RETURN) reduce 224) ((T_START_HEREDOC) reduce 224) ((T_STATIC) reduce 224) ((T_STRING) reduce 224) ((T_STRING_CAST) reduce 224) ((T_SWITCH) reduce 224) ((T_THROW) reduce 224) ((T_TRAIT) reduce 224) ((T_TRAIT_C) reduce 224) ((T_TRY) reduce 224) ((T_UNSET) reduce 224) ((T_UNSET_CAST) reduce 224) ((T_VARIABLE) reduce 224) ((T_WHILE) reduce 224) ((T_YIELD) reduce 224) ((T_YIELD_FROM) reduce 224) (("[") reduce 224) (("`") reduce 224) (("{") reduce 224) (("~") reduce 224)) 24330 ((("!") reduce 167) (("\"") reduce 167) (("$") reduce 167) (("(") reduce 167) (("+") reduce 167) (("-") reduce 167) ((";") reduce 167) (("@") reduce 167) ((T_ABSTRACT) reduce 167) ((T_ARRAY) reduce 167) ((T_ARRAY_CAST) reduce 167) ((T_ATTRIBUTE) reduce 167) ((T_BOOL_CAST) reduce 167) ((T_BREAK) reduce 167) ((T_CLASS) reduce 167) ((T_CLASS_C) reduce 167) ((T_CLONE) reduce 167) ((T_CONSTANT_ENCAPSED_STRING) reduce 167) ((T_CONTINUE) reduce 167) ((T_DEC) reduce 167) ((T_DECLARE) reduce 167) ((T_DIR) reduce 167) ((T_DNUMBER) reduce 167) ((T_DO) reduce 167) ((T_DOUBLE_CAST) reduce 167) ((T_ECHO) reduce 167) ((T_EMPTY) reduce 167) ((T_ENDIF) reduce 167) ((T_ENUM) reduce 167) ((T_EVAL) reduce 167) ((T_EXIT) reduce 167) ((T_FILE) reduce 167) ((T_FINAL) reduce 167) ((T_FN) reduce 167) ((T_FOR) reduce 167) ((T_FOREACH) reduce 167) ((T_FUNCTION) reduce 167) ((T_FUNC_C) reduce 167) ((T_GLOBAL) reduce 167) ((T_GOTO) reduce 167) ((T_HALT_COMPILER) reduce 167) ((T_IF) reduce 167) ((T_INC) reduce 167) ((T_INCLUDE) reduce 167) ((T_INCLUDE_ONCE) reduce 167) ((T_INLINE_HTML) reduce 167) ((T_INTERFACE) reduce 167) ((T_INT_CAST) reduce 167) ((T_ISSET) reduce 167) ((T_LINE) reduce 167) ((T_LIST) reduce 167) ((T_LNUMBER) reduce 167) ((T_MATCH) reduce 167) ((T_METHOD_C) reduce 167) ((T_NAME_FULLY_QUALIFIED) reduce 167) ((T_NAME_QUALIFIED) reduce 167) ((T_NAME_RELATIVE) reduce 167) ((T_NEW) reduce 167) ((T_NS_C) reduce 167) ((T_OBJECT_CAST) reduce 167) ((T_PRINT) reduce 167) ((T_READONLY) reduce 167) ((T_REQUIRE) reduce 167) ((T_REQUIRE_ONCE) reduce 167) ((T_RETURN) reduce 167) ((T_START_HEREDOC) reduce 167) ((T_STATIC) reduce 167) ((T_STRING) reduce 167) ((T_STRING_CAST) reduce 167) ((T_SWITCH) reduce 167) ((T_THROW) reduce 167) ((T_TRAIT) reduce 167) ((T_TRAIT_C) reduce 167) ((T_TRY) reduce 167) ((T_UNSET) reduce 167) ((T_UNSET_CAST) reduce 167) ((T_VARIABLE) reduce 167) ((T_WHILE) reduce 167) ((T_YIELD) reduce 167) ((T_YIELD_FROM) reduce 167) (("[") reduce 167) (("`") reduce 167) (("{") reduce 167) (("~") reduce 167)) 24332 ((("!") reduce 156) (("\"") reduce 156) (("$") reduce 156) (("(") reduce 156) (("+") reduce 156) (("-") reduce 156) ((";") reduce 156) (("@") reduce 156) ((T_ABSTRACT) reduce 156) ((T_ARRAY) reduce 156) ((T_ARRAY_CAST) reduce 156) ((T_ATTRIBUTE) reduce 156) ((T_BOOL_CAST) reduce 156) ((T_BREAK) reduce 156) ((T_CLASS) reduce 156) ((T_CLASS_C) reduce 156) ((T_CLONE) reduce 156) ((T_CONSTANT_ENCAPSED_STRING) reduce 156) ((T_CONTINUE) reduce 156) ((T_DEC) reduce 156) ((T_DECLARE) reduce 156) ((T_DIR) reduce 156) ((T_DNUMBER) reduce 156) ((T_DO) reduce 156) ((T_DOUBLE_CAST) reduce 156) ((T_ECHO) reduce 156) ((T_EMPTY) reduce 156) ((T_ENDIF) reduce 156) ((T_ENUM) reduce 156) ((T_EVAL) reduce 156) ((T_EXIT) reduce 156) ((T_FILE) reduce 156) ((T_FINAL) reduce 156) ((T_FN) reduce 156) ((T_FOR) reduce 156) ((T_FOREACH) reduce 156) ((T_FUNCTION) reduce 156) ((T_FUNC_C) reduce 156) ((T_GLOBAL) reduce 156) ((T_GOTO) reduce 156) ((T_HALT_COMPILER) reduce 156) ((T_IF) reduce 156) ((T_INC) reduce 156) ((T_INCLUDE) reduce 156) ((T_INCLUDE_ONCE) reduce 156) ((T_INLINE_HTML) reduce 156) ((T_INTERFACE) reduce 156) ((T_INT_CAST) reduce 156) ((T_ISSET) reduce 156) ((T_LINE) reduce 156) ((T_LIST) reduce 156) ((T_LNUMBER) reduce 156) ((T_MATCH) reduce 156) ((T_METHOD_C) reduce 156) ((T_NAME_FULLY_QUALIFIED) reduce 156) ((T_NAME_QUALIFIED) reduce 156) ((T_NAME_RELATIVE) reduce 156) ((T_NEW) reduce 156) ((T_NS_C) reduce 156) ((T_OBJECT_CAST) reduce 156) ((T_PRINT) reduce 156) ((T_READONLY) reduce 156) ((T_REQUIRE) reduce 156) ((T_REQUIRE_ONCE) reduce 156) ((T_RETURN) reduce 156) ((T_START_HEREDOC) reduce 156) ((T_STATIC) reduce 156) ((T_STRING) reduce 156) ((T_STRING_CAST) reduce 156) ((T_SWITCH) reduce 156) ((T_THROW) reduce 156) ((T_TRAIT) reduce 156) ((T_TRAIT_C) reduce 156) ((T_TRY) reduce 156) ((T_UNSET) reduce 156) ((T_UNSET_CAST) reduce 156) ((T_VARIABLE) reduce 156) ((T_WHILE) reduce 156) ((T_YIELD) reduce 156) ((T_YIELD_FROM) reduce 156) (("[") reduce 156) (("`") reduce 156) (("{") reduce 156) (("~") reduce 156)) 24334 ((("!") reduce 154) (("\"") reduce 154) (("$") reduce 154) (("(") reduce 154) (("+") reduce 154) (("-") reduce 154) ((";") reduce 154) (("@") reduce 154) ((T_ABSTRACT) reduce 154) ((T_ARRAY) reduce 154) ((T_ARRAY_CAST) reduce 154) ((T_ATTRIBUTE) reduce 154) ((T_BOOL_CAST) reduce 154) ((T_BREAK) reduce 154) ((T_CLASS) reduce 154) ((T_CLASS_C) reduce 154) ((T_CLONE) reduce 154) ((T_CONSTANT_ENCAPSED_STRING) reduce 154) ((T_CONTINUE) reduce 154) ((T_DEC) reduce 154) ((T_DECLARE) reduce 154) ((T_DIR) reduce 154) ((T_DNUMBER) reduce 154) ((T_DO) reduce 154) ((T_DOUBLE_CAST) reduce 154) ((T_ECHO) reduce 154) ((T_EMPTY) reduce 154) ((T_ENDIF) reduce 154) ((T_ENUM) reduce 154) ((T_EVAL) reduce 154) ((T_EXIT) reduce 154) ((T_FILE) reduce 154) ((T_FINAL) reduce 154) ((T_FN) reduce 154) ((T_FOR) reduce 154) ((T_FOREACH) reduce 154) ((T_FUNCTION) reduce 154) ((T_FUNC_C) reduce 154) ((T_GLOBAL) reduce 154) ((T_GOTO) reduce 154) ((T_HALT_COMPILER) reduce 154) ((T_IF) reduce 154) ((T_INC) reduce 154) ((T_INCLUDE) reduce 154) ((T_INCLUDE_ONCE) reduce 154) ((T_INLINE_HTML) reduce 154) ((T_INTERFACE) reduce 154) ((T_INT_CAST) reduce 154) ((T_ISSET) reduce 154) ((T_LINE) reduce 154) ((T_LIST) reduce 154) ((T_LNUMBER) reduce 154) ((T_MATCH) reduce 154) ((T_METHOD_C) reduce 154) ((T_NAME_FULLY_QUALIFIED) reduce 154) ((T_NAME_QUALIFIED) reduce 154) ((T_NAME_RELATIVE) reduce 154) ((T_NEW) reduce 154) ((T_NS_C) reduce 154) ((T_OBJECT_CAST) reduce 154) ((T_PRINT) reduce 154) ((T_READONLY) reduce 154) ((T_REQUIRE) reduce 154) ((T_REQUIRE_ONCE) reduce 154) ((T_RETURN) reduce 154) ((T_START_HEREDOC) reduce 154) ((T_STATIC) reduce 154) ((T_STRING) reduce 154) ((T_STRING_CAST) reduce 154) ((T_SWITCH) reduce 154) ((T_THROW) reduce 154) ((T_TRAIT) reduce 154) ((T_TRAIT_C) reduce 154) ((T_TRY) reduce 154) ((T_UNSET) reduce 154) ((T_UNSET_CAST) reduce 154) ((T_VARIABLE) reduce 154) ((T_WHILE) reduce 154) ((T_YIELD) reduce 154) ((T_YIELD_FROM) reduce 154) (("[") reduce 154) (("`") reduce 154) (("{") reduce 154) (("~") reduce 154)) 24340 ((("!") reduce 198) (("\"") reduce 198) (("$") reduce 198) (("(") reduce 198) (("+") reduce 198) (("-") reduce 198) ((";") reduce 198) (("@") reduce 198) ((T_ABSTRACT) reduce 198) ((T_ARRAY) reduce 198) ((T_ARRAY_CAST) reduce 198) ((T_ATTRIBUTE) reduce 198) ((T_BOOL_CAST) reduce 198) ((T_BREAK) reduce 198) ((T_CLASS) reduce 198) ((T_CLASS_C) reduce 198) ((T_CLONE) reduce 198) ((T_CONSTANT_ENCAPSED_STRING) reduce 198) ((T_CONTINUE) reduce 198) ((T_DEC) reduce 198) ((T_DECLARE) reduce 198) ((T_DIR) reduce 198) ((T_DNUMBER) reduce 198) ((T_DO) reduce 198) ((T_DOUBLE_CAST) reduce 198) ((T_ECHO) reduce 198) ((T_EMPTY) reduce 198) ((T_ENDIF) reduce 198) ((T_ENUM) reduce 198) ((T_EVAL) reduce 198) ((T_EXIT) reduce 198) ((T_FILE) reduce 198) ((T_FINAL) reduce 198) ((T_FN) reduce 198) ((T_FOR) reduce 198) ((T_FOREACH) reduce 198) ((T_FUNCTION) reduce 198) ((T_FUNC_C) reduce 198) ((T_GLOBAL) reduce 198) ((T_GOTO) reduce 198) ((T_HALT_COMPILER) reduce 198) ((T_IF) reduce 198) ((T_INC) reduce 198) ((T_INCLUDE) reduce 198) ((T_INCLUDE_ONCE) reduce 198) ((T_INLINE_HTML) reduce 198) ((T_INTERFACE) reduce 198) ((T_INT_CAST) reduce 198) ((T_ISSET) reduce 198) ((T_LINE) reduce 198) ((T_LIST) reduce 198) ((T_LNUMBER) reduce 198) ((T_MATCH) reduce 198) ((T_METHOD_C) reduce 198) ((T_NAME_FULLY_QUALIFIED) reduce 198) ((T_NAME_QUALIFIED) reduce 198) ((T_NAME_RELATIVE) reduce 198) ((T_NEW) reduce 198) ((T_NS_C) reduce 198) ((T_OBJECT_CAST) reduce 198) ((T_PRINT) reduce 198) ((T_READONLY) reduce 198) ((T_REQUIRE) reduce 198) ((T_REQUIRE_ONCE) reduce 198) ((T_RETURN) reduce 198) ((T_START_HEREDOC) reduce 198) ((T_STATIC) reduce 198) ((T_STRING) reduce 198) ((T_STRING_CAST) reduce 198) ((T_SWITCH) reduce 198) ((T_THROW) reduce 198) ((T_TRAIT) reduce 198) ((T_TRAIT_C) reduce 198) ((T_TRY) reduce 198) ((T_UNSET) reduce 198) ((T_UNSET_CAST) reduce 198) ((T_VARIABLE) reduce 198) ((T_WHILE) reduce 198) ((T_YIELD) reduce 198) ((T_YIELD_FROM) reduce 198) (("[") reduce 198) (("`") reduce 198) (("{") reduce 198) (("~") reduce 198)) 24343 ((("!") reduce 144) (("\"") reduce 144) (("$") reduce 144) (("(") reduce 144) (("+") reduce 144) (("-") reduce 144) ((";") reduce 144) (("@") reduce 144) ((T_ABSTRACT) reduce 144) ((T_ARRAY) reduce 144) ((T_ARRAY_CAST) reduce 144) ((T_ATTRIBUTE) reduce 144) ((T_BOOL_CAST) reduce 144) ((T_BREAK) reduce 144) ((T_CLASS) reduce 144) ((T_CLASS_C) reduce 144) ((T_CLONE) reduce 144) ((T_CONSTANT_ENCAPSED_STRING) reduce 144) ((T_CONTINUE) reduce 144) ((T_DEC) reduce 144) ((T_DECLARE) reduce 144) ((T_DIR) reduce 144) ((T_DNUMBER) reduce 144) ((T_DO) reduce 144) ((T_DOUBLE_CAST) reduce 144) ((T_ECHO) reduce 144) ((T_EMPTY) reduce 144) ((T_ENDIF) reduce 144) ((T_ENUM) reduce 144) ((T_EVAL) reduce 144) ((T_EXIT) reduce 144) ((T_FILE) reduce 144) ((T_FINAL) reduce 144) ((T_FN) reduce 144) ((T_FOR) reduce 144) ((T_FOREACH) reduce 144) ((T_FUNCTION) reduce 144) ((T_FUNC_C) reduce 144) ((T_GLOBAL) reduce 144) ((T_GOTO) reduce 144) ((T_HALT_COMPILER) reduce 144) ((T_IF) reduce 144) ((T_INC) reduce 144) ((T_INCLUDE) reduce 144) ((T_INCLUDE_ONCE) reduce 144) ((T_INLINE_HTML) reduce 144) ((T_INTERFACE) reduce 144) ((T_INT_CAST) reduce 144) ((T_ISSET) reduce 144) ((T_LINE) reduce 144) ((T_LIST) reduce 144) ((T_LNUMBER) reduce 144) ((T_MATCH) reduce 144) ((T_METHOD_C) reduce 144) ((T_NAME_FULLY_QUALIFIED) reduce 144) ((T_NAME_QUALIFIED) reduce 144) ((T_NAME_RELATIVE) reduce 144) ((T_NEW) reduce 144) ((T_NS_C) reduce 144) ((T_OBJECT_CAST) reduce 144) ((T_PRINT) reduce 144) ((T_READONLY) reduce 144) ((T_REQUIRE) reduce 144) ((T_REQUIRE_ONCE) reduce 144) ((T_RETURN) reduce 144) ((T_START_HEREDOC) reduce 144) ((T_STATIC) reduce 144) ((T_STRING) reduce 144) ((T_STRING_CAST) reduce 144) ((T_SWITCH) reduce 144) ((T_THROW) reduce 144) ((T_TRAIT) reduce 144) ((T_TRAIT_C) reduce 144) ((T_TRY) reduce 144) ((T_UNSET) reduce 144) ((T_UNSET_CAST) reduce 144) ((T_VARIABLE) reduce 144) ((T_WHILE) reduce 144) ((T_YIELD) reduce 144) ((T_YIELD_FROM) reduce 144) (("[") reduce 144) (("`") reduce 144) (("{") reduce 144) (("~") reduce 144)) 24345 ((("!") reduce 166) (("\"") reduce 166) (("$") reduce 166) (("(") reduce 166) (("+") reduce 166) (("-") reduce 166) ((";") reduce 166) (("@") reduce 166) ((T_ABSTRACT) reduce 166) ((T_ARRAY) reduce 166) ((T_ARRAY_CAST) reduce 166) ((T_ATTRIBUTE) reduce 166) ((T_BOOL_CAST) reduce 166) ((T_BREAK) reduce 166) ((T_CLASS) reduce 166) ((T_CLASS_C) reduce 166) ((T_CLONE) reduce 166) ((T_CONSTANT_ENCAPSED_STRING) reduce 166) ((T_CONTINUE) reduce 166) ((T_DEC) reduce 166) ((T_DECLARE) reduce 166) ((T_DIR) reduce 166) ((T_DNUMBER) reduce 166) ((T_DO) reduce 166) ((T_DOUBLE_CAST) reduce 166) ((T_ECHO) reduce 166) ((T_EMPTY) reduce 166) ((T_ENDIF) reduce 166) ((T_ENUM) reduce 166) ((T_EVAL) reduce 166) ((T_EXIT) reduce 166) ((T_FILE) reduce 166) ((T_FINAL) reduce 166) ((T_FN) reduce 166) ((T_FOR) reduce 166) ((T_FOREACH) reduce 166) ((T_FUNCTION) reduce 166) ((T_FUNC_C) reduce 166) ((T_GLOBAL) reduce 166) ((T_GOTO) reduce 166) ((T_HALT_COMPILER) reduce 166) ((T_IF) reduce 166) ((T_INC) reduce 166) ((T_INCLUDE) reduce 166) ((T_INCLUDE_ONCE) reduce 166) ((T_INLINE_HTML) reduce 166) ((T_INTERFACE) reduce 166) ((T_INT_CAST) reduce 166) ((T_ISSET) reduce 166) ((T_LINE) reduce 166) ((T_LIST) reduce 166) ((T_LNUMBER) reduce 166) ((T_MATCH) reduce 166) ((T_METHOD_C) reduce 166) ((T_NAME_FULLY_QUALIFIED) reduce 166) ((T_NAME_QUALIFIED) reduce 166) ((T_NAME_RELATIVE) reduce 166) ((T_NEW) reduce 166) ((T_NS_C) reduce 166) ((T_OBJECT_CAST) reduce 166) ((T_PRINT) reduce 166) ((T_READONLY) reduce 166) ((T_REQUIRE) reduce 166) ((T_REQUIRE_ONCE) reduce 166) ((T_RETURN) reduce 166) ((T_START_HEREDOC) reduce 166) ((T_STATIC) reduce 166) ((T_STRING) reduce 166) ((T_STRING_CAST) reduce 166) ((T_SWITCH) reduce 166) ((T_THROW) reduce 166) ((T_TRAIT) reduce 166) ((T_TRAIT_C) reduce 166) ((T_TRY) reduce 166) ((T_UNSET) reduce 166) ((T_UNSET_CAST) reduce 166) ((T_VARIABLE) reduce 166) ((T_WHILE) reduce 166) ((T_YIELD) reduce 166) ((T_YIELD_FROM) reduce 166) (("[") reduce 166) (("`") reduce 166) (("{") reduce 166) (("~") reduce 166)) 24347 ((("!") reduce 155) (("\"") reduce 155) (("$") reduce 155) (("(") reduce 155) (("+") reduce 155) (("-") reduce 155) ((";") reduce 155) (("@") reduce 155) ((T_ABSTRACT) reduce 155) ((T_ARRAY) reduce 155) ((T_ARRAY_CAST) reduce 155) ((T_ATTRIBUTE) reduce 155) ((T_BOOL_CAST) reduce 155) ((T_BREAK) reduce 155) ((T_CLASS) reduce 155) ((T_CLASS_C) reduce 155) ((T_CLONE) reduce 155) ((T_CONSTANT_ENCAPSED_STRING) reduce 155) ((T_CONTINUE) reduce 155) ((T_DEC) reduce 155) ((T_DECLARE) reduce 155) ((T_DIR) reduce 155) ((T_DNUMBER) reduce 155) ((T_DO) reduce 155) ((T_DOUBLE_CAST) reduce 155) ((T_ECHO) reduce 155) ((T_EMPTY) reduce 155) ((T_ENDIF) reduce 155) ((T_ENUM) reduce 155) ((T_EVAL) reduce 155) ((T_EXIT) reduce 155) ((T_FILE) reduce 155) ((T_FINAL) reduce 155) ((T_FN) reduce 155) ((T_FOR) reduce 155) ((T_FOREACH) reduce 155) ((T_FUNCTION) reduce 155) ((T_FUNC_C) reduce 155) ((T_GLOBAL) reduce 155) ((T_GOTO) reduce 155) ((T_HALT_COMPILER) reduce 155) ((T_IF) reduce 155) ((T_INC) reduce 155) ((T_INCLUDE) reduce 155) ((T_INCLUDE_ONCE) reduce 155) ((T_INLINE_HTML) reduce 155) ((T_INTERFACE) reduce 155) ((T_INT_CAST) reduce 155) ((T_ISSET) reduce 155) ((T_LINE) reduce 155) ((T_LIST) reduce 155) ((T_LNUMBER) reduce 155) ((T_MATCH) reduce 155) ((T_METHOD_C) reduce 155) ((T_NAME_FULLY_QUALIFIED) reduce 155) ((T_NAME_QUALIFIED) reduce 155) ((T_NAME_RELATIVE) reduce 155) ((T_NEW) reduce 155) ((T_NS_C) reduce 155) ((T_OBJECT_CAST) reduce 155) ((T_PRINT) reduce 155) ((T_READONLY) reduce 155) ((T_REQUIRE) reduce 155) ((T_REQUIRE_ONCE) reduce 155) ((T_RETURN) reduce 155) ((T_START_HEREDOC) reduce 155) ((T_STATIC) reduce 155) ((T_STRING) reduce 155) ((T_STRING_CAST) reduce 155) ((T_SWITCH) reduce 155) ((T_THROW) reduce 155) ((T_TRAIT) reduce 155) ((T_TRAIT_C) reduce 155) ((T_TRY) reduce 155) ((T_UNSET) reduce 155) ((T_UNSET_CAST) reduce 155) ((T_VARIABLE) reduce 155) ((T_WHILE) reduce 155) ((T_YIELD) reduce 155) ((T_YIELD_FROM) reduce 155) (("[") reduce 155) (("`") reduce 155) (("{") reduce 155) (("~") reduce 155)) 24357 ((("!") reduce 162) (("\"") reduce 162) (("$") reduce 162) (("(") reduce 162) (("+") reduce 162) (("-") reduce 162) ((";") reduce 162) (("@") reduce 162) ((T_ABSTRACT) reduce 162) ((T_ARRAY) reduce 162) ((T_ARRAY_CAST) reduce 162) ((T_ATTRIBUTE) reduce 162) ((T_BOOL_CAST) reduce 162) ((T_BREAK) reduce 162) ((T_CLASS) reduce 162) ((T_CLASS_C) reduce 162) ((T_CLONE) reduce 162) ((T_CONSTANT_ENCAPSED_STRING) reduce 162) ((T_CONTINUE) reduce 162) ((T_DEC) reduce 162) ((T_DECLARE) reduce 162) ((T_DIR) reduce 162) ((T_DNUMBER) reduce 162) ((T_DO) reduce 162) ((T_DOUBLE_CAST) reduce 162) ((T_ECHO) reduce 162) ((T_EMPTY) reduce 162) ((T_ENDIF) reduce 162) ((T_ENUM) reduce 162) ((T_EVAL) reduce 162) ((T_EXIT) reduce 162) ((T_FILE) reduce 162) ((T_FINAL) reduce 162) ((T_FN) reduce 162) ((T_FOR) reduce 162) ((T_FOREACH) reduce 162) ((T_FUNCTION) reduce 162) ((T_FUNC_C) reduce 162) ((T_GLOBAL) reduce 162) ((T_GOTO) reduce 162) ((T_HALT_COMPILER) reduce 162) ((T_IF) reduce 162) ((T_INC) reduce 162) ((T_INCLUDE) reduce 162) ((T_INCLUDE_ONCE) reduce 162) ((T_INLINE_HTML) reduce 162) ((T_INTERFACE) reduce 162) ((T_INT_CAST) reduce 162) ((T_ISSET) reduce 162) ((T_LINE) reduce 162) ((T_LIST) reduce 162) ((T_LNUMBER) reduce 162) ((T_MATCH) reduce 162) ((T_METHOD_C) reduce 162) ((T_NAME_FULLY_QUALIFIED) reduce 162) ((T_NAME_QUALIFIED) reduce 162) ((T_NAME_RELATIVE) reduce 162) ((T_NEW) reduce 162) ((T_NS_C) reduce 162) ((T_OBJECT_CAST) reduce 162) ((T_PRINT) reduce 162) ((T_READONLY) reduce 162) ((T_REQUIRE) reduce 162) ((T_REQUIRE_ONCE) reduce 162) ((T_RETURN) reduce 162) ((T_START_HEREDOC) reduce 162) ((T_STATIC) reduce 162) ((T_STRING) reduce 162) ((T_STRING_CAST) reduce 162) ((T_SWITCH) reduce 162) ((T_THROW) reduce 162) ((T_TRAIT) reduce 162) ((T_TRAIT_C) reduce 162) ((T_TRY) reduce 162) ((T_UNSET) reduce 162) ((T_UNSET_CAST) reduce 162) ((T_VARIABLE) reduce 162) ((T_WHILE) reduce 162) ((T_YIELD) reduce 162) ((T_YIELD_FROM) reduce 162) (("[") reduce 162) (("`") reduce 162) (("{") reduce 162) (("~") reduce 162)) 24358 ((("!") reduce 217) (("\"") reduce 217) (("$") reduce 217) (("(") reduce 217) (("+") reduce 217) (("-") reduce 217) ((";") reduce 217) (("@") reduce 217) ((T_ABSTRACT) reduce 217) ((T_ARRAY) reduce 217) ((T_ARRAY_CAST) reduce 217) ((T_ATTRIBUTE) reduce 217) ((T_BOOL_CAST) reduce 217) ((T_BREAK) reduce 217) ((T_CLASS) reduce 217) ((T_CLASS_C) reduce 217) ((T_CLONE) reduce 217) ((T_CONSTANT_ENCAPSED_STRING) reduce 217) ((T_CONTINUE) reduce 217) ((T_DEC) reduce 217) ((T_DECLARE) reduce 217) ((T_DIR) reduce 217) ((T_DNUMBER) reduce 217) ((T_DO) reduce 217) ((T_DOUBLE_CAST) reduce 217) ((T_ECHO) reduce 217) ((T_EMPTY) reduce 217) ((T_ENDIF) reduce 217) ((T_ENUM) reduce 217) ((T_EVAL) reduce 217) ((T_EXIT) reduce 217) ((T_FILE) reduce 217) ((T_FINAL) reduce 217) ((T_FN) reduce 217) ((T_FOR) reduce 217) ((T_FOREACH) reduce 217) ((T_FUNCTION) reduce 217) ((T_FUNC_C) reduce 217) ((T_GLOBAL) reduce 217) ((T_GOTO) reduce 217) ((T_HALT_COMPILER) reduce 217) ((T_IF) reduce 217) ((T_INC) reduce 217) ((T_INCLUDE) reduce 217) ((T_INCLUDE_ONCE) reduce 217) ((T_INLINE_HTML) reduce 217) ((T_INTERFACE) reduce 217) ((T_INT_CAST) reduce 217) ((T_ISSET) reduce 217) ((T_LINE) reduce 217) ((T_LIST) reduce 217) ((T_LNUMBER) reduce 217) ((T_MATCH) reduce 217) ((T_METHOD_C) reduce 217) ((T_NAME_FULLY_QUALIFIED) reduce 217) ((T_NAME_QUALIFIED) reduce 217) ((T_NAME_RELATIVE) reduce 217) ((T_NEW) reduce 217) ((T_NS_C) reduce 217) ((T_OBJECT_CAST) reduce 217) ((T_PRINT) reduce 217) ((T_READONLY) reduce 217) ((T_REQUIRE) reduce 217) ((T_REQUIRE_ONCE) reduce 217) ((T_RETURN) reduce 217) ((T_START_HEREDOC) reduce 217) ((T_STATIC) reduce 217) ((T_STRING) reduce 217) ((T_STRING_CAST) reduce 217) ((T_SWITCH) reduce 217) ((T_THROW) reduce 217) ((T_TRAIT) reduce 217) ((T_TRAIT_C) reduce 217) ((T_TRY) reduce 217) ((T_UNSET) reduce 217) ((T_UNSET_CAST) reduce 217) ((T_VARIABLE) reduce 217) ((T_WHILE) reduce 217) ((T_YIELD) reduce 217) ((T_YIELD_FROM) reduce 217) (("[") reduce 217) (("`") reduce 217) (("{") reduce 217) (("~") reduce 217)) 24361 ((("!") reduce 218) (("\"") reduce 218) (("$") reduce 218) (("(") reduce 218) (("+") reduce 218) (("-") reduce 218) ((";") reduce 218) (("@") reduce 218) ((T_ABSTRACT) reduce 218) ((T_ARRAY) reduce 218) ((T_ARRAY_CAST) reduce 218) ((T_ATTRIBUTE) reduce 218) ((T_BOOL_CAST) reduce 218) ((T_BREAK) reduce 218) ((T_CLASS) reduce 218) ((T_CLASS_C) reduce 218) ((T_CLONE) reduce 218) ((T_CONSTANT_ENCAPSED_STRING) reduce 218) ((T_CONTINUE) reduce 218) ((T_DEC) reduce 218) ((T_DECLARE) reduce 218) ((T_DIR) reduce 218) ((T_DNUMBER) reduce 218) ((T_DO) reduce 218) ((T_DOUBLE_CAST) reduce 218) ((T_ECHO) reduce 218) ((T_EMPTY) reduce 218) ((T_ENDIF) reduce 218) ((T_ENUM) reduce 218) ((T_EVAL) reduce 218) ((T_EXIT) reduce 218) ((T_FILE) reduce 218) ((T_FINAL) reduce 218) ((T_FN) reduce 218) ((T_FOR) reduce 218) ((T_FOREACH) reduce 218) ((T_FUNCTION) reduce 218) ((T_FUNC_C) reduce 218) ((T_GLOBAL) reduce 218) ((T_GOTO) reduce 218) ((T_HALT_COMPILER) reduce 218) ((T_IF) reduce 218) ((T_INC) reduce 218) ((T_INCLUDE) reduce 218) ((T_INCLUDE_ONCE) reduce 218) ((T_INLINE_HTML) reduce 218) ((T_INTERFACE) reduce 218) ((T_INT_CAST) reduce 218) ((T_ISSET) reduce 218) ((T_LINE) reduce 218) ((T_LIST) reduce 218) ((T_LNUMBER) reduce 218) ((T_MATCH) reduce 218) ((T_METHOD_C) reduce 218) ((T_NAME_FULLY_QUALIFIED) reduce 218) ((T_NAME_QUALIFIED) reduce 218) ((T_NAME_RELATIVE) reduce 218) ((T_NEW) reduce 218) ((T_NS_C) reduce 218) ((T_OBJECT_CAST) reduce 218) ((T_PRINT) reduce 218) ((T_READONLY) reduce 218) ((T_REQUIRE) reduce 218) ((T_REQUIRE_ONCE) reduce 218) ((T_RETURN) reduce 218) ((T_START_HEREDOC) reduce 218) ((T_STATIC) reduce 218) ((T_STRING) reduce 218) ((T_STRING_CAST) reduce 218) ((T_SWITCH) reduce 218) ((T_THROW) reduce 218) ((T_TRAIT) reduce 218) ((T_TRAIT_C) reduce 218) ((T_TRY) reduce 218) ((T_UNSET) reduce 218) ((T_UNSET_CAST) reduce 218) ((T_VARIABLE) reduce 218) ((T_WHILE) reduce 218) ((T_YIELD) reduce 218) ((T_YIELD_FROM) reduce 218) (("[") reduce 218) (("`") reduce 218) (("{") reduce 218) (("~") reduce 218)) 24362 ((("!") reduce 161) (("\"") reduce 161) (("$") reduce 161) (("(") reduce 161) (("+") reduce 161) (("-") reduce 161) ((";") reduce 161) (("@") reduce 161) ((T_ABSTRACT) reduce 161) ((T_ARRAY) reduce 161) ((T_ARRAY_CAST) reduce 161) ((T_ATTRIBUTE) reduce 161) ((T_BOOL_CAST) reduce 161) ((T_BREAK) reduce 161) ((T_CLASS) reduce 161) ((T_CLASS_C) reduce 161) ((T_CLONE) reduce 161) ((T_CONSTANT_ENCAPSED_STRING) reduce 161) ((T_CONTINUE) reduce 161) ((T_DEC) reduce 161) ((T_DECLARE) reduce 161) ((T_DIR) reduce 161) ((T_DNUMBER) reduce 161) ((T_DO) reduce 161) ((T_DOUBLE_CAST) reduce 161) ((T_ECHO) reduce 161) ((T_EMPTY) reduce 161) ((T_ENDIF) reduce 161) ((T_ENUM) reduce 161) ((T_EVAL) reduce 161) ((T_EXIT) reduce 161) ((T_FILE) reduce 161) ((T_FINAL) reduce 161) ((T_FN) reduce 161) ((T_FOR) reduce 161) ((T_FOREACH) reduce 161) ((T_FUNCTION) reduce 161) ((T_FUNC_C) reduce 161) ((T_GLOBAL) reduce 161) ((T_GOTO) reduce 161) ((T_HALT_COMPILER) reduce 161) ((T_IF) reduce 161) ((T_INC) reduce 161) ((T_INCLUDE) reduce 161) ((T_INCLUDE_ONCE) reduce 161) ((T_INLINE_HTML) reduce 161) ((T_INTERFACE) reduce 161) ((T_INT_CAST) reduce 161) ((T_ISSET) reduce 161) ((T_LINE) reduce 161) ((T_LIST) reduce 161) ((T_LNUMBER) reduce 161) ((T_MATCH) reduce 161) ((T_METHOD_C) reduce 161) ((T_NAME_FULLY_QUALIFIED) reduce 161) ((T_NAME_QUALIFIED) reduce 161) ((T_NAME_RELATIVE) reduce 161) ((T_NEW) reduce 161) ((T_NS_C) reduce 161) ((T_OBJECT_CAST) reduce 161) ((T_PRINT) reduce 161) ((T_READONLY) reduce 161) ((T_REQUIRE) reduce 161) ((T_REQUIRE_ONCE) reduce 161) ((T_RETURN) reduce 161) ((T_START_HEREDOC) reduce 161) ((T_STATIC) reduce 161) ((T_STRING) reduce 161) ((T_STRING_CAST) reduce 161) ((T_SWITCH) reduce 161) ((T_THROW) reduce 161) ((T_TRAIT) reduce 161) ((T_TRAIT_C) reduce 161) ((T_TRY) reduce 161) ((T_UNSET) reduce 161) ((T_UNSET_CAST) reduce 161) ((T_VARIABLE) reduce 161) ((T_WHILE) reduce 161) ((T_YIELD) reduce 161) ((T_YIELD_FROM) reduce 161) (("[") reduce 161) (("`") reduce 161) (("{") reduce 161) (("~") reduce 161)) 24371 ((("!") reduce 150) (("\"") reduce 150) (("$") reduce 150) (("(") reduce 150) (("+") reduce 150) (("-") reduce 150) ((";") reduce 150) (("@") reduce 150) ((T_ABSTRACT) reduce 150) ((T_ARRAY) reduce 150) ((T_ARRAY_CAST) reduce 150) ((T_ATTRIBUTE) reduce 150) ((T_BOOL_CAST) reduce 150) ((T_BREAK) reduce 150) ((T_CLASS) reduce 150) ((T_CLASS_C) reduce 150) ((T_CLONE) reduce 150) ((T_CONSTANT_ENCAPSED_STRING) reduce 150) ((T_CONTINUE) reduce 150) ((T_DEC) reduce 150) ((T_DECLARE) reduce 150) ((T_DIR) reduce 150) ((T_DNUMBER) reduce 150) ((T_DO) reduce 150) ((T_DOUBLE_CAST) reduce 150) ((T_ECHO) reduce 150) ((T_EMPTY) reduce 150) ((T_ENDIF) reduce 150) ((T_ENUM) reduce 150) ((T_EVAL) reduce 150) ((T_EXIT) reduce 150) ((T_FILE) reduce 150) ((T_FINAL) reduce 150) ((T_FN) reduce 150) ((T_FOR) reduce 150) ((T_FOREACH) reduce 150) ((T_FUNCTION) reduce 150) ((T_FUNC_C) reduce 150) ((T_GLOBAL) reduce 150) ((T_GOTO) reduce 150) ((T_HALT_COMPILER) reduce 150) ((T_IF) reduce 150) ((T_INC) reduce 150) ((T_INCLUDE) reduce 150) ((T_INCLUDE_ONCE) reduce 150) ((T_INLINE_HTML) reduce 150) ((T_INTERFACE) reduce 150) ((T_INT_CAST) reduce 150) ((T_ISSET) reduce 150) ((T_LINE) reduce 150) ((T_LIST) reduce 150) ((T_LNUMBER) reduce 150) ((T_MATCH) reduce 150) ((T_METHOD_C) reduce 150) ((T_NAME_FULLY_QUALIFIED) reduce 150) ((T_NAME_QUALIFIED) reduce 150) ((T_NAME_RELATIVE) reduce 150) ((T_NEW) reduce 150) ((T_NS_C) reduce 150) ((T_OBJECT_CAST) reduce 150) ((T_PRINT) reduce 150) ((T_READONLY) reduce 150) ((T_REQUIRE) reduce 150) ((T_REQUIRE_ONCE) reduce 150) ((T_RETURN) reduce 150) ((T_START_HEREDOC) reduce 150) ((T_STATIC) reduce 150) ((T_STRING) reduce 150) ((T_STRING_CAST) reduce 150) ((T_SWITCH) reduce 150) ((T_THROW) reduce 150) ((T_TRAIT) reduce 150) ((T_TRAIT_C) reduce 150) ((T_TRY) reduce 150) ((T_UNSET) reduce 150) ((T_UNSET_CAST) reduce 150) ((T_VARIABLE) reduce 150) ((T_WHILE) reduce 150) ((T_YIELD) reduce 150) ((T_YIELD_FROM) reduce 150) (("[") reduce 150) (("`") reduce 150) (("{") reduce 150) (("~") reduce 150)) 24372 ((("!") reduce 215) (("\"") reduce 215) (("$") reduce 215) (("(") reduce 215) (("+") reduce 215) (("-") reduce 215) ((";") reduce 215) (("@") reduce 215) ((T_ABSTRACT) reduce 215) ((T_ARRAY) reduce 215) ((T_ARRAY_CAST) reduce 215) ((T_ATTRIBUTE) reduce 215) ((T_BOOL_CAST) reduce 215) ((T_BREAK) reduce 215) ((T_CLASS) reduce 215) ((T_CLASS_C) reduce 215) ((T_CLONE) reduce 215) ((T_CONSTANT_ENCAPSED_STRING) reduce 215) ((T_CONTINUE) reduce 215) ((T_DEC) reduce 215) ((T_DECLARE) reduce 215) ((T_DIR) reduce 215) ((T_DNUMBER) reduce 215) ((T_DO) reduce 215) ((T_DOUBLE_CAST) reduce 215) ((T_ECHO) reduce 215) ((T_EMPTY) reduce 215) ((T_ENDIF) reduce 215) ((T_ENUM) reduce 215) ((T_EVAL) reduce 215) ((T_EXIT) reduce 215) ((T_FILE) reduce 215) ((T_FINAL) reduce 215) ((T_FN) reduce 215) ((T_FOR) reduce 215) ((T_FOREACH) reduce 215) ((T_FUNCTION) reduce 215) ((T_FUNC_C) reduce 215) ((T_GLOBAL) reduce 215) ((T_GOTO) reduce 215) ((T_HALT_COMPILER) reduce 215) ((T_IF) reduce 215) ((T_INC) reduce 215) ((T_INCLUDE) reduce 215) ((T_INCLUDE_ONCE) reduce 215) ((T_INLINE_HTML) reduce 215) ((T_INTERFACE) reduce 215) ((T_INT_CAST) reduce 215) ((T_ISSET) reduce 215) ((T_LINE) reduce 215) ((T_LIST) reduce 215) ((T_LNUMBER) reduce 215) ((T_MATCH) reduce 215) ((T_METHOD_C) reduce 215) ((T_NAME_FULLY_QUALIFIED) reduce 215) ((T_NAME_QUALIFIED) reduce 215) ((T_NAME_RELATIVE) reduce 215) ((T_NEW) reduce 215) ((T_NS_C) reduce 215) ((T_OBJECT_CAST) reduce 215) ((T_PRINT) reduce 215) ((T_READONLY) reduce 215) ((T_REQUIRE) reduce 215) ((T_REQUIRE_ONCE) reduce 215) ((T_RETURN) reduce 215) ((T_START_HEREDOC) reduce 215) ((T_STATIC) reduce 215) ((T_STRING) reduce 215) ((T_STRING_CAST) reduce 215) ((T_SWITCH) reduce 215) ((T_THROW) reduce 215) ((T_TRAIT) reduce 215) ((T_TRAIT_C) reduce 215) ((T_TRY) reduce 215) ((T_UNSET) reduce 215) ((T_UNSET_CAST) reduce 215) ((T_VARIABLE) reduce 215) ((T_WHILE) reduce 215) ((T_YIELD) reduce 215) ((T_YIELD_FROM) reduce 215) (("[") reduce 215) (("`") reduce 215) (("{") reduce 215) (("~") reduce 215)) 24375 ((("!") reduce 216) (("\"") reduce 216) (("$") reduce 216) (("(") reduce 216) (("+") reduce 216) (("-") reduce 216) ((";") reduce 216) (("@") reduce 216) ((T_ABSTRACT) reduce 216) ((T_ARRAY) reduce 216) ((T_ARRAY_CAST) reduce 216) ((T_ATTRIBUTE) reduce 216) ((T_BOOL_CAST) reduce 216) ((T_BREAK) reduce 216) ((T_CLASS) reduce 216) ((T_CLASS_C) reduce 216) ((T_CLONE) reduce 216) ((T_CONSTANT_ENCAPSED_STRING) reduce 216) ((T_CONTINUE) reduce 216) ((T_DEC) reduce 216) ((T_DECLARE) reduce 216) ((T_DIR) reduce 216) ((T_DNUMBER) reduce 216) ((T_DO) reduce 216) ((T_DOUBLE_CAST) reduce 216) ((T_ECHO) reduce 216) ((T_EMPTY) reduce 216) ((T_ENDIF) reduce 216) ((T_ENUM) reduce 216) ((T_EVAL) reduce 216) ((T_EXIT) reduce 216) ((T_FILE) reduce 216) ((T_FINAL) reduce 216) ((T_FN) reduce 216) ((T_FOR) reduce 216) ((T_FOREACH) reduce 216) ((T_FUNCTION) reduce 216) ((T_FUNC_C) reduce 216) ((T_GLOBAL) reduce 216) ((T_GOTO) reduce 216) ((T_HALT_COMPILER) reduce 216) ((T_IF) reduce 216) ((T_INC) reduce 216) ((T_INCLUDE) reduce 216) ((T_INCLUDE_ONCE) reduce 216) ((T_INLINE_HTML) reduce 216) ((T_INTERFACE) reduce 216) ((T_INT_CAST) reduce 216) ((T_ISSET) reduce 216) ((T_LINE) reduce 216) ((T_LIST) reduce 216) ((T_LNUMBER) reduce 216) ((T_MATCH) reduce 216) ((T_METHOD_C) reduce 216) ((T_NAME_FULLY_QUALIFIED) reduce 216) ((T_NAME_QUALIFIED) reduce 216) ((T_NAME_RELATIVE) reduce 216) ((T_NEW) reduce 216) ((T_NS_C) reduce 216) ((T_OBJECT_CAST) reduce 216) ((T_PRINT) reduce 216) ((T_READONLY) reduce 216) ((T_REQUIRE) reduce 216) ((T_REQUIRE_ONCE) reduce 216) ((T_RETURN) reduce 216) ((T_START_HEREDOC) reduce 216) ((T_STATIC) reduce 216) ((T_STRING) reduce 216) ((T_STRING_CAST) reduce 216) ((T_SWITCH) reduce 216) ((T_THROW) reduce 216) ((T_TRAIT) reduce 216) ((T_TRAIT_C) reduce 216) ((T_TRY) reduce 216) ((T_UNSET) reduce 216) ((T_UNSET_CAST) reduce 216) ((T_VARIABLE) reduce 216) ((T_WHILE) reduce 216) ((T_YIELD) reduce 216) ((T_YIELD_FROM) reduce 216) (("[") reduce 216) (("`") reduce 216) (("{") reduce 216) (("~") reduce 216)) 24382 ((("!") reduce 199) (("\"") reduce 199) (("$") reduce 199) (("(") reduce 199) (("+") reduce 199) (("-") reduce 199) ((";") reduce 199) (("@") reduce 199) ((T_ABSTRACT) reduce 199) ((T_ARRAY) reduce 199) ((T_ARRAY_CAST) reduce 199) ((T_ATTRIBUTE) reduce 199) ((T_BOOL_CAST) reduce 199) ((T_BREAK) reduce 199) ((T_CLASS) reduce 199) ((T_CLASS_C) reduce 199) ((T_CLONE) reduce 199) ((T_CONSTANT_ENCAPSED_STRING) reduce 199) ((T_CONTINUE) reduce 199) ((T_DEC) reduce 199) ((T_DECLARE) reduce 199) ((T_DIR) reduce 199) ((T_DNUMBER) reduce 199) ((T_DO) reduce 199) ((T_DOUBLE_CAST) reduce 199) ((T_ECHO) reduce 199) ((T_EMPTY) reduce 199) ((T_ENDIF) reduce 199) ((T_ENUM) reduce 199) ((T_EVAL) reduce 199) ((T_EXIT) reduce 199) ((T_FILE) reduce 199) ((T_FINAL) reduce 199) ((T_FN) reduce 199) ((T_FOR) reduce 199) ((T_FOREACH) reduce 199) ((T_FUNCTION) reduce 199) ((T_FUNC_C) reduce 199) ((T_GLOBAL) reduce 199) ((T_GOTO) reduce 199) ((T_HALT_COMPILER) reduce 199) ((T_IF) reduce 199) ((T_INC) reduce 199) ((T_INCLUDE) reduce 199) ((T_INCLUDE_ONCE) reduce 199) ((T_INLINE_HTML) reduce 199) ((T_INTERFACE) reduce 199) ((T_INT_CAST) reduce 199) ((T_ISSET) reduce 199) ((T_LINE) reduce 199) ((T_LIST) reduce 199) ((T_LNUMBER) reduce 199) ((T_MATCH) reduce 199) ((T_METHOD_C) reduce 199) ((T_NAME_FULLY_QUALIFIED) reduce 199) ((T_NAME_QUALIFIED) reduce 199) ((T_NAME_RELATIVE) reduce 199) ((T_NEW) reduce 199) ((T_NS_C) reduce 199) ((T_OBJECT_CAST) reduce 199) ((T_PRINT) reduce 199) ((T_READONLY) reduce 199) ((T_REQUIRE) reduce 199) ((T_REQUIRE_ONCE) reduce 199) ((T_RETURN) reduce 199) ((T_START_HEREDOC) reduce 199) ((T_STATIC) reduce 199) ((T_STRING) reduce 199) ((T_STRING_CAST) reduce 199) ((T_SWITCH) reduce 199) ((T_THROW) reduce 199) ((T_TRAIT) reduce 199) ((T_TRAIT_C) reduce 199) ((T_TRY) reduce 199) ((T_UNSET) reduce 199) ((T_UNSET_CAST) reduce 199) ((T_VARIABLE) reduce 199) ((T_WHILE) reduce 199) ((T_YIELD) reduce 199) ((T_YIELD_FROM) reduce 199) (("[") reduce 199) (("`") reduce 199) (("{") reduce 199) (("~") reduce 199)) 24383 ((("!") reduce 248) (("\"") reduce 248) (("$") reduce 248) (("(") reduce 248) (("+") reduce 248) (("-") reduce 248) ((";") reduce 248) (("@") reduce 248) ((T_ABSTRACT) reduce 248) ((T_ARRAY) reduce 248) ((T_ARRAY_CAST) reduce 248) ((T_ATTRIBUTE) reduce 248) ((T_BOOL_CAST) reduce 248) ((T_BREAK) reduce 248) ((T_CLASS) reduce 248) ((T_CLASS_C) reduce 248) ((T_CLONE) reduce 248) ((T_CONSTANT_ENCAPSED_STRING) reduce 248) ((T_CONTINUE) reduce 248) ((T_DEC) reduce 248) ((T_DECLARE) reduce 248) ((T_DIR) reduce 248) ((T_DNUMBER) reduce 248) ((T_DO) reduce 248) ((T_DOUBLE_CAST) reduce 248) ((T_ECHO) reduce 248) ((T_ELSE) reduce 248) ((T_ELSEIF) reduce 248) ((T_EMPTY) reduce 248) ((T_ENDIF) reduce 248) ((T_ENUM) reduce 248) ((T_EVAL) reduce 248) ((T_EXIT) reduce 248) ((T_FILE) reduce 248) ((T_FINAL) reduce 248) ((T_FN) reduce 248) ((T_FOR) reduce 248) ((T_FOREACH) reduce 248) ((T_FUNCTION) reduce 248) ((T_FUNC_C) reduce 248) ((T_GLOBAL) reduce 248) ((T_GOTO) reduce 248) ((T_HALT_COMPILER) reduce 248) ((T_IF) reduce 248) ((T_INC) reduce 248) ((T_INCLUDE) reduce 248) ((T_INCLUDE_ONCE) reduce 248) ((T_INLINE_HTML) reduce 248) ((T_INTERFACE) reduce 248) ((T_INT_CAST) reduce 248) ((T_ISSET) reduce 248) ((T_LINE) reduce 248) ((T_LIST) reduce 248) ((T_LNUMBER) reduce 248) ((T_MATCH) reduce 248) ((T_METHOD_C) reduce 248) ((T_NAME_FULLY_QUALIFIED) reduce 248) ((T_NAME_QUALIFIED) reduce 248) ((T_NAME_RELATIVE) reduce 248) ((T_NEW) reduce 248) ((T_NS_C) reduce 248) ((T_OBJECT_CAST) reduce 248) ((T_PRINT) reduce 248) ((T_READONLY) reduce 248) ((T_REQUIRE) reduce 248) ((T_REQUIRE_ONCE) reduce 248) ((T_RETURN) reduce 248) ((T_START_HEREDOC) reduce 248) ((T_STATIC) reduce 248) ((T_STRING) reduce 248) ((T_STRING_CAST) reduce 248) ((T_SWITCH) reduce 248) ((T_THROW) reduce 248) ((T_TRAIT) reduce 248) ((T_TRAIT_C) reduce 248) ((T_TRY) reduce 248) ((T_UNSET) reduce 248) ((T_UNSET_CAST) reduce 248) ((T_VARIABLE) reduce 248) ((T_WHILE) reduce 248) ((T_YIELD) reduce 248) ((T_YIELD_FROM) reduce 248) (("[") reduce 248) (("`") reduce 248) (("{") reduce 248) (("~") reduce 248)) 24385 ((("!") reduce 157) (("\"") reduce 157) (("$") reduce 157) (("(") reduce 157) (("+") reduce 157) (("-") reduce 157) ((";") reduce 157) (("@") reduce 157) ((T_ABSTRACT) reduce 157) ((T_ARRAY) reduce 157) ((T_ARRAY_CAST) reduce 157) ((T_ATTRIBUTE) reduce 157) ((T_BOOL_CAST) reduce 157) ((T_BREAK) reduce 157) ((T_CLASS) reduce 157) ((T_CLASS_C) reduce 157) ((T_CLONE) reduce 157) ((T_CONSTANT_ENCAPSED_STRING) reduce 157) ((T_CONTINUE) reduce 157) ((T_DEC) reduce 157) ((T_DECLARE) reduce 157) ((T_DIR) reduce 157) ((T_DNUMBER) reduce 157) ((T_DO) reduce 157) ((T_DOUBLE_CAST) reduce 157) ((T_ECHO) reduce 157) ((T_EMPTY) reduce 157) ((T_ENDIF) reduce 157) ((T_ENUM) reduce 157) ((T_EVAL) reduce 157) ((T_EXIT) reduce 157) ((T_FILE) reduce 157) ((T_FINAL) reduce 157) ((T_FN) reduce 157) ((T_FOR) reduce 157) ((T_FOREACH) reduce 157) ((T_FUNCTION) reduce 157) ((T_FUNC_C) reduce 157) ((T_GLOBAL) reduce 157) ((T_GOTO) reduce 157) ((T_HALT_COMPILER) reduce 157) ((T_IF) reduce 157) ((T_INC) reduce 157) ((T_INCLUDE) reduce 157) ((T_INCLUDE_ONCE) reduce 157) ((T_INLINE_HTML) reduce 157) ((T_INTERFACE) reduce 157) ((T_INT_CAST) reduce 157) ((T_ISSET) reduce 157) ((T_LINE) reduce 157) ((T_LIST) reduce 157) ((T_LNUMBER) reduce 157) ((T_MATCH) reduce 157) ((T_METHOD_C) reduce 157) ((T_NAME_FULLY_QUALIFIED) reduce 157) ((T_NAME_QUALIFIED) reduce 157) ((T_NAME_RELATIVE) reduce 157) ((T_NEW) reduce 157) ((T_NS_C) reduce 157) ((T_OBJECT_CAST) reduce 157) ((T_PRINT) reduce 157) ((T_READONLY) reduce 157) ((T_REQUIRE) reduce 157) ((T_REQUIRE_ONCE) reduce 157) ((T_RETURN) reduce 157) ((T_START_HEREDOC) reduce 157) ((T_STATIC) reduce 157) ((T_STRING) reduce 157) ((T_STRING_CAST) reduce 157) ((T_SWITCH) reduce 157) ((T_THROW) reduce 157) ((T_TRAIT) reduce 157) ((T_TRAIT_C) reduce 157) ((T_TRY) reduce 157) ((T_UNSET) reduce 157) ((T_UNSET_CAST) reduce 157) ((T_VARIABLE) reduce 157) ((T_WHILE) reduce 157) ((T_YIELD) reduce 157) ((T_YIELD_FROM) reduce 157) (("[") reduce 157) (("`") reduce 157) (("{") reduce 157) (("~") reduce 157)) 24391 ((("!") reduce 149) (("\"") reduce 149) (("$") reduce 149) (("(") reduce 149) (("+") reduce 149) (("-") reduce 149) ((";") reduce 149) (("@") reduce 149) ((T_ABSTRACT) reduce 149) ((T_ARRAY) reduce 149) ((T_ARRAY_CAST) reduce 149) ((T_ATTRIBUTE) reduce 149) ((T_BOOL_CAST) reduce 149) ((T_BREAK) reduce 149) ((T_CLASS) reduce 149) ((T_CLASS_C) reduce 149) ((T_CLONE) reduce 149) ((T_CONSTANT_ENCAPSED_STRING) reduce 149) ((T_CONTINUE) reduce 149) ((T_DEC) reduce 149) ((T_DECLARE) reduce 149) ((T_DIR) reduce 149) ((T_DNUMBER) reduce 149) ((T_DO) reduce 149) ((T_DOUBLE_CAST) reduce 149) ((T_ECHO) reduce 149) ((T_EMPTY) reduce 149) ((T_ENDIF) reduce 149) ((T_ENUM) reduce 149) ((T_EVAL) reduce 149) ((T_EXIT) reduce 149) ((T_FILE) reduce 149) ((T_FINAL) reduce 149) ((T_FN) reduce 149) ((T_FOR) reduce 149) ((T_FOREACH) reduce 149) ((T_FUNCTION) reduce 149) ((T_FUNC_C) reduce 149) ((T_GLOBAL) reduce 149) ((T_GOTO) reduce 149) ((T_HALT_COMPILER) reduce 149) ((T_IF) reduce 149) ((T_INC) reduce 149) ((T_INCLUDE) reduce 149) ((T_INCLUDE_ONCE) reduce 149) ((T_INLINE_HTML) reduce 149) ((T_INTERFACE) reduce 149) ((T_INT_CAST) reduce 149) ((T_ISSET) reduce 149) ((T_LINE) reduce 149) ((T_LIST) reduce 149) ((T_LNUMBER) reduce 149) ((T_MATCH) reduce 149) ((T_METHOD_C) reduce 149) ((T_NAME_FULLY_QUALIFIED) reduce 149) ((T_NAME_QUALIFIED) reduce 149) ((T_NAME_RELATIVE) reduce 149) ((T_NEW) reduce 149) ((T_NS_C) reduce 149) ((T_OBJECT_CAST) reduce 149) ((T_PRINT) reduce 149) ((T_READONLY) reduce 149) ((T_REQUIRE) reduce 149) ((T_REQUIRE_ONCE) reduce 149) ((T_RETURN) reduce 149) ((T_START_HEREDOC) reduce 149) ((T_STATIC) reduce 149) ((T_STRING) reduce 149) ((T_STRING_CAST) reduce 149) ((T_SWITCH) reduce 149) ((T_THROW) reduce 149) ((T_TRAIT) reduce 149) ((T_TRAIT_C) reduce 149) ((T_TRY) reduce 149) ((T_UNSET) reduce 149) ((T_UNSET_CAST) reduce 149) ((T_VARIABLE) reduce 149) ((T_WHILE) reduce 149) ((T_YIELD) reduce 149) ((T_YIELD_FROM) reduce 149) (("[") reduce 149) (("`") reduce 149) (("{") reduce 149) (("~") reduce 149)) 24396 ((("!") reduce 163) (("\"") reduce 163) (("$") reduce 163) (("(") reduce 163) (("+") reduce 163) (("-") reduce 163) ((";") reduce 163) (("@") reduce 163) ((T_ABSTRACT) reduce 163) ((T_ARRAY) reduce 163) ((T_ARRAY_CAST) reduce 163) ((T_ATTRIBUTE) reduce 163) ((T_BOOL_CAST) reduce 163) ((T_BREAK) reduce 163) ((T_CLASS) reduce 163) ((T_CLASS_C) reduce 163) ((T_CLONE) reduce 163) ((T_CONSTANT_ENCAPSED_STRING) reduce 163) ((T_CONTINUE) reduce 163) ((T_DEC) reduce 163) ((T_DECLARE) reduce 163) ((T_DIR) reduce 163) ((T_DNUMBER) reduce 163) ((T_DO) reduce 163) ((T_DOUBLE_CAST) reduce 163) ((T_ECHO) reduce 163) ((T_EMPTY) reduce 163) ((T_ENDIF) reduce 163) ((T_ENUM) reduce 163) ((T_EVAL) reduce 163) ((T_EXIT) reduce 163) ((T_FILE) reduce 163) ((T_FINAL) reduce 163) ((T_FN) reduce 163) ((T_FOR) reduce 163) ((T_FOREACH) reduce 163) ((T_FUNCTION) reduce 163) ((T_FUNC_C) reduce 163) ((T_GLOBAL) reduce 163) ((T_GOTO) reduce 163) ((T_HALT_COMPILER) reduce 163) ((T_IF) reduce 163) ((T_INC) reduce 163) ((T_INCLUDE) reduce 163) ((T_INCLUDE_ONCE) reduce 163) ((T_INLINE_HTML) reduce 163) ((T_INTERFACE) reduce 163) ((T_INT_CAST) reduce 163) ((T_ISSET) reduce 163) ((T_LINE) reduce 163) ((T_LIST) reduce 163) ((T_LNUMBER) reduce 163) ((T_MATCH) reduce 163) ((T_METHOD_C) reduce 163) ((T_NAME_FULLY_QUALIFIED) reduce 163) ((T_NAME_QUALIFIED) reduce 163) ((T_NAME_RELATIVE) reduce 163) ((T_NEW) reduce 163) ((T_NS_C) reduce 163) ((T_OBJECT_CAST) reduce 163) ((T_PRINT) reduce 163) ((T_READONLY) reduce 163) ((T_REQUIRE) reduce 163) ((T_REQUIRE_ONCE) reduce 163) ((T_RETURN) reduce 163) ((T_START_HEREDOC) reduce 163) ((T_STATIC) reduce 163) ((T_STRING) reduce 163) ((T_STRING_CAST) reduce 163) ((T_SWITCH) reduce 163) ((T_THROW) reduce 163) ((T_TRAIT) reduce 163) ((T_TRAIT_C) reduce 163) ((T_TRY) reduce 163) ((T_UNSET) reduce 163) ((T_UNSET_CAST) reduce 163) ((T_VARIABLE) reduce 163) ((T_WHILE) reduce 163) ((T_YIELD) reduce 163) ((T_YIELD_FROM) reduce 163) (("[") reduce 163) (("`") reduce 163) (("{") reduce 163) (("~") reduce 163)) 24397 ((("!") reduce 219) (("\"") reduce 219) (("$") reduce 219) (("(") reduce 219) (("+") reduce 219) (("-") reduce 219) ((";") reduce 219) (("@") reduce 219) ((T_ABSTRACT) reduce 219) ((T_ARRAY) reduce 219) ((T_ARRAY_CAST) reduce 219) ((T_ATTRIBUTE) reduce 219) ((T_BOOL_CAST) reduce 219) ((T_BREAK) reduce 219) ((T_CLASS) reduce 219) ((T_CLASS_C) reduce 219) ((T_CLONE) reduce 219) ((T_CONSTANT_ENCAPSED_STRING) reduce 219) ((T_CONTINUE) reduce 219) ((T_DEC) reduce 219) ((T_DECLARE) reduce 219) ((T_DIR) reduce 219) ((T_DNUMBER) reduce 219) ((T_DO) reduce 219) ((T_DOUBLE_CAST) reduce 219) ((T_ECHO) reduce 219) ((T_EMPTY) reduce 219) ((T_ENDIF) reduce 219) ((T_ENUM) reduce 219) ((T_EVAL) reduce 219) ((T_EXIT) reduce 219) ((T_FILE) reduce 219) ((T_FINAL) reduce 219) ((T_FN) reduce 219) ((T_FOR) reduce 219) ((T_FOREACH) reduce 219) ((T_FUNCTION) reduce 219) ((T_FUNC_C) reduce 219) ((T_GLOBAL) reduce 219) ((T_GOTO) reduce 219) ((T_HALT_COMPILER) reduce 219) ((T_IF) reduce 219) ((T_INC) reduce 219) ((T_INCLUDE) reduce 219) ((T_INCLUDE_ONCE) reduce 219) ((T_INLINE_HTML) reduce 219) ((T_INTERFACE) reduce 219) ((T_INT_CAST) reduce 219) ((T_ISSET) reduce 219) ((T_LINE) reduce 219) ((T_LIST) reduce 219) ((T_LNUMBER) reduce 219) ((T_MATCH) reduce 219) ((T_METHOD_C) reduce 219) ((T_NAME_FULLY_QUALIFIED) reduce 219) ((T_NAME_QUALIFIED) reduce 219) ((T_NAME_RELATIVE) reduce 219) ((T_NEW) reduce 219) ((T_NS_C) reduce 219) ((T_OBJECT_CAST) reduce 219) ((T_PRINT) reduce 219) ((T_READONLY) reduce 219) ((T_REQUIRE) reduce 219) ((T_REQUIRE_ONCE) reduce 219) ((T_RETURN) reduce 219) ((T_START_HEREDOC) reduce 219) ((T_STATIC) reduce 219) ((T_STRING) reduce 219) ((T_STRING_CAST) reduce 219) ((T_SWITCH) reduce 219) ((T_THROW) reduce 219) ((T_TRAIT) reduce 219) ((T_TRAIT_C) reduce 219) ((T_TRY) reduce 219) ((T_UNSET) reduce 219) ((T_UNSET_CAST) reduce 219) ((T_VARIABLE) reduce 219) ((T_WHILE) reduce 219) ((T_YIELD) reduce 219) ((T_YIELD_FROM) reduce 219) (("[") reduce 219) (("`") reduce 219) (("{") reduce 219) (("~") reduce 219)) 24400 ((("!") reduce 220) (("\"") reduce 220) (("$") reduce 220) (("(") reduce 220) (("+") reduce 220) (("-") reduce 220) ((";") reduce 220) (("@") reduce 220) ((T_ABSTRACT) reduce 220) ((T_ARRAY) reduce 220) ((T_ARRAY_CAST) reduce 220) ((T_ATTRIBUTE) reduce 220) ((T_BOOL_CAST) reduce 220) ((T_BREAK) reduce 220) ((T_CLASS) reduce 220) ((T_CLASS_C) reduce 220) ((T_CLONE) reduce 220) ((T_CONSTANT_ENCAPSED_STRING) reduce 220) ((T_CONTINUE) reduce 220) ((T_DEC) reduce 220) ((T_DECLARE) reduce 220) ((T_DIR) reduce 220) ((T_DNUMBER) reduce 220) ((T_DO) reduce 220) ((T_DOUBLE_CAST) reduce 220) ((T_ECHO) reduce 220) ((T_EMPTY) reduce 220) ((T_ENDIF) reduce 220) ((T_ENUM) reduce 220) ((T_EVAL) reduce 220) ((T_EXIT) reduce 220) ((T_FILE) reduce 220) ((T_FINAL) reduce 220) ((T_FN) reduce 220) ((T_FOR) reduce 220) ((T_FOREACH) reduce 220) ((T_FUNCTION) reduce 220) ((T_FUNC_C) reduce 220) ((T_GLOBAL) reduce 220) ((T_GOTO) reduce 220) ((T_HALT_COMPILER) reduce 220) ((T_IF) reduce 220) ((T_INC) reduce 220) ((T_INCLUDE) reduce 220) ((T_INCLUDE_ONCE) reduce 220) ((T_INLINE_HTML) reduce 220) ((T_INTERFACE) reduce 220) ((T_INT_CAST) reduce 220) ((T_ISSET) reduce 220) ((T_LINE) reduce 220) ((T_LIST) reduce 220) ((T_LNUMBER) reduce 220) ((T_MATCH) reduce 220) ((T_METHOD_C) reduce 220) ((T_NAME_FULLY_QUALIFIED) reduce 220) ((T_NAME_QUALIFIED) reduce 220) ((T_NAME_RELATIVE) reduce 220) ((T_NEW) reduce 220) ((T_NS_C) reduce 220) ((T_OBJECT_CAST) reduce 220) ((T_PRINT) reduce 220) ((T_READONLY) reduce 220) ((T_REQUIRE) reduce 220) ((T_REQUIRE_ONCE) reduce 220) ((T_RETURN) reduce 220) ((T_START_HEREDOC) reduce 220) ((T_STATIC) reduce 220) ((T_STRING) reduce 220) ((T_STRING_CAST) reduce 220) ((T_SWITCH) reduce 220) ((T_THROW) reduce 220) ((T_TRAIT) reduce 220) ((T_TRAIT_C) reduce 220) ((T_TRY) reduce 220) ((T_UNSET) reduce 220) ((T_UNSET_CAST) reduce 220) ((T_VARIABLE) reduce 220) ((T_WHILE) reduce 220) ((T_YIELD) reduce 220) ((T_YIELD_FROM) reduce 220) (("[") reduce 220) (("`") reduce 220) (("{") reduce 220) (("~") reduce 220)) 24402 ((("!") reduce 153) (("\"") reduce 153) (("$") reduce 153) (("(") reduce 153) (("+") reduce 153) (("-") reduce 153) ((";") reduce 153) (("@") reduce 153) ((T_ABSTRACT) reduce 153) ((T_ARRAY) reduce 153) ((T_ARRAY_CAST) reduce 153) ((T_ATTRIBUTE) reduce 153) ((T_BOOL_CAST) reduce 153) ((T_BREAK) reduce 153) ((T_CLASS) reduce 153) ((T_CLASS_C) reduce 153) ((T_CLONE) reduce 153) ((T_CONSTANT_ENCAPSED_STRING) reduce 153) ((T_CONTINUE) reduce 153) ((T_DEC) reduce 153) ((T_DECLARE) reduce 153) ((T_DIR) reduce 153) ((T_DNUMBER) reduce 153) ((T_DO) reduce 153) ((T_DOUBLE_CAST) reduce 153) ((T_ECHO) reduce 153) ((T_EMPTY) reduce 153) ((T_ENDIF) reduce 153) ((T_ENUM) reduce 153) ((T_EVAL) reduce 153) ((T_EXIT) reduce 153) ((T_FILE) reduce 153) ((T_FINAL) reduce 153) ((T_FN) reduce 153) ((T_FOR) reduce 153) ((T_FOREACH) reduce 153) ((T_FUNCTION) reduce 153) ((T_FUNC_C) reduce 153) ((T_GLOBAL) reduce 153) ((T_GOTO) reduce 153) ((T_HALT_COMPILER) reduce 153) ((T_IF) reduce 153) ((T_INC) reduce 153) ((T_INCLUDE) reduce 153) ((T_INCLUDE_ONCE) reduce 153) ((T_INLINE_HTML) reduce 153) ((T_INTERFACE) reduce 153) ((T_INT_CAST) reduce 153) ((T_ISSET) reduce 153) ((T_LINE) reduce 153) ((T_LIST) reduce 153) ((T_LNUMBER) reduce 153) ((T_MATCH) reduce 153) ((T_METHOD_C) reduce 153) ((T_NAME_FULLY_QUALIFIED) reduce 153) ((T_NAME_QUALIFIED) reduce 153) ((T_NAME_RELATIVE) reduce 153) ((T_NEW) reduce 153) ((T_NS_C) reduce 153) ((T_OBJECT_CAST) reduce 153) ((T_PRINT) reduce 153) ((T_READONLY) reduce 153) ((T_REQUIRE) reduce 153) ((T_REQUIRE_ONCE) reduce 153) ((T_RETURN) reduce 153) ((T_START_HEREDOC) reduce 153) ((T_STATIC) reduce 153) ((T_STRING) reduce 153) ((T_STRING_CAST) reduce 153) ((T_SWITCH) reduce 153) ((T_THROW) reduce 153) ((T_TRAIT) reduce 153) ((T_TRAIT_C) reduce 153) ((T_TRY) reduce 153) ((T_UNSET) reduce 153) ((T_UNSET_CAST) reduce 153) ((T_VARIABLE) reduce 153) ((T_WHILE) reduce 153) ((T_YIELD) reduce 153) ((T_YIELD_FROM) reduce 153) (("[") reduce 153) (("`") reduce 153) (("{") reduce 153) (("~") reduce 153)) 24409 ((("!") reduce 187) (("\"") reduce 187) (("$") reduce 187) (("(") reduce 187) (("+") reduce 187) (("-") reduce 187) ((";") reduce 187) (("@") reduce 187) ((T_ABSTRACT) reduce 187) ((T_ARRAY) reduce 187) ((T_ARRAY_CAST) reduce 187) ((T_ATTRIBUTE) reduce 187) ((T_BOOL_CAST) reduce 187) ((T_BREAK) reduce 187) ((T_CLASS) reduce 187) ((T_CLASS_C) reduce 187) ((T_CLONE) reduce 187) ((T_CONSTANT_ENCAPSED_STRING) reduce 187) ((T_CONTINUE) reduce 187) ((T_DEC) reduce 187) ((T_DECLARE) reduce 187) ((T_DIR) reduce 187) ((T_DNUMBER) reduce 187) ((T_DO) reduce 187) ((T_DOUBLE_CAST) reduce 187) ((T_ECHO) reduce 187) ((T_EMPTY) reduce 187) ((T_ENDIF) reduce 187) ((T_ENUM) reduce 187) ((T_EVAL) reduce 187) ((T_EXIT) reduce 187) ((T_FILE) reduce 187) ((T_FINAL) reduce 187) ((T_FN) reduce 187) ((T_FOR) reduce 187) ((T_FOREACH) reduce 187) ((T_FUNCTION) reduce 187) ((T_FUNC_C) reduce 187) ((T_GLOBAL) reduce 187) ((T_GOTO) reduce 187) ((T_HALT_COMPILER) reduce 187) ((T_IF) reduce 187) ((T_INC) reduce 187) ((T_INCLUDE) reduce 187) ((T_INCLUDE_ONCE) reduce 187) ((T_INLINE_HTML) reduce 187) ((T_INTERFACE) reduce 187) ((T_INT_CAST) reduce 187) ((T_ISSET) reduce 187) ((T_LINE) reduce 187) ((T_LIST) reduce 187) ((T_LNUMBER) reduce 187) ((T_MATCH) reduce 187) ((T_METHOD_C) reduce 187) ((T_NAME_FULLY_QUALIFIED) reduce 187) ((T_NAME_QUALIFIED) reduce 187) ((T_NAME_RELATIVE) reduce 187) ((T_NEW) reduce 187) ((T_NS_C) reduce 187) ((T_OBJECT_CAST) reduce 187) ((T_PRINT) reduce 187) ((T_READONLY) reduce 187) ((T_REQUIRE) reduce 187) ((T_REQUIRE_ONCE) reduce 187) ((T_RETURN) reduce 187) ((T_START_HEREDOC) reduce 187) ((T_STATIC) reduce 187) ((T_STRING) reduce 187) ((T_STRING_CAST) reduce 187) ((T_SWITCH) reduce 187) ((T_THROW) reduce 187) ((T_TRAIT) reduce 187) ((T_TRAIT_C) reduce 187) ((T_TRY) reduce 187) ((T_UNSET) reduce 187) ((T_UNSET_CAST) reduce 187) ((T_VARIABLE) reduce 187) ((T_WHILE) reduce 187) ((T_YIELD) reduce 187) ((T_YIELD_FROM) reduce 187) (("[") reduce 187) (("`") reduce 187) (("{") reduce 187) (("~") reduce 187)) 24411 ((("!") reduce 152) (("\"") reduce 152) (("$") reduce 152) (("(") reduce 152) (("+") reduce 152) (("-") reduce 152) ((";") reduce 152) (("@") reduce 152) ((T_ABSTRACT) reduce 152) ((T_ARRAY) reduce 152) ((T_ARRAY_CAST) reduce 152) ((T_ATTRIBUTE) reduce 152) ((T_BOOL_CAST) reduce 152) ((T_BREAK) reduce 152) ((T_CLASS) reduce 152) ((T_CLASS_C) reduce 152) ((T_CLONE) reduce 152) ((T_CONSTANT_ENCAPSED_STRING) reduce 152) ((T_CONTINUE) reduce 152) ((T_DEC) reduce 152) ((T_DECLARE) reduce 152) ((T_DIR) reduce 152) ((T_DNUMBER) reduce 152) ((T_DO) reduce 152) ((T_DOUBLE_CAST) reduce 152) ((T_ECHO) reduce 152) ((T_EMPTY) reduce 152) ((T_ENDIF) reduce 152) ((T_ENUM) reduce 152) ((T_EVAL) reduce 152) ((T_EXIT) reduce 152) ((T_FILE) reduce 152) ((T_FINAL) reduce 152) ((T_FN) reduce 152) ((T_FOR) reduce 152) ((T_FOREACH) reduce 152) ((T_FUNCTION) reduce 152) ((T_FUNC_C) reduce 152) ((T_GLOBAL) reduce 152) ((T_GOTO) reduce 152) ((T_HALT_COMPILER) reduce 152) ((T_IF) reduce 152) ((T_INC) reduce 152) ((T_INCLUDE) reduce 152) ((T_INCLUDE_ONCE) reduce 152) ((T_INLINE_HTML) reduce 152) ((T_INTERFACE) reduce 152) ((T_INT_CAST) reduce 152) ((T_ISSET) reduce 152) ((T_LINE) reduce 152) ((T_LIST) reduce 152) ((T_LNUMBER) reduce 152) ((T_MATCH) reduce 152) ((T_METHOD_C) reduce 152) ((T_NAME_FULLY_QUALIFIED) reduce 152) ((T_NAME_QUALIFIED) reduce 152) ((T_NAME_RELATIVE) reduce 152) ((T_NEW) reduce 152) ((T_NS_C) reduce 152) ((T_OBJECT_CAST) reduce 152) ((T_PRINT) reduce 152) ((T_READONLY) reduce 152) ((T_REQUIRE) reduce 152) ((T_REQUIRE_ONCE) reduce 152) ((T_RETURN) reduce 152) ((T_START_HEREDOC) reduce 152) ((T_STATIC) reduce 152) ((T_STRING) reduce 152) ((T_STRING_CAST) reduce 152) ((T_SWITCH) reduce 152) ((T_THROW) reduce 152) ((T_TRAIT) reduce 152) ((T_TRAIT_C) reduce 152) ((T_TRY) reduce 152) ((T_UNSET) reduce 152) ((T_UNSET_CAST) reduce 152) ((T_VARIABLE) reduce 152) ((T_WHILE) reduce 152) ((T_YIELD) reduce 152) ((T_YIELD_FROM) reduce 152) (("[") reduce 152) (("`") reduce 152) (("{") reduce 152) (("~") reduce 152)) 24416 ((("!") reduce 239) (("\"") reduce 239) (("$") reduce 239) (("(") reduce 239) (("+") reduce 239) (("-") reduce 239) ((";") reduce 239) (("@") reduce 239) ((T_ABSTRACT) reduce 239) ((T_ARRAY) reduce 239) ((T_ARRAY_CAST) reduce 239) ((T_ATTRIBUTE) reduce 239) ((T_BOOL_CAST) reduce 239) ((T_BREAK) reduce 239) ((T_CLASS) reduce 239) ((T_CLASS_C) reduce 239) ((T_CLONE) reduce 239) ((T_CONSTANT_ENCAPSED_STRING) reduce 239) ((T_CONTINUE) reduce 239) ((T_DEC) reduce 239) ((T_DECLARE) reduce 239) ((T_DIR) reduce 239) ((T_DNUMBER) reduce 239) ((T_DO) reduce 239) ((T_DOUBLE_CAST) reduce 239) ((T_ECHO) reduce 239) ((T_ELSE) reduce 239) ((T_ELSEIF) reduce 239) ((T_EMPTY) reduce 239) ((T_ENDIF) reduce 239) ((T_ENUM) reduce 239) ((T_EVAL) reduce 239) ((T_EXIT) reduce 239) ((T_FILE) reduce 239) ((T_FINAL) reduce 239) ((T_FN) reduce 239) ((T_FOR) reduce 239) ((T_FOREACH) reduce 239) ((T_FUNCTION) reduce 239) ((T_FUNC_C) reduce 239) ((T_GLOBAL) reduce 239) ((T_GOTO) reduce 239) ((T_HALT_COMPILER) reduce 239) ((T_IF) reduce 239) ((T_INC) reduce 239) ((T_INCLUDE) reduce 239) ((T_INCLUDE_ONCE) reduce 239) ((T_INLINE_HTML) reduce 239) ((T_INTERFACE) reduce 239) ((T_INT_CAST) reduce 239) ((T_ISSET) reduce 239) ((T_LINE) reduce 239) ((T_LIST) reduce 239) ((T_LNUMBER) reduce 239) ((T_MATCH) reduce 239) ((T_METHOD_C) reduce 239) ((T_NAME_FULLY_QUALIFIED) reduce 239) ((T_NAME_QUALIFIED) reduce 239) ((T_NAME_RELATIVE) reduce 239) ((T_NEW) reduce 239) ((T_NS_C) reduce 239) ((T_OBJECT_CAST) reduce 239) ((T_PRINT) reduce 239) ((T_READONLY) reduce 239) ((T_REQUIRE) reduce 239) ((T_REQUIRE_ONCE) reduce 239) ((T_RETURN) reduce 239) ((T_START_HEREDOC) reduce 239) ((T_STATIC) reduce 239) ((T_STRING) reduce 239) ((T_STRING_CAST) reduce 239) ((T_SWITCH) reduce 239) ((T_THROW) reduce 239) ((T_TRAIT) reduce 239) ((T_TRAIT_C) reduce 239) ((T_TRY) reduce 239) ((T_UNSET) reduce 239) ((T_UNSET_CAST) reduce 239) ((T_VARIABLE) reduce 239) ((T_WHILE) reduce 239) ((T_YIELD) reduce 239) ((T_YIELD_FROM) reduce 239) (("[") reduce 239) (("`") reduce 239) (("{") reduce 239) (("~") reduce 239)) 24417 ((("!") reduce 148) (("\"") reduce 148) (("$") reduce 148) (("(") reduce 148) (("+") reduce 148) (("-") reduce 148) ((";") reduce 148) (("@") reduce 148) ((T_ABSTRACT) reduce 148) ((T_ARRAY) reduce 148) ((T_ARRAY_CAST) reduce 148) ((T_ATTRIBUTE) reduce 148) ((T_BOOL_CAST) reduce 148) ((T_BREAK) reduce 148) ((T_CLASS) reduce 148) ((T_CLASS_C) reduce 148) ((T_CLONE) reduce 148) ((T_CONSTANT_ENCAPSED_STRING) reduce 148) ((T_CONTINUE) reduce 148) ((T_DEC) reduce 148) ((T_DECLARE) reduce 148) ((T_DIR) reduce 148) ((T_DNUMBER) reduce 148) ((T_DO) reduce 148) ((T_DOUBLE_CAST) reduce 148) ((T_ECHO) reduce 148) ((T_ELSE) reduce 148) ((T_ELSEIF) reduce 148) ((T_EMPTY) reduce 148) ((T_ENDIF) reduce 148) ((T_ENUM) reduce 148) ((T_EVAL) reduce 148) ((T_EXIT) reduce 148) ((T_FILE) reduce 148) ((T_FINAL) reduce 148) ((T_FN) reduce 148) ((T_FOR) reduce 148) ((T_FOREACH) reduce 148) ((T_FUNCTION) reduce 148) ((T_FUNC_C) reduce 148) ((T_GLOBAL) reduce 148) ((T_GOTO) reduce 148) ((T_HALT_COMPILER) reduce 148) ((T_IF) reduce 148) ((T_INC) reduce 148) ((T_INCLUDE) reduce 148) ((T_INCLUDE_ONCE) reduce 148) ((T_INLINE_HTML) reduce 148) ((T_INTERFACE) reduce 148) ((T_INT_CAST) reduce 148) ((T_ISSET) reduce 148) ((T_LINE) reduce 148) ((T_LIST) reduce 148) ((T_LNUMBER) reduce 148) ((T_MATCH) reduce 148) ((T_METHOD_C) reduce 148) ((T_NAME_FULLY_QUALIFIED) reduce 148) ((T_NAME_QUALIFIED) reduce 148) ((T_NAME_RELATIVE) reduce 148) ((T_NEW) reduce 148) ((T_NS_C) reduce 148) ((T_OBJECT_CAST) reduce 148) ((T_PRINT) reduce 148) ((T_READONLY) reduce 148) ((T_REQUIRE) reduce 148) ((T_REQUIRE_ONCE) reduce 148) ((T_RETURN) reduce 148) ((T_START_HEREDOC) reduce 148) ((T_STATIC) reduce 148) ((T_STRING) reduce 148) ((T_STRING_CAST) reduce 148) ((T_SWITCH) reduce 148) ((T_THROW) reduce 148) ((T_TRAIT) reduce 148) ((T_TRAIT_C) reduce 148) ((T_TRY) reduce 148) ((T_UNSET) reduce 148) ((T_UNSET_CAST) reduce 148) ((T_VARIABLE) reduce 148) ((T_WHILE) reduce 148) ((T_YIELD) reduce 148) ((T_YIELD_FROM) reduce 148) (("[") reduce 148) (("`") reduce 148) (("{") reduce 148) (("~") reduce 148)) 24420 ((("!") reduce 240) (("\"") reduce 240) (("$") reduce 240) (("(") reduce 240) (("+") reduce 240) (("-") reduce 240) ((";") reduce 240) (("@") reduce 240) ((T_ABSTRACT) reduce 240) ((T_ARRAY) reduce 240) ((T_ARRAY_CAST) reduce 240) ((T_ATTRIBUTE) reduce 240) ((T_BOOL_CAST) reduce 240) ((T_BREAK) reduce 240) ((T_CLASS) reduce 240) ((T_CLASS_C) reduce 240) ((T_CLONE) reduce 240) ((T_CONSTANT_ENCAPSED_STRING) reduce 240) ((T_CONTINUE) reduce 240) ((T_DEC) reduce 240) ((T_DECLARE) reduce 240) ((T_DIR) reduce 240) ((T_DNUMBER) reduce 240) ((T_DO) reduce 240) ((T_DOUBLE_CAST) reduce 240) ((T_ECHO) reduce 240) ((T_ELSE) reduce 240) ((T_ELSEIF) reduce 240) ((T_EMPTY) reduce 240) ((T_ENDIF) reduce 240) ((T_ENUM) reduce 240) ((T_EVAL) reduce 240) ((T_EXIT) reduce 240) ((T_FILE) reduce 240) ((T_FINAL) reduce 240) ((T_FN) reduce 240) ((T_FOR) reduce 240) ((T_FOREACH) reduce 240) ((T_FUNCTION) reduce 240) ((T_FUNC_C) reduce 240) ((T_GLOBAL) reduce 240) ((T_GOTO) reduce 240) ((T_HALT_COMPILER) reduce 240) ((T_IF) reduce 240) ((T_INC) reduce 240) ((T_INCLUDE) reduce 240) ((T_INCLUDE_ONCE) reduce 240) ((T_INLINE_HTML) reduce 240) ((T_INTERFACE) reduce 240) ((T_INT_CAST) reduce 240) ((T_ISSET) reduce 240) ((T_LINE) reduce 240) ((T_LIST) reduce 240) ((T_LNUMBER) reduce 240) ((T_MATCH) reduce 240) ((T_METHOD_C) reduce 240) ((T_NAME_FULLY_QUALIFIED) reduce 240) ((T_NAME_QUALIFIED) reduce 240) ((T_NAME_RELATIVE) reduce 240) ((T_NEW) reduce 240) ((T_NS_C) reduce 240) ((T_OBJECT_CAST) reduce 240) ((T_PRINT) reduce 240) ((T_READONLY) reduce 240) ((T_REQUIRE) reduce 240) ((T_REQUIRE_ONCE) reduce 240) ((T_RETURN) reduce 240) ((T_START_HEREDOC) reduce 240) ((T_STATIC) reduce 240) ((T_STRING) reduce 240) ((T_STRING_CAST) reduce 240) ((T_SWITCH) reduce 240) ((T_THROW) reduce 240) ((T_TRAIT) reduce 240) ((T_TRAIT_C) reduce 240) ((T_TRY) reduce 240) ((T_UNSET) reduce 240) ((T_UNSET_CAST) reduce 240) ((T_VARIABLE) reduce 240) ((T_WHILE) reduce 240) ((T_YIELD) reduce 240) ((T_YIELD_FROM) reduce 240) (("[") reduce 240) (("`") reduce 240) (("{") reduce 240) (("~") reduce 240)) 24425 ((("!") reduce 160) (("\"") reduce 160) (("$") reduce 160) (("(") reduce 160) (("+") reduce 160) (("-") reduce 160) ((";") reduce 160) (("@") reduce 160) ((T_ABSTRACT) reduce 160) ((T_ARRAY) reduce 160) ((T_ARRAY_CAST) reduce 160) ((T_ATTRIBUTE) reduce 160) ((T_BOOL_CAST) reduce 160) ((T_BREAK) reduce 160) ((T_CLASS) reduce 160) ((T_CLASS_C) reduce 160) ((T_CLONE) reduce 160) ((T_CONSTANT_ENCAPSED_STRING) reduce 160) ((T_CONTINUE) reduce 160) ((T_DEC) reduce 160) ((T_DECLARE) reduce 160) ((T_DIR) reduce 160) ((T_DNUMBER) reduce 160) ((T_DO) reduce 160) ((T_DOUBLE_CAST) reduce 160) ((T_ECHO) reduce 160) ((T_ELSE) reduce 160) ((T_ELSEIF) reduce 160) ((T_EMPTY) reduce 160) ((T_ENDIF) reduce 160) ((T_ENUM) reduce 160) ((T_EVAL) reduce 160) ((T_EXIT) reduce 160) ((T_FILE) reduce 160) ((T_FINAL) reduce 160) ((T_FN) reduce 160) ((T_FOR) reduce 160) ((T_FOREACH) reduce 160) ((T_FUNCTION) reduce 160) ((T_FUNC_C) reduce 160) ((T_GLOBAL) reduce 160) ((T_GOTO) reduce 160) ((T_HALT_COMPILER) reduce 160) ((T_IF) reduce 160) ((T_INC) reduce 160) ((T_INCLUDE) reduce 160) ((T_INCLUDE_ONCE) reduce 160) ((T_INLINE_HTML) reduce 160) ((T_INTERFACE) reduce 160) ((T_INT_CAST) reduce 160) ((T_ISSET) reduce 160) ((T_LINE) reduce 160) ((T_LIST) reduce 160) ((T_LNUMBER) reduce 160) ((T_MATCH) reduce 160) ((T_METHOD_C) reduce 160) ((T_NAME_FULLY_QUALIFIED) reduce 160) ((T_NAME_QUALIFIED) reduce 160) ((T_NAME_RELATIVE) reduce 160) ((T_NEW) reduce 160) ((T_NS_C) reduce 160) ((T_OBJECT_CAST) reduce 160) ((T_PRINT) reduce 160) ((T_READONLY) reduce 160) ((T_REQUIRE) reduce 160) ((T_REQUIRE_ONCE) reduce 160) ((T_RETURN) reduce 160) ((T_START_HEREDOC) reduce 160) ((T_STATIC) reduce 160) ((T_STRING) reduce 160) ((T_STRING_CAST) reduce 160) ((T_SWITCH) reduce 160) ((T_THROW) reduce 160) ((T_TRAIT) reduce 160) ((T_TRAIT_C) reduce 160) ((T_TRY) reduce 160) ((T_UNSET) reduce 160) ((T_UNSET_CAST) reduce 160) ((T_VARIABLE) reduce 160) ((T_WHILE) reduce 160) ((T_YIELD) reduce 160) ((T_YIELD_FROM) reduce 160) (("[") reduce 160) (("`") reduce 160) (("{") reduce 160) (("~") reduce 160)) 24428 ((("!") reduce 168) (("\"") reduce 168) (("$") reduce 168) (("(") reduce 168) (("+") reduce 168) (("-") reduce 168) ((";") reduce 168) (("@") reduce 168) ((T_ABSTRACT) reduce 168) ((T_ARRAY) reduce 168) ((T_ARRAY_CAST) reduce 168) ((T_ATTRIBUTE) reduce 168) ((T_BOOL_CAST) reduce 168) ((T_BREAK) reduce 168) ((T_CATCH) reduce 168) ((T_CLASS) reduce 168) ((T_CLASS_C) reduce 168) ((T_CLONE) reduce 168) ((T_CONSTANT_ENCAPSED_STRING) reduce 168) ((T_CONTINUE) reduce 168) ((T_DEC) reduce 168) ((T_DECLARE) reduce 168) ((T_DIR) reduce 168) ((T_DNUMBER) reduce 168) ((T_DO) reduce 168) ((T_DOUBLE_CAST) reduce 168) ((T_ECHO) reduce 168) ((T_ELSE) reduce 168) ((T_ELSEIF) reduce 168) ((T_EMPTY) reduce 168) ((T_ENDIF) reduce 168) ((T_ENUM) reduce 168) ((T_EVAL) reduce 168) ((T_EXIT) reduce 168) ((T_FILE) reduce 168) ((T_FINAL) reduce 168) ((T_FINALLY) reduce 168) ((T_FN) reduce 168) ((T_FOR) reduce 168) ((T_FOREACH) reduce 168) ((T_FUNCTION) reduce 168) ((T_FUNC_C) reduce 168) ((T_GLOBAL) reduce 168) ((T_GOTO) reduce 168) ((T_HALT_COMPILER) reduce 168) ((T_IF) reduce 168) ((T_INC) reduce 168) ((T_INCLUDE) reduce 168) ((T_INCLUDE_ONCE) reduce 168) ((T_INLINE_HTML) reduce 168) ((T_INTERFACE) reduce 168) ((T_INT_CAST) reduce 168) ((T_ISSET) reduce 168) ((T_LINE) reduce 168) ((T_LIST) reduce 168) ((T_LNUMBER) reduce 168) ((T_MATCH) reduce 168) ((T_METHOD_C) reduce 168) ((T_NAME_FULLY_QUALIFIED) reduce 168) ((T_NAME_QUALIFIED) reduce 168) ((T_NAME_RELATIVE) reduce 168) ((T_NEW) reduce 168) ((T_NS_C) reduce 168) ((T_OBJECT_CAST) reduce 168) ((T_PRINT) reduce 168) ((T_READONLY) reduce 168) ((T_REQUIRE) reduce 168) ((T_REQUIRE_ONCE) reduce 168) ((T_RETURN) reduce 168) ((T_START_HEREDOC) reduce 168) ((T_STATIC) reduce 168) ((T_STRING) reduce 168) ((T_STRING_CAST) reduce 168) ((T_SWITCH) reduce 168) ((T_THROW) reduce 168) ((T_TRAIT) reduce 168) ((T_TRAIT_C) reduce 168) ((T_TRY) reduce 168) ((T_UNSET) reduce 168) ((T_UNSET_CAST) reduce 168) ((T_VARIABLE) reduce 168) ((T_WHILE) reduce 168) ((T_YIELD) reduce 168) ((T_YIELD_FROM) reduce 168) (("[") reduce 168) (("`") reduce 168) (("{") reduce 168) (("~") reduce 168)) 24429 ((("!") reduce 174) (("\"") reduce 174) (("$") reduce 174) (("(") reduce 174) (("+") reduce 174) (("-") reduce 174) ((";") reduce 174) (("@") reduce 174) ((T_ABSTRACT) reduce 174) ((T_ARRAY) reduce 174) ((T_ARRAY_CAST) reduce 174) ((T_ATTRIBUTE) reduce 174) ((T_BOOL_CAST) reduce 174) ((T_BREAK) reduce 174) ((T_CATCH) shift) ((T_CLASS) reduce 174) ((T_CLASS_C) reduce 174) ((T_CLONE) reduce 174) ((T_CONSTANT_ENCAPSED_STRING) reduce 174) ((T_CONTINUE) reduce 174) ((T_DEC) reduce 174) ((T_DECLARE) reduce 174) ((T_DIR) reduce 174) ((T_DNUMBER) reduce 174) ((T_DO) reduce 174) ((T_DOUBLE_CAST) reduce 174) ((T_ECHO) reduce 174) ((T_ELSE) reduce 174) ((T_ELSEIF) reduce 174) ((T_EMPTY) reduce 174) ((T_ENDIF) reduce 174) ((T_ENUM) reduce 174) ((T_EVAL) reduce 174) ((T_EXIT) reduce 174) ((T_FILE) reduce 174) ((T_FINAL) reduce 174) ((T_FINALLY) shift) ((T_FN) reduce 174) ((T_FOR) reduce 174) ((T_FOREACH) reduce 174) ((T_FUNCTION) reduce 174) ((T_FUNC_C) reduce 174) ((T_GLOBAL) reduce 174) ((T_GOTO) reduce 174) ((T_HALT_COMPILER) reduce 174) ((T_IF) reduce 174) ((T_INC) reduce 174) ((T_INCLUDE) reduce 174) ((T_INCLUDE_ONCE) reduce 174) ((T_INLINE_HTML) reduce 174) ((T_INTERFACE) reduce 174) ((T_INT_CAST) reduce 174) ((T_ISSET) reduce 174) ((T_LINE) reduce 174) ((T_LIST) reduce 174) ((T_LNUMBER) reduce 174) ((T_MATCH) reduce 174) ((T_METHOD_C) reduce 174) ((T_NAME_FULLY_QUALIFIED) reduce 174) ((T_NAME_QUALIFIED) reduce 174) ((T_NAME_RELATIVE) reduce 174) ((T_NEW) reduce 174) ((T_NS_C) reduce 174) ((T_OBJECT_CAST) reduce 174) ((T_PRINT) reduce 174) ((T_READONLY) reduce 174) ((T_REQUIRE) reduce 174) ((T_REQUIRE_ONCE) reduce 174) ((T_RETURN) reduce 174) ((T_START_HEREDOC) reduce 174) ((T_STATIC) reduce 174) ((T_STRING) reduce 174) ((T_STRING_CAST) reduce 174) ((T_SWITCH) reduce 174) ((T_THROW) reduce 174) ((T_TRAIT) reduce 174) ((T_TRAIT_C) reduce 174) ((T_TRY) reduce 174) ((T_UNSET) reduce 174) ((T_UNSET_CAST) reduce 174) ((T_VARIABLE) reduce 174) ((T_WHILE) reduce 174) ((T_YIELD) reduce 174) ((T_YIELD_FROM) reduce 174) (("[") reduce 174) (("`") reduce 174) (("{") reduce 174) (("~") reduce 174)) 24432 ((("!") reduce 165) (("\"") reduce 165) (("$") reduce 165) (("(") reduce 165) (("+") reduce 165) (("-") reduce 165) ((";") reduce 165) (("@") reduce 165) ((T_ABSTRACT) reduce 165) ((T_ARRAY) reduce 165) ((T_ARRAY_CAST) reduce 165) ((T_ATTRIBUTE) reduce 165) ((T_BOOL_CAST) reduce 165) ((T_BREAK) reduce 165) ((T_CLASS) reduce 165) ((T_CLASS_C) reduce 165) ((T_CLONE) reduce 165) ((T_CONSTANT_ENCAPSED_STRING) reduce 165) ((T_CONTINUE) reduce 165) ((T_DEC) reduce 165) ((T_DECLARE) reduce 165) ((T_DIR) reduce 165) ((T_DNUMBER) reduce 165) ((T_DO) reduce 165) ((T_DOUBLE_CAST) reduce 165) ((T_ECHO) reduce 165) ((T_ELSE) reduce 165) ((T_ELSEIF) reduce 165) ((T_EMPTY) reduce 165) ((T_ENDIF) reduce 165) ((T_ENUM) reduce 165) ((T_EVAL) reduce 165) ((T_EXIT) reduce 165) ((T_FILE) reduce 165) ((T_FINAL) reduce 165) ((T_FN) reduce 165) ((T_FOR) reduce 165) ((T_FOREACH) reduce 165) ((T_FUNCTION) reduce 165) ((T_FUNC_C) reduce 165) ((T_GLOBAL) reduce 165) ((T_GOTO) reduce 165) ((T_HALT_COMPILER) reduce 165) ((T_IF) reduce 165) ((T_INC) reduce 165) ((T_INCLUDE) reduce 165) ((T_INCLUDE_ONCE) reduce 165) ((T_INLINE_HTML) reduce 165) ((T_INTERFACE) reduce 165) ((T_INT_CAST) reduce 165) ((T_ISSET) reduce 165) ((T_LINE) reduce 165) ((T_LIST) reduce 165) ((T_LNUMBER) reduce 165) ((T_MATCH) reduce 165) ((T_METHOD_C) reduce 165) ((T_NAME_FULLY_QUALIFIED) reduce 165) ((T_NAME_QUALIFIED) reduce 165) ((T_NAME_RELATIVE) reduce 165) ((T_NEW) reduce 165) ((T_NS_C) reduce 165) ((T_OBJECT_CAST) reduce 165) ((T_PRINT) reduce 165) ((T_READONLY) reduce 165) ((T_REQUIRE) reduce 165) ((T_REQUIRE_ONCE) reduce 165) ((T_RETURN) reduce 165) ((T_START_HEREDOC) reduce 165) ((T_STATIC) reduce 165) ((T_STRING) reduce 165) ((T_STRING_CAST) reduce 165) ((T_SWITCH) reduce 165) ((T_THROW) reduce 165) ((T_TRAIT) reduce 165) ((T_TRAIT_C) reduce 165) ((T_TRY) reduce 165) ((T_UNSET) reduce 165) ((T_UNSET_CAST) reduce 165) ((T_VARIABLE) reduce 165) ((T_WHILE) reduce 165) ((T_YIELD) reduce 165) ((T_YIELD_FROM) reduce 165) (("[") reduce 165) (("`") reduce 165) (("{") reduce 165) (("~") reduce 165)) 24435 ((("!") reduce 175) (("\"") reduce 175) (("$") reduce 175) (("(") reduce 175) (("+") reduce 175) (("-") reduce 175) ((";") reduce 175) (("@") reduce 175) ((T_ABSTRACT) reduce 175) ((T_ARRAY) reduce 175) ((T_ARRAY_CAST) reduce 175) ((T_ATTRIBUTE) reduce 175) ((T_BOOL_CAST) reduce 175) ((T_BREAK) reduce 175) ((T_CLASS) reduce 175) ((T_CLASS_C) reduce 175) ((T_CLONE) reduce 175) ((T_CONSTANT_ENCAPSED_STRING) reduce 175) ((T_CONTINUE) reduce 175) ((T_DEC) reduce 175) ((T_DECLARE) reduce 175) ((T_DIR) reduce 175) ((T_DNUMBER) reduce 175) ((T_DO) reduce 175) ((T_DOUBLE_CAST) reduce 175) ((T_ECHO) reduce 175) ((T_ELSE) reduce 175) ((T_ELSEIF) reduce 175) ((T_EMPTY) reduce 175) ((T_ENDIF) reduce 175) ((T_ENUM) reduce 175) ((T_EVAL) reduce 175) ((T_EXIT) reduce 175) ((T_FILE) reduce 175) ((T_FINAL) reduce 175) ((T_FN) reduce 175) ((T_FOR) reduce 175) ((T_FOREACH) reduce 175) ((T_FUNCTION) reduce 175) ((T_FUNC_C) reduce 175) ((T_GLOBAL) reduce 175) ((T_GOTO) reduce 175) ((T_HALT_COMPILER) reduce 175) ((T_IF) reduce 175) ((T_INC) reduce 175) ((T_INCLUDE) reduce 175) ((T_INCLUDE_ONCE) reduce 175) ((T_INLINE_HTML) reduce 175) ((T_INTERFACE) reduce 175) ((T_INT_CAST) reduce 175) ((T_ISSET) reduce 175) ((T_LINE) reduce 175) ((T_LIST) reduce 175) ((T_LNUMBER) reduce 175) ((T_MATCH) reduce 175) ((T_METHOD_C) reduce 175) ((T_NAME_FULLY_QUALIFIED) reduce 175) ((T_NAME_QUALIFIED) reduce 175) ((T_NAME_RELATIVE) reduce 175) ((T_NEW) reduce 175) ((T_NS_C) reduce 175) ((T_OBJECT_CAST) reduce 175) ((T_PRINT) reduce 175) ((T_READONLY) reduce 175) ((T_REQUIRE) reduce 175) ((T_REQUIRE_ONCE) reduce 175) ((T_RETURN) reduce 175) ((T_START_HEREDOC) reduce 175) ((T_STATIC) reduce 175) ((T_STRING) reduce 175) ((T_STRING_CAST) reduce 175) ((T_SWITCH) reduce 175) ((T_THROW) reduce 175) ((T_TRAIT) reduce 175) ((T_TRAIT_C) reduce 175) ((T_TRY) reduce 175) ((T_UNSET) reduce 175) ((T_UNSET_CAST) reduce 175) ((T_VARIABLE) reduce 175) ((T_WHILE) reduce 175) ((T_YIELD) reduce 175) ((T_YIELD_FROM) reduce 175) (("[") reduce 175) (("`") reduce 175) (("{") reduce 175) (("~") reduce 175)) 24442 ((("!") reduce 169) (("\"") reduce 169) (("$") reduce 169) (("(") reduce 169) (("+") reduce 169) (("-") reduce 169) ((";") reduce 169) (("@") reduce 169) ((T_ABSTRACT) reduce 169) ((T_ARRAY) reduce 169) ((T_ARRAY_CAST) reduce 169) ((T_ATTRIBUTE) reduce 169) ((T_BOOL_CAST) reduce 169) ((T_BREAK) reduce 169) ((T_CATCH) reduce 169) ((T_CLASS) reduce 169) ((T_CLASS_C) reduce 169) ((T_CLONE) reduce 169) ((T_CONSTANT_ENCAPSED_STRING) reduce 169) ((T_CONTINUE) reduce 169) ((T_DEC) reduce 169) ((T_DECLARE) reduce 169) ((T_DIR) reduce 169) ((T_DNUMBER) reduce 169) ((T_DO) reduce 169) ((T_DOUBLE_CAST) reduce 169) ((T_ECHO) reduce 169) ((T_ELSE) reduce 169) ((T_ELSEIF) reduce 169) ((T_EMPTY) reduce 169) ((T_ENDIF) reduce 169) ((T_ENUM) reduce 169) ((T_EVAL) reduce 169) ((T_EXIT) reduce 169) ((T_FILE) reduce 169) ((T_FINAL) reduce 169) ((T_FINALLY) reduce 169) ((T_FN) reduce 169) ((T_FOR) reduce 169) ((T_FOREACH) reduce 169) ((T_FUNCTION) reduce 169) ((T_FUNC_C) reduce 169) ((T_GLOBAL) reduce 169) ((T_GOTO) reduce 169) ((T_HALT_COMPILER) reduce 169) ((T_IF) reduce 169) ((T_INC) reduce 169) ((T_INCLUDE) reduce 169) ((T_INCLUDE_ONCE) reduce 169) ((T_INLINE_HTML) reduce 169) ((T_INTERFACE) reduce 169) ((T_INT_CAST) reduce 169) ((T_ISSET) reduce 169) ((T_LINE) reduce 169) ((T_LIST) reduce 169) ((T_LNUMBER) reduce 169) ((T_MATCH) reduce 169) ((T_METHOD_C) reduce 169) ((T_NAME_FULLY_QUALIFIED) reduce 169) ((T_NAME_QUALIFIED) reduce 169) ((T_NAME_RELATIVE) reduce 169) ((T_NEW) reduce 169) ((T_NS_C) reduce 169) ((T_OBJECT_CAST) reduce 169) ((T_PRINT) reduce 169) ((T_READONLY) reduce 169) ((T_REQUIRE) reduce 169) ((T_REQUIRE_ONCE) reduce 169) ((T_RETURN) reduce 169) ((T_START_HEREDOC) reduce 169) ((T_STATIC) reduce 169) ((T_STRING) reduce 169) ((T_STRING_CAST) reduce 169) ((T_SWITCH) reduce 169) ((T_THROW) reduce 169) ((T_TRAIT) reduce 169) ((T_TRAIT_C) reduce 169) ((T_TRY) reduce 169) ((T_UNSET) reduce 169) ((T_UNSET_CAST) reduce 169) ((T_VARIABLE) reduce 169) ((T_WHILE) reduce 169) ((T_YIELD) reduce 169) ((T_YIELD_FROM) reduce 169) (("[") reduce 169) (("`") reduce 169) (("{") reduce 169) (("~") reduce 169)) 24447 ((("!") reduce 197) (("\"") reduce 197) (("$") reduce 197) (("(") reduce 197) (("+") reduce 197) (("-") reduce 197) ((";") reduce 197) (("@") reduce 197) ((T_ABSTRACT) reduce 197) ((T_ARRAY) reduce 197) ((T_ARRAY_CAST) reduce 197) ((T_ATTRIBUTE) reduce 197) ((T_BOOL_CAST) reduce 197) ((T_BREAK) reduce 197) ((T_CLASS) reduce 197) ((T_CLASS_C) reduce 197) ((T_CLONE) reduce 197) ((T_CONSTANT_ENCAPSED_STRING) reduce 197) ((T_CONTINUE) reduce 197) ((T_DEC) reduce 197) ((T_DECLARE) reduce 197) ((T_DIR) reduce 197) ((T_DNUMBER) reduce 197) ((T_DO) reduce 197) ((T_DOUBLE_CAST) reduce 197) ((T_ECHO) reduce 197) ((T_ELSE) reduce 197) ((T_ELSEIF) reduce 197) ((T_EMPTY) reduce 197) ((T_ENDIF) reduce 197) ((T_ENUM) reduce 197) ((T_EVAL) reduce 197) ((T_EXIT) reduce 197) ((T_FILE) reduce 197) ((T_FINAL) reduce 197) ((T_FN) reduce 197) ((T_FOR) reduce 197) ((T_FOREACH) reduce 197) ((T_FUNCTION) reduce 197) ((T_FUNC_C) reduce 197) ((T_GLOBAL) reduce 197) ((T_GOTO) reduce 197) ((T_HALT_COMPILER) reduce 197) ((T_IF) reduce 197) ((T_INC) reduce 197) ((T_INCLUDE) reduce 197) ((T_INCLUDE_ONCE) reduce 197) ((T_INLINE_HTML) reduce 197) ((T_INTERFACE) reduce 197) ((T_INT_CAST) reduce 197) ((T_ISSET) reduce 197) ((T_LINE) reduce 197) ((T_LIST) reduce 197) ((T_LNUMBER) reduce 197) ((T_MATCH) reduce 197) ((T_METHOD_C) reduce 197) ((T_NAME_FULLY_QUALIFIED) reduce 197) ((T_NAME_QUALIFIED) reduce 197) ((T_NAME_RELATIVE) reduce 197) ((T_NEW) reduce 197) ((T_NS_C) reduce 197) ((T_OBJECT_CAST) reduce 197) ((T_PRINT) reduce 197) ((T_READONLY) reduce 197) ((T_REQUIRE) reduce 197) ((T_REQUIRE_ONCE) reduce 197) ((T_RETURN) reduce 197) ((T_START_HEREDOC) reduce 197) ((T_STATIC) reduce 197) ((T_STRING) reduce 197) ((T_STRING_CAST) reduce 197) ((T_SWITCH) reduce 197) ((T_THROW) reduce 197) ((T_TRAIT) reduce 197) ((T_TRAIT_C) reduce 197) ((T_TRY) reduce 197) ((T_UNSET) reduce 197) ((T_UNSET_CAST) reduce 197) ((T_VARIABLE) reduce 197) ((T_WHILE) reduce 197) ((T_YIELD) reduce 197) ((T_YIELD_FROM) reduce 197) (("[") reduce 197) (("`") reduce 197) (("{") reduce 197) (("~") reduce 197)) 24452 ((("!") reduce 151) (("\"") reduce 151) (("$") reduce 151) (("(") reduce 151) (("+") reduce 151) (("-") reduce 151) ((";") reduce 151) (("@") reduce 151) ((T_ABSTRACT) reduce 151) ((T_ARRAY) reduce 151) ((T_ARRAY_CAST) reduce 151) ((T_ATTRIBUTE) reduce 151) ((T_BOOL_CAST) reduce 151) ((T_BREAK) reduce 151) ((T_CLASS) reduce 151) ((T_CLASS_C) reduce 151) ((T_CLONE) reduce 151) ((T_CONSTANT_ENCAPSED_STRING) reduce 151) ((T_CONTINUE) reduce 151) ((T_DEC) reduce 151) ((T_DECLARE) reduce 151) ((T_DIR) reduce 151) ((T_DNUMBER) reduce 151) ((T_DO) reduce 151) ((T_DOUBLE_CAST) reduce 151) ((T_ECHO) reduce 151) ((T_ELSE) reduce 151) ((T_ELSEIF) reduce 151) ((T_EMPTY) reduce 151) ((T_ENDIF) reduce 151) ((T_ENUM) reduce 151) ((T_EVAL) reduce 151) ((T_EXIT) reduce 151) ((T_FILE) reduce 151) ((T_FINAL) reduce 151) ((T_FN) reduce 151) ((T_FOR) reduce 151) ((T_FOREACH) reduce 151) ((T_FUNCTION) reduce 151) ((T_FUNC_C) reduce 151) ((T_GLOBAL) reduce 151) ((T_GOTO) reduce 151) ((T_HALT_COMPILER) reduce 151) ((T_IF) reduce 151) ((T_INC) reduce 151) ((T_INCLUDE) reduce 151) ((T_INCLUDE_ONCE) reduce 151) ((T_INLINE_HTML) reduce 151) ((T_INTERFACE) reduce 151) ((T_INT_CAST) reduce 151) ((T_ISSET) reduce 151) ((T_LINE) reduce 151) ((T_LIST) reduce 151) ((T_LNUMBER) reduce 151) ((T_MATCH) reduce 151) ((T_METHOD_C) reduce 151) ((T_NAME_FULLY_QUALIFIED) reduce 151) ((T_NAME_QUALIFIED) reduce 151) ((T_NAME_RELATIVE) reduce 151) ((T_NEW) reduce 151) ((T_NS_C) reduce 151) ((T_OBJECT_CAST) reduce 151) ((T_PRINT) reduce 151) ((T_READONLY) reduce 151) ((T_REQUIRE) reduce 151) ((T_REQUIRE_ONCE) reduce 151) ((T_RETURN) reduce 151) ((T_START_HEREDOC) reduce 151) ((T_STATIC) reduce 151) ((T_STRING) reduce 151) ((T_STRING_CAST) reduce 151) ((T_SWITCH) reduce 151) ((T_THROW) reduce 151) ((T_TRAIT) reduce 151) ((T_TRAIT_C) reduce 151) ((T_TRY) reduce 151) ((T_UNSET) reduce 151) ((T_UNSET_CAST) reduce 151) ((T_VARIABLE) reduce 151) ((T_WHILE) reduce 151) ((T_YIELD) reduce 151) ((T_YIELD_FROM) reduce 151) (("[") reduce 151) (("`") reduce 151) (("{") reduce 151) (("~") reduce 151)) 24456 ((("!") reduce 221) (("\"") reduce 221) (("$") reduce 221) (("(") reduce 221) (("+") reduce 221) (("-") reduce 221) ((";") reduce 221) (("@") reduce 221) ((T_ABSTRACT) reduce 221) ((T_ARRAY) reduce 221) ((T_ARRAY_CAST) reduce 221) ((T_ATTRIBUTE) reduce 221) ((T_BOOL_CAST) reduce 221) ((T_BREAK) reduce 221) ((T_CLASS) reduce 221) ((T_CLASS_C) reduce 221) ((T_CLONE) reduce 221) ((T_CONSTANT_ENCAPSED_STRING) reduce 221) ((T_CONTINUE) reduce 221) ((T_DEC) reduce 221) ((T_DECLARE) reduce 221) ((T_DIR) reduce 221) ((T_DNUMBER) reduce 221) ((T_DO) reduce 221) ((T_DOUBLE_CAST) reduce 221) ((T_ECHO) reduce 221) ((T_ELSE) reduce 221) ((T_ELSEIF) reduce 221) ((T_EMPTY) reduce 221) ((T_ENDIF) reduce 221) ((T_ENUM) reduce 221) ((T_EVAL) reduce 221) ((T_EXIT) reduce 221) ((T_FILE) reduce 221) ((T_FINAL) reduce 221) ((T_FN) reduce 221) ((T_FOR) reduce 221) ((T_FOREACH) reduce 221) ((T_FUNCTION) reduce 221) ((T_FUNC_C) reduce 221) ((T_GLOBAL) reduce 221) ((T_GOTO) reduce 221) ((T_HALT_COMPILER) reduce 221) ((T_IF) reduce 221) ((T_INC) reduce 221) ((T_INCLUDE) reduce 221) ((T_INCLUDE_ONCE) reduce 221) ((T_INLINE_HTML) reduce 221) ((T_INTERFACE) reduce 221) ((T_INT_CAST) reduce 221) ((T_ISSET) reduce 221) ((T_LINE) reduce 221) ((T_LIST) reduce 221) ((T_LNUMBER) reduce 221) ((T_MATCH) reduce 221) ((T_METHOD_C) reduce 221) ((T_NAME_FULLY_QUALIFIED) reduce 221) ((T_NAME_QUALIFIED) reduce 221) ((T_NAME_RELATIVE) reduce 221) ((T_NEW) reduce 221) ((T_NS_C) reduce 221) ((T_OBJECT_CAST) reduce 221) ((T_PRINT) reduce 221) ((T_READONLY) reduce 221) ((T_REQUIRE) reduce 221) ((T_REQUIRE_ONCE) reduce 221) ((T_RETURN) reduce 221) ((T_START_HEREDOC) reduce 221) ((T_STATIC) reduce 221) ((T_STRING) reduce 221) ((T_STRING_CAST) reduce 221) ((T_SWITCH) reduce 221) ((T_THROW) reduce 221) ((T_TRAIT) reduce 221) ((T_TRAIT_C) reduce 221) ((T_TRY) reduce 221) ((T_UNSET) reduce 221) ((T_UNSET_CAST) reduce 221) ((T_VARIABLE) reduce 221) ((T_WHILE) reduce 221) ((T_YIELD) reduce 221) ((T_YIELD_FROM) reduce 221) (("[") reduce 221) (("`") reduce 221) (("{") reduce 221) (("~") reduce 221)) 24458 ((("!") reduce 222) (("\"") reduce 222) (("$") reduce 222) (("(") reduce 222) (("+") reduce 222) (("-") reduce 222) ((";") reduce 222) (("@") reduce 222) ((T_ABSTRACT) reduce 222) ((T_ARRAY) reduce 222) ((T_ARRAY_CAST) reduce 222) ((T_ATTRIBUTE) reduce 222) ((T_BOOL_CAST) reduce 222) ((T_BREAK) reduce 222) ((T_CLASS) reduce 222) ((T_CLASS_C) reduce 222) ((T_CLONE) reduce 222) ((T_CONSTANT_ENCAPSED_STRING) reduce 222) ((T_CONTINUE) reduce 222) ((T_DEC) reduce 222) ((T_DECLARE) reduce 222) ((T_DIR) reduce 222) ((T_DNUMBER) reduce 222) ((T_DO) reduce 222) ((T_DOUBLE_CAST) reduce 222) ((T_ECHO) reduce 222) ((T_ELSE) reduce 222) ((T_ELSEIF) reduce 222) ((T_EMPTY) reduce 222) ((T_ENDIF) reduce 222) ((T_ENUM) reduce 222) ((T_EVAL) reduce 222) ((T_EXIT) reduce 222) ((T_FILE) reduce 222) ((T_FINAL) reduce 222) ((T_FN) reduce 222) ((T_FOR) reduce 222) ((T_FOREACH) reduce 222) ((T_FUNCTION) reduce 222) ((T_FUNC_C) reduce 222) ((T_GLOBAL) reduce 222) ((T_GOTO) reduce 222) ((T_HALT_COMPILER) reduce 222) ((T_IF) reduce 222) ((T_INC) reduce 222) ((T_INCLUDE) reduce 222) ((T_INCLUDE_ONCE) reduce 222) ((T_INLINE_HTML) reduce 222) ((T_INTERFACE) reduce 222) ((T_INT_CAST) reduce 222) ((T_ISSET) reduce 222) ((T_LINE) reduce 222) ((T_LIST) reduce 222) ((T_LNUMBER) reduce 222) ((T_MATCH) reduce 222) ((T_METHOD_C) reduce 222) ((T_NAME_FULLY_QUALIFIED) reduce 222) ((T_NAME_QUALIFIED) reduce 222) ((T_NAME_RELATIVE) reduce 222) ((T_NEW) reduce 222) ((T_NS_C) reduce 222) ((T_OBJECT_CAST) reduce 222) ((T_PRINT) reduce 222) ((T_READONLY) reduce 222) ((T_REQUIRE) reduce 222) ((T_REQUIRE_ONCE) reduce 222) ((T_RETURN) reduce 222) ((T_START_HEREDOC) reduce 222) ((T_STATIC) reduce 222) ((T_STRING) reduce 222) ((T_STRING_CAST) reduce 222) ((T_SWITCH) reduce 222) ((T_THROW) reduce 222) ((T_TRAIT) reduce 222) ((T_TRAIT_C) reduce 222) ((T_TRY) reduce 222) ((T_UNSET) reduce 222) ((T_UNSET_CAST) reduce 222) ((T_VARIABLE) reduce 222) ((T_WHILE) reduce 222) ((T_YIELD) reduce 222) ((T_YIELD_FROM) reduce 222) (("[") reduce 222) (("`") reduce 222) (("{") reduce 222) (("~") reduce 222)) 24462 ((("!") reduce 223) (("\"") reduce 223) (("$") reduce 223) (("(") reduce 223) (("+") reduce 223) (("-") reduce 223) ((";") reduce 223) (("@") reduce 223) ((T_ABSTRACT) reduce 223) ((T_ARRAY) reduce 223) ((T_ARRAY_CAST) reduce 223) ((T_ATTRIBUTE) reduce 223) ((T_BOOL_CAST) reduce 223) ((T_BREAK) reduce 223) ((T_CLASS) reduce 223) ((T_CLASS_C) reduce 223) ((T_CLONE) reduce 223) ((T_CONSTANT_ENCAPSED_STRING) reduce 223) ((T_CONTINUE) reduce 223) ((T_DEC) reduce 223) ((T_DECLARE) reduce 223) ((T_DIR) reduce 223) ((T_DNUMBER) reduce 223) ((T_DO) reduce 223) ((T_DOUBLE_CAST) reduce 223) ((T_ECHO) reduce 223) ((T_ELSE) reduce 223) ((T_ELSEIF) reduce 223) ((T_EMPTY) reduce 223) ((T_ENDIF) reduce 223) ((T_ENUM) reduce 223) ((T_EVAL) reduce 223) ((T_EXIT) reduce 223) ((T_FILE) reduce 223) ((T_FINAL) reduce 223) ((T_FN) reduce 223) ((T_FOR) reduce 223) ((T_FOREACH) reduce 223) ((T_FUNCTION) reduce 223) ((T_FUNC_C) reduce 223) ((T_GLOBAL) reduce 223) ((T_GOTO) reduce 223) ((T_HALT_COMPILER) reduce 223) ((T_IF) reduce 223) ((T_INC) reduce 223) ((T_INCLUDE) reduce 223) ((T_INCLUDE_ONCE) reduce 223) ((T_INLINE_HTML) reduce 223) ((T_INTERFACE) reduce 223) ((T_INT_CAST) reduce 223) ((T_ISSET) reduce 223) ((T_LINE) reduce 223) ((T_LIST) reduce 223) ((T_LNUMBER) reduce 223) ((T_MATCH) reduce 223) ((T_METHOD_C) reduce 223) ((T_NAME_FULLY_QUALIFIED) reduce 223) ((T_NAME_QUALIFIED) reduce 223) ((T_NAME_RELATIVE) reduce 223) ((T_NEW) reduce 223) ((T_NS_C) reduce 223) ((T_OBJECT_CAST) reduce 223) ((T_PRINT) reduce 223) ((T_READONLY) reduce 223) ((T_REQUIRE) reduce 223) ((T_REQUIRE_ONCE) reduce 223) ((T_RETURN) reduce 223) ((T_START_HEREDOC) reduce 223) ((T_STATIC) reduce 223) ((T_STRING) reduce 223) ((T_STRING_CAST) reduce 223) ((T_SWITCH) reduce 223) ((T_THROW) reduce 223) ((T_TRAIT) reduce 223) ((T_TRAIT_C) reduce 223) ((T_TRY) reduce 223) ((T_UNSET) reduce 223) ((T_UNSET_CAST) reduce 223) ((T_VARIABLE) reduce 223) ((T_WHILE) reduce 223) ((T_YIELD) reduce 223) ((T_YIELD_FROM) reduce 223) (("[") reduce 223) (("`") reduce 223) (("{") reduce 223) (("~") reduce 223)) 24465 ((("!") reduce 224) (("\"") reduce 224) (("$") reduce 224) (("(") reduce 224) (("+") reduce 224) (("-") reduce 224) ((";") reduce 224) (("@") reduce 224) ((T_ABSTRACT) reduce 224) ((T_ARRAY) reduce 224) ((T_ARRAY_CAST) reduce 224) ((T_ATTRIBUTE) reduce 224) ((T_BOOL_CAST) reduce 224) ((T_BREAK) reduce 224) ((T_CLASS) reduce 224) ((T_CLASS_C) reduce 224) ((T_CLONE) reduce 224) ((T_CONSTANT_ENCAPSED_STRING) reduce 224) ((T_CONTINUE) reduce 224) ((T_DEC) reduce 224) ((T_DECLARE) reduce 224) ((T_DIR) reduce 224) ((T_DNUMBER) reduce 224) ((T_DO) reduce 224) ((T_DOUBLE_CAST) reduce 224) ((T_ECHO) reduce 224) ((T_ELSE) reduce 224) ((T_ELSEIF) reduce 224) ((T_EMPTY) reduce 224) ((T_ENDIF) reduce 224) ((T_ENUM) reduce 224) ((T_EVAL) reduce 224) ((T_EXIT) reduce 224) ((T_FILE) reduce 224) ((T_FINAL) reduce 224) ((T_FN) reduce 224) ((T_FOR) reduce 224) ((T_FOREACH) reduce 224) ((T_FUNCTION) reduce 224) ((T_FUNC_C) reduce 224) ((T_GLOBAL) reduce 224) ((T_GOTO) reduce 224) ((T_HALT_COMPILER) reduce 224) ((T_IF) reduce 224) ((T_INC) reduce 224) ((T_INCLUDE) reduce 224) ((T_INCLUDE_ONCE) reduce 224) ((T_INLINE_HTML) reduce 224) ((T_INTERFACE) reduce 224) ((T_INT_CAST) reduce 224) ((T_ISSET) reduce 224) ((T_LINE) reduce 224) ((T_LIST) reduce 224) ((T_LNUMBER) reduce 224) ((T_MATCH) reduce 224) ((T_METHOD_C) reduce 224) ((T_NAME_FULLY_QUALIFIED) reduce 224) ((T_NAME_QUALIFIED) reduce 224) ((T_NAME_RELATIVE) reduce 224) ((T_NEW) reduce 224) ((T_NS_C) reduce 224) ((T_OBJECT_CAST) reduce 224) ((T_PRINT) reduce 224) ((T_READONLY) reduce 224) ((T_REQUIRE) reduce 224) ((T_REQUIRE_ONCE) reduce 224) ((T_RETURN) reduce 224) ((T_START_HEREDOC) reduce 224) ((T_STATIC) reduce 224) ((T_STRING) reduce 224) ((T_STRING_CAST) reduce 224) ((T_SWITCH) reduce 224) ((T_THROW) reduce 224) ((T_TRAIT) reduce 224) ((T_TRAIT_C) reduce 224) ((T_TRY) reduce 224) ((T_UNSET) reduce 224) ((T_UNSET_CAST) reduce 224) ((T_VARIABLE) reduce 224) ((T_WHILE) reduce 224) ((T_YIELD) reduce 224) ((T_YIELD_FROM) reduce 224) (("[") reduce 224) (("`") reduce 224) (("{") reduce 224) (("~") reduce 224)) 24466 ((("!") reduce 167) (("\"") reduce 167) (("$") reduce 167) (("(") reduce 167) (("+") reduce 167) (("-") reduce 167) ((";") reduce 167) (("@") reduce 167) ((T_ABSTRACT) reduce 167) ((T_ARRAY) reduce 167) ((T_ARRAY_CAST) reduce 167) ((T_ATTRIBUTE) reduce 167) ((T_BOOL_CAST) reduce 167) ((T_BREAK) reduce 167) ((T_CLASS) reduce 167) ((T_CLASS_C) reduce 167) ((T_CLONE) reduce 167) ((T_CONSTANT_ENCAPSED_STRING) reduce 167) ((T_CONTINUE) reduce 167) ((T_DEC) reduce 167) ((T_DECLARE) reduce 167) ((T_DIR) reduce 167) ((T_DNUMBER) reduce 167) ((T_DO) reduce 167) ((T_DOUBLE_CAST) reduce 167) ((T_ECHO) reduce 167) ((T_ELSE) reduce 167) ((T_ELSEIF) reduce 167) ((T_EMPTY) reduce 167) ((T_ENDIF) reduce 167) ((T_ENUM) reduce 167) ((T_EVAL) reduce 167) ((T_EXIT) reduce 167) ((T_FILE) reduce 167) ((T_FINAL) reduce 167) ((T_FN) reduce 167) ((T_FOR) reduce 167) ((T_FOREACH) reduce 167) ((T_FUNCTION) reduce 167) ((T_FUNC_C) reduce 167) ((T_GLOBAL) reduce 167) ((T_GOTO) reduce 167) ((T_HALT_COMPILER) reduce 167) ((T_IF) reduce 167) ((T_INC) reduce 167) ((T_INCLUDE) reduce 167) ((T_INCLUDE_ONCE) reduce 167) ((T_INLINE_HTML) reduce 167) ((T_INTERFACE) reduce 167) ((T_INT_CAST) reduce 167) ((T_ISSET) reduce 167) ((T_LINE) reduce 167) ((T_LIST) reduce 167) ((T_LNUMBER) reduce 167) ((T_MATCH) reduce 167) ((T_METHOD_C) reduce 167) ((T_NAME_FULLY_QUALIFIED) reduce 167) ((T_NAME_QUALIFIED) reduce 167) ((T_NAME_RELATIVE) reduce 167) ((T_NEW) reduce 167) ((T_NS_C) reduce 167) ((T_OBJECT_CAST) reduce 167) ((T_PRINT) reduce 167) ((T_READONLY) reduce 167) ((T_REQUIRE) reduce 167) ((T_REQUIRE_ONCE) reduce 167) ((T_RETURN) reduce 167) ((T_START_HEREDOC) reduce 167) ((T_STATIC) reduce 167) ((T_STRING) reduce 167) ((T_STRING_CAST) reduce 167) ((T_SWITCH) reduce 167) ((T_THROW) reduce 167) ((T_TRAIT) reduce 167) ((T_TRAIT_C) reduce 167) ((T_TRY) reduce 167) ((T_UNSET) reduce 167) ((T_UNSET_CAST) reduce 167) ((T_VARIABLE) reduce 167) ((T_WHILE) reduce 167) ((T_YIELD) reduce 167) ((T_YIELD_FROM) reduce 167) (("[") reduce 167) (("`") reduce 167) (("{") reduce 167) (("~") reduce 167)) 24468 ((("!") reduce 156) (("\"") reduce 156) (("$") reduce 156) (("(") reduce 156) (("+") reduce 156) (("-") reduce 156) ((";") reduce 156) (("@") reduce 156) ((T_ABSTRACT) reduce 156) ((T_ARRAY) reduce 156) ((T_ARRAY_CAST) reduce 156) ((T_ATTRIBUTE) reduce 156) ((T_BOOL_CAST) reduce 156) ((T_BREAK) reduce 156) ((T_CLASS) reduce 156) ((T_CLASS_C) reduce 156) ((T_CLONE) reduce 156) ((T_CONSTANT_ENCAPSED_STRING) reduce 156) ((T_CONTINUE) reduce 156) ((T_DEC) reduce 156) ((T_DECLARE) reduce 156) ((T_DIR) reduce 156) ((T_DNUMBER) reduce 156) ((T_DO) reduce 156) ((T_DOUBLE_CAST) reduce 156) ((T_ECHO) reduce 156) ((T_ELSE) reduce 156) ((T_ELSEIF) reduce 156) ((T_EMPTY) reduce 156) ((T_ENDIF) reduce 156) ((T_ENUM) reduce 156) ((T_EVAL) reduce 156) ((T_EXIT) reduce 156) ((T_FILE) reduce 156) ((T_FINAL) reduce 156) ((T_FN) reduce 156) ((T_FOR) reduce 156) ((T_FOREACH) reduce 156) ((T_FUNCTION) reduce 156) ((T_FUNC_C) reduce 156) ((T_GLOBAL) reduce 156) ((T_GOTO) reduce 156) ((T_HALT_COMPILER) reduce 156) ((T_IF) reduce 156) ((T_INC) reduce 156) ((T_INCLUDE) reduce 156) ((T_INCLUDE_ONCE) reduce 156) ((T_INLINE_HTML) reduce 156) ((T_INTERFACE) reduce 156) ((T_INT_CAST) reduce 156) ((T_ISSET) reduce 156) ((T_LINE) reduce 156) ((T_LIST) reduce 156) ((T_LNUMBER) reduce 156) ((T_MATCH) reduce 156) ((T_METHOD_C) reduce 156) ((T_NAME_FULLY_QUALIFIED) reduce 156) ((T_NAME_QUALIFIED) reduce 156) ((T_NAME_RELATIVE) reduce 156) ((T_NEW) reduce 156) ((T_NS_C) reduce 156) ((T_OBJECT_CAST) reduce 156) ((T_PRINT) reduce 156) ((T_READONLY) reduce 156) ((T_REQUIRE) reduce 156) ((T_REQUIRE_ONCE) reduce 156) ((T_RETURN) reduce 156) ((T_START_HEREDOC) reduce 156) ((T_STATIC) reduce 156) ((T_STRING) reduce 156) ((T_STRING_CAST) reduce 156) ((T_SWITCH) reduce 156) ((T_THROW) reduce 156) ((T_TRAIT) reduce 156) ((T_TRAIT_C) reduce 156) ((T_TRY) reduce 156) ((T_UNSET) reduce 156) ((T_UNSET_CAST) reduce 156) ((T_VARIABLE) reduce 156) ((T_WHILE) reduce 156) ((T_YIELD) reduce 156) ((T_YIELD_FROM) reduce 156) (("[") reduce 156) (("`") reduce 156) (("{") reduce 156) (("~") reduce 156)) 24470 ((("!") reduce 154) (("\"") reduce 154) (("$") reduce 154) (("(") reduce 154) (("+") reduce 154) (("-") reduce 154) ((";") reduce 154) (("@") reduce 154) ((T_ABSTRACT) reduce 154) ((T_ARRAY) reduce 154) ((T_ARRAY_CAST) reduce 154) ((T_ATTRIBUTE) reduce 154) ((T_BOOL_CAST) reduce 154) ((T_BREAK) reduce 154) ((T_CLASS) reduce 154) ((T_CLASS_C) reduce 154) ((T_CLONE) reduce 154) ((T_CONSTANT_ENCAPSED_STRING) reduce 154) ((T_CONTINUE) reduce 154) ((T_DEC) reduce 154) ((T_DECLARE) reduce 154) ((T_DIR) reduce 154) ((T_DNUMBER) reduce 154) ((T_DO) reduce 154) ((T_DOUBLE_CAST) reduce 154) ((T_ECHO) reduce 154) ((T_ELSE) reduce 154) ((T_ELSEIF) reduce 154) ((T_EMPTY) reduce 154) ((T_ENDIF) reduce 154) ((T_ENUM) reduce 154) ((T_EVAL) reduce 154) ((T_EXIT) reduce 154) ((T_FILE) reduce 154) ((T_FINAL) reduce 154) ((T_FN) reduce 154) ((T_FOR) reduce 154) ((T_FOREACH) reduce 154) ((T_FUNCTION) reduce 154) ((T_FUNC_C) reduce 154) ((T_GLOBAL) reduce 154) ((T_GOTO) reduce 154) ((T_HALT_COMPILER) reduce 154) ((T_IF) reduce 154) ((T_INC) reduce 154) ((T_INCLUDE) reduce 154) ((T_INCLUDE_ONCE) reduce 154) ((T_INLINE_HTML) reduce 154) ((T_INTERFACE) reduce 154) ((T_INT_CAST) reduce 154) ((T_ISSET) reduce 154) ((T_LINE) reduce 154) ((T_LIST) reduce 154) ((T_LNUMBER) reduce 154) ((T_MATCH) reduce 154) ((T_METHOD_C) reduce 154) ((T_NAME_FULLY_QUALIFIED) reduce 154) ((T_NAME_QUALIFIED) reduce 154) ((T_NAME_RELATIVE) reduce 154) ((T_NEW) reduce 154) ((T_NS_C) reduce 154) ((T_OBJECT_CAST) reduce 154) ((T_PRINT) reduce 154) ((T_READONLY) reduce 154) ((T_REQUIRE) reduce 154) ((T_REQUIRE_ONCE) reduce 154) ((T_RETURN) reduce 154) ((T_START_HEREDOC) reduce 154) ((T_STATIC) reduce 154) ((T_STRING) reduce 154) ((T_STRING_CAST) reduce 154) ((T_SWITCH) reduce 154) ((T_THROW) reduce 154) ((T_TRAIT) reduce 154) ((T_TRAIT_C) reduce 154) ((T_TRY) reduce 154) ((T_UNSET) reduce 154) ((T_UNSET_CAST) reduce 154) ((T_VARIABLE) reduce 154) ((T_WHILE) reduce 154) ((T_YIELD) reduce 154) ((T_YIELD_FROM) reduce 154) (("[") reduce 154) (("`") reduce 154) (("{") reduce 154) (("~") reduce 154)) 24476 ((("!") reduce 198) (("\"") reduce 198) (("$") reduce 198) (("(") reduce 198) (("+") reduce 198) (("-") reduce 198) ((";") reduce 198) (("@") reduce 198) ((T_ABSTRACT) reduce 198) ((T_ARRAY) reduce 198) ((T_ARRAY_CAST) reduce 198) ((T_ATTRIBUTE) reduce 198) ((T_BOOL_CAST) reduce 198) ((T_BREAK) reduce 198) ((T_CLASS) reduce 198) ((T_CLASS_C) reduce 198) ((T_CLONE) reduce 198) ((T_CONSTANT_ENCAPSED_STRING) reduce 198) ((T_CONTINUE) reduce 198) ((T_DEC) reduce 198) ((T_DECLARE) reduce 198) ((T_DIR) reduce 198) ((T_DNUMBER) reduce 198) ((T_DO) reduce 198) ((T_DOUBLE_CAST) reduce 198) ((T_ECHO) reduce 198) ((T_ELSE) reduce 198) ((T_ELSEIF) reduce 198) ((T_EMPTY) reduce 198) ((T_ENDIF) reduce 198) ((T_ENUM) reduce 198) ((T_EVAL) reduce 198) ((T_EXIT) reduce 198) ((T_FILE) reduce 198) ((T_FINAL) reduce 198) ((T_FN) reduce 198) ((T_FOR) reduce 198) ((T_FOREACH) reduce 198) ((T_FUNCTION) reduce 198) ((T_FUNC_C) reduce 198) ((T_GLOBAL) reduce 198) ((T_GOTO) reduce 198) ((T_HALT_COMPILER) reduce 198) ((T_IF) reduce 198) ((T_INC) reduce 198) ((T_INCLUDE) reduce 198) ((T_INCLUDE_ONCE) reduce 198) ((T_INLINE_HTML) reduce 198) ((T_INTERFACE) reduce 198) ((T_INT_CAST) reduce 198) ((T_ISSET) reduce 198) ((T_LINE) reduce 198) ((T_LIST) reduce 198) ((T_LNUMBER) reduce 198) ((T_MATCH) reduce 198) ((T_METHOD_C) reduce 198) ((T_NAME_FULLY_QUALIFIED) reduce 198) ((T_NAME_QUALIFIED) reduce 198) ((T_NAME_RELATIVE) reduce 198) ((T_NEW) reduce 198) ((T_NS_C) reduce 198) ((T_OBJECT_CAST) reduce 198) ((T_PRINT) reduce 198) ((T_READONLY) reduce 198) ((T_REQUIRE) reduce 198) ((T_REQUIRE_ONCE) reduce 198) ((T_RETURN) reduce 198) ((T_START_HEREDOC) reduce 198) ((T_STATIC) reduce 198) ((T_STRING) reduce 198) ((T_STRING_CAST) reduce 198) ((T_SWITCH) reduce 198) ((T_THROW) reduce 198) ((T_TRAIT) reduce 198) ((T_TRAIT_C) reduce 198) ((T_TRY) reduce 198) ((T_UNSET) reduce 198) ((T_UNSET_CAST) reduce 198) ((T_VARIABLE) reduce 198) ((T_WHILE) reduce 198) ((T_YIELD) reduce 198) ((T_YIELD_FROM) reduce 198) (("[") reduce 198) (("`") reduce 198) (("{") reduce 198) (("~") reduce 198)) 24480 ((("!") reduce 241) (("\"") reduce 241) (("$") reduce 241) (("(") reduce 241) (("+") reduce 241) (("-") reduce 241) ((";") reduce 241) (("@") reduce 241) ((T_ABSTRACT) reduce 241) ((T_ARRAY) reduce 241) ((T_ARRAY_CAST) reduce 241) ((T_ATTRIBUTE) reduce 241) ((T_BOOL_CAST) reduce 241) ((T_BREAK) reduce 241) ((T_CLASS) reduce 241) ((T_CLASS_C) reduce 241) ((T_CLONE) reduce 241) ((T_CONSTANT_ENCAPSED_STRING) reduce 241) ((T_CONTINUE) reduce 241) ((T_DEC) reduce 241) ((T_DECLARE) reduce 241) ((T_DIR) reduce 241) ((T_DNUMBER) reduce 241) ((T_DO) reduce 241) ((T_DOUBLE_CAST) reduce 241) ((T_ECHO) reduce 241) ((T_ELSE) reduce 241) ((T_ELSEIF) reduce 241) ((T_EMPTY) reduce 241) ((T_ENDIF) reduce 241) ((T_ENUM) reduce 241) ((T_EVAL) reduce 241) ((T_EXIT) reduce 241) ((T_FILE) reduce 241) ((T_FINAL) reduce 241) ((T_FN) reduce 241) ((T_FOR) reduce 241) ((T_FOREACH) reduce 241) ((T_FUNCTION) reduce 241) ((T_FUNC_C) reduce 241) ((T_GLOBAL) reduce 241) ((T_GOTO) reduce 241) ((T_HALT_COMPILER) reduce 241) ((T_IF) reduce 241) ((T_INC) reduce 241) ((T_INCLUDE) reduce 241) ((T_INCLUDE_ONCE) reduce 241) ((T_INLINE_HTML) reduce 241) ((T_INTERFACE) reduce 241) ((T_INT_CAST) reduce 241) ((T_ISSET) reduce 241) ((T_LINE) reduce 241) ((T_LIST) reduce 241) ((T_LNUMBER) reduce 241) ((T_MATCH) reduce 241) ((T_METHOD_C) reduce 241) ((T_NAME_FULLY_QUALIFIED) reduce 241) ((T_NAME_QUALIFIED) reduce 241) ((T_NAME_RELATIVE) reduce 241) ((T_NEW) reduce 241) ((T_NS_C) reduce 241) ((T_OBJECT_CAST) reduce 241) ((T_PRINT) reduce 241) ((T_READONLY) reduce 241) ((T_REQUIRE) reduce 241) ((T_REQUIRE_ONCE) reduce 241) ((T_RETURN) reduce 241) ((T_START_HEREDOC) reduce 241) ((T_STATIC) reduce 241) ((T_STRING) reduce 241) ((T_STRING_CAST) reduce 241) ((T_SWITCH) reduce 241) ((T_THROW) reduce 241) ((T_TRAIT) reduce 241) ((T_TRAIT_C) reduce 241) ((T_TRY) reduce 241) ((T_UNSET) reduce 241) ((T_UNSET_CAST) reduce 241) ((T_VARIABLE) reduce 241) ((T_WHILE) reduce 241) ((T_YIELD) reduce 241) ((T_YIELD_FROM) reduce 241) (("[") reduce 241) (("`") reduce 241) (("{") reduce 241) (("~") reduce 241)) 24483 ((("!") reduce 144) (("\"") reduce 144) (("$") reduce 144) (("(") reduce 144) (("+") reduce 144) (("-") reduce 144) ((";") reduce 144) (("@") reduce 144) ((T_ABSTRACT) reduce 144) ((T_ARRAY) reduce 144) ((T_ARRAY_CAST) reduce 144) ((T_ATTRIBUTE) reduce 144) ((T_BOOL_CAST) reduce 144) ((T_BREAK) reduce 144) ((T_CLASS) reduce 144) ((T_CLASS_C) reduce 144) ((T_CLONE) reduce 144) ((T_CONSTANT_ENCAPSED_STRING) reduce 144) ((T_CONTINUE) reduce 144) ((T_DEC) reduce 144) ((T_DECLARE) reduce 144) ((T_DIR) reduce 144) ((T_DNUMBER) reduce 144) ((T_DO) reduce 144) ((T_DOUBLE_CAST) reduce 144) ((T_ECHO) reduce 144) ((T_ELSE) reduce 144) ((T_ELSEIF) reduce 144) ((T_EMPTY) reduce 144) ((T_ENDIF) reduce 144) ((T_ENUM) reduce 144) ((T_EVAL) reduce 144) ((T_EXIT) reduce 144) ((T_FILE) reduce 144) ((T_FINAL) reduce 144) ((T_FN) reduce 144) ((T_FOR) reduce 144) ((T_FOREACH) reduce 144) ((T_FUNCTION) reduce 144) ((T_FUNC_C) reduce 144) ((T_GLOBAL) reduce 144) ((T_GOTO) reduce 144) ((T_HALT_COMPILER) reduce 144) ((T_IF) reduce 144) ((T_INC) reduce 144) ((T_INCLUDE) reduce 144) ((T_INCLUDE_ONCE) reduce 144) ((T_INLINE_HTML) reduce 144) ((T_INTERFACE) reduce 144) ((T_INT_CAST) reduce 144) ((T_ISSET) reduce 144) ((T_LINE) reduce 144) ((T_LIST) reduce 144) ((T_LNUMBER) reduce 144) ((T_MATCH) reduce 144) ((T_METHOD_C) reduce 144) ((T_NAME_FULLY_QUALIFIED) reduce 144) ((T_NAME_QUALIFIED) reduce 144) ((T_NAME_RELATIVE) reduce 144) ((T_NEW) reduce 144) ((T_NS_C) reduce 144) ((T_OBJECT_CAST) reduce 144) ((T_PRINT) reduce 144) ((T_READONLY) reduce 144) ((T_REQUIRE) reduce 144) ((T_REQUIRE_ONCE) reduce 144) ((T_RETURN) reduce 144) ((T_START_HEREDOC) reduce 144) ((T_STATIC) reduce 144) ((T_STRING) reduce 144) ((T_STRING_CAST) reduce 144) ((T_SWITCH) reduce 144) ((T_THROW) reduce 144) ((T_TRAIT) reduce 144) ((T_TRAIT_C) reduce 144) ((T_TRY) reduce 144) ((T_UNSET) reduce 144) ((T_UNSET_CAST) reduce 144) ((T_VARIABLE) reduce 144) ((T_WHILE) reduce 144) ((T_YIELD) reduce 144) ((T_YIELD_FROM) reduce 144) (("[") reduce 144) (("`") reduce 144) (("{") reduce 144) (("~") reduce 144)) 24485 ((("!") reduce 166) (("\"") reduce 166) (("$") reduce 166) (("(") reduce 166) (("+") reduce 166) (("-") reduce 166) ((";") reduce 166) (("@") reduce 166) ((T_ABSTRACT) reduce 166) ((T_ARRAY) reduce 166) ((T_ARRAY_CAST) reduce 166) ((T_ATTRIBUTE) reduce 166) ((T_BOOL_CAST) reduce 166) ((T_BREAK) reduce 166) ((T_CLASS) reduce 166) ((T_CLASS_C) reduce 166) ((T_CLONE) reduce 166) ((T_CONSTANT_ENCAPSED_STRING) reduce 166) ((T_CONTINUE) reduce 166) ((T_DEC) reduce 166) ((T_DECLARE) reduce 166) ((T_DIR) reduce 166) ((T_DNUMBER) reduce 166) ((T_DO) reduce 166) ((T_DOUBLE_CAST) reduce 166) ((T_ECHO) reduce 166) ((T_ELSE) reduce 166) ((T_ELSEIF) reduce 166) ((T_EMPTY) reduce 166) ((T_ENDIF) reduce 166) ((T_ENUM) reduce 166) ((T_EVAL) reduce 166) ((T_EXIT) reduce 166) ((T_FILE) reduce 166) ((T_FINAL) reduce 166) ((T_FN) reduce 166) ((T_FOR) reduce 166) ((T_FOREACH) reduce 166) ((T_FUNCTION) reduce 166) ((T_FUNC_C) reduce 166) ((T_GLOBAL) reduce 166) ((T_GOTO) reduce 166) ((T_HALT_COMPILER) reduce 166) ((T_IF) reduce 166) ((T_INC) reduce 166) ((T_INCLUDE) reduce 166) ((T_INCLUDE_ONCE) reduce 166) ((T_INLINE_HTML) reduce 166) ((T_INTERFACE) reduce 166) ((T_INT_CAST) reduce 166) ((T_ISSET) reduce 166) ((T_LINE) reduce 166) ((T_LIST) reduce 166) ((T_LNUMBER) reduce 166) ((T_MATCH) reduce 166) ((T_METHOD_C) reduce 166) ((T_NAME_FULLY_QUALIFIED) reduce 166) ((T_NAME_QUALIFIED) reduce 166) ((T_NAME_RELATIVE) reduce 166) ((T_NEW) reduce 166) ((T_NS_C) reduce 166) ((T_OBJECT_CAST) reduce 166) ((T_PRINT) reduce 166) ((T_READONLY) reduce 166) ((T_REQUIRE) reduce 166) ((T_REQUIRE_ONCE) reduce 166) ((T_RETURN) reduce 166) ((T_START_HEREDOC) reduce 166) ((T_STATIC) reduce 166) ((T_STRING) reduce 166) ((T_STRING_CAST) reduce 166) ((T_SWITCH) reduce 166) ((T_THROW) reduce 166) ((T_TRAIT) reduce 166) ((T_TRAIT_C) reduce 166) ((T_TRY) reduce 166) ((T_UNSET) reduce 166) ((T_UNSET_CAST) reduce 166) ((T_VARIABLE) reduce 166) ((T_WHILE) reduce 166) ((T_YIELD) reduce 166) ((T_YIELD_FROM) reduce 166) (("[") reduce 166) (("`") reduce 166) (("{") reduce 166) (("~") reduce 166)) 24487 ((("!") reduce 155) (("\"") reduce 155) (("$") reduce 155) (("(") reduce 155) (("+") reduce 155) (("-") reduce 155) ((";") reduce 155) (("@") reduce 155) ((T_ABSTRACT) reduce 155) ((T_ARRAY) reduce 155) ((T_ARRAY_CAST) reduce 155) ((T_ATTRIBUTE) reduce 155) ((T_BOOL_CAST) reduce 155) ((T_BREAK) reduce 155) ((T_CLASS) reduce 155) ((T_CLASS_C) reduce 155) ((T_CLONE) reduce 155) ((T_CONSTANT_ENCAPSED_STRING) reduce 155) ((T_CONTINUE) reduce 155) ((T_DEC) reduce 155) ((T_DECLARE) reduce 155) ((T_DIR) reduce 155) ((T_DNUMBER) reduce 155) ((T_DO) reduce 155) ((T_DOUBLE_CAST) reduce 155) ((T_ECHO) reduce 155) ((T_ELSE) reduce 155) ((T_ELSEIF) reduce 155) ((T_EMPTY) reduce 155) ((T_ENDIF) reduce 155) ((T_ENUM) reduce 155) ((T_EVAL) reduce 155) ((T_EXIT) reduce 155) ((T_FILE) reduce 155) ((T_FINAL) reduce 155) ((T_FN) reduce 155) ((T_FOR) reduce 155) ((T_FOREACH) reduce 155) ((T_FUNCTION) reduce 155) ((T_FUNC_C) reduce 155) ((T_GLOBAL) reduce 155) ((T_GOTO) reduce 155) ((T_HALT_COMPILER) reduce 155) ((T_IF) reduce 155) ((T_INC) reduce 155) ((T_INCLUDE) reduce 155) ((T_INCLUDE_ONCE) reduce 155) ((T_INLINE_HTML) reduce 155) ((T_INTERFACE) reduce 155) ((T_INT_CAST) reduce 155) ((T_ISSET) reduce 155) ((T_LINE) reduce 155) ((T_LIST) reduce 155) ((T_LNUMBER) reduce 155) ((T_MATCH) reduce 155) ((T_METHOD_C) reduce 155) ((T_NAME_FULLY_QUALIFIED) reduce 155) ((T_NAME_QUALIFIED) reduce 155) ((T_NAME_RELATIVE) reduce 155) ((T_NEW) reduce 155) ((T_NS_C) reduce 155) ((T_OBJECT_CAST) reduce 155) ((T_PRINT) reduce 155) ((T_READONLY) reduce 155) ((T_REQUIRE) reduce 155) ((T_REQUIRE_ONCE) reduce 155) ((T_RETURN) reduce 155) ((T_START_HEREDOC) reduce 155) ((T_STATIC) reduce 155) ((T_STRING) reduce 155) ((T_STRING_CAST) reduce 155) ((T_SWITCH) reduce 155) ((T_THROW) reduce 155) ((T_TRAIT) reduce 155) ((T_TRAIT_C) reduce 155) ((T_TRY) reduce 155) ((T_UNSET) reduce 155) ((T_UNSET_CAST) reduce 155) ((T_VARIABLE) reduce 155) ((T_WHILE) reduce 155) ((T_YIELD) reduce 155) ((T_YIELD_FROM) reduce 155) (("[") reduce 155) (("`") reduce 155) (("{") reduce 155) (("~") reduce 155)) 24497 ((("!") reduce 162) (("\"") reduce 162) (("$") reduce 162) (("(") reduce 162) (("+") reduce 162) (("-") reduce 162) ((";") reduce 162) (("@") reduce 162) ((T_ABSTRACT) reduce 162) ((T_ARRAY) reduce 162) ((T_ARRAY_CAST) reduce 162) ((T_ATTRIBUTE) reduce 162) ((T_BOOL_CAST) reduce 162) ((T_BREAK) reduce 162) ((T_CLASS) reduce 162) ((T_CLASS_C) reduce 162) ((T_CLONE) reduce 162) ((T_CONSTANT_ENCAPSED_STRING) reduce 162) ((T_CONTINUE) reduce 162) ((T_DEC) reduce 162) ((T_DECLARE) reduce 162) ((T_DIR) reduce 162) ((T_DNUMBER) reduce 162) ((T_DO) reduce 162) ((T_DOUBLE_CAST) reduce 162) ((T_ECHO) reduce 162) ((T_ELSE) reduce 162) ((T_ELSEIF) reduce 162) ((T_EMPTY) reduce 162) ((T_ENDIF) reduce 162) ((T_ENUM) reduce 162) ((T_EVAL) reduce 162) ((T_EXIT) reduce 162) ((T_FILE) reduce 162) ((T_FINAL) reduce 162) ((T_FN) reduce 162) ((T_FOR) reduce 162) ((T_FOREACH) reduce 162) ((T_FUNCTION) reduce 162) ((T_FUNC_C) reduce 162) ((T_GLOBAL) reduce 162) ((T_GOTO) reduce 162) ((T_HALT_COMPILER) reduce 162) ((T_IF) reduce 162) ((T_INC) reduce 162) ((T_INCLUDE) reduce 162) ((T_INCLUDE_ONCE) reduce 162) ((T_INLINE_HTML) reduce 162) ((T_INTERFACE) reduce 162) ((T_INT_CAST) reduce 162) ((T_ISSET) reduce 162) ((T_LINE) reduce 162) ((T_LIST) reduce 162) ((T_LNUMBER) reduce 162) ((T_MATCH) reduce 162) ((T_METHOD_C) reduce 162) ((T_NAME_FULLY_QUALIFIED) reduce 162) ((T_NAME_QUALIFIED) reduce 162) ((T_NAME_RELATIVE) reduce 162) ((T_NEW) reduce 162) ((T_NS_C) reduce 162) ((T_OBJECT_CAST) reduce 162) ((T_PRINT) reduce 162) ((T_READONLY) reduce 162) ((T_REQUIRE) reduce 162) ((T_REQUIRE_ONCE) reduce 162) ((T_RETURN) reduce 162) ((T_START_HEREDOC) reduce 162) ((T_STATIC) reduce 162) ((T_STRING) reduce 162) ((T_STRING_CAST) reduce 162) ((T_SWITCH) reduce 162) ((T_THROW) reduce 162) ((T_TRAIT) reduce 162) ((T_TRAIT_C) reduce 162) ((T_TRY) reduce 162) ((T_UNSET) reduce 162) ((T_UNSET_CAST) reduce 162) ((T_VARIABLE) reduce 162) ((T_WHILE) reduce 162) ((T_YIELD) reduce 162) ((T_YIELD_FROM) reduce 162) (("[") reduce 162) (("`") reduce 162) (("{") reduce 162) (("~") reduce 162)) 24498 ((("!") reduce 217) (("\"") reduce 217) (("$") reduce 217) (("(") reduce 217) (("+") reduce 217) (("-") reduce 217) ((";") reduce 217) (("@") reduce 217) ((T_ABSTRACT) reduce 217) ((T_ARRAY) reduce 217) ((T_ARRAY_CAST) reduce 217) ((T_ATTRIBUTE) reduce 217) ((T_BOOL_CAST) reduce 217) ((T_BREAK) reduce 217) ((T_CLASS) reduce 217) ((T_CLASS_C) reduce 217) ((T_CLONE) reduce 217) ((T_CONSTANT_ENCAPSED_STRING) reduce 217) ((T_CONTINUE) reduce 217) ((T_DEC) reduce 217) ((T_DECLARE) reduce 217) ((T_DIR) reduce 217) ((T_DNUMBER) reduce 217) ((T_DO) reduce 217) ((T_DOUBLE_CAST) reduce 217) ((T_ECHO) reduce 217) ((T_ELSE) reduce 217) ((T_ELSEIF) reduce 217) ((T_EMPTY) reduce 217) ((T_ENDIF) reduce 217) ((T_ENUM) reduce 217) ((T_EVAL) reduce 217) ((T_EXIT) reduce 217) ((T_FILE) reduce 217) ((T_FINAL) reduce 217) ((T_FN) reduce 217) ((T_FOR) reduce 217) ((T_FOREACH) reduce 217) ((T_FUNCTION) reduce 217) ((T_FUNC_C) reduce 217) ((T_GLOBAL) reduce 217) ((T_GOTO) reduce 217) ((T_HALT_COMPILER) reduce 217) ((T_IF) reduce 217) ((T_INC) reduce 217) ((T_INCLUDE) reduce 217) ((T_INCLUDE_ONCE) reduce 217) ((T_INLINE_HTML) reduce 217) ((T_INTERFACE) reduce 217) ((T_INT_CAST) reduce 217) ((T_ISSET) reduce 217) ((T_LINE) reduce 217) ((T_LIST) reduce 217) ((T_LNUMBER) reduce 217) ((T_MATCH) reduce 217) ((T_METHOD_C) reduce 217) ((T_NAME_FULLY_QUALIFIED) reduce 217) ((T_NAME_QUALIFIED) reduce 217) ((T_NAME_RELATIVE) reduce 217) ((T_NEW) reduce 217) ((T_NS_C) reduce 217) ((T_OBJECT_CAST) reduce 217) ((T_PRINT) reduce 217) ((T_READONLY) reduce 217) ((T_REQUIRE) reduce 217) ((T_REQUIRE_ONCE) reduce 217) ((T_RETURN) reduce 217) ((T_START_HEREDOC) reduce 217) ((T_STATIC) reduce 217) ((T_STRING) reduce 217) ((T_STRING_CAST) reduce 217) ((T_SWITCH) reduce 217) ((T_THROW) reduce 217) ((T_TRAIT) reduce 217) ((T_TRAIT_C) reduce 217) ((T_TRY) reduce 217) ((T_UNSET) reduce 217) ((T_UNSET_CAST) reduce 217) ((T_VARIABLE) reduce 217) ((T_WHILE) reduce 217) ((T_YIELD) reduce 217) ((T_YIELD_FROM) reduce 217) (("[") reduce 217) (("`") reduce 217) (("{") reduce 217) (("~") reduce 217)) 24501 ((("!") reduce 218) (("\"") reduce 218) (("$") reduce 218) (("(") reduce 218) (("+") reduce 218) (("-") reduce 218) ((";") reduce 218) (("@") reduce 218) ((T_ABSTRACT) reduce 218) ((T_ARRAY) reduce 218) ((T_ARRAY_CAST) reduce 218) ((T_ATTRIBUTE) reduce 218) ((T_BOOL_CAST) reduce 218) ((T_BREAK) reduce 218) ((T_CLASS) reduce 218) ((T_CLASS_C) reduce 218) ((T_CLONE) reduce 218) ((T_CONSTANT_ENCAPSED_STRING) reduce 218) ((T_CONTINUE) reduce 218) ((T_DEC) reduce 218) ((T_DECLARE) reduce 218) ((T_DIR) reduce 218) ((T_DNUMBER) reduce 218) ((T_DO) reduce 218) ((T_DOUBLE_CAST) reduce 218) ((T_ECHO) reduce 218) ((T_ELSE) reduce 218) ((T_ELSEIF) reduce 218) ((T_EMPTY) reduce 218) ((T_ENDIF) reduce 218) ((T_ENUM) reduce 218) ((T_EVAL) reduce 218) ((T_EXIT) reduce 218) ((T_FILE) reduce 218) ((T_FINAL) reduce 218) ((T_FN) reduce 218) ((T_FOR) reduce 218) ((T_FOREACH) reduce 218) ((T_FUNCTION) reduce 218) ((T_FUNC_C) reduce 218) ((T_GLOBAL) reduce 218) ((T_GOTO) reduce 218) ((T_HALT_COMPILER) reduce 218) ((T_IF) reduce 218) ((T_INC) reduce 218) ((T_INCLUDE) reduce 218) ((T_INCLUDE_ONCE) reduce 218) ((T_INLINE_HTML) reduce 218) ((T_INTERFACE) reduce 218) ((T_INT_CAST) reduce 218) ((T_ISSET) reduce 218) ((T_LINE) reduce 218) ((T_LIST) reduce 218) ((T_LNUMBER) reduce 218) ((T_MATCH) reduce 218) ((T_METHOD_C) reduce 218) ((T_NAME_FULLY_QUALIFIED) reduce 218) ((T_NAME_QUALIFIED) reduce 218) ((T_NAME_RELATIVE) reduce 218) ((T_NEW) reduce 218) ((T_NS_C) reduce 218) ((T_OBJECT_CAST) reduce 218) ((T_PRINT) reduce 218) ((T_READONLY) reduce 218) ((T_REQUIRE) reduce 218) ((T_REQUIRE_ONCE) reduce 218) ((T_RETURN) reduce 218) ((T_START_HEREDOC) reduce 218) ((T_STATIC) reduce 218) ((T_STRING) reduce 218) ((T_STRING_CAST) reduce 218) ((T_SWITCH) reduce 218) ((T_THROW) reduce 218) ((T_TRAIT) reduce 218) ((T_TRAIT_C) reduce 218) ((T_TRY) reduce 218) ((T_UNSET) reduce 218) ((T_UNSET_CAST) reduce 218) ((T_VARIABLE) reduce 218) ((T_WHILE) reduce 218) ((T_YIELD) reduce 218) ((T_YIELD_FROM) reduce 218) (("[") reduce 218) (("`") reduce 218) (("{") reduce 218) (("~") reduce 218)) 24502 ((("!") reduce 161) (("\"") reduce 161) (("$") reduce 161) (("(") reduce 161) (("+") reduce 161) (("-") reduce 161) ((";") reduce 161) (("@") reduce 161) ((T_ABSTRACT) reduce 161) ((T_ARRAY) reduce 161) ((T_ARRAY_CAST) reduce 161) ((T_ATTRIBUTE) reduce 161) ((T_BOOL_CAST) reduce 161) ((T_BREAK) reduce 161) ((T_CLASS) reduce 161) ((T_CLASS_C) reduce 161) ((T_CLONE) reduce 161) ((T_CONSTANT_ENCAPSED_STRING) reduce 161) ((T_CONTINUE) reduce 161) ((T_DEC) reduce 161) ((T_DECLARE) reduce 161) ((T_DIR) reduce 161) ((T_DNUMBER) reduce 161) ((T_DO) reduce 161) ((T_DOUBLE_CAST) reduce 161) ((T_ECHO) reduce 161) ((T_ELSE) reduce 161) ((T_ELSEIF) reduce 161) ((T_EMPTY) reduce 161) ((T_ENDIF) reduce 161) ((T_ENUM) reduce 161) ((T_EVAL) reduce 161) ((T_EXIT) reduce 161) ((T_FILE) reduce 161) ((T_FINAL) reduce 161) ((T_FN) reduce 161) ((T_FOR) reduce 161) ((T_FOREACH) reduce 161) ((T_FUNCTION) reduce 161) ((T_FUNC_C) reduce 161) ((T_GLOBAL) reduce 161) ((T_GOTO) reduce 161) ((T_HALT_COMPILER) reduce 161) ((T_IF) reduce 161) ((T_INC) reduce 161) ((T_INCLUDE) reduce 161) ((T_INCLUDE_ONCE) reduce 161) ((T_INLINE_HTML) reduce 161) ((T_INTERFACE) reduce 161) ((T_INT_CAST) reduce 161) ((T_ISSET) reduce 161) ((T_LINE) reduce 161) ((T_LIST) reduce 161) ((T_LNUMBER) reduce 161) ((T_MATCH) reduce 161) ((T_METHOD_C) reduce 161) ((T_NAME_FULLY_QUALIFIED) reduce 161) ((T_NAME_QUALIFIED) reduce 161) ((T_NAME_RELATIVE) reduce 161) ((T_NEW) reduce 161) ((T_NS_C) reduce 161) ((T_OBJECT_CAST) reduce 161) ((T_PRINT) reduce 161) ((T_READONLY) reduce 161) ((T_REQUIRE) reduce 161) ((T_REQUIRE_ONCE) reduce 161) ((T_RETURN) reduce 161) ((T_START_HEREDOC) reduce 161) ((T_STATIC) reduce 161) ((T_STRING) reduce 161) ((T_STRING_CAST) reduce 161) ((T_SWITCH) reduce 161) ((T_THROW) reduce 161) ((T_TRAIT) reduce 161) ((T_TRAIT_C) reduce 161) ((T_TRY) reduce 161) ((T_UNSET) reduce 161) ((T_UNSET_CAST) reduce 161) ((T_VARIABLE) reduce 161) ((T_WHILE) reduce 161) ((T_YIELD) reduce 161) ((T_YIELD_FROM) reduce 161) (("[") reduce 161) (("`") reduce 161) (("{") reduce 161) (("~") reduce 161)) 24511 ((("!") reduce 150) (("\"") reduce 150) (("$") reduce 150) (("(") reduce 150) (("+") reduce 150) (("-") reduce 150) ((";") reduce 150) (("@") reduce 150) ((T_ABSTRACT) reduce 150) ((T_ARRAY) reduce 150) ((T_ARRAY_CAST) reduce 150) ((T_ATTRIBUTE) reduce 150) ((T_BOOL_CAST) reduce 150) ((T_BREAK) reduce 150) ((T_CLASS) reduce 150) ((T_CLASS_C) reduce 150) ((T_CLONE) reduce 150) ((T_CONSTANT_ENCAPSED_STRING) reduce 150) ((T_CONTINUE) reduce 150) ((T_DEC) reduce 150) ((T_DECLARE) reduce 150) ((T_DIR) reduce 150) ((T_DNUMBER) reduce 150) ((T_DO) reduce 150) ((T_DOUBLE_CAST) reduce 150) ((T_ECHO) reduce 150) ((T_ELSE) reduce 150) ((T_ELSEIF) reduce 150) ((T_EMPTY) reduce 150) ((T_ENDIF) reduce 150) ((T_ENUM) reduce 150) ((T_EVAL) reduce 150) ((T_EXIT) reduce 150) ((T_FILE) reduce 150) ((T_FINAL) reduce 150) ((T_FN) reduce 150) ((T_FOR) reduce 150) ((T_FOREACH) reduce 150) ((T_FUNCTION) reduce 150) ((T_FUNC_C) reduce 150) ((T_GLOBAL) reduce 150) ((T_GOTO) reduce 150) ((T_HALT_COMPILER) reduce 150) ((T_IF) reduce 150) ((T_INC) reduce 150) ((T_INCLUDE) reduce 150) ((T_INCLUDE_ONCE) reduce 150) ((T_INLINE_HTML) reduce 150) ((T_INTERFACE) reduce 150) ((T_INT_CAST) reduce 150) ((T_ISSET) reduce 150) ((T_LINE) reduce 150) ((T_LIST) reduce 150) ((T_LNUMBER) reduce 150) ((T_MATCH) reduce 150) ((T_METHOD_C) reduce 150) ((T_NAME_FULLY_QUALIFIED) reduce 150) ((T_NAME_QUALIFIED) reduce 150) ((T_NAME_RELATIVE) reduce 150) ((T_NEW) reduce 150) ((T_NS_C) reduce 150) ((T_OBJECT_CAST) reduce 150) ((T_PRINT) reduce 150) ((T_READONLY) reduce 150) ((T_REQUIRE) reduce 150) ((T_REQUIRE_ONCE) reduce 150) ((T_RETURN) reduce 150) ((T_START_HEREDOC) reduce 150) ((T_STATIC) reduce 150) ((T_STRING) reduce 150) ((T_STRING_CAST) reduce 150) ((T_SWITCH) reduce 150) ((T_THROW) reduce 150) ((T_TRAIT) reduce 150) ((T_TRAIT_C) reduce 150) ((T_TRY) reduce 150) ((T_UNSET) reduce 150) ((T_UNSET_CAST) reduce 150) ((T_VARIABLE) reduce 150) ((T_WHILE) reduce 150) ((T_YIELD) reduce 150) ((T_YIELD_FROM) reduce 150) (("[") reduce 150) (("`") reduce 150) (("{") reduce 150) (("~") reduce 150)) 24512 ((("!") reduce 215) (("\"") reduce 215) (("$") reduce 215) (("(") reduce 215) (("+") reduce 215) (("-") reduce 215) ((";") reduce 215) (("@") reduce 215) ((T_ABSTRACT) reduce 215) ((T_ARRAY) reduce 215) ((T_ARRAY_CAST) reduce 215) ((T_ATTRIBUTE) reduce 215) ((T_BOOL_CAST) reduce 215) ((T_BREAK) reduce 215) ((T_CLASS) reduce 215) ((T_CLASS_C) reduce 215) ((T_CLONE) reduce 215) ((T_CONSTANT_ENCAPSED_STRING) reduce 215) ((T_CONTINUE) reduce 215) ((T_DEC) reduce 215) ((T_DECLARE) reduce 215) ((T_DIR) reduce 215) ((T_DNUMBER) reduce 215) ((T_DO) reduce 215) ((T_DOUBLE_CAST) reduce 215) ((T_ECHO) reduce 215) ((T_ELSE) reduce 215) ((T_ELSEIF) reduce 215) ((T_EMPTY) reduce 215) ((T_ENDIF) reduce 215) ((T_ENUM) reduce 215) ((T_EVAL) reduce 215) ((T_EXIT) reduce 215) ((T_FILE) reduce 215) ((T_FINAL) reduce 215) ((T_FN) reduce 215) ((T_FOR) reduce 215) ((T_FOREACH) reduce 215) ((T_FUNCTION) reduce 215) ((T_FUNC_C) reduce 215) ((T_GLOBAL) reduce 215) ((T_GOTO) reduce 215) ((T_HALT_COMPILER) reduce 215) ((T_IF) reduce 215) ((T_INC) reduce 215) ((T_INCLUDE) reduce 215) ((T_INCLUDE_ONCE) reduce 215) ((T_INLINE_HTML) reduce 215) ((T_INTERFACE) reduce 215) ((T_INT_CAST) reduce 215) ((T_ISSET) reduce 215) ((T_LINE) reduce 215) ((T_LIST) reduce 215) ((T_LNUMBER) reduce 215) ((T_MATCH) reduce 215) ((T_METHOD_C) reduce 215) ((T_NAME_FULLY_QUALIFIED) reduce 215) ((T_NAME_QUALIFIED) reduce 215) ((T_NAME_RELATIVE) reduce 215) ((T_NEW) reduce 215) ((T_NS_C) reduce 215) ((T_OBJECT_CAST) reduce 215) ((T_PRINT) reduce 215) ((T_READONLY) reduce 215) ((T_REQUIRE) reduce 215) ((T_REQUIRE_ONCE) reduce 215) ((T_RETURN) reduce 215) ((T_START_HEREDOC) reduce 215) ((T_STATIC) reduce 215) ((T_STRING) reduce 215) ((T_STRING_CAST) reduce 215) ((T_SWITCH) reduce 215) ((T_THROW) reduce 215) ((T_TRAIT) reduce 215) ((T_TRAIT_C) reduce 215) ((T_TRY) reduce 215) ((T_UNSET) reduce 215) ((T_UNSET_CAST) reduce 215) ((T_VARIABLE) reduce 215) ((T_WHILE) reduce 215) ((T_YIELD) reduce 215) ((T_YIELD_FROM) reduce 215) (("[") reduce 215) (("`") reduce 215) (("{") reduce 215) (("~") reduce 215)) 24515 ((("!") reduce 216) (("\"") reduce 216) (("$") reduce 216) (("(") reduce 216) (("+") reduce 216) (("-") reduce 216) ((";") reduce 216) (("@") reduce 216) ((T_ABSTRACT) reduce 216) ((T_ARRAY) reduce 216) ((T_ARRAY_CAST) reduce 216) ((T_ATTRIBUTE) reduce 216) ((T_BOOL_CAST) reduce 216) ((T_BREAK) reduce 216) ((T_CLASS) reduce 216) ((T_CLASS_C) reduce 216) ((T_CLONE) reduce 216) ((T_CONSTANT_ENCAPSED_STRING) reduce 216) ((T_CONTINUE) reduce 216) ((T_DEC) reduce 216) ((T_DECLARE) reduce 216) ((T_DIR) reduce 216) ((T_DNUMBER) reduce 216) ((T_DO) reduce 216) ((T_DOUBLE_CAST) reduce 216) ((T_ECHO) reduce 216) ((T_ELSE) reduce 216) ((T_ELSEIF) reduce 216) ((T_EMPTY) reduce 216) ((T_ENDIF) reduce 216) ((T_ENUM) reduce 216) ((T_EVAL) reduce 216) ((T_EXIT) reduce 216) ((T_FILE) reduce 216) ((T_FINAL) reduce 216) ((T_FN) reduce 216) ((T_FOR) reduce 216) ((T_FOREACH) reduce 216) ((T_FUNCTION) reduce 216) ((T_FUNC_C) reduce 216) ((T_GLOBAL) reduce 216) ((T_GOTO) reduce 216) ((T_HALT_COMPILER) reduce 216) ((T_IF) reduce 216) ((T_INC) reduce 216) ((T_INCLUDE) reduce 216) ((T_INCLUDE_ONCE) reduce 216) ((T_INLINE_HTML) reduce 216) ((T_INTERFACE) reduce 216) ((T_INT_CAST) reduce 216) ((T_ISSET) reduce 216) ((T_LINE) reduce 216) ((T_LIST) reduce 216) ((T_LNUMBER) reduce 216) ((T_MATCH) reduce 216) ((T_METHOD_C) reduce 216) ((T_NAME_FULLY_QUALIFIED) reduce 216) ((T_NAME_QUALIFIED) reduce 216) ((T_NAME_RELATIVE) reduce 216) ((T_NEW) reduce 216) ((T_NS_C) reduce 216) ((T_OBJECT_CAST) reduce 216) ((T_PRINT) reduce 216) ((T_READONLY) reduce 216) ((T_REQUIRE) reduce 216) ((T_REQUIRE_ONCE) reduce 216) ((T_RETURN) reduce 216) ((T_START_HEREDOC) reduce 216) ((T_STATIC) reduce 216) ((T_STRING) reduce 216) ((T_STRING_CAST) reduce 216) ((T_SWITCH) reduce 216) ((T_THROW) reduce 216) ((T_TRAIT) reduce 216) ((T_TRAIT_C) reduce 216) ((T_TRY) reduce 216) ((T_UNSET) reduce 216) ((T_UNSET_CAST) reduce 216) ((T_VARIABLE) reduce 216) ((T_WHILE) reduce 216) ((T_YIELD) reduce 216) ((T_YIELD_FROM) reduce 216) (("[") reduce 216) (("`") reduce 216) (("{") reduce 216) (("~") reduce 216)) 24522 ((("!") reduce 199) (("\"") reduce 199) (("$") reduce 199) (("(") reduce 199) (("+") reduce 199) (("-") reduce 199) ((";") reduce 199) (("@") reduce 199) ((T_ABSTRACT) reduce 199) ((T_ARRAY) reduce 199) ((T_ARRAY_CAST) reduce 199) ((T_ATTRIBUTE) reduce 199) ((T_BOOL_CAST) reduce 199) ((T_BREAK) reduce 199) ((T_CLASS) reduce 199) ((T_CLASS_C) reduce 199) ((T_CLONE) reduce 199) ((T_CONSTANT_ENCAPSED_STRING) reduce 199) ((T_CONTINUE) reduce 199) ((T_DEC) reduce 199) ((T_DECLARE) reduce 199) ((T_DIR) reduce 199) ((T_DNUMBER) reduce 199) ((T_DO) reduce 199) ((T_DOUBLE_CAST) reduce 199) ((T_ECHO) reduce 199) ((T_ELSE) reduce 199) ((T_ELSEIF) reduce 199) ((T_EMPTY) reduce 199) ((T_ENDIF) reduce 199) ((T_ENUM) reduce 199) ((T_EVAL) reduce 199) ((T_EXIT) reduce 199) ((T_FILE) reduce 199) ((T_FINAL) reduce 199) ((T_FN) reduce 199) ((T_FOR) reduce 199) ((T_FOREACH) reduce 199) ((T_FUNCTION) reduce 199) ((T_FUNC_C) reduce 199) ((T_GLOBAL) reduce 199) ((T_GOTO) reduce 199) ((T_HALT_COMPILER) reduce 199) ((T_IF) reduce 199) ((T_INC) reduce 199) ((T_INCLUDE) reduce 199) ((T_INCLUDE_ONCE) reduce 199) ((T_INLINE_HTML) reduce 199) ((T_INTERFACE) reduce 199) ((T_INT_CAST) reduce 199) ((T_ISSET) reduce 199) ((T_LINE) reduce 199) ((T_LIST) reduce 199) ((T_LNUMBER) reduce 199) ((T_MATCH) reduce 199) ((T_METHOD_C) reduce 199) ((T_NAME_FULLY_QUALIFIED) reduce 199) ((T_NAME_QUALIFIED) reduce 199) ((T_NAME_RELATIVE) reduce 199) ((T_NEW) reduce 199) ((T_NS_C) reduce 199) ((T_OBJECT_CAST) reduce 199) ((T_PRINT) reduce 199) ((T_READONLY) reduce 199) ((T_REQUIRE) reduce 199) ((T_REQUIRE_ONCE) reduce 199) ((T_RETURN) reduce 199) ((T_START_HEREDOC) reduce 199) ((T_STATIC) reduce 199) ((T_STRING) reduce 199) ((T_STRING_CAST) reduce 199) ((T_SWITCH) reduce 199) ((T_THROW) reduce 199) ((T_TRAIT) reduce 199) ((T_TRAIT_C) reduce 199) ((T_TRY) reduce 199) ((T_UNSET) reduce 199) ((T_UNSET_CAST) reduce 199) ((T_VARIABLE) reduce 199) ((T_WHILE) reduce 199) ((T_YIELD) reduce 199) ((T_YIELD_FROM) reduce 199) (("[") reduce 199) (("`") reduce 199) (("{") reduce 199) (("~") reduce 199)) 24524 ((("!") reduce 157) (("\"") reduce 157) (("$") reduce 157) (("(") reduce 157) (("+") reduce 157) (("-") reduce 157) ((";") reduce 157) (("@") reduce 157) ((T_ABSTRACT) reduce 157) ((T_ARRAY) reduce 157) ((T_ARRAY_CAST) reduce 157) ((T_ATTRIBUTE) reduce 157) ((T_BOOL_CAST) reduce 157) ((T_BREAK) reduce 157) ((T_CLASS) reduce 157) ((T_CLASS_C) reduce 157) ((T_CLONE) reduce 157) ((T_CONSTANT_ENCAPSED_STRING) reduce 157) ((T_CONTINUE) reduce 157) ((T_DEC) reduce 157) ((T_DECLARE) reduce 157) ((T_DIR) reduce 157) ((T_DNUMBER) reduce 157) ((T_DO) reduce 157) ((T_DOUBLE_CAST) reduce 157) ((T_ECHO) reduce 157) ((T_ELSE) reduce 157) ((T_ELSEIF) reduce 157) ((T_EMPTY) reduce 157) ((T_ENDIF) reduce 157) ((T_ENUM) reduce 157) ((T_EVAL) reduce 157) ((T_EXIT) reduce 157) ((T_FILE) reduce 157) ((T_FINAL) reduce 157) ((T_FN) reduce 157) ((T_FOR) reduce 157) ((T_FOREACH) reduce 157) ((T_FUNCTION) reduce 157) ((T_FUNC_C) reduce 157) ((T_GLOBAL) reduce 157) ((T_GOTO) reduce 157) ((T_HALT_COMPILER) reduce 157) ((T_IF) reduce 157) ((T_INC) reduce 157) ((T_INCLUDE) reduce 157) ((T_INCLUDE_ONCE) reduce 157) ((T_INLINE_HTML) reduce 157) ((T_INTERFACE) reduce 157) ((T_INT_CAST) reduce 157) ((T_ISSET) reduce 157) ((T_LINE) reduce 157) ((T_LIST) reduce 157) ((T_LNUMBER) reduce 157) ((T_MATCH) reduce 157) ((T_METHOD_C) reduce 157) ((T_NAME_FULLY_QUALIFIED) reduce 157) ((T_NAME_QUALIFIED) reduce 157) ((T_NAME_RELATIVE) reduce 157) ((T_NEW) reduce 157) ((T_NS_C) reduce 157) ((T_OBJECT_CAST) reduce 157) ((T_PRINT) reduce 157) ((T_READONLY) reduce 157) ((T_REQUIRE) reduce 157) ((T_REQUIRE_ONCE) reduce 157) ((T_RETURN) reduce 157) ((T_START_HEREDOC) reduce 157) ((T_STATIC) reduce 157) ((T_STRING) reduce 157) ((T_STRING_CAST) reduce 157) ((T_SWITCH) reduce 157) ((T_THROW) reduce 157) ((T_TRAIT) reduce 157) ((T_TRAIT_C) reduce 157) ((T_TRY) reduce 157) ((T_UNSET) reduce 157) ((T_UNSET_CAST) reduce 157) ((T_VARIABLE) reduce 157) ((T_WHILE) reduce 157) ((T_YIELD) reduce 157) ((T_YIELD_FROM) reduce 157) (("[") reduce 157) (("`") reduce 157) (("{") reduce 157) (("~") reduce 157)) 24530 ((("!") reduce 149) (("\"") reduce 149) (("$") reduce 149) (("(") reduce 149) (("+") reduce 149) (("-") reduce 149) ((";") reduce 149) (("@") reduce 149) ((T_ABSTRACT) reduce 149) ((T_ARRAY) reduce 149) ((T_ARRAY_CAST) reduce 149) ((T_ATTRIBUTE) reduce 149) ((T_BOOL_CAST) reduce 149) ((T_BREAK) reduce 149) ((T_CLASS) reduce 149) ((T_CLASS_C) reduce 149) ((T_CLONE) reduce 149) ((T_CONSTANT_ENCAPSED_STRING) reduce 149) ((T_CONTINUE) reduce 149) ((T_DEC) reduce 149) ((T_DECLARE) reduce 149) ((T_DIR) reduce 149) ((T_DNUMBER) reduce 149) ((T_DO) reduce 149) ((T_DOUBLE_CAST) reduce 149) ((T_ECHO) reduce 149) ((T_ELSE) reduce 149) ((T_ELSEIF) reduce 149) ((T_EMPTY) reduce 149) ((T_ENDIF) reduce 149) ((T_ENUM) reduce 149) ((T_EVAL) reduce 149) ((T_EXIT) reduce 149) ((T_FILE) reduce 149) ((T_FINAL) reduce 149) ((T_FN) reduce 149) ((T_FOR) reduce 149) ((T_FOREACH) reduce 149) ((T_FUNCTION) reduce 149) ((T_FUNC_C) reduce 149) ((T_GLOBAL) reduce 149) ((T_GOTO) reduce 149) ((T_HALT_COMPILER) reduce 149) ((T_IF) reduce 149) ((T_INC) reduce 149) ((T_INCLUDE) reduce 149) ((T_INCLUDE_ONCE) reduce 149) ((T_INLINE_HTML) reduce 149) ((T_INTERFACE) reduce 149) ((T_INT_CAST) reduce 149) ((T_ISSET) reduce 149) ((T_LINE) reduce 149) ((T_LIST) reduce 149) ((T_LNUMBER) reduce 149) ((T_MATCH) reduce 149) ((T_METHOD_C) reduce 149) ((T_NAME_FULLY_QUALIFIED) reduce 149) ((T_NAME_QUALIFIED) reduce 149) ((T_NAME_RELATIVE) reduce 149) ((T_NEW) reduce 149) ((T_NS_C) reduce 149) ((T_OBJECT_CAST) reduce 149) ((T_PRINT) reduce 149) ((T_READONLY) reduce 149) ((T_REQUIRE) reduce 149) ((T_REQUIRE_ONCE) reduce 149) ((T_RETURN) reduce 149) ((T_START_HEREDOC) reduce 149) ((T_STATIC) reduce 149) ((T_STRING) reduce 149) ((T_STRING_CAST) reduce 149) ((T_SWITCH) reduce 149) ((T_THROW) reduce 149) ((T_TRAIT) reduce 149) ((T_TRAIT_C) reduce 149) ((T_TRY) reduce 149) ((T_UNSET) reduce 149) ((T_UNSET_CAST) reduce 149) ((T_VARIABLE) reduce 149) ((T_WHILE) reduce 149) ((T_YIELD) reduce 149) ((T_YIELD_FROM) reduce 149) (("[") reduce 149) (("`") reduce 149) (("{") reduce 149) (("~") reduce 149)) 24535 ((("!") reduce 163) (("\"") reduce 163) (("$") reduce 163) (("(") reduce 163) (("+") reduce 163) (("-") reduce 163) ((";") reduce 163) (("@") reduce 163) ((T_ABSTRACT) reduce 163) ((T_ARRAY) reduce 163) ((T_ARRAY_CAST) reduce 163) ((T_ATTRIBUTE) reduce 163) ((T_BOOL_CAST) reduce 163) ((T_BREAK) reduce 163) ((T_CLASS) reduce 163) ((T_CLASS_C) reduce 163) ((T_CLONE) reduce 163) ((T_CONSTANT_ENCAPSED_STRING) reduce 163) ((T_CONTINUE) reduce 163) ((T_DEC) reduce 163) ((T_DECLARE) reduce 163) ((T_DIR) reduce 163) ((T_DNUMBER) reduce 163) ((T_DO) reduce 163) ((T_DOUBLE_CAST) reduce 163) ((T_ECHO) reduce 163) ((T_ELSE) reduce 163) ((T_ELSEIF) reduce 163) ((T_EMPTY) reduce 163) ((T_ENDIF) reduce 163) ((T_ENUM) reduce 163) ((T_EVAL) reduce 163) ((T_EXIT) reduce 163) ((T_FILE) reduce 163) ((T_FINAL) reduce 163) ((T_FN) reduce 163) ((T_FOR) reduce 163) ((T_FOREACH) reduce 163) ((T_FUNCTION) reduce 163) ((T_FUNC_C) reduce 163) ((T_GLOBAL) reduce 163) ((T_GOTO) reduce 163) ((T_HALT_COMPILER) reduce 163) ((T_IF) reduce 163) ((T_INC) reduce 163) ((T_INCLUDE) reduce 163) ((T_INCLUDE_ONCE) reduce 163) ((T_INLINE_HTML) reduce 163) ((T_INTERFACE) reduce 163) ((T_INT_CAST) reduce 163) ((T_ISSET) reduce 163) ((T_LINE) reduce 163) ((T_LIST) reduce 163) ((T_LNUMBER) reduce 163) ((T_MATCH) reduce 163) ((T_METHOD_C) reduce 163) ((T_NAME_FULLY_QUALIFIED) reduce 163) ((T_NAME_QUALIFIED) reduce 163) ((T_NAME_RELATIVE) reduce 163) ((T_NEW) reduce 163) ((T_NS_C) reduce 163) ((T_OBJECT_CAST) reduce 163) ((T_PRINT) reduce 163) ((T_READONLY) reduce 163) ((T_REQUIRE) reduce 163) ((T_REQUIRE_ONCE) reduce 163) ((T_RETURN) reduce 163) ((T_START_HEREDOC) reduce 163) ((T_STATIC) reduce 163) ((T_STRING) reduce 163) ((T_STRING_CAST) reduce 163) ((T_SWITCH) reduce 163) ((T_THROW) reduce 163) ((T_TRAIT) reduce 163) ((T_TRAIT_C) reduce 163) ((T_TRY) reduce 163) ((T_UNSET) reduce 163) ((T_UNSET_CAST) reduce 163) ((T_VARIABLE) reduce 163) ((T_WHILE) reduce 163) ((T_YIELD) reduce 163) ((T_YIELD_FROM) reduce 163) (("[") reduce 163) (("`") reduce 163) (("{") reduce 163) (("~") reduce 163)) 24536 ((("!") reduce 219) (("\"") reduce 219) (("$") reduce 219) (("(") reduce 219) (("+") reduce 219) (("-") reduce 219) ((";") reduce 219) (("@") reduce 219) ((T_ABSTRACT) reduce 219) ((T_ARRAY) reduce 219) ((T_ARRAY_CAST) reduce 219) ((T_ATTRIBUTE) reduce 219) ((T_BOOL_CAST) reduce 219) ((T_BREAK) reduce 219) ((T_CLASS) reduce 219) ((T_CLASS_C) reduce 219) ((T_CLONE) reduce 219) ((T_CONSTANT_ENCAPSED_STRING) reduce 219) ((T_CONTINUE) reduce 219) ((T_DEC) reduce 219) ((T_DECLARE) reduce 219) ((T_DIR) reduce 219) ((T_DNUMBER) reduce 219) ((T_DO) reduce 219) ((T_DOUBLE_CAST) reduce 219) ((T_ECHO) reduce 219) ((T_ELSE) reduce 219) ((T_ELSEIF) reduce 219) ((T_EMPTY) reduce 219) ((T_ENDIF) reduce 219) ((T_ENUM) reduce 219) ((T_EVAL) reduce 219) ((T_EXIT) reduce 219) ((T_FILE) reduce 219) ((T_FINAL) reduce 219) ((T_FN) reduce 219) ((T_FOR) reduce 219) ((T_FOREACH) reduce 219) ((T_FUNCTION) reduce 219) ((T_FUNC_C) reduce 219) ((T_GLOBAL) reduce 219) ((T_GOTO) reduce 219) ((T_HALT_COMPILER) reduce 219) ((T_IF) reduce 219) ((T_INC) reduce 219) ((T_INCLUDE) reduce 219) ((T_INCLUDE_ONCE) reduce 219) ((T_INLINE_HTML) reduce 219) ((T_INTERFACE) reduce 219) ((T_INT_CAST) reduce 219) ((T_ISSET) reduce 219) ((T_LINE) reduce 219) ((T_LIST) reduce 219) ((T_LNUMBER) reduce 219) ((T_MATCH) reduce 219) ((T_METHOD_C) reduce 219) ((T_NAME_FULLY_QUALIFIED) reduce 219) ((T_NAME_QUALIFIED) reduce 219) ((T_NAME_RELATIVE) reduce 219) ((T_NEW) reduce 219) ((T_NS_C) reduce 219) ((T_OBJECT_CAST) reduce 219) ((T_PRINT) reduce 219) ((T_READONLY) reduce 219) ((T_REQUIRE) reduce 219) ((T_REQUIRE_ONCE) reduce 219) ((T_RETURN) reduce 219) ((T_START_HEREDOC) reduce 219) ((T_STATIC) reduce 219) ((T_STRING) reduce 219) ((T_STRING_CAST) reduce 219) ((T_SWITCH) reduce 219) ((T_THROW) reduce 219) ((T_TRAIT) reduce 219) ((T_TRAIT_C) reduce 219) ((T_TRY) reduce 219) ((T_UNSET) reduce 219) ((T_UNSET_CAST) reduce 219) ((T_VARIABLE) reduce 219) ((T_WHILE) reduce 219) ((T_YIELD) reduce 219) ((T_YIELD_FROM) reduce 219) (("[") reduce 219) (("`") reduce 219) (("{") reduce 219) (("~") reduce 219)) 24539 ((("!") reduce 220) (("\"") reduce 220) (("$") reduce 220) (("(") reduce 220) (("+") reduce 220) (("-") reduce 220) ((";") reduce 220) (("@") reduce 220) ((T_ABSTRACT) reduce 220) ((T_ARRAY) reduce 220) ((T_ARRAY_CAST) reduce 220) ((T_ATTRIBUTE) reduce 220) ((T_BOOL_CAST) reduce 220) ((T_BREAK) reduce 220) ((T_CLASS) reduce 220) ((T_CLASS_C) reduce 220) ((T_CLONE) reduce 220) ((T_CONSTANT_ENCAPSED_STRING) reduce 220) ((T_CONTINUE) reduce 220) ((T_DEC) reduce 220) ((T_DECLARE) reduce 220) ((T_DIR) reduce 220) ((T_DNUMBER) reduce 220) ((T_DO) reduce 220) ((T_DOUBLE_CAST) reduce 220) ((T_ECHO) reduce 220) ((T_ELSE) reduce 220) ((T_ELSEIF) reduce 220) ((T_EMPTY) reduce 220) ((T_ENDIF) reduce 220) ((T_ENUM) reduce 220) ((T_EVAL) reduce 220) ((T_EXIT) reduce 220) ((T_FILE) reduce 220) ((T_FINAL) reduce 220) ((T_FN) reduce 220) ((T_FOR) reduce 220) ((T_FOREACH) reduce 220) ((T_FUNCTION) reduce 220) ((T_FUNC_C) reduce 220) ((T_GLOBAL) reduce 220) ((T_GOTO) reduce 220) ((T_HALT_COMPILER) reduce 220) ((T_IF) reduce 220) ((T_INC) reduce 220) ((T_INCLUDE) reduce 220) ((T_INCLUDE_ONCE) reduce 220) ((T_INLINE_HTML) reduce 220) ((T_INTERFACE) reduce 220) ((T_INT_CAST) reduce 220) ((T_ISSET) reduce 220) ((T_LINE) reduce 220) ((T_LIST) reduce 220) ((T_LNUMBER) reduce 220) ((T_MATCH) reduce 220) ((T_METHOD_C) reduce 220) ((T_NAME_FULLY_QUALIFIED) reduce 220) ((T_NAME_QUALIFIED) reduce 220) ((T_NAME_RELATIVE) reduce 220) ((T_NEW) reduce 220) ((T_NS_C) reduce 220) ((T_OBJECT_CAST) reduce 220) ((T_PRINT) reduce 220) ((T_READONLY) reduce 220) ((T_REQUIRE) reduce 220) ((T_REQUIRE_ONCE) reduce 220) ((T_RETURN) reduce 220) ((T_START_HEREDOC) reduce 220) ((T_STATIC) reduce 220) ((T_STRING) reduce 220) ((T_STRING_CAST) reduce 220) ((T_SWITCH) reduce 220) ((T_THROW) reduce 220) ((T_TRAIT) reduce 220) ((T_TRAIT_C) reduce 220) ((T_TRY) reduce 220) ((T_UNSET) reduce 220) ((T_UNSET_CAST) reduce 220) ((T_VARIABLE) reduce 220) ((T_WHILE) reduce 220) ((T_YIELD) reduce 220) ((T_YIELD_FROM) reduce 220) (("[") reduce 220) (("`") reduce 220) (("{") reduce 220) (("~") reduce 220)) 24541 ((("!") reduce 153) (("\"") reduce 153) (("$") reduce 153) (("(") reduce 153) (("+") reduce 153) (("-") reduce 153) ((";") reduce 153) (("@") reduce 153) ((T_ABSTRACT) reduce 153) ((T_ARRAY) reduce 153) ((T_ARRAY_CAST) reduce 153) ((T_ATTRIBUTE) reduce 153) ((T_BOOL_CAST) reduce 153) ((T_BREAK) reduce 153) ((T_CLASS) reduce 153) ((T_CLASS_C) reduce 153) ((T_CLONE) reduce 153) ((T_CONSTANT_ENCAPSED_STRING) reduce 153) ((T_CONTINUE) reduce 153) ((T_DEC) reduce 153) ((T_DECLARE) reduce 153) ((T_DIR) reduce 153) ((T_DNUMBER) reduce 153) ((T_DO) reduce 153) ((T_DOUBLE_CAST) reduce 153) ((T_ECHO) reduce 153) ((T_ELSE) reduce 153) ((T_ELSEIF) reduce 153) ((T_EMPTY) reduce 153) ((T_ENDIF) reduce 153) ((T_ENUM) reduce 153) ((T_EVAL) reduce 153) ((T_EXIT) reduce 153) ((T_FILE) reduce 153) ((T_FINAL) reduce 153) ((T_FN) reduce 153) ((T_FOR) reduce 153) ((T_FOREACH) reduce 153) ((T_FUNCTION) reduce 153) ((T_FUNC_C) reduce 153) ((T_GLOBAL) reduce 153) ((T_GOTO) reduce 153) ((T_HALT_COMPILER) reduce 153) ((T_IF) reduce 153) ((T_INC) reduce 153) ((T_INCLUDE) reduce 153) ((T_INCLUDE_ONCE) reduce 153) ((T_INLINE_HTML) reduce 153) ((T_INTERFACE) reduce 153) ((T_INT_CAST) reduce 153) ((T_ISSET) reduce 153) ((T_LINE) reduce 153) ((T_LIST) reduce 153) ((T_LNUMBER) reduce 153) ((T_MATCH) reduce 153) ((T_METHOD_C) reduce 153) ((T_NAME_FULLY_QUALIFIED) reduce 153) ((T_NAME_QUALIFIED) reduce 153) ((T_NAME_RELATIVE) reduce 153) ((T_NEW) reduce 153) ((T_NS_C) reduce 153) ((T_OBJECT_CAST) reduce 153) ((T_PRINT) reduce 153) ((T_READONLY) reduce 153) ((T_REQUIRE) reduce 153) ((T_REQUIRE_ONCE) reduce 153) ((T_RETURN) reduce 153) ((T_START_HEREDOC) reduce 153) ((T_STATIC) reduce 153) ((T_STRING) reduce 153) ((T_STRING_CAST) reduce 153) ((T_SWITCH) reduce 153) ((T_THROW) reduce 153) ((T_TRAIT) reduce 153) ((T_TRAIT_C) reduce 153) ((T_TRY) reduce 153) ((T_UNSET) reduce 153) ((T_UNSET_CAST) reduce 153) ((T_VARIABLE) reduce 153) ((T_WHILE) reduce 153) ((T_YIELD) reduce 153) ((T_YIELD_FROM) reduce 153) (("[") reduce 153) (("`") reduce 153) (("{") reduce 153) (("~") reduce 153)) 24548 ((("!") reduce 187) (("\"") reduce 187) (("$") reduce 187) (("(") reduce 187) (("+") reduce 187) (("-") reduce 187) ((";") reduce 187) (("@") reduce 187) ((T_ABSTRACT) reduce 187) ((T_ARRAY) reduce 187) ((T_ARRAY_CAST) reduce 187) ((T_ATTRIBUTE) reduce 187) ((T_BOOL_CAST) reduce 187) ((T_BREAK) reduce 187) ((T_CLASS) reduce 187) ((T_CLASS_C) reduce 187) ((T_CLONE) reduce 187) ((T_CONSTANT_ENCAPSED_STRING) reduce 187) ((T_CONTINUE) reduce 187) ((T_DEC) reduce 187) ((T_DECLARE) reduce 187) ((T_DIR) reduce 187) ((T_DNUMBER) reduce 187) ((T_DO) reduce 187) ((T_DOUBLE_CAST) reduce 187) ((T_ECHO) reduce 187) ((T_ELSE) reduce 187) ((T_ELSEIF) reduce 187) ((T_EMPTY) reduce 187) ((T_ENDIF) reduce 187) ((T_ENUM) reduce 187) ((T_EVAL) reduce 187) ((T_EXIT) reduce 187) ((T_FILE) reduce 187) ((T_FINAL) reduce 187) ((T_FN) reduce 187) ((T_FOR) reduce 187) ((T_FOREACH) reduce 187) ((T_FUNCTION) reduce 187) ((T_FUNC_C) reduce 187) ((T_GLOBAL) reduce 187) ((T_GOTO) reduce 187) ((T_HALT_COMPILER) reduce 187) ((T_IF) reduce 187) ((T_INC) reduce 187) ((T_INCLUDE) reduce 187) ((T_INCLUDE_ONCE) reduce 187) ((T_INLINE_HTML) reduce 187) ((T_INTERFACE) reduce 187) ((T_INT_CAST) reduce 187) ((T_ISSET) reduce 187) ((T_LINE) reduce 187) ((T_LIST) reduce 187) ((T_LNUMBER) reduce 187) ((T_MATCH) reduce 187) ((T_METHOD_C) reduce 187) ((T_NAME_FULLY_QUALIFIED) reduce 187) ((T_NAME_QUALIFIED) reduce 187) ((T_NAME_RELATIVE) reduce 187) ((T_NEW) reduce 187) ((T_NS_C) reduce 187) ((T_OBJECT_CAST) reduce 187) ((T_PRINT) reduce 187) ((T_READONLY) reduce 187) ((T_REQUIRE) reduce 187) ((T_REQUIRE_ONCE) reduce 187) ((T_RETURN) reduce 187) ((T_START_HEREDOC) reduce 187) ((T_STATIC) reduce 187) ((T_STRING) reduce 187) ((T_STRING_CAST) reduce 187) ((T_SWITCH) reduce 187) ((T_THROW) reduce 187) ((T_TRAIT) reduce 187) ((T_TRAIT_C) reduce 187) ((T_TRY) reduce 187) ((T_UNSET) reduce 187) ((T_UNSET_CAST) reduce 187) ((T_VARIABLE) reduce 187) ((T_WHILE) reduce 187) ((T_YIELD) reduce 187) ((T_YIELD_FROM) reduce 187) (("[") reduce 187) (("`") reduce 187) (("{") reduce 187) (("~") reduce 187)) 24550 ((("!") reduce 152) (("\"") reduce 152) (("$") reduce 152) (("(") reduce 152) (("+") reduce 152) (("-") reduce 152) ((";") reduce 152) (("@") reduce 152) ((T_ABSTRACT) reduce 152) ((T_ARRAY) reduce 152) ((T_ARRAY_CAST) reduce 152) ((T_ATTRIBUTE) reduce 152) ((T_BOOL_CAST) reduce 152) ((T_BREAK) reduce 152) ((T_CLASS) reduce 152) ((T_CLASS_C) reduce 152) ((T_CLONE) reduce 152) ((T_CONSTANT_ENCAPSED_STRING) reduce 152) ((T_CONTINUE) reduce 152) ((T_DEC) reduce 152) ((T_DECLARE) reduce 152) ((T_DIR) reduce 152) ((T_DNUMBER) reduce 152) ((T_DO) reduce 152) ((T_DOUBLE_CAST) reduce 152) ((T_ECHO) reduce 152) ((T_ELSE) reduce 152) ((T_ELSEIF) reduce 152) ((T_EMPTY) reduce 152) ((T_ENDIF) reduce 152) ((T_ENUM) reduce 152) ((T_EVAL) reduce 152) ((T_EXIT) reduce 152) ((T_FILE) reduce 152) ((T_FINAL) reduce 152) ((T_FN) reduce 152) ((T_FOR) reduce 152) ((T_FOREACH) reduce 152) ((T_FUNCTION) reduce 152) ((T_FUNC_C) reduce 152) ((T_GLOBAL) reduce 152) ((T_GOTO) reduce 152) ((T_HALT_COMPILER) reduce 152) ((T_IF) reduce 152) ((T_INC) reduce 152) ((T_INCLUDE) reduce 152) ((T_INCLUDE_ONCE) reduce 152) ((T_INLINE_HTML) reduce 152) ((T_INTERFACE) reduce 152) ((T_INT_CAST) reduce 152) ((T_ISSET) reduce 152) ((T_LINE) reduce 152) ((T_LIST) reduce 152) ((T_LNUMBER) reduce 152) ((T_MATCH) reduce 152) ((T_METHOD_C) reduce 152) ((T_NAME_FULLY_QUALIFIED) reduce 152) ((T_NAME_QUALIFIED) reduce 152) ((T_NAME_RELATIVE) reduce 152) ((T_NEW) reduce 152) ((T_NS_C) reduce 152) ((T_OBJECT_CAST) reduce 152) ((T_PRINT) reduce 152) ((T_READONLY) reduce 152) ((T_REQUIRE) reduce 152) ((T_REQUIRE_ONCE) reduce 152) ((T_RETURN) reduce 152) ((T_START_HEREDOC) reduce 152) ((T_STATIC) reduce 152) ((T_STRING) reduce 152) ((T_STRING_CAST) reduce 152) ((T_SWITCH) reduce 152) ((T_THROW) reduce 152) ((T_TRAIT) reduce 152) ((T_TRAIT_C) reduce 152) ((T_TRY) reduce 152) ((T_UNSET) reduce 152) ((T_UNSET_CAST) reduce 152) ((T_VARIABLE) reduce 152) ((T_WHILE) reduce 152) ((T_YIELD) reduce 152) ((T_YIELD_FROM) reduce 152) (("[") reduce 152) (("`") reduce 152) (("{") reduce 152) (("~") reduce 152)) 24554 ((("!") reduce 248) (("\"") reduce 248) (("$") reduce 248) (("(") reduce 248) (("+") reduce 248) (("-") reduce 248) ((";") reduce 248) (("@") reduce 248) ((T_ABSTRACT) reduce 248) ((T_ARRAY) reduce 248) ((T_ARRAY_CAST) reduce 248) ((T_ATTRIBUTE) reduce 248) ((T_BOOL_CAST) reduce 248) ((T_BREAK) reduce 248) ((T_CLASS) reduce 248) ((T_CLASS_C) reduce 248) ((T_CLONE) reduce 248) ((T_CONSTANT_ENCAPSED_STRING) reduce 248) ((T_CONTINUE) reduce 248) ((T_DEC) reduce 248) ((T_DECLARE) reduce 248) ((T_DIR) reduce 248) ((T_DNUMBER) reduce 248) ((T_DO) reduce 248) ((T_DOUBLE_CAST) reduce 248) ((T_ECHO) reduce 248) ((T_ELSE) reduce 248) ((T_ELSEIF) reduce 248) ((T_EMPTY) reduce 248) ((T_ENUM) reduce 248) ((T_EVAL) reduce 248) ((T_EXIT) reduce 248) ((T_FILE) reduce 248) ((T_FINAL) reduce 248) ((T_FN) reduce 248) ((T_FOR) reduce 248) ((T_FOREACH) reduce 248) ((T_FUNCTION) reduce 248) ((T_FUNC_C) reduce 248) ((T_GLOBAL) reduce 248) ((T_GOTO) reduce 248) ((T_HALT_COMPILER) reduce 248) ((T_IF) reduce 248) ((T_INC) reduce 248) ((T_INCLUDE) reduce 248) ((T_INCLUDE_ONCE) reduce 248) ((T_INLINE_HTML) reduce 248) ((T_INTERFACE) reduce 248) ((T_INT_CAST) reduce 248) ((T_ISSET) reduce 248) ((T_LINE) reduce 248) ((T_LIST) reduce 248) ((T_LNUMBER) reduce 248) ((T_MATCH) reduce 248) ((T_METHOD_C) reduce 248) ((T_NAME_FULLY_QUALIFIED) reduce 248) ((T_NAME_QUALIFIED) reduce 248) ((T_NAME_RELATIVE) reduce 248) ((T_NEW) reduce 248) ((T_NS_C) reduce 248) ((T_OBJECT_CAST) reduce 248) ((T_PRINT) reduce 248) ((T_READONLY) reduce 248) ((T_REQUIRE) reduce 248) ((T_REQUIRE_ONCE) reduce 248) ((T_RETURN) reduce 248) ((T_START_HEREDOC) reduce 248) ((T_STATIC) reduce 248) ((T_STRING) reduce 248) ((T_STRING_CAST) reduce 248) ((T_SWITCH) reduce 248) ((T_THROW) reduce 248) ((T_TRAIT) reduce 248) ((T_TRAIT_C) reduce 248) ((T_TRY) reduce 248) ((T_UNSET) reduce 248) ((T_UNSET_CAST) reduce 248) ((T_VARIABLE) reduce 248) ((T_WHILE) reduce 248) ((T_YIELD) reduce 248) ((T_YIELD_FROM) reduce 248) (("[") reduce 248) (("`") reduce 248) (("{") reduce 248) (("}") reduce 248) (("~") reduce 248)) 24559 ((("!") reduce 239) (("\"") reduce 239) (("$") reduce 239) (("(") reduce 239) (("+") reduce 239) (("-") reduce 239) ((";") reduce 239) (("@") reduce 239) ((T_ABSTRACT) reduce 239) ((T_ARRAY) reduce 239) ((T_ARRAY_CAST) reduce 239) ((T_ATTRIBUTE) reduce 239) ((T_BOOL_CAST) reduce 239) ((T_BREAK) reduce 239) ((T_CLASS) reduce 239) ((T_CLASS_C) reduce 239) ((T_CLONE) reduce 239) ((T_CONSTANT_ENCAPSED_STRING) reduce 239) ((T_CONTINUE) reduce 239) ((T_DEC) reduce 239) ((T_DECLARE) reduce 239) ((T_DIR) reduce 239) ((T_DNUMBER) reduce 239) ((T_DO) reduce 239) ((T_DOUBLE_CAST) reduce 239) ((T_ECHO) reduce 239) ((T_ELSE) reduce 239) ((T_ELSEIF) reduce 239) ((T_EMPTY) reduce 239) ((T_ENUM) reduce 239) ((T_EVAL) reduce 239) ((T_EXIT) reduce 239) ((T_FILE) reduce 239) ((T_FINAL) reduce 239) ((T_FN) reduce 239) ((T_FOR) reduce 239) ((T_FOREACH) reduce 239) ((T_FUNCTION) reduce 239) ((T_FUNC_C) reduce 239) ((T_GLOBAL) reduce 239) ((T_GOTO) reduce 239) ((T_HALT_COMPILER) reduce 239) ((T_IF) reduce 239) ((T_INC) reduce 239) ((T_INCLUDE) reduce 239) ((T_INCLUDE_ONCE) reduce 239) ((T_INLINE_HTML) reduce 239) ((T_INTERFACE) reduce 239) ((T_INT_CAST) reduce 239) ((T_ISSET) reduce 239) ((T_LINE) reduce 239) ((T_LIST) reduce 239) ((T_LNUMBER) reduce 239) ((T_MATCH) reduce 239) ((T_METHOD_C) reduce 239) ((T_NAME_FULLY_QUALIFIED) reduce 239) ((T_NAME_QUALIFIED) reduce 239) ((T_NAME_RELATIVE) reduce 239) ((T_NEW) reduce 239) ((T_NS_C) reduce 239) ((T_OBJECT_CAST) reduce 239) ((T_PRINT) reduce 239) ((T_READONLY) reduce 239) ((T_REQUIRE) reduce 239) ((T_REQUIRE_ONCE) reduce 239) ((T_RETURN) reduce 239) ((T_START_HEREDOC) reduce 239) ((T_STATIC) reduce 239) ((T_STRING) reduce 239) ((T_STRING_CAST) reduce 239) ((T_SWITCH) reduce 239) ((T_THROW) reduce 239) ((T_TRAIT) reduce 239) ((T_TRAIT_C) reduce 239) ((T_TRY) reduce 239) ((T_UNSET) reduce 239) ((T_UNSET_CAST) reduce 239) ((T_VARIABLE) reduce 239) ((T_WHILE) reduce 239) ((T_YIELD) reduce 239) ((T_YIELD_FROM) reduce 239) (("[") reduce 239) (("`") reduce 239) (("{") reduce 239) (("}") reduce 239) (("~") reduce 239)) 24560 ((("!") reduce 148) (("\"") reduce 148) (("$") reduce 148) (("(") reduce 148) (("+") reduce 148) (("-") reduce 148) ((";") reduce 148) (("@") reduce 148) ((T_ABSTRACT) reduce 148) ((T_ARRAY) reduce 148) ((T_ARRAY_CAST) reduce 148) ((T_ATTRIBUTE) reduce 148) ((T_BOOL_CAST) reduce 148) ((T_BREAK) reduce 148) ((T_CLASS) reduce 148) ((T_CLASS_C) reduce 148) ((T_CLONE) reduce 148) ((T_CONSTANT_ENCAPSED_STRING) reduce 148) ((T_CONTINUE) reduce 148) ((T_DEC) reduce 148) ((T_DECLARE) reduce 148) ((T_DIR) reduce 148) ((T_DNUMBER) reduce 148) ((T_DO) reduce 148) ((T_DOUBLE_CAST) reduce 148) ((T_ECHO) reduce 148) ((T_ELSE) reduce 148) ((T_ELSEIF) reduce 148) ((T_EMPTY) reduce 148) ((T_ENUM) reduce 148) ((T_EVAL) reduce 148) ((T_EXIT) reduce 148) ((T_FILE) reduce 148) ((T_FINAL) reduce 148) ((T_FN) reduce 148) ((T_FOR) reduce 148) ((T_FOREACH) reduce 148) ((T_FUNCTION) reduce 148) ((T_FUNC_C) reduce 148) ((T_GLOBAL) reduce 148) ((T_GOTO) reduce 148) ((T_HALT_COMPILER) reduce 148) ((T_IF) reduce 148) ((T_INC) reduce 148) ((T_INCLUDE) reduce 148) ((T_INCLUDE_ONCE) reduce 148) ((T_INLINE_HTML) reduce 148) ((T_INTERFACE) reduce 148) ((T_INT_CAST) reduce 148) ((T_ISSET) reduce 148) ((T_LINE) reduce 148) ((T_LIST) reduce 148) ((T_LNUMBER) reduce 148) ((T_MATCH) reduce 148) ((T_METHOD_C) reduce 148) ((T_NAME_FULLY_QUALIFIED) reduce 148) ((T_NAME_QUALIFIED) reduce 148) ((T_NAME_RELATIVE) reduce 148) ((T_NEW) reduce 148) ((T_NS_C) reduce 148) ((T_OBJECT_CAST) reduce 148) ((T_PRINT) reduce 148) ((T_READONLY) reduce 148) ((T_REQUIRE) reduce 148) ((T_REQUIRE_ONCE) reduce 148) ((T_RETURN) reduce 148) ((T_START_HEREDOC) reduce 148) ((T_STATIC) reduce 148) ((T_STRING) reduce 148) ((T_STRING_CAST) reduce 148) ((T_SWITCH) reduce 148) ((T_THROW) reduce 148) ((T_TRAIT) reduce 148) ((T_TRAIT_C) reduce 148) ((T_TRY) reduce 148) ((T_UNSET) reduce 148) ((T_UNSET_CAST) reduce 148) ((T_VARIABLE) reduce 148) ((T_WHILE) reduce 148) ((T_YIELD) reduce 148) ((T_YIELD_FROM) reduce 148) (("[") reduce 148) (("`") reduce 148) (("{") reduce 148) (("}") reduce 148) (("~") reduce 148)) 24563 ((("!") reduce 240) (("\"") reduce 240) (("$") reduce 240) (("(") reduce 240) (("+") reduce 240) (("-") reduce 240) ((";") reduce 240) (("@") reduce 240) ((T_ABSTRACT) reduce 240) ((T_ARRAY) reduce 240) ((T_ARRAY_CAST) reduce 240) ((T_ATTRIBUTE) reduce 240) ((T_BOOL_CAST) reduce 240) ((T_BREAK) reduce 240) ((T_CLASS) reduce 240) ((T_CLASS_C) reduce 240) ((T_CLONE) reduce 240) ((T_CONSTANT_ENCAPSED_STRING) reduce 240) ((T_CONTINUE) reduce 240) ((T_DEC) reduce 240) ((T_DECLARE) reduce 240) ((T_DIR) reduce 240) ((T_DNUMBER) reduce 240) ((T_DO) reduce 240) ((T_DOUBLE_CAST) reduce 240) ((T_ECHO) reduce 240) ((T_ELSE) reduce 240) ((T_ELSEIF) reduce 240) ((T_EMPTY) reduce 240) ((T_ENUM) reduce 240) ((T_EVAL) reduce 240) ((T_EXIT) reduce 240) ((T_FILE) reduce 240) ((T_FINAL) reduce 240) ((T_FN) reduce 240) ((T_FOR) reduce 240) ((T_FOREACH) reduce 240) ((T_FUNCTION) reduce 240) ((T_FUNC_C) reduce 240) ((T_GLOBAL) reduce 240) ((T_GOTO) reduce 240) ((T_HALT_COMPILER) reduce 240) ((T_IF) reduce 240) ((T_INC) reduce 240) ((T_INCLUDE) reduce 240) ((T_INCLUDE_ONCE) reduce 240) ((T_INLINE_HTML) reduce 240) ((T_INTERFACE) reduce 240) ((T_INT_CAST) reduce 240) ((T_ISSET) reduce 240) ((T_LINE) reduce 240) ((T_LIST) reduce 240) ((T_LNUMBER) reduce 240) ((T_MATCH) reduce 240) ((T_METHOD_C) reduce 240) ((T_NAME_FULLY_QUALIFIED) reduce 240) ((T_NAME_QUALIFIED) reduce 240) ((T_NAME_RELATIVE) reduce 240) ((T_NEW) reduce 240) ((T_NS_C) reduce 240) ((T_OBJECT_CAST) reduce 240) ((T_PRINT) reduce 240) ((T_READONLY) reduce 240) ((T_REQUIRE) reduce 240) ((T_REQUIRE_ONCE) reduce 240) ((T_RETURN) reduce 240) ((T_START_HEREDOC) reduce 240) ((T_STATIC) reduce 240) ((T_STRING) reduce 240) ((T_STRING_CAST) reduce 240) ((T_SWITCH) reduce 240) ((T_THROW) reduce 240) ((T_TRAIT) reduce 240) ((T_TRAIT_C) reduce 240) ((T_TRY) reduce 240) ((T_UNSET) reduce 240) ((T_UNSET_CAST) reduce 240) ((T_VARIABLE) reduce 240) ((T_WHILE) reduce 240) ((T_YIELD) reduce 240) ((T_YIELD_FROM) reduce 240) (("[") reduce 240) (("`") reduce 240) (("{") reduce 240) (("}") reduce 240) (("~") reduce 240)) 24568 ((("!") reduce 160) (("\"") reduce 160) (("$") reduce 160) (("(") reduce 160) (("+") reduce 160) (("-") reduce 160) ((";") reduce 160) (("@") reduce 160) ((T_ABSTRACT) reduce 160) ((T_ARRAY) reduce 160) ((T_ARRAY_CAST) reduce 160) ((T_ATTRIBUTE) reduce 160) ((T_BOOL_CAST) reduce 160) ((T_BREAK) reduce 160) ((T_CLASS) reduce 160) ((T_CLASS_C) reduce 160) ((T_CLONE) reduce 160) ((T_CONSTANT_ENCAPSED_STRING) reduce 160) ((T_CONTINUE) reduce 160) ((T_DEC) reduce 160) ((T_DECLARE) reduce 160) ((T_DIR) reduce 160) ((T_DNUMBER) reduce 160) ((T_DO) reduce 160) ((T_DOUBLE_CAST) reduce 160) ((T_ECHO) reduce 160) ((T_ELSE) reduce 160) ((T_ELSEIF) reduce 160) ((T_EMPTY) reduce 160) ((T_ENUM) reduce 160) ((T_EVAL) reduce 160) ((T_EXIT) reduce 160) ((T_FILE) reduce 160) ((T_FINAL) reduce 160) ((T_FN) reduce 160) ((T_FOR) reduce 160) ((T_FOREACH) reduce 160) ((T_FUNCTION) reduce 160) ((T_FUNC_C) reduce 160) ((T_GLOBAL) reduce 160) ((T_GOTO) reduce 160) ((T_HALT_COMPILER) reduce 160) ((T_IF) reduce 160) ((T_INC) reduce 160) ((T_INCLUDE) reduce 160) ((T_INCLUDE_ONCE) reduce 160) ((T_INLINE_HTML) reduce 160) ((T_INTERFACE) reduce 160) ((T_INT_CAST) reduce 160) ((T_ISSET) reduce 160) ((T_LINE) reduce 160) ((T_LIST) reduce 160) ((T_LNUMBER) reduce 160) ((T_MATCH) reduce 160) ((T_METHOD_C) reduce 160) ((T_NAME_FULLY_QUALIFIED) reduce 160) ((T_NAME_QUALIFIED) reduce 160) ((T_NAME_RELATIVE) reduce 160) ((T_NEW) reduce 160) ((T_NS_C) reduce 160) ((T_OBJECT_CAST) reduce 160) ((T_PRINT) reduce 160) ((T_READONLY) reduce 160) ((T_REQUIRE) reduce 160) ((T_REQUIRE_ONCE) reduce 160) ((T_RETURN) reduce 160) ((T_START_HEREDOC) reduce 160) ((T_STATIC) reduce 160) ((T_STRING) reduce 160) ((T_STRING_CAST) reduce 160) ((T_SWITCH) reduce 160) ((T_THROW) reduce 160) ((T_TRAIT) reduce 160) ((T_TRAIT_C) reduce 160) ((T_TRY) reduce 160) ((T_UNSET) reduce 160) ((T_UNSET_CAST) reduce 160) ((T_VARIABLE) reduce 160) ((T_WHILE) reduce 160) ((T_YIELD) reduce 160) ((T_YIELD_FROM) reduce 160) (("[") reduce 160) (("`") reduce 160) (("{") reduce 160) (("}") reduce 160) (("~") reduce 160)) 24571 ((("!") reduce 168) (("\"") reduce 168) (("$") reduce 168) (("(") reduce 168) (("+") reduce 168) (("-") reduce 168) ((";") reduce 168) (("@") reduce 168) ((T_ABSTRACT) reduce 168) ((T_ARRAY) reduce 168) ((T_ARRAY_CAST) reduce 168) ((T_ATTRIBUTE) reduce 168) ((T_BOOL_CAST) reduce 168) ((T_BREAK) reduce 168) ((T_CATCH) reduce 168) ((T_CLASS) reduce 168) ((T_CLASS_C) reduce 168) ((T_CLONE) reduce 168) ((T_CONSTANT_ENCAPSED_STRING) reduce 168) ((T_CONTINUE) reduce 168) ((T_DEC) reduce 168) ((T_DECLARE) reduce 168) ((T_DIR) reduce 168) ((T_DNUMBER) reduce 168) ((T_DO) reduce 168) ((T_DOUBLE_CAST) reduce 168) ((T_ECHO) reduce 168) ((T_ELSE) reduce 168) ((T_ELSEIF) reduce 168) ((T_EMPTY) reduce 168) ((T_ENUM) reduce 168) ((T_EVAL) reduce 168) ((T_EXIT) reduce 168) ((T_FILE) reduce 168) ((T_FINAL) reduce 168) ((T_FINALLY) reduce 168) ((T_FN) reduce 168) ((T_FOR) reduce 168) ((T_FOREACH) reduce 168) ((T_FUNCTION) reduce 168) ((T_FUNC_C) reduce 168) ((T_GLOBAL) reduce 168) ((T_GOTO) reduce 168) ((T_HALT_COMPILER) reduce 168) ((T_IF) reduce 168) ((T_INC) reduce 168) ((T_INCLUDE) reduce 168) ((T_INCLUDE_ONCE) reduce 168) ((T_INLINE_HTML) reduce 168) ((T_INTERFACE) reduce 168) ((T_INT_CAST) reduce 168) ((T_ISSET) reduce 168) ((T_LINE) reduce 168) ((T_LIST) reduce 168) ((T_LNUMBER) reduce 168) ((T_MATCH) reduce 168) ((T_METHOD_C) reduce 168) ((T_NAME_FULLY_QUALIFIED) reduce 168) ((T_NAME_QUALIFIED) reduce 168) ((T_NAME_RELATIVE) reduce 168) ((T_NEW) reduce 168) ((T_NS_C) reduce 168) ((T_OBJECT_CAST) reduce 168) ((T_PRINT) reduce 168) ((T_READONLY) reduce 168) ((T_REQUIRE) reduce 168) ((T_REQUIRE_ONCE) reduce 168) ((T_RETURN) reduce 168) ((T_START_HEREDOC) reduce 168) ((T_STATIC) reduce 168) ((T_STRING) reduce 168) ((T_STRING_CAST) reduce 168) ((T_SWITCH) reduce 168) ((T_THROW) reduce 168) ((T_TRAIT) reduce 168) ((T_TRAIT_C) reduce 168) ((T_TRY) reduce 168) ((T_UNSET) reduce 168) ((T_UNSET_CAST) reduce 168) ((T_VARIABLE) reduce 168) ((T_WHILE) reduce 168) ((T_YIELD) reduce 168) ((T_YIELD_FROM) reduce 168) (("[") reduce 168) (("`") reduce 168) (("{") reduce 168) (("}") reduce 168) (("~") reduce 168)) 24572 ((("!") reduce 174) (("\"") reduce 174) (("$") reduce 174) (("(") reduce 174) (("+") reduce 174) (("-") reduce 174) ((";") reduce 174) (("@") reduce 174) ((T_ABSTRACT) reduce 174) ((T_ARRAY) reduce 174) ((T_ARRAY_CAST) reduce 174) ((T_ATTRIBUTE) reduce 174) ((T_BOOL_CAST) reduce 174) ((T_BREAK) reduce 174) ((T_CATCH) shift) ((T_CLASS) reduce 174) ((T_CLASS_C) reduce 174) ((T_CLONE) reduce 174) ((T_CONSTANT_ENCAPSED_STRING) reduce 174) ((T_CONTINUE) reduce 174) ((T_DEC) reduce 174) ((T_DECLARE) reduce 174) ((T_DIR) reduce 174) ((T_DNUMBER) reduce 174) ((T_DO) reduce 174) ((T_DOUBLE_CAST) reduce 174) ((T_ECHO) reduce 174) ((T_ELSE) reduce 174) ((T_ELSEIF) reduce 174) ((T_EMPTY) reduce 174) ((T_ENUM) reduce 174) ((T_EVAL) reduce 174) ((T_EXIT) reduce 174) ((T_FILE) reduce 174) ((T_FINAL) reduce 174) ((T_FINALLY) shift) ((T_FN) reduce 174) ((T_FOR) reduce 174) ((T_FOREACH) reduce 174) ((T_FUNCTION) reduce 174) ((T_FUNC_C) reduce 174) ((T_GLOBAL) reduce 174) ((T_GOTO) reduce 174) ((T_HALT_COMPILER) reduce 174) ((T_IF) reduce 174) ((T_INC) reduce 174) ((T_INCLUDE) reduce 174) ((T_INCLUDE_ONCE) reduce 174) ((T_INLINE_HTML) reduce 174) ((T_INTERFACE) reduce 174) ((T_INT_CAST) reduce 174) ((T_ISSET) reduce 174) ((T_LINE) reduce 174) ((T_LIST) reduce 174) ((T_LNUMBER) reduce 174) ((T_MATCH) reduce 174) ((T_METHOD_C) reduce 174) ((T_NAME_FULLY_QUALIFIED) reduce 174) ((T_NAME_QUALIFIED) reduce 174) ((T_NAME_RELATIVE) reduce 174) ((T_NEW) reduce 174) ((T_NS_C) reduce 174) ((T_OBJECT_CAST) reduce 174) ((T_PRINT) reduce 174) ((T_READONLY) reduce 174) ((T_REQUIRE) reduce 174) ((T_REQUIRE_ONCE) reduce 174) ((T_RETURN) reduce 174) ((T_START_HEREDOC) reduce 174) ((T_STATIC) reduce 174) ((T_STRING) reduce 174) ((T_STRING_CAST) reduce 174) ((T_SWITCH) reduce 174) ((T_THROW) reduce 174) ((T_TRAIT) reduce 174) ((T_TRAIT_C) reduce 174) ((T_TRY) reduce 174) ((T_UNSET) reduce 174) ((T_UNSET_CAST) reduce 174) ((T_VARIABLE) reduce 174) ((T_WHILE) reduce 174) ((T_YIELD) reduce 174) ((T_YIELD_FROM) reduce 174) (("[") reduce 174) (("`") reduce 174) (("{") reduce 174) (("}") reduce 174) (("~") reduce 174)) 24575 ((("!") reduce 165) (("\"") reduce 165) (("$") reduce 165) (("(") reduce 165) (("+") reduce 165) (("-") reduce 165) ((";") reduce 165) (("@") reduce 165) ((T_ABSTRACT) reduce 165) ((T_ARRAY) reduce 165) ((T_ARRAY_CAST) reduce 165) ((T_ATTRIBUTE) reduce 165) ((T_BOOL_CAST) reduce 165) ((T_BREAK) reduce 165) ((T_CLASS) reduce 165) ((T_CLASS_C) reduce 165) ((T_CLONE) reduce 165) ((T_CONSTANT_ENCAPSED_STRING) reduce 165) ((T_CONTINUE) reduce 165) ((T_DEC) reduce 165) ((T_DECLARE) reduce 165) ((T_DIR) reduce 165) ((T_DNUMBER) reduce 165) ((T_DO) reduce 165) ((T_DOUBLE_CAST) reduce 165) ((T_ECHO) reduce 165) ((T_ELSE) reduce 165) ((T_ELSEIF) reduce 165) ((T_EMPTY) reduce 165) ((T_ENUM) reduce 165) ((T_EVAL) reduce 165) ((T_EXIT) reduce 165) ((T_FILE) reduce 165) ((T_FINAL) reduce 165) ((T_FN) reduce 165) ((T_FOR) reduce 165) ((T_FOREACH) reduce 165) ((T_FUNCTION) reduce 165) ((T_FUNC_C) reduce 165) ((T_GLOBAL) reduce 165) ((T_GOTO) reduce 165) ((T_HALT_COMPILER) reduce 165) ((T_IF) reduce 165) ((T_INC) reduce 165) ((T_INCLUDE) reduce 165) ((T_INCLUDE_ONCE) reduce 165) ((T_INLINE_HTML) reduce 165) ((T_INTERFACE) reduce 165) ((T_INT_CAST) reduce 165) ((T_ISSET) reduce 165) ((T_LINE) reduce 165) ((T_LIST) reduce 165) ((T_LNUMBER) reduce 165) ((T_MATCH) reduce 165) ((T_METHOD_C) reduce 165) ((T_NAME_FULLY_QUALIFIED) reduce 165) ((T_NAME_QUALIFIED) reduce 165) ((T_NAME_RELATIVE) reduce 165) ((T_NEW) reduce 165) ((T_NS_C) reduce 165) ((T_OBJECT_CAST) reduce 165) ((T_PRINT) reduce 165) ((T_READONLY) reduce 165) ((T_REQUIRE) reduce 165) ((T_REQUIRE_ONCE) reduce 165) ((T_RETURN) reduce 165) ((T_START_HEREDOC) reduce 165) ((T_STATIC) reduce 165) ((T_STRING) reduce 165) ((T_STRING_CAST) reduce 165) ((T_SWITCH) reduce 165) ((T_THROW) reduce 165) ((T_TRAIT) reduce 165) ((T_TRAIT_C) reduce 165) ((T_TRY) reduce 165) ((T_UNSET) reduce 165) ((T_UNSET_CAST) reduce 165) ((T_VARIABLE) reduce 165) ((T_WHILE) reduce 165) ((T_YIELD) reduce 165) ((T_YIELD_FROM) reduce 165) (("[") reduce 165) (("`") reduce 165) (("{") reduce 165) (("}") reduce 165) (("~") reduce 165)) 24578 ((("!") reduce 175) (("\"") reduce 175) (("$") reduce 175) (("(") reduce 175) (("+") reduce 175) (("-") reduce 175) ((";") reduce 175) (("@") reduce 175) ((T_ABSTRACT) reduce 175) ((T_ARRAY) reduce 175) ((T_ARRAY_CAST) reduce 175) ((T_ATTRIBUTE) reduce 175) ((T_BOOL_CAST) reduce 175) ((T_BREAK) reduce 175) ((T_CLASS) reduce 175) ((T_CLASS_C) reduce 175) ((T_CLONE) reduce 175) ((T_CONSTANT_ENCAPSED_STRING) reduce 175) ((T_CONTINUE) reduce 175) ((T_DEC) reduce 175) ((T_DECLARE) reduce 175) ((T_DIR) reduce 175) ((T_DNUMBER) reduce 175) ((T_DO) reduce 175) ((T_DOUBLE_CAST) reduce 175) ((T_ECHO) reduce 175) ((T_ELSE) reduce 175) ((T_ELSEIF) reduce 175) ((T_EMPTY) reduce 175) ((T_ENUM) reduce 175) ((T_EVAL) reduce 175) ((T_EXIT) reduce 175) ((T_FILE) reduce 175) ((T_FINAL) reduce 175) ((T_FN) reduce 175) ((T_FOR) reduce 175) ((T_FOREACH) reduce 175) ((T_FUNCTION) reduce 175) ((T_FUNC_C) reduce 175) ((T_GLOBAL) reduce 175) ((T_GOTO) reduce 175) ((T_HALT_COMPILER) reduce 175) ((T_IF) reduce 175) ((T_INC) reduce 175) ((T_INCLUDE) reduce 175) ((T_INCLUDE_ONCE) reduce 175) ((T_INLINE_HTML) reduce 175) ((T_INTERFACE) reduce 175) ((T_INT_CAST) reduce 175) ((T_ISSET) reduce 175) ((T_LINE) reduce 175) ((T_LIST) reduce 175) ((T_LNUMBER) reduce 175) ((T_MATCH) reduce 175) ((T_METHOD_C) reduce 175) ((T_NAME_FULLY_QUALIFIED) reduce 175) ((T_NAME_QUALIFIED) reduce 175) ((T_NAME_RELATIVE) reduce 175) ((T_NEW) reduce 175) ((T_NS_C) reduce 175) ((T_OBJECT_CAST) reduce 175) ((T_PRINT) reduce 175) ((T_READONLY) reduce 175) ((T_REQUIRE) reduce 175) ((T_REQUIRE_ONCE) reduce 175) ((T_RETURN) reduce 175) ((T_START_HEREDOC) reduce 175) ((T_STATIC) reduce 175) ((T_STRING) reduce 175) ((T_STRING_CAST) reduce 175) ((T_SWITCH) reduce 175) ((T_THROW) reduce 175) ((T_TRAIT) reduce 175) ((T_TRAIT_C) reduce 175) ((T_TRY) reduce 175) ((T_UNSET) reduce 175) ((T_UNSET_CAST) reduce 175) ((T_VARIABLE) reduce 175) ((T_WHILE) reduce 175) ((T_YIELD) reduce 175) ((T_YIELD_FROM) reduce 175) (("[") reduce 175) (("`") reduce 175) (("{") reduce 175) (("}") reduce 175) (("~") reduce 175)) 24585 ((("!") reduce 169) (("\"") reduce 169) (("$") reduce 169) (("(") reduce 169) (("+") reduce 169) (("-") reduce 169) ((";") reduce 169) (("@") reduce 169) ((T_ABSTRACT) reduce 169) ((T_ARRAY) reduce 169) ((T_ARRAY_CAST) reduce 169) ((T_ATTRIBUTE) reduce 169) ((T_BOOL_CAST) reduce 169) ((T_BREAK) reduce 169) ((T_CATCH) reduce 169) ((T_CLASS) reduce 169) ((T_CLASS_C) reduce 169) ((T_CLONE) reduce 169) ((T_CONSTANT_ENCAPSED_STRING) reduce 169) ((T_CONTINUE) reduce 169) ((T_DEC) reduce 169) ((T_DECLARE) reduce 169) ((T_DIR) reduce 169) ((T_DNUMBER) reduce 169) ((T_DO) reduce 169) ((T_DOUBLE_CAST) reduce 169) ((T_ECHO) reduce 169) ((T_ELSE) reduce 169) ((T_ELSEIF) reduce 169) ((T_EMPTY) reduce 169) ((T_ENUM) reduce 169) ((T_EVAL) reduce 169) ((T_EXIT) reduce 169) ((T_FILE) reduce 169) ((T_FINAL) reduce 169) ((T_FINALLY) reduce 169) ((T_FN) reduce 169) ((T_FOR) reduce 169) ((T_FOREACH) reduce 169) ((T_FUNCTION) reduce 169) ((T_FUNC_C) reduce 169) ((T_GLOBAL) reduce 169) ((T_GOTO) reduce 169) ((T_HALT_COMPILER) reduce 169) ((T_IF) reduce 169) ((T_INC) reduce 169) ((T_INCLUDE) reduce 169) ((T_INCLUDE_ONCE) reduce 169) ((T_INLINE_HTML) reduce 169) ((T_INTERFACE) reduce 169) ((T_INT_CAST) reduce 169) ((T_ISSET) reduce 169) ((T_LINE) reduce 169) ((T_LIST) reduce 169) ((T_LNUMBER) reduce 169) ((T_MATCH) reduce 169) ((T_METHOD_C) reduce 169) ((T_NAME_FULLY_QUALIFIED) reduce 169) ((T_NAME_QUALIFIED) reduce 169) ((T_NAME_RELATIVE) reduce 169) ((T_NEW) reduce 169) ((T_NS_C) reduce 169) ((T_OBJECT_CAST) reduce 169) ((T_PRINT) reduce 169) ((T_READONLY) reduce 169) ((T_REQUIRE) reduce 169) ((T_REQUIRE_ONCE) reduce 169) ((T_RETURN) reduce 169) ((T_START_HEREDOC) reduce 169) ((T_STATIC) reduce 169) ((T_STRING) reduce 169) ((T_STRING_CAST) reduce 169) ((T_SWITCH) reduce 169) ((T_THROW) reduce 169) ((T_TRAIT) reduce 169) ((T_TRAIT_C) reduce 169) ((T_TRY) reduce 169) ((T_UNSET) reduce 169) ((T_UNSET_CAST) reduce 169) ((T_VARIABLE) reduce 169) ((T_WHILE) reduce 169) ((T_YIELD) reduce 169) ((T_YIELD_FROM) reduce 169) (("[") reduce 169) (("`") reduce 169) (("{") reduce 169) (("}") reduce 169) (("~") reduce 169)) 24590 ((("!") reduce 151) (("\"") reduce 151) (("$") reduce 151) (("(") reduce 151) (("+") reduce 151) (("-") reduce 151) ((";") reduce 151) (("@") reduce 151) ((T_ABSTRACT) reduce 151) ((T_ARRAY) reduce 151) ((T_ARRAY_CAST) reduce 151) ((T_ATTRIBUTE) reduce 151) ((T_BOOL_CAST) reduce 151) ((T_BREAK) reduce 151) ((T_CLASS) reduce 151) ((T_CLASS_C) reduce 151) ((T_CLONE) reduce 151) ((T_CONSTANT_ENCAPSED_STRING) reduce 151) ((T_CONTINUE) reduce 151) ((T_DEC) reduce 151) ((T_DECLARE) reduce 151) ((T_DIR) reduce 151) ((T_DNUMBER) reduce 151) ((T_DO) reduce 151) ((T_DOUBLE_CAST) reduce 151) ((T_ECHO) reduce 151) ((T_ELSE) reduce 151) ((T_ELSEIF) reduce 151) ((T_EMPTY) reduce 151) ((T_ENUM) reduce 151) ((T_EVAL) reduce 151) ((T_EXIT) reduce 151) ((T_FILE) reduce 151) ((T_FINAL) reduce 151) ((T_FN) reduce 151) ((T_FOR) reduce 151) ((T_FOREACH) reduce 151) ((T_FUNCTION) reduce 151) ((T_FUNC_C) reduce 151) ((T_GLOBAL) reduce 151) ((T_GOTO) reduce 151) ((T_HALT_COMPILER) reduce 151) ((T_IF) reduce 151) ((T_INC) reduce 151) ((T_INCLUDE) reduce 151) ((T_INCLUDE_ONCE) reduce 151) ((T_INLINE_HTML) reduce 151) ((T_INTERFACE) reduce 151) ((T_INT_CAST) reduce 151) ((T_ISSET) reduce 151) ((T_LINE) reduce 151) ((T_LIST) reduce 151) ((T_LNUMBER) reduce 151) ((T_MATCH) reduce 151) ((T_METHOD_C) reduce 151) ((T_NAME_FULLY_QUALIFIED) reduce 151) ((T_NAME_QUALIFIED) reduce 151) ((T_NAME_RELATIVE) reduce 151) ((T_NEW) reduce 151) ((T_NS_C) reduce 151) ((T_OBJECT_CAST) reduce 151) ((T_PRINT) reduce 151) ((T_READONLY) reduce 151) ((T_REQUIRE) reduce 151) ((T_REQUIRE_ONCE) reduce 151) ((T_RETURN) reduce 151) ((T_START_HEREDOC) reduce 151) ((T_STATIC) reduce 151) ((T_STRING) reduce 151) ((T_STRING_CAST) reduce 151) ((T_SWITCH) reduce 151) ((T_THROW) reduce 151) ((T_TRAIT) reduce 151) ((T_TRAIT_C) reduce 151) ((T_TRY) reduce 151) ((T_UNSET) reduce 151) ((T_UNSET_CAST) reduce 151) ((T_VARIABLE) reduce 151) ((T_WHILE) reduce 151) ((T_YIELD) reduce 151) ((T_YIELD_FROM) reduce 151) (("[") reduce 151) (("`") reduce 151) (("{") reduce 151) (("}") reduce 151) (("~") reduce 151)) 24594 ((("!") reduce 221) (("\"") reduce 221) (("$") reduce 221) (("(") reduce 221) (("+") reduce 221) (("-") reduce 221) ((";") reduce 221) (("@") reduce 221) ((T_ABSTRACT) reduce 221) ((T_ARRAY) reduce 221) ((T_ARRAY_CAST) reduce 221) ((T_ATTRIBUTE) reduce 221) ((T_BOOL_CAST) reduce 221) ((T_BREAK) reduce 221) ((T_CLASS) reduce 221) ((T_CLASS_C) reduce 221) ((T_CLONE) reduce 221) ((T_CONSTANT_ENCAPSED_STRING) reduce 221) ((T_CONTINUE) reduce 221) ((T_DEC) reduce 221) ((T_DECLARE) reduce 221) ((T_DIR) reduce 221) ((T_DNUMBER) reduce 221) ((T_DO) reduce 221) ((T_DOUBLE_CAST) reduce 221) ((T_ECHO) reduce 221) ((T_ELSE) reduce 221) ((T_ELSEIF) reduce 221) ((T_EMPTY) reduce 221) ((T_ENUM) reduce 221) ((T_EVAL) reduce 221) ((T_EXIT) reduce 221) ((T_FILE) reduce 221) ((T_FINAL) reduce 221) ((T_FN) reduce 221) ((T_FOR) reduce 221) ((T_FOREACH) reduce 221) ((T_FUNCTION) reduce 221) ((T_FUNC_C) reduce 221) ((T_GLOBAL) reduce 221) ((T_GOTO) reduce 221) ((T_HALT_COMPILER) reduce 221) ((T_IF) reduce 221) ((T_INC) reduce 221) ((T_INCLUDE) reduce 221) ((T_INCLUDE_ONCE) reduce 221) ((T_INLINE_HTML) reduce 221) ((T_INTERFACE) reduce 221) ((T_INT_CAST) reduce 221) ((T_ISSET) reduce 221) ((T_LINE) reduce 221) ((T_LIST) reduce 221) ((T_LNUMBER) reduce 221) ((T_MATCH) reduce 221) ((T_METHOD_C) reduce 221) ((T_NAME_FULLY_QUALIFIED) reduce 221) ((T_NAME_QUALIFIED) reduce 221) ((T_NAME_RELATIVE) reduce 221) ((T_NEW) reduce 221) ((T_NS_C) reduce 221) ((T_OBJECT_CAST) reduce 221) ((T_PRINT) reduce 221) ((T_READONLY) reduce 221) ((T_REQUIRE) reduce 221) ((T_REQUIRE_ONCE) reduce 221) ((T_RETURN) reduce 221) ((T_START_HEREDOC) reduce 221) ((T_STATIC) reduce 221) ((T_STRING) reduce 221) ((T_STRING_CAST) reduce 221) ((T_SWITCH) reduce 221) ((T_THROW) reduce 221) ((T_TRAIT) reduce 221) ((T_TRAIT_C) reduce 221) ((T_TRY) reduce 221) ((T_UNSET) reduce 221) ((T_UNSET_CAST) reduce 221) ((T_VARIABLE) reduce 221) ((T_WHILE) reduce 221) ((T_YIELD) reduce 221) ((T_YIELD_FROM) reduce 221) (("[") reduce 221) (("`") reduce 221) (("{") reduce 221) (("}") reduce 221) (("~") reduce 221)) 24596 ((("!") reduce 222) (("\"") reduce 222) (("$") reduce 222) (("(") reduce 222) (("+") reduce 222) (("-") reduce 222) ((";") reduce 222) (("@") reduce 222) ((T_ABSTRACT) reduce 222) ((T_ARRAY) reduce 222) ((T_ARRAY_CAST) reduce 222) ((T_ATTRIBUTE) reduce 222) ((T_BOOL_CAST) reduce 222) ((T_BREAK) reduce 222) ((T_CLASS) reduce 222) ((T_CLASS_C) reduce 222) ((T_CLONE) reduce 222) ((T_CONSTANT_ENCAPSED_STRING) reduce 222) ((T_CONTINUE) reduce 222) ((T_DEC) reduce 222) ((T_DECLARE) reduce 222) ((T_DIR) reduce 222) ((T_DNUMBER) reduce 222) ((T_DO) reduce 222) ((T_DOUBLE_CAST) reduce 222) ((T_ECHO) reduce 222) ((T_ELSE) reduce 222) ((T_ELSEIF) reduce 222) ((T_EMPTY) reduce 222) ((T_ENUM) reduce 222) ((T_EVAL) reduce 222) ((T_EXIT) reduce 222) ((T_FILE) reduce 222) ((T_FINAL) reduce 222) ((T_FN) reduce 222) ((T_FOR) reduce 222) ((T_FOREACH) reduce 222) ((T_FUNCTION) reduce 222) ((T_FUNC_C) reduce 222) ((T_GLOBAL) reduce 222) ((T_GOTO) reduce 222) ((T_HALT_COMPILER) reduce 222) ((T_IF) reduce 222) ((T_INC) reduce 222) ((T_INCLUDE) reduce 222) ((T_INCLUDE_ONCE) reduce 222) ((T_INLINE_HTML) reduce 222) ((T_INTERFACE) reduce 222) ((T_INT_CAST) reduce 222) ((T_ISSET) reduce 222) ((T_LINE) reduce 222) ((T_LIST) reduce 222) ((T_LNUMBER) reduce 222) ((T_MATCH) reduce 222) ((T_METHOD_C) reduce 222) ((T_NAME_FULLY_QUALIFIED) reduce 222) ((T_NAME_QUALIFIED) reduce 222) ((T_NAME_RELATIVE) reduce 222) ((T_NEW) reduce 222) ((T_NS_C) reduce 222) ((T_OBJECT_CAST) reduce 222) ((T_PRINT) reduce 222) ((T_READONLY) reduce 222) ((T_REQUIRE) reduce 222) ((T_REQUIRE_ONCE) reduce 222) ((T_RETURN) reduce 222) ((T_START_HEREDOC) reduce 222) ((T_STATIC) reduce 222) ((T_STRING) reduce 222) ((T_STRING_CAST) reduce 222) ((T_SWITCH) reduce 222) ((T_THROW) reduce 222) ((T_TRAIT) reduce 222) ((T_TRAIT_C) reduce 222) ((T_TRY) reduce 222) ((T_UNSET) reduce 222) ((T_UNSET_CAST) reduce 222) ((T_VARIABLE) reduce 222) ((T_WHILE) reduce 222) ((T_YIELD) reduce 222) ((T_YIELD_FROM) reduce 222) (("[") reduce 222) (("`") reduce 222) (("{") reduce 222) (("}") reduce 222) (("~") reduce 222)) 24600 ((("!") reduce 223) (("\"") reduce 223) (("$") reduce 223) (("(") reduce 223) (("+") reduce 223) (("-") reduce 223) ((";") reduce 223) (("@") reduce 223) ((T_ABSTRACT) reduce 223) ((T_ARRAY) reduce 223) ((T_ARRAY_CAST) reduce 223) ((T_ATTRIBUTE) reduce 223) ((T_BOOL_CAST) reduce 223) ((T_BREAK) reduce 223) ((T_CLASS) reduce 223) ((T_CLASS_C) reduce 223) ((T_CLONE) reduce 223) ((T_CONSTANT_ENCAPSED_STRING) reduce 223) ((T_CONTINUE) reduce 223) ((T_DEC) reduce 223) ((T_DECLARE) reduce 223) ((T_DIR) reduce 223) ((T_DNUMBER) reduce 223) ((T_DO) reduce 223) ((T_DOUBLE_CAST) reduce 223) ((T_ECHO) reduce 223) ((T_ELSE) reduce 223) ((T_ELSEIF) reduce 223) ((T_EMPTY) reduce 223) ((T_ENUM) reduce 223) ((T_EVAL) reduce 223) ((T_EXIT) reduce 223) ((T_FILE) reduce 223) ((T_FINAL) reduce 223) ((T_FN) reduce 223) ((T_FOR) reduce 223) ((T_FOREACH) reduce 223) ((T_FUNCTION) reduce 223) ((T_FUNC_C) reduce 223) ((T_GLOBAL) reduce 223) ((T_GOTO) reduce 223) ((T_HALT_COMPILER) reduce 223) ((T_IF) reduce 223) ((T_INC) reduce 223) ((T_INCLUDE) reduce 223) ((T_INCLUDE_ONCE) reduce 223) ((T_INLINE_HTML) reduce 223) ((T_INTERFACE) reduce 223) ((T_INT_CAST) reduce 223) ((T_ISSET) reduce 223) ((T_LINE) reduce 223) ((T_LIST) reduce 223) ((T_LNUMBER) reduce 223) ((T_MATCH) reduce 223) ((T_METHOD_C) reduce 223) ((T_NAME_FULLY_QUALIFIED) reduce 223) ((T_NAME_QUALIFIED) reduce 223) ((T_NAME_RELATIVE) reduce 223) ((T_NEW) reduce 223) ((T_NS_C) reduce 223) ((T_OBJECT_CAST) reduce 223) ((T_PRINT) reduce 223) ((T_READONLY) reduce 223) ((T_REQUIRE) reduce 223) ((T_REQUIRE_ONCE) reduce 223) ((T_RETURN) reduce 223) ((T_START_HEREDOC) reduce 223) ((T_STATIC) reduce 223) ((T_STRING) reduce 223) ((T_STRING_CAST) reduce 223) ((T_SWITCH) reduce 223) ((T_THROW) reduce 223) ((T_TRAIT) reduce 223) ((T_TRAIT_C) reduce 223) ((T_TRY) reduce 223) ((T_UNSET) reduce 223) ((T_UNSET_CAST) reduce 223) ((T_VARIABLE) reduce 223) ((T_WHILE) reduce 223) ((T_YIELD) reduce 223) ((T_YIELD_FROM) reduce 223) (("[") reduce 223) (("`") reduce 223) (("{") reduce 223) (("}") reduce 223) (("~") reduce 223)) 24603 ((("!") reduce 224) (("\"") reduce 224) (("$") reduce 224) (("(") reduce 224) (("+") reduce 224) (("-") reduce 224) ((";") reduce 224) (("@") reduce 224) ((T_ABSTRACT) reduce 224) ((T_ARRAY) reduce 224) ((T_ARRAY_CAST) reduce 224) ((T_ATTRIBUTE) reduce 224) ((T_BOOL_CAST) reduce 224) ((T_BREAK) reduce 224) ((T_CLASS) reduce 224) ((T_CLASS_C) reduce 224) ((T_CLONE) reduce 224) ((T_CONSTANT_ENCAPSED_STRING) reduce 224) ((T_CONTINUE) reduce 224) ((T_DEC) reduce 224) ((T_DECLARE) reduce 224) ((T_DIR) reduce 224) ((T_DNUMBER) reduce 224) ((T_DO) reduce 224) ((T_DOUBLE_CAST) reduce 224) ((T_ECHO) reduce 224) ((T_ELSE) reduce 224) ((T_ELSEIF) reduce 224) ((T_EMPTY) reduce 224) ((T_ENUM) reduce 224) ((T_EVAL) reduce 224) ((T_EXIT) reduce 224) ((T_FILE) reduce 224) ((T_FINAL) reduce 224) ((T_FN) reduce 224) ((T_FOR) reduce 224) ((T_FOREACH) reduce 224) ((T_FUNCTION) reduce 224) ((T_FUNC_C) reduce 224) ((T_GLOBAL) reduce 224) ((T_GOTO) reduce 224) ((T_HALT_COMPILER) reduce 224) ((T_IF) reduce 224) ((T_INC) reduce 224) ((T_INCLUDE) reduce 224) ((T_INCLUDE_ONCE) reduce 224) ((T_INLINE_HTML) reduce 224) ((T_INTERFACE) reduce 224) ((T_INT_CAST) reduce 224) ((T_ISSET) reduce 224) ((T_LINE) reduce 224) ((T_LIST) reduce 224) ((T_LNUMBER) reduce 224) ((T_MATCH) reduce 224) ((T_METHOD_C) reduce 224) ((T_NAME_FULLY_QUALIFIED) reduce 224) ((T_NAME_QUALIFIED) reduce 224) ((T_NAME_RELATIVE) reduce 224) ((T_NEW) reduce 224) ((T_NS_C) reduce 224) ((T_OBJECT_CAST) reduce 224) ((T_PRINT) reduce 224) ((T_READONLY) reduce 224) ((T_REQUIRE) reduce 224) ((T_REQUIRE_ONCE) reduce 224) ((T_RETURN) reduce 224) ((T_START_HEREDOC) reduce 224) ((T_STATIC) reduce 224) ((T_STRING) reduce 224) ((T_STRING_CAST) reduce 224) ((T_SWITCH) reduce 224) ((T_THROW) reduce 224) ((T_TRAIT) reduce 224) ((T_TRAIT_C) reduce 224) ((T_TRY) reduce 224) ((T_UNSET) reduce 224) ((T_UNSET_CAST) reduce 224) ((T_VARIABLE) reduce 224) ((T_WHILE) reduce 224) ((T_YIELD) reduce 224) ((T_YIELD_FROM) reduce 224) (("[") reduce 224) (("`") reduce 224) (("{") reduce 224) (("}") reduce 224) (("~") reduce 224)) 24604 ((("!") reduce 167) (("\"") reduce 167) (("$") reduce 167) (("(") reduce 167) (("+") reduce 167) (("-") reduce 167) ((";") reduce 167) (("@") reduce 167) ((T_ABSTRACT) reduce 167) ((T_ARRAY) reduce 167) ((T_ARRAY_CAST) reduce 167) ((T_ATTRIBUTE) reduce 167) ((T_BOOL_CAST) reduce 167) ((T_BREAK) reduce 167) ((T_CLASS) reduce 167) ((T_CLASS_C) reduce 167) ((T_CLONE) reduce 167) ((T_CONSTANT_ENCAPSED_STRING) reduce 167) ((T_CONTINUE) reduce 167) ((T_DEC) reduce 167) ((T_DECLARE) reduce 167) ((T_DIR) reduce 167) ((T_DNUMBER) reduce 167) ((T_DO) reduce 167) ((T_DOUBLE_CAST) reduce 167) ((T_ECHO) reduce 167) ((T_ELSE) reduce 167) ((T_ELSEIF) reduce 167) ((T_EMPTY) reduce 167) ((T_ENUM) reduce 167) ((T_EVAL) reduce 167) ((T_EXIT) reduce 167) ((T_FILE) reduce 167) ((T_FINAL) reduce 167) ((T_FN) reduce 167) ((T_FOR) reduce 167) ((T_FOREACH) reduce 167) ((T_FUNCTION) reduce 167) ((T_FUNC_C) reduce 167) ((T_GLOBAL) reduce 167) ((T_GOTO) reduce 167) ((T_HALT_COMPILER) reduce 167) ((T_IF) reduce 167) ((T_INC) reduce 167) ((T_INCLUDE) reduce 167) ((T_INCLUDE_ONCE) reduce 167) ((T_INLINE_HTML) reduce 167) ((T_INTERFACE) reduce 167) ((T_INT_CAST) reduce 167) ((T_ISSET) reduce 167) ((T_LINE) reduce 167) ((T_LIST) reduce 167) ((T_LNUMBER) reduce 167) ((T_MATCH) reduce 167) ((T_METHOD_C) reduce 167) ((T_NAME_FULLY_QUALIFIED) reduce 167) ((T_NAME_QUALIFIED) reduce 167) ((T_NAME_RELATIVE) reduce 167) ((T_NEW) reduce 167) ((T_NS_C) reduce 167) ((T_OBJECT_CAST) reduce 167) ((T_PRINT) reduce 167) ((T_READONLY) reduce 167) ((T_REQUIRE) reduce 167) ((T_REQUIRE_ONCE) reduce 167) ((T_RETURN) reduce 167) ((T_START_HEREDOC) reduce 167) ((T_STATIC) reduce 167) ((T_STRING) reduce 167) ((T_STRING_CAST) reduce 167) ((T_SWITCH) reduce 167) ((T_THROW) reduce 167) ((T_TRAIT) reduce 167) ((T_TRAIT_C) reduce 167) ((T_TRY) reduce 167) ((T_UNSET) reduce 167) ((T_UNSET_CAST) reduce 167) ((T_VARIABLE) reduce 167) ((T_WHILE) reduce 167) ((T_YIELD) reduce 167) ((T_YIELD_FROM) reduce 167) (("[") reduce 167) (("`") reduce 167) (("{") reduce 167) (("}") reduce 167) (("~") reduce 167)) 24606 ((("!") reduce 156) (("\"") reduce 156) (("$") reduce 156) (("(") reduce 156) (("+") reduce 156) (("-") reduce 156) ((";") reduce 156) (("@") reduce 156) ((T_ABSTRACT) reduce 156) ((T_ARRAY) reduce 156) ((T_ARRAY_CAST) reduce 156) ((T_ATTRIBUTE) reduce 156) ((T_BOOL_CAST) reduce 156) ((T_BREAK) reduce 156) ((T_CLASS) reduce 156) ((T_CLASS_C) reduce 156) ((T_CLONE) reduce 156) ((T_CONSTANT_ENCAPSED_STRING) reduce 156) ((T_CONTINUE) reduce 156) ((T_DEC) reduce 156) ((T_DECLARE) reduce 156) ((T_DIR) reduce 156) ((T_DNUMBER) reduce 156) ((T_DO) reduce 156) ((T_DOUBLE_CAST) reduce 156) ((T_ECHO) reduce 156) ((T_ELSE) reduce 156) ((T_ELSEIF) reduce 156) ((T_EMPTY) reduce 156) ((T_ENUM) reduce 156) ((T_EVAL) reduce 156) ((T_EXIT) reduce 156) ((T_FILE) reduce 156) ((T_FINAL) reduce 156) ((T_FN) reduce 156) ((T_FOR) reduce 156) ((T_FOREACH) reduce 156) ((T_FUNCTION) reduce 156) ((T_FUNC_C) reduce 156) ((T_GLOBAL) reduce 156) ((T_GOTO) reduce 156) ((T_HALT_COMPILER) reduce 156) ((T_IF) reduce 156) ((T_INC) reduce 156) ((T_INCLUDE) reduce 156) ((T_INCLUDE_ONCE) reduce 156) ((T_INLINE_HTML) reduce 156) ((T_INTERFACE) reduce 156) ((T_INT_CAST) reduce 156) ((T_ISSET) reduce 156) ((T_LINE) reduce 156) ((T_LIST) reduce 156) ((T_LNUMBER) reduce 156) ((T_MATCH) reduce 156) ((T_METHOD_C) reduce 156) ((T_NAME_FULLY_QUALIFIED) reduce 156) ((T_NAME_QUALIFIED) reduce 156) ((T_NAME_RELATIVE) reduce 156) ((T_NEW) reduce 156) ((T_NS_C) reduce 156) ((T_OBJECT_CAST) reduce 156) ((T_PRINT) reduce 156) ((T_READONLY) reduce 156) ((T_REQUIRE) reduce 156) ((T_REQUIRE_ONCE) reduce 156) ((T_RETURN) reduce 156) ((T_START_HEREDOC) reduce 156) ((T_STATIC) reduce 156) ((T_STRING) reduce 156) ((T_STRING_CAST) reduce 156) ((T_SWITCH) reduce 156) ((T_THROW) reduce 156) ((T_TRAIT) reduce 156) ((T_TRAIT_C) reduce 156) ((T_TRY) reduce 156) ((T_UNSET) reduce 156) ((T_UNSET_CAST) reduce 156) ((T_VARIABLE) reduce 156) ((T_WHILE) reduce 156) ((T_YIELD) reduce 156) ((T_YIELD_FROM) reduce 156) (("[") reduce 156) (("`") reduce 156) (("{") reduce 156) (("}") reduce 156) (("~") reduce 156)) 24608 ((("!") reduce 154) (("\"") reduce 154) (("$") reduce 154) (("(") reduce 154) (("+") reduce 154) (("-") reduce 154) ((";") reduce 154) (("@") reduce 154) ((T_ABSTRACT) reduce 154) ((T_ARRAY) reduce 154) ((T_ARRAY_CAST) reduce 154) ((T_ATTRIBUTE) reduce 154) ((T_BOOL_CAST) reduce 154) ((T_BREAK) reduce 154) ((T_CLASS) reduce 154) ((T_CLASS_C) reduce 154) ((T_CLONE) reduce 154) ((T_CONSTANT_ENCAPSED_STRING) reduce 154) ((T_CONTINUE) reduce 154) ((T_DEC) reduce 154) ((T_DECLARE) reduce 154) ((T_DIR) reduce 154) ((T_DNUMBER) reduce 154) ((T_DO) reduce 154) ((T_DOUBLE_CAST) reduce 154) ((T_ECHO) reduce 154) ((T_ELSE) reduce 154) ((T_ELSEIF) reduce 154) ((T_EMPTY) reduce 154) ((T_ENUM) reduce 154) ((T_EVAL) reduce 154) ((T_EXIT) reduce 154) ((T_FILE) reduce 154) ((T_FINAL) reduce 154) ((T_FN) reduce 154) ((T_FOR) reduce 154) ((T_FOREACH) reduce 154) ((T_FUNCTION) reduce 154) ((T_FUNC_C) reduce 154) ((T_GLOBAL) reduce 154) ((T_GOTO) reduce 154) ((T_HALT_COMPILER) reduce 154) ((T_IF) reduce 154) ((T_INC) reduce 154) ((T_INCLUDE) reduce 154) ((T_INCLUDE_ONCE) reduce 154) ((T_INLINE_HTML) reduce 154) ((T_INTERFACE) reduce 154) ((T_INT_CAST) reduce 154) ((T_ISSET) reduce 154) ((T_LINE) reduce 154) ((T_LIST) reduce 154) ((T_LNUMBER) reduce 154) ((T_MATCH) reduce 154) ((T_METHOD_C) reduce 154) ((T_NAME_FULLY_QUALIFIED) reduce 154) ((T_NAME_QUALIFIED) reduce 154) ((T_NAME_RELATIVE) reduce 154) ((T_NEW) reduce 154) ((T_NS_C) reduce 154) ((T_OBJECT_CAST) reduce 154) ((T_PRINT) reduce 154) ((T_READONLY) reduce 154) ((T_REQUIRE) reduce 154) ((T_REQUIRE_ONCE) reduce 154) ((T_RETURN) reduce 154) ((T_START_HEREDOC) reduce 154) ((T_STATIC) reduce 154) ((T_STRING) reduce 154) ((T_STRING_CAST) reduce 154) ((T_SWITCH) reduce 154) ((T_THROW) reduce 154) ((T_TRAIT) reduce 154) ((T_TRAIT_C) reduce 154) ((T_TRY) reduce 154) ((T_UNSET) reduce 154) ((T_UNSET_CAST) reduce 154) ((T_VARIABLE) reduce 154) ((T_WHILE) reduce 154) ((T_YIELD) reduce 154) ((T_YIELD_FROM) reduce 154) (("[") reduce 154) (("`") reduce 154) (("{") reduce 154) (("}") reduce 154) (("~") reduce 154)) 24610 ((("!") reduce 166) (("\"") reduce 166) (("$") reduce 166) (("(") reduce 166) (("+") reduce 166) (("-") reduce 166) ((";") reduce 166) (("@") reduce 166) ((T_ABSTRACT) reduce 166) ((T_ARRAY) reduce 166) ((T_ARRAY_CAST) reduce 166) ((T_ATTRIBUTE) reduce 166) ((T_BOOL_CAST) reduce 166) ((T_BREAK) reduce 166) ((T_CLASS) reduce 166) ((T_CLASS_C) reduce 166) ((T_CLONE) reduce 166) ((T_CONSTANT_ENCAPSED_STRING) reduce 166) ((T_CONTINUE) reduce 166) ((T_DEC) reduce 166) ((T_DECLARE) reduce 166) ((T_DIR) reduce 166) ((T_DNUMBER) reduce 166) ((T_DO) reduce 166) ((T_DOUBLE_CAST) reduce 166) ((T_ECHO) reduce 166) ((T_ELSE) reduce 166) ((T_ELSEIF) reduce 166) ((T_EMPTY) reduce 166) ((T_ENUM) reduce 166) ((T_EVAL) reduce 166) ((T_EXIT) reduce 166) ((T_FILE) reduce 166) ((T_FINAL) reduce 166) ((T_FN) reduce 166) ((T_FOR) reduce 166) ((T_FOREACH) reduce 166) ((T_FUNCTION) reduce 166) ((T_FUNC_C) reduce 166) ((T_GLOBAL) reduce 166) ((T_GOTO) reduce 166) ((T_HALT_COMPILER) reduce 166) ((T_IF) reduce 166) ((T_INC) reduce 166) ((T_INCLUDE) reduce 166) ((T_INCLUDE_ONCE) reduce 166) ((T_INLINE_HTML) reduce 166) ((T_INTERFACE) reduce 166) ((T_INT_CAST) reduce 166) ((T_ISSET) reduce 166) ((T_LINE) reduce 166) ((T_LIST) reduce 166) ((T_LNUMBER) reduce 166) ((T_MATCH) reduce 166) ((T_METHOD_C) reduce 166) ((T_NAME_FULLY_QUALIFIED) reduce 166) ((T_NAME_QUALIFIED) reduce 166) ((T_NAME_RELATIVE) reduce 166) ((T_NEW) reduce 166) ((T_NS_C) reduce 166) ((T_OBJECT_CAST) reduce 166) ((T_PRINT) reduce 166) ((T_READONLY) reduce 166) ((T_REQUIRE) reduce 166) ((T_REQUIRE_ONCE) reduce 166) ((T_RETURN) reduce 166) ((T_START_HEREDOC) reduce 166) ((T_STATIC) reduce 166) ((T_STRING) reduce 166) ((T_STRING_CAST) reduce 166) ((T_SWITCH) reduce 166) ((T_THROW) reduce 166) ((T_TRAIT) reduce 166) ((T_TRAIT_C) reduce 166) ((T_TRY) reduce 166) ((T_UNSET) reduce 166) ((T_UNSET_CAST) reduce 166) ((T_VARIABLE) reduce 166) ((T_WHILE) reduce 166) ((T_YIELD) reduce 166) ((T_YIELD_FROM) reduce 166) (("[") reduce 166) (("`") reduce 166) (("{") reduce 166) (("}") reduce 166) (("~") reduce 166)) 24612 ((("!") reduce 155) (("\"") reduce 155) (("$") reduce 155) (("(") reduce 155) (("+") reduce 155) (("-") reduce 155) ((";") reduce 155) (("@") reduce 155) ((T_ABSTRACT) reduce 155) ((T_ARRAY) reduce 155) ((T_ARRAY_CAST) reduce 155) ((T_ATTRIBUTE) reduce 155) ((T_BOOL_CAST) reduce 155) ((T_BREAK) reduce 155) ((T_CLASS) reduce 155) ((T_CLASS_C) reduce 155) ((T_CLONE) reduce 155) ((T_CONSTANT_ENCAPSED_STRING) reduce 155) ((T_CONTINUE) reduce 155) ((T_DEC) reduce 155) ((T_DECLARE) reduce 155) ((T_DIR) reduce 155) ((T_DNUMBER) reduce 155) ((T_DO) reduce 155) ((T_DOUBLE_CAST) reduce 155) ((T_ECHO) reduce 155) ((T_ELSE) reduce 155) ((T_ELSEIF) reduce 155) ((T_EMPTY) reduce 155) ((T_ENUM) reduce 155) ((T_EVAL) reduce 155) ((T_EXIT) reduce 155) ((T_FILE) reduce 155) ((T_FINAL) reduce 155) ((T_FN) reduce 155) ((T_FOR) reduce 155) ((T_FOREACH) reduce 155) ((T_FUNCTION) reduce 155) ((T_FUNC_C) reduce 155) ((T_GLOBAL) reduce 155) ((T_GOTO) reduce 155) ((T_HALT_COMPILER) reduce 155) ((T_IF) reduce 155) ((T_INC) reduce 155) ((T_INCLUDE) reduce 155) ((T_INCLUDE_ONCE) reduce 155) ((T_INLINE_HTML) reduce 155) ((T_INTERFACE) reduce 155) ((T_INT_CAST) reduce 155) ((T_ISSET) reduce 155) ((T_LINE) reduce 155) ((T_LIST) reduce 155) ((T_LNUMBER) reduce 155) ((T_MATCH) reduce 155) ((T_METHOD_C) reduce 155) ((T_NAME_FULLY_QUALIFIED) reduce 155) ((T_NAME_QUALIFIED) reduce 155) ((T_NAME_RELATIVE) reduce 155) ((T_NEW) reduce 155) ((T_NS_C) reduce 155) ((T_OBJECT_CAST) reduce 155) ((T_PRINT) reduce 155) ((T_READONLY) reduce 155) ((T_REQUIRE) reduce 155) ((T_REQUIRE_ONCE) reduce 155) ((T_RETURN) reduce 155) ((T_START_HEREDOC) reduce 155) ((T_STATIC) reduce 155) ((T_STRING) reduce 155) ((T_STRING_CAST) reduce 155) ((T_SWITCH) reduce 155) ((T_THROW) reduce 155) ((T_TRAIT) reduce 155) ((T_TRAIT_C) reduce 155) ((T_TRY) reduce 155) ((T_UNSET) reduce 155) ((T_UNSET_CAST) reduce 155) ((T_VARIABLE) reduce 155) ((T_WHILE) reduce 155) ((T_YIELD) reduce 155) ((T_YIELD_FROM) reduce 155) (("[") reduce 155) (("`") reduce 155) (("{") reduce 155) (("}") reduce 155) (("~") reduce 155)) 24622 ((("!") reduce 162) (("\"") reduce 162) (("$") reduce 162) (("(") reduce 162) (("+") reduce 162) (("-") reduce 162) ((";") reduce 162) (("@") reduce 162) ((T_ABSTRACT) reduce 162) ((T_ARRAY) reduce 162) ((T_ARRAY_CAST) reduce 162) ((T_ATTRIBUTE) reduce 162) ((T_BOOL_CAST) reduce 162) ((T_BREAK) reduce 162) ((T_CLASS) reduce 162) ((T_CLASS_C) reduce 162) ((T_CLONE) reduce 162) ((T_CONSTANT_ENCAPSED_STRING) reduce 162) ((T_CONTINUE) reduce 162) ((T_DEC) reduce 162) ((T_DECLARE) reduce 162) ((T_DIR) reduce 162) ((T_DNUMBER) reduce 162) ((T_DO) reduce 162) ((T_DOUBLE_CAST) reduce 162) ((T_ECHO) reduce 162) ((T_ELSE) reduce 162) ((T_ELSEIF) reduce 162) ((T_EMPTY) reduce 162) ((T_ENUM) reduce 162) ((T_EVAL) reduce 162) ((T_EXIT) reduce 162) ((T_FILE) reduce 162) ((T_FINAL) reduce 162) ((T_FN) reduce 162) ((T_FOR) reduce 162) ((T_FOREACH) reduce 162) ((T_FUNCTION) reduce 162) ((T_FUNC_C) reduce 162) ((T_GLOBAL) reduce 162) ((T_GOTO) reduce 162) ((T_HALT_COMPILER) reduce 162) ((T_IF) reduce 162) ((T_INC) reduce 162) ((T_INCLUDE) reduce 162) ((T_INCLUDE_ONCE) reduce 162) ((T_INLINE_HTML) reduce 162) ((T_INTERFACE) reduce 162) ((T_INT_CAST) reduce 162) ((T_ISSET) reduce 162) ((T_LINE) reduce 162) ((T_LIST) reduce 162) ((T_LNUMBER) reduce 162) ((T_MATCH) reduce 162) ((T_METHOD_C) reduce 162) ((T_NAME_FULLY_QUALIFIED) reduce 162) ((T_NAME_QUALIFIED) reduce 162) ((T_NAME_RELATIVE) reduce 162) ((T_NEW) reduce 162) ((T_NS_C) reduce 162) ((T_OBJECT_CAST) reduce 162) ((T_PRINT) reduce 162) ((T_READONLY) reduce 162) ((T_REQUIRE) reduce 162) ((T_REQUIRE_ONCE) reduce 162) ((T_RETURN) reduce 162) ((T_START_HEREDOC) reduce 162) ((T_STATIC) reduce 162) ((T_STRING) reduce 162) ((T_STRING_CAST) reduce 162) ((T_SWITCH) reduce 162) ((T_THROW) reduce 162) ((T_TRAIT) reduce 162) ((T_TRAIT_C) reduce 162) ((T_TRY) reduce 162) ((T_UNSET) reduce 162) ((T_UNSET_CAST) reduce 162) ((T_VARIABLE) reduce 162) ((T_WHILE) reduce 162) ((T_YIELD) reduce 162) ((T_YIELD_FROM) reduce 162) (("[") reduce 162) (("`") reduce 162) (("{") reduce 162) (("}") reduce 162) (("~") reduce 162)) 24623 ((("!") reduce 217) (("\"") reduce 217) (("$") reduce 217) (("(") reduce 217) (("+") reduce 217) (("-") reduce 217) ((";") reduce 217) (("@") reduce 217) ((T_ABSTRACT) reduce 217) ((T_ARRAY) reduce 217) ((T_ARRAY_CAST) reduce 217) ((T_ATTRIBUTE) reduce 217) ((T_BOOL_CAST) reduce 217) ((T_BREAK) reduce 217) ((T_CLASS) reduce 217) ((T_CLASS_C) reduce 217) ((T_CLONE) reduce 217) ((T_CONSTANT_ENCAPSED_STRING) reduce 217) ((T_CONTINUE) reduce 217) ((T_DEC) reduce 217) ((T_DECLARE) reduce 217) ((T_DIR) reduce 217) ((T_DNUMBER) reduce 217) ((T_DO) reduce 217) ((T_DOUBLE_CAST) reduce 217) ((T_ECHO) reduce 217) ((T_ELSE) reduce 217) ((T_ELSEIF) reduce 217) ((T_EMPTY) reduce 217) ((T_ENUM) reduce 217) ((T_EVAL) reduce 217) ((T_EXIT) reduce 217) ((T_FILE) reduce 217) ((T_FINAL) reduce 217) ((T_FN) reduce 217) ((T_FOR) reduce 217) ((T_FOREACH) reduce 217) ((T_FUNCTION) reduce 217) ((T_FUNC_C) reduce 217) ((T_GLOBAL) reduce 217) ((T_GOTO) reduce 217) ((T_HALT_COMPILER) reduce 217) ((T_IF) reduce 217) ((T_INC) reduce 217) ((T_INCLUDE) reduce 217) ((T_INCLUDE_ONCE) reduce 217) ((T_INLINE_HTML) reduce 217) ((T_INTERFACE) reduce 217) ((T_INT_CAST) reduce 217) ((T_ISSET) reduce 217) ((T_LINE) reduce 217) ((T_LIST) reduce 217) ((T_LNUMBER) reduce 217) ((T_MATCH) reduce 217) ((T_METHOD_C) reduce 217) ((T_NAME_FULLY_QUALIFIED) reduce 217) ((T_NAME_QUALIFIED) reduce 217) ((T_NAME_RELATIVE) reduce 217) ((T_NEW) reduce 217) ((T_NS_C) reduce 217) ((T_OBJECT_CAST) reduce 217) ((T_PRINT) reduce 217) ((T_READONLY) reduce 217) ((T_REQUIRE) reduce 217) ((T_REQUIRE_ONCE) reduce 217) ((T_RETURN) reduce 217) ((T_START_HEREDOC) reduce 217) ((T_STATIC) reduce 217) ((T_STRING) reduce 217) ((T_STRING_CAST) reduce 217) ((T_SWITCH) reduce 217) ((T_THROW) reduce 217) ((T_TRAIT) reduce 217) ((T_TRAIT_C) reduce 217) ((T_TRY) reduce 217) ((T_UNSET) reduce 217) ((T_UNSET_CAST) reduce 217) ((T_VARIABLE) reduce 217) ((T_WHILE) reduce 217) ((T_YIELD) reduce 217) ((T_YIELD_FROM) reduce 217) (("[") reduce 217) (("`") reduce 217) (("{") reduce 217) (("}") reduce 217) (("~") reduce 217)) 24626 ((("!") reduce 218) (("\"") reduce 218) (("$") reduce 218) (("(") reduce 218) (("+") reduce 218) (("-") reduce 218) ((";") reduce 218) (("@") reduce 218) ((T_ABSTRACT) reduce 218) ((T_ARRAY) reduce 218) ((T_ARRAY_CAST) reduce 218) ((T_ATTRIBUTE) reduce 218) ((T_BOOL_CAST) reduce 218) ((T_BREAK) reduce 218) ((T_CLASS) reduce 218) ((T_CLASS_C) reduce 218) ((T_CLONE) reduce 218) ((T_CONSTANT_ENCAPSED_STRING) reduce 218) ((T_CONTINUE) reduce 218) ((T_DEC) reduce 218) ((T_DECLARE) reduce 218) ((T_DIR) reduce 218) ((T_DNUMBER) reduce 218) ((T_DO) reduce 218) ((T_DOUBLE_CAST) reduce 218) ((T_ECHO) reduce 218) ((T_ELSE) reduce 218) ((T_ELSEIF) reduce 218) ((T_EMPTY) reduce 218) ((T_ENUM) reduce 218) ((T_EVAL) reduce 218) ((T_EXIT) reduce 218) ((T_FILE) reduce 218) ((T_FINAL) reduce 218) ((T_FN) reduce 218) ((T_FOR) reduce 218) ((T_FOREACH) reduce 218) ((T_FUNCTION) reduce 218) ((T_FUNC_C) reduce 218) ((T_GLOBAL) reduce 218) ((T_GOTO) reduce 218) ((T_HALT_COMPILER) reduce 218) ((T_IF) reduce 218) ((T_INC) reduce 218) ((T_INCLUDE) reduce 218) ((T_INCLUDE_ONCE) reduce 218) ((T_INLINE_HTML) reduce 218) ((T_INTERFACE) reduce 218) ((T_INT_CAST) reduce 218) ((T_ISSET) reduce 218) ((T_LINE) reduce 218) ((T_LIST) reduce 218) ((T_LNUMBER) reduce 218) ((T_MATCH) reduce 218) ((T_METHOD_C) reduce 218) ((T_NAME_FULLY_QUALIFIED) reduce 218) ((T_NAME_QUALIFIED) reduce 218) ((T_NAME_RELATIVE) reduce 218) ((T_NEW) reduce 218) ((T_NS_C) reduce 218) ((T_OBJECT_CAST) reduce 218) ((T_PRINT) reduce 218) ((T_READONLY) reduce 218) ((T_REQUIRE) reduce 218) ((T_REQUIRE_ONCE) reduce 218) ((T_RETURN) reduce 218) ((T_START_HEREDOC) reduce 218) ((T_STATIC) reduce 218) ((T_STRING) reduce 218) ((T_STRING_CAST) reduce 218) ((T_SWITCH) reduce 218) ((T_THROW) reduce 218) ((T_TRAIT) reduce 218) ((T_TRAIT_C) reduce 218) ((T_TRY) reduce 218) ((T_UNSET) reduce 218) ((T_UNSET_CAST) reduce 218) ((T_VARIABLE) reduce 218) ((T_WHILE) reduce 218) ((T_YIELD) reduce 218) ((T_YIELD_FROM) reduce 218) (("[") reduce 218) (("`") reduce 218) (("{") reduce 218) (("}") reduce 218) (("~") reduce 218)) 24627 ((("!") reduce 161) (("\"") reduce 161) (("$") reduce 161) (("(") reduce 161) (("+") reduce 161) (("-") reduce 161) ((";") reduce 161) (("@") reduce 161) ((T_ABSTRACT) reduce 161) ((T_ARRAY) reduce 161) ((T_ARRAY_CAST) reduce 161) ((T_ATTRIBUTE) reduce 161) ((T_BOOL_CAST) reduce 161) ((T_BREAK) reduce 161) ((T_CLASS) reduce 161) ((T_CLASS_C) reduce 161) ((T_CLONE) reduce 161) ((T_CONSTANT_ENCAPSED_STRING) reduce 161) ((T_CONTINUE) reduce 161) ((T_DEC) reduce 161) ((T_DECLARE) reduce 161) ((T_DIR) reduce 161) ((T_DNUMBER) reduce 161) ((T_DO) reduce 161) ((T_DOUBLE_CAST) reduce 161) ((T_ECHO) reduce 161) ((T_ELSE) reduce 161) ((T_ELSEIF) reduce 161) ((T_EMPTY) reduce 161) ((T_ENUM) reduce 161) ((T_EVAL) reduce 161) ((T_EXIT) reduce 161) ((T_FILE) reduce 161) ((T_FINAL) reduce 161) ((T_FN) reduce 161) ((T_FOR) reduce 161) ((T_FOREACH) reduce 161) ((T_FUNCTION) reduce 161) ((T_FUNC_C) reduce 161) ((T_GLOBAL) reduce 161) ((T_GOTO) reduce 161) ((T_HALT_COMPILER) reduce 161) ((T_IF) reduce 161) ((T_INC) reduce 161) ((T_INCLUDE) reduce 161) ((T_INCLUDE_ONCE) reduce 161) ((T_INLINE_HTML) reduce 161) ((T_INTERFACE) reduce 161) ((T_INT_CAST) reduce 161) ((T_ISSET) reduce 161) ((T_LINE) reduce 161) ((T_LIST) reduce 161) ((T_LNUMBER) reduce 161) ((T_MATCH) reduce 161) ((T_METHOD_C) reduce 161) ((T_NAME_FULLY_QUALIFIED) reduce 161) ((T_NAME_QUALIFIED) reduce 161) ((T_NAME_RELATIVE) reduce 161) ((T_NEW) reduce 161) ((T_NS_C) reduce 161) ((T_OBJECT_CAST) reduce 161) ((T_PRINT) reduce 161) ((T_READONLY) reduce 161) ((T_REQUIRE) reduce 161) ((T_REQUIRE_ONCE) reduce 161) ((T_RETURN) reduce 161) ((T_START_HEREDOC) reduce 161) ((T_STATIC) reduce 161) ((T_STRING) reduce 161) ((T_STRING_CAST) reduce 161) ((T_SWITCH) reduce 161) ((T_THROW) reduce 161) ((T_TRAIT) reduce 161) ((T_TRAIT_C) reduce 161) ((T_TRY) reduce 161) ((T_UNSET) reduce 161) ((T_UNSET_CAST) reduce 161) ((T_VARIABLE) reduce 161) ((T_WHILE) reduce 161) ((T_YIELD) reduce 161) ((T_YIELD_FROM) reduce 161) (("[") reduce 161) (("`") reduce 161) (("{") reduce 161) (("}") reduce 161) (("~") reduce 161)) 24636 ((("!") reduce 150) (("\"") reduce 150) (("$") reduce 150) (("(") reduce 150) (("+") reduce 150) (("-") reduce 150) ((";") reduce 150) (("@") reduce 150) ((T_ABSTRACT) reduce 150) ((T_ARRAY) reduce 150) ((T_ARRAY_CAST) reduce 150) ((T_ATTRIBUTE) reduce 150) ((T_BOOL_CAST) reduce 150) ((T_BREAK) reduce 150) ((T_CLASS) reduce 150) ((T_CLASS_C) reduce 150) ((T_CLONE) reduce 150) ((T_CONSTANT_ENCAPSED_STRING) reduce 150) ((T_CONTINUE) reduce 150) ((T_DEC) reduce 150) ((T_DECLARE) reduce 150) ((T_DIR) reduce 150) ((T_DNUMBER) reduce 150) ((T_DO) reduce 150) ((T_DOUBLE_CAST) reduce 150) ((T_ECHO) reduce 150) ((T_ELSE) reduce 150) ((T_ELSEIF) reduce 150) ((T_EMPTY) reduce 150) ((T_ENUM) reduce 150) ((T_EVAL) reduce 150) ((T_EXIT) reduce 150) ((T_FILE) reduce 150) ((T_FINAL) reduce 150) ((T_FN) reduce 150) ((T_FOR) reduce 150) ((T_FOREACH) reduce 150) ((T_FUNCTION) reduce 150) ((T_FUNC_C) reduce 150) ((T_GLOBAL) reduce 150) ((T_GOTO) reduce 150) ((T_HALT_COMPILER) reduce 150) ((T_IF) reduce 150) ((T_INC) reduce 150) ((T_INCLUDE) reduce 150) ((T_INCLUDE_ONCE) reduce 150) ((T_INLINE_HTML) reduce 150) ((T_INTERFACE) reduce 150) ((T_INT_CAST) reduce 150) ((T_ISSET) reduce 150) ((T_LINE) reduce 150) ((T_LIST) reduce 150) ((T_LNUMBER) reduce 150) ((T_MATCH) reduce 150) ((T_METHOD_C) reduce 150) ((T_NAME_FULLY_QUALIFIED) reduce 150) ((T_NAME_QUALIFIED) reduce 150) ((T_NAME_RELATIVE) reduce 150) ((T_NEW) reduce 150) ((T_NS_C) reduce 150) ((T_OBJECT_CAST) reduce 150) ((T_PRINT) reduce 150) ((T_READONLY) reduce 150) ((T_REQUIRE) reduce 150) ((T_REQUIRE_ONCE) reduce 150) ((T_RETURN) reduce 150) ((T_START_HEREDOC) reduce 150) ((T_STATIC) reduce 150) ((T_STRING) reduce 150) ((T_STRING_CAST) reduce 150) ((T_SWITCH) reduce 150) ((T_THROW) reduce 150) ((T_TRAIT) reduce 150) ((T_TRAIT_C) reduce 150) ((T_TRY) reduce 150) ((T_UNSET) reduce 150) ((T_UNSET_CAST) reduce 150) ((T_VARIABLE) reduce 150) ((T_WHILE) reduce 150) ((T_YIELD) reduce 150) ((T_YIELD_FROM) reduce 150) (("[") reduce 150) (("`") reduce 150) (("{") reduce 150) (("}") reduce 150) (("~") reduce 150)) 24637 ((("!") reduce 215) (("\"") reduce 215) (("$") reduce 215) (("(") reduce 215) (("+") reduce 215) (("-") reduce 215) ((";") reduce 215) (("@") reduce 215) ((T_ABSTRACT) reduce 215) ((T_ARRAY) reduce 215) ((T_ARRAY_CAST) reduce 215) ((T_ATTRIBUTE) reduce 215) ((T_BOOL_CAST) reduce 215) ((T_BREAK) reduce 215) ((T_CLASS) reduce 215) ((T_CLASS_C) reduce 215) ((T_CLONE) reduce 215) ((T_CONSTANT_ENCAPSED_STRING) reduce 215) ((T_CONTINUE) reduce 215) ((T_DEC) reduce 215) ((T_DECLARE) reduce 215) ((T_DIR) reduce 215) ((T_DNUMBER) reduce 215) ((T_DO) reduce 215) ((T_DOUBLE_CAST) reduce 215) ((T_ECHO) reduce 215) ((T_ELSE) reduce 215) ((T_ELSEIF) reduce 215) ((T_EMPTY) reduce 215) ((T_ENUM) reduce 215) ((T_EVAL) reduce 215) ((T_EXIT) reduce 215) ((T_FILE) reduce 215) ((T_FINAL) reduce 215) ((T_FN) reduce 215) ((T_FOR) reduce 215) ((T_FOREACH) reduce 215) ((T_FUNCTION) reduce 215) ((T_FUNC_C) reduce 215) ((T_GLOBAL) reduce 215) ((T_GOTO) reduce 215) ((T_HALT_COMPILER) reduce 215) ((T_IF) reduce 215) ((T_INC) reduce 215) ((T_INCLUDE) reduce 215) ((T_INCLUDE_ONCE) reduce 215) ((T_INLINE_HTML) reduce 215) ((T_INTERFACE) reduce 215) ((T_INT_CAST) reduce 215) ((T_ISSET) reduce 215) ((T_LINE) reduce 215) ((T_LIST) reduce 215) ((T_LNUMBER) reduce 215) ((T_MATCH) reduce 215) ((T_METHOD_C) reduce 215) ((T_NAME_FULLY_QUALIFIED) reduce 215) ((T_NAME_QUALIFIED) reduce 215) ((T_NAME_RELATIVE) reduce 215) ((T_NEW) reduce 215) ((T_NS_C) reduce 215) ((T_OBJECT_CAST) reduce 215) ((T_PRINT) reduce 215) ((T_READONLY) reduce 215) ((T_REQUIRE) reduce 215) ((T_REQUIRE_ONCE) reduce 215) ((T_RETURN) reduce 215) ((T_START_HEREDOC) reduce 215) ((T_STATIC) reduce 215) ((T_STRING) reduce 215) ((T_STRING_CAST) reduce 215) ((T_SWITCH) reduce 215) ((T_THROW) reduce 215) ((T_TRAIT) reduce 215) ((T_TRAIT_C) reduce 215) ((T_TRY) reduce 215) ((T_UNSET) reduce 215) ((T_UNSET_CAST) reduce 215) ((T_VARIABLE) reduce 215) ((T_WHILE) reduce 215) ((T_YIELD) reduce 215) ((T_YIELD_FROM) reduce 215) (("[") reduce 215) (("`") reduce 215) (("{") reduce 215) (("}") reduce 215) (("~") reduce 215)) 24640 ((("!") reduce 216) (("\"") reduce 216) (("$") reduce 216) (("(") reduce 216) (("+") reduce 216) (("-") reduce 216) ((";") reduce 216) (("@") reduce 216) ((T_ABSTRACT) reduce 216) ((T_ARRAY) reduce 216) ((T_ARRAY_CAST) reduce 216) ((T_ATTRIBUTE) reduce 216) ((T_BOOL_CAST) reduce 216) ((T_BREAK) reduce 216) ((T_CLASS) reduce 216) ((T_CLASS_C) reduce 216) ((T_CLONE) reduce 216) ((T_CONSTANT_ENCAPSED_STRING) reduce 216) ((T_CONTINUE) reduce 216) ((T_DEC) reduce 216) ((T_DECLARE) reduce 216) ((T_DIR) reduce 216) ((T_DNUMBER) reduce 216) ((T_DO) reduce 216) ((T_DOUBLE_CAST) reduce 216) ((T_ECHO) reduce 216) ((T_ELSE) reduce 216) ((T_ELSEIF) reduce 216) ((T_EMPTY) reduce 216) ((T_ENUM) reduce 216) ((T_EVAL) reduce 216) ((T_EXIT) reduce 216) ((T_FILE) reduce 216) ((T_FINAL) reduce 216) ((T_FN) reduce 216) ((T_FOR) reduce 216) ((T_FOREACH) reduce 216) ((T_FUNCTION) reduce 216) ((T_FUNC_C) reduce 216) ((T_GLOBAL) reduce 216) ((T_GOTO) reduce 216) ((T_HALT_COMPILER) reduce 216) ((T_IF) reduce 216) ((T_INC) reduce 216) ((T_INCLUDE) reduce 216) ((T_INCLUDE_ONCE) reduce 216) ((T_INLINE_HTML) reduce 216) ((T_INTERFACE) reduce 216) ((T_INT_CAST) reduce 216) ((T_ISSET) reduce 216) ((T_LINE) reduce 216) ((T_LIST) reduce 216) ((T_LNUMBER) reduce 216) ((T_MATCH) reduce 216) ((T_METHOD_C) reduce 216) ((T_NAME_FULLY_QUALIFIED) reduce 216) ((T_NAME_QUALIFIED) reduce 216) ((T_NAME_RELATIVE) reduce 216) ((T_NEW) reduce 216) ((T_NS_C) reduce 216) ((T_OBJECT_CAST) reduce 216) ((T_PRINT) reduce 216) ((T_READONLY) reduce 216) ((T_REQUIRE) reduce 216) ((T_REQUIRE_ONCE) reduce 216) ((T_RETURN) reduce 216) ((T_START_HEREDOC) reduce 216) ((T_STATIC) reduce 216) ((T_STRING) reduce 216) ((T_STRING_CAST) reduce 216) ((T_SWITCH) reduce 216) ((T_THROW) reduce 216) ((T_TRAIT) reduce 216) ((T_TRAIT_C) reduce 216) ((T_TRY) reduce 216) ((T_UNSET) reduce 216) ((T_UNSET_CAST) reduce 216) ((T_VARIABLE) reduce 216) ((T_WHILE) reduce 216) ((T_YIELD) reduce 216) ((T_YIELD_FROM) reduce 216) (("[") reduce 216) (("`") reduce 216) (("{") reduce 216) (("}") reduce 216) (("~") reduce 216)) 24642 ((("!") reduce 157) (("\"") reduce 157) (("$") reduce 157) (("(") reduce 157) (("+") reduce 157) (("-") reduce 157) ((";") reduce 157) (("@") reduce 157) ((T_ABSTRACT) reduce 157) ((T_ARRAY) reduce 157) ((T_ARRAY_CAST) reduce 157) ((T_ATTRIBUTE) reduce 157) ((T_BOOL_CAST) reduce 157) ((T_BREAK) reduce 157) ((T_CLASS) reduce 157) ((T_CLASS_C) reduce 157) ((T_CLONE) reduce 157) ((T_CONSTANT_ENCAPSED_STRING) reduce 157) ((T_CONTINUE) reduce 157) ((T_DEC) reduce 157) ((T_DECLARE) reduce 157) ((T_DIR) reduce 157) ((T_DNUMBER) reduce 157) ((T_DO) reduce 157) ((T_DOUBLE_CAST) reduce 157) ((T_ECHO) reduce 157) ((T_ELSE) reduce 157) ((T_ELSEIF) reduce 157) ((T_EMPTY) reduce 157) ((T_ENUM) reduce 157) ((T_EVAL) reduce 157) ((T_EXIT) reduce 157) ((T_FILE) reduce 157) ((T_FINAL) reduce 157) ((T_FN) reduce 157) ((T_FOR) reduce 157) ((T_FOREACH) reduce 157) ((T_FUNCTION) reduce 157) ((T_FUNC_C) reduce 157) ((T_GLOBAL) reduce 157) ((T_GOTO) reduce 157) ((T_HALT_COMPILER) reduce 157) ((T_IF) reduce 157) ((T_INC) reduce 157) ((T_INCLUDE) reduce 157) ((T_INCLUDE_ONCE) reduce 157) ((T_INLINE_HTML) reduce 157) ((T_INTERFACE) reduce 157) ((T_INT_CAST) reduce 157) ((T_ISSET) reduce 157) ((T_LINE) reduce 157) ((T_LIST) reduce 157) ((T_LNUMBER) reduce 157) ((T_MATCH) reduce 157) ((T_METHOD_C) reduce 157) ((T_NAME_FULLY_QUALIFIED) reduce 157) ((T_NAME_QUALIFIED) reduce 157) ((T_NAME_RELATIVE) reduce 157) ((T_NEW) reduce 157) ((T_NS_C) reduce 157) ((T_OBJECT_CAST) reduce 157) ((T_PRINT) reduce 157) ((T_READONLY) reduce 157) ((T_REQUIRE) reduce 157) ((T_REQUIRE_ONCE) reduce 157) ((T_RETURN) reduce 157) ((T_START_HEREDOC) reduce 157) ((T_STATIC) reduce 157) ((T_STRING) reduce 157) ((T_STRING_CAST) reduce 157) ((T_SWITCH) reduce 157) ((T_THROW) reduce 157) ((T_TRAIT) reduce 157) ((T_TRAIT_C) reduce 157) ((T_TRY) reduce 157) ((T_UNSET) reduce 157) ((T_UNSET_CAST) reduce 157) ((T_VARIABLE) reduce 157) ((T_WHILE) reduce 157) ((T_YIELD) reduce 157) ((T_YIELD_FROM) reduce 157) (("[") reduce 157) (("`") reduce 157) (("{") reduce 157) (("}") reduce 157) (("~") reduce 157)) 24648 ((("!") reduce 149) (("\"") reduce 149) (("$") reduce 149) (("(") reduce 149) (("+") reduce 149) (("-") reduce 149) ((";") reduce 149) (("@") reduce 149) ((T_ABSTRACT) reduce 149) ((T_ARRAY) reduce 149) ((T_ARRAY_CAST) reduce 149) ((T_ATTRIBUTE) reduce 149) ((T_BOOL_CAST) reduce 149) ((T_BREAK) reduce 149) ((T_CLASS) reduce 149) ((T_CLASS_C) reduce 149) ((T_CLONE) reduce 149) ((T_CONSTANT_ENCAPSED_STRING) reduce 149) ((T_CONTINUE) reduce 149) ((T_DEC) reduce 149) ((T_DECLARE) reduce 149) ((T_DIR) reduce 149) ((T_DNUMBER) reduce 149) ((T_DO) reduce 149) ((T_DOUBLE_CAST) reduce 149) ((T_ECHO) reduce 149) ((T_ELSE) reduce 149) ((T_ELSEIF) reduce 149) ((T_EMPTY) reduce 149) ((T_ENUM) reduce 149) ((T_EVAL) reduce 149) ((T_EXIT) reduce 149) ((T_FILE) reduce 149) ((T_FINAL) reduce 149) ((T_FN) reduce 149) ((T_FOR) reduce 149) ((T_FOREACH) reduce 149) ((T_FUNCTION) reduce 149) ((T_FUNC_C) reduce 149) ((T_GLOBAL) reduce 149) ((T_GOTO) reduce 149) ((T_HALT_COMPILER) reduce 149) ((T_IF) reduce 149) ((T_INC) reduce 149) ((T_INCLUDE) reduce 149) ((T_INCLUDE_ONCE) reduce 149) ((T_INLINE_HTML) reduce 149) ((T_INTERFACE) reduce 149) ((T_INT_CAST) reduce 149) ((T_ISSET) reduce 149) ((T_LINE) reduce 149) ((T_LIST) reduce 149) ((T_LNUMBER) reduce 149) ((T_MATCH) reduce 149) ((T_METHOD_C) reduce 149) ((T_NAME_FULLY_QUALIFIED) reduce 149) ((T_NAME_QUALIFIED) reduce 149) ((T_NAME_RELATIVE) reduce 149) ((T_NEW) reduce 149) ((T_NS_C) reduce 149) ((T_OBJECT_CAST) reduce 149) ((T_PRINT) reduce 149) ((T_READONLY) reduce 149) ((T_REQUIRE) reduce 149) ((T_REQUIRE_ONCE) reduce 149) ((T_RETURN) reduce 149) ((T_START_HEREDOC) reduce 149) ((T_STATIC) reduce 149) ((T_STRING) reduce 149) ((T_STRING_CAST) reduce 149) ((T_SWITCH) reduce 149) ((T_THROW) reduce 149) ((T_TRAIT) reduce 149) ((T_TRAIT_C) reduce 149) ((T_TRY) reduce 149) ((T_UNSET) reduce 149) ((T_UNSET_CAST) reduce 149) ((T_VARIABLE) reduce 149) ((T_WHILE) reduce 149) ((T_YIELD) reduce 149) ((T_YIELD_FROM) reduce 149) (("[") reduce 149) (("`") reduce 149) (("{") reduce 149) (("}") reduce 149) (("~") reduce 149)) 24653 ((("!") reduce 163) (("\"") reduce 163) (("$") reduce 163) (("(") reduce 163) (("+") reduce 163) (("-") reduce 163) ((";") reduce 163) (("@") reduce 163) ((T_ABSTRACT) reduce 163) ((T_ARRAY) reduce 163) ((T_ARRAY_CAST) reduce 163) ((T_ATTRIBUTE) reduce 163) ((T_BOOL_CAST) reduce 163) ((T_BREAK) reduce 163) ((T_CLASS) reduce 163) ((T_CLASS_C) reduce 163) ((T_CLONE) reduce 163) ((T_CONSTANT_ENCAPSED_STRING) reduce 163) ((T_CONTINUE) reduce 163) ((T_DEC) reduce 163) ((T_DECLARE) reduce 163) ((T_DIR) reduce 163) ((T_DNUMBER) reduce 163) ((T_DO) reduce 163) ((T_DOUBLE_CAST) reduce 163) ((T_ECHO) reduce 163) ((T_ELSE) reduce 163) ((T_ELSEIF) reduce 163) ((T_EMPTY) reduce 163) ((T_ENUM) reduce 163) ((T_EVAL) reduce 163) ((T_EXIT) reduce 163) ((T_FILE) reduce 163) ((T_FINAL) reduce 163) ((T_FN) reduce 163) ((T_FOR) reduce 163) ((T_FOREACH) reduce 163) ((T_FUNCTION) reduce 163) ((T_FUNC_C) reduce 163) ((T_GLOBAL) reduce 163) ((T_GOTO) reduce 163) ((T_HALT_COMPILER) reduce 163) ((T_IF) reduce 163) ((T_INC) reduce 163) ((T_INCLUDE) reduce 163) ((T_INCLUDE_ONCE) reduce 163) ((T_INLINE_HTML) reduce 163) ((T_INTERFACE) reduce 163) ((T_INT_CAST) reduce 163) ((T_ISSET) reduce 163) ((T_LINE) reduce 163) ((T_LIST) reduce 163) ((T_LNUMBER) reduce 163) ((T_MATCH) reduce 163) ((T_METHOD_C) reduce 163) ((T_NAME_FULLY_QUALIFIED) reduce 163) ((T_NAME_QUALIFIED) reduce 163) ((T_NAME_RELATIVE) reduce 163) ((T_NEW) reduce 163) ((T_NS_C) reduce 163) ((T_OBJECT_CAST) reduce 163) ((T_PRINT) reduce 163) ((T_READONLY) reduce 163) ((T_REQUIRE) reduce 163) ((T_REQUIRE_ONCE) reduce 163) ((T_RETURN) reduce 163) ((T_START_HEREDOC) reduce 163) ((T_STATIC) reduce 163) ((T_STRING) reduce 163) ((T_STRING_CAST) reduce 163) ((T_SWITCH) reduce 163) ((T_THROW) reduce 163) ((T_TRAIT) reduce 163) ((T_TRAIT_C) reduce 163) ((T_TRY) reduce 163) ((T_UNSET) reduce 163) ((T_UNSET_CAST) reduce 163) ((T_VARIABLE) reduce 163) ((T_WHILE) reduce 163) ((T_YIELD) reduce 163) ((T_YIELD_FROM) reduce 163) (("[") reduce 163) (("`") reduce 163) (("{") reduce 163) (("}") reduce 163) (("~") reduce 163)) 24654 ((("!") reduce 219) (("\"") reduce 219) (("$") reduce 219) (("(") reduce 219) (("+") reduce 219) (("-") reduce 219) ((";") reduce 219) (("@") reduce 219) ((T_ABSTRACT) reduce 219) ((T_ARRAY) reduce 219) ((T_ARRAY_CAST) reduce 219) ((T_ATTRIBUTE) reduce 219) ((T_BOOL_CAST) reduce 219) ((T_BREAK) reduce 219) ((T_CLASS) reduce 219) ((T_CLASS_C) reduce 219) ((T_CLONE) reduce 219) ((T_CONSTANT_ENCAPSED_STRING) reduce 219) ((T_CONTINUE) reduce 219) ((T_DEC) reduce 219) ((T_DECLARE) reduce 219) ((T_DIR) reduce 219) ((T_DNUMBER) reduce 219) ((T_DO) reduce 219) ((T_DOUBLE_CAST) reduce 219) ((T_ECHO) reduce 219) ((T_ELSE) reduce 219) ((T_ELSEIF) reduce 219) ((T_EMPTY) reduce 219) ((T_ENUM) reduce 219) ((T_EVAL) reduce 219) ((T_EXIT) reduce 219) ((T_FILE) reduce 219) ((T_FINAL) reduce 219) ((T_FN) reduce 219) ((T_FOR) reduce 219) ((T_FOREACH) reduce 219) ((T_FUNCTION) reduce 219) ((T_FUNC_C) reduce 219) ((T_GLOBAL) reduce 219) ((T_GOTO) reduce 219) ((T_HALT_COMPILER) reduce 219) ((T_IF) reduce 219) ((T_INC) reduce 219) ((T_INCLUDE) reduce 219) ((T_INCLUDE_ONCE) reduce 219) ((T_INLINE_HTML) reduce 219) ((T_INTERFACE) reduce 219) ((T_INT_CAST) reduce 219) ((T_ISSET) reduce 219) ((T_LINE) reduce 219) ((T_LIST) reduce 219) ((T_LNUMBER) reduce 219) ((T_MATCH) reduce 219) ((T_METHOD_C) reduce 219) ((T_NAME_FULLY_QUALIFIED) reduce 219) ((T_NAME_QUALIFIED) reduce 219) ((T_NAME_RELATIVE) reduce 219) ((T_NEW) reduce 219) ((T_NS_C) reduce 219) ((T_OBJECT_CAST) reduce 219) ((T_PRINT) reduce 219) ((T_READONLY) reduce 219) ((T_REQUIRE) reduce 219) ((T_REQUIRE_ONCE) reduce 219) ((T_RETURN) reduce 219) ((T_START_HEREDOC) reduce 219) ((T_STATIC) reduce 219) ((T_STRING) reduce 219) ((T_STRING_CAST) reduce 219) ((T_SWITCH) reduce 219) ((T_THROW) reduce 219) ((T_TRAIT) reduce 219) ((T_TRAIT_C) reduce 219) ((T_TRY) reduce 219) ((T_UNSET) reduce 219) ((T_UNSET_CAST) reduce 219) ((T_VARIABLE) reduce 219) ((T_WHILE) reduce 219) ((T_YIELD) reduce 219) ((T_YIELD_FROM) reduce 219) (("[") reduce 219) (("`") reduce 219) (("{") reduce 219) (("}") reduce 219) (("~") reduce 219)) 24657 ((("!") reduce 220) (("\"") reduce 220) (("$") reduce 220) (("(") reduce 220) (("+") reduce 220) (("-") reduce 220) ((";") reduce 220) (("@") reduce 220) ((T_ABSTRACT) reduce 220) ((T_ARRAY) reduce 220) ((T_ARRAY_CAST) reduce 220) ((T_ATTRIBUTE) reduce 220) ((T_BOOL_CAST) reduce 220) ((T_BREAK) reduce 220) ((T_CLASS) reduce 220) ((T_CLASS_C) reduce 220) ((T_CLONE) reduce 220) ((T_CONSTANT_ENCAPSED_STRING) reduce 220) ((T_CONTINUE) reduce 220) ((T_DEC) reduce 220) ((T_DECLARE) reduce 220) ((T_DIR) reduce 220) ((T_DNUMBER) reduce 220) ((T_DO) reduce 220) ((T_DOUBLE_CAST) reduce 220) ((T_ECHO) reduce 220) ((T_ELSE) reduce 220) ((T_ELSEIF) reduce 220) ((T_EMPTY) reduce 220) ((T_ENUM) reduce 220) ((T_EVAL) reduce 220) ((T_EXIT) reduce 220) ((T_FILE) reduce 220) ((T_FINAL) reduce 220) ((T_FN) reduce 220) ((T_FOR) reduce 220) ((T_FOREACH) reduce 220) ((T_FUNCTION) reduce 220) ((T_FUNC_C) reduce 220) ((T_GLOBAL) reduce 220) ((T_GOTO) reduce 220) ((T_HALT_COMPILER) reduce 220) ((T_IF) reduce 220) ((T_INC) reduce 220) ((T_INCLUDE) reduce 220) ((T_INCLUDE_ONCE) reduce 220) ((T_INLINE_HTML) reduce 220) ((T_INTERFACE) reduce 220) ((T_INT_CAST) reduce 220) ((T_ISSET) reduce 220) ((T_LINE) reduce 220) ((T_LIST) reduce 220) ((T_LNUMBER) reduce 220) ((T_MATCH) reduce 220) ((T_METHOD_C) reduce 220) ((T_NAME_FULLY_QUALIFIED) reduce 220) ((T_NAME_QUALIFIED) reduce 220) ((T_NAME_RELATIVE) reduce 220) ((T_NEW) reduce 220) ((T_NS_C) reduce 220) ((T_OBJECT_CAST) reduce 220) ((T_PRINT) reduce 220) ((T_READONLY) reduce 220) ((T_REQUIRE) reduce 220) ((T_REQUIRE_ONCE) reduce 220) ((T_RETURN) reduce 220) ((T_START_HEREDOC) reduce 220) ((T_STATIC) reduce 220) ((T_STRING) reduce 220) ((T_STRING_CAST) reduce 220) ((T_SWITCH) reduce 220) ((T_THROW) reduce 220) ((T_TRAIT) reduce 220) ((T_TRAIT_C) reduce 220) ((T_TRY) reduce 220) ((T_UNSET) reduce 220) ((T_UNSET_CAST) reduce 220) ((T_VARIABLE) reduce 220) ((T_WHILE) reduce 220) ((T_YIELD) reduce 220) ((T_YIELD_FROM) reduce 220) (("[") reduce 220) (("`") reduce 220) (("{") reduce 220) (("}") reduce 220) (("~") reduce 220)) 24659 ((("!") reduce 153) (("\"") reduce 153) (("$") reduce 153) (("(") reduce 153) (("+") reduce 153) (("-") reduce 153) ((";") reduce 153) (("@") reduce 153) ((T_ABSTRACT) reduce 153) ((T_ARRAY) reduce 153) ((T_ARRAY_CAST) reduce 153) ((T_ATTRIBUTE) reduce 153) ((T_BOOL_CAST) reduce 153) ((T_BREAK) reduce 153) ((T_CLASS) reduce 153) ((T_CLASS_C) reduce 153) ((T_CLONE) reduce 153) ((T_CONSTANT_ENCAPSED_STRING) reduce 153) ((T_CONTINUE) reduce 153) ((T_DEC) reduce 153) ((T_DECLARE) reduce 153) ((T_DIR) reduce 153) ((T_DNUMBER) reduce 153) ((T_DO) reduce 153) ((T_DOUBLE_CAST) reduce 153) ((T_ECHO) reduce 153) ((T_ELSE) reduce 153) ((T_ELSEIF) reduce 153) ((T_EMPTY) reduce 153) ((T_ENUM) reduce 153) ((T_EVAL) reduce 153) ((T_EXIT) reduce 153) ((T_FILE) reduce 153) ((T_FINAL) reduce 153) ((T_FN) reduce 153) ((T_FOR) reduce 153) ((T_FOREACH) reduce 153) ((T_FUNCTION) reduce 153) ((T_FUNC_C) reduce 153) ((T_GLOBAL) reduce 153) ((T_GOTO) reduce 153) ((T_HALT_COMPILER) reduce 153) ((T_IF) reduce 153) ((T_INC) reduce 153) ((T_INCLUDE) reduce 153) ((T_INCLUDE_ONCE) reduce 153) ((T_INLINE_HTML) reduce 153) ((T_INTERFACE) reduce 153) ((T_INT_CAST) reduce 153) ((T_ISSET) reduce 153) ((T_LINE) reduce 153) ((T_LIST) reduce 153) ((T_LNUMBER) reduce 153) ((T_MATCH) reduce 153) ((T_METHOD_C) reduce 153) ((T_NAME_FULLY_QUALIFIED) reduce 153) ((T_NAME_QUALIFIED) reduce 153) ((T_NAME_RELATIVE) reduce 153) ((T_NEW) reduce 153) ((T_NS_C) reduce 153) ((T_OBJECT_CAST) reduce 153) ((T_PRINT) reduce 153) ((T_READONLY) reduce 153) ((T_REQUIRE) reduce 153) ((T_REQUIRE_ONCE) reduce 153) ((T_RETURN) reduce 153) ((T_START_HEREDOC) reduce 153) ((T_STATIC) reduce 153) ((T_STRING) reduce 153) ((T_STRING_CAST) reduce 153) ((T_SWITCH) reduce 153) ((T_THROW) reduce 153) ((T_TRAIT) reduce 153) ((T_TRAIT_C) reduce 153) ((T_TRY) reduce 153) ((T_UNSET) reduce 153) ((T_UNSET_CAST) reduce 153) ((T_VARIABLE) reduce 153) ((T_WHILE) reduce 153) ((T_YIELD) reduce 153) ((T_YIELD_FROM) reduce 153) (("[") reduce 153) (("`") reduce 153) (("{") reduce 153) (("}") reduce 153) (("~") reduce 153)) 24661 ((("!") reduce 152) (("\"") reduce 152) (("$") reduce 152) (("(") reduce 152) (("+") reduce 152) (("-") reduce 152) ((";") reduce 152) (("@") reduce 152) ((T_ABSTRACT) reduce 152) ((T_ARRAY) reduce 152) ((T_ARRAY_CAST) reduce 152) ((T_ATTRIBUTE) reduce 152) ((T_BOOL_CAST) reduce 152) ((T_BREAK) reduce 152) ((T_CLASS) reduce 152) ((T_CLASS_C) reduce 152) ((T_CLONE) reduce 152) ((T_CONSTANT_ENCAPSED_STRING) reduce 152) ((T_CONTINUE) reduce 152) ((T_DEC) reduce 152) ((T_DECLARE) reduce 152) ((T_DIR) reduce 152) ((T_DNUMBER) reduce 152) ((T_DO) reduce 152) ((T_DOUBLE_CAST) reduce 152) ((T_ECHO) reduce 152) ((T_ELSE) reduce 152) ((T_ELSEIF) reduce 152) ((T_EMPTY) reduce 152) ((T_ENUM) reduce 152) ((T_EVAL) reduce 152) ((T_EXIT) reduce 152) ((T_FILE) reduce 152) ((T_FINAL) reduce 152) ((T_FN) reduce 152) ((T_FOR) reduce 152) ((T_FOREACH) reduce 152) ((T_FUNCTION) reduce 152) ((T_FUNC_C) reduce 152) ((T_GLOBAL) reduce 152) ((T_GOTO) reduce 152) ((T_HALT_COMPILER) reduce 152) ((T_IF) reduce 152) ((T_INC) reduce 152) ((T_INCLUDE) reduce 152) ((T_INCLUDE_ONCE) reduce 152) ((T_INLINE_HTML) reduce 152) ((T_INTERFACE) reduce 152) ((T_INT_CAST) reduce 152) ((T_ISSET) reduce 152) ((T_LINE) reduce 152) ((T_LIST) reduce 152) ((T_LNUMBER) reduce 152) ((T_MATCH) reduce 152) ((T_METHOD_C) reduce 152) ((T_NAME_FULLY_QUALIFIED) reduce 152) ((T_NAME_QUALIFIED) reduce 152) ((T_NAME_RELATIVE) reduce 152) ((T_NEW) reduce 152) ((T_NS_C) reduce 152) ((T_OBJECT_CAST) reduce 152) ((T_PRINT) reduce 152) ((T_READONLY) reduce 152) ((T_REQUIRE) reduce 152) ((T_REQUIRE_ONCE) reduce 152) ((T_RETURN) reduce 152) ((T_START_HEREDOC) reduce 152) ((T_STATIC) reduce 152) ((T_STRING) reduce 152) ((T_STRING_CAST) reduce 152) ((T_SWITCH) reduce 152) ((T_THROW) reduce 152) ((T_TRAIT) reduce 152) ((T_TRAIT_C) reduce 152) ((T_TRY) reduce 152) ((T_UNSET) reduce 152) ((T_UNSET_CAST) reduce 152) ((T_VARIABLE) reduce 152) ((T_WHILE) reduce 152) ((T_YIELD) reduce 152) ((T_YIELD_FROM) reduce 152) (("[") reduce 152) (("`") reduce 152) (("{") reduce 152) (("}") reduce 152) (("~") reduce 152)) 25290 ((("!") reduce 244) (("\"") reduce 244) (("$") reduce 244) (("(") reduce 244) (("+") reduce 244) (("-") reduce 244) ((";") reduce 244) (("@") reduce 244) ((T_ABSTRACT) reduce 244) ((T_ARRAY) reduce 244) ((T_ARRAY_CAST) reduce 244) ((T_ATTRIBUTE) reduce 244) ((T_BOOL_CAST) reduce 244) ((T_BREAK) reduce 244) ((T_CLASS) reduce 244) ((T_CLASS_C) reduce 244) ((T_CLONE) reduce 244) ((T_CONSTANT_ENCAPSED_STRING) reduce 244) ((T_CONTINUE) reduce 244) ((T_DEC) reduce 244) ((T_DECLARE) reduce 244) ((T_DIR) reduce 244) ((T_DNUMBER) reduce 244) ((T_DO) reduce 244) ((T_DOUBLE_CAST) reduce 244) ((T_ECHO) reduce 244) ((T_EMPTY) reduce 244) ((T_ENUM) reduce 244) ((T_EVAL) reduce 244) ((T_EXIT) reduce 244) ((T_FILE) reduce 244) ((T_FINAL) reduce 244) ((T_FN) reduce 244) ((T_FOR) reduce 244) ((T_FOREACH) reduce 244) ((T_FUNCTION) reduce 244) ((T_FUNC_C) reduce 244) ((T_GLOBAL) reduce 244) ((T_GOTO) reduce 244) ((T_HALT_COMPILER) reduce 244) ((T_IF) reduce 244) ((T_INC) reduce 244) ((T_INCLUDE) reduce 244) ((T_INCLUDE_ONCE) reduce 244) ((T_INLINE_HTML) reduce 244) ((T_INTERFACE) reduce 244) ((T_INT_CAST) reduce 244) ((T_ISSET) reduce 244) ((T_LINE) reduce 244) ((T_LIST) reduce 244) ((T_LNUMBER) reduce 244) ((T_MATCH) reduce 244) ((T_METHOD_C) reduce 244) ((T_NAME_FULLY_QUALIFIED) reduce 244) ((T_NAME_QUALIFIED) reduce 244) ((T_NAME_RELATIVE) reduce 244) ((T_NEW) reduce 244) ((T_NS_C) reduce 244) ((T_OBJECT_CAST) reduce 244) ((T_PRINT) reduce 244) ((T_READONLY) reduce 244) ((T_REQUIRE) reduce 244) ((T_REQUIRE_ONCE) reduce 244) ((T_RETURN) reduce 244) ((T_START_HEREDOC) reduce 244) ((T_STATIC) reduce 244) ((T_STRING) reduce 244) ((T_STRING_CAST) reduce 244) ((T_SWITCH) reduce 244) ((T_THROW) reduce 244) ((T_TRAIT) reduce 244) ((T_TRAIT_C) reduce 244) ((T_TRY) reduce 244) ((T_UNSET) reduce 244) ((T_UNSET_CAST) reduce 244) ((T_VARIABLE) reduce 244) ((T_WHILE) reduce 244) ((T_YIELD) reduce 244) ((T_YIELD_FROM) reduce 244) (("[") reduce 244) (("`") reduce 244) (("{") reduce 244) (("}") reduce 244) (("~") reduce 244)) 25301 ((("!") reduce 455) (("\"") reduce 455) (("$") reduce 455) (("(") reduce 455) (("+") reduce 455) (("-") reduce 455) ((";") reduce 455) (("@") reduce 455) ((T_ABSTRACT) reduce 455) ((T_ARRAY) reduce 455) ((T_ARRAY_CAST) reduce 455) ((T_ATTRIBUTE) reduce 455) ((T_BOOL_CAST) reduce 455) ((T_BREAK) reduce 455) ((T_CLASS) reduce 455) ((T_CLASS_C) reduce 455) ((T_CLONE) reduce 455) ((T_CONSTANT_ENCAPSED_STRING) reduce 455) ((T_CONTINUE) reduce 455) ((T_DEC) reduce 455) ((T_DECLARE) reduce 455) ((T_DIR) reduce 455) ((T_DNUMBER) reduce 455) ((T_DO) reduce 455) ((T_DOUBLE_CAST) reduce 455) ((T_ECHO) reduce 455) ((T_EMPTY) reduce 455) ((T_ENUM) reduce 455) ((T_EVAL) reduce 455) ((T_EXIT) reduce 455) ((T_FILE) reduce 455) ((T_FINAL) reduce 455) ((T_FN) reduce 455) ((T_FOR) reduce 455) ((T_FOREACH) reduce 455) ((T_FUNCTION) reduce 455) ((T_FUNC_C) reduce 455) ((T_GLOBAL) reduce 455) ((T_GOTO) reduce 455) ((T_HALT_COMPILER) reduce 455) ((T_IF) reduce 455) ((T_INC) reduce 455) ((T_INCLUDE) reduce 455) ((T_INCLUDE_ONCE) reduce 455) ((T_INLINE_HTML) reduce 455) ((T_INTERFACE) reduce 455) ((T_INT_CAST) reduce 455) ((T_ISSET) reduce 455) ((T_LINE) reduce 455) ((T_LIST) reduce 455) ((T_LNUMBER) reduce 455) ((T_MATCH) reduce 455) ((T_METHOD_C) reduce 455) ((T_NAME_FULLY_QUALIFIED) reduce 455) ((T_NAME_QUALIFIED) reduce 455) ((T_NAME_RELATIVE) reduce 455) ((T_NEW) reduce 455) ((T_NS_C) reduce 455) ((T_OBJECT_CAST) reduce 455) ((T_PRINT) reduce 455) ((T_READONLY) reduce 455) ((T_REQUIRE) reduce 455) ((T_REQUIRE_ONCE) reduce 455) ((T_RETURN) reduce 455) ((T_START_HEREDOC) reduce 455) ((T_STATIC) reduce 455) ((T_STRING) reduce 455) ((T_STRING_CAST) reduce 455) ((T_SWITCH) reduce 455) ((T_THROW) reduce 455) ((T_TRAIT) reduce 455) ((T_TRAIT_C) reduce 455) ((T_TRY) reduce 455) ((T_UNSET) reduce 455) ((T_UNSET_CAST) reduce 455) ((T_VARIABLE) reduce 455) ((T_WHILE) reduce 455) ((T_YIELD) reduce 455) ((T_YIELD_FROM) reduce 455) (("[") reduce 455) (("`") reduce 455) (("{") reduce 455) (("}") reduce 455) (("~") reduce 455)) 25302 ((("!") reduce 181) (("\"") reduce 181) (("$") reduce 181) (("(") reduce 181) (("+") reduce 181) (("-") reduce 181) ((";") reduce 181) (("@") reduce 181) ((T_ABSTRACT) reduce 181) ((T_ARRAY) reduce 181) ((T_ARRAY_CAST) reduce 181) ((T_ATTRIBUTE) reduce 181) ((T_BOOL_CAST) reduce 181) ((T_BREAK) reduce 181) ((T_CLASS) reduce 181) ((T_CLASS_C) reduce 181) ((T_CLONE) reduce 181) ((T_CONSTANT_ENCAPSED_STRING) reduce 181) ((T_CONTINUE) reduce 181) ((T_DEC) reduce 181) ((T_DECLARE) reduce 181) ((T_DIR) reduce 181) ((T_DNUMBER) reduce 181) ((T_DO) reduce 181) ((T_DOUBLE_CAST) reduce 181) ((T_ECHO) reduce 181) ((T_EMPTY) reduce 181) ((T_ENUM) reduce 181) ((T_EVAL) reduce 181) ((T_EXIT) reduce 181) ((T_FILE) reduce 181) ((T_FINAL) reduce 181) ((T_FN) reduce 181) ((T_FOR) reduce 181) ((T_FOREACH) reduce 181) ((T_FUNCTION) reduce 181) ((T_FUNC_C) reduce 181) ((T_GLOBAL) reduce 181) ((T_GOTO) reduce 181) ((T_HALT_COMPILER) reduce 181) ((T_IF) reduce 181) ((T_INC) reduce 181) ((T_INCLUDE) reduce 181) ((T_INCLUDE_ONCE) reduce 181) ((T_INLINE_HTML) reduce 181) ((T_INTERFACE) reduce 181) ((T_INT_CAST) reduce 181) ((T_ISSET) reduce 181) ((T_LINE) reduce 181) ((T_LIST) reduce 181) ((T_LNUMBER) reduce 181) ((T_MATCH) reduce 181) ((T_METHOD_C) reduce 181) ((T_NAME_FULLY_QUALIFIED) reduce 181) ((T_NAME_QUALIFIED) reduce 181) ((T_NAME_RELATIVE) reduce 181) ((T_NEW) reduce 181) ((T_NS_C) reduce 181) ((T_OBJECT_CAST) reduce 181) ((T_PRINT) reduce 181) ((T_READONLY) reduce 181) ((T_REQUIRE) reduce 181) ((T_REQUIRE_ONCE) reduce 181) ((T_RETURN) reduce 181) ((T_START_HEREDOC) reduce 181) ((T_STATIC) reduce 181) ((T_STRING) reduce 181) ((T_STRING_CAST) reduce 181) ((T_SWITCH) reduce 181) ((T_THROW) reduce 181) ((T_TRAIT) reduce 181) ((T_TRAIT_C) reduce 181) ((T_TRY) reduce 181) ((T_UNSET) reduce 181) ((T_UNSET_CAST) reduce 181) ((T_VARIABLE) reduce 181) ((T_WHILE) reduce 181) ((T_YIELD) reduce 181) ((T_YIELD_FROM) reduce 181) (("[") reduce 181) (("`") reduce 181) (("{") reduce 181) (("}") reduce 181) (("~") reduce 181)) 25303 ((("!") reduce 159) (("\"") reduce 159) (("$") reduce 159) (("(") reduce 159) (("+") reduce 159) (("-") reduce 159) ((";") reduce 159) (("@") reduce 159) ((T_ABSTRACT) reduce 159) ((T_ARRAY) reduce 159) ((T_ARRAY_CAST) reduce 159) ((T_ATTRIBUTE) reduce 159) ((T_BOOL_CAST) reduce 159) ((T_BREAK) reduce 159) ((T_CLASS) reduce 159) ((T_CLASS_C) reduce 159) ((T_CLONE) reduce 159) ((T_CONSTANT_ENCAPSED_STRING) reduce 159) ((T_CONTINUE) reduce 159) ((T_DEC) reduce 159) ((T_DECLARE) reduce 159) ((T_DIR) reduce 159) ((T_DNUMBER) reduce 159) ((T_DO) reduce 159) ((T_DOUBLE_CAST) reduce 159) ((T_ECHO) reduce 159) ((T_EMPTY) reduce 159) ((T_ENUM) reduce 159) ((T_EVAL) reduce 159) ((T_EXIT) reduce 159) ((T_FILE) reduce 159) ((T_FINAL) reduce 159) ((T_FN) reduce 159) ((T_FOR) reduce 159) ((T_FOREACH) reduce 159) ((T_FUNCTION) reduce 159) ((T_FUNC_C) reduce 159) ((T_GLOBAL) reduce 159) ((T_GOTO) reduce 159) ((T_HALT_COMPILER) reduce 159) ((T_IF) reduce 159) ((T_INC) reduce 159) ((T_INCLUDE) reduce 159) ((T_INCLUDE_ONCE) reduce 159) ((T_INLINE_HTML) reduce 159) ((T_INTERFACE) reduce 159) ((T_INT_CAST) reduce 159) ((T_ISSET) reduce 159) ((T_LINE) reduce 159) ((T_LIST) reduce 159) ((T_LNUMBER) reduce 159) ((T_MATCH) reduce 159) ((T_METHOD_C) reduce 159) ((T_NAME_FULLY_QUALIFIED) reduce 159) ((T_NAME_QUALIFIED) reduce 159) ((T_NAME_RELATIVE) reduce 159) ((T_NEW) reduce 159) ((T_NS_C) reduce 159) ((T_OBJECT_CAST) reduce 159) ((T_PRINT) reduce 159) ((T_READONLY) reduce 159) ((T_REQUIRE) reduce 159) ((T_REQUIRE_ONCE) reduce 159) ((T_RETURN) reduce 159) ((T_START_HEREDOC) reduce 159) ((T_STATIC) reduce 159) ((T_STRING) reduce 159) ((T_STRING_CAST) reduce 159) ((T_SWITCH) reduce 159) ((T_THROW) reduce 159) ((T_TRAIT) reduce 159) ((T_TRAIT_C) reduce 159) ((T_TRY) reduce 159) ((T_UNSET) reduce 159) ((T_UNSET_CAST) reduce 159) ((T_VARIABLE) reduce 159) ((T_WHILE) reduce 159) ((T_YIELD) reduce 159) ((T_YIELD_FROM) reduce 159) (("[") reduce 159) (("`") reduce 159) (("{") reduce 159) (("}") reduce 159) (("~") reduce 159)) 25311 ((("!") reduce 186) (("\"") reduce 186) (("$") reduce 186) (("(") reduce 186) (("+") reduce 186) (("-") reduce 186) ((";") reduce 186) (("@") reduce 186) ((T_ABSTRACT) reduce 186) ((T_ARRAY) reduce 186) ((T_ARRAY_CAST) reduce 186) ((T_ATTRIBUTE) reduce 186) ((T_BOOL_CAST) reduce 186) ((T_BREAK) reduce 186) ((T_CLASS) reduce 186) ((T_CLASS_C) reduce 186) ((T_CLONE) reduce 186) ((T_CONSTANT_ENCAPSED_STRING) reduce 186) ((T_CONTINUE) reduce 186) ((T_DEC) reduce 186) ((T_DECLARE) reduce 186) ((T_DIR) reduce 186) ((T_DNUMBER) reduce 186) ((T_DO) reduce 186) ((T_DOUBLE_CAST) reduce 186) ((T_ECHO) reduce 186) ((T_EMPTY) reduce 186) ((T_ENUM) reduce 186) ((T_EVAL) reduce 186) ((T_EXIT) reduce 186) ((T_FILE) reduce 186) ((T_FINAL) reduce 186) ((T_FN) reduce 186) ((T_FOR) reduce 186) ((T_FOREACH) reduce 186) ((T_FUNCTION) reduce 186) ((T_FUNC_C) reduce 186) ((T_GLOBAL) reduce 186) ((T_GOTO) reduce 186) ((T_HALT_COMPILER) reduce 186) ((T_IF) reduce 186) ((T_INC) reduce 186) ((T_INCLUDE) reduce 186) ((T_INCLUDE_ONCE) reduce 186) ((T_INLINE_HTML) reduce 186) ((T_INTERFACE) reduce 186) ((T_INT_CAST) reduce 186) ((T_ISSET) reduce 186) ((T_LINE) reduce 186) ((T_LIST) reduce 186) ((T_LNUMBER) reduce 186) ((T_MATCH) reduce 186) ((T_METHOD_C) reduce 186) ((T_NAME_FULLY_QUALIFIED) reduce 186) ((T_NAME_QUALIFIED) reduce 186) ((T_NAME_RELATIVE) reduce 186) ((T_NEW) reduce 186) ((T_NS_C) reduce 186) ((T_OBJECT_CAST) reduce 186) ((T_PRINT) reduce 186) ((T_READONLY) reduce 186) ((T_REQUIRE) reduce 186) ((T_REQUIRE_ONCE) reduce 186) ((T_RETURN) reduce 186) ((T_START_HEREDOC) reduce 186) ((T_STATIC) reduce 186) ((T_STRING) reduce 186) ((T_STRING_CAST) reduce 186) ((T_SWITCH) reduce 186) ((T_THROW) reduce 186) ((T_TRAIT) reduce 186) ((T_TRAIT_C) reduce 186) ((T_TRY) reduce 186) ((T_UNSET) reduce 186) ((T_UNSET_CAST) reduce 186) ((T_VARIABLE) reduce 186) ((T_WHILE) reduce 186) ((T_YIELD) reduce 186) ((T_YIELD_FROM) reduce 186) (("[") reduce 186) (("`") reduce 186) (("{") reduce 186) (("}") reduce 186) (("~") reduce 186)) 25312 ((("!") reduce 143) (("\"") reduce 143) (("$") reduce 143) (("(") reduce 143) (("+") reduce 143) (("-") reduce 143) ((";") reduce 143) (("@") reduce 143) ((T_ABSTRACT) reduce 143) ((T_ARRAY) reduce 143) ((T_ARRAY_CAST) reduce 143) ((T_ATTRIBUTE) reduce 143) ((T_BOOL_CAST) reduce 143) ((T_BREAK) reduce 143) ((T_CLASS) reduce 143) ((T_CLASS_C) reduce 143) ((T_CLONE) reduce 143) ((T_CONSTANT_ENCAPSED_STRING) reduce 143) ((T_CONTINUE) reduce 143) ((T_DEC) reduce 143) ((T_DECLARE) reduce 143) ((T_DIR) reduce 143) ((T_DNUMBER) reduce 143) ((T_DO) reduce 143) ((T_DOUBLE_CAST) reduce 143) ((T_ECHO) reduce 143) ((T_EMPTY) reduce 143) ((T_ENUM) reduce 143) ((T_EVAL) reduce 143) ((T_EXIT) reduce 143) ((T_FILE) reduce 143) ((T_FINAL) reduce 143) ((T_FN) reduce 143) ((T_FOR) reduce 143) ((T_FOREACH) reduce 143) ((T_FUNCTION) reduce 143) ((T_FUNC_C) reduce 143) ((T_GLOBAL) reduce 143) ((T_GOTO) reduce 143) ((T_HALT_COMPILER) reduce 143) ((T_IF) reduce 143) ((T_INC) reduce 143) ((T_INCLUDE) reduce 143) ((T_INCLUDE_ONCE) reduce 143) ((T_INLINE_HTML) reduce 143) ((T_INTERFACE) reduce 143) ((T_INT_CAST) reduce 143) ((T_ISSET) reduce 143) ((T_LINE) reduce 143) ((T_LIST) reduce 143) ((T_LNUMBER) reduce 143) ((T_MATCH) reduce 143) ((T_METHOD_C) reduce 143) ((T_NAME_FULLY_QUALIFIED) reduce 143) ((T_NAME_QUALIFIED) reduce 143) ((T_NAME_RELATIVE) reduce 143) ((T_NEW) reduce 143) ((T_NS_C) reduce 143) ((T_OBJECT_CAST) reduce 143) ((T_PRINT) reduce 143) ((T_READONLY) reduce 143) ((T_REQUIRE) reduce 143) ((T_REQUIRE_ONCE) reduce 143) ((T_RETURN) reduce 143) ((T_START_HEREDOC) reduce 143) ((T_STATIC) reduce 143) ((T_STRING) reduce 143) ((T_STRING_CAST) reduce 143) ((T_SWITCH) reduce 143) ((T_THROW) reduce 143) ((T_TRAIT) reduce 143) ((T_TRAIT_C) reduce 143) ((T_TRY) reduce 143) ((T_UNSET) reduce 143) ((T_UNSET_CAST) reduce 143) ((T_VARIABLE) reduce 143) ((T_WHILE) reduce 143) ((T_YIELD) reduce 143) ((T_YIELD_FROM) reduce 143) (("[") reduce 143) (("`") reduce 143) (("{") reduce 143) (("}") reduce 143) (("~") reduce 143)) 25315 ((("!") reduce 247) (("\"") reduce 247) (("$") reduce 247) (("(") reduce 247) (("+") reduce 247) (("-") reduce 247) ((";") reduce 247) (("@") reduce 247) ((T_ABSTRACT) reduce 247) ((T_ARRAY) reduce 247) ((T_ARRAY_CAST) reduce 247) ((T_ATTRIBUTE) reduce 247) ((T_BOOL_CAST) reduce 247) ((T_BREAK) reduce 247) ((T_CLASS) reduce 247) ((T_CLASS_C) reduce 247) ((T_CLONE) reduce 247) ((T_CONSTANT_ENCAPSED_STRING) reduce 247) ((T_CONTINUE) reduce 247) ((T_DEC) reduce 247) ((T_DECLARE) reduce 247) ((T_DIR) reduce 247) ((T_DNUMBER) reduce 247) ((T_DO) reduce 247) ((T_DOUBLE_CAST) reduce 247) ((T_ECHO) reduce 247) ((T_EMPTY) reduce 247) ((T_ENUM) reduce 247) ((T_EVAL) reduce 247) ((T_EXIT) reduce 247) ((T_FILE) reduce 247) ((T_FINAL) reduce 247) ((T_FN) reduce 247) ((T_FOR) reduce 247) ((T_FOREACH) reduce 247) ((T_FUNCTION) reduce 247) ((T_FUNC_C) reduce 247) ((T_GLOBAL) reduce 247) ((T_GOTO) reduce 247) ((T_HALT_COMPILER) reduce 247) ((T_IF) reduce 247) ((T_INC) reduce 247) ((T_INCLUDE) reduce 247) ((T_INCLUDE_ONCE) reduce 247) ((T_INLINE_HTML) reduce 247) ((T_INTERFACE) reduce 247) ((T_INT_CAST) reduce 247) ((T_ISSET) reduce 247) ((T_LINE) reduce 247) ((T_LIST) reduce 247) ((T_LNUMBER) reduce 247) ((T_MATCH) reduce 247) ((T_METHOD_C) reduce 247) ((T_NAME_FULLY_QUALIFIED) reduce 247) ((T_NAME_QUALIFIED) reduce 247) ((T_NAME_RELATIVE) reduce 247) ((T_NEW) reduce 247) ((T_NS_C) reduce 247) ((T_OBJECT_CAST) reduce 247) ((T_PRINT) reduce 247) ((T_READONLY) reduce 247) ((T_REQUIRE) reduce 247) ((T_REQUIRE_ONCE) reduce 247) ((T_RETURN) reduce 247) ((T_START_HEREDOC) reduce 247) ((T_STATIC) reduce 247) ((T_STRING) reduce 247) ((T_STRING_CAST) reduce 247) ((T_SWITCH) reduce 247) ((T_THROW) reduce 247) ((T_TRAIT) reduce 247) ((T_TRAIT_C) reduce 247) ((T_TRY) reduce 247) ((T_UNSET) reduce 247) ((T_UNSET_CAST) reduce 247) ((T_VARIABLE) reduce 247) ((T_WHILE) reduce 247) ((T_YIELD) reduce 247) ((T_YIELD_FROM) reduce 247) (("[") reduce 247) (("`") reduce 247) (("{") reduce 247) (("}") reduce 247) (("~") reduce 247)) 25319 ((("!") reduce 248) (("\"") reduce 248) (("$") reduce 248) (("(") reduce 248) (("+") reduce 248) (("-") reduce 248) ((";") reduce 248) (("@") reduce 248) ((T_ABSTRACT) reduce 248) ((T_ARRAY) reduce 248) ((T_ARRAY_CAST) reduce 248) ((T_ATTRIBUTE) reduce 248) ((T_BOOL_CAST) reduce 248) ((T_BREAK) reduce 248) ((T_CLASS) reduce 248) ((T_CLASS_C) reduce 248) ((T_CLONE) reduce 248) ((T_CONSTANT_ENCAPSED_STRING) reduce 248) ((T_CONTINUE) reduce 248) ((T_DEC) reduce 248) ((T_DECLARE) reduce 248) ((T_DIR) reduce 248) ((T_DNUMBER) reduce 248) ((T_DO) reduce 248) ((T_DOUBLE_CAST) reduce 248) ((T_ECHO) reduce 248) ((T_EMPTY) reduce 248) ((T_ENUM) reduce 248) ((T_EVAL) reduce 248) ((T_EXIT) reduce 248) ((T_FILE) reduce 248) ((T_FINAL) reduce 248) ((T_FN) reduce 248) ((T_FOR) reduce 248) ((T_FOREACH) reduce 248) ((T_FUNCTION) reduce 248) ((T_FUNC_C) reduce 248) ((T_GLOBAL) reduce 248) ((T_GOTO) reduce 248) ((T_HALT_COMPILER) reduce 248) ((T_IF) reduce 248) ((T_INC) reduce 248) ((T_INCLUDE) reduce 248) ((T_INCLUDE_ONCE) reduce 248) ((T_INLINE_HTML) reduce 248) ((T_INTERFACE) reduce 248) ((T_INT_CAST) reduce 248) ((T_ISSET) reduce 248) ((T_LINE) reduce 248) ((T_LIST) reduce 248) ((T_LNUMBER) reduce 248) ((T_MATCH) reduce 248) ((T_METHOD_C) reduce 248) ((T_NAME_FULLY_QUALIFIED) reduce 248) ((T_NAME_QUALIFIED) reduce 248) ((T_NAME_RELATIVE) reduce 248) ((T_NEW) reduce 248) ((T_NS_C) reduce 248) ((T_OBJECT_CAST) reduce 248) ((T_PRINT) reduce 248) ((T_READONLY) reduce 248) ((T_REQUIRE) reduce 248) ((T_REQUIRE_ONCE) reduce 248) ((T_RETURN) reduce 248) ((T_START_HEREDOC) reduce 248) ((T_STATIC) reduce 248) ((T_STRING) reduce 248) ((T_STRING_CAST) reduce 248) ((T_SWITCH) reduce 248) ((T_THROW) reduce 248) ((T_TRAIT) reduce 248) ((T_TRAIT_C) reduce 248) ((T_TRY) reduce 248) ((T_UNSET) reduce 248) ((T_UNSET_CAST) reduce 248) ((T_VARIABLE) reduce 248) ((T_WHILE) reduce 248) ((T_YIELD) reduce 248) ((T_YIELD_FROM) reduce 248) (("[") reduce 248) (("`") reduce 248) (("{") reduce 248) (("}") reduce 248) (("~") reduce 248)) 25324 ((("!") reduce 239) (("\"") reduce 239) (("$") reduce 239) (("(") reduce 239) (("+") reduce 239) (("-") reduce 239) ((";") reduce 239) (("@") reduce 239) ((T_ABSTRACT) reduce 239) ((T_ARRAY) reduce 239) ((T_ARRAY_CAST) reduce 239) ((T_ATTRIBUTE) reduce 239) ((T_BOOL_CAST) reduce 239) ((T_BREAK) reduce 239) ((T_CLASS) reduce 239) ((T_CLASS_C) reduce 239) ((T_CLONE) reduce 239) ((T_CONSTANT_ENCAPSED_STRING) reduce 239) ((T_CONTINUE) reduce 239) ((T_DEC) reduce 239) ((T_DECLARE) reduce 239) ((T_DIR) reduce 239) ((T_DNUMBER) reduce 239) ((T_DO) reduce 239) ((T_DOUBLE_CAST) reduce 239) ((T_ECHO) reduce 239) ((T_EMPTY) reduce 239) ((T_ENUM) reduce 239) ((T_EVAL) reduce 239) ((T_EXIT) reduce 239) ((T_FILE) reduce 239) ((T_FINAL) reduce 239) ((T_FN) reduce 239) ((T_FOR) reduce 239) ((T_FOREACH) reduce 239) ((T_FUNCTION) reduce 239) ((T_FUNC_C) reduce 239) ((T_GLOBAL) reduce 239) ((T_GOTO) reduce 239) ((T_HALT_COMPILER) reduce 239) ((T_IF) reduce 239) ((T_INC) reduce 239) ((T_INCLUDE) reduce 239) ((T_INCLUDE_ONCE) reduce 239) ((T_INLINE_HTML) reduce 239) ((T_INTERFACE) reduce 239) ((T_INT_CAST) reduce 239) ((T_ISSET) reduce 239) ((T_LINE) reduce 239) ((T_LIST) reduce 239) ((T_LNUMBER) reduce 239) ((T_MATCH) reduce 239) ((T_METHOD_C) reduce 239) ((T_NAME_FULLY_QUALIFIED) reduce 239) ((T_NAME_QUALIFIED) reduce 239) ((T_NAME_RELATIVE) reduce 239) ((T_NEW) reduce 239) ((T_NS_C) reduce 239) ((T_OBJECT_CAST) reduce 239) ((T_PRINT) reduce 239) ((T_READONLY) reduce 239) ((T_REQUIRE) reduce 239) ((T_REQUIRE_ONCE) reduce 239) ((T_RETURN) reduce 239) ((T_START_HEREDOC) reduce 239) ((T_STATIC) reduce 239) ((T_STRING) reduce 239) ((T_STRING_CAST) reduce 239) ((T_SWITCH) reduce 239) ((T_THROW) reduce 239) ((T_TRAIT) reduce 239) ((T_TRAIT_C) reduce 239) ((T_TRY) reduce 239) ((T_UNSET) reduce 239) ((T_UNSET_CAST) reduce 239) ((T_VARIABLE) reduce 239) ((T_WHILE) reduce 239) ((T_YIELD) reduce 239) ((T_YIELD_FROM) reduce 239) (("[") reduce 239) (("`") reduce 239) (("{") reduce 239) (("}") reduce 239) (("~") reduce 239)) 25325 ((("!") reduce 148) (("\"") reduce 148) (("$") reduce 148) (("(") reduce 148) (("+") reduce 148) (("-") reduce 148) ((";") reduce 148) (("@") reduce 148) ((T_ABSTRACT) reduce 148) ((T_ARRAY) reduce 148) ((T_ARRAY_CAST) reduce 148) ((T_ATTRIBUTE) reduce 148) ((T_BOOL_CAST) reduce 148) ((T_BREAK) reduce 148) ((T_CLASS) reduce 148) ((T_CLASS_C) reduce 148) ((T_CLONE) reduce 148) ((T_CONSTANT_ENCAPSED_STRING) reduce 148) ((T_CONTINUE) reduce 148) ((T_DEC) reduce 148) ((T_DECLARE) reduce 148) ((T_DIR) reduce 148) ((T_DNUMBER) reduce 148) ((T_DO) reduce 148) ((T_DOUBLE_CAST) reduce 148) ((T_ECHO) reduce 148) ((T_EMPTY) reduce 148) ((T_ENUM) reduce 148) ((T_EVAL) reduce 148) ((T_EXIT) reduce 148) ((T_FILE) reduce 148) ((T_FINAL) reduce 148) ((T_FN) reduce 148) ((T_FOR) reduce 148) ((T_FOREACH) reduce 148) ((T_FUNCTION) reduce 148) ((T_FUNC_C) reduce 148) ((T_GLOBAL) reduce 148) ((T_GOTO) reduce 148) ((T_HALT_COMPILER) reduce 148) ((T_IF) reduce 148) ((T_INC) reduce 148) ((T_INCLUDE) reduce 148) ((T_INCLUDE_ONCE) reduce 148) ((T_INLINE_HTML) reduce 148) ((T_INTERFACE) reduce 148) ((T_INT_CAST) reduce 148) ((T_ISSET) reduce 148) ((T_LINE) reduce 148) ((T_LIST) reduce 148) ((T_LNUMBER) reduce 148) ((T_MATCH) reduce 148) ((T_METHOD_C) reduce 148) ((T_NAME_FULLY_QUALIFIED) reduce 148) ((T_NAME_QUALIFIED) reduce 148) ((T_NAME_RELATIVE) reduce 148) ((T_NEW) reduce 148) ((T_NS_C) reduce 148) ((T_OBJECT_CAST) reduce 148) ((T_PRINT) reduce 148) ((T_READONLY) reduce 148) ((T_REQUIRE) reduce 148) ((T_REQUIRE_ONCE) reduce 148) ((T_RETURN) reduce 148) ((T_START_HEREDOC) reduce 148) ((T_STATIC) reduce 148) ((T_STRING) reduce 148) ((T_STRING_CAST) reduce 148) ((T_SWITCH) reduce 148) ((T_THROW) reduce 148) ((T_TRAIT) reduce 148) ((T_TRAIT_C) reduce 148) ((T_TRY) reduce 148) ((T_UNSET) reduce 148) ((T_UNSET_CAST) reduce 148) ((T_VARIABLE) reduce 148) ((T_WHILE) reduce 148) ((T_YIELD) reduce 148) ((T_YIELD_FROM) reduce 148) (("[") reduce 148) (("`") reduce 148) (("{") reduce 148) (("}") reduce 148) (("~") reduce 148)) 25328 ((("!") reduce 240) (("\"") reduce 240) (("$") reduce 240) (("(") reduce 240) (("+") reduce 240) (("-") reduce 240) ((";") reduce 240) (("@") reduce 240) ((T_ABSTRACT) reduce 240) ((T_ARRAY) reduce 240) ((T_ARRAY_CAST) reduce 240) ((T_ATTRIBUTE) reduce 240) ((T_BOOL_CAST) reduce 240) ((T_BREAK) reduce 240) ((T_CLASS) reduce 240) ((T_CLASS_C) reduce 240) ((T_CLONE) reduce 240) ((T_CONSTANT_ENCAPSED_STRING) reduce 240) ((T_CONTINUE) reduce 240) ((T_DEC) reduce 240) ((T_DECLARE) reduce 240) ((T_DIR) reduce 240) ((T_DNUMBER) reduce 240) ((T_DO) reduce 240) ((T_DOUBLE_CAST) reduce 240) ((T_ECHO) reduce 240) ((T_EMPTY) reduce 240) ((T_ENUM) reduce 240) ((T_EVAL) reduce 240) ((T_EXIT) reduce 240) ((T_FILE) reduce 240) ((T_FINAL) reduce 240) ((T_FN) reduce 240) ((T_FOR) reduce 240) ((T_FOREACH) reduce 240) ((T_FUNCTION) reduce 240) ((T_FUNC_C) reduce 240) ((T_GLOBAL) reduce 240) ((T_GOTO) reduce 240) ((T_HALT_COMPILER) reduce 240) ((T_IF) reduce 240) ((T_INC) reduce 240) ((T_INCLUDE) reduce 240) ((T_INCLUDE_ONCE) reduce 240) ((T_INLINE_HTML) reduce 240) ((T_INTERFACE) reduce 240) ((T_INT_CAST) reduce 240) ((T_ISSET) reduce 240) ((T_LINE) reduce 240) ((T_LIST) reduce 240) ((T_LNUMBER) reduce 240) ((T_MATCH) reduce 240) ((T_METHOD_C) reduce 240) ((T_NAME_FULLY_QUALIFIED) reduce 240) ((T_NAME_QUALIFIED) reduce 240) ((T_NAME_RELATIVE) reduce 240) ((T_NEW) reduce 240) ((T_NS_C) reduce 240) ((T_OBJECT_CAST) reduce 240) ((T_PRINT) reduce 240) ((T_READONLY) reduce 240) ((T_REQUIRE) reduce 240) ((T_REQUIRE_ONCE) reduce 240) ((T_RETURN) reduce 240) ((T_START_HEREDOC) reduce 240) ((T_STATIC) reduce 240) ((T_STRING) reduce 240) ((T_STRING_CAST) reduce 240) ((T_SWITCH) reduce 240) ((T_THROW) reduce 240) ((T_TRAIT) reduce 240) ((T_TRAIT_C) reduce 240) ((T_TRY) reduce 240) ((T_UNSET) reduce 240) ((T_UNSET_CAST) reduce 240) ((T_VARIABLE) reduce 240) ((T_WHILE) reduce 240) ((T_YIELD) reduce 240) ((T_YIELD_FROM) reduce 240) (("[") reduce 240) (("`") reduce 240) (("{") reduce 240) (("}") reduce 240) (("~") reduce 240)) 25333 ((("!") reduce 160) (("\"") reduce 160) (("$") reduce 160) (("(") reduce 160) (("+") reduce 160) (("-") reduce 160) ((";") reduce 160) (("@") reduce 160) ((T_ABSTRACT) reduce 160) ((T_ARRAY) reduce 160) ((T_ARRAY_CAST) reduce 160) ((T_ATTRIBUTE) reduce 160) ((T_BOOL_CAST) reduce 160) ((T_BREAK) reduce 160) ((T_CLASS) reduce 160) ((T_CLASS_C) reduce 160) ((T_CLONE) reduce 160) ((T_CONSTANT_ENCAPSED_STRING) reduce 160) ((T_CONTINUE) reduce 160) ((T_DEC) reduce 160) ((T_DECLARE) reduce 160) ((T_DIR) reduce 160) ((T_DNUMBER) reduce 160) ((T_DO) reduce 160) ((T_DOUBLE_CAST) reduce 160) ((T_ECHO) reduce 160) ((T_EMPTY) reduce 160) ((T_ENUM) reduce 160) ((T_EVAL) reduce 160) ((T_EXIT) reduce 160) ((T_FILE) reduce 160) ((T_FINAL) reduce 160) ((T_FN) reduce 160) ((T_FOR) reduce 160) ((T_FOREACH) reduce 160) ((T_FUNCTION) reduce 160) ((T_FUNC_C) reduce 160) ((T_GLOBAL) reduce 160) ((T_GOTO) reduce 160) ((T_HALT_COMPILER) reduce 160) ((T_IF) reduce 160) ((T_INC) reduce 160) ((T_INCLUDE) reduce 160) ((T_INCLUDE_ONCE) reduce 160) ((T_INLINE_HTML) reduce 160) ((T_INTERFACE) reduce 160) ((T_INT_CAST) reduce 160) ((T_ISSET) reduce 160) ((T_LINE) reduce 160) ((T_LIST) reduce 160) ((T_LNUMBER) reduce 160) ((T_MATCH) reduce 160) ((T_METHOD_C) reduce 160) ((T_NAME_FULLY_QUALIFIED) reduce 160) ((T_NAME_QUALIFIED) reduce 160) ((T_NAME_RELATIVE) reduce 160) ((T_NEW) reduce 160) ((T_NS_C) reduce 160) ((T_OBJECT_CAST) reduce 160) ((T_PRINT) reduce 160) ((T_READONLY) reduce 160) ((T_REQUIRE) reduce 160) ((T_REQUIRE_ONCE) reduce 160) ((T_RETURN) reduce 160) ((T_START_HEREDOC) reduce 160) ((T_STATIC) reduce 160) ((T_STRING) reduce 160) ((T_STRING_CAST) reduce 160) ((T_SWITCH) reduce 160) ((T_THROW) reduce 160) ((T_TRAIT) reduce 160) ((T_TRAIT_C) reduce 160) ((T_TRY) reduce 160) ((T_UNSET) reduce 160) ((T_UNSET_CAST) reduce 160) ((T_VARIABLE) reduce 160) ((T_WHILE) reduce 160) ((T_YIELD) reduce 160) ((T_YIELD_FROM) reduce 160) (("[") reduce 160) (("`") reduce 160) (("{") reduce 160) (("}") reduce 160) (("~") reduce 160)) 25336 ((("!") reduce 168) (("\"") reduce 168) (("$") reduce 168) (("(") reduce 168) (("+") reduce 168) (("-") reduce 168) ((";") reduce 168) (("@") reduce 168) ((T_ABSTRACT) reduce 168) ((T_ARRAY) reduce 168) ((T_ARRAY_CAST) reduce 168) ((T_ATTRIBUTE) reduce 168) ((T_BOOL_CAST) reduce 168) ((T_BREAK) reduce 168) ((T_CATCH) reduce 168) ((T_CLASS) reduce 168) ((T_CLASS_C) reduce 168) ((T_CLONE) reduce 168) ((T_CONSTANT_ENCAPSED_STRING) reduce 168) ((T_CONTINUE) reduce 168) ((T_DEC) reduce 168) ((T_DECLARE) reduce 168) ((T_DIR) reduce 168) ((T_DNUMBER) reduce 168) ((T_DO) reduce 168) ((T_DOUBLE_CAST) reduce 168) ((T_ECHO) reduce 168) ((T_EMPTY) reduce 168) ((T_ENUM) reduce 168) ((T_EVAL) reduce 168) ((T_EXIT) reduce 168) ((T_FILE) reduce 168) ((T_FINAL) reduce 168) ((T_FINALLY) reduce 168) ((T_FN) reduce 168) ((T_FOR) reduce 168) ((T_FOREACH) reduce 168) ((T_FUNCTION) reduce 168) ((T_FUNC_C) reduce 168) ((T_GLOBAL) reduce 168) ((T_GOTO) reduce 168) ((T_HALT_COMPILER) reduce 168) ((T_IF) reduce 168) ((T_INC) reduce 168) ((T_INCLUDE) reduce 168) ((T_INCLUDE_ONCE) reduce 168) ((T_INLINE_HTML) reduce 168) ((T_INTERFACE) reduce 168) ((T_INT_CAST) reduce 168) ((T_ISSET) reduce 168) ((T_LINE) reduce 168) ((T_LIST) reduce 168) ((T_LNUMBER) reduce 168) ((T_MATCH) reduce 168) ((T_METHOD_C) reduce 168) ((T_NAME_FULLY_QUALIFIED) reduce 168) ((T_NAME_QUALIFIED) reduce 168) ((T_NAME_RELATIVE) reduce 168) ((T_NEW) reduce 168) ((T_NS_C) reduce 168) ((T_OBJECT_CAST) reduce 168) ((T_PRINT) reduce 168) ((T_READONLY) reduce 168) ((T_REQUIRE) reduce 168) ((T_REQUIRE_ONCE) reduce 168) ((T_RETURN) reduce 168) ((T_START_HEREDOC) reduce 168) ((T_STATIC) reduce 168) ((T_STRING) reduce 168) ((T_STRING_CAST) reduce 168) ((T_SWITCH) reduce 168) ((T_THROW) reduce 168) ((T_TRAIT) reduce 168) ((T_TRAIT_C) reduce 168) ((T_TRY) reduce 168) ((T_UNSET) reduce 168) ((T_UNSET_CAST) reduce 168) ((T_VARIABLE) reduce 168) ((T_WHILE) reduce 168) ((T_YIELD) reduce 168) ((T_YIELD_FROM) reduce 168) (("[") reduce 168) (("`") reduce 168) (("{") reduce 168) (("}") reduce 168) (("~") reduce 168)) 25337 ((("!") reduce 174) (("\"") reduce 174) (("$") reduce 174) (("(") reduce 174) (("+") reduce 174) (("-") reduce 174) ((";") reduce 174) (("@") reduce 174) ((T_ABSTRACT) reduce 174) ((T_ARRAY) reduce 174) ((T_ARRAY_CAST) reduce 174) ((T_ATTRIBUTE) reduce 174) ((T_BOOL_CAST) reduce 174) ((T_BREAK) reduce 174) ((T_CATCH) shift) ((T_CLASS) reduce 174) ((T_CLASS_C) reduce 174) ((T_CLONE) reduce 174) ((T_CONSTANT_ENCAPSED_STRING) reduce 174) ((T_CONTINUE) reduce 174) ((T_DEC) reduce 174) ((T_DECLARE) reduce 174) ((T_DIR) reduce 174) ((T_DNUMBER) reduce 174) ((T_DO) reduce 174) ((T_DOUBLE_CAST) reduce 174) ((T_ECHO) reduce 174) ((T_EMPTY) reduce 174) ((T_ENUM) reduce 174) ((T_EVAL) reduce 174) ((T_EXIT) reduce 174) ((T_FILE) reduce 174) ((T_FINAL) reduce 174) ((T_FINALLY) shift) ((T_FN) reduce 174) ((T_FOR) reduce 174) ((T_FOREACH) reduce 174) ((T_FUNCTION) reduce 174) ((T_FUNC_C) reduce 174) ((T_GLOBAL) reduce 174) ((T_GOTO) reduce 174) ((T_HALT_COMPILER) reduce 174) ((T_IF) reduce 174) ((T_INC) reduce 174) ((T_INCLUDE) reduce 174) ((T_INCLUDE_ONCE) reduce 174) ((T_INLINE_HTML) reduce 174) ((T_INTERFACE) reduce 174) ((T_INT_CAST) reduce 174) ((T_ISSET) reduce 174) ((T_LINE) reduce 174) ((T_LIST) reduce 174) ((T_LNUMBER) reduce 174) ((T_MATCH) reduce 174) ((T_METHOD_C) reduce 174) ((T_NAME_FULLY_QUALIFIED) reduce 174) ((T_NAME_QUALIFIED) reduce 174) ((T_NAME_RELATIVE) reduce 174) ((T_NEW) reduce 174) ((T_NS_C) reduce 174) ((T_OBJECT_CAST) reduce 174) ((T_PRINT) reduce 174) ((T_READONLY) reduce 174) ((T_REQUIRE) reduce 174) ((T_REQUIRE_ONCE) reduce 174) ((T_RETURN) reduce 174) ((T_START_HEREDOC) reduce 174) ((T_STATIC) reduce 174) ((T_STRING) reduce 174) ((T_STRING_CAST) reduce 174) ((T_SWITCH) reduce 174) ((T_THROW) reduce 174) ((T_TRAIT) reduce 174) ((T_TRAIT_C) reduce 174) ((T_TRY) reduce 174) ((T_UNSET) reduce 174) ((T_UNSET_CAST) reduce 174) ((T_VARIABLE) reduce 174) ((T_WHILE) reduce 174) ((T_YIELD) reduce 174) ((T_YIELD_FROM) reduce 174) (("[") reduce 174) (("`") reduce 174) (("{") reduce 174) (("}") reduce 174) (("~") reduce 174)) 25340 ((("!") reduce 165) (("\"") reduce 165) (("$") reduce 165) (("(") reduce 165) (("+") reduce 165) (("-") reduce 165) ((";") reduce 165) (("@") reduce 165) ((T_ABSTRACT) reduce 165) ((T_ARRAY) reduce 165) ((T_ARRAY_CAST) reduce 165) ((T_ATTRIBUTE) reduce 165) ((T_BOOL_CAST) reduce 165) ((T_BREAK) reduce 165) ((T_CLASS) reduce 165) ((T_CLASS_C) reduce 165) ((T_CLONE) reduce 165) ((T_CONSTANT_ENCAPSED_STRING) reduce 165) ((T_CONTINUE) reduce 165) ((T_DEC) reduce 165) ((T_DECLARE) reduce 165) ((T_DIR) reduce 165) ((T_DNUMBER) reduce 165) ((T_DO) reduce 165) ((T_DOUBLE_CAST) reduce 165) ((T_ECHO) reduce 165) ((T_EMPTY) reduce 165) ((T_ENUM) reduce 165) ((T_EVAL) reduce 165) ((T_EXIT) reduce 165) ((T_FILE) reduce 165) ((T_FINAL) reduce 165) ((T_FN) reduce 165) ((T_FOR) reduce 165) ((T_FOREACH) reduce 165) ((T_FUNCTION) reduce 165) ((T_FUNC_C) reduce 165) ((T_GLOBAL) reduce 165) ((T_GOTO) reduce 165) ((T_HALT_COMPILER) reduce 165) ((T_IF) reduce 165) ((T_INC) reduce 165) ((T_INCLUDE) reduce 165) ((T_INCLUDE_ONCE) reduce 165) ((T_INLINE_HTML) reduce 165) ((T_INTERFACE) reduce 165) ((T_INT_CAST) reduce 165) ((T_ISSET) reduce 165) ((T_LINE) reduce 165) ((T_LIST) reduce 165) ((T_LNUMBER) reduce 165) ((T_MATCH) reduce 165) ((T_METHOD_C) reduce 165) ((T_NAME_FULLY_QUALIFIED) reduce 165) ((T_NAME_QUALIFIED) reduce 165) ((T_NAME_RELATIVE) reduce 165) ((T_NEW) reduce 165) ((T_NS_C) reduce 165) ((T_OBJECT_CAST) reduce 165) ((T_PRINT) reduce 165) ((T_READONLY) reduce 165) ((T_REQUIRE) reduce 165) ((T_REQUIRE_ONCE) reduce 165) ((T_RETURN) reduce 165) ((T_START_HEREDOC) reduce 165) ((T_STATIC) reduce 165) ((T_STRING) reduce 165) ((T_STRING_CAST) reduce 165) ((T_SWITCH) reduce 165) ((T_THROW) reduce 165) ((T_TRAIT) reduce 165) ((T_TRAIT_C) reduce 165) ((T_TRY) reduce 165) ((T_UNSET) reduce 165) ((T_UNSET_CAST) reduce 165) ((T_VARIABLE) reduce 165) ((T_WHILE) reduce 165) ((T_YIELD) reduce 165) ((T_YIELD_FROM) reduce 165) (("[") reduce 165) (("`") reduce 165) (("{") reduce 165) (("}") reduce 165) (("~") reduce 165)) 25343 ((("!") reduce 175) (("\"") reduce 175) (("$") reduce 175) (("(") reduce 175) (("+") reduce 175) (("-") reduce 175) ((";") reduce 175) (("@") reduce 175) ((T_ABSTRACT) reduce 175) ((T_ARRAY) reduce 175) ((T_ARRAY_CAST) reduce 175) ((T_ATTRIBUTE) reduce 175) ((T_BOOL_CAST) reduce 175) ((T_BREAK) reduce 175) ((T_CLASS) reduce 175) ((T_CLASS_C) reduce 175) ((T_CLONE) reduce 175) ((T_CONSTANT_ENCAPSED_STRING) reduce 175) ((T_CONTINUE) reduce 175) ((T_DEC) reduce 175) ((T_DECLARE) reduce 175) ((T_DIR) reduce 175) ((T_DNUMBER) reduce 175) ((T_DO) reduce 175) ((T_DOUBLE_CAST) reduce 175) ((T_ECHO) reduce 175) ((T_EMPTY) reduce 175) ((T_ENUM) reduce 175) ((T_EVAL) reduce 175) ((T_EXIT) reduce 175) ((T_FILE) reduce 175) ((T_FINAL) reduce 175) ((T_FN) reduce 175) ((T_FOR) reduce 175) ((T_FOREACH) reduce 175) ((T_FUNCTION) reduce 175) ((T_FUNC_C) reduce 175) ((T_GLOBAL) reduce 175) ((T_GOTO) reduce 175) ((T_HALT_COMPILER) reduce 175) ((T_IF) reduce 175) ((T_INC) reduce 175) ((T_INCLUDE) reduce 175) ((T_INCLUDE_ONCE) reduce 175) ((T_INLINE_HTML) reduce 175) ((T_INTERFACE) reduce 175) ((T_INT_CAST) reduce 175) ((T_ISSET) reduce 175) ((T_LINE) reduce 175) ((T_LIST) reduce 175) ((T_LNUMBER) reduce 175) ((T_MATCH) reduce 175) ((T_METHOD_C) reduce 175) ((T_NAME_FULLY_QUALIFIED) reduce 175) ((T_NAME_QUALIFIED) reduce 175) ((T_NAME_RELATIVE) reduce 175) ((T_NEW) reduce 175) ((T_NS_C) reduce 175) ((T_OBJECT_CAST) reduce 175) ((T_PRINT) reduce 175) ((T_READONLY) reduce 175) ((T_REQUIRE) reduce 175) ((T_REQUIRE_ONCE) reduce 175) ((T_RETURN) reduce 175) ((T_START_HEREDOC) reduce 175) ((T_STATIC) reduce 175) ((T_STRING) reduce 175) ((T_STRING_CAST) reduce 175) ((T_SWITCH) reduce 175) ((T_THROW) reduce 175) ((T_TRAIT) reduce 175) ((T_TRAIT_C) reduce 175) ((T_TRY) reduce 175) ((T_UNSET) reduce 175) ((T_UNSET_CAST) reduce 175) ((T_VARIABLE) reduce 175) ((T_WHILE) reduce 175) ((T_YIELD) reduce 175) ((T_YIELD_FROM) reduce 175) (("[") reduce 175) (("`") reduce 175) (("{") reduce 175) (("}") reduce 175) (("~") reduce 175)) 25350 ((("!") reduce 169) (("\"") reduce 169) (("$") reduce 169) (("(") reduce 169) (("+") reduce 169) (("-") reduce 169) ((";") reduce 169) (("@") reduce 169) ((T_ABSTRACT) reduce 169) ((T_ARRAY) reduce 169) ((T_ARRAY_CAST) reduce 169) ((T_ATTRIBUTE) reduce 169) ((T_BOOL_CAST) reduce 169) ((T_BREAK) reduce 169) ((T_CATCH) reduce 169) ((T_CLASS) reduce 169) ((T_CLASS_C) reduce 169) ((T_CLONE) reduce 169) ((T_CONSTANT_ENCAPSED_STRING) reduce 169) ((T_CONTINUE) reduce 169) ((T_DEC) reduce 169) ((T_DECLARE) reduce 169) ((T_DIR) reduce 169) ((T_DNUMBER) reduce 169) ((T_DO) reduce 169) ((T_DOUBLE_CAST) reduce 169) ((T_ECHO) reduce 169) ((T_EMPTY) reduce 169) ((T_ENUM) reduce 169) ((T_EVAL) reduce 169) ((T_EXIT) reduce 169) ((T_FILE) reduce 169) ((T_FINAL) reduce 169) ((T_FINALLY) reduce 169) ((T_FN) reduce 169) ((T_FOR) reduce 169) ((T_FOREACH) reduce 169) ((T_FUNCTION) reduce 169) ((T_FUNC_C) reduce 169) ((T_GLOBAL) reduce 169) ((T_GOTO) reduce 169) ((T_HALT_COMPILER) reduce 169) ((T_IF) reduce 169) ((T_INC) reduce 169) ((T_INCLUDE) reduce 169) ((T_INCLUDE_ONCE) reduce 169) ((T_INLINE_HTML) reduce 169) ((T_INTERFACE) reduce 169) ((T_INT_CAST) reduce 169) ((T_ISSET) reduce 169) ((T_LINE) reduce 169) ((T_LIST) reduce 169) ((T_LNUMBER) reduce 169) ((T_MATCH) reduce 169) ((T_METHOD_C) reduce 169) ((T_NAME_FULLY_QUALIFIED) reduce 169) ((T_NAME_QUALIFIED) reduce 169) ((T_NAME_RELATIVE) reduce 169) ((T_NEW) reduce 169) ((T_NS_C) reduce 169) ((T_OBJECT_CAST) reduce 169) ((T_PRINT) reduce 169) ((T_READONLY) reduce 169) ((T_REQUIRE) reduce 169) ((T_REQUIRE_ONCE) reduce 169) ((T_RETURN) reduce 169) ((T_START_HEREDOC) reduce 169) ((T_STATIC) reduce 169) ((T_STRING) reduce 169) ((T_STRING_CAST) reduce 169) ((T_SWITCH) reduce 169) ((T_THROW) reduce 169) ((T_TRAIT) reduce 169) ((T_TRAIT_C) reduce 169) ((T_TRY) reduce 169) ((T_UNSET) reduce 169) ((T_UNSET_CAST) reduce 169) ((T_VARIABLE) reduce 169) ((T_WHILE) reduce 169) ((T_YIELD) reduce 169) ((T_YIELD_FROM) reduce 169) (("[") reduce 169) (("`") reduce 169) (("{") reduce 169) (("}") reduce 169) (("~") reduce 169)) 25355 ((("!") reduce 197) (("\"") reduce 197) (("$") reduce 197) (("(") reduce 197) (("+") reduce 197) (("-") reduce 197) ((";") reduce 197) (("@") reduce 197) ((T_ABSTRACT) reduce 197) ((T_ARRAY) reduce 197) ((T_ARRAY_CAST) reduce 197) ((T_ATTRIBUTE) reduce 197) ((T_BOOL_CAST) reduce 197) ((T_BREAK) reduce 197) ((T_CLASS) reduce 197) ((T_CLASS_C) reduce 197) ((T_CLONE) reduce 197) ((T_CONSTANT_ENCAPSED_STRING) reduce 197) ((T_CONTINUE) reduce 197) ((T_DEC) reduce 197) ((T_DECLARE) reduce 197) ((T_DIR) reduce 197) ((T_DNUMBER) reduce 197) ((T_DO) reduce 197) ((T_DOUBLE_CAST) reduce 197) ((T_ECHO) reduce 197) ((T_EMPTY) reduce 197) ((T_ENUM) reduce 197) ((T_EVAL) reduce 197) ((T_EXIT) reduce 197) ((T_FILE) reduce 197) ((T_FINAL) reduce 197) ((T_FN) reduce 197) ((T_FOR) reduce 197) ((T_FOREACH) reduce 197) ((T_FUNCTION) reduce 197) ((T_FUNC_C) reduce 197) ((T_GLOBAL) reduce 197) ((T_GOTO) reduce 197) ((T_HALT_COMPILER) reduce 197) ((T_IF) reduce 197) ((T_INC) reduce 197) ((T_INCLUDE) reduce 197) ((T_INCLUDE_ONCE) reduce 197) ((T_INLINE_HTML) reduce 197) ((T_INTERFACE) reduce 197) ((T_INT_CAST) reduce 197) ((T_ISSET) reduce 197) ((T_LINE) reduce 197) ((T_LIST) reduce 197) ((T_LNUMBER) reduce 197) ((T_MATCH) reduce 197) ((T_METHOD_C) reduce 197) ((T_NAME_FULLY_QUALIFIED) reduce 197) ((T_NAME_QUALIFIED) reduce 197) ((T_NAME_RELATIVE) reduce 197) ((T_NEW) reduce 197) ((T_NS_C) reduce 197) ((T_OBJECT_CAST) reduce 197) ((T_PRINT) reduce 197) ((T_READONLY) reduce 197) ((T_REQUIRE) reduce 197) ((T_REQUIRE_ONCE) reduce 197) ((T_RETURN) reduce 197) ((T_START_HEREDOC) reduce 197) ((T_STATIC) reduce 197) ((T_STRING) reduce 197) ((T_STRING_CAST) reduce 197) ((T_SWITCH) reduce 197) ((T_THROW) reduce 197) ((T_TRAIT) reduce 197) ((T_TRAIT_C) reduce 197) ((T_TRY) reduce 197) ((T_UNSET) reduce 197) ((T_UNSET_CAST) reduce 197) ((T_VARIABLE) reduce 197) ((T_WHILE) reduce 197) ((T_YIELD) reduce 197) ((T_YIELD_FROM) reduce 197) (("[") reduce 197) (("`") reduce 197) (("{") reduce 197) (("}") reduce 197) (("~") reduce 197)) 25360 ((("!") reduce 151) (("\"") reduce 151) (("$") reduce 151) (("(") reduce 151) (("+") reduce 151) (("-") reduce 151) ((";") reduce 151) (("@") reduce 151) ((T_ABSTRACT) reduce 151) ((T_ARRAY) reduce 151) ((T_ARRAY_CAST) reduce 151) ((T_ATTRIBUTE) reduce 151) ((T_BOOL_CAST) reduce 151) ((T_BREAK) reduce 151) ((T_CLASS) reduce 151) ((T_CLASS_C) reduce 151) ((T_CLONE) reduce 151) ((T_CONSTANT_ENCAPSED_STRING) reduce 151) ((T_CONTINUE) reduce 151) ((T_DEC) reduce 151) ((T_DECLARE) reduce 151) ((T_DIR) reduce 151) ((T_DNUMBER) reduce 151) ((T_DO) reduce 151) ((T_DOUBLE_CAST) reduce 151) ((T_ECHO) reduce 151) ((T_EMPTY) reduce 151) ((T_ENUM) reduce 151) ((T_EVAL) reduce 151) ((T_EXIT) reduce 151) ((T_FILE) reduce 151) ((T_FINAL) reduce 151) ((T_FN) reduce 151) ((T_FOR) reduce 151) ((T_FOREACH) reduce 151) ((T_FUNCTION) reduce 151) ((T_FUNC_C) reduce 151) ((T_GLOBAL) reduce 151) ((T_GOTO) reduce 151) ((T_HALT_COMPILER) reduce 151) ((T_IF) reduce 151) ((T_INC) reduce 151) ((T_INCLUDE) reduce 151) ((T_INCLUDE_ONCE) reduce 151) ((T_INLINE_HTML) reduce 151) ((T_INTERFACE) reduce 151) ((T_INT_CAST) reduce 151) ((T_ISSET) reduce 151) ((T_LINE) reduce 151) ((T_LIST) reduce 151) ((T_LNUMBER) reduce 151) ((T_MATCH) reduce 151) ((T_METHOD_C) reduce 151) ((T_NAME_FULLY_QUALIFIED) reduce 151) ((T_NAME_QUALIFIED) reduce 151) ((T_NAME_RELATIVE) reduce 151) ((T_NEW) reduce 151) ((T_NS_C) reduce 151) ((T_OBJECT_CAST) reduce 151) ((T_PRINT) reduce 151) ((T_READONLY) reduce 151) ((T_REQUIRE) reduce 151) ((T_REQUIRE_ONCE) reduce 151) ((T_RETURN) reduce 151) ((T_START_HEREDOC) reduce 151) ((T_STATIC) reduce 151) ((T_STRING) reduce 151) ((T_STRING_CAST) reduce 151) ((T_SWITCH) reduce 151) ((T_THROW) reduce 151) ((T_TRAIT) reduce 151) ((T_TRAIT_C) reduce 151) ((T_TRY) reduce 151) ((T_UNSET) reduce 151) ((T_UNSET_CAST) reduce 151) ((T_VARIABLE) reduce 151) ((T_WHILE) reduce 151) ((T_YIELD) reduce 151) ((T_YIELD_FROM) reduce 151) (("[") reduce 151) (("`") reduce 151) (("{") reduce 151) (("}") reduce 151) (("~") reduce 151)) 25364 ((("!") reduce 221) (("\"") reduce 221) (("$") reduce 221) (("(") reduce 221) (("+") reduce 221) (("-") reduce 221) ((";") reduce 221) (("@") reduce 221) ((T_ABSTRACT) reduce 221) ((T_ARRAY) reduce 221) ((T_ARRAY_CAST) reduce 221) ((T_ATTRIBUTE) reduce 221) ((T_BOOL_CAST) reduce 221) ((T_BREAK) reduce 221) ((T_CLASS) reduce 221) ((T_CLASS_C) reduce 221) ((T_CLONE) reduce 221) ((T_CONSTANT_ENCAPSED_STRING) reduce 221) ((T_CONTINUE) reduce 221) ((T_DEC) reduce 221) ((T_DECLARE) reduce 221) ((T_DIR) reduce 221) ((T_DNUMBER) reduce 221) ((T_DO) reduce 221) ((T_DOUBLE_CAST) reduce 221) ((T_ECHO) reduce 221) ((T_EMPTY) reduce 221) ((T_ENUM) reduce 221) ((T_EVAL) reduce 221) ((T_EXIT) reduce 221) ((T_FILE) reduce 221) ((T_FINAL) reduce 221) ((T_FN) reduce 221) ((T_FOR) reduce 221) ((T_FOREACH) reduce 221) ((T_FUNCTION) reduce 221) ((T_FUNC_C) reduce 221) ((T_GLOBAL) reduce 221) ((T_GOTO) reduce 221) ((T_HALT_COMPILER) reduce 221) ((T_IF) reduce 221) ((T_INC) reduce 221) ((T_INCLUDE) reduce 221) ((T_INCLUDE_ONCE) reduce 221) ((T_INLINE_HTML) reduce 221) ((T_INTERFACE) reduce 221) ((T_INT_CAST) reduce 221) ((T_ISSET) reduce 221) ((T_LINE) reduce 221) ((T_LIST) reduce 221) ((T_LNUMBER) reduce 221) ((T_MATCH) reduce 221) ((T_METHOD_C) reduce 221) ((T_NAME_FULLY_QUALIFIED) reduce 221) ((T_NAME_QUALIFIED) reduce 221) ((T_NAME_RELATIVE) reduce 221) ((T_NEW) reduce 221) ((T_NS_C) reduce 221) ((T_OBJECT_CAST) reduce 221) ((T_PRINT) reduce 221) ((T_READONLY) reduce 221) ((T_REQUIRE) reduce 221) ((T_REQUIRE_ONCE) reduce 221) ((T_RETURN) reduce 221) ((T_START_HEREDOC) reduce 221) ((T_STATIC) reduce 221) ((T_STRING) reduce 221) ((T_STRING_CAST) reduce 221) ((T_SWITCH) reduce 221) ((T_THROW) reduce 221) ((T_TRAIT) reduce 221) ((T_TRAIT_C) reduce 221) ((T_TRY) reduce 221) ((T_UNSET) reduce 221) ((T_UNSET_CAST) reduce 221) ((T_VARIABLE) reduce 221) ((T_WHILE) reduce 221) ((T_YIELD) reduce 221) ((T_YIELD_FROM) reduce 221) (("[") reduce 221) (("`") reduce 221) (("{") reduce 221) (("}") reduce 221) (("~") reduce 221)) 25366 ((("!") reduce 222) (("\"") reduce 222) (("$") reduce 222) (("(") reduce 222) (("+") reduce 222) (("-") reduce 222) ((";") reduce 222) (("@") reduce 222) ((T_ABSTRACT) reduce 222) ((T_ARRAY) reduce 222) ((T_ARRAY_CAST) reduce 222) ((T_ATTRIBUTE) reduce 222) ((T_BOOL_CAST) reduce 222) ((T_BREAK) reduce 222) ((T_CLASS) reduce 222) ((T_CLASS_C) reduce 222) ((T_CLONE) reduce 222) ((T_CONSTANT_ENCAPSED_STRING) reduce 222) ((T_CONTINUE) reduce 222) ((T_DEC) reduce 222) ((T_DECLARE) reduce 222) ((T_DIR) reduce 222) ((T_DNUMBER) reduce 222) ((T_DO) reduce 222) ((T_DOUBLE_CAST) reduce 222) ((T_ECHO) reduce 222) ((T_EMPTY) reduce 222) ((T_ENUM) reduce 222) ((T_EVAL) reduce 222) ((T_EXIT) reduce 222) ((T_FILE) reduce 222) ((T_FINAL) reduce 222) ((T_FN) reduce 222) ((T_FOR) reduce 222) ((T_FOREACH) reduce 222) ((T_FUNCTION) reduce 222) ((T_FUNC_C) reduce 222) ((T_GLOBAL) reduce 222) ((T_GOTO) reduce 222) ((T_HALT_COMPILER) reduce 222) ((T_IF) reduce 222) ((T_INC) reduce 222) ((T_INCLUDE) reduce 222) ((T_INCLUDE_ONCE) reduce 222) ((T_INLINE_HTML) reduce 222) ((T_INTERFACE) reduce 222) ((T_INT_CAST) reduce 222) ((T_ISSET) reduce 222) ((T_LINE) reduce 222) ((T_LIST) reduce 222) ((T_LNUMBER) reduce 222) ((T_MATCH) reduce 222) ((T_METHOD_C) reduce 222) ((T_NAME_FULLY_QUALIFIED) reduce 222) ((T_NAME_QUALIFIED) reduce 222) ((T_NAME_RELATIVE) reduce 222) ((T_NEW) reduce 222) ((T_NS_C) reduce 222) ((T_OBJECT_CAST) reduce 222) ((T_PRINT) reduce 222) ((T_READONLY) reduce 222) ((T_REQUIRE) reduce 222) ((T_REQUIRE_ONCE) reduce 222) ((T_RETURN) reduce 222) ((T_START_HEREDOC) reduce 222) ((T_STATIC) reduce 222) ((T_STRING) reduce 222) ((T_STRING_CAST) reduce 222) ((T_SWITCH) reduce 222) ((T_THROW) reduce 222) ((T_TRAIT) reduce 222) ((T_TRAIT_C) reduce 222) ((T_TRY) reduce 222) ((T_UNSET) reduce 222) ((T_UNSET_CAST) reduce 222) ((T_VARIABLE) reduce 222) ((T_WHILE) reduce 222) ((T_YIELD) reduce 222) ((T_YIELD_FROM) reduce 222) (("[") reduce 222) (("`") reduce 222) (("{") reduce 222) (("}") reduce 222) (("~") reduce 222)) 25370 ((("!") reduce 223) (("\"") reduce 223) (("$") reduce 223) (("(") reduce 223) (("+") reduce 223) (("-") reduce 223) ((";") reduce 223) (("@") reduce 223) ((T_ABSTRACT) reduce 223) ((T_ARRAY) reduce 223) ((T_ARRAY_CAST) reduce 223) ((T_ATTRIBUTE) reduce 223) ((T_BOOL_CAST) reduce 223) ((T_BREAK) reduce 223) ((T_CLASS) reduce 223) ((T_CLASS_C) reduce 223) ((T_CLONE) reduce 223) ((T_CONSTANT_ENCAPSED_STRING) reduce 223) ((T_CONTINUE) reduce 223) ((T_DEC) reduce 223) ((T_DECLARE) reduce 223) ((T_DIR) reduce 223) ((T_DNUMBER) reduce 223) ((T_DO) reduce 223) ((T_DOUBLE_CAST) reduce 223) ((T_ECHO) reduce 223) ((T_EMPTY) reduce 223) ((T_ENUM) reduce 223) ((T_EVAL) reduce 223) ((T_EXIT) reduce 223) ((T_FILE) reduce 223) ((T_FINAL) reduce 223) ((T_FN) reduce 223) ((T_FOR) reduce 223) ((T_FOREACH) reduce 223) ((T_FUNCTION) reduce 223) ((T_FUNC_C) reduce 223) ((T_GLOBAL) reduce 223) ((T_GOTO) reduce 223) ((T_HALT_COMPILER) reduce 223) ((T_IF) reduce 223) ((T_INC) reduce 223) ((T_INCLUDE) reduce 223) ((T_INCLUDE_ONCE) reduce 223) ((T_INLINE_HTML) reduce 223) ((T_INTERFACE) reduce 223) ((T_INT_CAST) reduce 223) ((T_ISSET) reduce 223) ((T_LINE) reduce 223) ((T_LIST) reduce 223) ((T_LNUMBER) reduce 223) ((T_MATCH) reduce 223) ((T_METHOD_C) reduce 223) ((T_NAME_FULLY_QUALIFIED) reduce 223) ((T_NAME_QUALIFIED) reduce 223) ((T_NAME_RELATIVE) reduce 223) ((T_NEW) reduce 223) ((T_NS_C) reduce 223) ((T_OBJECT_CAST) reduce 223) ((T_PRINT) reduce 223) ((T_READONLY) reduce 223) ((T_REQUIRE) reduce 223) ((T_REQUIRE_ONCE) reduce 223) ((T_RETURN) reduce 223) ((T_START_HEREDOC) reduce 223) ((T_STATIC) reduce 223) ((T_STRING) reduce 223) ((T_STRING_CAST) reduce 223) ((T_SWITCH) reduce 223) ((T_THROW) reduce 223) ((T_TRAIT) reduce 223) ((T_TRAIT_C) reduce 223) ((T_TRY) reduce 223) ((T_UNSET) reduce 223) ((T_UNSET_CAST) reduce 223) ((T_VARIABLE) reduce 223) ((T_WHILE) reduce 223) ((T_YIELD) reduce 223) ((T_YIELD_FROM) reduce 223) (("[") reduce 223) (("`") reduce 223) (("{") reduce 223) (("}") reduce 223) (("~") reduce 223)) 25373 ((("!") reduce 224) (("\"") reduce 224) (("$") reduce 224) (("(") reduce 224) (("+") reduce 224) (("-") reduce 224) ((";") reduce 224) (("@") reduce 224) ((T_ABSTRACT) reduce 224) ((T_ARRAY) reduce 224) ((T_ARRAY_CAST) reduce 224) ((T_ATTRIBUTE) reduce 224) ((T_BOOL_CAST) reduce 224) ((T_BREAK) reduce 224) ((T_CLASS) reduce 224) ((T_CLASS_C) reduce 224) ((T_CLONE) reduce 224) ((T_CONSTANT_ENCAPSED_STRING) reduce 224) ((T_CONTINUE) reduce 224) ((T_DEC) reduce 224) ((T_DECLARE) reduce 224) ((T_DIR) reduce 224) ((T_DNUMBER) reduce 224) ((T_DO) reduce 224) ((T_DOUBLE_CAST) reduce 224) ((T_ECHO) reduce 224) ((T_EMPTY) reduce 224) ((T_ENUM) reduce 224) ((T_EVAL) reduce 224) ((T_EXIT) reduce 224) ((T_FILE) reduce 224) ((T_FINAL) reduce 224) ((T_FN) reduce 224) ((T_FOR) reduce 224) ((T_FOREACH) reduce 224) ((T_FUNCTION) reduce 224) ((T_FUNC_C) reduce 224) ((T_GLOBAL) reduce 224) ((T_GOTO) reduce 224) ((T_HALT_COMPILER) reduce 224) ((T_IF) reduce 224) ((T_INC) reduce 224) ((T_INCLUDE) reduce 224) ((T_INCLUDE_ONCE) reduce 224) ((T_INLINE_HTML) reduce 224) ((T_INTERFACE) reduce 224) ((T_INT_CAST) reduce 224) ((T_ISSET) reduce 224) ((T_LINE) reduce 224) ((T_LIST) reduce 224) ((T_LNUMBER) reduce 224) ((T_MATCH) reduce 224) ((T_METHOD_C) reduce 224) ((T_NAME_FULLY_QUALIFIED) reduce 224) ((T_NAME_QUALIFIED) reduce 224) ((T_NAME_RELATIVE) reduce 224) ((T_NEW) reduce 224) ((T_NS_C) reduce 224) ((T_OBJECT_CAST) reduce 224) ((T_PRINT) reduce 224) ((T_READONLY) reduce 224) ((T_REQUIRE) reduce 224) ((T_REQUIRE_ONCE) reduce 224) ((T_RETURN) reduce 224) ((T_START_HEREDOC) reduce 224) ((T_STATIC) reduce 224) ((T_STRING) reduce 224) ((T_STRING_CAST) reduce 224) ((T_SWITCH) reduce 224) ((T_THROW) reduce 224) ((T_TRAIT) reduce 224) ((T_TRAIT_C) reduce 224) ((T_TRY) reduce 224) ((T_UNSET) reduce 224) ((T_UNSET_CAST) reduce 224) ((T_VARIABLE) reduce 224) ((T_WHILE) reduce 224) ((T_YIELD) reduce 224) ((T_YIELD_FROM) reduce 224) (("[") reduce 224) (("`") reduce 224) (("{") reduce 224) (("}") reduce 224) (("~") reduce 224)) 25374 ((("!") reduce 167) (("\"") reduce 167) (("$") reduce 167) (("(") reduce 167) (("+") reduce 167) (("-") reduce 167) ((";") reduce 167) (("@") reduce 167) ((T_ABSTRACT) reduce 167) ((T_ARRAY) reduce 167) ((T_ARRAY_CAST) reduce 167) ((T_ATTRIBUTE) reduce 167) ((T_BOOL_CAST) reduce 167) ((T_BREAK) reduce 167) ((T_CLASS) reduce 167) ((T_CLASS_C) reduce 167) ((T_CLONE) reduce 167) ((T_CONSTANT_ENCAPSED_STRING) reduce 167) ((T_CONTINUE) reduce 167) ((T_DEC) reduce 167) ((T_DECLARE) reduce 167) ((T_DIR) reduce 167) ((T_DNUMBER) reduce 167) ((T_DO) reduce 167) ((T_DOUBLE_CAST) reduce 167) ((T_ECHO) reduce 167) ((T_EMPTY) reduce 167) ((T_ENUM) reduce 167) ((T_EVAL) reduce 167) ((T_EXIT) reduce 167) ((T_FILE) reduce 167) ((T_FINAL) reduce 167) ((T_FN) reduce 167) ((T_FOR) reduce 167) ((T_FOREACH) reduce 167) ((T_FUNCTION) reduce 167) ((T_FUNC_C) reduce 167) ((T_GLOBAL) reduce 167) ((T_GOTO) reduce 167) ((T_HALT_COMPILER) reduce 167) ((T_IF) reduce 167) ((T_INC) reduce 167) ((T_INCLUDE) reduce 167) ((T_INCLUDE_ONCE) reduce 167) ((T_INLINE_HTML) reduce 167) ((T_INTERFACE) reduce 167) ((T_INT_CAST) reduce 167) ((T_ISSET) reduce 167) ((T_LINE) reduce 167) ((T_LIST) reduce 167) ((T_LNUMBER) reduce 167) ((T_MATCH) reduce 167) ((T_METHOD_C) reduce 167) ((T_NAME_FULLY_QUALIFIED) reduce 167) ((T_NAME_QUALIFIED) reduce 167) ((T_NAME_RELATIVE) reduce 167) ((T_NEW) reduce 167) ((T_NS_C) reduce 167) ((T_OBJECT_CAST) reduce 167) ((T_PRINT) reduce 167) ((T_READONLY) reduce 167) ((T_REQUIRE) reduce 167) ((T_REQUIRE_ONCE) reduce 167) ((T_RETURN) reduce 167) ((T_START_HEREDOC) reduce 167) ((T_STATIC) reduce 167) ((T_STRING) reduce 167) ((T_STRING_CAST) reduce 167) ((T_SWITCH) reduce 167) ((T_THROW) reduce 167) ((T_TRAIT) reduce 167) ((T_TRAIT_C) reduce 167) ((T_TRY) reduce 167) ((T_UNSET) reduce 167) ((T_UNSET_CAST) reduce 167) ((T_VARIABLE) reduce 167) ((T_WHILE) reduce 167) ((T_YIELD) reduce 167) ((T_YIELD_FROM) reduce 167) (("[") reduce 167) (("`") reduce 167) (("{") reduce 167) (("}") reduce 167) (("~") reduce 167)) 25376 ((("!") reduce 156) (("\"") reduce 156) (("$") reduce 156) (("(") reduce 156) (("+") reduce 156) (("-") reduce 156) ((";") reduce 156) (("@") reduce 156) ((T_ABSTRACT) reduce 156) ((T_ARRAY) reduce 156) ((T_ARRAY_CAST) reduce 156) ((T_ATTRIBUTE) reduce 156) ((T_BOOL_CAST) reduce 156) ((T_BREAK) reduce 156) ((T_CLASS) reduce 156) ((T_CLASS_C) reduce 156) ((T_CLONE) reduce 156) ((T_CONSTANT_ENCAPSED_STRING) reduce 156) ((T_CONTINUE) reduce 156) ((T_DEC) reduce 156) ((T_DECLARE) reduce 156) ((T_DIR) reduce 156) ((T_DNUMBER) reduce 156) ((T_DO) reduce 156) ((T_DOUBLE_CAST) reduce 156) ((T_ECHO) reduce 156) ((T_EMPTY) reduce 156) ((T_ENUM) reduce 156) ((T_EVAL) reduce 156) ((T_EXIT) reduce 156) ((T_FILE) reduce 156) ((T_FINAL) reduce 156) ((T_FN) reduce 156) ((T_FOR) reduce 156) ((T_FOREACH) reduce 156) ((T_FUNCTION) reduce 156) ((T_FUNC_C) reduce 156) ((T_GLOBAL) reduce 156) ((T_GOTO) reduce 156) ((T_HALT_COMPILER) reduce 156) ((T_IF) reduce 156) ((T_INC) reduce 156) ((T_INCLUDE) reduce 156) ((T_INCLUDE_ONCE) reduce 156) ((T_INLINE_HTML) reduce 156) ((T_INTERFACE) reduce 156) ((T_INT_CAST) reduce 156) ((T_ISSET) reduce 156) ((T_LINE) reduce 156) ((T_LIST) reduce 156) ((T_LNUMBER) reduce 156) ((T_MATCH) reduce 156) ((T_METHOD_C) reduce 156) ((T_NAME_FULLY_QUALIFIED) reduce 156) ((T_NAME_QUALIFIED) reduce 156) ((T_NAME_RELATIVE) reduce 156) ((T_NEW) reduce 156) ((T_NS_C) reduce 156) ((T_OBJECT_CAST) reduce 156) ((T_PRINT) reduce 156) ((T_READONLY) reduce 156) ((T_REQUIRE) reduce 156) ((T_REQUIRE_ONCE) reduce 156) ((T_RETURN) reduce 156) ((T_START_HEREDOC) reduce 156) ((T_STATIC) reduce 156) ((T_STRING) reduce 156) ((T_STRING_CAST) reduce 156) ((T_SWITCH) reduce 156) ((T_THROW) reduce 156) ((T_TRAIT) reduce 156) ((T_TRAIT_C) reduce 156) ((T_TRY) reduce 156) ((T_UNSET) reduce 156) ((T_UNSET_CAST) reduce 156) ((T_VARIABLE) reduce 156) ((T_WHILE) reduce 156) ((T_YIELD) reduce 156) ((T_YIELD_FROM) reduce 156) (("[") reduce 156) (("`") reduce 156) (("{") reduce 156) (("}") reduce 156) (("~") reduce 156)) 25378 ((("!") reduce 154) (("\"") reduce 154) (("$") reduce 154) (("(") reduce 154) (("+") reduce 154) (("-") reduce 154) ((";") reduce 154) (("@") reduce 154) ((T_ABSTRACT) reduce 154) ((T_ARRAY) reduce 154) ((T_ARRAY_CAST) reduce 154) ((T_ATTRIBUTE) reduce 154) ((T_BOOL_CAST) reduce 154) ((T_BREAK) reduce 154) ((T_CLASS) reduce 154) ((T_CLASS_C) reduce 154) ((T_CLONE) reduce 154) ((T_CONSTANT_ENCAPSED_STRING) reduce 154) ((T_CONTINUE) reduce 154) ((T_DEC) reduce 154) ((T_DECLARE) reduce 154) ((T_DIR) reduce 154) ((T_DNUMBER) reduce 154) ((T_DO) reduce 154) ((T_DOUBLE_CAST) reduce 154) ((T_ECHO) reduce 154) ((T_EMPTY) reduce 154) ((T_ENUM) reduce 154) ((T_EVAL) reduce 154) ((T_EXIT) reduce 154) ((T_FILE) reduce 154) ((T_FINAL) reduce 154) ((T_FN) reduce 154) ((T_FOR) reduce 154) ((T_FOREACH) reduce 154) ((T_FUNCTION) reduce 154) ((T_FUNC_C) reduce 154) ((T_GLOBAL) reduce 154) ((T_GOTO) reduce 154) ((T_HALT_COMPILER) reduce 154) ((T_IF) reduce 154) ((T_INC) reduce 154) ((T_INCLUDE) reduce 154) ((T_INCLUDE_ONCE) reduce 154) ((T_INLINE_HTML) reduce 154) ((T_INTERFACE) reduce 154) ((T_INT_CAST) reduce 154) ((T_ISSET) reduce 154) ((T_LINE) reduce 154) ((T_LIST) reduce 154) ((T_LNUMBER) reduce 154) ((T_MATCH) reduce 154) ((T_METHOD_C) reduce 154) ((T_NAME_FULLY_QUALIFIED) reduce 154) ((T_NAME_QUALIFIED) reduce 154) ((T_NAME_RELATIVE) reduce 154) ((T_NEW) reduce 154) ((T_NS_C) reduce 154) ((T_OBJECT_CAST) reduce 154) ((T_PRINT) reduce 154) ((T_READONLY) reduce 154) ((T_REQUIRE) reduce 154) ((T_REQUIRE_ONCE) reduce 154) ((T_RETURN) reduce 154) ((T_START_HEREDOC) reduce 154) ((T_STATIC) reduce 154) ((T_STRING) reduce 154) ((T_STRING_CAST) reduce 154) ((T_SWITCH) reduce 154) ((T_THROW) reduce 154) ((T_TRAIT) reduce 154) ((T_TRAIT_C) reduce 154) ((T_TRY) reduce 154) ((T_UNSET) reduce 154) ((T_UNSET_CAST) reduce 154) ((T_VARIABLE) reduce 154) ((T_WHILE) reduce 154) ((T_YIELD) reduce 154) ((T_YIELD_FROM) reduce 154) (("[") reduce 154) (("`") reduce 154) (("{") reduce 154) (("}") reduce 154) (("~") reduce 154)) 25384 ((("!") reduce 198) (("\"") reduce 198) (("$") reduce 198) (("(") reduce 198) (("+") reduce 198) (("-") reduce 198) ((";") reduce 198) (("@") reduce 198) ((T_ABSTRACT) reduce 198) ((T_ARRAY) reduce 198) ((T_ARRAY_CAST) reduce 198) ((T_ATTRIBUTE) reduce 198) ((T_BOOL_CAST) reduce 198) ((T_BREAK) reduce 198) ((T_CLASS) reduce 198) ((T_CLASS_C) reduce 198) ((T_CLONE) reduce 198) ((T_CONSTANT_ENCAPSED_STRING) reduce 198) ((T_CONTINUE) reduce 198) ((T_DEC) reduce 198) ((T_DECLARE) reduce 198) ((T_DIR) reduce 198) ((T_DNUMBER) reduce 198) ((T_DO) reduce 198) ((T_DOUBLE_CAST) reduce 198) ((T_ECHO) reduce 198) ((T_EMPTY) reduce 198) ((T_ENUM) reduce 198) ((T_EVAL) reduce 198) ((T_EXIT) reduce 198) ((T_FILE) reduce 198) ((T_FINAL) reduce 198) ((T_FN) reduce 198) ((T_FOR) reduce 198) ((T_FOREACH) reduce 198) ((T_FUNCTION) reduce 198) ((T_FUNC_C) reduce 198) ((T_GLOBAL) reduce 198) ((T_GOTO) reduce 198) ((T_HALT_COMPILER) reduce 198) ((T_IF) reduce 198) ((T_INC) reduce 198) ((T_INCLUDE) reduce 198) ((T_INCLUDE_ONCE) reduce 198) ((T_INLINE_HTML) reduce 198) ((T_INTERFACE) reduce 198) ((T_INT_CAST) reduce 198) ((T_ISSET) reduce 198) ((T_LINE) reduce 198) ((T_LIST) reduce 198) ((T_LNUMBER) reduce 198) ((T_MATCH) reduce 198) ((T_METHOD_C) reduce 198) ((T_NAME_FULLY_QUALIFIED) reduce 198) ((T_NAME_QUALIFIED) reduce 198) ((T_NAME_RELATIVE) reduce 198) ((T_NEW) reduce 198) ((T_NS_C) reduce 198) ((T_OBJECT_CAST) reduce 198) ((T_PRINT) reduce 198) ((T_READONLY) reduce 198) ((T_REQUIRE) reduce 198) ((T_REQUIRE_ONCE) reduce 198) ((T_RETURN) reduce 198) ((T_START_HEREDOC) reduce 198) ((T_STATIC) reduce 198) ((T_STRING) reduce 198) ((T_STRING_CAST) reduce 198) ((T_SWITCH) reduce 198) ((T_THROW) reduce 198) ((T_TRAIT) reduce 198) ((T_TRAIT_C) reduce 198) ((T_TRY) reduce 198) ((T_UNSET) reduce 198) ((T_UNSET_CAST) reduce 198) ((T_VARIABLE) reduce 198) ((T_WHILE) reduce 198) ((T_YIELD) reduce 198) ((T_YIELD_FROM) reduce 198) (("[") reduce 198) (("`") reduce 198) (("{") reduce 198) (("}") reduce 198) (("~") reduce 198)) 25388 ((("!") reduce 241) (("\"") reduce 241) (("$") reduce 241) (("(") reduce 241) (("+") reduce 241) (("-") reduce 241) ((";") reduce 241) (("@") reduce 241) ((T_ABSTRACT) reduce 241) ((T_ARRAY) reduce 241) ((T_ARRAY_CAST) reduce 241) ((T_ATTRIBUTE) reduce 241) ((T_BOOL_CAST) reduce 241) ((T_BREAK) reduce 241) ((T_CLASS) reduce 241) ((T_CLASS_C) reduce 241) ((T_CLONE) reduce 241) ((T_CONSTANT_ENCAPSED_STRING) reduce 241) ((T_CONTINUE) reduce 241) ((T_DEC) reduce 241) ((T_DECLARE) reduce 241) ((T_DIR) reduce 241) ((T_DNUMBER) reduce 241) ((T_DO) reduce 241) ((T_DOUBLE_CAST) reduce 241) ((T_ECHO) reduce 241) ((T_ELSE) reduce 241) ((T_ELSEIF) reduce 241) ((T_EMPTY) reduce 241) ((T_ENUM) reduce 241) ((T_EVAL) reduce 241) ((T_EXIT) reduce 241) ((T_FILE) reduce 241) ((T_FINAL) reduce 241) ((T_FN) reduce 241) ((T_FOR) reduce 241) ((T_FOREACH) reduce 241) ((T_FUNCTION) reduce 241) ((T_FUNC_C) reduce 241) ((T_GLOBAL) reduce 241) ((T_GOTO) reduce 241) ((T_HALT_COMPILER) reduce 241) ((T_IF) reduce 241) ((T_INC) reduce 241) ((T_INCLUDE) reduce 241) ((T_INCLUDE_ONCE) reduce 241) ((T_INLINE_HTML) reduce 241) ((T_INTERFACE) reduce 241) ((T_INT_CAST) reduce 241) ((T_ISSET) reduce 241) ((T_LINE) reduce 241) ((T_LIST) reduce 241) ((T_LNUMBER) reduce 241) ((T_MATCH) reduce 241) ((T_METHOD_C) reduce 241) ((T_NAME_FULLY_QUALIFIED) reduce 241) ((T_NAME_QUALIFIED) reduce 241) ((T_NAME_RELATIVE) reduce 241) ((T_NEW) reduce 241) ((T_NS_C) reduce 241) ((T_OBJECT_CAST) reduce 241) ((T_PRINT) reduce 241) ((T_READONLY) reduce 241) ((T_REQUIRE) reduce 241) ((T_REQUIRE_ONCE) reduce 241) ((T_RETURN) reduce 241) ((T_START_HEREDOC) reduce 241) ((T_STATIC) reduce 241) ((T_STRING) reduce 241) ((T_STRING_CAST) reduce 241) ((T_SWITCH) reduce 241) ((T_THROW) reduce 241) ((T_TRAIT) reduce 241) ((T_TRAIT_C) reduce 241) ((T_TRY) reduce 241) ((T_UNSET) reduce 241) ((T_UNSET_CAST) reduce 241) ((T_VARIABLE) reduce 241) ((T_WHILE) reduce 241) ((T_YIELD) reduce 241) ((T_YIELD_FROM) reduce 241) (("[") reduce 241) (("`") reduce 241) (("{") reduce 241) (("}") reduce 241) (("~") reduce 241)) 25391 ((("!") reduce 144) (("\"") reduce 144) (("$") reduce 144) (("(") reduce 144) (("+") reduce 144) (("-") reduce 144) ((";") reduce 144) (("@") reduce 144) ((T_ABSTRACT) reduce 144) ((T_ARRAY) reduce 144) ((T_ARRAY_CAST) reduce 144) ((T_ATTRIBUTE) reduce 144) ((T_BOOL_CAST) reduce 144) ((T_BREAK) reduce 144) ((T_CLASS) reduce 144) ((T_CLASS_C) reduce 144) ((T_CLONE) reduce 144) ((T_CONSTANT_ENCAPSED_STRING) reduce 144) ((T_CONTINUE) reduce 144) ((T_DEC) reduce 144) ((T_DECLARE) reduce 144) ((T_DIR) reduce 144) ((T_DNUMBER) reduce 144) ((T_DO) reduce 144) ((T_DOUBLE_CAST) reduce 144) ((T_ECHO) reduce 144) ((T_EMPTY) reduce 144) ((T_ENUM) reduce 144) ((T_EVAL) reduce 144) ((T_EXIT) reduce 144) ((T_FILE) reduce 144) ((T_FINAL) reduce 144) ((T_FN) reduce 144) ((T_FOR) reduce 144) ((T_FOREACH) reduce 144) ((T_FUNCTION) reduce 144) ((T_FUNC_C) reduce 144) ((T_GLOBAL) reduce 144) ((T_GOTO) reduce 144) ((T_HALT_COMPILER) reduce 144) ((T_IF) reduce 144) ((T_INC) reduce 144) ((T_INCLUDE) reduce 144) ((T_INCLUDE_ONCE) reduce 144) ((T_INLINE_HTML) reduce 144) ((T_INTERFACE) reduce 144) ((T_INT_CAST) reduce 144) ((T_ISSET) reduce 144) ((T_LINE) reduce 144) ((T_LIST) reduce 144) ((T_LNUMBER) reduce 144) ((T_MATCH) reduce 144) ((T_METHOD_C) reduce 144) ((T_NAME_FULLY_QUALIFIED) reduce 144) ((T_NAME_QUALIFIED) reduce 144) ((T_NAME_RELATIVE) reduce 144) ((T_NEW) reduce 144) ((T_NS_C) reduce 144) ((T_OBJECT_CAST) reduce 144) ((T_PRINT) reduce 144) ((T_READONLY) reduce 144) ((T_REQUIRE) reduce 144) ((T_REQUIRE_ONCE) reduce 144) ((T_RETURN) reduce 144) ((T_START_HEREDOC) reduce 144) ((T_STATIC) reduce 144) ((T_STRING) reduce 144) ((T_STRING_CAST) reduce 144) ((T_SWITCH) reduce 144) ((T_THROW) reduce 144) ((T_TRAIT) reduce 144) ((T_TRAIT_C) reduce 144) ((T_TRY) reduce 144) ((T_UNSET) reduce 144) ((T_UNSET_CAST) reduce 144) ((T_VARIABLE) reduce 144) ((T_WHILE) reduce 144) ((T_YIELD) reduce 144) ((T_YIELD_FROM) reduce 144) (("[") reduce 144) (("`") reduce 144) (("{") reduce 144) (("}") reduce 144) (("~") reduce 144)) 25393 ((("!") reduce 166) (("\"") reduce 166) (("$") reduce 166) (("(") reduce 166) (("+") reduce 166) (("-") reduce 166) ((";") reduce 166) (("@") reduce 166) ((T_ABSTRACT) reduce 166) ((T_ARRAY) reduce 166) ((T_ARRAY_CAST) reduce 166) ((T_ATTRIBUTE) reduce 166) ((T_BOOL_CAST) reduce 166) ((T_BREAK) reduce 166) ((T_CLASS) reduce 166) ((T_CLASS_C) reduce 166) ((T_CLONE) reduce 166) ((T_CONSTANT_ENCAPSED_STRING) reduce 166) ((T_CONTINUE) reduce 166) ((T_DEC) reduce 166) ((T_DECLARE) reduce 166) ((T_DIR) reduce 166) ((T_DNUMBER) reduce 166) ((T_DO) reduce 166) ((T_DOUBLE_CAST) reduce 166) ((T_ECHO) reduce 166) ((T_EMPTY) reduce 166) ((T_ENUM) reduce 166) ((T_EVAL) reduce 166) ((T_EXIT) reduce 166) ((T_FILE) reduce 166) ((T_FINAL) reduce 166) ((T_FN) reduce 166) ((T_FOR) reduce 166) ((T_FOREACH) reduce 166) ((T_FUNCTION) reduce 166) ((T_FUNC_C) reduce 166) ((T_GLOBAL) reduce 166) ((T_GOTO) reduce 166) ((T_HALT_COMPILER) reduce 166) ((T_IF) reduce 166) ((T_INC) reduce 166) ((T_INCLUDE) reduce 166) ((T_INCLUDE_ONCE) reduce 166) ((T_INLINE_HTML) reduce 166) ((T_INTERFACE) reduce 166) ((T_INT_CAST) reduce 166) ((T_ISSET) reduce 166) ((T_LINE) reduce 166) ((T_LIST) reduce 166) ((T_LNUMBER) reduce 166) ((T_MATCH) reduce 166) ((T_METHOD_C) reduce 166) ((T_NAME_FULLY_QUALIFIED) reduce 166) ((T_NAME_QUALIFIED) reduce 166) ((T_NAME_RELATIVE) reduce 166) ((T_NEW) reduce 166) ((T_NS_C) reduce 166) ((T_OBJECT_CAST) reduce 166) ((T_PRINT) reduce 166) ((T_READONLY) reduce 166) ((T_REQUIRE) reduce 166) ((T_REQUIRE_ONCE) reduce 166) ((T_RETURN) reduce 166) ((T_START_HEREDOC) reduce 166) ((T_STATIC) reduce 166) ((T_STRING) reduce 166) ((T_STRING_CAST) reduce 166) ((T_SWITCH) reduce 166) ((T_THROW) reduce 166) ((T_TRAIT) reduce 166) ((T_TRAIT_C) reduce 166) ((T_TRY) reduce 166) ((T_UNSET) reduce 166) ((T_UNSET_CAST) reduce 166) ((T_VARIABLE) reduce 166) ((T_WHILE) reduce 166) ((T_YIELD) reduce 166) ((T_YIELD_FROM) reduce 166) (("[") reduce 166) (("`") reduce 166) (("{") reduce 166) (("}") reduce 166) (("~") reduce 166)) 25395 ((("!") reduce 155) (("\"") reduce 155) (("$") reduce 155) (("(") reduce 155) (("+") reduce 155) (("-") reduce 155) ((";") reduce 155) (("@") reduce 155) ((T_ABSTRACT) reduce 155) ((T_ARRAY) reduce 155) ((T_ARRAY_CAST) reduce 155) ((T_ATTRIBUTE) reduce 155) ((T_BOOL_CAST) reduce 155) ((T_BREAK) reduce 155) ((T_CLASS) reduce 155) ((T_CLASS_C) reduce 155) ((T_CLONE) reduce 155) ((T_CONSTANT_ENCAPSED_STRING) reduce 155) ((T_CONTINUE) reduce 155) ((T_DEC) reduce 155) ((T_DECLARE) reduce 155) ((T_DIR) reduce 155) ((T_DNUMBER) reduce 155) ((T_DO) reduce 155) ((T_DOUBLE_CAST) reduce 155) ((T_ECHO) reduce 155) ((T_EMPTY) reduce 155) ((T_ENUM) reduce 155) ((T_EVAL) reduce 155) ((T_EXIT) reduce 155) ((T_FILE) reduce 155) ((T_FINAL) reduce 155) ((T_FN) reduce 155) ((T_FOR) reduce 155) ((T_FOREACH) reduce 155) ((T_FUNCTION) reduce 155) ((T_FUNC_C) reduce 155) ((T_GLOBAL) reduce 155) ((T_GOTO) reduce 155) ((T_HALT_COMPILER) reduce 155) ((T_IF) reduce 155) ((T_INC) reduce 155) ((T_INCLUDE) reduce 155) ((T_INCLUDE_ONCE) reduce 155) ((T_INLINE_HTML) reduce 155) ((T_INTERFACE) reduce 155) ((T_INT_CAST) reduce 155) ((T_ISSET) reduce 155) ((T_LINE) reduce 155) ((T_LIST) reduce 155) ((T_LNUMBER) reduce 155) ((T_MATCH) reduce 155) ((T_METHOD_C) reduce 155) ((T_NAME_FULLY_QUALIFIED) reduce 155) ((T_NAME_QUALIFIED) reduce 155) ((T_NAME_RELATIVE) reduce 155) ((T_NEW) reduce 155) ((T_NS_C) reduce 155) ((T_OBJECT_CAST) reduce 155) ((T_PRINT) reduce 155) ((T_READONLY) reduce 155) ((T_REQUIRE) reduce 155) ((T_REQUIRE_ONCE) reduce 155) ((T_RETURN) reduce 155) ((T_START_HEREDOC) reduce 155) ((T_STATIC) reduce 155) ((T_STRING) reduce 155) ((T_STRING_CAST) reduce 155) ((T_SWITCH) reduce 155) ((T_THROW) reduce 155) ((T_TRAIT) reduce 155) ((T_TRAIT_C) reduce 155) ((T_TRY) reduce 155) ((T_UNSET) reduce 155) ((T_UNSET_CAST) reduce 155) ((T_VARIABLE) reduce 155) ((T_WHILE) reduce 155) ((T_YIELD) reduce 155) ((T_YIELD_FROM) reduce 155) (("[") reduce 155) (("`") reduce 155) (("{") reduce 155) (("}") reduce 155) (("~") reduce 155)) 25405 ((("!") reduce 162) (("\"") reduce 162) (("$") reduce 162) (("(") reduce 162) (("+") reduce 162) (("-") reduce 162) ((";") reduce 162) (("@") reduce 162) ((T_ABSTRACT) reduce 162) ((T_ARRAY) reduce 162) ((T_ARRAY_CAST) reduce 162) ((T_ATTRIBUTE) reduce 162) ((T_BOOL_CAST) reduce 162) ((T_BREAK) reduce 162) ((T_CLASS) reduce 162) ((T_CLASS_C) reduce 162) ((T_CLONE) reduce 162) ((T_CONSTANT_ENCAPSED_STRING) reduce 162) ((T_CONTINUE) reduce 162) ((T_DEC) reduce 162) ((T_DECLARE) reduce 162) ((T_DIR) reduce 162) ((T_DNUMBER) reduce 162) ((T_DO) reduce 162) ((T_DOUBLE_CAST) reduce 162) ((T_ECHO) reduce 162) ((T_EMPTY) reduce 162) ((T_ENUM) reduce 162) ((T_EVAL) reduce 162) ((T_EXIT) reduce 162) ((T_FILE) reduce 162) ((T_FINAL) reduce 162) ((T_FN) reduce 162) ((T_FOR) reduce 162) ((T_FOREACH) reduce 162) ((T_FUNCTION) reduce 162) ((T_FUNC_C) reduce 162) ((T_GLOBAL) reduce 162) ((T_GOTO) reduce 162) ((T_HALT_COMPILER) reduce 162) ((T_IF) reduce 162) ((T_INC) reduce 162) ((T_INCLUDE) reduce 162) ((T_INCLUDE_ONCE) reduce 162) ((T_INLINE_HTML) reduce 162) ((T_INTERFACE) reduce 162) ((T_INT_CAST) reduce 162) ((T_ISSET) reduce 162) ((T_LINE) reduce 162) ((T_LIST) reduce 162) ((T_LNUMBER) reduce 162) ((T_MATCH) reduce 162) ((T_METHOD_C) reduce 162) ((T_NAME_FULLY_QUALIFIED) reduce 162) ((T_NAME_QUALIFIED) reduce 162) ((T_NAME_RELATIVE) reduce 162) ((T_NEW) reduce 162) ((T_NS_C) reduce 162) ((T_OBJECT_CAST) reduce 162) ((T_PRINT) reduce 162) ((T_READONLY) reduce 162) ((T_REQUIRE) reduce 162) ((T_REQUIRE_ONCE) reduce 162) ((T_RETURN) reduce 162) ((T_START_HEREDOC) reduce 162) ((T_STATIC) reduce 162) ((T_STRING) reduce 162) ((T_STRING_CAST) reduce 162) ((T_SWITCH) reduce 162) ((T_THROW) reduce 162) ((T_TRAIT) reduce 162) ((T_TRAIT_C) reduce 162) ((T_TRY) reduce 162) ((T_UNSET) reduce 162) ((T_UNSET_CAST) reduce 162) ((T_VARIABLE) reduce 162) ((T_WHILE) reduce 162) ((T_YIELD) reduce 162) ((T_YIELD_FROM) reduce 162) (("[") reduce 162) (("`") reduce 162) (("{") reduce 162) (("}") reduce 162) (("~") reduce 162)) 25406 ((("!") reduce 217) (("\"") reduce 217) (("$") reduce 217) (("(") reduce 217) (("+") reduce 217) (("-") reduce 217) ((";") reduce 217) (("@") reduce 217) ((T_ABSTRACT) reduce 217) ((T_ARRAY) reduce 217) ((T_ARRAY_CAST) reduce 217) ((T_ATTRIBUTE) reduce 217) ((T_BOOL_CAST) reduce 217) ((T_BREAK) reduce 217) ((T_CLASS) reduce 217) ((T_CLASS_C) reduce 217) ((T_CLONE) reduce 217) ((T_CONSTANT_ENCAPSED_STRING) reduce 217) ((T_CONTINUE) reduce 217) ((T_DEC) reduce 217) ((T_DECLARE) reduce 217) ((T_DIR) reduce 217) ((T_DNUMBER) reduce 217) ((T_DO) reduce 217) ((T_DOUBLE_CAST) reduce 217) ((T_ECHO) reduce 217) ((T_EMPTY) reduce 217) ((T_ENUM) reduce 217) ((T_EVAL) reduce 217) ((T_EXIT) reduce 217) ((T_FILE) reduce 217) ((T_FINAL) reduce 217) ((T_FN) reduce 217) ((T_FOR) reduce 217) ((T_FOREACH) reduce 217) ((T_FUNCTION) reduce 217) ((T_FUNC_C) reduce 217) ((T_GLOBAL) reduce 217) ((T_GOTO) reduce 217) ((T_HALT_COMPILER) reduce 217) ((T_IF) reduce 217) ((T_INC) reduce 217) ((T_INCLUDE) reduce 217) ((T_INCLUDE_ONCE) reduce 217) ((T_INLINE_HTML) reduce 217) ((T_INTERFACE) reduce 217) ((T_INT_CAST) reduce 217) ((T_ISSET) reduce 217) ((T_LINE) reduce 217) ((T_LIST) reduce 217) ((T_LNUMBER) reduce 217) ((T_MATCH) reduce 217) ((T_METHOD_C) reduce 217) ((T_NAME_FULLY_QUALIFIED) reduce 217) ((T_NAME_QUALIFIED) reduce 217) ((T_NAME_RELATIVE) reduce 217) ((T_NEW) reduce 217) ((T_NS_C) reduce 217) ((T_OBJECT_CAST) reduce 217) ((T_PRINT) reduce 217) ((T_READONLY) reduce 217) ((T_REQUIRE) reduce 217) ((T_REQUIRE_ONCE) reduce 217) ((T_RETURN) reduce 217) ((T_START_HEREDOC) reduce 217) ((T_STATIC) reduce 217) ((T_STRING) reduce 217) ((T_STRING_CAST) reduce 217) ((T_SWITCH) reduce 217) ((T_THROW) reduce 217) ((T_TRAIT) reduce 217) ((T_TRAIT_C) reduce 217) ((T_TRY) reduce 217) ((T_UNSET) reduce 217) ((T_UNSET_CAST) reduce 217) ((T_VARIABLE) reduce 217) ((T_WHILE) reduce 217) ((T_YIELD) reduce 217) ((T_YIELD_FROM) reduce 217) (("[") reduce 217) (("`") reduce 217) (("{") reduce 217) (("}") reduce 217) (("~") reduce 217)) 25409 ((("!") reduce 218) (("\"") reduce 218) (("$") reduce 218) (("(") reduce 218) (("+") reduce 218) (("-") reduce 218) ((";") reduce 218) (("@") reduce 218) ((T_ABSTRACT) reduce 218) ((T_ARRAY) reduce 218) ((T_ARRAY_CAST) reduce 218) ((T_ATTRIBUTE) reduce 218) ((T_BOOL_CAST) reduce 218) ((T_BREAK) reduce 218) ((T_CLASS) reduce 218) ((T_CLASS_C) reduce 218) ((T_CLONE) reduce 218) ((T_CONSTANT_ENCAPSED_STRING) reduce 218) ((T_CONTINUE) reduce 218) ((T_DEC) reduce 218) ((T_DECLARE) reduce 218) ((T_DIR) reduce 218) ((T_DNUMBER) reduce 218) ((T_DO) reduce 218) ((T_DOUBLE_CAST) reduce 218) ((T_ECHO) reduce 218) ((T_EMPTY) reduce 218) ((T_ENUM) reduce 218) ((T_EVAL) reduce 218) ((T_EXIT) reduce 218) ((T_FILE) reduce 218) ((T_FINAL) reduce 218) ((T_FN) reduce 218) ((T_FOR) reduce 218) ((T_FOREACH) reduce 218) ((T_FUNCTION) reduce 218) ((T_FUNC_C) reduce 218) ((T_GLOBAL) reduce 218) ((T_GOTO) reduce 218) ((T_HALT_COMPILER) reduce 218) ((T_IF) reduce 218) ((T_INC) reduce 218) ((T_INCLUDE) reduce 218) ((T_INCLUDE_ONCE) reduce 218) ((T_INLINE_HTML) reduce 218) ((T_INTERFACE) reduce 218) ((T_INT_CAST) reduce 218) ((T_ISSET) reduce 218) ((T_LINE) reduce 218) ((T_LIST) reduce 218) ((T_LNUMBER) reduce 218) ((T_MATCH) reduce 218) ((T_METHOD_C) reduce 218) ((T_NAME_FULLY_QUALIFIED) reduce 218) ((T_NAME_QUALIFIED) reduce 218) ((T_NAME_RELATIVE) reduce 218) ((T_NEW) reduce 218) ((T_NS_C) reduce 218) ((T_OBJECT_CAST) reduce 218) ((T_PRINT) reduce 218) ((T_READONLY) reduce 218) ((T_REQUIRE) reduce 218) ((T_REQUIRE_ONCE) reduce 218) ((T_RETURN) reduce 218) ((T_START_HEREDOC) reduce 218) ((T_STATIC) reduce 218) ((T_STRING) reduce 218) ((T_STRING_CAST) reduce 218) ((T_SWITCH) reduce 218) ((T_THROW) reduce 218) ((T_TRAIT) reduce 218) ((T_TRAIT_C) reduce 218) ((T_TRY) reduce 218) ((T_UNSET) reduce 218) ((T_UNSET_CAST) reduce 218) ((T_VARIABLE) reduce 218) ((T_WHILE) reduce 218) ((T_YIELD) reduce 218) ((T_YIELD_FROM) reduce 218) (("[") reduce 218) (("`") reduce 218) (("{") reduce 218) (("}") reduce 218) (("~") reduce 218)) 25410 ((("!") reduce 161) (("\"") reduce 161) (("$") reduce 161) (("(") reduce 161) (("+") reduce 161) (("-") reduce 161) ((";") reduce 161) (("@") reduce 161) ((T_ABSTRACT) reduce 161) ((T_ARRAY) reduce 161) ((T_ARRAY_CAST) reduce 161) ((T_ATTRIBUTE) reduce 161) ((T_BOOL_CAST) reduce 161) ((T_BREAK) reduce 161) ((T_CLASS) reduce 161) ((T_CLASS_C) reduce 161) ((T_CLONE) reduce 161) ((T_CONSTANT_ENCAPSED_STRING) reduce 161) ((T_CONTINUE) reduce 161) ((T_DEC) reduce 161) ((T_DECLARE) reduce 161) ((T_DIR) reduce 161) ((T_DNUMBER) reduce 161) ((T_DO) reduce 161) ((T_DOUBLE_CAST) reduce 161) ((T_ECHO) reduce 161) ((T_EMPTY) reduce 161) ((T_ENUM) reduce 161) ((T_EVAL) reduce 161) ((T_EXIT) reduce 161) ((T_FILE) reduce 161) ((T_FINAL) reduce 161) ((T_FN) reduce 161) ((T_FOR) reduce 161) ((T_FOREACH) reduce 161) ((T_FUNCTION) reduce 161) ((T_FUNC_C) reduce 161) ((T_GLOBAL) reduce 161) ((T_GOTO) reduce 161) ((T_HALT_COMPILER) reduce 161) ((T_IF) reduce 161) ((T_INC) reduce 161) ((T_INCLUDE) reduce 161) ((T_INCLUDE_ONCE) reduce 161) ((T_INLINE_HTML) reduce 161) ((T_INTERFACE) reduce 161) ((T_INT_CAST) reduce 161) ((T_ISSET) reduce 161) ((T_LINE) reduce 161) ((T_LIST) reduce 161) ((T_LNUMBER) reduce 161) ((T_MATCH) reduce 161) ((T_METHOD_C) reduce 161) ((T_NAME_FULLY_QUALIFIED) reduce 161) ((T_NAME_QUALIFIED) reduce 161) ((T_NAME_RELATIVE) reduce 161) ((T_NEW) reduce 161) ((T_NS_C) reduce 161) ((T_OBJECT_CAST) reduce 161) ((T_PRINT) reduce 161) ((T_READONLY) reduce 161) ((T_REQUIRE) reduce 161) ((T_REQUIRE_ONCE) reduce 161) ((T_RETURN) reduce 161) ((T_START_HEREDOC) reduce 161) ((T_STATIC) reduce 161) ((T_STRING) reduce 161) ((T_STRING_CAST) reduce 161) ((T_SWITCH) reduce 161) ((T_THROW) reduce 161) ((T_TRAIT) reduce 161) ((T_TRAIT_C) reduce 161) ((T_TRY) reduce 161) ((T_UNSET) reduce 161) ((T_UNSET_CAST) reduce 161) ((T_VARIABLE) reduce 161) ((T_WHILE) reduce 161) ((T_YIELD) reduce 161) ((T_YIELD_FROM) reduce 161) (("[") reduce 161) (("`") reduce 161) (("{") reduce 161) (("}") reduce 161) (("~") reduce 161)) 25419 ((("!") reduce 150) (("\"") reduce 150) (("$") reduce 150) (("(") reduce 150) (("+") reduce 150) (("-") reduce 150) ((";") reduce 150) (("@") reduce 150) ((T_ABSTRACT) reduce 150) ((T_ARRAY) reduce 150) ((T_ARRAY_CAST) reduce 150) ((T_ATTRIBUTE) reduce 150) ((T_BOOL_CAST) reduce 150) ((T_BREAK) reduce 150) ((T_CLASS) reduce 150) ((T_CLASS_C) reduce 150) ((T_CLONE) reduce 150) ((T_CONSTANT_ENCAPSED_STRING) reduce 150) ((T_CONTINUE) reduce 150) ((T_DEC) reduce 150) ((T_DECLARE) reduce 150) ((T_DIR) reduce 150) ((T_DNUMBER) reduce 150) ((T_DO) reduce 150) ((T_DOUBLE_CAST) reduce 150) ((T_ECHO) reduce 150) ((T_EMPTY) reduce 150) ((T_ENUM) reduce 150) ((T_EVAL) reduce 150) ((T_EXIT) reduce 150) ((T_FILE) reduce 150) ((T_FINAL) reduce 150) ((T_FN) reduce 150) ((T_FOR) reduce 150) ((T_FOREACH) reduce 150) ((T_FUNCTION) reduce 150) ((T_FUNC_C) reduce 150) ((T_GLOBAL) reduce 150) ((T_GOTO) reduce 150) ((T_HALT_COMPILER) reduce 150) ((T_IF) reduce 150) ((T_INC) reduce 150) ((T_INCLUDE) reduce 150) ((T_INCLUDE_ONCE) reduce 150) ((T_INLINE_HTML) reduce 150) ((T_INTERFACE) reduce 150) ((T_INT_CAST) reduce 150) ((T_ISSET) reduce 150) ((T_LINE) reduce 150) ((T_LIST) reduce 150) ((T_LNUMBER) reduce 150) ((T_MATCH) reduce 150) ((T_METHOD_C) reduce 150) ((T_NAME_FULLY_QUALIFIED) reduce 150) ((T_NAME_QUALIFIED) reduce 150) ((T_NAME_RELATIVE) reduce 150) ((T_NEW) reduce 150) ((T_NS_C) reduce 150) ((T_OBJECT_CAST) reduce 150) ((T_PRINT) reduce 150) ((T_READONLY) reduce 150) ((T_REQUIRE) reduce 150) ((T_REQUIRE_ONCE) reduce 150) ((T_RETURN) reduce 150) ((T_START_HEREDOC) reduce 150) ((T_STATIC) reduce 150) ((T_STRING) reduce 150) ((T_STRING_CAST) reduce 150) ((T_SWITCH) reduce 150) ((T_THROW) reduce 150) ((T_TRAIT) reduce 150) ((T_TRAIT_C) reduce 150) ((T_TRY) reduce 150) ((T_UNSET) reduce 150) ((T_UNSET_CAST) reduce 150) ((T_VARIABLE) reduce 150) ((T_WHILE) reduce 150) ((T_YIELD) reduce 150) ((T_YIELD_FROM) reduce 150) (("[") reduce 150) (("`") reduce 150) (("{") reduce 150) (("}") reduce 150) (("~") reduce 150)) 25420 ((("!") reduce 215) (("\"") reduce 215) (("$") reduce 215) (("(") reduce 215) (("+") reduce 215) (("-") reduce 215) ((";") reduce 215) (("@") reduce 215) ((T_ABSTRACT) reduce 215) ((T_ARRAY) reduce 215) ((T_ARRAY_CAST) reduce 215) ((T_ATTRIBUTE) reduce 215) ((T_BOOL_CAST) reduce 215) ((T_BREAK) reduce 215) ((T_CLASS) reduce 215) ((T_CLASS_C) reduce 215) ((T_CLONE) reduce 215) ((T_CONSTANT_ENCAPSED_STRING) reduce 215) ((T_CONTINUE) reduce 215) ((T_DEC) reduce 215) ((T_DECLARE) reduce 215) ((T_DIR) reduce 215) ((T_DNUMBER) reduce 215) ((T_DO) reduce 215) ((T_DOUBLE_CAST) reduce 215) ((T_ECHO) reduce 215) ((T_EMPTY) reduce 215) ((T_ENUM) reduce 215) ((T_EVAL) reduce 215) ((T_EXIT) reduce 215) ((T_FILE) reduce 215) ((T_FINAL) reduce 215) ((T_FN) reduce 215) ((T_FOR) reduce 215) ((T_FOREACH) reduce 215) ((T_FUNCTION) reduce 215) ((T_FUNC_C) reduce 215) ((T_GLOBAL) reduce 215) ((T_GOTO) reduce 215) ((T_HALT_COMPILER) reduce 215) ((T_IF) reduce 215) ((T_INC) reduce 215) ((T_INCLUDE) reduce 215) ((T_INCLUDE_ONCE) reduce 215) ((T_INLINE_HTML) reduce 215) ((T_INTERFACE) reduce 215) ((T_INT_CAST) reduce 215) ((T_ISSET) reduce 215) ((T_LINE) reduce 215) ((T_LIST) reduce 215) ((T_LNUMBER) reduce 215) ((T_MATCH) reduce 215) ((T_METHOD_C) reduce 215) ((T_NAME_FULLY_QUALIFIED) reduce 215) ((T_NAME_QUALIFIED) reduce 215) ((T_NAME_RELATIVE) reduce 215) ((T_NEW) reduce 215) ((T_NS_C) reduce 215) ((T_OBJECT_CAST) reduce 215) ((T_PRINT) reduce 215) ((T_READONLY) reduce 215) ((T_REQUIRE) reduce 215) ((T_REQUIRE_ONCE) reduce 215) ((T_RETURN) reduce 215) ((T_START_HEREDOC) reduce 215) ((T_STATIC) reduce 215) ((T_STRING) reduce 215) ((T_STRING_CAST) reduce 215) ((T_SWITCH) reduce 215) ((T_THROW) reduce 215) ((T_TRAIT) reduce 215) ((T_TRAIT_C) reduce 215) ((T_TRY) reduce 215) ((T_UNSET) reduce 215) ((T_UNSET_CAST) reduce 215) ((T_VARIABLE) reduce 215) ((T_WHILE) reduce 215) ((T_YIELD) reduce 215) ((T_YIELD_FROM) reduce 215) (("[") reduce 215) (("`") reduce 215) (("{") reduce 215) (("}") reduce 215) (("~") reduce 215)) 25423 ((("!") reduce 216) (("\"") reduce 216) (("$") reduce 216) (("(") reduce 216) (("+") reduce 216) (("-") reduce 216) ((";") reduce 216) (("@") reduce 216) ((T_ABSTRACT) reduce 216) ((T_ARRAY) reduce 216) ((T_ARRAY_CAST) reduce 216) ((T_ATTRIBUTE) reduce 216) ((T_BOOL_CAST) reduce 216) ((T_BREAK) reduce 216) ((T_CLASS) reduce 216) ((T_CLASS_C) reduce 216) ((T_CLONE) reduce 216) ((T_CONSTANT_ENCAPSED_STRING) reduce 216) ((T_CONTINUE) reduce 216) ((T_DEC) reduce 216) ((T_DECLARE) reduce 216) ((T_DIR) reduce 216) ((T_DNUMBER) reduce 216) ((T_DO) reduce 216) ((T_DOUBLE_CAST) reduce 216) ((T_ECHO) reduce 216) ((T_EMPTY) reduce 216) ((T_ENUM) reduce 216) ((T_EVAL) reduce 216) ((T_EXIT) reduce 216) ((T_FILE) reduce 216) ((T_FINAL) reduce 216) ((T_FN) reduce 216) ((T_FOR) reduce 216) ((T_FOREACH) reduce 216) ((T_FUNCTION) reduce 216) ((T_FUNC_C) reduce 216) ((T_GLOBAL) reduce 216) ((T_GOTO) reduce 216) ((T_HALT_COMPILER) reduce 216) ((T_IF) reduce 216) ((T_INC) reduce 216) ((T_INCLUDE) reduce 216) ((T_INCLUDE_ONCE) reduce 216) ((T_INLINE_HTML) reduce 216) ((T_INTERFACE) reduce 216) ((T_INT_CAST) reduce 216) ((T_ISSET) reduce 216) ((T_LINE) reduce 216) ((T_LIST) reduce 216) ((T_LNUMBER) reduce 216) ((T_MATCH) reduce 216) ((T_METHOD_C) reduce 216) ((T_NAME_FULLY_QUALIFIED) reduce 216) ((T_NAME_QUALIFIED) reduce 216) ((T_NAME_RELATIVE) reduce 216) ((T_NEW) reduce 216) ((T_NS_C) reduce 216) ((T_OBJECT_CAST) reduce 216) ((T_PRINT) reduce 216) ((T_READONLY) reduce 216) ((T_REQUIRE) reduce 216) ((T_REQUIRE_ONCE) reduce 216) ((T_RETURN) reduce 216) ((T_START_HEREDOC) reduce 216) ((T_STATIC) reduce 216) ((T_STRING) reduce 216) ((T_STRING_CAST) reduce 216) ((T_SWITCH) reduce 216) ((T_THROW) reduce 216) ((T_TRAIT) reduce 216) ((T_TRAIT_C) reduce 216) ((T_TRY) reduce 216) ((T_UNSET) reduce 216) ((T_UNSET_CAST) reduce 216) ((T_VARIABLE) reduce 216) ((T_WHILE) reduce 216) ((T_YIELD) reduce 216) ((T_YIELD_FROM) reduce 216) (("[") reduce 216) (("`") reduce 216) (("{") reduce 216) (("}") reduce 216) (("~") reduce 216)) 25430 ((("!") reduce 199) (("\"") reduce 199) (("$") reduce 199) (("(") reduce 199) (("+") reduce 199) (("-") reduce 199) ((";") reduce 199) (("@") reduce 199) ((T_ABSTRACT) reduce 199) ((T_ARRAY) reduce 199) ((T_ARRAY_CAST) reduce 199) ((T_ATTRIBUTE) reduce 199) ((T_BOOL_CAST) reduce 199) ((T_BREAK) reduce 199) ((T_CLASS) reduce 199) ((T_CLASS_C) reduce 199) ((T_CLONE) reduce 199) ((T_CONSTANT_ENCAPSED_STRING) reduce 199) ((T_CONTINUE) reduce 199) ((T_DEC) reduce 199) ((T_DECLARE) reduce 199) ((T_DIR) reduce 199) ((T_DNUMBER) reduce 199) ((T_DO) reduce 199) ((T_DOUBLE_CAST) reduce 199) ((T_ECHO) reduce 199) ((T_EMPTY) reduce 199) ((T_ENUM) reduce 199) ((T_EVAL) reduce 199) ((T_EXIT) reduce 199) ((T_FILE) reduce 199) ((T_FINAL) reduce 199) ((T_FN) reduce 199) ((T_FOR) reduce 199) ((T_FOREACH) reduce 199) ((T_FUNCTION) reduce 199) ((T_FUNC_C) reduce 199) ((T_GLOBAL) reduce 199) ((T_GOTO) reduce 199) ((T_HALT_COMPILER) reduce 199) ((T_IF) reduce 199) ((T_INC) reduce 199) ((T_INCLUDE) reduce 199) ((T_INCLUDE_ONCE) reduce 199) ((T_INLINE_HTML) reduce 199) ((T_INTERFACE) reduce 199) ((T_INT_CAST) reduce 199) ((T_ISSET) reduce 199) ((T_LINE) reduce 199) ((T_LIST) reduce 199) ((T_LNUMBER) reduce 199) ((T_MATCH) reduce 199) ((T_METHOD_C) reduce 199) ((T_NAME_FULLY_QUALIFIED) reduce 199) ((T_NAME_QUALIFIED) reduce 199) ((T_NAME_RELATIVE) reduce 199) ((T_NEW) reduce 199) ((T_NS_C) reduce 199) ((T_OBJECT_CAST) reduce 199) ((T_PRINT) reduce 199) ((T_READONLY) reduce 199) ((T_REQUIRE) reduce 199) ((T_REQUIRE_ONCE) reduce 199) ((T_RETURN) reduce 199) ((T_START_HEREDOC) reduce 199) ((T_STATIC) reduce 199) ((T_STRING) reduce 199) ((T_STRING_CAST) reduce 199) ((T_SWITCH) reduce 199) ((T_THROW) reduce 199) ((T_TRAIT) reduce 199) ((T_TRAIT_C) reduce 199) ((T_TRY) reduce 199) ((T_UNSET) reduce 199) ((T_UNSET_CAST) reduce 199) ((T_VARIABLE) reduce 199) ((T_WHILE) reduce 199) ((T_YIELD) reduce 199) ((T_YIELD_FROM) reduce 199) (("[") reduce 199) (("`") reduce 199) (("{") reduce 199) (("}") reduce 199) (("~") reduce 199)) 25432 ((("!") reduce 157) (("\"") reduce 157) (("$") reduce 157) (("(") reduce 157) (("+") reduce 157) (("-") reduce 157) ((";") reduce 157) (("@") reduce 157) ((T_ABSTRACT) reduce 157) ((T_ARRAY) reduce 157) ((T_ARRAY_CAST) reduce 157) ((T_ATTRIBUTE) reduce 157) ((T_BOOL_CAST) reduce 157) ((T_BREAK) reduce 157) ((T_CLASS) reduce 157) ((T_CLASS_C) reduce 157) ((T_CLONE) reduce 157) ((T_CONSTANT_ENCAPSED_STRING) reduce 157) ((T_CONTINUE) reduce 157) ((T_DEC) reduce 157) ((T_DECLARE) reduce 157) ((T_DIR) reduce 157) ((T_DNUMBER) reduce 157) ((T_DO) reduce 157) ((T_DOUBLE_CAST) reduce 157) ((T_ECHO) reduce 157) ((T_EMPTY) reduce 157) ((T_ENUM) reduce 157) ((T_EVAL) reduce 157) ((T_EXIT) reduce 157) ((T_FILE) reduce 157) ((T_FINAL) reduce 157) ((T_FN) reduce 157) ((T_FOR) reduce 157) ((T_FOREACH) reduce 157) ((T_FUNCTION) reduce 157) ((T_FUNC_C) reduce 157) ((T_GLOBAL) reduce 157) ((T_GOTO) reduce 157) ((T_HALT_COMPILER) reduce 157) ((T_IF) reduce 157) ((T_INC) reduce 157) ((T_INCLUDE) reduce 157) ((T_INCLUDE_ONCE) reduce 157) ((T_INLINE_HTML) reduce 157) ((T_INTERFACE) reduce 157) ((T_INT_CAST) reduce 157) ((T_ISSET) reduce 157) ((T_LINE) reduce 157) ((T_LIST) reduce 157) ((T_LNUMBER) reduce 157) ((T_MATCH) reduce 157) ((T_METHOD_C) reduce 157) ((T_NAME_FULLY_QUALIFIED) reduce 157) ((T_NAME_QUALIFIED) reduce 157) ((T_NAME_RELATIVE) reduce 157) ((T_NEW) reduce 157) ((T_NS_C) reduce 157) ((T_OBJECT_CAST) reduce 157) ((T_PRINT) reduce 157) ((T_READONLY) reduce 157) ((T_REQUIRE) reduce 157) ((T_REQUIRE_ONCE) reduce 157) ((T_RETURN) reduce 157) ((T_START_HEREDOC) reduce 157) ((T_STATIC) reduce 157) ((T_STRING) reduce 157) ((T_STRING_CAST) reduce 157) ((T_SWITCH) reduce 157) ((T_THROW) reduce 157) ((T_TRAIT) reduce 157) ((T_TRAIT_C) reduce 157) ((T_TRY) reduce 157) ((T_UNSET) reduce 157) ((T_UNSET_CAST) reduce 157) ((T_VARIABLE) reduce 157) ((T_WHILE) reduce 157) ((T_YIELD) reduce 157) ((T_YIELD_FROM) reduce 157) (("[") reduce 157) (("`") reduce 157) (("{") reduce 157) (("}") reduce 157) (("~") reduce 157)) 25438 ((("!") reduce 149) (("\"") reduce 149) (("$") reduce 149) (("(") reduce 149) (("+") reduce 149) (("-") reduce 149) ((";") reduce 149) (("@") reduce 149) ((T_ABSTRACT) reduce 149) ((T_ARRAY) reduce 149) ((T_ARRAY_CAST) reduce 149) ((T_ATTRIBUTE) reduce 149) ((T_BOOL_CAST) reduce 149) ((T_BREAK) reduce 149) ((T_CLASS) reduce 149) ((T_CLASS_C) reduce 149) ((T_CLONE) reduce 149) ((T_CONSTANT_ENCAPSED_STRING) reduce 149) ((T_CONTINUE) reduce 149) ((T_DEC) reduce 149) ((T_DECLARE) reduce 149) ((T_DIR) reduce 149) ((T_DNUMBER) reduce 149) ((T_DO) reduce 149) ((T_DOUBLE_CAST) reduce 149) ((T_ECHO) reduce 149) ((T_EMPTY) reduce 149) ((T_ENUM) reduce 149) ((T_EVAL) reduce 149) ((T_EXIT) reduce 149) ((T_FILE) reduce 149) ((T_FINAL) reduce 149) ((T_FN) reduce 149) ((T_FOR) reduce 149) ((T_FOREACH) reduce 149) ((T_FUNCTION) reduce 149) ((T_FUNC_C) reduce 149) ((T_GLOBAL) reduce 149) ((T_GOTO) reduce 149) ((T_HALT_COMPILER) reduce 149) ((T_IF) reduce 149) ((T_INC) reduce 149) ((T_INCLUDE) reduce 149) ((T_INCLUDE_ONCE) reduce 149) ((T_INLINE_HTML) reduce 149) ((T_INTERFACE) reduce 149) ((T_INT_CAST) reduce 149) ((T_ISSET) reduce 149) ((T_LINE) reduce 149) ((T_LIST) reduce 149) ((T_LNUMBER) reduce 149) ((T_MATCH) reduce 149) ((T_METHOD_C) reduce 149) ((T_NAME_FULLY_QUALIFIED) reduce 149) ((T_NAME_QUALIFIED) reduce 149) ((T_NAME_RELATIVE) reduce 149) ((T_NEW) reduce 149) ((T_NS_C) reduce 149) ((T_OBJECT_CAST) reduce 149) ((T_PRINT) reduce 149) ((T_READONLY) reduce 149) ((T_REQUIRE) reduce 149) ((T_REQUIRE_ONCE) reduce 149) ((T_RETURN) reduce 149) ((T_START_HEREDOC) reduce 149) ((T_STATIC) reduce 149) ((T_STRING) reduce 149) ((T_STRING_CAST) reduce 149) ((T_SWITCH) reduce 149) ((T_THROW) reduce 149) ((T_TRAIT) reduce 149) ((T_TRAIT_C) reduce 149) ((T_TRY) reduce 149) ((T_UNSET) reduce 149) ((T_UNSET_CAST) reduce 149) ((T_VARIABLE) reduce 149) ((T_WHILE) reduce 149) ((T_YIELD) reduce 149) ((T_YIELD_FROM) reduce 149) (("[") reduce 149) (("`") reduce 149) (("{") reduce 149) (("}") reduce 149) (("~") reduce 149)) 25443 ((("!") reduce 163) (("\"") reduce 163) (("$") reduce 163) (("(") reduce 163) (("+") reduce 163) (("-") reduce 163) ((";") reduce 163) (("@") reduce 163) ((T_ABSTRACT) reduce 163) ((T_ARRAY) reduce 163) ((T_ARRAY_CAST) reduce 163) ((T_ATTRIBUTE) reduce 163) ((T_BOOL_CAST) reduce 163) ((T_BREAK) reduce 163) ((T_CLASS) reduce 163) ((T_CLASS_C) reduce 163) ((T_CLONE) reduce 163) ((T_CONSTANT_ENCAPSED_STRING) reduce 163) ((T_CONTINUE) reduce 163) ((T_DEC) reduce 163) ((T_DECLARE) reduce 163) ((T_DIR) reduce 163) ((T_DNUMBER) reduce 163) ((T_DO) reduce 163) ((T_DOUBLE_CAST) reduce 163) ((T_ECHO) reduce 163) ((T_EMPTY) reduce 163) ((T_ENUM) reduce 163) ((T_EVAL) reduce 163) ((T_EXIT) reduce 163) ((T_FILE) reduce 163) ((T_FINAL) reduce 163) ((T_FN) reduce 163) ((T_FOR) reduce 163) ((T_FOREACH) reduce 163) ((T_FUNCTION) reduce 163) ((T_FUNC_C) reduce 163) ((T_GLOBAL) reduce 163) ((T_GOTO) reduce 163) ((T_HALT_COMPILER) reduce 163) ((T_IF) reduce 163) ((T_INC) reduce 163) ((T_INCLUDE) reduce 163) ((T_INCLUDE_ONCE) reduce 163) ((T_INLINE_HTML) reduce 163) ((T_INTERFACE) reduce 163) ((T_INT_CAST) reduce 163) ((T_ISSET) reduce 163) ((T_LINE) reduce 163) ((T_LIST) reduce 163) ((T_LNUMBER) reduce 163) ((T_MATCH) reduce 163) ((T_METHOD_C) reduce 163) ((T_NAME_FULLY_QUALIFIED) reduce 163) ((T_NAME_QUALIFIED) reduce 163) ((T_NAME_RELATIVE) reduce 163) ((T_NEW) reduce 163) ((T_NS_C) reduce 163) ((T_OBJECT_CAST) reduce 163) ((T_PRINT) reduce 163) ((T_READONLY) reduce 163) ((T_REQUIRE) reduce 163) ((T_REQUIRE_ONCE) reduce 163) ((T_RETURN) reduce 163) ((T_START_HEREDOC) reduce 163) ((T_STATIC) reduce 163) ((T_STRING) reduce 163) ((T_STRING_CAST) reduce 163) ((T_SWITCH) reduce 163) ((T_THROW) reduce 163) ((T_TRAIT) reduce 163) ((T_TRAIT_C) reduce 163) ((T_TRY) reduce 163) ((T_UNSET) reduce 163) ((T_UNSET_CAST) reduce 163) ((T_VARIABLE) reduce 163) ((T_WHILE) reduce 163) ((T_YIELD) reduce 163) ((T_YIELD_FROM) reduce 163) (("[") reduce 163) (("`") reduce 163) (("{") reduce 163) (("}") reduce 163) (("~") reduce 163)) 25444 ((("!") reduce 219) (("\"") reduce 219) (("$") reduce 219) (("(") reduce 219) (("+") reduce 219) (("-") reduce 219) ((";") reduce 219) (("@") reduce 219) ((T_ABSTRACT) reduce 219) ((T_ARRAY) reduce 219) ((T_ARRAY_CAST) reduce 219) ((T_ATTRIBUTE) reduce 219) ((T_BOOL_CAST) reduce 219) ((T_BREAK) reduce 219) ((T_CLASS) reduce 219) ((T_CLASS_C) reduce 219) ((T_CLONE) reduce 219) ((T_CONSTANT_ENCAPSED_STRING) reduce 219) ((T_CONTINUE) reduce 219) ((T_DEC) reduce 219) ((T_DECLARE) reduce 219) ((T_DIR) reduce 219) ((T_DNUMBER) reduce 219) ((T_DO) reduce 219) ((T_DOUBLE_CAST) reduce 219) ((T_ECHO) reduce 219) ((T_EMPTY) reduce 219) ((T_ENUM) reduce 219) ((T_EVAL) reduce 219) ((T_EXIT) reduce 219) ((T_FILE) reduce 219) ((T_FINAL) reduce 219) ((T_FN) reduce 219) ((T_FOR) reduce 219) ((T_FOREACH) reduce 219) ((T_FUNCTION) reduce 219) ((T_FUNC_C) reduce 219) ((T_GLOBAL) reduce 219) ((T_GOTO) reduce 219) ((T_HALT_COMPILER) reduce 219) ((T_IF) reduce 219) ((T_INC) reduce 219) ((T_INCLUDE) reduce 219) ((T_INCLUDE_ONCE) reduce 219) ((T_INLINE_HTML) reduce 219) ((T_INTERFACE) reduce 219) ((T_INT_CAST) reduce 219) ((T_ISSET) reduce 219) ((T_LINE) reduce 219) ((T_LIST) reduce 219) ((T_LNUMBER) reduce 219) ((T_MATCH) reduce 219) ((T_METHOD_C) reduce 219) ((T_NAME_FULLY_QUALIFIED) reduce 219) ((T_NAME_QUALIFIED) reduce 219) ((T_NAME_RELATIVE) reduce 219) ((T_NEW) reduce 219) ((T_NS_C) reduce 219) ((T_OBJECT_CAST) reduce 219) ((T_PRINT) reduce 219) ((T_READONLY) reduce 219) ((T_REQUIRE) reduce 219) ((T_REQUIRE_ONCE) reduce 219) ((T_RETURN) reduce 219) ((T_START_HEREDOC) reduce 219) ((T_STATIC) reduce 219) ((T_STRING) reduce 219) ((T_STRING_CAST) reduce 219) ((T_SWITCH) reduce 219) ((T_THROW) reduce 219) ((T_TRAIT) reduce 219) ((T_TRAIT_C) reduce 219) ((T_TRY) reduce 219) ((T_UNSET) reduce 219) ((T_UNSET_CAST) reduce 219) ((T_VARIABLE) reduce 219) ((T_WHILE) reduce 219) ((T_YIELD) reduce 219) ((T_YIELD_FROM) reduce 219) (("[") reduce 219) (("`") reduce 219) (("{") reduce 219) (("}") reduce 219) (("~") reduce 219)) 25447 ((("!") reduce 220) (("\"") reduce 220) (("$") reduce 220) (("(") reduce 220) (("+") reduce 220) (("-") reduce 220) ((";") reduce 220) (("@") reduce 220) ((T_ABSTRACT) reduce 220) ((T_ARRAY) reduce 220) ((T_ARRAY_CAST) reduce 220) ((T_ATTRIBUTE) reduce 220) ((T_BOOL_CAST) reduce 220) ((T_BREAK) reduce 220) ((T_CLASS) reduce 220) ((T_CLASS_C) reduce 220) ((T_CLONE) reduce 220) ((T_CONSTANT_ENCAPSED_STRING) reduce 220) ((T_CONTINUE) reduce 220) ((T_DEC) reduce 220) ((T_DECLARE) reduce 220) ((T_DIR) reduce 220) ((T_DNUMBER) reduce 220) ((T_DO) reduce 220) ((T_DOUBLE_CAST) reduce 220) ((T_ECHO) reduce 220) ((T_EMPTY) reduce 220) ((T_ENUM) reduce 220) ((T_EVAL) reduce 220) ((T_EXIT) reduce 220) ((T_FILE) reduce 220) ((T_FINAL) reduce 220) ((T_FN) reduce 220) ((T_FOR) reduce 220) ((T_FOREACH) reduce 220) ((T_FUNCTION) reduce 220) ((T_FUNC_C) reduce 220) ((T_GLOBAL) reduce 220) ((T_GOTO) reduce 220) ((T_HALT_COMPILER) reduce 220) ((T_IF) reduce 220) ((T_INC) reduce 220) ((T_INCLUDE) reduce 220) ((T_INCLUDE_ONCE) reduce 220) ((T_INLINE_HTML) reduce 220) ((T_INTERFACE) reduce 220) ((T_INT_CAST) reduce 220) ((T_ISSET) reduce 220) ((T_LINE) reduce 220) ((T_LIST) reduce 220) ((T_LNUMBER) reduce 220) ((T_MATCH) reduce 220) ((T_METHOD_C) reduce 220) ((T_NAME_FULLY_QUALIFIED) reduce 220) ((T_NAME_QUALIFIED) reduce 220) ((T_NAME_RELATIVE) reduce 220) ((T_NEW) reduce 220) ((T_NS_C) reduce 220) ((T_OBJECT_CAST) reduce 220) ((T_PRINT) reduce 220) ((T_READONLY) reduce 220) ((T_REQUIRE) reduce 220) ((T_REQUIRE_ONCE) reduce 220) ((T_RETURN) reduce 220) ((T_START_HEREDOC) reduce 220) ((T_STATIC) reduce 220) ((T_STRING) reduce 220) ((T_STRING_CAST) reduce 220) ((T_SWITCH) reduce 220) ((T_THROW) reduce 220) ((T_TRAIT) reduce 220) ((T_TRAIT_C) reduce 220) ((T_TRY) reduce 220) ((T_UNSET) reduce 220) ((T_UNSET_CAST) reduce 220) ((T_VARIABLE) reduce 220) ((T_WHILE) reduce 220) ((T_YIELD) reduce 220) ((T_YIELD_FROM) reduce 220) (("[") reduce 220) (("`") reduce 220) (("{") reduce 220) (("}") reduce 220) (("~") reduce 220)) 25449 ((("!") reduce 153) (("\"") reduce 153) (("$") reduce 153) (("(") reduce 153) (("+") reduce 153) (("-") reduce 153) ((";") reduce 153) (("@") reduce 153) ((T_ABSTRACT) reduce 153) ((T_ARRAY) reduce 153) ((T_ARRAY_CAST) reduce 153) ((T_ATTRIBUTE) reduce 153) ((T_BOOL_CAST) reduce 153) ((T_BREAK) reduce 153) ((T_CLASS) reduce 153) ((T_CLASS_C) reduce 153) ((T_CLONE) reduce 153) ((T_CONSTANT_ENCAPSED_STRING) reduce 153) ((T_CONTINUE) reduce 153) ((T_DEC) reduce 153) ((T_DECLARE) reduce 153) ((T_DIR) reduce 153) ((T_DNUMBER) reduce 153) ((T_DO) reduce 153) ((T_DOUBLE_CAST) reduce 153) ((T_ECHO) reduce 153) ((T_EMPTY) reduce 153) ((T_ENUM) reduce 153) ((T_EVAL) reduce 153) ((T_EXIT) reduce 153) ((T_FILE) reduce 153) ((T_FINAL) reduce 153) ((T_FN) reduce 153) ((T_FOR) reduce 153) ((T_FOREACH) reduce 153) ((T_FUNCTION) reduce 153) ((T_FUNC_C) reduce 153) ((T_GLOBAL) reduce 153) ((T_GOTO) reduce 153) ((T_HALT_COMPILER) reduce 153) ((T_IF) reduce 153) ((T_INC) reduce 153) ((T_INCLUDE) reduce 153) ((T_INCLUDE_ONCE) reduce 153) ((T_INLINE_HTML) reduce 153) ((T_INTERFACE) reduce 153) ((T_INT_CAST) reduce 153) ((T_ISSET) reduce 153) ((T_LINE) reduce 153) ((T_LIST) reduce 153) ((T_LNUMBER) reduce 153) ((T_MATCH) reduce 153) ((T_METHOD_C) reduce 153) ((T_NAME_FULLY_QUALIFIED) reduce 153) ((T_NAME_QUALIFIED) reduce 153) ((T_NAME_RELATIVE) reduce 153) ((T_NEW) reduce 153) ((T_NS_C) reduce 153) ((T_OBJECT_CAST) reduce 153) ((T_PRINT) reduce 153) ((T_READONLY) reduce 153) ((T_REQUIRE) reduce 153) ((T_REQUIRE_ONCE) reduce 153) ((T_RETURN) reduce 153) ((T_START_HEREDOC) reduce 153) ((T_STATIC) reduce 153) ((T_STRING) reduce 153) ((T_STRING_CAST) reduce 153) ((T_SWITCH) reduce 153) ((T_THROW) reduce 153) ((T_TRAIT) reduce 153) ((T_TRAIT_C) reduce 153) ((T_TRY) reduce 153) ((T_UNSET) reduce 153) ((T_UNSET_CAST) reduce 153) ((T_VARIABLE) reduce 153) ((T_WHILE) reduce 153) ((T_YIELD) reduce 153) ((T_YIELD_FROM) reduce 153) (("[") reduce 153) (("`") reduce 153) (("{") reduce 153) (("}") reduce 153) (("~") reduce 153)) 25456 ((("!") reduce 187) (("\"") reduce 187) (("$") reduce 187) (("(") reduce 187) (("+") reduce 187) (("-") reduce 187) ((";") reduce 187) (("@") reduce 187) ((T_ABSTRACT) reduce 187) ((T_ARRAY) reduce 187) ((T_ARRAY_CAST) reduce 187) ((T_ATTRIBUTE) reduce 187) ((T_BOOL_CAST) reduce 187) ((T_BREAK) reduce 187) ((T_CLASS) reduce 187) ((T_CLASS_C) reduce 187) ((T_CLONE) reduce 187) ((T_CONSTANT_ENCAPSED_STRING) reduce 187) ((T_CONTINUE) reduce 187) ((T_DEC) reduce 187) ((T_DECLARE) reduce 187) ((T_DIR) reduce 187) ((T_DNUMBER) reduce 187) ((T_DO) reduce 187) ((T_DOUBLE_CAST) reduce 187) ((T_ECHO) reduce 187) ((T_EMPTY) reduce 187) ((T_ENUM) reduce 187) ((T_EVAL) reduce 187) ((T_EXIT) reduce 187) ((T_FILE) reduce 187) ((T_FINAL) reduce 187) ((T_FN) reduce 187) ((T_FOR) reduce 187) ((T_FOREACH) reduce 187) ((T_FUNCTION) reduce 187) ((T_FUNC_C) reduce 187) ((T_GLOBAL) reduce 187) ((T_GOTO) reduce 187) ((T_HALT_COMPILER) reduce 187) ((T_IF) reduce 187) ((T_INC) reduce 187) ((T_INCLUDE) reduce 187) ((T_INCLUDE_ONCE) reduce 187) ((T_INLINE_HTML) reduce 187) ((T_INTERFACE) reduce 187) ((T_INT_CAST) reduce 187) ((T_ISSET) reduce 187) ((T_LINE) reduce 187) ((T_LIST) reduce 187) ((T_LNUMBER) reduce 187) ((T_MATCH) reduce 187) ((T_METHOD_C) reduce 187) ((T_NAME_FULLY_QUALIFIED) reduce 187) ((T_NAME_QUALIFIED) reduce 187) ((T_NAME_RELATIVE) reduce 187) ((T_NEW) reduce 187) ((T_NS_C) reduce 187) ((T_OBJECT_CAST) reduce 187) ((T_PRINT) reduce 187) ((T_READONLY) reduce 187) ((T_REQUIRE) reduce 187) ((T_REQUIRE_ONCE) reduce 187) ((T_RETURN) reduce 187) ((T_START_HEREDOC) reduce 187) ((T_STATIC) reduce 187) ((T_STRING) reduce 187) ((T_STRING_CAST) reduce 187) ((T_SWITCH) reduce 187) ((T_THROW) reduce 187) ((T_TRAIT) reduce 187) ((T_TRAIT_C) reduce 187) ((T_TRY) reduce 187) ((T_UNSET) reduce 187) ((T_UNSET_CAST) reduce 187) ((T_VARIABLE) reduce 187) ((T_WHILE) reduce 187) ((T_YIELD) reduce 187) ((T_YIELD_FROM) reduce 187) (("[") reduce 187) (("`") reduce 187) (("{") reduce 187) (("}") reduce 187) (("~") reduce 187)) 25458 ((("!") reduce 152) (("\"") reduce 152) (("$") reduce 152) (("(") reduce 152) (("+") reduce 152) (("-") reduce 152) ((";") reduce 152) (("@") reduce 152) ((T_ABSTRACT) reduce 152) ((T_ARRAY) reduce 152) ((T_ARRAY_CAST) reduce 152) ((T_ATTRIBUTE) reduce 152) ((T_BOOL_CAST) reduce 152) ((T_BREAK) reduce 152) ((T_CLASS) reduce 152) ((T_CLASS_C) reduce 152) ((T_CLONE) reduce 152) ((T_CONSTANT_ENCAPSED_STRING) reduce 152) ((T_CONTINUE) reduce 152) ((T_DEC) reduce 152) ((T_DECLARE) reduce 152) ((T_DIR) reduce 152) ((T_DNUMBER) reduce 152) ((T_DO) reduce 152) ((T_DOUBLE_CAST) reduce 152) ((T_ECHO) reduce 152) ((T_EMPTY) reduce 152) ((T_ENUM) reduce 152) ((T_EVAL) reduce 152) ((T_EXIT) reduce 152) ((T_FILE) reduce 152) ((T_FINAL) reduce 152) ((T_FN) reduce 152) ((T_FOR) reduce 152) ((T_FOREACH) reduce 152) ((T_FUNCTION) reduce 152) ((T_FUNC_C) reduce 152) ((T_GLOBAL) reduce 152) ((T_GOTO) reduce 152) ((T_HALT_COMPILER) reduce 152) ((T_IF) reduce 152) ((T_INC) reduce 152) ((T_INCLUDE) reduce 152) ((T_INCLUDE_ONCE) reduce 152) ((T_INLINE_HTML) reduce 152) ((T_INTERFACE) reduce 152) ((T_INT_CAST) reduce 152) ((T_ISSET) reduce 152) ((T_LINE) reduce 152) ((T_LIST) reduce 152) ((T_LNUMBER) reduce 152) ((T_MATCH) reduce 152) ((T_METHOD_C) reduce 152) ((T_NAME_FULLY_QUALIFIED) reduce 152) ((T_NAME_QUALIFIED) reduce 152) ((T_NAME_RELATIVE) reduce 152) ((T_NEW) reduce 152) ((T_NS_C) reduce 152) ((T_OBJECT_CAST) reduce 152) ((T_PRINT) reduce 152) ((T_READONLY) reduce 152) ((T_REQUIRE) reduce 152) ((T_REQUIRE_ONCE) reduce 152) ((T_RETURN) reduce 152) ((T_START_HEREDOC) reduce 152) ((T_STATIC) reduce 152) ((T_STRING) reduce 152) ((T_STRING_CAST) reduce 152) ((T_SWITCH) reduce 152) ((T_THROW) reduce 152) ((T_TRAIT) reduce 152) ((T_TRAIT_C) reduce 152) ((T_TRY) reduce 152) ((T_UNSET) reduce 152) ((T_UNSET_CAST) reduce 152) ((T_VARIABLE) reduce 152) ((T_WHILE) reduce 152) ((T_YIELD) reduce 152) ((T_YIELD_FROM) reduce 152) (("[") reduce 152) (("`") reduce 152) (("{") reduce 152) (("}") reduce 152) (("~") reduce 152)) 25460 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 277) (("{") reduce 277) (("|") reduce 277)) 25461 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 278) (("{") reduce 278) (("|") reduce 278)) 25462 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) (("{") reduce 93) (("|") reduce 93)) 25463 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) (("{") reduce 92) (("|") reduce 92)) 25464 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) (("{") reduce 94) (("|") reduce 94)) 25465 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 266) (("{") reduce 266) (("|") reduce 266)) 25466 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) (("{") reduce 91) (("|") reduce 91)) 25467 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) (("{") reduce 264)) 25468 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 279) (("{") reduce 279) (("|") reduce 279)) 25469 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) (("{") reduce 261) (("|") reduce 267)) 25470 ((("{") reduce 287)) 25471 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 265) (("{") reduce 265) (("|") reduce 265)) 25472 ((("{") reduce 263) (("|") shift)) 25476 ((("{") reduce 277) (("|") reduce 277)) 25477 ((("{") reduce 278) (("|") reduce 278)) 25478 ((("{") reduce 93) (("|") reduce 93)) 25479 ((("{") reduce 92) (("|") reduce 92)) 25480 ((("{") reduce 94) (("|") reduce 94)) 25481 ((("{") reduce 266) (("|") reduce 266)) 25482 ((("{") reduce 91) (("|") reduce 91)) 25483 ((("{") reduce 279) (("|") reduce 279)) 25484 ((("{") reduce 267) (("|") reduce 267)) 25485 ((("{") reduce 265) (("|") reduce 265)) 25486 ((("{") reduce 269) (("|") reduce 269)) 25488 ((("{") reduce 268) (("|") reduce 268)) 25490 ((("{") reduce 270) (("|") reduce 270)) 25492 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 277) (("{") reduce 277)) 25493 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 278) (("{") reduce 278)) 25494 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) (("{") reduce 93)) 25495 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) (("{") reduce 92)) 25496 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) (("{") reduce 94)) 25497 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 266) (("{") reduce 266)) 25498 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) (("{") reduce 91)) 25499 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 279) (("{") reduce 279)) 25500 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 271) (("{") reduce 271)) 25501 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 265) (("{") reduce 265)) 25503 (((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 272) (("{") reduce 272)) 25504 ((("{") reduce 277)) 25505 ((("{") reduce 278)) 25506 ((("{") reduce 93)) 25507 ((("{") reduce 92)) 25508 ((("{") reduce 94)) 25509 ((("{") reduce 266)) 25510 ((("{") reduce 91)) 25511 ((("{") reduce 279)) 25512 ((("{") reduce 262)) 25513 ((("{") reduce 265)) 25514 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_VARIABLE) shift)) 25515 (((T_VARIABLE) reduce 79)) 25516 (((T_VARIABLE) reduce 80)) 25517 (((")") reduce 463) ((",") reduce 463)) 25519 (((")") reduce 462) ((",") reduce 462)) 25521 (((")") reduce 124) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_VARIABLE) shift)) 25523 (((":") reduce 460) (("{") reduce 460)) 25524 (((")") reduce 461) ((",") reduce 461)) 25525 (((")") reduce 464) ((",") reduce 464)) 25527 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 277) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 277) ((T_ELLIPSIS) reduce 277) ((T_VARIABLE) reduce 277) (("|") reduce 277)) 25528 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 278) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 278) ((T_ELLIPSIS) reduce 278) ((T_VARIABLE) reduce 278) (("|") reduce 278)) 25529 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_ELLIPSIS) reduce 93) ((T_VARIABLE) reduce 93) (("|") reduce 93)) 25530 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_ELLIPSIS) reduce 92) ((T_VARIABLE) reduce 92) (("|") reduce 92)) 25531 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_ELLIPSIS) reduce 94) ((T_VARIABLE) reduce 94) (("|") reduce 94)) 25532 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_ELLIPSIS) reduce 91) ((T_VARIABLE) reduce 91) (("|") reduce 91)) 25533 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 276) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_ELLIPSIS) reduce 276) ((T_VARIABLE) reduce 276)) 25534 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 279) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 279) ((T_ELLIPSIS) reduce 279) ((T_VARIABLE) reduce 279) (("|") reduce 279)) 25535 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_ELLIPSIS) reduce 182) ((T_VARIABLE) reduce 182)) 25536 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 260) ((T_ELLIPSIS) reduce 260) ((T_VARIABLE) reduce 260)) 25537 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 273) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_ELLIPSIS) reduce 273) ((T_VARIABLE) reduce 273) (("|") reduce 280)) 25538 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 275) ((T_ELLIPSIS) reduce 275) ((T_VARIABLE) reduce 275) (("|") shift)) 25542 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 277) ((T_ELLIPSIS) reduce 277) ((T_VARIABLE) reduce 277) (("|") reduce 277)) 25543 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 278) ((T_ELLIPSIS) reduce 278) ((T_VARIABLE) reduce 278) (("|") reduce 278)) 25544 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_ELLIPSIS) reduce 93) ((T_VARIABLE) reduce 93) (("|") reduce 93)) 25545 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_ELLIPSIS) reduce 92) ((T_VARIABLE) reduce 92) (("|") reduce 92)) 25546 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_ELLIPSIS) reduce 94) ((T_VARIABLE) reduce 94) (("|") reduce 94)) 25547 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_ELLIPSIS) reduce 91) ((T_VARIABLE) reduce 91) (("|") reduce 91)) 25548 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 279) ((T_ELLIPSIS) reduce 279) ((T_VARIABLE) reduce 279) (("|") reduce 279)) 25549 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 280) ((T_ELLIPSIS) reduce 280) ((T_VARIABLE) reduce 280) (("|") reduce 280)) 25550 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 282) ((T_ELLIPSIS) reduce 282) ((T_VARIABLE) reduce 282) (("|") reduce 282)) 25552 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 281) ((T_ELLIPSIS) reduce 281) ((T_VARIABLE) reduce 281) (("|") reduce 281)) 25554 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 283) ((T_ELLIPSIS) reduce 283) ((T_VARIABLE) reduce 283) (("|") reduce 283)) 25556 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 277) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 277) ((T_ELLIPSIS) reduce 277) ((T_VARIABLE) reduce 277)) 25557 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 278) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 278) ((T_ELLIPSIS) reduce 278) ((T_VARIABLE) reduce 278)) 25558 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_ELLIPSIS) reduce 93) ((T_VARIABLE) reduce 93)) 25559 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_ELLIPSIS) reduce 92) ((T_VARIABLE) reduce 92)) 25560 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_ELLIPSIS) reduce 94) ((T_VARIABLE) reduce 94)) 25561 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_ELLIPSIS) reduce 91) ((T_VARIABLE) reduce 91)) 25562 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 279) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 279) ((T_ELLIPSIS) reduce 279) ((T_VARIABLE) reduce 279)) 25563 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 284) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 284) ((T_ELLIPSIS) reduce 284) ((T_VARIABLE) reduce 284)) 25564 (((T_ELLIPSIS) reduce 183) ((T_VARIABLE) reduce 183)) 25565 (((T_ELLIPSIS) shift) ((T_VARIABLE) reduce 184)) 25566 (((T_VARIABLE) reduce 185)) 25568 (((")") reduce 454) ((",") reduce 454) (("=") reduce 454)) 25569 (((")") reduce 257) ((",") reduce 257) (("=") shift)) 25571 ((("%") shift) ((")") reduce 258) (("*") shift) (("+") shift) ((",") reduce 258) (("-") shift) ((".") shift) (("/") shift) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 25573 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 285) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 285) ((T_ELLIPSIS) reduce 285) ((T_VARIABLE) reduce 285)) 25574 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 277) ((T_ELLIPSIS) reduce 277) ((T_VARIABLE) reduce 277)) 25575 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 278) ((T_ELLIPSIS) reduce 278) ((T_VARIABLE) reduce 278)) 25576 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_ELLIPSIS) reduce 93) ((T_VARIABLE) reduce 93)) 25577 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_ELLIPSIS) reduce 92) ((T_VARIABLE) reduce 92)) 25578 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_ELLIPSIS) reduce 94) ((T_VARIABLE) reduce 94)) 25579 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_ELLIPSIS) reduce 91) ((T_VARIABLE) reduce 91)) 25580 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 279) ((T_ELLIPSIS) reduce 279) ((T_VARIABLE) reduce 279)) 25581 (((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 274) ((T_ELLIPSIS) reduce 274) ((T_VARIABLE) reduce 274)) 25582 ((("(") reduce 255) ((")") reduce 124) (("?") reduce 255) ((T_ABSTRACT) shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 255) ((T_ARRAY) reduce 255) ((T_ATTRIBUTE) shift) ((T_CALLABLE) reduce 255) ((T_ELLIPSIS) reduce 255) ((T_FINAL) shift) ((T_NAME_FULLY_QUALIFIED) reduce 255) ((T_NAME_QUALIFIED) reduce 255) ((T_NAME_RELATIVE) reduce 255) ((T_PRIVATE) shift) ((T_PROTECTED) shift) ((T_PUBLIC) shift) ((T_READONLY) shift) ((T_STATIC) shift) ((T_STRING) reduce 255) ((T_VARIABLE) reduce 255)) 25583 (((")") reduce 249)) 25584 (((")") reduce 252) ((",") reduce 252)) 25585 ((("(") reduce 339) (("?") reduce 339) ((T_ABSTRACT) reduce 339) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 339) ((T_ARRAY) reduce 339) ((T_CALLABLE) reduce 339) ((T_ELLIPSIS) reduce 339) ((T_FINAL) reduce 339) ((T_NAME_FULLY_QUALIFIED) reduce 339) ((T_NAME_QUALIFIED) reduce 339) ((T_NAME_RELATIVE) reduce 339) ((T_PRIVATE) reduce 339) ((T_PROTECTED) reduce 339) ((T_PUBLIC) reduce 339) ((T_READONLY) reduce 339) ((T_STATIC) reduce 339) ((T_STRING) reduce 339) ((T_VARIABLE) reduce 339)) 25586 ((("(") reduce 101) (("?") reduce 101) ((T_ABSTRACT) reduce 101) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 101) ((T_ARRAY) reduce 101) ((T_ATTRIBUTE) reduce 101) ((T_CALLABLE) reduce 101) ((T_ELLIPSIS) reduce 101) ((T_FINAL) reduce 101) ((T_NAME_FULLY_QUALIFIED) reduce 101) ((T_NAME_QUALIFIED) reduce 101) ((T_NAME_RELATIVE) reduce 101) ((T_PRIVATE) reduce 101) ((T_PROTECTED) reduce 101) ((T_PUBLIC) reduce 101) ((T_READONLY) reduce 101) ((T_STATIC) reduce 101) ((T_STRING) reduce 101) ((T_VARIABLE) reduce 101)) 25587 (((")") reduce 253) ((",") reduce 253)) 25590 ((("(") reduce 99) (("?") reduce 99) ((T_ABSTRACT) reduce 99) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 99) ((T_ARRAY) reduce 99) ((T_ATTRIBUTE) reduce 99) ((T_CALLABLE) reduce 99) ((T_ELLIPSIS) reduce 99) ((T_FINAL) reduce 99) ((T_NAME_FULLY_QUALIFIED) reduce 99) ((T_NAME_QUALIFIED) reduce 99) ((T_NAME_RELATIVE) reduce 99) ((T_PRIVATE) reduce 99) ((T_PROTECTED) reduce 99) ((T_PUBLIC) reduce 99) ((T_READONLY) reduce 99) ((T_STATIC) reduce 99) ((T_STRING) reduce 99) ((T_VARIABLE) reduce 99)) 25592 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) ((";") reduce 466) (("<") reduce 466) (("=") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AND_EQUAL) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_COALESCE_EQUAL) reduce 466) ((T_CONCAT_EQUAL) reduce 466) ((T_DEC) reduce 466) ((T_DIV_EQUAL) reduce 466) ((T_INC) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_MINUS_EQUAL) reduce 466) ((T_MOD_EQUAL) reduce 466) ((T_MUL_EQUAL) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_OR_EQUAL) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_PLUS_EQUAL) reduce 466) ((T_POW) reduce 466) ((T_POW_EQUAL) reduce 466) ((T_SL) reduce 466) ((T_SL_EQUAL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) ((T_SR_EQUAL) reduce 466) ((T_XOR_EQUAL) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 25593 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) ((";") reduce 288) (("<") reduce 288) (("=") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AND_EQUAL) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_COALESCE_EQUAL) reduce 288) ((T_CONCAT_EQUAL) reduce 288) ((T_DEC) reduce 288) ((T_DIV_EQUAL) reduce 288) ((T_INC) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_MINUS_EQUAL) reduce 288) ((T_MOD_EQUAL) reduce 288) ((T_MUL_EQUAL) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_OR_EQUAL) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_PLUS_EQUAL) reduce 288) ((T_POW) reduce 288) ((T_POW_EQUAL) reduce 288) ((T_SL) reduce 288) ((T_SL_EQUAL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) ((T_SR_EQUAL) reduce 288) ((T_XOR_EQUAL) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 25597 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) ((";") reduce 289) (("<") reduce 289) (("=") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AND_EQUAL) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_COALESCE_EQUAL) reduce 289) ((T_CONCAT_EQUAL) reduce 289) ((T_DEC) reduce 289) ((T_DIV_EQUAL) reduce 289) ((T_INC) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_MINUS_EQUAL) reduce 289) ((T_MOD_EQUAL) reduce 289) ((T_MUL_EQUAL) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_OR_EQUAL) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_PLUS_EQUAL) reduce 289) ((T_POW) reduce 289) ((T_POW_EQUAL) reduce 289) ((T_SL) reduce 289) ((T_SL_EQUAL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) ((T_SR_EQUAL) reduce 289) ((T_XOR_EQUAL) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 25598 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) ((";") reduce 290) (("<") reduce 290) (("=") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AND_EQUAL) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_COALESCE_EQUAL) reduce 290) ((T_CONCAT_EQUAL) reduce 290) ((T_DEC) reduce 290) ((T_DIV_EQUAL) reduce 290) ((T_INC) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_MINUS_EQUAL) reduce 290) ((T_MOD_EQUAL) reduce 290) ((T_MUL_EQUAL) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_OR_EQUAL) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_PLUS_EQUAL) reduce 290) ((T_POW) reduce 290) ((T_POW_EQUAL) reduce 290) ((T_SL) reduce 290) ((T_SL_EQUAL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) ((T_SR_EQUAL) reduce 290) ((T_XOR_EQUAL) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 25601 (((T_ATTRIBUTE) reduce 99) ((T_FN) reduce 99) ((T_FUNCTION) reduce 99) ((T_STATIC) reduce 99)) 25603 ((("!") reduce 145) (("\"") reduce 145) (($) reduce 145) (("$") reduce 145) (("(") reduce 145) (("+") reduce 145) (("-") reduce 145) ((";") reduce 145) (("@") reduce 145) ((T_ABSTRACT) reduce 145) ((T_ARRAY) reduce 145) ((T_ARRAY_CAST) reduce 145) ((T_ATTRIBUTE) reduce 145) ((T_BOOL_CAST) reduce 145) ((T_BREAK) reduce 145) ((T_CLASS) reduce 145) ((T_CLASS_C) reduce 145) ((T_CLONE) reduce 145) ((T_CONST) reduce 145) ((T_CONSTANT_ENCAPSED_STRING) reduce 145) ((T_CONTINUE) reduce 145) ((T_DEC) reduce 145) ((T_DECLARE) reduce 145) ((T_DIR) reduce 145) ((T_DNUMBER) reduce 145) ((T_DO) reduce 145) ((T_DOUBLE_CAST) reduce 145) ((T_ECHO) reduce 145) ((T_EMPTY) reduce 145) ((T_ENUM) reduce 145) ((T_EVAL) reduce 145) ((T_EXIT) reduce 145) ((T_FILE) reduce 145) ((T_FINAL) reduce 145) ((T_FN) reduce 145) ((T_FOR) reduce 145) ((T_FOREACH) reduce 145) ((T_FUNCTION) reduce 145) ((T_FUNC_C) reduce 145) ((T_GLOBAL) reduce 145) ((T_GOTO) reduce 145) ((T_HALT_COMPILER) reduce 145) ((T_IF) reduce 145) ((T_INC) reduce 145) ((T_INCLUDE) reduce 145) ((T_INCLUDE_ONCE) reduce 145) ((T_INLINE_HTML) reduce 145) ((T_INTERFACE) reduce 145) ((T_INT_CAST) reduce 145) ((T_ISSET) reduce 145) ((T_LINE) reduce 145) ((T_LIST) reduce 145) ((T_LNUMBER) reduce 145) ((T_MATCH) reduce 145) ((T_METHOD_C) reduce 145) ((T_NAMESPACE) reduce 145) ((T_NAME_FULLY_QUALIFIED) reduce 145) ((T_NAME_QUALIFIED) reduce 145) ((T_NAME_RELATIVE) reduce 145) ((T_NEW) reduce 145) ((T_NS_C) reduce 145) ((T_OBJECT_CAST) reduce 145) ((T_PRINT) reduce 145) ((T_READONLY) reduce 145) ((T_REQUIRE) reduce 145) ((T_REQUIRE_ONCE) reduce 145) ((T_RETURN) reduce 145) ((T_START_HEREDOC) reduce 145) ((T_STATIC) reduce 145) ((T_STRING) reduce 145) ((T_STRING_CAST) reduce 145) ((T_SWITCH) reduce 145) ((T_THROW) reduce 145) ((T_TRAIT) reduce 145) ((T_TRAIT_C) reduce 145) ((T_TRY) reduce 145) ((T_UNSET) reduce 145) ((T_UNSET_CAST) reduce 145) ((T_USE) reduce 145) ((T_VARIABLE) reduce 145) ((T_WHILE) reduce 145) ((T_YIELD) reduce 145) ((T_YIELD_FROM) reduce 145) (("[") reduce 145) (("`") reduce 145) (("{") reduce 145) (("~") reduce 145)) 25605 ((("%") reduce 73) (("(") reduce 73) (("*") reduce 73) (("+") reduce 73) (("-") reduce 73) ((".") reduce 73) (("/") reduce 73) ((";") reduce 73) (("<") reduce 73) ((">") reduce 73) (("?") reduce 73) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_BOOLEAN_AND) reduce 73) ((T_BOOLEAN_OR) reduce 73) ((T_COALESCE) reduce 73) ((T_INSTANCEOF) reduce 73) ((T_IS_EQUAL) reduce 73) ((T_IS_GREATER_OR_EQUAL) reduce 73) ((T_IS_IDENTICAL) reduce 73) ((T_IS_NOT_EQUAL) reduce 73) ((T_IS_NOT_IDENTICAL) reduce 73) ((T_IS_SMALLER_OR_EQUAL) reduce 73) ((T_LOGICAL_AND) reduce 73) ((T_LOGICAL_OR) reduce 73) ((T_LOGICAL_XOR) reduce 73) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 73) ((T_OBJECT_OPERATOR) reduce 73) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 73) ((T_POW) reduce 73) ((T_SL) reduce 73) ((T_SPACESHIP) reduce 73) ((T_SR) reduce 73) (("[") reduce 73) (("^") reduce 73) (("{") reduce 73) (("|") reduce 73)) 25606 ((("%") reduce 52) (("(") reduce 52) (("*") reduce 52) (("+") reduce 52) (("-") reduce 52) ((".") reduce 52) (("/") reduce 52) ((";") reduce 52) (("<") reduce 52) ((">") reduce 52) (("?") reduce 52) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_BOOLEAN_AND) reduce 52) ((T_BOOLEAN_OR) reduce 52) ((T_COALESCE) reduce 52) ((T_INSTANCEOF) reduce 52) ((T_IS_EQUAL) reduce 52) ((T_IS_GREATER_OR_EQUAL) reduce 52) ((T_IS_IDENTICAL) reduce 52) ((T_IS_NOT_EQUAL) reduce 52) ((T_IS_NOT_IDENTICAL) reduce 52) ((T_IS_SMALLER_OR_EQUAL) reduce 52) ((T_LOGICAL_AND) reduce 52) ((T_LOGICAL_OR) reduce 52) ((T_LOGICAL_XOR) reduce 52) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 52) ((T_OBJECT_OPERATOR) reduce 52) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 52) ((T_POW) reduce 52) ((T_SL) reduce 52) ((T_SPACESHIP) reduce 52) ((T_SR) reduce 52) (("[") reduce 52) (("^") reduce 52) (("{") reduce 52) (("|") reduce 52)) 25607 ((("%") reduce 27) (("(") reduce 27) (("*") reduce 27) (("+") reduce 27) (("-") reduce 27) ((".") reduce 27) (("/") reduce 27) ((";") reduce 27) (("<") reduce 27) ((">") reduce 27) (("?") reduce 27) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_BOOLEAN_AND) reduce 27) ((T_BOOLEAN_OR) reduce 27) ((T_COALESCE) reduce 27) ((T_INSTANCEOF) reduce 27) ((T_IS_EQUAL) reduce 27) ((T_IS_GREATER_OR_EQUAL) reduce 27) ((T_IS_IDENTICAL) reduce 27) ((T_IS_NOT_EQUAL) reduce 27) ((T_IS_NOT_IDENTICAL) reduce 27) ((T_IS_SMALLER_OR_EQUAL) reduce 27) ((T_LOGICAL_AND) reduce 27) ((T_LOGICAL_OR) reduce 27) ((T_LOGICAL_XOR) reduce 27) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 27) ((T_OBJECT_OPERATOR) reduce 27) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 27) ((T_POW) reduce 27) ((T_SL) reduce 27) ((T_SPACESHIP) reduce 27) ((T_SR) reduce 27) (("[") reduce 27) (("^") reduce 27) (("{") reduce 27) (("|") reduce 27)) 25608 ((("%") reduce 51) (("(") reduce 51) (("*") reduce 51) (("+") reduce 51) (("-") reduce 51) ((".") reduce 51) (("/") reduce 51) ((";") reduce 51) (("<") reduce 51) ((">") reduce 51) (("?") reduce 51) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_BOOLEAN_AND) reduce 51) ((T_BOOLEAN_OR) reduce 51) ((T_COALESCE) reduce 51) ((T_INSTANCEOF) reduce 51) ((T_IS_EQUAL) reduce 51) ((T_IS_GREATER_OR_EQUAL) reduce 51) ((T_IS_IDENTICAL) reduce 51) ((T_IS_NOT_EQUAL) reduce 51) ((T_IS_NOT_IDENTICAL) reduce 51) ((T_IS_SMALLER_OR_EQUAL) reduce 51) ((T_LOGICAL_AND) reduce 51) ((T_LOGICAL_OR) reduce 51) ((T_LOGICAL_XOR) reduce 51) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 51) ((T_OBJECT_OPERATOR) reduce 51) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 51) ((T_POW) reduce 51) ((T_SL) reduce 51) ((T_SPACESHIP) reduce 51) ((T_SR) reduce 51) (("[") reduce 51) (("^") reduce 51) (("{") reduce 51) (("|") reduce 51)) 25609 ((("%") reduce 53) (("(") reduce 53) (("*") reduce 53) (("+") reduce 53) (("-") reduce 53) ((".") reduce 53) (("/") reduce 53) ((";") reduce 53) (("<") reduce 53) ((">") reduce 53) (("?") reduce 53) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_BOOLEAN_AND) reduce 53) ((T_BOOLEAN_OR) reduce 53) ((T_COALESCE) reduce 53) ((T_INSTANCEOF) reduce 53) ((T_IS_EQUAL) reduce 53) ((T_IS_GREATER_OR_EQUAL) reduce 53) ((T_IS_IDENTICAL) reduce 53) ((T_IS_NOT_EQUAL) reduce 53) ((T_IS_NOT_IDENTICAL) reduce 53) ((T_IS_SMALLER_OR_EQUAL) reduce 53) ((T_LOGICAL_AND) reduce 53) ((T_LOGICAL_OR) reduce 53) ((T_LOGICAL_XOR) reduce 53) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 53) ((T_OBJECT_OPERATOR) reduce 53) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 53) ((T_POW) reduce 53) ((T_SL) reduce 53) ((T_SPACESHIP) reduce 53) ((T_SR) reduce 53) (("[") reduce 53) (("^") reduce 53) (("{") reduce 53) (("|") reduce 53)) 25610 ((("%") reduce 49) (("(") reduce 49) (("*") reduce 49) (("+") reduce 49) (("-") reduce 49) ((".") reduce 49) (("/") reduce 49) ((";") reduce 49) (("<") reduce 49) ((">") reduce 49) (("?") reduce 49) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_BOOLEAN_AND) reduce 49) ((T_BOOLEAN_OR) reduce 49) ((T_COALESCE) reduce 49) ((T_INSTANCEOF) reduce 49) ((T_IS_EQUAL) reduce 49) ((T_IS_GREATER_OR_EQUAL) reduce 49) ((T_IS_IDENTICAL) reduce 49) ((T_IS_NOT_EQUAL) reduce 49) ((T_IS_NOT_IDENTICAL) reduce 49) ((T_IS_SMALLER_OR_EQUAL) reduce 49) ((T_LOGICAL_AND) reduce 49) ((T_LOGICAL_OR) reduce 49) ((T_LOGICAL_XOR) reduce 49) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 49) ((T_OBJECT_OPERATOR) reduce 49) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 49) ((T_POW) reduce 49) ((T_SL) reduce 49) ((T_SPACESHIP) reduce 49) ((T_SR) reduce 49) (("[") reduce 49) (("^") reduce 49) (("{") reduce 49) (("|") reduce 49)) 25611 ((("%") reduce 29) (("(") reduce 29) (("*") reduce 29) (("+") reduce 29) (("-") reduce 29) ((".") reduce 29) (("/") reduce 29) ((";") reduce 29) (("<") reduce 29) ((">") reduce 29) (("?") reduce 29) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_BOOLEAN_AND) reduce 29) ((T_BOOLEAN_OR) reduce 29) ((T_COALESCE) reduce 29) ((T_INSTANCEOF) reduce 29) ((T_IS_EQUAL) reduce 29) ((T_IS_GREATER_OR_EQUAL) reduce 29) ((T_IS_IDENTICAL) reduce 29) ((T_IS_NOT_EQUAL) reduce 29) ((T_IS_NOT_IDENTICAL) reduce 29) ((T_IS_SMALLER_OR_EQUAL) reduce 29) ((T_LOGICAL_AND) reduce 29) ((T_LOGICAL_OR) reduce 29) ((T_LOGICAL_XOR) reduce 29) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 29) ((T_OBJECT_OPERATOR) reduce 29) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 29) ((T_POW) reduce 29) ((T_SL) reduce 29) ((T_SPACESHIP) reduce 29) ((T_SR) reduce 29) (("[") reduce 29) (("^") reduce 29) (("{") reduce 29) (("|") reduce 29)) 25612 ((("%") reduce 59) (("(") reduce 59) (("*") reduce 59) (("+") reduce 59) (("-") reduce 59) ((".") reduce 59) (("/") reduce 59) ((";") reduce 59) (("<") reduce 59) ((">") reduce 59) (("?") reduce 59) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_BOOLEAN_AND) reduce 59) ((T_BOOLEAN_OR) reduce 59) ((T_COALESCE) reduce 59) ((T_INSTANCEOF) reduce 59) ((T_IS_EQUAL) reduce 59) ((T_IS_GREATER_OR_EQUAL) reduce 59) ((T_IS_IDENTICAL) reduce 59) ((T_IS_NOT_EQUAL) reduce 59) ((T_IS_NOT_IDENTICAL) reduce 59) ((T_IS_SMALLER_OR_EQUAL) reduce 59) ((T_LOGICAL_AND) reduce 59) ((T_LOGICAL_OR) reduce 59) ((T_LOGICAL_XOR) reduce 59) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 59) ((T_OBJECT_OPERATOR) reduce 59) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 59) ((T_POW) reduce 59) ((T_SL) reduce 59) ((T_SPACESHIP) reduce 59) ((T_SR) reduce 59) (("[") reduce 59) (("^") reduce 59) (("{") reduce 59) (("|") reduce 59)) 25613 ((("%") reduce 60) (("(") reduce 60) (("*") reduce 60) (("+") reduce 60) (("-") reduce 60) ((".") reduce 60) (("/") reduce 60) ((";") reduce 60) (("<") reduce 60) ((">") reduce 60) (("?") reduce 60) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_BOOLEAN_AND) reduce 60) ((T_BOOLEAN_OR) reduce 60) ((T_COALESCE) reduce 60) ((T_INSTANCEOF) reduce 60) ((T_IS_EQUAL) reduce 60) ((T_IS_GREATER_OR_EQUAL) reduce 60) ((T_IS_IDENTICAL) reduce 60) ((T_IS_NOT_EQUAL) reduce 60) ((T_IS_NOT_IDENTICAL) reduce 60) ((T_IS_SMALLER_OR_EQUAL) reduce 60) ((T_LOGICAL_AND) reduce 60) ((T_LOGICAL_OR) reduce 60) ((T_LOGICAL_XOR) reduce 60) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 60) ((T_OBJECT_OPERATOR) reduce 60) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 60) ((T_POW) reduce 60) ((T_SL) reduce 60) ((T_SPACESHIP) reduce 60) ((T_SR) reduce 60) (("[") reduce 60) (("^") reduce 60) (("{") reduce 60) (("|") reduce 60)) 25614 ((("%") reduce 11) (("(") reduce 11) (("*") reduce 11) (("+") reduce 11) (("-") reduce 11) ((".") reduce 11) (("/") reduce 11) ((";") reduce 11) (("<") reduce 11) ((">") reduce 11) (("?") reduce 11) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_BOOLEAN_AND) reduce 11) ((T_BOOLEAN_OR) reduce 11) ((T_COALESCE) reduce 11) ((T_INSTANCEOF) reduce 11) ((T_IS_EQUAL) reduce 11) ((T_IS_GREATER_OR_EQUAL) reduce 11) ((T_IS_IDENTICAL) reduce 11) ((T_IS_NOT_EQUAL) reduce 11) ((T_IS_NOT_IDENTICAL) reduce 11) ((T_IS_SMALLER_OR_EQUAL) reduce 11) ((T_LOGICAL_AND) reduce 11) ((T_LOGICAL_OR) reduce 11) ((T_LOGICAL_XOR) reduce 11) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 11) ((T_OBJECT_OPERATOR) reduce 11) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 11) ((T_POW) reduce 11) ((T_SL) reduce 11) ((T_SPACESHIP) reduce 11) ((T_SR) reduce 11) (("[") reduce 11) (("^") reduce 11) (("{") reduce 11) (("|") reduce 11)) 25615 ((("%") reduce 42) (("(") reduce 42) (("*") reduce 42) (("+") reduce 42) (("-") reduce 42) ((".") reduce 42) (("/") reduce 42) ((";") reduce 42) (("<") reduce 42) ((">") reduce 42) (("?") reduce 42) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_BOOLEAN_AND) reduce 42) ((T_BOOLEAN_OR) reduce 42) ((T_COALESCE) reduce 42) ((T_INSTANCEOF) reduce 42) ((T_IS_EQUAL) reduce 42) ((T_IS_GREATER_OR_EQUAL) reduce 42) ((T_IS_IDENTICAL) reduce 42) ((T_IS_NOT_EQUAL) reduce 42) ((T_IS_NOT_IDENTICAL) reduce 42) ((T_IS_SMALLER_OR_EQUAL) reduce 42) ((T_LOGICAL_AND) reduce 42) ((T_LOGICAL_OR) reduce 42) ((T_LOGICAL_XOR) reduce 42) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 42) ((T_OBJECT_OPERATOR) reduce 42) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 42) ((T_POW) reduce 42) ((T_SL) reduce 42) ((T_SPACESHIP) reduce 42) ((T_SR) reduce 42) (("[") reduce 42) (("^") reduce 42) (("{") reduce 42) (("|") reduce 42)) 25616 ((("%") reduce 39) (("(") reduce 39) (("*") reduce 39) (("+") reduce 39) (("-") reduce 39) ((".") reduce 39) (("/") reduce 39) ((";") reduce 39) (("<") reduce 39) ((">") reduce 39) (("?") reduce 39) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_BOOLEAN_AND) reduce 39) ((T_BOOLEAN_OR) reduce 39) ((T_COALESCE) reduce 39) ((T_INSTANCEOF) reduce 39) ((T_IS_EQUAL) reduce 39) ((T_IS_GREATER_OR_EQUAL) reduce 39) ((T_IS_IDENTICAL) reduce 39) ((T_IS_NOT_EQUAL) reduce 39) ((T_IS_NOT_IDENTICAL) reduce 39) ((T_IS_SMALLER_OR_EQUAL) reduce 39) ((T_LOGICAL_AND) reduce 39) ((T_LOGICAL_OR) reduce 39) ((T_LOGICAL_XOR) reduce 39) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 39) ((T_OBJECT_OPERATOR) reduce 39) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 39) ((T_POW) reduce 39) ((T_SL) reduce 39) ((T_SPACESHIP) reduce 39) ((T_SR) reduce 39) (("[") reduce 39) (("^") reduce 39) (("{") reduce 39) (("|") reduce 39)) 25617 ((("%") reduce 25) (("(") reduce 25) (("*") reduce 25) (("+") reduce 25) (("-") reduce 25) ((".") reduce 25) (("/") reduce 25) ((";") reduce 25) (("<") reduce 25) ((">") reduce 25) (("?") reduce 25) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_BOOLEAN_AND) reduce 25) ((T_BOOLEAN_OR) reduce 25) ((T_COALESCE) reduce 25) ((T_INSTANCEOF) reduce 25) ((T_IS_EQUAL) reduce 25) ((T_IS_GREATER_OR_EQUAL) reduce 25) ((T_IS_IDENTICAL) reduce 25) ((T_IS_NOT_EQUAL) reduce 25) ((T_IS_NOT_IDENTICAL) reduce 25) ((T_IS_SMALLER_OR_EQUAL) reduce 25) ((T_LOGICAL_AND) reduce 25) ((T_LOGICAL_OR) reduce 25) ((T_LOGICAL_XOR) reduce 25) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 25) ((T_OBJECT_OPERATOR) reduce 25) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 25) ((T_POW) reduce 25) ((T_SL) reduce 25) ((T_SPACESHIP) reduce 25) ((T_SR) reduce 25) (("[") reduce 25) (("^") reduce 25) (("{") reduce 25) (("|") reduce 25)) 25618 ((("%") reduce 50) (("(") reduce 50) (("*") reduce 50) (("+") reduce 50) (("-") reduce 50) ((".") reduce 50) (("/") reduce 50) ((";") reduce 50) (("<") reduce 50) ((">") reduce 50) (("?") reduce 50) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_BOOLEAN_AND) reduce 50) ((T_BOOLEAN_OR) reduce 50) ((T_COALESCE) reduce 50) ((T_INSTANCEOF) reduce 50) ((T_IS_EQUAL) reduce 50) ((T_IS_GREATER_OR_EQUAL) reduce 50) ((T_IS_IDENTICAL) reduce 50) ((T_IS_NOT_EQUAL) reduce 50) ((T_IS_NOT_IDENTICAL) reduce 50) ((T_IS_SMALLER_OR_EQUAL) reduce 50) ((T_LOGICAL_AND) reduce 50) ((T_LOGICAL_OR) reduce 50) ((T_LOGICAL_XOR) reduce 50) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 50) ((T_OBJECT_OPERATOR) reduce 50) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 50) ((T_POW) reduce 50) ((T_SL) reduce 50) ((T_SPACESHIP) reduce 50) ((T_SR) reduce 50) (("[") reduce 50) (("^") reduce 50) (("{") reduce 50) (("|") reduce 50)) 25619 ((("%") reduce 66) (("(") reduce 66) (("*") reduce 66) (("+") reduce 66) (("-") reduce 66) ((".") reduce 66) (("/") reduce 66) ((";") reduce 66) (("<") reduce 66) ((">") reduce 66) (("?") reduce 66) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_BOOLEAN_AND) reduce 66) ((T_BOOLEAN_OR) reduce 66) ((T_COALESCE) reduce 66) ((T_INSTANCEOF) reduce 66) ((T_IS_EQUAL) reduce 66) ((T_IS_GREATER_OR_EQUAL) reduce 66) ((T_IS_IDENTICAL) reduce 66) ((T_IS_NOT_EQUAL) reduce 66) ((T_IS_NOT_IDENTICAL) reduce 66) ((T_IS_SMALLER_OR_EQUAL) reduce 66) ((T_LOGICAL_AND) reduce 66) ((T_LOGICAL_OR) reduce 66) ((T_LOGICAL_XOR) reduce 66) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 66) ((T_OBJECT_OPERATOR) reduce 66) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 66) ((T_POW) reduce 66) ((T_SL) reduce 66) ((T_SPACESHIP) reduce 66) ((T_SR) reduce 66) (("[") reduce 66) (("^") reduce 66) (("{") reduce 66) (("|") reduce 66)) 25620 ((("%") reduce 18) (("(") reduce 18) (("*") reduce 18) (("+") reduce 18) (("-") reduce 18) ((".") reduce 18) (("/") reduce 18) ((";") reduce 18) (("<") reduce 18) ((">") reduce 18) (("?") reduce 18) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_BOOLEAN_AND) reduce 18) ((T_BOOLEAN_OR) reduce 18) ((T_COALESCE) reduce 18) ((T_INSTANCEOF) reduce 18) ((T_IS_EQUAL) reduce 18) ((T_IS_GREATER_OR_EQUAL) reduce 18) ((T_IS_IDENTICAL) reduce 18) ((T_IS_NOT_EQUAL) reduce 18) ((T_IS_NOT_IDENTICAL) reduce 18) ((T_IS_SMALLER_OR_EQUAL) reduce 18) ((T_LOGICAL_AND) reduce 18) ((T_LOGICAL_OR) reduce 18) ((T_LOGICAL_XOR) reduce 18) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 18) ((T_OBJECT_OPERATOR) reduce 18) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 18) ((T_POW) reduce 18) ((T_SL) reduce 18) ((T_SPACESHIP) reduce 18) ((T_SR) reduce 18) (("[") reduce 18) (("^") reduce 18) (("{") reduce 18) (("|") reduce 18)) 25621 ((("%") reduce 17) (("(") reduce 17) (("*") reduce 17) (("+") reduce 17) (("-") reduce 17) ((".") reduce 17) (("/") reduce 17) ((";") reduce 17) (("<") reduce 17) ((">") reduce 17) (("?") reduce 17) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_BOOLEAN_AND) reduce 17) ((T_BOOLEAN_OR) reduce 17) ((T_COALESCE) reduce 17) ((T_INSTANCEOF) reduce 17) ((T_IS_EQUAL) reduce 17) ((T_IS_GREATER_OR_EQUAL) reduce 17) ((T_IS_IDENTICAL) reduce 17) ((T_IS_NOT_EQUAL) reduce 17) ((T_IS_NOT_IDENTICAL) reduce 17) ((T_IS_SMALLER_OR_EQUAL) reduce 17) ((T_LOGICAL_AND) reduce 17) ((T_LOGICAL_OR) reduce 17) ((T_LOGICAL_XOR) reduce 17) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 17) ((T_OBJECT_OPERATOR) reduce 17) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 17) ((T_POW) reduce 17) ((T_SL) reduce 17) ((T_SPACESHIP) reduce 17) ((T_SR) reduce 17) (("[") reduce 17) (("^") reduce 17) (("{") reduce 17) (("|") reduce 17)) 25622 ((("%") reduce 15) (("(") reduce 15) (("*") reduce 15) (("+") reduce 15) (("-") reduce 15) ((".") reduce 15) (("/") reduce 15) ((";") reduce 15) (("<") reduce 15) ((">") reduce 15) (("?") reduce 15) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_BOOLEAN_AND) reduce 15) ((T_BOOLEAN_OR) reduce 15) ((T_COALESCE) reduce 15) ((T_INSTANCEOF) reduce 15) ((T_IS_EQUAL) reduce 15) ((T_IS_GREATER_OR_EQUAL) reduce 15) ((T_IS_IDENTICAL) reduce 15) ((T_IS_NOT_EQUAL) reduce 15) ((T_IS_NOT_IDENTICAL) reduce 15) ((T_IS_SMALLER_OR_EQUAL) reduce 15) ((T_LOGICAL_AND) reduce 15) ((T_LOGICAL_OR) reduce 15) ((T_LOGICAL_XOR) reduce 15) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 15) ((T_OBJECT_OPERATOR) reduce 15) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 15) ((T_POW) reduce 15) ((T_SL) reduce 15) ((T_SPACESHIP) reduce 15) ((T_SR) reduce 15) (("[") reduce 15) (("^") reduce 15) (("{") reduce 15) (("|") reduce 15)) 25623 ((("%") reduce 14) (("(") reduce 14) (("*") reduce 14) (("+") reduce 14) (("-") reduce 14) ((".") reduce 14) (("/") reduce 14) ((";") reduce 14) (("<") reduce 14) ((">") reduce 14) (("?") reduce 14) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_BOOLEAN_AND) reduce 14) ((T_BOOLEAN_OR) reduce 14) ((T_COALESCE) reduce 14) ((T_INSTANCEOF) reduce 14) ((T_IS_EQUAL) reduce 14) ((T_IS_GREATER_OR_EQUAL) reduce 14) ((T_IS_IDENTICAL) reduce 14) ((T_IS_NOT_EQUAL) reduce 14) ((T_IS_NOT_IDENTICAL) reduce 14) ((T_IS_SMALLER_OR_EQUAL) reduce 14) ((T_LOGICAL_AND) reduce 14) ((T_LOGICAL_OR) reduce 14) ((T_LOGICAL_XOR) reduce 14) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 14) ((T_OBJECT_OPERATOR) reduce 14) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 14) ((T_POW) reduce 14) ((T_SL) reduce 14) ((T_SPACESHIP) reduce 14) ((T_SR) reduce 14) (("[") reduce 14) (("^") reduce 14) (("{") reduce 14) (("|") reduce 14)) 25624 ((("%") reduce 38) (("(") reduce 38) (("*") reduce 38) (("+") reduce 38) (("-") reduce 38) ((".") reduce 38) (("/") reduce 38) ((";") reduce 38) (("<") reduce 38) ((">") reduce 38) (("?") reduce 38) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_BOOLEAN_AND) reduce 38) ((T_BOOLEAN_OR) reduce 38) ((T_COALESCE) reduce 38) ((T_INSTANCEOF) reduce 38) ((T_IS_EQUAL) reduce 38) ((T_IS_GREATER_OR_EQUAL) reduce 38) ((T_IS_IDENTICAL) reduce 38) ((T_IS_NOT_EQUAL) reduce 38) ((T_IS_NOT_IDENTICAL) reduce 38) ((T_IS_SMALLER_OR_EQUAL) reduce 38) ((T_LOGICAL_AND) reduce 38) ((T_LOGICAL_OR) reduce 38) ((T_LOGICAL_XOR) reduce 38) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 38) ((T_OBJECT_OPERATOR) reduce 38) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 38) ((T_POW) reduce 38) ((T_SL) reduce 38) ((T_SPACESHIP) reduce 38) ((T_SR) reduce 38) (("[") reduce 38) (("^") reduce 38) (("{") reduce 38) (("|") reduce 38)) 25625 ((("%") reduce 26) (("(") reduce 26) (("*") reduce 26) (("+") reduce 26) (("-") reduce 26) ((".") reduce 26) (("/") reduce 26) ((";") reduce 26) (("<") reduce 26) ((">") reduce 26) (("?") reduce 26) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_BOOLEAN_AND) reduce 26) ((T_BOOLEAN_OR) reduce 26) ((T_COALESCE) reduce 26) ((T_INSTANCEOF) reduce 26) ((T_IS_EQUAL) reduce 26) ((T_IS_GREATER_OR_EQUAL) reduce 26) ((T_IS_IDENTICAL) reduce 26) ((T_IS_NOT_EQUAL) reduce 26) ((T_IS_NOT_IDENTICAL) reduce 26) ((T_IS_SMALLER_OR_EQUAL) reduce 26) ((T_LOGICAL_AND) reduce 26) ((T_LOGICAL_OR) reduce 26) ((T_LOGICAL_XOR) reduce 26) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 26) ((T_OBJECT_OPERATOR) reduce 26) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 26) ((T_POW) reduce 26) ((T_SL) reduce 26) ((T_SPACESHIP) reduce 26) ((T_SR) reduce 26) (("[") reduce 26) (("^") reduce 26) (("{") reduce 26) (("|") reduce 26)) 25626 ((("%") reduce 22) (("(") reduce 22) (("*") reduce 22) (("+") reduce 22) (("-") reduce 22) ((".") reduce 22) (("/") reduce 22) ((";") reduce 22) (("<") reduce 22) ((">") reduce 22) (("?") reduce 22) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_BOOLEAN_AND) reduce 22) ((T_BOOLEAN_OR) reduce 22) ((T_COALESCE) reduce 22) ((T_INSTANCEOF) reduce 22) ((T_IS_EQUAL) reduce 22) ((T_IS_GREATER_OR_EQUAL) reduce 22) ((T_IS_IDENTICAL) reduce 22) ((T_IS_NOT_EQUAL) reduce 22) ((T_IS_NOT_IDENTICAL) reduce 22) ((T_IS_SMALLER_OR_EQUAL) reduce 22) ((T_LOGICAL_AND) reduce 22) ((T_LOGICAL_OR) reduce 22) ((T_LOGICAL_XOR) reduce 22) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 22) ((T_OBJECT_OPERATOR) reduce 22) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 22) ((T_POW) reduce 22) ((T_SL) reduce 22) ((T_SPACESHIP) reduce 22) ((T_SR) reduce 22) (("[") reduce 22) (("^") reduce 22) (("{") reduce 22) (("|") reduce 22)) 25627 ((("%") reduce 24) (("(") reduce 24) (("*") reduce 24) (("+") reduce 24) (("-") reduce 24) ((".") reduce 24) (("/") reduce 24) ((";") reduce 24) (("<") reduce 24) ((">") reduce 24) (("?") reduce 24) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_BOOLEAN_AND) reduce 24) ((T_BOOLEAN_OR) reduce 24) ((T_COALESCE) reduce 24) ((T_INSTANCEOF) reduce 24) ((T_IS_EQUAL) reduce 24) ((T_IS_GREATER_OR_EQUAL) reduce 24) ((T_IS_IDENTICAL) reduce 24) ((T_IS_NOT_EQUAL) reduce 24) ((T_IS_NOT_IDENTICAL) reduce 24) ((T_IS_SMALLER_OR_EQUAL) reduce 24) ((T_LOGICAL_AND) reduce 24) ((T_LOGICAL_OR) reduce 24) ((T_LOGICAL_XOR) reduce 24) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 24) ((T_OBJECT_OPERATOR) reduce 24) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 24) ((T_POW) reduce 24) ((T_SL) reduce 24) ((T_SPACESHIP) reduce 24) ((T_SR) reduce 24) (("[") reduce 24) (("^") reduce 24) (("{") reduce 24) (("|") reduce 24)) 25628 ((("%") reduce 16) (("(") reduce 16) (("*") reduce 16) (("+") reduce 16) (("-") reduce 16) ((".") reduce 16) (("/") reduce 16) ((";") reduce 16) (("<") reduce 16) ((">") reduce 16) (("?") reduce 16) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_BOOLEAN_AND) reduce 16) ((T_BOOLEAN_OR) reduce 16) ((T_COALESCE) reduce 16) ((T_INSTANCEOF) reduce 16) ((T_IS_EQUAL) reduce 16) ((T_IS_GREATER_OR_EQUAL) reduce 16) ((T_IS_IDENTICAL) reduce 16) ((T_IS_NOT_EQUAL) reduce 16) ((T_IS_NOT_IDENTICAL) reduce 16) ((T_IS_SMALLER_OR_EQUAL) reduce 16) ((T_LOGICAL_AND) reduce 16) ((T_LOGICAL_OR) reduce 16) ((T_LOGICAL_XOR) reduce 16) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 16) ((T_OBJECT_OPERATOR) reduce 16) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 16) ((T_POW) reduce 16) ((T_SL) reduce 16) ((T_SPACESHIP) reduce 16) ((T_SR) reduce 16) (("[") reduce 16) (("^") reduce 16) (("{") reduce 16) (("|") reduce 16)) 25629 ((("%") reduce 48) (("(") reduce 48) (("*") reduce 48) (("+") reduce 48) (("-") reduce 48) ((".") reduce 48) (("/") reduce 48) ((";") reduce 48) (("<") reduce 48) ((">") reduce 48) (("?") reduce 48) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_BOOLEAN_AND) reduce 48) ((T_BOOLEAN_OR) reduce 48) ((T_COALESCE) reduce 48) ((T_INSTANCEOF) reduce 48) ((T_IS_EQUAL) reduce 48) ((T_IS_GREATER_OR_EQUAL) reduce 48) ((T_IS_IDENTICAL) reduce 48) ((T_IS_NOT_EQUAL) reduce 48) ((T_IS_NOT_IDENTICAL) reduce 48) ((T_IS_SMALLER_OR_EQUAL) reduce 48) ((T_LOGICAL_AND) reduce 48) ((T_LOGICAL_OR) reduce 48) ((T_LOGICAL_XOR) reduce 48) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 48) ((T_OBJECT_OPERATOR) reduce 48) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 48) ((T_POW) reduce 48) ((T_SL) reduce 48) ((T_SPACESHIP) reduce 48) ((T_SR) reduce 48) (("[") reduce 48) (("^") reduce 48) (("{") reduce 48) (("|") reduce 48)) 25630 ((("%") reduce 20) (("(") reduce 20) (("*") reduce 20) (("+") reduce 20) (("-") reduce 20) ((".") reduce 20) (("/") reduce 20) ((";") reduce 20) (("<") reduce 20) ((">") reduce 20) (("?") reduce 20) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_BOOLEAN_AND) reduce 20) ((T_BOOLEAN_OR) reduce 20) ((T_COALESCE) reduce 20) ((T_INSTANCEOF) reduce 20) ((T_IS_EQUAL) reduce 20) ((T_IS_GREATER_OR_EQUAL) reduce 20) ((T_IS_IDENTICAL) reduce 20) ((T_IS_NOT_EQUAL) reduce 20) ((T_IS_NOT_IDENTICAL) reduce 20) ((T_IS_SMALLER_OR_EQUAL) reduce 20) ((T_LOGICAL_AND) reduce 20) ((T_LOGICAL_OR) reduce 20) ((T_LOGICAL_XOR) reduce 20) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 20) ((T_OBJECT_OPERATOR) reduce 20) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 20) ((T_POW) reduce 20) ((T_SL) reduce 20) ((T_SPACESHIP) reduce 20) ((T_SR) reduce 20) (("[") reduce 20) (("^") reduce 20) (("{") reduce 20) (("|") reduce 20)) 25631 ((("%") reduce 70) (("(") reduce 70) (("*") reduce 70) (("+") reduce 70) (("-") reduce 70) ((".") reduce 70) (("/") reduce 70) ((";") reduce 70) (("<") reduce 70) ((">") reduce 70) (("?") reduce 70) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_BOOLEAN_AND) reduce 70) ((T_BOOLEAN_OR) reduce 70) ((T_COALESCE) reduce 70) ((T_INSTANCEOF) reduce 70) ((T_IS_EQUAL) reduce 70) ((T_IS_GREATER_OR_EQUAL) reduce 70) ((T_IS_IDENTICAL) reduce 70) ((T_IS_NOT_EQUAL) reduce 70) ((T_IS_NOT_IDENTICAL) reduce 70) ((T_IS_SMALLER_OR_EQUAL) reduce 70) ((T_LOGICAL_AND) reduce 70) ((T_LOGICAL_OR) reduce 70) ((T_LOGICAL_XOR) reduce 70) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 70) ((T_OBJECT_OPERATOR) reduce 70) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 70) ((T_POW) reduce 70) ((T_SL) reduce 70) ((T_SPACESHIP) reduce 70) ((T_SR) reduce 70) (("[") reduce 70) (("^") reduce 70) (("{") reduce 70) (("|") reduce 70)) 25632 ((("%") reduce 3) (("(") reduce 3) (("*") reduce 3) (("+") reduce 3) (("-") reduce 3) ((".") reduce 3) (("/") reduce 3) ((";") reduce 3) (("<") reduce 3) ((">") reduce 3) (("?") reduce 3) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_BOOLEAN_AND) reduce 3) ((T_BOOLEAN_OR) reduce 3) ((T_COALESCE) reduce 3) ((T_INSTANCEOF) reduce 3) ((T_IS_EQUAL) reduce 3) ((T_IS_GREATER_OR_EQUAL) reduce 3) ((T_IS_IDENTICAL) reduce 3) ((T_IS_NOT_EQUAL) reduce 3) ((T_IS_NOT_IDENTICAL) reduce 3) ((T_IS_SMALLER_OR_EQUAL) reduce 3) ((T_LOGICAL_AND) reduce 3) ((T_LOGICAL_OR) reduce 3) ((T_LOGICAL_XOR) reduce 3) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 3) ((T_OBJECT_OPERATOR) reduce 3) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 3) ((T_POW) reduce 3) ((T_SL) reduce 3) ((T_SPACESHIP) reduce 3) ((T_SR) reduce 3) (("[") reduce 3) (("^") reduce 3) (("{") reduce 3) (("|") reduce 3)) 25633 ((("%") reduce 12) (("(") reduce 12) (("*") reduce 12) (("+") reduce 12) (("-") reduce 12) ((".") reduce 12) (("/") reduce 12) ((";") reduce 12) (("<") reduce 12) ((">") reduce 12) (("?") reduce 12) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_BOOLEAN_AND) reduce 12) ((T_BOOLEAN_OR) reduce 12) ((T_COALESCE) reduce 12) ((T_INSTANCEOF) reduce 12) ((T_IS_EQUAL) reduce 12) ((T_IS_GREATER_OR_EQUAL) reduce 12) ((T_IS_IDENTICAL) reduce 12) ((T_IS_NOT_EQUAL) reduce 12) ((T_IS_NOT_IDENTICAL) reduce 12) ((T_IS_SMALLER_OR_EQUAL) reduce 12) ((T_LOGICAL_AND) reduce 12) ((T_LOGICAL_OR) reduce 12) ((T_LOGICAL_XOR) reduce 12) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 12) ((T_OBJECT_OPERATOR) reduce 12) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 12) ((T_POW) reduce 12) ((T_SL) reduce 12) ((T_SPACESHIP) reduce 12) ((T_SR) reduce 12) (("[") reduce 12) (("^") reduce 12) (("{") reduce 12) (("|") reduce 12)) 25634 ((("%") reduce 54) (("(") reduce 54) (("*") reduce 54) (("+") reduce 54) (("-") reduce 54) ((".") reduce 54) (("/") reduce 54) ((";") reduce 54) (("<") reduce 54) ((">") reduce 54) (("?") reduce 54) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_BOOLEAN_AND) reduce 54) ((T_BOOLEAN_OR) reduce 54) ((T_COALESCE) reduce 54) ((T_INSTANCEOF) reduce 54) ((T_IS_EQUAL) reduce 54) ((T_IS_GREATER_OR_EQUAL) reduce 54) ((T_IS_IDENTICAL) reduce 54) ((T_IS_NOT_EQUAL) reduce 54) ((T_IS_NOT_IDENTICAL) reduce 54) ((T_IS_SMALLER_OR_EQUAL) reduce 54) ((T_LOGICAL_AND) reduce 54) ((T_LOGICAL_OR) reduce 54) ((T_LOGICAL_XOR) reduce 54) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 54) ((T_OBJECT_OPERATOR) reduce 54) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 54) ((T_POW) reduce 54) ((T_SL) reduce 54) ((T_SPACESHIP) reduce 54) ((T_SR) reduce 54) (("[") reduce 54) (("^") reduce 54) (("{") reduce 54) (("|") reduce 54)) 25635 ((("%") reduce 65) (("(") reduce 65) (("*") reduce 65) (("+") reduce 65) (("-") reduce 65) ((".") reduce 65) (("/") reduce 65) ((";") reduce 65) (("<") reduce 65) ((">") reduce 65) (("?") reduce 65) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_BOOLEAN_AND) reduce 65) ((T_BOOLEAN_OR) reduce 65) ((T_COALESCE) reduce 65) ((T_INSTANCEOF) reduce 65) ((T_IS_EQUAL) reduce 65) ((T_IS_GREATER_OR_EQUAL) reduce 65) ((T_IS_IDENTICAL) reduce 65) ((T_IS_NOT_EQUAL) reduce 65) ((T_IS_NOT_IDENTICAL) reduce 65) ((T_IS_SMALLER_OR_EQUAL) reduce 65) ((T_LOGICAL_AND) reduce 65) ((T_LOGICAL_OR) reduce 65) ((T_LOGICAL_XOR) reduce 65) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 65) ((T_OBJECT_OPERATOR) reduce 65) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 65) ((T_POW) reduce 65) ((T_SL) reduce 65) ((T_SPACESHIP) reduce 65) ((T_SR) reduce 65) (("[") reduce 65) (("^") reduce 65) (("{") reduce 65) (("|") reduce 65)) 25636 ((("%") reduce 74) (("(") reduce 74) (("*") reduce 74) (("+") reduce 74) (("-") reduce 74) ((".") reduce 74) (("/") reduce 74) ((";") reduce 74) (("<") reduce 74) ((">") reduce 74) (("?") reduce 74) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_BOOLEAN_AND) reduce 74) ((T_BOOLEAN_OR) reduce 74) ((T_COALESCE) reduce 74) ((T_INSTANCEOF) reduce 74) ((T_IS_EQUAL) reduce 74) ((T_IS_GREATER_OR_EQUAL) reduce 74) ((T_IS_IDENTICAL) reduce 74) ((T_IS_NOT_EQUAL) reduce 74) ((T_IS_NOT_IDENTICAL) reduce 74) ((T_IS_SMALLER_OR_EQUAL) reduce 74) ((T_LOGICAL_AND) reduce 74) ((T_LOGICAL_OR) reduce 74) ((T_LOGICAL_XOR) reduce 74) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 74) ((T_OBJECT_OPERATOR) reduce 74) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 74) ((T_POW) reduce 74) ((T_SL) reduce 74) ((T_SPACESHIP) reduce 74) ((T_SR) reduce 74) (("[") reduce 74) (("^") reduce 74) (("{") reduce 74) (("|") reduce 74)) 25637 ((("%") reduce 30) (("(") reduce 30) (("*") reduce 30) (("+") reduce 30) (("-") reduce 30) ((".") reduce 30) (("/") reduce 30) ((";") reduce 30) (("<") reduce 30) ((">") reduce 30) (("?") reduce 30) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_BOOLEAN_AND) reduce 30) ((T_BOOLEAN_OR) reduce 30) ((T_COALESCE) reduce 30) ((T_INSTANCEOF) reduce 30) ((T_IS_EQUAL) reduce 30) ((T_IS_GREATER_OR_EQUAL) reduce 30) ((T_IS_IDENTICAL) reduce 30) ((T_IS_NOT_EQUAL) reduce 30) ((T_IS_NOT_IDENTICAL) reduce 30) ((T_IS_SMALLER_OR_EQUAL) reduce 30) ((T_LOGICAL_AND) reduce 30) ((T_LOGICAL_OR) reduce 30) ((T_LOGICAL_XOR) reduce 30) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 30) ((T_OBJECT_OPERATOR) reduce 30) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 30) ((T_POW) reduce 30) ((T_SL) reduce 30) ((T_SPACESHIP) reduce 30) ((T_SR) reduce 30) (("[") reduce 30) (("^") reduce 30) (("{") reduce 30) (("|") reduce 30)) 25638 ((("%") reduce 68) (("(") reduce 68) (("*") reduce 68) (("+") reduce 68) (("-") reduce 68) ((".") reduce 68) (("/") reduce 68) ((";") reduce 68) (("<") reduce 68) ((">") reduce 68) (("?") reduce 68) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_BOOLEAN_AND) reduce 68) ((T_BOOLEAN_OR) reduce 68) ((T_COALESCE) reduce 68) ((T_INSTANCEOF) reduce 68) ((T_IS_EQUAL) reduce 68) ((T_IS_GREATER_OR_EQUAL) reduce 68) ((T_IS_IDENTICAL) reduce 68) ((T_IS_NOT_EQUAL) reduce 68) ((T_IS_NOT_IDENTICAL) reduce 68) ((T_IS_SMALLER_OR_EQUAL) reduce 68) ((T_LOGICAL_AND) reduce 68) ((T_LOGICAL_OR) reduce 68) ((T_LOGICAL_XOR) reduce 68) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 68) ((T_OBJECT_OPERATOR) reduce 68) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 68) ((T_POW) reduce 68) ((T_SL) reduce 68) ((T_SPACESHIP) reduce 68) ((T_SR) reduce 68) (("[") reduce 68) (("^") reduce 68) (("{") reduce 68) (("|") reduce 68)) 25639 ((("%") reduce 21) (("(") reduce 21) (("*") reduce 21) (("+") reduce 21) (("-") reduce 21) ((".") reduce 21) (("/") reduce 21) ((";") reduce 21) (("<") reduce 21) ((">") reduce 21) (("?") reduce 21) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_BOOLEAN_AND) reduce 21) ((T_BOOLEAN_OR) reduce 21) ((T_COALESCE) reduce 21) ((T_INSTANCEOF) reduce 21) ((T_IS_EQUAL) reduce 21) ((T_IS_GREATER_OR_EQUAL) reduce 21) ((T_IS_IDENTICAL) reduce 21) ((T_IS_NOT_EQUAL) reduce 21) ((T_IS_NOT_IDENTICAL) reduce 21) ((T_IS_SMALLER_OR_EQUAL) reduce 21) ((T_LOGICAL_AND) reduce 21) ((T_LOGICAL_OR) reduce 21) ((T_LOGICAL_XOR) reduce 21) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 21) ((T_OBJECT_OPERATOR) reduce 21) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 21) ((T_POW) reduce 21) ((T_SL) reduce 21) ((T_SPACESHIP) reduce 21) ((T_SR) reduce 21) (("[") reduce 21) (("^") reduce 21) (("{") reduce 21) (("|") reduce 21)) 25640 ((("%") reduce 23) (("(") reduce 23) (("*") reduce 23) (("+") reduce 23) (("-") reduce 23) ((".") reduce 23) (("/") reduce 23) ((";") reduce 23) (("<") reduce 23) ((">") reduce 23) (("?") reduce 23) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_BOOLEAN_AND) reduce 23) ((T_BOOLEAN_OR) reduce 23) ((T_COALESCE) reduce 23) ((T_INSTANCEOF) reduce 23) ((T_IS_EQUAL) reduce 23) ((T_IS_GREATER_OR_EQUAL) reduce 23) ((T_IS_IDENTICAL) reduce 23) ((T_IS_NOT_EQUAL) reduce 23) ((T_IS_NOT_IDENTICAL) reduce 23) ((T_IS_SMALLER_OR_EQUAL) reduce 23) ((T_LOGICAL_AND) reduce 23) ((T_LOGICAL_OR) reduce 23) ((T_LOGICAL_XOR) reduce 23) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 23) ((T_OBJECT_OPERATOR) reduce 23) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 23) ((T_POW) reduce 23) ((T_SL) reduce 23) ((T_SPACESHIP) reduce 23) ((T_SR) reduce 23) (("[") reduce 23) (("^") reduce 23) (("{") reduce 23) (("|") reduce 23)) 25641 ((("%") reduce 41) (("(") reduce 41) (("*") reduce 41) (("+") reduce 41) (("-") reduce 41) ((".") reduce 41) (("/") reduce 41) ((";") reduce 41) (("<") reduce 41) ((">") reduce 41) (("?") reduce 41) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_BOOLEAN_AND) reduce 41) ((T_BOOLEAN_OR) reduce 41) ((T_COALESCE) reduce 41) ((T_INSTANCEOF) reduce 41) ((T_IS_EQUAL) reduce 41) ((T_IS_GREATER_OR_EQUAL) reduce 41) ((T_IS_IDENTICAL) reduce 41) ((T_IS_NOT_EQUAL) reduce 41) ((T_IS_NOT_IDENTICAL) reduce 41) ((T_IS_SMALLER_OR_EQUAL) reduce 41) ((T_LOGICAL_AND) reduce 41) ((T_LOGICAL_OR) reduce 41) ((T_LOGICAL_XOR) reduce 41) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 41) ((T_OBJECT_OPERATOR) reduce 41) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 41) ((T_POW) reduce 41) ((T_SL) reduce 41) ((T_SPACESHIP) reduce 41) ((T_SR) reduce 41) (("[") reduce 41) (("^") reduce 41) (("{") reduce 41) (("|") reduce 41)) 25642 ((("%") reduce 62) (("(") reduce 62) (("*") reduce 62) (("+") reduce 62) (("-") reduce 62) ((".") reduce 62) (("/") reduce 62) ((";") reduce 62) (("<") reduce 62) ((">") reduce 62) (("?") reduce 62) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_BOOLEAN_AND) reduce 62) ((T_BOOLEAN_OR) reduce 62) ((T_COALESCE) reduce 62) ((T_INSTANCEOF) reduce 62) ((T_IS_EQUAL) reduce 62) ((T_IS_GREATER_OR_EQUAL) reduce 62) ((T_IS_IDENTICAL) reduce 62) ((T_IS_NOT_EQUAL) reduce 62) ((T_IS_NOT_IDENTICAL) reduce 62) ((T_IS_SMALLER_OR_EQUAL) reduce 62) ((T_LOGICAL_AND) reduce 62) ((T_LOGICAL_OR) reduce 62) ((T_LOGICAL_XOR) reduce 62) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 62) ((T_OBJECT_OPERATOR) reduce 62) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 62) ((T_POW) reduce 62) ((T_SL) reduce 62) ((T_SPACESHIP) reduce 62) ((T_SR) reduce 62) (("[") reduce 62) (("^") reduce 62) (("{") reduce 62) (("|") reduce 62)) 25643 ((("%") reduce 34) (("(") reduce 34) (("*") reduce 34) (("+") reduce 34) (("-") reduce 34) ((".") reduce 34) (("/") reduce 34) ((";") reduce 34) (("<") reduce 34) ((">") reduce 34) (("?") reduce 34) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_BOOLEAN_AND) reduce 34) ((T_BOOLEAN_OR) reduce 34) ((T_COALESCE) reduce 34) ((T_INSTANCEOF) reduce 34) ((T_IS_EQUAL) reduce 34) ((T_IS_GREATER_OR_EQUAL) reduce 34) ((T_IS_IDENTICAL) reduce 34) ((T_IS_NOT_EQUAL) reduce 34) ((T_IS_NOT_IDENTICAL) reduce 34) ((T_IS_SMALLER_OR_EQUAL) reduce 34) ((T_LOGICAL_AND) reduce 34) ((T_LOGICAL_OR) reduce 34) ((T_LOGICAL_XOR) reduce 34) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 34) ((T_OBJECT_OPERATOR) reduce 34) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 34) ((T_POW) reduce 34) ((T_SL) reduce 34) ((T_SPACESHIP) reduce 34) ((T_SR) reduce 34) (("[") reduce 34) (("^") reduce 34) (("{") reduce 34) (("|") reduce 34)) 25644 ((("%") reduce 40) (("(") reduce 40) (("*") reduce 40) (("+") reduce 40) (("-") reduce 40) ((".") reduce 40) (("/") reduce 40) ((";") reduce 40) (("<") reduce 40) ((">") reduce 40) (("?") reduce 40) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_BOOLEAN_AND) reduce 40) ((T_BOOLEAN_OR) reduce 40) ((T_COALESCE) reduce 40) ((T_INSTANCEOF) reduce 40) ((T_IS_EQUAL) reduce 40) ((T_IS_GREATER_OR_EQUAL) reduce 40) ((T_IS_IDENTICAL) reduce 40) ((T_IS_NOT_EQUAL) reduce 40) ((T_IS_NOT_IDENTICAL) reduce 40) ((T_IS_SMALLER_OR_EQUAL) reduce 40) ((T_LOGICAL_AND) reduce 40) ((T_LOGICAL_OR) reduce 40) ((T_LOGICAL_XOR) reduce 40) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 40) ((T_OBJECT_OPERATOR) reduce 40) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 40) ((T_POW) reduce 40) ((T_SL) reduce 40) ((T_SPACESHIP) reduce 40) ((T_SR) reduce 40) (("[") reduce 40) (("^") reduce 40) (("{") reduce 40) (("|") reduce 40)) 25645 ((("%") reduce 13) (("(") reduce 13) (("*") reduce 13) (("+") reduce 13) (("-") reduce 13) ((".") reduce 13) (("/") reduce 13) ((";") reduce 13) (("<") reduce 13) ((">") reduce 13) (("?") reduce 13) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_BOOLEAN_AND) reduce 13) ((T_BOOLEAN_OR) reduce 13) ((T_COALESCE) reduce 13) ((T_INSTANCEOF) reduce 13) ((T_IS_EQUAL) reduce 13) ((T_IS_GREATER_OR_EQUAL) reduce 13) ((T_IS_IDENTICAL) reduce 13) ((T_IS_NOT_EQUAL) reduce 13) ((T_IS_NOT_IDENTICAL) reduce 13) ((T_IS_SMALLER_OR_EQUAL) reduce 13) ((T_LOGICAL_AND) reduce 13) ((T_LOGICAL_OR) reduce 13) ((T_LOGICAL_XOR) reduce 13) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 13) ((T_OBJECT_OPERATOR) reduce 13) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 13) ((T_POW) reduce 13) ((T_SL) reduce 13) ((T_SPACESHIP) reduce 13) ((T_SR) reduce 13) (("[") reduce 13) (("^") reduce 13) (("{") reduce 13) (("|") reduce 13)) 25646 ((("%") reduce 55) (("(") reduce 55) (("*") reduce 55) (("+") reduce 55) (("-") reduce 55) ((".") reduce 55) (("/") reduce 55) ((";") reduce 55) (("<") reduce 55) ((">") reduce 55) (("?") reduce 55) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_BOOLEAN_AND) reduce 55) ((T_BOOLEAN_OR) reduce 55) ((T_COALESCE) reduce 55) ((T_INSTANCEOF) reduce 55) ((T_IS_EQUAL) reduce 55) ((T_IS_GREATER_OR_EQUAL) reduce 55) ((T_IS_IDENTICAL) reduce 55) ((T_IS_NOT_EQUAL) reduce 55) ((T_IS_NOT_IDENTICAL) reduce 55) ((T_IS_SMALLER_OR_EQUAL) reduce 55) ((T_LOGICAL_AND) reduce 55) ((T_LOGICAL_OR) reduce 55) ((T_LOGICAL_XOR) reduce 55) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 55) ((T_OBJECT_OPERATOR) reduce 55) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 55) ((T_POW) reduce 55) ((T_SL) reduce 55) ((T_SPACESHIP) reduce 55) ((T_SR) reduce 55) (("[") reduce 55) (("^") reduce 55) (("{") reduce 55) (("|") reduce 55)) 25647 ((("%") reduce 1) (("(") reduce 1) (("*") reduce 1) (("+") reduce 1) (("-") reduce 1) ((".") reduce 1) (("/") reduce 1) ((";") reduce 1) (("<") reduce 1) ((">") reduce 1) (("?") reduce 1) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_BOOLEAN_AND) reduce 1) ((T_BOOLEAN_OR) reduce 1) ((T_COALESCE) reduce 1) ((T_INSTANCEOF) reduce 1) ((T_IS_EQUAL) reduce 1) ((T_IS_GREATER_OR_EQUAL) reduce 1) ((T_IS_IDENTICAL) reduce 1) ((T_IS_NOT_EQUAL) reduce 1) ((T_IS_NOT_IDENTICAL) reduce 1) ((T_IS_SMALLER_OR_EQUAL) reduce 1) ((T_LOGICAL_AND) reduce 1) ((T_LOGICAL_OR) reduce 1) ((T_LOGICAL_XOR) reduce 1) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 1) ((T_OBJECT_OPERATOR) reduce 1) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 1) ((T_POW) reduce 1) ((T_SL) reduce 1) ((T_SPACESHIP) reduce 1) ((T_SR) reduce 1) (("[") reduce 1) (("^") reduce 1) (("{") reduce 1) (("|") reduce 1)) 25648 ((("%") reduce 2) (("(") reduce 2) (("*") reduce 2) (("+") reduce 2) (("-") reduce 2) ((".") reduce 2) (("/") reduce 2) ((";") reduce 2) (("<") reduce 2) ((">") reduce 2) (("?") reduce 2) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_BOOLEAN_AND) reduce 2) ((T_BOOLEAN_OR) reduce 2) ((T_COALESCE) reduce 2) ((T_INSTANCEOF) reduce 2) ((T_IS_EQUAL) reduce 2) ((T_IS_GREATER_OR_EQUAL) reduce 2) ((T_IS_IDENTICAL) reduce 2) ((T_IS_NOT_EQUAL) reduce 2) ((T_IS_NOT_IDENTICAL) reduce 2) ((T_IS_SMALLER_OR_EQUAL) reduce 2) ((T_LOGICAL_AND) reduce 2) ((T_LOGICAL_OR) reduce 2) ((T_LOGICAL_XOR) reduce 2) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 2) ((T_OBJECT_OPERATOR) reduce 2) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 2) ((T_POW) reduce 2) ((T_SL) reduce 2) ((T_SPACESHIP) reduce 2) ((T_SR) reduce 2) (("[") reduce 2) (("^") reduce 2) (("{") reduce 2) (("|") reduce 2)) 25649 ((("%") reduce 9) (("(") reduce 9) (("*") reduce 9) (("+") reduce 9) (("-") reduce 9) ((".") reduce 9) (("/") reduce 9) ((";") reduce 9) (("<") reduce 9) ((">") reduce 9) (("?") reduce 9) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_BOOLEAN_AND) reduce 9) ((T_BOOLEAN_OR) reduce 9) ((T_COALESCE) reduce 9) ((T_INSTANCEOF) reduce 9) ((T_IS_EQUAL) reduce 9) ((T_IS_GREATER_OR_EQUAL) reduce 9) ((T_IS_IDENTICAL) reduce 9) ((T_IS_NOT_EQUAL) reduce 9) ((T_IS_NOT_IDENTICAL) reduce 9) ((T_IS_SMALLER_OR_EQUAL) reduce 9) ((T_LOGICAL_AND) reduce 9) ((T_LOGICAL_OR) reduce 9) ((T_LOGICAL_XOR) reduce 9) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 9) ((T_OBJECT_OPERATOR) reduce 9) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 9) ((T_POW) reduce 9) ((T_SL) reduce 9) ((T_SPACESHIP) reduce 9) ((T_SR) reduce 9) (("[") reduce 9) (("^") reduce 9) (("{") reduce 9) (("|") reduce 9)) 25650 ((("%") reduce 33) (("(") reduce 33) (("*") reduce 33) (("+") reduce 33) (("-") reduce 33) ((".") reduce 33) (("/") reduce 33) ((";") reduce 33) (("<") reduce 33) ((">") reduce 33) (("?") reduce 33) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_BOOLEAN_AND) reduce 33) ((T_BOOLEAN_OR) reduce 33) ((T_COALESCE) reduce 33) ((T_INSTANCEOF) reduce 33) ((T_IS_EQUAL) reduce 33) ((T_IS_GREATER_OR_EQUAL) reduce 33) ((T_IS_IDENTICAL) reduce 33) ((T_IS_NOT_EQUAL) reduce 33) ((T_IS_NOT_IDENTICAL) reduce 33) ((T_IS_SMALLER_OR_EQUAL) reduce 33) ((T_LOGICAL_AND) reduce 33) ((T_LOGICAL_OR) reduce 33) ((T_LOGICAL_XOR) reduce 33) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 33) ((T_OBJECT_OPERATOR) reduce 33) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 33) ((T_POW) reduce 33) ((T_SL) reduce 33) ((T_SPACESHIP) reduce 33) ((T_SR) reduce 33) (("[") reduce 33) (("^") reduce 33) (("{") reduce 33) (("|") reduce 33)) 25651 ((("%") reduce 58) (("(") reduce 58) (("*") reduce 58) (("+") reduce 58) (("-") reduce 58) ((".") reduce 58) (("/") reduce 58) ((";") reduce 58) (("<") reduce 58) ((">") reduce 58) (("?") reduce 58) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_BOOLEAN_AND) reduce 58) ((T_BOOLEAN_OR) reduce 58) ((T_COALESCE) reduce 58) ((T_INSTANCEOF) reduce 58) ((T_IS_EQUAL) reduce 58) ((T_IS_GREATER_OR_EQUAL) reduce 58) ((T_IS_IDENTICAL) reduce 58) ((T_IS_NOT_EQUAL) reduce 58) ((T_IS_NOT_IDENTICAL) reduce 58) ((T_IS_SMALLER_OR_EQUAL) reduce 58) ((T_LOGICAL_AND) reduce 58) ((T_LOGICAL_OR) reduce 58) ((T_LOGICAL_XOR) reduce 58) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 58) ((T_OBJECT_OPERATOR) reduce 58) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 58) ((T_POW) reduce 58) ((T_SL) reduce 58) ((T_SPACESHIP) reduce 58) ((T_SR) reduce 58) (("[") reduce 58) (("^") reduce 58) (("{") reduce 58) (("|") reduce 58)) 25652 ((("%") reduce 37) (("(") reduce 37) (("*") reduce 37) (("+") reduce 37) (("-") reduce 37) ((".") reduce 37) (("/") reduce 37) ((";") reduce 37) (("<") reduce 37) ((">") reduce 37) (("?") reduce 37) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_BOOLEAN_AND) reduce 37) ((T_BOOLEAN_OR) reduce 37) ((T_COALESCE) reduce 37) ((T_INSTANCEOF) reduce 37) ((T_IS_EQUAL) reduce 37) ((T_IS_GREATER_OR_EQUAL) reduce 37) ((T_IS_IDENTICAL) reduce 37) ((T_IS_NOT_EQUAL) reduce 37) ((T_IS_NOT_IDENTICAL) reduce 37) ((T_IS_SMALLER_OR_EQUAL) reduce 37) ((T_LOGICAL_AND) reduce 37) ((T_LOGICAL_OR) reduce 37) ((T_LOGICAL_XOR) reduce 37) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 37) ((T_OBJECT_OPERATOR) reduce 37) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 37) ((T_POW) reduce 37) ((T_SL) reduce 37) ((T_SPACESHIP) reduce 37) ((T_SR) reduce 37) (("[") reduce 37) (("^") reduce 37) (("{") reduce 37) (("|") reduce 37)) 25653 ((("%") reduce 64) (("(") reduce 64) (("*") reduce 64) (("+") reduce 64) (("-") reduce 64) ((".") reduce 64) (("/") reduce 64) ((";") reduce 64) (("<") reduce 64) ((">") reduce 64) (("?") reduce 64) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_BOOLEAN_AND) reduce 64) ((T_BOOLEAN_OR) reduce 64) ((T_COALESCE) reduce 64) ((T_INSTANCEOF) reduce 64) ((T_IS_EQUAL) reduce 64) ((T_IS_GREATER_OR_EQUAL) reduce 64) ((T_IS_IDENTICAL) reduce 64) ((T_IS_NOT_EQUAL) reduce 64) ((T_IS_NOT_IDENTICAL) reduce 64) ((T_IS_SMALLER_OR_EQUAL) reduce 64) ((T_LOGICAL_AND) reduce 64) ((T_LOGICAL_OR) reduce 64) ((T_LOGICAL_XOR) reduce 64) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 64) ((T_OBJECT_OPERATOR) reduce 64) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 64) ((T_POW) reduce 64) ((T_SL) reduce 64) ((T_SPACESHIP) reduce 64) ((T_SR) reduce 64) (("[") reduce 64) (("^") reduce 64) (("{") reduce 64) (("|") reduce 64)) 25654 ((("%") reduce 46) (("(") reduce 46) (("*") reduce 46) (("+") reduce 46) (("-") reduce 46) ((".") reduce 46) (("/") reduce 46) ((";") reduce 46) (("<") reduce 46) ((">") reduce 46) (("?") reduce 46) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_BOOLEAN_AND) reduce 46) ((T_BOOLEAN_OR) reduce 46) ((T_COALESCE) reduce 46) ((T_INSTANCEOF) reduce 46) ((T_IS_EQUAL) reduce 46) ((T_IS_GREATER_OR_EQUAL) reduce 46) ((T_IS_IDENTICAL) reduce 46) ((T_IS_NOT_EQUAL) reduce 46) ((T_IS_NOT_IDENTICAL) reduce 46) ((T_IS_SMALLER_OR_EQUAL) reduce 46) ((T_LOGICAL_AND) reduce 46) ((T_LOGICAL_OR) reduce 46) ((T_LOGICAL_XOR) reduce 46) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 46) ((T_OBJECT_OPERATOR) reduce 46) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 46) ((T_POW) reduce 46) ((T_SL) reduce 46) ((T_SPACESHIP) reduce 46) ((T_SR) reduce 46) (("[") reduce 46) (("^") reduce 46) (("{") reduce 46) (("|") reduce 46)) 25655 ((("%") reduce 8) (("(") reduce 8) (("*") reduce 8) (("+") reduce 8) (("-") reduce 8) ((".") reduce 8) (("/") reduce 8) ((";") reduce 8) (("<") reduce 8) ((">") reduce 8) (("?") reduce 8) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_BOOLEAN_AND) reduce 8) ((T_BOOLEAN_OR) reduce 8) ((T_COALESCE) reduce 8) ((T_INSTANCEOF) reduce 8) ((T_IS_EQUAL) reduce 8) ((T_IS_GREATER_OR_EQUAL) reduce 8) ((T_IS_IDENTICAL) reduce 8) ((T_IS_NOT_EQUAL) reduce 8) ((T_IS_NOT_IDENTICAL) reduce 8) ((T_IS_SMALLER_OR_EQUAL) reduce 8) ((T_LOGICAL_AND) reduce 8) ((T_LOGICAL_OR) reduce 8) ((T_LOGICAL_XOR) reduce 8) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 8) ((T_OBJECT_OPERATOR) reduce 8) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 8) ((T_POW) reduce 8) ((T_SL) reduce 8) ((T_SPACESHIP) reduce 8) ((T_SR) reduce 8) (("[") reduce 8) (("^") reduce 8) (("{") reduce 8) (("|") reduce 8)) 25656 ((("%") reduce 6) (("(") reduce 6) (("*") reduce 6) (("+") reduce 6) (("-") reduce 6) ((".") reduce 6) (("/") reduce 6) ((";") reduce 6) (("<") reduce 6) ((">") reduce 6) (("?") reduce 6) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_BOOLEAN_AND) reduce 6) ((T_BOOLEAN_OR) reduce 6) ((T_COALESCE) reduce 6) ((T_INSTANCEOF) reduce 6) ((T_IS_EQUAL) reduce 6) ((T_IS_GREATER_OR_EQUAL) reduce 6) ((T_IS_IDENTICAL) reduce 6) ((T_IS_NOT_EQUAL) reduce 6) ((T_IS_NOT_IDENTICAL) reduce 6) ((T_IS_SMALLER_OR_EQUAL) reduce 6) ((T_LOGICAL_AND) reduce 6) ((T_LOGICAL_OR) reduce 6) ((T_LOGICAL_XOR) reduce 6) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 6) ((T_OBJECT_OPERATOR) reduce 6) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 6) ((T_POW) reduce 6) ((T_SL) reduce 6) ((T_SPACESHIP) reduce 6) ((T_SR) reduce 6) (("[") reduce 6) (("^") reduce 6) (("{") reduce 6) (("|") reduce 6)) 25657 ((("%") reduce 7) (("(") reduce 7) (("*") reduce 7) (("+") reduce 7) (("-") reduce 7) ((".") reduce 7) (("/") reduce 7) ((";") reduce 7) (("<") reduce 7) ((">") reduce 7) (("?") reduce 7) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_BOOLEAN_AND) reduce 7) ((T_BOOLEAN_OR) reduce 7) ((T_COALESCE) reduce 7) ((T_INSTANCEOF) reduce 7) ((T_IS_EQUAL) reduce 7) ((T_IS_GREATER_OR_EQUAL) reduce 7) ((T_IS_IDENTICAL) reduce 7) ((T_IS_NOT_EQUAL) reduce 7) ((T_IS_NOT_IDENTICAL) reduce 7) ((T_IS_SMALLER_OR_EQUAL) reduce 7) ((T_LOGICAL_AND) reduce 7) ((T_LOGICAL_OR) reduce 7) ((T_LOGICAL_XOR) reduce 7) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 7) ((T_OBJECT_OPERATOR) reduce 7) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 7) ((T_POW) reduce 7) ((T_SL) reduce 7) ((T_SPACESHIP) reduce 7) ((T_SR) reduce 7) (("[") reduce 7) (("^") reduce 7) (("{") reduce 7) (("|") reduce 7)) 25658 ((("%") reduce 69) (("(") reduce 69) (("*") reduce 69) (("+") reduce 69) (("-") reduce 69) ((".") reduce 69) (("/") reduce 69) ((";") reduce 69) (("<") reduce 69) ((">") reduce 69) (("?") reduce 69) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_BOOLEAN_AND) reduce 69) ((T_BOOLEAN_OR) reduce 69) ((T_COALESCE) reduce 69) ((T_INSTANCEOF) reduce 69) ((T_IS_EQUAL) reduce 69) ((T_IS_GREATER_OR_EQUAL) reduce 69) ((T_IS_IDENTICAL) reduce 69) ((T_IS_NOT_EQUAL) reduce 69) ((T_IS_NOT_IDENTICAL) reduce 69) ((T_IS_SMALLER_OR_EQUAL) reduce 69) ((T_LOGICAL_AND) reduce 69) ((T_LOGICAL_OR) reduce 69) ((T_LOGICAL_XOR) reduce 69) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 69) ((T_OBJECT_OPERATOR) reduce 69) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 69) ((T_POW) reduce 69) ((T_SL) reduce 69) ((T_SPACESHIP) reduce 69) ((T_SR) reduce 69) (("[") reduce 69) (("^") reduce 69) (("{") reduce 69) (("|") reduce 69)) 25659 ((("%") reduce 63) (("(") reduce 63) (("*") reduce 63) (("+") reduce 63) (("-") reduce 63) ((".") reduce 63) (("/") reduce 63) ((";") reduce 63) (("<") reduce 63) ((">") reduce 63) (("?") reduce 63) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_BOOLEAN_AND) reduce 63) ((T_BOOLEAN_OR) reduce 63) ((T_COALESCE) reduce 63) ((T_INSTANCEOF) reduce 63) ((T_IS_EQUAL) reduce 63) ((T_IS_GREATER_OR_EQUAL) reduce 63) ((T_IS_IDENTICAL) reduce 63) ((T_IS_NOT_EQUAL) reduce 63) ((T_IS_NOT_IDENTICAL) reduce 63) ((T_IS_SMALLER_OR_EQUAL) reduce 63) ((T_LOGICAL_AND) reduce 63) ((T_LOGICAL_OR) reduce 63) ((T_LOGICAL_XOR) reduce 63) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 63) ((T_OBJECT_OPERATOR) reduce 63) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 63) ((T_POW) reduce 63) ((T_SL) reduce 63) ((T_SPACESHIP) reduce 63) ((T_SR) reduce 63) (("[") reduce 63) (("^") reduce 63) (("{") reduce 63) (("|") reduce 63)) 25660 ((("%") reduce 56) (("(") reduce 56) (("*") reduce 56) (("+") reduce 56) (("-") reduce 56) ((".") reduce 56) (("/") reduce 56) ((";") reduce 56) (("<") reduce 56) ((">") reduce 56) (("?") reduce 56) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_BOOLEAN_AND) reduce 56) ((T_BOOLEAN_OR) reduce 56) ((T_COALESCE) reduce 56) ((T_INSTANCEOF) reduce 56) ((T_IS_EQUAL) reduce 56) ((T_IS_GREATER_OR_EQUAL) reduce 56) ((T_IS_IDENTICAL) reduce 56) ((T_IS_NOT_EQUAL) reduce 56) ((T_IS_NOT_IDENTICAL) reduce 56) ((T_IS_SMALLER_OR_EQUAL) reduce 56) ((T_LOGICAL_AND) reduce 56) ((T_LOGICAL_OR) reduce 56) ((T_LOGICAL_XOR) reduce 56) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 56) ((T_OBJECT_OPERATOR) reduce 56) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 56) ((T_POW) reduce 56) ((T_SL) reduce 56) ((T_SPACESHIP) reduce 56) ((T_SR) reduce 56) (("[") reduce 56) (("^") reduce 56) (("{") reduce 56) (("|") reduce 56)) 25661 ((("%") reduce 10) (("(") reduce 10) (("*") reduce 10) (("+") reduce 10) (("-") reduce 10) ((".") reduce 10) (("/") reduce 10) ((";") reduce 10) (("<") reduce 10) ((">") reduce 10) (("?") reduce 10) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_BOOLEAN_AND) reduce 10) ((T_BOOLEAN_OR) reduce 10) ((T_COALESCE) reduce 10) ((T_INSTANCEOF) reduce 10) ((T_IS_EQUAL) reduce 10) ((T_IS_GREATER_OR_EQUAL) reduce 10) ((T_IS_IDENTICAL) reduce 10) ((T_IS_NOT_EQUAL) reduce 10) ((T_IS_NOT_IDENTICAL) reduce 10) ((T_IS_SMALLER_OR_EQUAL) reduce 10) ((T_LOGICAL_AND) reduce 10) ((T_LOGICAL_OR) reduce 10) ((T_LOGICAL_XOR) reduce 10) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 10) ((T_OBJECT_OPERATOR) reduce 10) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 10) ((T_POW) reduce 10) ((T_SL) reduce 10) ((T_SPACESHIP) reduce 10) ((T_SR) reduce 10) (("[") reduce 10) (("^") reduce 10) (("{") reduce 10) (("|") reduce 10)) 25662 ((("%") reduce 67) (("(") reduce 67) (("*") reduce 67) (("+") reduce 67) (("-") reduce 67) ((".") reduce 67) (("/") reduce 67) ((";") reduce 67) (("<") reduce 67) ((">") reduce 67) (("?") reduce 67) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_BOOLEAN_AND) reduce 67) ((T_BOOLEAN_OR) reduce 67) ((T_COALESCE) reduce 67) ((T_INSTANCEOF) reduce 67) ((T_IS_EQUAL) reduce 67) ((T_IS_GREATER_OR_EQUAL) reduce 67) ((T_IS_IDENTICAL) reduce 67) ((T_IS_NOT_EQUAL) reduce 67) ((T_IS_NOT_IDENTICAL) reduce 67) ((T_IS_SMALLER_OR_EQUAL) reduce 67) ((T_LOGICAL_AND) reduce 67) ((T_LOGICAL_OR) reduce 67) ((T_LOGICAL_XOR) reduce 67) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 67) ((T_OBJECT_OPERATOR) reduce 67) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 67) ((T_POW) reduce 67) ((T_SL) reduce 67) ((T_SPACESHIP) reduce 67) ((T_SR) reduce 67) (("[") reduce 67) (("^") reduce 67) (("{") reduce 67) (("|") reduce 67)) 25663 ((("%") reduce 44) (("(") reduce 44) (("*") reduce 44) (("+") reduce 44) (("-") reduce 44) ((".") reduce 44) (("/") reduce 44) ((";") reduce 44) (("<") reduce 44) ((">") reduce 44) (("?") reduce 44) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_BOOLEAN_AND) reduce 44) ((T_BOOLEAN_OR) reduce 44) ((T_COALESCE) reduce 44) ((T_INSTANCEOF) reduce 44) ((T_IS_EQUAL) reduce 44) ((T_IS_GREATER_OR_EQUAL) reduce 44) ((T_IS_IDENTICAL) reduce 44) ((T_IS_NOT_EQUAL) reduce 44) ((T_IS_NOT_IDENTICAL) reduce 44) ((T_IS_SMALLER_OR_EQUAL) reduce 44) ((T_LOGICAL_AND) reduce 44) ((T_LOGICAL_OR) reduce 44) ((T_LOGICAL_XOR) reduce 44) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 44) ((T_OBJECT_OPERATOR) reduce 44) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 44) ((T_POW) reduce 44) ((T_SL) reduce 44) ((T_SPACESHIP) reduce 44) ((T_SR) reduce 44) (("[") reduce 44) (("^") reduce 44) (("{") reduce 44) (("|") reduce 44)) 25664 ((("%") reduce 75) (("(") reduce 75) (("*") reduce 75) (("+") reduce 75) (("-") reduce 75) ((".") reduce 75) (("/") reduce 75) ((";") reduce 75) (("<") reduce 75) ((">") reduce 75) (("?") reduce 75) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_BOOLEAN_AND) reduce 75) ((T_BOOLEAN_OR) reduce 75) ((T_COALESCE) reduce 75) ((T_INSTANCEOF) reduce 75) ((T_IS_EQUAL) reduce 75) ((T_IS_GREATER_OR_EQUAL) reduce 75) ((T_IS_IDENTICAL) reduce 75) ((T_IS_NOT_EQUAL) reduce 75) ((T_IS_NOT_IDENTICAL) reduce 75) ((T_IS_SMALLER_OR_EQUAL) reduce 75) ((T_LOGICAL_AND) reduce 75) ((T_LOGICAL_OR) reduce 75) ((T_LOGICAL_XOR) reduce 75) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 75) ((T_OBJECT_OPERATOR) reduce 75) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 75) ((T_POW) reduce 75) ((T_SL) reduce 75) ((T_SPACESHIP) reduce 75) ((T_SR) reduce 75) (("[") reduce 75) (("^") reduce 75) (("{") reduce 75) (("|") reduce 75)) 25665 ((("%") reduce 76) (("(") reduce 76) (("*") reduce 76) (("+") reduce 76) (("-") reduce 76) ((".") reduce 76) (("/") reduce 76) ((";") reduce 76) (("<") reduce 76) ((">") reduce 76) (("?") reduce 76) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_BOOLEAN_AND) reduce 76) ((T_BOOLEAN_OR) reduce 76) ((T_COALESCE) reduce 76) ((T_INSTANCEOF) reduce 76) ((T_IS_EQUAL) reduce 76) ((T_IS_GREATER_OR_EQUAL) reduce 76) ((T_IS_IDENTICAL) reduce 76) ((T_IS_NOT_EQUAL) reduce 76) ((T_IS_NOT_IDENTICAL) reduce 76) ((T_IS_SMALLER_OR_EQUAL) reduce 76) ((T_LOGICAL_AND) reduce 76) ((T_LOGICAL_OR) reduce 76) ((T_LOGICAL_XOR) reduce 76) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 76) ((T_OBJECT_OPERATOR) reduce 76) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 76) ((T_POW) reduce 76) ((T_SL) reduce 76) ((T_SPACESHIP) reduce 76) ((T_SR) reduce 76) (("[") reduce 76) (("^") reduce 76) (("{") reduce 76) (("|") reduce 76)) 25666 ((("%") reduce 77) (("(") reduce 77) (("*") reduce 77) (("+") reduce 77) (("-") reduce 77) ((".") reduce 77) (("/") reduce 77) ((";") reduce 77) (("<") reduce 77) ((">") reduce 77) (("?") reduce 77) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_BOOLEAN_AND) reduce 77) ((T_BOOLEAN_OR) reduce 77) ((T_COALESCE) reduce 77) ((T_INSTANCEOF) reduce 77) ((T_IS_EQUAL) reduce 77) ((T_IS_GREATER_OR_EQUAL) reduce 77) ((T_IS_IDENTICAL) reduce 77) ((T_IS_NOT_EQUAL) reduce 77) ((T_IS_NOT_IDENTICAL) reduce 77) ((T_IS_SMALLER_OR_EQUAL) reduce 77) ((T_LOGICAL_AND) reduce 77) ((T_LOGICAL_OR) reduce 77) ((T_LOGICAL_XOR) reduce 77) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 77) ((T_OBJECT_OPERATOR) reduce 77) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 77) ((T_POW) reduce 77) ((T_SL) reduce 77) ((T_SPACESHIP) reduce 77) ((T_SR) reduce 77) (("[") reduce 77) (("^") reduce 77) (("{") reduce 77) (("|") reduce 77)) 25667 ((("%") reduce 78) (("(") reduce 78) (("*") reduce 78) (("+") reduce 78) (("-") reduce 78) ((".") reduce 78) (("/") reduce 78) ((";") reduce 78) (("<") reduce 78) ((">") reduce 78) (("?") reduce 78) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_BOOLEAN_AND) reduce 78) ((T_BOOLEAN_OR) reduce 78) ((T_COALESCE) reduce 78) ((T_INSTANCEOF) reduce 78) ((T_IS_EQUAL) reduce 78) ((T_IS_GREATER_OR_EQUAL) reduce 78) ((T_IS_IDENTICAL) reduce 78) ((T_IS_NOT_EQUAL) reduce 78) ((T_IS_NOT_IDENTICAL) reduce 78) ((T_IS_SMALLER_OR_EQUAL) reduce 78) ((T_LOGICAL_AND) reduce 78) ((T_LOGICAL_OR) reduce 78) ((T_LOGICAL_XOR) reduce 78) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 78) ((T_OBJECT_OPERATOR) reduce 78) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 78) ((T_POW) reduce 78) ((T_SL) reduce 78) ((T_SPACESHIP) reduce 78) ((T_SR) reduce 78) (("[") reduce 78) (("^") reduce 78) (("{") reduce 78) (("|") reduce 78)) 25668 ((("%") reduce 4) (("(") reduce 4) (("*") reduce 4) (("+") reduce 4) (("-") reduce 4) ((".") reduce 4) (("/") reduce 4) ((";") reduce 4) (("<") reduce 4) ((">") reduce 4) (("?") reduce 4) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_BOOLEAN_AND) reduce 4) ((T_BOOLEAN_OR) reduce 4) ((T_COALESCE) reduce 4) ((T_INSTANCEOF) reduce 4) ((T_IS_EQUAL) reduce 4) ((T_IS_GREATER_OR_EQUAL) reduce 4) ((T_IS_IDENTICAL) reduce 4) ((T_IS_NOT_EQUAL) reduce 4) ((T_IS_NOT_IDENTICAL) reduce 4) ((T_IS_SMALLER_OR_EQUAL) reduce 4) ((T_LOGICAL_AND) reduce 4) ((T_LOGICAL_OR) reduce 4) ((T_LOGICAL_XOR) reduce 4) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 4) ((T_OBJECT_OPERATOR) reduce 4) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 4) ((T_POW) reduce 4) ((T_SL) reduce 4) ((T_SPACESHIP) reduce 4) ((T_SR) reduce 4) (("[") reduce 4) (("^") reduce 4) (("{") reduce 4) (("|") reduce 4)) 25669 ((("%") reduce 5) (("(") reduce 5) (("*") reduce 5) (("+") reduce 5) (("-") reduce 5) ((".") reduce 5) (("/") reduce 5) ((";") reduce 5) (("<") reduce 5) ((">") reduce 5) (("?") reduce 5) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_BOOLEAN_AND) reduce 5) ((T_BOOLEAN_OR) reduce 5) ((T_COALESCE) reduce 5) ((T_INSTANCEOF) reduce 5) ((T_IS_EQUAL) reduce 5) ((T_IS_GREATER_OR_EQUAL) reduce 5) ((T_IS_IDENTICAL) reduce 5) ((T_IS_NOT_EQUAL) reduce 5) ((T_IS_NOT_IDENTICAL) reduce 5) ((T_IS_SMALLER_OR_EQUAL) reduce 5) ((T_LOGICAL_AND) reduce 5) ((T_LOGICAL_OR) reduce 5) ((T_LOGICAL_XOR) reduce 5) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 5) ((T_OBJECT_OPERATOR) reduce 5) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 5) ((T_POW) reduce 5) ((T_SL) reduce 5) ((T_SPACESHIP) reduce 5) ((T_SR) reduce 5) (("[") reduce 5) (("^") reduce 5) (("{") reduce 5) (("|") reduce 5)) 25670 ((("%") reduce 43) (("(") reduce 43) (("*") reduce 43) (("+") reduce 43) (("-") reduce 43) ((".") reduce 43) (("/") reduce 43) ((";") reduce 43) (("<") reduce 43) ((">") reduce 43) (("?") reduce 43) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_BOOLEAN_AND) reduce 43) ((T_BOOLEAN_OR) reduce 43) ((T_COALESCE) reduce 43) ((T_INSTANCEOF) reduce 43) ((T_IS_EQUAL) reduce 43) ((T_IS_GREATER_OR_EQUAL) reduce 43) ((T_IS_IDENTICAL) reduce 43) ((T_IS_NOT_EQUAL) reduce 43) ((T_IS_NOT_IDENTICAL) reduce 43) ((T_IS_SMALLER_OR_EQUAL) reduce 43) ((T_LOGICAL_AND) reduce 43) ((T_LOGICAL_OR) reduce 43) ((T_LOGICAL_XOR) reduce 43) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 43) ((T_OBJECT_OPERATOR) reduce 43) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 43) ((T_POW) reduce 43) ((T_SL) reduce 43) ((T_SPACESHIP) reduce 43) ((T_SR) reduce 43) (("[") reduce 43) (("^") reduce 43) (("{") reduce 43) (("|") reduce 43)) 25671 ((("%") reduce 72) (("(") reduce 72) (("*") reduce 72) (("+") reduce 72) (("-") reduce 72) ((".") reduce 72) (("/") reduce 72) ((";") reduce 72) (("<") reduce 72) ((">") reduce 72) (("?") reduce 72) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_BOOLEAN_AND) reduce 72) ((T_BOOLEAN_OR) reduce 72) ((T_COALESCE) reduce 72) ((T_INSTANCEOF) reduce 72) ((T_IS_EQUAL) reduce 72) ((T_IS_GREATER_OR_EQUAL) reduce 72) ((T_IS_IDENTICAL) reduce 72) ((T_IS_NOT_EQUAL) reduce 72) ((T_IS_NOT_IDENTICAL) reduce 72) ((T_IS_SMALLER_OR_EQUAL) reduce 72) ((T_LOGICAL_AND) reduce 72) ((T_LOGICAL_OR) reduce 72) ((T_LOGICAL_XOR) reduce 72) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 72) ((T_OBJECT_OPERATOR) reduce 72) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 72) ((T_POW) reduce 72) ((T_SL) reduce 72) ((T_SPACESHIP) reduce 72) ((T_SR) reduce 72) (("[") reduce 72) (("^") reduce 72) (("{") reduce 72) (("|") reduce 72)) 25672 ((("%") reduce 81) (("(") reduce 81) (("*") reduce 81) (("+") reduce 81) (("-") reduce 81) ((".") reduce 81) (("/") reduce 81) ((";") reduce 81) (("<") reduce 81) ((">") reduce 81) (("?") reduce 81) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_BOOLEAN_AND) reduce 81) ((T_BOOLEAN_OR) reduce 81) ((T_COALESCE) reduce 81) ((T_INSTANCEOF) reduce 81) ((T_IS_EQUAL) reduce 81) ((T_IS_GREATER_OR_EQUAL) reduce 81) ((T_IS_IDENTICAL) reduce 81) ((T_IS_NOT_EQUAL) reduce 81) ((T_IS_NOT_IDENTICAL) reduce 81) ((T_IS_SMALLER_OR_EQUAL) reduce 81) ((T_LOGICAL_AND) reduce 81) ((T_LOGICAL_OR) reduce 81) ((T_LOGICAL_XOR) reduce 81) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 81) ((T_OBJECT_OPERATOR) reduce 81) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 81) ((T_POW) reduce 81) ((T_SL) reduce 81) ((T_SPACESHIP) reduce 81) ((T_SR) reduce 81) (("[") reduce 81) (("^") reduce 81) (("{") reduce 81) (("|") reduce 81)) 25673 ((("%") reduce 47) (("(") reduce 47) (("*") reduce 47) (("+") reduce 47) (("-") reduce 47) ((".") reduce 47) (("/") reduce 47) ((";") reduce 47) (("<") reduce 47) ((">") reduce 47) (("?") reduce 47) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_BOOLEAN_AND) reduce 47) ((T_BOOLEAN_OR) reduce 47) ((T_COALESCE) reduce 47) ((T_INSTANCEOF) reduce 47) ((T_IS_EQUAL) reduce 47) ((T_IS_GREATER_OR_EQUAL) reduce 47) ((T_IS_IDENTICAL) reduce 47) ((T_IS_NOT_EQUAL) reduce 47) ((T_IS_NOT_IDENTICAL) reduce 47) ((T_IS_SMALLER_OR_EQUAL) reduce 47) ((T_LOGICAL_AND) reduce 47) ((T_LOGICAL_OR) reduce 47) ((T_LOGICAL_XOR) reduce 47) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 47) ((T_OBJECT_OPERATOR) reduce 47) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 47) ((T_POW) reduce 47) ((T_SL) reduce 47) ((T_SPACESHIP) reduce 47) ((T_SR) reduce 47) (("[") reduce 47) (("^") reduce 47) (("{") reduce 47) (("|") reduce 47)) 25674 ((("%") reduce 31) (("(") reduce 31) (("*") reduce 31) (("+") reduce 31) (("-") reduce 31) ((".") reduce 31) (("/") reduce 31) ((";") reduce 31) (("<") reduce 31) ((">") reduce 31) (("?") reduce 31) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_BOOLEAN_AND) reduce 31) ((T_BOOLEAN_OR) reduce 31) ((T_COALESCE) reduce 31) ((T_INSTANCEOF) reduce 31) ((T_IS_EQUAL) reduce 31) ((T_IS_GREATER_OR_EQUAL) reduce 31) ((T_IS_IDENTICAL) reduce 31) ((T_IS_NOT_EQUAL) reduce 31) ((T_IS_NOT_IDENTICAL) reduce 31) ((T_IS_SMALLER_OR_EQUAL) reduce 31) ((T_LOGICAL_AND) reduce 31) ((T_LOGICAL_OR) reduce 31) ((T_LOGICAL_XOR) reduce 31) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 31) ((T_OBJECT_OPERATOR) reduce 31) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 31) ((T_POW) reduce 31) ((T_SL) reduce 31) ((T_SPACESHIP) reduce 31) ((T_SR) reduce 31) (("[") reduce 31) (("^") reduce 31) (("{") reduce 31) (("|") reduce 31)) 25675 ((("%") reduce 57) (("(") reduce 57) (("*") reduce 57) (("+") reduce 57) (("-") reduce 57) ((".") reduce 57) (("/") reduce 57) ((";") reduce 57) (("<") reduce 57) ((">") reduce 57) (("?") reduce 57) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_BOOLEAN_AND) reduce 57) ((T_BOOLEAN_OR) reduce 57) ((T_COALESCE) reduce 57) ((T_INSTANCEOF) reduce 57) ((T_IS_EQUAL) reduce 57) ((T_IS_GREATER_OR_EQUAL) reduce 57) ((T_IS_IDENTICAL) reduce 57) ((T_IS_NOT_EQUAL) reduce 57) ((T_IS_NOT_IDENTICAL) reduce 57) ((T_IS_SMALLER_OR_EQUAL) reduce 57) ((T_LOGICAL_AND) reduce 57) ((T_LOGICAL_OR) reduce 57) ((T_LOGICAL_XOR) reduce 57) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 57) ((T_OBJECT_OPERATOR) reduce 57) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 57) ((T_POW) reduce 57) ((T_SL) reduce 57) ((T_SPACESHIP) reduce 57) ((T_SR) reduce 57) (("[") reduce 57) (("^") reduce 57) (("{") reduce 57) (("|") reduce 57)) 25676 ((("%") reduce 61) (("(") reduce 61) (("*") reduce 61) (("+") reduce 61) (("-") reduce 61) ((".") reduce 61) (("/") reduce 61) ((";") reduce 61) (("<") reduce 61) ((">") reduce 61) (("?") reduce 61) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_BOOLEAN_AND) reduce 61) ((T_BOOLEAN_OR) reduce 61) ((T_COALESCE) reduce 61) ((T_INSTANCEOF) reduce 61) ((T_IS_EQUAL) reduce 61) ((T_IS_GREATER_OR_EQUAL) reduce 61) ((T_IS_IDENTICAL) reduce 61) ((T_IS_NOT_EQUAL) reduce 61) ((T_IS_NOT_IDENTICAL) reduce 61) ((T_IS_SMALLER_OR_EQUAL) reduce 61) ((T_LOGICAL_AND) reduce 61) ((T_LOGICAL_OR) reduce 61) ((T_LOGICAL_XOR) reduce 61) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 61) ((T_OBJECT_OPERATOR) reduce 61) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 61) ((T_POW) reduce 61) ((T_SL) reduce 61) ((T_SPACESHIP) reduce 61) ((T_SR) reduce 61) (("[") reduce 61) (("^") reduce 61) (("{") reduce 61) (("|") reduce 61)) 25677 ((("%") reduce 28) (("(") reduce 28) (("*") reduce 28) (("+") reduce 28) (("-") reduce 28) ((".") reduce 28) (("/") reduce 28) ((";") reduce 28) (("<") reduce 28) ((">") reduce 28) (("?") reduce 28) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_BOOLEAN_AND) reduce 28) ((T_BOOLEAN_OR) reduce 28) ((T_COALESCE) reduce 28) ((T_INSTANCEOF) reduce 28) ((T_IS_EQUAL) reduce 28) ((T_IS_GREATER_OR_EQUAL) reduce 28) ((T_IS_IDENTICAL) reduce 28) ((T_IS_NOT_EQUAL) reduce 28) ((T_IS_NOT_IDENTICAL) reduce 28) ((T_IS_SMALLER_OR_EQUAL) reduce 28) ((T_LOGICAL_AND) reduce 28) ((T_LOGICAL_OR) reduce 28) ((T_LOGICAL_XOR) reduce 28) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 28) ((T_OBJECT_OPERATOR) reduce 28) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 28) ((T_POW) reduce 28) ((T_SL) reduce 28) ((T_SPACESHIP) reduce 28) ((T_SR) reduce 28) (("[") reduce 28) (("^") reduce 28) (("{") reduce 28) (("|") reduce 28)) 25678 ((("%") reduce 36) (("(") reduce 36) (("*") reduce 36) (("+") reduce 36) (("-") reduce 36) ((".") reduce 36) (("/") reduce 36) ((";") reduce 36) (("<") reduce 36) ((">") reduce 36) (("?") reduce 36) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_BOOLEAN_AND) reduce 36) ((T_BOOLEAN_OR) reduce 36) ((T_COALESCE) reduce 36) ((T_INSTANCEOF) reduce 36) ((T_IS_EQUAL) reduce 36) ((T_IS_GREATER_OR_EQUAL) reduce 36) ((T_IS_IDENTICAL) reduce 36) ((T_IS_NOT_EQUAL) reduce 36) ((T_IS_NOT_IDENTICAL) reduce 36) ((T_IS_SMALLER_OR_EQUAL) reduce 36) ((T_LOGICAL_AND) reduce 36) ((T_LOGICAL_OR) reduce 36) ((T_LOGICAL_XOR) reduce 36) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 36) ((T_OBJECT_OPERATOR) reduce 36) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 36) ((T_POW) reduce 36) ((T_SL) reduce 36) ((T_SPACESHIP) reduce 36) ((T_SR) reduce 36) (("[") reduce 36) (("^") reduce 36) (("{") reduce 36) (("|") reduce 36)) 25679 ((("%") reduce 32) (("(") reduce 32) (("*") reduce 32) (("+") reduce 32) (("-") reduce 32) ((".") reduce 32) (("/") reduce 32) ((";") reduce 32) (("<") reduce 32) ((">") reduce 32) (("?") reduce 32) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_BOOLEAN_AND) reduce 32) ((T_BOOLEAN_OR) reduce 32) ((T_COALESCE) reduce 32) ((T_INSTANCEOF) reduce 32) ((T_IS_EQUAL) reduce 32) ((T_IS_GREATER_OR_EQUAL) reduce 32) ((T_IS_IDENTICAL) reduce 32) ((T_IS_NOT_EQUAL) reduce 32) ((T_IS_NOT_IDENTICAL) reduce 32) ((T_IS_SMALLER_OR_EQUAL) reduce 32) ((T_LOGICAL_AND) reduce 32) ((T_LOGICAL_OR) reduce 32) ((T_LOGICAL_XOR) reduce 32) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 32) ((T_OBJECT_OPERATOR) reduce 32) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 32) ((T_POW) reduce 32) ((T_SL) reduce 32) ((T_SPACESHIP) reduce 32) ((T_SR) reduce 32) (("[") reduce 32) (("^") reduce 32) (("{") reduce 32) (("|") reduce 32)) 25680 ((("%") reduce 35) (("(") reduce 35) (("*") reduce 35) (("+") reduce 35) (("-") reduce 35) ((".") reduce 35) (("/") reduce 35) ((";") reduce 35) (("<") reduce 35) ((">") reduce 35) (("?") reduce 35) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_BOOLEAN_AND) reduce 35) ((T_BOOLEAN_OR) reduce 35) ((T_COALESCE) reduce 35) ((T_INSTANCEOF) reduce 35) ((T_IS_EQUAL) reduce 35) ((T_IS_GREATER_OR_EQUAL) reduce 35) ((T_IS_IDENTICAL) reduce 35) ((T_IS_NOT_EQUAL) reduce 35) ((T_IS_NOT_IDENTICAL) reduce 35) ((T_IS_SMALLER_OR_EQUAL) reduce 35) ((T_LOGICAL_AND) reduce 35) ((T_LOGICAL_OR) reduce 35) ((T_LOGICAL_XOR) reduce 35) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 35) ((T_OBJECT_OPERATOR) reduce 35) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 35) ((T_POW) reduce 35) ((T_SL) reduce 35) ((T_SPACESHIP) reduce 35) ((T_SR) reduce 35) (("[") reduce 35) (("^") reduce 35) (("{") reduce 35) (("|") reduce 35)) 25681 ((("%") reduce 19) (("(") reduce 19) (("*") reduce 19) (("+") reduce 19) (("-") reduce 19) ((".") reduce 19) (("/") reduce 19) ((";") reduce 19) (("<") reduce 19) ((">") reduce 19) (("?") reduce 19) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_BOOLEAN_AND) reduce 19) ((T_BOOLEAN_OR) reduce 19) ((T_COALESCE) reduce 19) ((T_INSTANCEOF) reduce 19) ((T_IS_EQUAL) reduce 19) ((T_IS_GREATER_OR_EQUAL) reduce 19) ((T_IS_IDENTICAL) reduce 19) ((T_IS_NOT_EQUAL) reduce 19) ((T_IS_NOT_IDENTICAL) reduce 19) ((T_IS_SMALLER_OR_EQUAL) reduce 19) ((T_LOGICAL_AND) reduce 19) ((T_LOGICAL_OR) reduce 19) ((T_LOGICAL_XOR) reduce 19) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 19) ((T_OBJECT_OPERATOR) reduce 19) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 19) ((T_POW) reduce 19) ((T_SL) reduce 19) ((T_SPACESHIP) reduce 19) ((T_SR) reduce 19) (("[") reduce 19) (("^") reduce 19) (("{") reduce 19) (("|") reduce 19)) 25682 ((("%") reduce 45) (("(") reduce 45) (("*") reduce 45) (("+") reduce 45) (("-") reduce 45) ((".") reduce 45) (("/") reduce 45) ((";") reduce 45) (("<") reduce 45) ((">") reduce 45) (("?") reduce 45) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_BOOLEAN_AND) reduce 45) ((T_BOOLEAN_OR) reduce 45) ((T_COALESCE) reduce 45) ((T_INSTANCEOF) reduce 45) ((T_IS_EQUAL) reduce 45) ((T_IS_GREATER_OR_EQUAL) reduce 45) ((T_IS_IDENTICAL) reduce 45) ((T_IS_NOT_EQUAL) reduce 45) ((T_IS_NOT_IDENTICAL) reduce 45) ((T_IS_SMALLER_OR_EQUAL) reduce 45) ((T_LOGICAL_AND) reduce 45) ((T_LOGICAL_OR) reduce 45) ((T_LOGICAL_XOR) reduce 45) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 45) ((T_OBJECT_OPERATOR) reduce 45) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 45) ((T_POW) reduce 45) ((T_SL) reduce 45) ((T_SPACESHIP) reduce 45) ((T_SR) reduce 45) (("[") reduce 45) (("^") reduce 45) (("{") reduce 45) (("|") reduce 45)) 25683 ((("%") reduce 504) (("(") reduce 541) (("*") reduce 504) (("+") reduce 504) (("-") reduce 504) ((".") reduce 504) (("/") reduce 504) ((";") reduce 504) (("<") reduce 504) ((">") reduce 504) (("?") reduce 504) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_BOOLEAN_AND) reduce 504) ((T_BOOLEAN_OR) reduce 504) ((T_COALESCE) reduce 504) ((T_INSTANCEOF) reduce 504) ((T_IS_EQUAL) reduce 504) ((T_IS_GREATER_OR_EQUAL) reduce 504) ((T_IS_IDENTICAL) reduce 504) ((T_IS_NOT_EQUAL) reduce 504) ((T_IS_NOT_IDENTICAL) reduce 504) ((T_IS_SMALLER_OR_EQUAL) reduce 504) ((T_LOGICAL_AND) reduce 504) ((T_LOGICAL_OR) reduce 504) ((T_LOGICAL_XOR) reduce 504) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 504) ((T_OBJECT_OPERATOR) reduce 504) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 504) ((T_POW) reduce 504) ((T_SL) reduce 504) ((T_SPACESHIP) reduce 504) ((T_SR) reduce 504) (("[") reduce 504) (("^") reduce 504) (("{") reduce 504) (("|") reduce 504)) 25685 ((("%") reduce 71) (("(") reduce 71) (("*") reduce 71) (("+") reduce 71) (("-") reduce 71) ((".") reduce 71) (("/") reduce 71) ((";") reduce 71) (("<") reduce 71) ((">") reduce 71) (("?") reduce 71) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_BOOLEAN_AND) reduce 71) ((T_BOOLEAN_OR) reduce 71) ((T_COALESCE) reduce 71) ((T_INSTANCEOF) reduce 71) ((T_IS_EQUAL) reduce 71) ((T_IS_GREATER_OR_EQUAL) reduce 71) ((T_IS_IDENTICAL) reduce 71) ((T_IS_NOT_EQUAL) reduce 71) ((T_IS_NOT_IDENTICAL) reduce 71) ((T_IS_SMALLER_OR_EQUAL) reduce 71) ((T_LOGICAL_AND) reduce 71) ((T_LOGICAL_OR) reduce 71) ((T_LOGICAL_XOR) reduce 71) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 71) ((T_OBJECT_OPERATOR) reduce 71) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 71) ((T_POW) reduce 71) ((T_SL) reduce 71) ((T_SPACESHIP) reduce 71) ((T_SR) reduce 71) (("[") reduce 71) (("^") reduce 71) (("{") reduce 71) (("|") reduce 71)) 25686 ((("%") reduce 82) (("(") reduce 82) (("*") reduce 82) (("+") reduce 82) (("-") reduce 82) ((".") reduce 82) (("/") reduce 82) ((";") reduce 82) (("<") reduce 82) ((">") reduce 82) (("?") reduce 82) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_BOOLEAN_AND) reduce 82) ((T_BOOLEAN_OR) reduce 82) ((T_COALESCE) reduce 82) ((T_INSTANCEOF) reduce 82) ((T_IS_EQUAL) reduce 82) ((T_IS_GREATER_OR_EQUAL) reduce 82) ((T_IS_IDENTICAL) reduce 82) ((T_IS_NOT_EQUAL) reduce 82) ((T_IS_NOT_IDENTICAL) reduce 82) ((T_IS_SMALLER_OR_EQUAL) reduce 82) ((T_LOGICAL_AND) reduce 82) ((T_LOGICAL_OR) reduce 82) ((T_LOGICAL_XOR) reduce 82) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 82) ((T_OBJECT_OPERATOR) reduce 82) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 82) ((T_POW) reduce 82) ((T_SL) reduce 82) ((T_SPACESHIP) reduce 82) ((T_SR) reduce 82) (("[") reduce 82) (("^") reduce 82) (("{") reduce 82) (("|") reduce 82)) 25687 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) ((";") reduce 533) (("<") reduce 533) (("=") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AND_EQUAL) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_COALESCE_EQUAL) reduce 533) ((T_CONCAT_EQUAL) reduce 533) ((T_DEC) reduce 533) ((T_DIV_EQUAL) reduce 533) ((T_INC) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_MINUS_EQUAL) reduce 533) ((T_MOD_EQUAL) reduce 533) ((T_MUL_EQUAL) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_OR_EQUAL) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_PLUS_EQUAL) reduce 533) ((T_POW) reduce 533) ((T_POW_EQUAL) reduce 533) ((T_SL) reduce 533) ((T_SL_EQUAL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) ((T_SR_EQUAL) reduce 533) ((T_XOR_EQUAL) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 25690 ((("%") reduce 506) (("(") reduce 542) (("*") reduce 506) (("+") reduce 506) (("-") reduce 506) ((".") reduce 506) (("/") reduce 506) ((";") reduce 506) (("<") reduce 506) ((">") reduce 506) (("?") reduce 506) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_BOOLEAN_AND) reduce 506) ((T_BOOLEAN_OR) reduce 506) ((T_COALESCE) reduce 506) ((T_INSTANCEOF) reduce 506) ((T_IS_EQUAL) reduce 506) ((T_IS_GREATER_OR_EQUAL) reduce 506) ((T_IS_IDENTICAL) reduce 506) ((T_IS_NOT_EQUAL) reduce 506) ((T_IS_NOT_IDENTICAL) reduce 506) ((T_IS_SMALLER_OR_EQUAL) reduce 506) ((T_LOGICAL_AND) reduce 506) ((T_LOGICAL_OR) reduce 506) ((T_LOGICAL_XOR) reduce 506) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 506) ((T_OBJECT_OPERATOR) reduce 506) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 506) ((T_POW) reduce 506) ((T_SL) reduce 506) ((T_SPACESHIP) reduce 506) ((T_SR) reduce 506) (("[") reduce 506) (("^") reduce 506) (("{") reduce 506) (("|") reduce 506)) 25691 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) ((";") reduce 468) (("<") reduce 468) (("=") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AND_EQUAL) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_COALESCE_EQUAL) reduce 468) ((T_CONCAT_EQUAL) reduce 468) ((T_DEC) reduce 468) ((T_DIV_EQUAL) reduce 468) ((T_INC) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_MINUS_EQUAL) reduce 468) ((T_MOD_EQUAL) reduce 468) ((T_MUL_EQUAL) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_OR_EQUAL) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_PLUS_EQUAL) reduce 468) ((T_POW) reduce 468) ((T_POW_EQUAL) reduce 468) ((T_SL) reduce 468) ((T_SL_EQUAL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) ((T_SR_EQUAL) reduce 468) ((T_XOR_EQUAL) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 25696 ((("%") reduce 388) (("*") reduce 388) (("+") reduce 388) (("-") reduce 388) ((".") reduce 388) (("/") reduce 388) ((";") reduce 388) (("<") reduce 388) ((">") reduce 388) (("?") reduce 388) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_BOOLEAN_AND) reduce 388) ((T_BOOLEAN_OR) reduce 388) ((T_COALESCE) reduce 388) ((T_INSTANCEOF) reduce 388) ((T_IS_EQUAL) reduce 388) ((T_IS_GREATER_OR_EQUAL) reduce 388) ((T_IS_IDENTICAL) reduce 388) ((T_IS_NOT_EQUAL) reduce 388) ((T_IS_NOT_IDENTICAL) reduce 388) ((T_IS_SMALLER_OR_EQUAL) reduce 388) ((T_LOGICAL_AND) reduce 388) ((T_LOGICAL_OR) reduce 388) ((T_LOGICAL_XOR) reduce 388) ((T_POW) reduce 388) ((T_SL) reduce 388) ((T_SPACESHIP) reduce 388) ((T_SR) reduce 388) (("^") reduce 388) (("|") reduce 388)) 25698 ((("%") reduce 386) (("*") reduce 386) (("+") reduce 386) (("-") reduce 386) ((".") reduce 386) (("/") reduce 386) ((";") reduce 386) (("<") reduce 386) ((">") reduce 386) (("?") reduce 386) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_BOOLEAN_AND) reduce 386) ((T_BOOLEAN_OR) reduce 386) ((T_COALESCE) reduce 386) ((T_INSTANCEOF) reduce 386) ((T_IS_EQUAL) reduce 386) ((T_IS_GREATER_OR_EQUAL) reduce 386) ((T_IS_IDENTICAL) reduce 386) ((T_IS_NOT_EQUAL) reduce 386) ((T_IS_NOT_IDENTICAL) reduce 386) ((T_IS_SMALLER_OR_EQUAL) reduce 386) ((T_LOGICAL_AND) reduce 386) ((T_LOGICAL_OR) reduce 386) ((T_LOGICAL_XOR) reduce 386) ((T_POW) reduce 386) ((T_SL) reduce 386) ((T_SPACESHIP) reduce 386) ((T_SR) reduce 386) (("^") reduce 386) (("|") reduce 386)) 25708 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 382) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 382) ((T_LOGICAL_OR) reduce 382) ((T_LOGICAL_XOR) reduce 382) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 25709 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 384) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 384) ((T_LOGICAL_OR) reduce 384) ((T_LOGICAL_XOR) reduce 384) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 25710 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 383) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 383) ((T_LOGICAL_OR) reduce 383) ((T_LOGICAL_XOR) reduce 383) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 25711 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 376) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 376) ((T_LOGICAL_OR) reduce 376) ((T_LOGICAL_XOR) reduce 376) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 25712 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 373) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 373) ((T_LOGICAL_OR) reduce 373) ((T_LOGICAL_XOR) reduce 373) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 25713 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 381) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 381) ((T_LOGICAL_OR) reduce 381) ((T_LOGICAL_XOR) reduce 381) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 25714 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 375) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 375) ((T_LOGICAL_OR) reduce 375) ((T_LOGICAL_XOR) reduce 375) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 25715 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 379) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 379) ((T_LOGICAL_OR) reduce 379) ((T_LOGICAL_XOR) reduce 379) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 25716 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 374) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 374) ((T_LOGICAL_OR) reduce 374) ((T_LOGICAL_XOR) reduce 374) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 25717 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 377) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 377) ((T_LOGICAL_OR) reduce 377) ((T_LOGICAL_XOR) reduce 377) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 25718 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 378) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 378) ((T_LOGICAL_OR) reduce 378) ((T_LOGICAL_XOR) reduce 378) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 25719 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 385) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 385) ((T_LOGICAL_OR) reduce 385) ((T_LOGICAL_XOR) reduce 385) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 25720 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 380) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 380) ((T_LOGICAL_OR) reduce 380) ((T_LOGICAL_XOR) reduce 380) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 25722 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 370) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 370) ((T_LOGICAL_OR) reduce 370) ((T_LOGICAL_XOR) reduce 370) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 25725 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) ((";") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 25728 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) ((";") reduce 525) (("<") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_POW) reduce 525) ((T_SL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 25730 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) ((";") reduce 524) (("<") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_POW) reduce 524) ((T_SL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 25732 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) ((";") reduce 519) (("<") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_POW) reduce 519) ((T_SL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 25733 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) ((";") reduce 526) (("<") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_POW) reduce 526) ((T_SL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 25734 ((("%") reduce 371) (("*") reduce 371) (("+") reduce 371) (("-") reduce 371) ((".") reduce 371) (("/") reduce 371) ((";") reduce 371) (("<") reduce 371) ((">") reduce 371) (("?") reduce 371) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_BOOLEAN_AND) reduce 371) ((T_BOOLEAN_OR) reduce 371) ((T_COALESCE) reduce 371) ((T_INSTANCEOF) reduce 371) ((T_IS_EQUAL) reduce 371) ((T_IS_GREATER_OR_EQUAL) reduce 371) ((T_IS_IDENTICAL) reduce 371) ((T_IS_NOT_EQUAL) reduce 371) ((T_IS_NOT_IDENTICAL) reduce 371) ((T_IS_SMALLER_OR_EQUAL) reduce 371) ((T_LOGICAL_AND) reduce 371) ((T_LOGICAL_OR) reduce 371) ((T_LOGICAL_XOR) reduce 371) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 371) ((T_SL) reduce 371) ((T_SPACESHIP) reduce 371) ((T_SR) reduce 371) (("[") reduce 510) (("^") reduce 371) (("{") reduce 510) (("|") reduce 371)) 25738 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) ((";") reduce 533) (("<") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_POW) reduce 533) ((T_SL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 25740 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) ((";") reduce 468) (("<") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_POW) reduce 468) ((T_SL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 25741 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) ((";") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 25745 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) ((";") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 25746 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) ((";") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 25747 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) ((";") reduce 465) (("<") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_POW) reduce 465) ((T_SL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 25750 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) ((";") reduce 532) (("<") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_POW) reduce 532) ((T_SL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 25751 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) ((";") reduce 467) (("<") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_POW) reduce 467) ((T_SL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 25752 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) ((";") reduce 469) (("<") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_POW) reduce 469) ((T_SL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 25758 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) ((";") reduce 521) (("<") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_POW) reduce 521) ((T_SL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 25760 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) ((";") reduce 520) (("<") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_POW) reduce 520) ((T_SL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 25761 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) ((";") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 25762 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) ((";") reduce 527) (("<") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_POW) reduce 527) ((T_SL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 25763 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) ((";") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 25766 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) ((";") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 25767 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) ((";") reduce 522) (("<") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_POW) reduce 522) ((T_SL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 25768 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) ((";") reduce 528) (("<") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_POW) reduce 528) ((T_SL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 25769 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) ((";") reduce 523) (("<") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_POW) reduce 523) ((T_SL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 25770 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) ((";") reduce 466) (("<") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_POW) reduce 466) ((T_SL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 25771 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) ((";") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 25774 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) ((";") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 25775 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) ((";") reduce 465) (("<") reduce 465) (("=") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AND_EQUAL) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_COALESCE_EQUAL) reduce 465) ((T_CONCAT_EQUAL) reduce 465) ((T_DEC) reduce 465) ((T_DIV_EQUAL) reduce 465) ((T_INC) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_MINUS_EQUAL) reduce 465) ((T_MOD_EQUAL) reduce 465) ((T_MUL_EQUAL) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_OR_EQUAL) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_PLUS_EQUAL) reduce 465) ((T_POW) reduce 465) ((T_POW_EQUAL) reduce 465) ((T_SL) reduce 465) ((T_SL_EQUAL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) ((T_SR_EQUAL) reduce 465) ((T_XOR_EQUAL) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 25781 ((("!") reduce 164) (("\"") reduce 164) (($) reduce 164) (("$") reduce 164) (("(") reduce 164) (("+") reduce 164) (("-") reduce 164) ((";") reduce 164) (("@") reduce 164) ((T_ABSTRACT) reduce 164) ((T_ARRAY) reduce 164) ((T_ARRAY_CAST) reduce 164) ((T_ATTRIBUTE) reduce 164) ((T_BOOL_CAST) reduce 164) ((T_BREAK) reduce 164) ((T_CLASS) reduce 164) ((T_CLASS_C) reduce 164) ((T_CLONE) reduce 164) ((T_CONST) reduce 164) ((T_CONSTANT_ENCAPSED_STRING) reduce 164) ((T_CONTINUE) reduce 164) ((T_DEC) reduce 164) ((T_DECLARE) reduce 164) ((T_DIR) reduce 164) ((T_DNUMBER) reduce 164) ((T_DO) reduce 164) ((T_DOUBLE_CAST) reduce 164) ((T_ECHO) reduce 164) ((T_ELSE) reduce 164) ((T_ELSEIF) reduce 164) ((T_EMPTY) reduce 164) ((T_ENUM) reduce 164) ((T_EVAL) reduce 164) ((T_EXIT) reduce 164) ((T_FILE) reduce 164) ((T_FINAL) reduce 164) ((T_FN) reduce 164) ((T_FOR) reduce 164) ((T_FOREACH) reduce 164) ((T_FUNCTION) reduce 164) ((T_FUNC_C) reduce 164) ((T_GLOBAL) reduce 164) ((T_GOTO) reduce 164) ((T_HALT_COMPILER) reduce 164) ((T_IF) reduce 164) ((T_INC) reduce 164) ((T_INCLUDE) reduce 164) ((T_INCLUDE_ONCE) reduce 164) ((T_INLINE_HTML) reduce 164) ((T_INTERFACE) reduce 164) ((T_INT_CAST) reduce 164) ((T_ISSET) reduce 164) ((T_LINE) reduce 164) ((T_LIST) reduce 164) ((T_LNUMBER) reduce 164) ((T_MATCH) reduce 164) ((T_METHOD_C) reduce 164) ((T_NAMESPACE) reduce 164) ((T_NAME_FULLY_QUALIFIED) reduce 164) ((T_NAME_QUALIFIED) reduce 164) ((T_NAME_RELATIVE) reduce 164) ((T_NEW) reduce 164) ((T_NS_C) reduce 164) ((T_OBJECT_CAST) reduce 164) ((T_PRINT) reduce 164) ((T_READONLY) reduce 164) ((T_REQUIRE) reduce 164) ((T_REQUIRE_ONCE) reduce 164) ((T_RETURN) reduce 164) ((T_START_HEREDOC) reduce 164) ((T_STATIC) reduce 164) ((T_STRING) reduce 164) ((T_STRING_CAST) reduce 164) ((T_SWITCH) reduce 164) ((T_THROW) reduce 164) ((T_TRAIT) reduce 164) ((T_TRAIT_C) reduce 164) ((T_TRY) reduce 164) ((T_UNSET) reduce 164) ((T_UNSET_CAST) reduce 164) ((T_USE) reduce 164) ((T_VARIABLE) reduce 164) ((T_WHILE) reduce 164) ((T_YIELD) reduce 164) ((T_YIELD_FROM) reduce 164) (("[") reduce 164) (("`") reduce 164) (("{") reduce 164) (("~") reduce 164)) 25791 ((("!") reduce 158) (("\"") reduce 158) (($) reduce 158) (("$") reduce 158) (("(") reduce 158) (("+") reduce 158) (("-") reduce 158) ((";") reduce 158) (("@") reduce 158) ((T_ABSTRACT) reduce 158) ((T_ARRAY) reduce 158) ((T_ARRAY_CAST) reduce 158) ((T_ATTRIBUTE) reduce 158) ((T_BOOL_CAST) reduce 158) ((T_BREAK) reduce 158) ((T_CLASS) reduce 158) ((T_CLASS_C) reduce 158) ((T_CLONE) reduce 158) ((T_CONST) reduce 158) ((T_CONSTANT_ENCAPSED_STRING) reduce 158) ((T_CONTINUE) reduce 158) ((T_DEC) reduce 158) ((T_DECLARE) reduce 158) ((T_DIR) reduce 158) ((T_DNUMBER) reduce 158) ((T_DO) reduce 158) ((T_DOUBLE_CAST) reduce 158) ((T_ECHO) reduce 158) ((T_ELSE) reduce 158) ((T_ELSEIF) reduce 158) ((T_EMPTY) reduce 158) ((T_ENUM) reduce 158) ((T_EVAL) reduce 158) ((T_EXIT) reduce 158) ((T_FILE) reduce 158) ((T_FINAL) reduce 158) ((T_FN) reduce 158) ((T_FOR) reduce 158) ((T_FOREACH) reduce 158) ((T_FUNCTION) reduce 158) ((T_FUNC_C) reduce 158) ((T_GLOBAL) reduce 158) ((T_GOTO) reduce 158) ((T_HALT_COMPILER) reduce 158) ((T_IF) reduce 158) ((T_INC) reduce 158) ((T_INCLUDE) reduce 158) ((T_INCLUDE_ONCE) reduce 158) ((T_INLINE_HTML) reduce 158) ((T_INTERFACE) reduce 158) ((T_INT_CAST) reduce 158) ((T_ISSET) reduce 158) ((T_LINE) reduce 158) ((T_LIST) reduce 158) ((T_LNUMBER) reduce 158) ((T_MATCH) reduce 158) ((T_METHOD_C) reduce 158) ((T_NAMESPACE) reduce 158) ((T_NAME_FULLY_QUALIFIED) reduce 158) ((T_NAME_QUALIFIED) reduce 158) ((T_NAME_RELATIVE) reduce 158) ((T_NEW) reduce 158) ((T_NS_C) reduce 158) ((T_OBJECT_CAST) reduce 158) ((T_PRINT) reduce 158) ((T_READONLY) reduce 158) ((T_REQUIRE) reduce 158) ((T_REQUIRE_ONCE) reduce 158) ((T_RETURN) reduce 158) ((T_START_HEREDOC) reduce 158) ((T_STATIC) reduce 158) ((T_STRING) reduce 158) ((T_STRING_CAST) reduce 158) ((T_SWITCH) reduce 158) ((T_THROW) reduce 158) ((T_TRAIT) reduce 158) ((T_TRAIT_C) reduce 158) ((T_TRY) reduce 158) ((T_UNSET) reduce 158) ((T_UNSET_CAST) reduce 158) ((T_USE) reduce 158) ((T_VARIABLE) reduce 158) ((T_WHILE) reduce 158) ((T_YIELD) reduce 158) ((T_YIELD_FROM) reduce 158) (("[") reduce 158) (("`") reduce 158) (("{") reduce 158) (("~") reduce 158)) 25799 ((("!") reduce 147) (("\"") reduce 147) (($) reduce 147) (("$") reduce 147) (("(") reduce 147) (("+") reduce 147) (("-") reduce 147) ((";") reduce 147) (("@") reduce 147) ((T_ABSTRACT) reduce 147) ((T_ARRAY) reduce 147) ((T_ARRAY_CAST) reduce 147) ((T_ATTRIBUTE) reduce 147) ((T_BOOL_CAST) reduce 147) ((T_BREAK) reduce 147) ((T_CLASS) reduce 147) ((T_CLASS_C) reduce 147) ((T_CLONE) reduce 147) ((T_CONST) reduce 147) ((T_CONSTANT_ENCAPSED_STRING) reduce 147) ((T_CONTINUE) reduce 147) ((T_DEC) reduce 147) ((T_DECLARE) reduce 147) ((T_DIR) reduce 147) ((T_DNUMBER) reduce 147) ((T_DO) reduce 147) ((T_DOUBLE_CAST) reduce 147) ((T_ECHO) reduce 147) ((T_ELSE) reduce 147) ((T_ELSEIF) reduce 147) ((T_EMPTY) reduce 147) ((T_ENUM) reduce 147) ((T_EVAL) reduce 147) ((T_EXIT) reduce 147) ((T_FILE) reduce 147) ((T_FINAL) reduce 147) ((T_FN) reduce 147) ((T_FOR) reduce 147) ((T_FOREACH) reduce 147) ((T_FUNCTION) reduce 147) ((T_FUNC_C) reduce 147) ((T_GLOBAL) reduce 147) ((T_GOTO) reduce 147) ((T_HALT_COMPILER) reduce 147) ((T_IF) reduce 147) ((T_INC) reduce 147) ((T_INCLUDE) reduce 147) ((T_INCLUDE_ONCE) reduce 147) ((T_INLINE_HTML) reduce 147) ((T_INTERFACE) reduce 147) ((T_INT_CAST) reduce 147) ((T_ISSET) reduce 147) ((T_LINE) reduce 147) ((T_LIST) reduce 147) ((T_LNUMBER) reduce 147) ((T_MATCH) reduce 147) ((T_METHOD_C) reduce 147) ((T_NAMESPACE) reduce 147) ((T_NAME_FULLY_QUALIFIED) reduce 147) ((T_NAME_QUALIFIED) reduce 147) ((T_NAME_RELATIVE) reduce 147) ((T_NEW) reduce 147) ((T_NS_C) reduce 147) ((T_OBJECT_CAST) reduce 147) ((T_PRINT) reduce 147) ((T_READONLY) reduce 147) ((T_REQUIRE) reduce 147) ((T_REQUIRE_ONCE) reduce 147) ((T_RETURN) reduce 147) ((T_START_HEREDOC) reduce 147) ((T_STATIC) reduce 147) ((T_STRING) reduce 147) ((T_STRING_CAST) reduce 147) ((T_SWITCH) reduce 147) ((T_THROW) reduce 147) ((T_TRAIT) reduce 147) ((T_TRAIT_C) reduce 147) ((T_TRY) reduce 147) ((T_UNSET) reduce 147) ((T_UNSET_CAST) reduce 147) ((T_USE) reduce 147) ((T_VARIABLE) reduce 147) ((T_WHILE) reduce 147) ((T_YIELD) reduce 147) ((T_YIELD_FROM) reduce 147) (("[") reduce 147) (("`") reduce 147) (("{") reduce 147) (("~") reduce 147)) 25802 ((("!") reduce 146) (("\"") reduce 146) (($) reduce 146) (("$") reduce 146) (("(") reduce 146) (("+") reduce 146) (("-") reduce 146) ((";") reduce 146) (("@") reduce 146) ((T_ABSTRACT) reduce 146) ((T_ARRAY) reduce 146) ((T_ARRAY_CAST) reduce 146) ((T_ATTRIBUTE) reduce 146) ((T_BOOL_CAST) reduce 146) ((T_BREAK) reduce 146) ((T_CLASS) reduce 146) ((T_CLASS_C) reduce 146) ((T_CLONE) reduce 146) ((T_CONST) reduce 146) ((T_CONSTANT_ENCAPSED_STRING) reduce 146) ((T_CONTINUE) reduce 146) ((T_DEC) reduce 146) ((T_DECLARE) reduce 146) ((T_DIR) reduce 146) ((T_DNUMBER) reduce 146) ((T_DO) reduce 146) ((T_DOUBLE_CAST) reduce 146) ((T_ECHO) reduce 146) ((T_ELSE) reduce 146) ((T_ELSEIF) reduce 146) ((T_EMPTY) reduce 146) ((T_ENUM) reduce 146) ((T_EVAL) reduce 146) ((T_EXIT) reduce 146) ((T_FILE) reduce 146) ((T_FINAL) reduce 146) ((T_FN) reduce 146) ((T_FOR) reduce 146) ((T_FOREACH) reduce 146) ((T_FUNCTION) reduce 146) ((T_FUNC_C) reduce 146) ((T_GLOBAL) reduce 146) ((T_GOTO) reduce 146) ((T_HALT_COMPILER) reduce 146) ((T_IF) reduce 146) ((T_INC) reduce 146) ((T_INCLUDE) reduce 146) ((T_INCLUDE_ONCE) reduce 146) ((T_INLINE_HTML) reduce 146) ((T_INTERFACE) reduce 146) ((T_INT_CAST) reduce 146) ((T_ISSET) reduce 146) ((T_LINE) reduce 146) ((T_LIST) reduce 146) ((T_LNUMBER) reduce 146) ((T_MATCH) reduce 146) ((T_METHOD_C) reduce 146) ((T_NAMESPACE) reduce 146) ((T_NAME_FULLY_QUALIFIED) reduce 146) ((T_NAME_QUALIFIED) reduce 146) ((T_NAME_RELATIVE) reduce 146) ((T_NEW) reduce 146) ((T_NS_C) reduce 146) ((T_OBJECT_CAST) reduce 146) ((T_PRINT) reduce 146) ((T_READONLY) reduce 146) ((T_REQUIRE) reduce 146) ((T_REQUIRE_ONCE) reduce 146) ((T_RETURN) reduce 146) ((T_START_HEREDOC) reduce 146) ((T_STATIC) reduce 146) ((T_STRING) reduce 146) ((T_STRING_CAST) reduce 146) ((T_SWITCH) reduce 146) ((T_THROW) reduce 146) ((T_TRAIT) reduce 146) ((T_TRAIT_C) reduce 146) ((T_TRY) reduce 146) ((T_UNSET) reduce 146) ((T_UNSET_CAST) reduce 146) ((T_USE) reduce 146) ((T_VARIABLE) reduce 146) ((T_WHILE) reduce 146) ((T_YIELD) reduce 146) ((T_YIELD_FROM) reduce 146) (("[") reduce 146) (("`") reduce 146) (("{") reduce 146) (("~") reduce 146)) 25804 ((("!") reduce 242) (("\"") reduce 242) (("$") reduce 242) (($) reduce 242) (("(") reduce 242) (("+") reduce 242) (("-") reduce 242) ((";") reduce 242) (("@") reduce 242) ((T_ABSTRACT) reduce 242) ((T_ARRAY) reduce 242) ((T_ARRAY_CAST) reduce 242) ((T_ATTRIBUTE) reduce 242) ((T_BOOL_CAST) reduce 242) ((T_BREAK) reduce 242) ((T_CLASS) reduce 242) ((T_CLASS_C) reduce 242) ((T_CLONE) reduce 242) ((T_CONST) reduce 242) ((T_CONSTANT_ENCAPSED_STRING) reduce 242) ((T_CONTINUE) reduce 242) ((T_DEC) reduce 242) ((T_DECLARE) reduce 242) ((T_DIR) reduce 242) ((T_DNUMBER) reduce 242) ((T_DO) reduce 242) ((T_DOUBLE_CAST) reduce 242) ((T_ECHO) reduce 242) ((T_ELSE) reduce 242) ((T_ELSEIF) reduce 242) ((T_EMPTY) reduce 242) ((T_ENUM) reduce 242) ((T_EVAL) reduce 242) ((T_EXIT) reduce 242) ((T_FILE) reduce 242) ((T_FINAL) reduce 242) ((T_FN) reduce 242) ((T_FOR) reduce 242) ((T_FOREACH) reduce 242) ((T_FUNCTION) reduce 242) ((T_FUNC_C) reduce 242) ((T_GLOBAL) reduce 242) ((T_GOTO) reduce 242) ((T_HALT_COMPILER) reduce 242) ((T_IF) reduce 242) ((T_INC) reduce 242) ((T_INCLUDE) reduce 242) ((T_INCLUDE_ONCE) reduce 242) ((T_INLINE_HTML) reduce 242) ((T_INTERFACE) reduce 242) ((T_INT_CAST) reduce 242) ((T_ISSET) reduce 242) ((T_LINE) reduce 242) ((T_LIST) reduce 242) ((T_LNUMBER) reduce 242) ((T_MATCH) reduce 242) ((T_METHOD_C) reduce 242) ((T_NAMESPACE) reduce 242) ((T_NAME_FULLY_QUALIFIED) reduce 242) ((T_NAME_QUALIFIED) reduce 242) ((T_NAME_RELATIVE) reduce 242) ((T_NEW) reduce 242) ((T_NS_C) reduce 242) ((T_OBJECT_CAST) reduce 242) ((T_PRINT) reduce 242) ((T_READONLY) reduce 242) ((T_REQUIRE) reduce 242) ((T_REQUIRE_ONCE) reduce 242) ((T_RETURN) reduce 242) ((T_START_HEREDOC) reduce 242) ((T_STATIC) reduce 242) ((T_STRING) reduce 242) ((T_STRING_CAST) reduce 242) ((T_SWITCH) reduce 242) ((T_THROW) reduce 242) ((T_TRAIT) reduce 242) ((T_TRAIT_C) reduce 242) ((T_TRY) reduce 242) ((T_UNSET) reduce 242) ((T_UNSET_CAST) reduce 242) ((T_USE) reduce 242) ((T_VARIABLE) reduce 242) ((T_WHILE) reduce 242) ((T_YIELD) reduce 242) ((T_YIELD_FROM) reduce 242) (("[") reduce 242) (("`") reduce 242) (("{") reduce 242) (("~") reduce 242)) 25807 ((("!") reduce 145) (("\"") reduce 145) (($) reduce 145) (("$") reduce 145) (("(") reduce 145) (("+") reduce 145) (("-") reduce 145) ((";") reduce 145) (("@") reduce 145) ((T_ABSTRACT) reduce 145) ((T_ARRAY) reduce 145) ((T_ARRAY_CAST) reduce 145) ((T_ATTRIBUTE) reduce 145) ((T_BOOL_CAST) reduce 145) ((T_BREAK) reduce 145) ((T_CLASS) reduce 145) ((T_CLASS_C) reduce 145) ((T_CLONE) reduce 145) ((T_CONST) reduce 145) ((T_CONSTANT_ENCAPSED_STRING) reduce 145) ((T_CONTINUE) reduce 145) ((T_DEC) reduce 145) ((T_DECLARE) reduce 145) ((T_DIR) reduce 145) ((T_DNUMBER) reduce 145) ((T_DO) reduce 145) ((T_DOUBLE_CAST) reduce 145) ((T_ECHO) reduce 145) ((T_ELSE) reduce 145) ((T_ELSEIF) reduce 145) ((T_EMPTY) reduce 145) ((T_ENUM) reduce 145) ((T_EVAL) reduce 145) ((T_EXIT) reduce 145) ((T_FILE) reduce 145) ((T_FINAL) reduce 145) ((T_FN) reduce 145) ((T_FOR) reduce 145) ((T_FOREACH) reduce 145) ((T_FUNCTION) reduce 145) ((T_FUNC_C) reduce 145) ((T_GLOBAL) reduce 145) ((T_GOTO) reduce 145) ((T_HALT_COMPILER) reduce 145) ((T_IF) reduce 145) ((T_INC) reduce 145) ((T_INCLUDE) reduce 145) ((T_INCLUDE_ONCE) reduce 145) ((T_INLINE_HTML) reduce 145) ((T_INTERFACE) reduce 145) ((T_INT_CAST) reduce 145) ((T_ISSET) reduce 145) ((T_LINE) reduce 145) ((T_LIST) reduce 145) ((T_LNUMBER) reduce 145) ((T_MATCH) reduce 145) ((T_METHOD_C) reduce 145) ((T_NAMESPACE) reduce 145) ((T_NAME_FULLY_QUALIFIED) reduce 145) ((T_NAME_QUALIFIED) reduce 145) ((T_NAME_RELATIVE) reduce 145) ((T_NEW) reduce 145) ((T_NS_C) reduce 145) ((T_OBJECT_CAST) reduce 145) ((T_PRINT) reduce 145) ((T_READONLY) reduce 145) ((T_REQUIRE) reduce 145) ((T_REQUIRE_ONCE) reduce 145) ((T_RETURN) reduce 145) ((T_START_HEREDOC) reduce 145) ((T_STATIC) reduce 145) ((T_STRING) reduce 145) ((T_STRING_CAST) reduce 145) ((T_SWITCH) reduce 145) ((T_THROW) reduce 145) ((T_TRAIT) reduce 145) ((T_TRAIT_C) reduce 145) ((T_TRY) reduce 145) ((T_UNSET) reduce 145) ((T_UNSET_CAST) reduce 145) ((T_USE) reduce 145) ((T_VARIABLE) reduce 145) ((T_WHILE) reduce 145) ((T_YIELD) reduce 145) ((T_YIELD_FROM) reduce 145) (("[") reduce 145) (("`") reduce 145) (("{") reduce 145) (("~") reduce 145)) 25809 ((("!") reduce 244) (("\"") reduce 244) (("$") reduce 244) (($) reduce 244) (("(") reduce 244) (("+") reduce 244) (("-") reduce 244) ((";") reduce 244) (("@") reduce 244) ((T_ABSTRACT) reduce 244) ((T_ARRAY) reduce 244) ((T_ARRAY_CAST) reduce 244) ((T_ATTRIBUTE) reduce 244) ((T_BOOL_CAST) reduce 244) ((T_BREAK) reduce 244) ((T_CLASS) reduce 244) ((T_CLASS_C) reduce 244) ((T_CLONE) reduce 244) ((T_CONST) reduce 244) ((T_CONSTANT_ENCAPSED_STRING) reduce 244) ((T_CONTINUE) reduce 244) ((T_DEC) reduce 244) ((T_DECLARE) reduce 244) ((T_DIR) reduce 244) ((T_DNUMBER) reduce 244) ((T_DO) reduce 244) ((T_DOUBLE_CAST) reduce 244) ((T_ECHO) reduce 244) ((T_ELSE) reduce 244) ((T_ELSEIF) reduce 244) ((T_EMPTY) reduce 244) ((T_ENUM) reduce 244) ((T_EVAL) reduce 244) ((T_EXIT) reduce 244) ((T_FILE) reduce 244) ((T_FINAL) reduce 244) ((T_FN) reduce 244) ((T_FOR) reduce 244) ((T_FOREACH) reduce 244) ((T_FUNCTION) reduce 244) ((T_FUNC_C) reduce 244) ((T_GLOBAL) reduce 244) ((T_GOTO) reduce 244) ((T_HALT_COMPILER) reduce 244) ((T_IF) reduce 244) ((T_INC) reduce 244) ((T_INCLUDE) reduce 244) ((T_INCLUDE_ONCE) reduce 244) ((T_INLINE_HTML) reduce 244) ((T_INTERFACE) reduce 244) ((T_INT_CAST) reduce 244) ((T_ISSET) reduce 244) ((T_LINE) reduce 244) ((T_LIST) reduce 244) ((T_LNUMBER) reduce 244) ((T_MATCH) reduce 244) ((T_METHOD_C) reduce 244) ((T_NAMESPACE) reduce 244) ((T_NAME_FULLY_QUALIFIED) reduce 244) ((T_NAME_QUALIFIED) reduce 244) ((T_NAME_RELATIVE) reduce 244) ((T_NEW) reduce 244) ((T_NS_C) reduce 244) ((T_OBJECT_CAST) reduce 244) ((T_PRINT) reduce 244) ((T_READONLY) reduce 244) ((T_REQUIRE) reduce 244) ((T_REQUIRE_ONCE) reduce 244) ((T_RETURN) reduce 244) ((T_START_HEREDOC) reduce 244) ((T_STATIC) reduce 244) ((T_STRING) reduce 244) ((T_STRING_CAST) reduce 244) ((T_SWITCH) reduce 244) ((T_THROW) reduce 244) ((T_TRAIT) reduce 244) ((T_TRAIT_C) reduce 244) ((T_TRY) reduce 244) ((T_UNSET) reduce 244) ((T_UNSET_CAST) reduce 244) ((T_USE) reduce 244) ((T_VARIABLE) reduce 244) ((T_WHILE) reduce 244) ((T_YIELD) reduce 244) ((T_YIELD_FROM) reduce 244) (("[") reduce 244) (("`") reduce 244) (("{") reduce 244) (("~") reduce 244)) 25810 ((("!") reduce 159) (("\"") reduce 159) (("$") reduce 159) (($) reduce 159) (("(") reduce 159) (("+") reduce 159) (("-") reduce 159) ((";") reduce 159) (("@") reduce 159) ((T_ABSTRACT) reduce 159) ((T_ARRAY) reduce 159) ((T_ARRAY_CAST) reduce 159) ((T_ATTRIBUTE) reduce 159) ((T_BOOL_CAST) reduce 159) ((T_BREAK) reduce 159) ((T_CLASS) reduce 159) ((T_CLASS_C) reduce 159) ((T_CLONE) reduce 159) ((T_CONST) reduce 159) ((T_CONSTANT_ENCAPSED_STRING) reduce 159) ((T_CONTINUE) reduce 159) ((T_DEC) reduce 159) ((T_DECLARE) reduce 159) ((T_DIR) reduce 159) ((T_DNUMBER) reduce 159) ((T_DO) reduce 159) ((T_DOUBLE_CAST) reduce 159) ((T_ECHO) reduce 159) ((T_ELSE) reduce 159) ((T_ELSEIF) reduce 159) ((T_EMPTY) reduce 159) ((T_ENUM) reduce 159) ((T_EVAL) reduce 159) ((T_EXIT) reduce 159) ((T_FILE) reduce 159) ((T_FINAL) reduce 159) ((T_FN) reduce 159) ((T_FOR) reduce 159) ((T_FOREACH) reduce 159) ((T_FUNCTION) reduce 159) ((T_FUNC_C) reduce 159) ((T_GLOBAL) reduce 159) ((T_GOTO) reduce 159) ((T_HALT_COMPILER) reduce 159) ((T_IF) reduce 159) ((T_INC) reduce 159) ((T_INCLUDE) reduce 159) ((T_INCLUDE_ONCE) reduce 159) ((T_INLINE_HTML) reduce 159) ((T_INTERFACE) reduce 159) ((T_INT_CAST) reduce 159) ((T_ISSET) reduce 159) ((T_LINE) reduce 159) ((T_LIST) reduce 159) ((T_LNUMBER) reduce 159) ((T_MATCH) reduce 159) ((T_METHOD_C) reduce 159) ((T_NAMESPACE) reduce 159) ((T_NAME_FULLY_QUALIFIED) reduce 159) ((T_NAME_QUALIFIED) reduce 159) ((T_NAME_RELATIVE) reduce 159) ((T_NEW) reduce 159) ((T_NS_C) reduce 159) ((T_OBJECT_CAST) reduce 159) ((T_PRINT) reduce 159) ((T_READONLY) reduce 159) ((T_REQUIRE) reduce 159) ((T_REQUIRE_ONCE) reduce 159) ((T_RETURN) reduce 159) ((T_START_HEREDOC) reduce 159) ((T_STATIC) reduce 159) ((T_STRING) reduce 159) ((T_STRING_CAST) reduce 159) ((T_SWITCH) reduce 159) ((T_THROW) reduce 159) ((T_TRAIT) reduce 159) ((T_TRAIT_C) reduce 159) ((T_TRY) reduce 159) ((T_UNSET) reduce 159) ((T_UNSET_CAST) reduce 159) ((T_USE) reduce 159) ((T_VARIABLE) reduce 159) ((T_WHILE) reduce 159) ((T_YIELD) reduce 159) ((T_YIELD_FROM) reduce 159) (("[") reduce 159) (("`") reduce 159) (("{") reduce 159) (("~") reduce 159)) 25813 ((("!") reduce 247) (("\"") reduce 247) (("$") reduce 247) (($) reduce 247) (("(") reduce 247) (("+") reduce 247) (("-") reduce 247) ((";") reduce 247) (("@") reduce 247) ((T_ABSTRACT) reduce 247) ((T_ARRAY) reduce 247) ((T_ARRAY_CAST) reduce 247) ((T_ATTRIBUTE) reduce 247) ((T_BOOL_CAST) reduce 247) ((T_BREAK) reduce 247) ((T_CLASS) reduce 247) ((T_CLASS_C) reduce 247) ((T_CLONE) reduce 247) ((T_CONST) reduce 247) ((T_CONSTANT_ENCAPSED_STRING) reduce 247) ((T_CONTINUE) reduce 247) ((T_DEC) reduce 247) ((T_DECLARE) reduce 247) ((T_DIR) reduce 247) ((T_DNUMBER) reduce 247) ((T_DO) reduce 247) ((T_DOUBLE_CAST) reduce 247) ((T_ECHO) reduce 247) ((T_ELSE) reduce 247) ((T_ELSEIF) reduce 247) ((T_EMPTY) reduce 247) ((T_ENUM) reduce 247) ((T_EVAL) reduce 247) ((T_EXIT) reduce 247) ((T_FILE) reduce 247) ((T_FINAL) reduce 247) ((T_FN) reduce 247) ((T_FOR) reduce 247) ((T_FOREACH) reduce 247) ((T_FUNCTION) reduce 247) ((T_FUNC_C) reduce 247) ((T_GLOBAL) reduce 247) ((T_GOTO) reduce 247) ((T_HALT_COMPILER) reduce 247) ((T_IF) reduce 247) ((T_INC) reduce 247) ((T_INCLUDE) reduce 247) ((T_INCLUDE_ONCE) reduce 247) ((T_INLINE_HTML) reduce 247) ((T_INTERFACE) reduce 247) ((T_INT_CAST) reduce 247) ((T_ISSET) reduce 247) ((T_LINE) reduce 247) ((T_LIST) reduce 247) ((T_LNUMBER) reduce 247) ((T_MATCH) reduce 247) ((T_METHOD_C) reduce 247) ((T_NAMESPACE) reduce 247) ((T_NAME_FULLY_QUALIFIED) reduce 247) ((T_NAME_QUALIFIED) reduce 247) ((T_NAME_RELATIVE) reduce 247) ((T_NEW) reduce 247) ((T_NS_C) reduce 247) ((T_OBJECT_CAST) reduce 247) ((T_PRINT) reduce 247) ((T_READONLY) reduce 247) ((T_REQUIRE) reduce 247) ((T_REQUIRE_ONCE) reduce 247) ((T_RETURN) reduce 247) ((T_START_HEREDOC) reduce 247) ((T_STATIC) reduce 247) ((T_STRING) reduce 247) ((T_STRING_CAST) reduce 247) ((T_SWITCH) reduce 247) ((T_THROW) reduce 247) ((T_TRAIT) reduce 247) ((T_TRAIT_C) reduce 247) ((T_TRY) reduce 247) ((T_UNSET) reduce 247) ((T_UNSET_CAST) reduce 247) ((T_USE) reduce 247) ((T_VARIABLE) reduce 247) ((T_WHILE) reduce 247) ((T_YIELD) reduce 247) ((T_YIELD_FROM) reduce 247) (("[") reduce 247) (("`") reduce 247) (("{") reduce 247) (("~") reduce 247)) 25817 ((("!") reduce 248) (("\"") reduce 248) (($) reduce 248) (("$") reduce 248) (("(") reduce 248) (("+") reduce 248) (("-") reduce 248) ((";") reduce 248) (("@") reduce 248) ((T_ABSTRACT) reduce 248) ((T_ARRAY) reduce 248) ((T_ARRAY_CAST) reduce 248) ((T_ATTRIBUTE) reduce 248) ((T_BOOL_CAST) reduce 248) ((T_BREAK) reduce 248) ((T_CLASS) reduce 248) ((T_CLASS_C) reduce 248) ((T_CLONE) reduce 248) ((T_CONST) reduce 248) ((T_CONSTANT_ENCAPSED_STRING) reduce 248) ((T_CONTINUE) reduce 248) ((T_DEC) reduce 248) ((T_DECLARE) reduce 248) ((T_DIR) reduce 248) ((T_DNUMBER) reduce 248) ((T_DO) reduce 248) ((T_DOUBLE_CAST) reduce 248) ((T_ECHO) reduce 248) ((T_ELSE) reduce 248) ((T_ELSEIF) reduce 248) ((T_EMPTY) reduce 248) ((T_ENUM) reduce 248) ((T_EVAL) reduce 248) ((T_EXIT) reduce 248) ((T_FILE) reduce 248) ((T_FINAL) reduce 248) ((T_FN) reduce 248) ((T_FOR) reduce 248) ((T_FOREACH) reduce 248) ((T_FUNCTION) reduce 248) ((T_FUNC_C) reduce 248) ((T_GLOBAL) reduce 248) ((T_GOTO) reduce 248) ((T_HALT_COMPILER) reduce 248) ((T_IF) reduce 248) ((T_INC) reduce 248) ((T_INCLUDE) reduce 248) ((T_INCLUDE_ONCE) reduce 248) ((T_INLINE_HTML) reduce 248) ((T_INTERFACE) reduce 248) ((T_INT_CAST) reduce 248) ((T_ISSET) reduce 248) ((T_LINE) reduce 248) ((T_LIST) reduce 248) ((T_LNUMBER) reduce 248) ((T_MATCH) reduce 248) ((T_METHOD_C) reduce 248) ((T_NAMESPACE) reduce 248) ((T_NAME_FULLY_QUALIFIED) reduce 248) ((T_NAME_QUALIFIED) reduce 248) ((T_NAME_RELATIVE) reduce 248) ((T_NEW) reduce 248) ((T_NS_C) reduce 248) ((T_OBJECT_CAST) reduce 248) ((T_PRINT) reduce 248) ((T_READONLY) reduce 248) ((T_REQUIRE) reduce 248) ((T_REQUIRE_ONCE) reduce 248) ((T_RETURN) reduce 248) ((T_START_HEREDOC) reduce 248) ((T_STATIC) reduce 248) ((T_STRING) reduce 248) ((T_STRING_CAST) reduce 248) ((T_SWITCH) reduce 248) ((T_THROW) reduce 248) ((T_TRAIT) reduce 248) ((T_TRAIT_C) reduce 248) ((T_TRY) reduce 248) ((T_UNSET) reduce 248) ((T_UNSET_CAST) reduce 248) ((T_USE) reduce 248) ((T_VARIABLE) reduce 248) ((T_WHILE) reduce 248) ((T_YIELD) reduce 248) ((T_YIELD_FROM) reduce 248) (("[") reduce 248) (("`") reduce 248) (("{") reduce 248) (("~") reduce 248)) 25822 ((("!") reduce 239) (("\"") reduce 239) (("$") reduce 239) (($) reduce 239) (("(") reduce 239) (("+") reduce 239) (("-") reduce 239) ((";") reduce 239) (("@") reduce 239) ((T_ABSTRACT) reduce 239) ((T_ARRAY) reduce 239) ((T_ARRAY_CAST) reduce 239) ((T_ATTRIBUTE) reduce 239) ((T_BOOL_CAST) reduce 239) ((T_BREAK) reduce 239) ((T_CLASS) reduce 239) ((T_CLASS_C) reduce 239) ((T_CLONE) reduce 239) ((T_CONST) reduce 239) ((T_CONSTANT_ENCAPSED_STRING) reduce 239) ((T_CONTINUE) reduce 239) ((T_DEC) reduce 239) ((T_DECLARE) reduce 239) ((T_DIR) reduce 239) ((T_DNUMBER) reduce 239) ((T_DO) reduce 239) ((T_DOUBLE_CAST) reduce 239) ((T_ECHO) reduce 239) ((T_ELSE) reduce 239) ((T_ELSEIF) reduce 239) ((T_EMPTY) reduce 239) ((T_ENUM) reduce 239) ((T_EVAL) reduce 239) ((T_EXIT) reduce 239) ((T_FILE) reduce 239) ((T_FINAL) reduce 239) ((T_FN) reduce 239) ((T_FOR) reduce 239) ((T_FOREACH) reduce 239) ((T_FUNCTION) reduce 239) ((T_FUNC_C) reduce 239) ((T_GLOBAL) reduce 239) ((T_GOTO) reduce 239) ((T_HALT_COMPILER) reduce 239) ((T_IF) reduce 239) ((T_INC) reduce 239) ((T_INCLUDE) reduce 239) ((T_INCLUDE_ONCE) reduce 239) ((T_INLINE_HTML) reduce 239) ((T_INTERFACE) reduce 239) ((T_INT_CAST) reduce 239) ((T_ISSET) reduce 239) ((T_LINE) reduce 239) ((T_LIST) reduce 239) ((T_LNUMBER) reduce 239) ((T_MATCH) reduce 239) ((T_METHOD_C) reduce 239) ((T_NAMESPACE) reduce 239) ((T_NAME_FULLY_QUALIFIED) reduce 239) ((T_NAME_QUALIFIED) reduce 239) ((T_NAME_RELATIVE) reduce 239) ((T_NEW) reduce 239) ((T_NS_C) reduce 239) ((T_OBJECT_CAST) reduce 239) ((T_PRINT) reduce 239) ((T_READONLY) reduce 239) ((T_REQUIRE) reduce 239) ((T_REQUIRE_ONCE) reduce 239) ((T_RETURN) reduce 239) ((T_START_HEREDOC) reduce 239) ((T_STATIC) reduce 239) ((T_STRING) reduce 239) ((T_STRING_CAST) reduce 239) ((T_SWITCH) reduce 239) ((T_THROW) reduce 239) ((T_TRAIT) reduce 239) ((T_TRAIT_C) reduce 239) ((T_TRY) reduce 239) ((T_UNSET) reduce 239) ((T_UNSET_CAST) reduce 239) ((T_USE) reduce 239) ((T_VARIABLE) reduce 239) ((T_WHILE) reduce 239) ((T_YIELD) reduce 239) ((T_YIELD_FROM) reduce 239) (("[") reduce 239) (("`") reduce 239) (("{") reduce 239) (("~") reduce 239)) 25823 ((("!") reduce 148) (("\"") reduce 148) (($) reduce 148) (("$") reduce 148) (("(") reduce 148) (("+") reduce 148) (("-") reduce 148) ((";") reduce 148) (("@") reduce 148) ((T_ABSTRACT) reduce 148) ((T_ARRAY) reduce 148) ((T_ARRAY_CAST) reduce 148) ((T_ATTRIBUTE) reduce 148) ((T_BOOL_CAST) reduce 148) ((T_BREAK) reduce 148) ((T_CLASS) reduce 148) ((T_CLASS_C) reduce 148) ((T_CLONE) reduce 148) ((T_CONST) reduce 148) ((T_CONSTANT_ENCAPSED_STRING) reduce 148) ((T_CONTINUE) reduce 148) ((T_DEC) reduce 148) ((T_DECLARE) reduce 148) ((T_DIR) reduce 148) ((T_DNUMBER) reduce 148) ((T_DO) reduce 148) ((T_DOUBLE_CAST) reduce 148) ((T_ECHO) reduce 148) ((T_ELSE) reduce 148) ((T_ELSEIF) reduce 148) ((T_EMPTY) reduce 148) ((T_ENUM) reduce 148) ((T_EVAL) reduce 148) ((T_EXIT) reduce 148) ((T_FILE) reduce 148) ((T_FINAL) reduce 148) ((T_FN) reduce 148) ((T_FOR) reduce 148) ((T_FOREACH) reduce 148) ((T_FUNCTION) reduce 148) ((T_FUNC_C) reduce 148) ((T_GLOBAL) reduce 148) ((T_GOTO) reduce 148) ((T_HALT_COMPILER) reduce 148) ((T_IF) reduce 148) ((T_INC) reduce 148) ((T_INCLUDE) reduce 148) ((T_INCLUDE_ONCE) reduce 148) ((T_INLINE_HTML) reduce 148) ((T_INTERFACE) reduce 148) ((T_INT_CAST) reduce 148) ((T_ISSET) reduce 148) ((T_LINE) reduce 148) ((T_LIST) reduce 148) ((T_LNUMBER) reduce 148) ((T_MATCH) reduce 148) ((T_METHOD_C) reduce 148) ((T_NAMESPACE) reduce 148) ((T_NAME_FULLY_QUALIFIED) reduce 148) ((T_NAME_QUALIFIED) reduce 148) ((T_NAME_RELATIVE) reduce 148) ((T_NEW) reduce 148) ((T_NS_C) reduce 148) ((T_OBJECT_CAST) reduce 148) ((T_PRINT) reduce 148) ((T_READONLY) reduce 148) ((T_REQUIRE) reduce 148) ((T_REQUIRE_ONCE) reduce 148) ((T_RETURN) reduce 148) ((T_START_HEREDOC) reduce 148) ((T_STATIC) reduce 148) ((T_STRING) reduce 148) ((T_STRING_CAST) reduce 148) ((T_SWITCH) reduce 148) ((T_THROW) reduce 148) ((T_TRAIT) reduce 148) ((T_TRAIT_C) reduce 148) ((T_TRY) reduce 148) ((T_UNSET) reduce 148) ((T_UNSET_CAST) reduce 148) ((T_USE) reduce 148) ((T_VARIABLE) reduce 148) ((T_WHILE) reduce 148) ((T_YIELD) reduce 148) ((T_YIELD_FROM) reduce 148) (("[") reduce 148) (("`") reduce 148) (("{") reduce 148) (("~") reduce 148)) 25826 ((("!") reduce 240) (("\"") reduce 240) (($) reduce 240) (("$") reduce 240) (("(") reduce 240) (("+") reduce 240) (("-") reduce 240) ((";") reduce 240) (("@") reduce 240) ((T_ABSTRACT) reduce 240) ((T_ARRAY) reduce 240) ((T_ARRAY_CAST) reduce 240) ((T_ATTRIBUTE) reduce 240) ((T_BOOL_CAST) reduce 240) ((T_BREAK) reduce 240) ((T_CLASS) reduce 240) ((T_CLASS_C) reduce 240) ((T_CLONE) reduce 240) ((T_CONST) reduce 240) ((T_CONSTANT_ENCAPSED_STRING) reduce 240) ((T_CONTINUE) reduce 240) ((T_DEC) reduce 240) ((T_DECLARE) reduce 240) ((T_DIR) reduce 240) ((T_DNUMBER) reduce 240) ((T_DO) reduce 240) ((T_DOUBLE_CAST) reduce 240) ((T_ECHO) reduce 240) ((T_ELSE) reduce 240) ((T_ELSEIF) reduce 240) ((T_EMPTY) reduce 240) ((T_ENUM) reduce 240) ((T_EVAL) reduce 240) ((T_EXIT) reduce 240) ((T_FILE) reduce 240) ((T_FINAL) reduce 240) ((T_FN) reduce 240) ((T_FOR) reduce 240) ((T_FOREACH) reduce 240) ((T_FUNCTION) reduce 240) ((T_FUNC_C) reduce 240) ((T_GLOBAL) reduce 240) ((T_GOTO) reduce 240) ((T_HALT_COMPILER) reduce 240) ((T_IF) reduce 240) ((T_INC) reduce 240) ((T_INCLUDE) reduce 240) ((T_INCLUDE_ONCE) reduce 240) ((T_INLINE_HTML) reduce 240) ((T_INTERFACE) reduce 240) ((T_INT_CAST) reduce 240) ((T_ISSET) reduce 240) ((T_LINE) reduce 240) ((T_LIST) reduce 240) ((T_LNUMBER) reduce 240) ((T_MATCH) reduce 240) ((T_METHOD_C) reduce 240) ((T_NAMESPACE) reduce 240) ((T_NAME_FULLY_QUALIFIED) reduce 240) ((T_NAME_QUALIFIED) reduce 240) ((T_NAME_RELATIVE) reduce 240) ((T_NEW) reduce 240) ((T_NS_C) reduce 240) ((T_OBJECT_CAST) reduce 240) ((T_PRINT) reduce 240) ((T_READONLY) reduce 240) ((T_REQUIRE) reduce 240) ((T_REQUIRE_ONCE) reduce 240) ((T_RETURN) reduce 240) ((T_START_HEREDOC) reduce 240) ((T_STATIC) reduce 240) ((T_STRING) reduce 240) ((T_STRING_CAST) reduce 240) ((T_SWITCH) reduce 240) ((T_THROW) reduce 240) ((T_TRAIT) reduce 240) ((T_TRAIT_C) reduce 240) ((T_TRY) reduce 240) ((T_UNSET) reduce 240) ((T_UNSET_CAST) reduce 240) ((T_USE) reduce 240) ((T_VARIABLE) reduce 240) ((T_WHILE) reduce 240) ((T_YIELD) reduce 240) ((T_YIELD_FROM) reduce 240) (("[") reduce 240) (("`") reduce 240) (("{") reduce 240) (("~") reduce 240)) 25831 ((("!") reduce 160) (("\"") reduce 160) (("$") reduce 160) (($) reduce 160) (("(") reduce 160) (("+") reduce 160) (("-") reduce 160) ((";") reduce 160) (("@") reduce 160) ((T_ABSTRACT) reduce 160) ((T_ARRAY) reduce 160) ((T_ARRAY_CAST) reduce 160) ((T_ATTRIBUTE) reduce 160) ((T_BOOL_CAST) reduce 160) ((T_BREAK) reduce 160) ((T_CLASS) reduce 160) ((T_CLASS_C) reduce 160) ((T_CLONE) reduce 160) ((T_CONST) reduce 160) ((T_CONSTANT_ENCAPSED_STRING) reduce 160) ((T_CONTINUE) reduce 160) ((T_DEC) reduce 160) ((T_DECLARE) reduce 160) ((T_DIR) reduce 160) ((T_DNUMBER) reduce 160) ((T_DO) reduce 160) ((T_DOUBLE_CAST) reduce 160) ((T_ECHO) reduce 160) ((T_ELSE) reduce 160) ((T_ELSEIF) reduce 160) ((T_EMPTY) reduce 160) ((T_ENUM) reduce 160) ((T_EVAL) reduce 160) ((T_EXIT) reduce 160) ((T_FILE) reduce 160) ((T_FINAL) reduce 160) ((T_FN) reduce 160) ((T_FOR) reduce 160) ((T_FOREACH) reduce 160) ((T_FUNCTION) reduce 160) ((T_FUNC_C) reduce 160) ((T_GLOBAL) reduce 160) ((T_GOTO) reduce 160) ((T_HALT_COMPILER) reduce 160) ((T_IF) reduce 160) ((T_INC) reduce 160) ((T_INCLUDE) reduce 160) ((T_INCLUDE_ONCE) reduce 160) ((T_INLINE_HTML) reduce 160) ((T_INTERFACE) reduce 160) ((T_INT_CAST) reduce 160) ((T_ISSET) reduce 160) ((T_LINE) reduce 160) ((T_LIST) reduce 160) ((T_LNUMBER) reduce 160) ((T_MATCH) reduce 160) ((T_METHOD_C) reduce 160) ((T_NAMESPACE) reduce 160) ((T_NAME_FULLY_QUALIFIED) reduce 160) ((T_NAME_QUALIFIED) reduce 160) ((T_NAME_RELATIVE) reduce 160) ((T_NEW) reduce 160) ((T_NS_C) reduce 160) ((T_OBJECT_CAST) reduce 160) ((T_PRINT) reduce 160) ((T_READONLY) reduce 160) ((T_REQUIRE) reduce 160) ((T_REQUIRE_ONCE) reduce 160) ((T_RETURN) reduce 160) ((T_START_HEREDOC) reduce 160) ((T_STATIC) reduce 160) ((T_STRING) reduce 160) ((T_STRING_CAST) reduce 160) ((T_SWITCH) reduce 160) ((T_THROW) reduce 160) ((T_TRAIT) reduce 160) ((T_TRAIT_C) reduce 160) ((T_TRY) reduce 160) ((T_UNSET) reduce 160) ((T_UNSET_CAST) reduce 160) ((T_USE) reduce 160) ((T_VARIABLE) reduce 160) ((T_WHILE) reduce 160) ((T_YIELD) reduce 160) ((T_YIELD_FROM) reduce 160) (("[") reduce 160) (("`") reduce 160) (("{") reduce 160) (("~") reduce 160)) 25834 ((("!") reduce 168) (("\"") reduce 168) (($) reduce 168) (("$") reduce 168) (("(") reduce 168) (("+") reduce 168) (("-") reduce 168) ((";") reduce 168) (("@") reduce 168) ((T_ABSTRACT) reduce 168) ((T_ARRAY) reduce 168) ((T_ARRAY_CAST) reduce 168) ((T_ATTRIBUTE) reduce 168) ((T_BOOL_CAST) reduce 168) ((T_BREAK) reduce 168) ((T_CATCH) reduce 168) ((T_CLASS) reduce 168) ((T_CLASS_C) reduce 168) ((T_CLONE) reduce 168) ((T_CONST) reduce 168) ((T_CONSTANT_ENCAPSED_STRING) reduce 168) ((T_CONTINUE) reduce 168) ((T_DEC) reduce 168) ((T_DECLARE) reduce 168) ((T_DIR) reduce 168) ((T_DNUMBER) reduce 168) ((T_DO) reduce 168) ((T_DOUBLE_CAST) reduce 168) ((T_ECHO) reduce 168) ((T_ELSE) reduce 168) ((T_ELSEIF) reduce 168) ((T_EMPTY) reduce 168) ((T_ENUM) reduce 168) ((T_EVAL) reduce 168) ((T_EXIT) reduce 168) ((T_FILE) reduce 168) ((T_FINAL) reduce 168) ((T_FINALLY) reduce 168) ((T_FN) reduce 168) ((T_FOR) reduce 168) ((T_FOREACH) reduce 168) ((T_FUNCTION) reduce 168) ((T_FUNC_C) reduce 168) ((T_GLOBAL) reduce 168) ((T_GOTO) reduce 168) ((T_HALT_COMPILER) reduce 168) ((T_IF) reduce 168) ((T_INC) reduce 168) ((T_INCLUDE) reduce 168) ((T_INCLUDE_ONCE) reduce 168) ((T_INLINE_HTML) reduce 168) ((T_INTERFACE) reduce 168) ((T_INT_CAST) reduce 168) ((T_ISSET) reduce 168) ((T_LINE) reduce 168) ((T_LIST) reduce 168) ((T_LNUMBER) reduce 168) ((T_MATCH) reduce 168) ((T_METHOD_C) reduce 168) ((T_NAMESPACE) reduce 168) ((T_NAME_FULLY_QUALIFIED) reduce 168) ((T_NAME_QUALIFIED) reduce 168) ((T_NAME_RELATIVE) reduce 168) ((T_NEW) reduce 168) ((T_NS_C) reduce 168) ((T_OBJECT_CAST) reduce 168) ((T_PRINT) reduce 168) ((T_READONLY) reduce 168) ((T_REQUIRE) reduce 168) ((T_REQUIRE_ONCE) reduce 168) ((T_RETURN) reduce 168) ((T_START_HEREDOC) reduce 168) ((T_STATIC) reduce 168) ((T_STRING) reduce 168) ((T_STRING_CAST) reduce 168) ((T_SWITCH) reduce 168) ((T_THROW) reduce 168) ((T_TRAIT) reduce 168) ((T_TRAIT_C) reduce 168) ((T_TRY) reduce 168) ((T_UNSET) reduce 168) ((T_UNSET_CAST) reduce 168) ((T_USE) reduce 168) ((T_VARIABLE) reduce 168) ((T_WHILE) reduce 168) ((T_YIELD) reduce 168) ((T_YIELD_FROM) reduce 168) (("[") reduce 168) (("`") reduce 168) (("{") reduce 168) (("~") reduce 168)) 25835 ((("!") reduce 174) (("\"") reduce 174) (("$") reduce 174) (($) reduce 174) (("(") reduce 174) (("+") reduce 174) (("-") reduce 174) ((";") reduce 174) (("@") reduce 174) ((T_ABSTRACT) reduce 174) ((T_ARRAY) reduce 174) ((T_ARRAY_CAST) reduce 174) ((T_ATTRIBUTE) reduce 174) ((T_BOOL_CAST) reduce 174) ((T_BREAK) reduce 174) ((T_CATCH) shift) ((T_CLASS) reduce 174) ((T_CLASS_C) reduce 174) ((T_CLONE) reduce 174) ((T_CONST) reduce 174) ((T_CONSTANT_ENCAPSED_STRING) reduce 174) ((T_CONTINUE) reduce 174) ((T_DEC) reduce 174) ((T_DECLARE) reduce 174) ((T_DIR) reduce 174) ((T_DNUMBER) reduce 174) ((T_DO) reduce 174) ((T_DOUBLE_CAST) reduce 174) ((T_ECHO) reduce 174) ((T_ELSE) reduce 174) ((T_ELSEIF) reduce 174) ((T_EMPTY) reduce 174) ((T_ENUM) reduce 174) ((T_EVAL) reduce 174) ((T_EXIT) reduce 174) ((T_FILE) reduce 174) ((T_FINAL) reduce 174) ((T_FINALLY) shift) ((T_FN) reduce 174) ((T_FOR) reduce 174) ((T_FOREACH) reduce 174) ((T_FUNCTION) reduce 174) ((T_FUNC_C) reduce 174) ((T_GLOBAL) reduce 174) ((T_GOTO) reduce 174) ((T_HALT_COMPILER) reduce 174) ((T_IF) reduce 174) ((T_INC) reduce 174) ((T_INCLUDE) reduce 174) ((T_INCLUDE_ONCE) reduce 174) ((T_INLINE_HTML) reduce 174) ((T_INTERFACE) reduce 174) ((T_INT_CAST) reduce 174) ((T_ISSET) reduce 174) ((T_LINE) reduce 174) ((T_LIST) reduce 174) ((T_LNUMBER) reduce 174) ((T_MATCH) reduce 174) ((T_METHOD_C) reduce 174) ((T_NAMESPACE) reduce 174) ((T_NAME_FULLY_QUALIFIED) reduce 174) ((T_NAME_QUALIFIED) reduce 174) ((T_NAME_RELATIVE) reduce 174) ((T_NEW) reduce 174) ((T_NS_C) reduce 174) ((T_OBJECT_CAST) reduce 174) ((T_PRINT) reduce 174) ((T_READONLY) reduce 174) ((T_REQUIRE) reduce 174) ((T_REQUIRE_ONCE) reduce 174) ((T_RETURN) reduce 174) ((T_START_HEREDOC) reduce 174) ((T_STATIC) reduce 174) ((T_STRING) reduce 174) ((T_STRING_CAST) reduce 174) ((T_SWITCH) reduce 174) ((T_THROW) reduce 174) ((T_TRAIT) reduce 174) ((T_TRAIT_C) reduce 174) ((T_TRY) reduce 174) ((T_UNSET) reduce 174) ((T_UNSET_CAST) reduce 174) ((T_USE) reduce 174) ((T_VARIABLE) reduce 174) ((T_WHILE) reduce 174) ((T_YIELD) reduce 174) ((T_YIELD_FROM) reduce 174) (("[") reduce 174) (("`") reduce 174) (("{") reduce 174) (("~") reduce 174)) 25838 ((("!") reduce 165) (("\"") reduce 165) (("$") reduce 165) (($) reduce 165) (("(") reduce 165) (("+") reduce 165) (("-") reduce 165) ((";") reduce 165) (("@") reduce 165) ((T_ABSTRACT) reduce 165) ((T_ARRAY) reduce 165) ((T_ARRAY_CAST) reduce 165) ((T_ATTRIBUTE) reduce 165) ((T_BOOL_CAST) reduce 165) ((T_BREAK) reduce 165) ((T_CLASS) reduce 165) ((T_CLASS_C) reduce 165) ((T_CLONE) reduce 165) ((T_CONST) reduce 165) ((T_CONSTANT_ENCAPSED_STRING) reduce 165) ((T_CONTINUE) reduce 165) ((T_DEC) reduce 165) ((T_DECLARE) reduce 165) ((T_DIR) reduce 165) ((T_DNUMBER) reduce 165) ((T_DO) reduce 165) ((T_DOUBLE_CAST) reduce 165) ((T_ECHO) reduce 165) ((T_ELSE) reduce 165) ((T_ELSEIF) reduce 165) ((T_EMPTY) reduce 165) ((T_ENUM) reduce 165) ((T_EVAL) reduce 165) ((T_EXIT) reduce 165) ((T_FILE) reduce 165) ((T_FINAL) reduce 165) ((T_FN) reduce 165) ((T_FOR) reduce 165) ((T_FOREACH) reduce 165) ((T_FUNCTION) reduce 165) ((T_FUNC_C) reduce 165) ((T_GLOBAL) reduce 165) ((T_GOTO) reduce 165) ((T_HALT_COMPILER) reduce 165) ((T_IF) reduce 165) ((T_INC) reduce 165) ((T_INCLUDE) reduce 165) ((T_INCLUDE_ONCE) reduce 165) ((T_INLINE_HTML) reduce 165) ((T_INTERFACE) reduce 165) ((T_INT_CAST) reduce 165) ((T_ISSET) reduce 165) ((T_LINE) reduce 165) ((T_LIST) reduce 165) ((T_LNUMBER) reduce 165) ((T_MATCH) reduce 165) ((T_METHOD_C) reduce 165) ((T_NAMESPACE) reduce 165) ((T_NAME_FULLY_QUALIFIED) reduce 165) ((T_NAME_QUALIFIED) reduce 165) ((T_NAME_RELATIVE) reduce 165) ((T_NEW) reduce 165) ((T_NS_C) reduce 165) ((T_OBJECT_CAST) reduce 165) ((T_PRINT) reduce 165) ((T_READONLY) reduce 165) ((T_REQUIRE) reduce 165) ((T_REQUIRE_ONCE) reduce 165) ((T_RETURN) reduce 165) ((T_START_HEREDOC) reduce 165) ((T_STATIC) reduce 165) ((T_STRING) reduce 165) ((T_STRING_CAST) reduce 165) ((T_SWITCH) reduce 165) ((T_THROW) reduce 165) ((T_TRAIT) reduce 165) ((T_TRAIT_C) reduce 165) ((T_TRY) reduce 165) ((T_UNSET) reduce 165) ((T_UNSET_CAST) reduce 165) ((T_USE) reduce 165) ((T_VARIABLE) reduce 165) ((T_WHILE) reduce 165) ((T_YIELD) reduce 165) ((T_YIELD_FROM) reduce 165) (("[") reduce 165) (("`") reduce 165) (("{") reduce 165) (("~") reduce 165)) 25841 ((("!") reduce 175) (("\"") reduce 175) (("$") reduce 175) (($) reduce 175) (("(") reduce 175) (("+") reduce 175) (("-") reduce 175) ((";") reduce 175) (("@") reduce 175) ((T_ABSTRACT) reduce 175) ((T_ARRAY) reduce 175) ((T_ARRAY_CAST) reduce 175) ((T_ATTRIBUTE) reduce 175) ((T_BOOL_CAST) reduce 175) ((T_BREAK) reduce 175) ((T_CLASS) reduce 175) ((T_CLASS_C) reduce 175) ((T_CLONE) reduce 175) ((T_CONST) reduce 175) ((T_CONSTANT_ENCAPSED_STRING) reduce 175) ((T_CONTINUE) reduce 175) ((T_DEC) reduce 175) ((T_DECLARE) reduce 175) ((T_DIR) reduce 175) ((T_DNUMBER) reduce 175) ((T_DO) reduce 175) ((T_DOUBLE_CAST) reduce 175) ((T_ECHO) reduce 175) ((T_ELSE) reduce 175) ((T_ELSEIF) reduce 175) ((T_EMPTY) reduce 175) ((T_ENUM) reduce 175) ((T_EVAL) reduce 175) ((T_EXIT) reduce 175) ((T_FILE) reduce 175) ((T_FINAL) reduce 175) ((T_FN) reduce 175) ((T_FOR) reduce 175) ((T_FOREACH) reduce 175) ((T_FUNCTION) reduce 175) ((T_FUNC_C) reduce 175) ((T_GLOBAL) reduce 175) ((T_GOTO) reduce 175) ((T_HALT_COMPILER) reduce 175) ((T_IF) reduce 175) ((T_INC) reduce 175) ((T_INCLUDE) reduce 175) ((T_INCLUDE_ONCE) reduce 175) ((T_INLINE_HTML) reduce 175) ((T_INTERFACE) reduce 175) ((T_INT_CAST) reduce 175) ((T_ISSET) reduce 175) ((T_LINE) reduce 175) ((T_LIST) reduce 175) ((T_LNUMBER) reduce 175) ((T_MATCH) reduce 175) ((T_METHOD_C) reduce 175) ((T_NAMESPACE) reduce 175) ((T_NAME_FULLY_QUALIFIED) reduce 175) ((T_NAME_QUALIFIED) reduce 175) ((T_NAME_RELATIVE) reduce 175) ((T_NEW) reduce 175) ((T_NS_C) reduce 175) ((T_OBJECT_CAST) reduce 175) ((T_PRINT) reduce 175) ((T_READONLY) reduce 175) ((T_REQUIRE) reduce 175) ((T_REQUIRE_ONCE) reduce 175) ((T_RETURN) reduce 175) ((T_START_HEREDOC) reduce 175) ((T_STATIC) reduce 175) ((T_STRING) reduce 175) ((T_STRING_CAST) reduce 175) ((T_SWITCH) reduce 175) ((T_THROW) reduce 175) ((T_TRAIT) reduce 175) ((T_TRAIT_C) reduce 175) ((T_TRY) reduce 175) ((T_UNSET) reduce 175) ((T_UNSET_CAST) reduce 175) ((T_USE) reduce 175) ((T_VARIABLE) reduce 175) ((T_WHILE) reduce 175) ((T_YIELD) reduce 175) ((T_YIELD_FROM) reduce 175) (("[") reduce 175) (("`") reduce 175) (("{") reduce 175) (("~") reduce 175)) 25848 ((("!") reduce 169) (("\"") reduce 169) (("$") reduce 169) (($) reduce 169) (("(") reduce 169) (("+") reduce 169) (("-") reduce 169) ((";") reduce 169) (("@") reduce 169) ((T_ABSTRACT) reduce 169) ((T_ARRAY) reduce 169) ((T_ARRAY_CAST) reduce 169) ((T_ATTRIBUTE) reduce 169) ((T_BOOL_CAST) reduce 169) ((T_BREAK) reduce 169) ((T_CATCH) reduce 169) ((T_CLASS) reduce 169) ((T_CLASS_C) reduce 169) ((T_CLONE) reduce 169) ((T_CONST) reduce 169) ((T_CONSTANT_ENCAPSED_STRING) reduce 169) ((T_CONTINUE) reduce 169) ((T_DEC) reduce 169) ((T_DECLARE) reduce 169) ((T_DIR) reduce 169) ((T_DNUMBER) reduce 169) ((T_DO) reduce 169) ((T_DOUBLE_CAST) reduce 169) ((T_ECHO) reduce 169) ((T_ELSE) reduce 169) ((T_ELSEIF) reduce 169) ((T_EMPTY) reduce 169) ((T_ENUM) reduce 169) ((T_EVAL) reduce 169) ((T_EXIT) reduce 169) ((T_FILE) reduce 169) ((T_FINAL) reduce 169) ((T_FINALLY) reduce 169) ((T_FN) reduce 169) ((T_FOR) reduce 169) ((T_FOREACH) reduce 169) ((T_FUNCTION) reduce 169) ((T_FUNC_C) reduce 169) ((T_GLOBAL) reduce 169) ((T_GOTO) reduce 169) ((T_HALT_COMPILER) reduce 169) ((T_IF) reduce 169) ((T_INC) reduce 169) ((T_INCLUDE) reduce 169) ((T_INCLUDE_ONCE) reduce 169) ((T_INLINE_HTML) reduce 169) ((T_INTERFACE) reduce 169) ((T_INT_CAST) reduce 169) ((T_ISSET) reduce 169) ((T_LINE) reduce 169) ((T_LIST) reduce 169) ((T_LNUMBER) reduce 169) ((T_MATCH) reduce 169) ((T_METHOD_C) reduce 169) ((T_NAMESPACE) reduce 169) ((T_NAME_FULLY_QUALIFIED) reduce 169) ((T_NAME_QUALIFIED) reduce 169) ((T_NAME_RELATIVE) reduce 169) ((T_NEW) reduce 169) ((T_NS_C) reduce 169) ((T_OBJECT_CAST) reduce 169) ((T_PRINT) reduce 169) ((T_READONLY) reduce 169) ((T_REQUIRE) reduce 169) ((T_REQUIRE_ONCE) reduce 169) ((T_RETURN) reduce 169) ((T_START_HEREDOC) reduce 169) ((T_STATIC) reduce 169) ((T_STRING) reduce 169) ((T_STRING_CAST) reduce 169) ((T_SWITCH) reduce 169) ((T_THROW) reduce 169) ((T_TRAIT) reduce 169) ((T_TRAIT_C) reduce 169) ((T_TRY) reduce 169) ((T_UNSET) reduce 169) ((T_UNSET_CAST) reduce 169) ((T_USE) reduce 169) ((T_VARIABLE) reduce 169) ((T_WHILE) reduce 169) ((T_YIELD) reduce 169) ((T_YIELD_FROM) reduce 169) (("[") reduce 169) (("`") reduce 169) (("{") reduce 169) (("~") reduce 169)) 25853 ((("!") reduce 151) (("\"") reduce 151) (($) reduce 151) (("$") reduce 151) (("(") reduce 151) (("+") reduce 151) (("-") reduce 151) ((";") reduce 151) (("@") reduce 151) ((T_ABSTRACT) reduce 151) ((T_ARRAY) reduce 151) ((T_ARRAY_CAST) reduce 151) ((T_ATTRIBUTE) reduce 151) ((T_BOOL_CAST) reduce 151) ((T_BREAK) reduce 151) ((T_CLASS) reduce 151) ((T_CLASS_C) reduce 151) ((T_CLONE) reduce 151) ((T_CONST) reduce 151) ((T_CONSTANT_ENCAPSED_STRING) reduce 151) ((T_CONTINUE) reduce 151) ((T_DEC) reduce 151) ((T_DECLARE) reduce 151) ((T_DIR) reduce 151) ((T_DNUMBER) reduce 151) ((T_DO) reduce 151) ((T_DOUBLE_CAST) reduce 151) ((T_ECHO) reduce 151) ((T_ELSE) reduce 151) ((T_ELSEIF) reduce 151) ((T_EMPTY) reduce 151) ((T_ENUM) reduce 151) ((T_EVAL) reduce 151) ((T_EXIT) reduce 151) ((T_FILE) reduce 151) ((T_FINAL) reduce 151) ((T_FN) reduce 151) ((T_FOR) reduce 151) ((T_FOREACH) reduce 151) ((T_FUNCTION) reduce 151) ((T_FUNC_C) reduce 151) ((T_GLOBAL) reduce 151) ((T_GOTO) reduce 151) ((T_HALT_COMPILER) reduce 151) ((T_IF) reduce 151) ((T_INC) reduce 151) ((T_INCLUDE) reduce 151) ((T_INCLUDE_ONCE) reduce 151) ((T_INLINE_HTML) reduce 151) ((T_INTERFACE) reduce 151) ((T_INT_CAST) reduce 151) ((T_ISSET) reduce 151) ((T_LINE) reduce 151) ((T_LIST) reduce 151) ((T_LNUMBER) reduce 151) ((T_MATCH) reduce 151) ((T_METHOD_C) reduce 151) ((T_NAMESPACE) reduce 151) ((T_NAME_FULLY_QUALIFIED) reduce 151) ((T_NAME_QUALIFIED) reduce 151) ((T_NAME_RELATIVE) reduce 151) ((T_NEW) reduce 151) ((T_NS_C) reduce 151) ((T_OBJECT_CAST) reduce 151) ((T_PRINT) reduce 151) ((T_READONLY) reduce 151) ((T_REQUIRE) reduce 151) ((T_REQUIRE_ONCE) reduce 151) ((T_RETURN) reduce 151) ((T_START_HEREDOC) reduce 151) ((T_STATIC) reduce 151) ((T_STRING) reduce 151) ((T_STRING_CAST) reduce 151) ((T_SWITCH) reduce 151) ((T_THROW) reduce 151) ((T_TRAIT) reduce 151) ((T_TRAIT_C) reduce 151) ((T_TRY) reduce 151) ((T_UNSET) reduce 151) ((T_UNSET_CAST) reduce 151) ((T_USE) reduce 151) ((T_VARIABLE) reduce 151) ((T_WHILE) reduce 151) ((T_YIELD) reduce 151) ((T_YIELD_FROM) reduce 151) (("[") reduce 151) (("`") reduce 151) (("{") reduce 151) (("~") reduce 151)) 25857 ((("!") reduce 221) (("\"") reduce 221) (("$") reduce 221) (($) reduce 221) (("(") reduce 221) (("+") reduce 221) (("-") reduce 221) ((";") reduce 221) (("@") reduce 221) ((T_ABSTRACT) reduce 221) ((T_ARRAY) reduce 221) ((T_ARRAY_CAST) reduce 221) ((T_ATTRIBUTE) reduce 221) ((T_BOOL_CAST) reduce 221) ((T_BREAK) reduce 221) ((T_CLASS) reduce 221) ((T_CLASS_C) reduce 221) ((T_CLONE) reduce 221) ((T_CONST) reduce 221) ((T_CONSTANT_ENCAPSED_STRING) reduce 221) ((T_CONTINUE) reduce 221) ((T_DEC) reduce 221) ((T_DECLARE) reduce 221) ((T_DIR) reduce 221) ((T_DNUMBER) reduce 221) ((T_DO) reduce 221) ((T_DOUBLE_CAST) reduce 221) ((T_ECHO) reduce 221) ((T_ELSE) reduce 221) ((T_ELSEIF) reduce 221) ((T_EMPTY) reduce 221) ((T_ENUM) reduce 221) ((T_EVAL) reduce 221) ((T_EXIT) reduce 221) ((T_FILE) reduce 221) ((T_FINAL) reduce 221) ((T_FN) reduce 221) ((T_FOR) reduce 221) ((T_FOREACH) reduce 221) ((T_FUNCTION) reduce 221) ((T_FUNC_C) reduce 221) ((T_GLOBAL) reduce 221) ((T_GOTO) reduce 221) ((T_HALT_COMPILER) reduce 221) ((T_IF) reduce 221) ((T_INC) reduce 221) ((T_INCLUDE) reduce 221) ((T_INCLUDE_ONCE) reduce 221) ((T_INLINE_HTML) reduce 221) ((T_INTERFACE) reduce 221) ((T_INT_CAST) reduce 221) ((T_ISSET) reduce 221) ((T_LINE) reduce 221) ((T_LIST) reduce 221) ((T_LNUMBER) reduce 221) ((T_MATCH) reduce 221) ((T_METHOD_C) reduce 221) ((T_NAMESPACE) reduce 221) ((T_NAME_FULLY_QUALIFIED) reduce 221) ((T_NAME_QUALIFIED) reduce 221) ((T_NAME_RELATIVE) reduce 221) ((T_NEW) reduce 221) ((T_NS_C) reduce 221) ((T_OBJECT_CAST) reduce 221) ((T_PRINT) reduce 221) ((T_READONLY) reduce 221) ((T_REQUIRE) reduce 221) ((T_REQUIRE_ONCE) reduce 221) ((T_RETURN) reduce 221) ((T_START_HEREDOC) reduce 221) ((T_STATIC) reduce 221) ((T_STRING) reduce 221) ((T_STRING_CAST) reduce 221) ((T_SWITCH) reduce 221) ((T_THROW) reduce 221) ((T_TRAIT) reduce 221) ((T_TRAIT_C) reduce 221) ((T_TRY) reduce 221) ((T_UNSET) reduce 221) ((T_UNSET_CAST) reduce 221) ((T_USE) reduce 221) ((T_VARIABLE) reduce 221) ((T_WHILE) reduce 221) ((T_YIELD) reduce 221) ((T_YIELD_FROM) reduce 221) (("[") reduce 221) (("`") reduce 221) (("{") reduce 221) (("~") reduce 221)) 25859 ((("!") reduce 222) (("\"") reduce 222) (($) reduce 222) (("$") reduce 222) (("(") reduce 222) (("+") reduce 222) (("-") reduce 222) ((";") reduce 222) (("@") reduce 222) ((T_ABSTRACT) reduce 222) ((T_ARRAY) reduce 222) ((T_ARRAY_CAST) reduce 222) ((T_ATTRIBUTE) reduce 222) ((T_BOOL_CAST) reduce 222) ((T_BREAK) reduce 222) ((T_CLASS) reduce 222) ((T_CLASS_C) reduce 222) ((T_CLONE) reduce 222) ((T_CONST) reduce 222) ((T_CONSTANT_ENCAPSED_STRING) reduce 222) ((T_CONTINUE) reduce 222) ((T_DEC) reduce 222) ((T_DECLARE) reduce 222) ((T_DIR) reduce 222) ((T_DNUMBER) reduce 222) ((T_DO) reduce 222) ((T_DOUBLE_CAST) reduce 222) ((T_ECHO) reduce 222) ((T_ELSE) reduce 222) ((T_ELSEIF) reduce 222) ((T_EMPTY) reduce 222) ((T_ENUM) reduce 222) ((T_EVAL) reduce 222) ((T_EXIT) reduce 222) ((T_FILE) reduce 222) ((T_FINAL) reduce 222) ((T_FN) reduce 222) ((T_FOR) reduce 222) ((T_FOREACH) reduce 222) ((T_FUNCTION) reduce 222) ((T_FUNC_C) reduce 222) ((T_GLOBAL) reduce 222) ((T_GOTO) reduce 222) ((T_HALT_COMPILER) reduce 222) ((T_IF) reduce 222) ((T_INC) reduce 222) ((T_INCLUDE) reduce 222) ((T_INCLUDE_ONCE) reduce 222) ((T_INLINE_HTML) reduce 222) ((T_INTERFACE) reduce 222) ((T_INT_CAST) reduce 222) ((T_ISSET) reduce 222) ((T_LINE) reduce 222) ((T_LIST) reduce 222) ((T_LNUMBER) reduce 222) ((T_MATCH) reduce 222) ((T_METHOD_C) reduce 222) ((T_NAMESPACE) reduce 222) ((T_NAME_FULLY_QUALIFIED) reduce 222) ((T_NAME_QUALIFIED) reduce 222) ((T_NAME_RELATIVE) reduce 222) ((T_NEW) reduce 222) ((T_NS_C) reduce 222) ((T_OBJECT_CAST) reduce 222) ((T_PRINT) reduce 222) ((T_READONLY) reduce 222) ((T_REQUIRE) reduce 222) ((T_REQUIRE_ONCE) reduce 222) ((T_RETURN) reduce 222) ((T_START_HEREDOC) reduce 222) ((T_STATIC) reduce 222) ((T_STRING) reduce 222) ((T_STRING_CAST) reduce 222) ((T_SWITCH) reduce 222) ((T_THROW) reduce 222) ((T_TRAIT) reduce 222) ((T_TRAIT_C) reduce 222) ((T_TRY) reduce 222) ((T_UNSET) reduce 222) ((T_UNSET_CAST) reduce 222) ((T_USE) reduce 222) ((T_VARIABLE) reduce 222) ((T_WHILE) reduce 222) ((T_YIELD) reduce 222) ((T_YIELD_FROM) reduce 222) (("[") reduce 222) (("`") reduce 222) (("{") reduce 222) (("~") reduce 222)) 25863 ((("!") reduce 223) (("\"") reduce 223) (($) reduce 223) (("$") reduce 223) (("(") reduce 223) (("+") reduce 223) (("-") reduce 223) ((";") reduce 223) (("@") reduce 223) ((T_ABSTRACT) reduce 223) ((T_ARRAY) reduce 223) ((T_ARRAY_CAST) reduce 223) ((T_ATTRIBUTE) reduce 223) ((T_BOOL_CAST) reduce 223) ((T_BREAK) reduce 223) ((T_CLASS) reduce 223) ((T_CLASS_C) reduce 223) ((T_CLONE) reduce 223) ((T_CONST) reduce 223) ((T_CONSTANT_ENCAPSED_STRING) reduce 223) ((T_CONTINUE) reduce 223) ((T_DEC) reduce 223) ((T_DECLARE) reduce 223) ((T_DIR) reduce 223) ((T_DNUMBER) reduce 223) ((T_DO) reduce 223) ((T_DOUBLE_CAST) reduce 223) ((T_ECHO) reduce 223) ((T_ELSE) reduce 223) ((T_ELSEIF) reduce 223) ((T_EMPTY) reduce 223) ((T_ENUM) reduce 223) ((T_EVAL) reduce 223) ((T_EXIT) reduce 223) ((T_FILE) reduce 223) ((T_FINAL) reduce 223) ((T_FN) reduce 223) ((T_FOR) reduce 223) ((T_FOREACH) reduce 223) ((T_FUNCTION) reduce 223) ((T_FUNC_C) reduce 223) ((T_GLOBAL) reduce 223) ((T_GOTO) reduce 223) ((T_HALT_COMPILER) reduce 223) ((T_IF) reduce 223) ((T_INC) reduce 223) ((T_INCLUDE) reduce 223) ((T_INCLUDE_ONCE) reduce 223) ((T_INLINE_HTML) reduce 223) ((T_INTERFACE) reduce 223) ((T_INT_CAST) reduce 223) ((T_ISSET) reduce 223) ((T_LINE) reduce 223) ((T_LIST) reduce 223) ((T_LNUMBER) reduce 223) ((T_MATCH) reduce 223) ((T_METHOD_C) reduce 223) ((T_NAMESPACE) reduce 223) ((T_NAME_FULLY_QUALIFIED) reduce 223) ((T_NAME_QUALIFIED) reduce 223) ((T_NAME_RELATIVE) reduce 223) ((T_NEW) reduce 223) ((T_NS_C) reduce 223) ((T_OBJECT_CAST) reduce 223) ((T_PRINT) reduce 223) ((T_READONLY) reduce 223) ((T_REQUIRE) reduce 223) ((T_REQUIRE_ONCE) reduce 223) ((T_RETURN) reduce 223) ((T_START_HEREDOC) reduce 223) ((T_STATIC) reduce 223) ((T_STRING) reduce 223) ((T_STRING_CAST) reduce 223) ((T_SWITCH) reduce 223) ((T_THROW) reduce 223) ((T_TRAIT) reduce 223) ((T_TRAIT_C) reduce 223) ((T_TRY) reduce 223) ((T_UNSET) reduce 223) ((T_UNSET_CAST) reduce 223) ((T_USE) reduce 223) ((T_VARIABLE) reduce 223) ((T_WHILE) reduce 223) ((T_YIELD) reduce 223) ((T_YIELD_FROM) reduce 223) (("[") reduce 223) (("`") reduce 223) (("{") reduce 223) (("~") reduce 223)) 25866 ((("!") reduce 224) (("\"") reduce 224) (("$") reduce 224) (($) reduce 224) (("(") reduce 224) (("+") reduce 224) (("-") reduce 224) ((";") reduce 224) (("@") reduce 224) ((T_ABSTRACT) reduce 224) ((T_ARRAY) reduce 224) ((T_ARRAY_CAST) reduce 224) ((T_ATTRIBUTE) reduce 224) ((T_BOOL_CAST) reduce 224) ((T_BREAK) reduce 224) ((T_CLASS) reduce 224) ((T_CLASS_C) reduce 224) ((T_CLONE) reduce 224) ((T_CONST) reduce 224) ((T_CONSTANT_ENCAPSED_STRING) reduce 224) ((T_CONTINUE) reduce 224) ((T_DEC) reduce 224) ((T_DECLARE) reduce 224) ((T_DIR) reduce 224) ((T_DNUMBER) reduce 224) ((T_DO) reduce 224) ((T_DOUBLE_CAST) reduce 224) ((T_ECHO) reduce 224) ((T_ELSE) reduce 224) ((T_ELSEIF) reduce 224) ((T_EMPTY) reduce 224) ((T_ENUM) reduce 224) ((T_EVAL) reduce 224) ((T_EXIT) reduce 224) ((T_FILE) reduce 224) ((T_FINAL) reduce 224) ((T_FN) reduce 224) ((T_FOR) reduce 224) ((T_FOREACH) reduce 224) ((T_FUNCTION) reduce 224) ((T_FUNC_C) reduce 224) ((T_GLOBAL) reduce 224) ((T_GOTO) reduce 224) ((T_HALT_COMPILER) reduce 224) ((T_IF) reduce 224) ((T_INC) reduce 224) ((T_INCLUDE) reduce 224) ((T_INCLUDE_ONCE) reduce 224) ((T_INLINE_HTML) reduce 224) ((T_INTERFACE) reduce 224) ((T_INT_CAST) reduce 224) ((T_ISSET) reduce 224) ((T_LINE) reduce 224) ((T_LIST) reduce 224) ((T_LNUMBER) reduce 224) ((T_MATCH) reduce 224) ((T_METHOD_C) reduce 224) ((T_NAMESPACE) reduce 224) ((T_NAME_FULLY_QUALIFIED) reduce 224) ((T_NAME_QUALIFIED) reduce 224) ((T_NAME_RELATIVE) reduce 224) ((T_NEW) reduce 224) ((T_NS_C) reduce 224) ((T_OBJECT_CAST) reduce 224) ((T_PRINT) reduce 224) ((T_READONLY) reduce 224) ((T_REQUIRE) reduce 224) ((T_REQUIRE_ONCE) reduce 224) ((T_RETURN) reduce 224) ((T_START_HEREDOC) reduce 224) ((T_STATIC) reduce 224) ((T_STRING) reduce 224) ((T_STRING_CAST) reduce 224) ((T_SWITCH) reduce 224) ((T_THROW) reduce 224) ((T_TRAIT) reduce 224) ((T_TRAIT_C) reduce 224) ((T_TRY) reduce 224) ((T_UNSET) reduce 224) ((T_UNSET_CAST) reduce 224) ((T_USE) reduce 224) ((T_VARIABLE) reduce 224) ((T_WHILE) reduce 224) ((T_YIELD) reduce 224) ((T_YIELD_FROM) reduce 224) (("[") reduce 224) (("`") reduce 224) (("{") reduce 224) (("~") reduce 224)) 25867 ((("!") reduce 167) (("\"") reduce 167) (("$") reduce 167) (($) reduce 167) (("(") reduce 167) (("+") reduce 167) (("-") reduce 167) ((";") reduce 167) (("@") reduce 167) ((T_ABSTRACT) reduce 167) ((T_ARRAY) reduce 167) ((T_ARRAY_CAST) reduce 167) ((T_ATTRIBUTE) reduce 167) ((T_BOOL_CAST) reduce 167) ((T_BREAK) reduce 167) ((T_CLASS) reduce 167) ((T_CLASS_C) reduce 167) ((T_CLONE) reduce 167) ((T_CONST) reduce 167) ((T_CONSTANT_ENCAPSED_STRING) reduce 167) ((T_CONTINUE) reduce 167) ((T_DEC) reduce 167) ((T_DECLARE) reduce 167) ((T_DIR) reduce 167) ((T_DNUMBER) reduce 167) ((T_DO) reduce 167) ((T_DOUBLE_CAST) reduce 167) ((T_ECHO) reduce 167) ((T_ELSE) reduce 167) ((T_ELSEIF) reduce 167) ((T_EMPTY) reduce 167) ((T_ENUM) reduce 167) ((T_EVAL) reduce 167) ((T_EXIT) reduce 167) ((T_FILE) reduce 167) ((T_FINAL) reduce 167) ((T_FN) reduce 167) ((T_FOR) reduce 167) ((T_FOREACH) reduce 167) ((T_FUNCTION) reduce 167) ((T_FUNC_C) reduce 167) ((T_GLOBAL) reduce 167) ((T_GOTO) reduce 167) ((T_HALT_COMPILER) reduce 167) ((T_IF) reduce 167) ((T_INC) reduce 167) ((T_INCLUDE) reduce 167) ((T_INCLUDE_ONCE) reduce 167) ((T_INLINE_HTML) reduce 167) ((T_INTERFACE) reduce 167) ((T_INT_CAST) reduce 167) ((T_ISSET) reduce 167) ((T_LINE) reduce 167) ((T_LIST) reduce 167) ((T_LNUMBER) reduce 167) ((T_MATCH) reduce 167) ((T_METHOD_C) reduce 167) ((T_NAMESPACE) reduce 167) ((T_NAME_FULLY_QUALIFIED) reduce 167) ((T_NAME_QUALIFIED) reduce 167) ((T_NAME_RELATIVE) reduce 167) ((T_NEW) reduce 167) ((T_NS_C) reduce 167) ((T_OBJECT_CAST) reduce 167) ((T_PRINT) reduce 167) ((T_READONLY) reduce 167) ((T_REQUIRE) reduce 167) ((T_REQUIRE_ONCE) reduce 167) ((T_RETURN) reduce 167) ((T_START_HEREDOC) reduce 167) ((T_STATIC) reduce 167) ((T_STRING) reduce 167) ((T_STRING_CAST) reduce 167) ((T_SWITCH) reduce 167) ((T_THROW) reduce 167) ((T_TRAIT) reduce 167) ((T_TRAIT_C) reduce 167) ((T_TRY) reduce 167) ((T_UNSET) reduce 167) ((T_UNSET_CAST) reduce 167) ((T_USE) reduce 167) ((T_VARIABLE) reduce 167) ((T_WHILE) reduce 167) ((T_YIELD) reduce 167) ((T_YIELD_FROM) reduce 167) (("[") reduce 167) (("`") reduce 167) (("{") reduce 167) (("~") reduce 167)) 25869 ((("!") reduce 156) (("\"") reduce 156) (($) reduce 156) (("$") reduce 156) (("(") reduce 156) (("+") reduce 156) (("-") reduce 156) ((";") reduce 156) (("@") reduce 156) ((T_ABSTRACT) reduce 156) ((T_ARRAY) reduce 156) ((T_ARRAY_CAST) reduce 156) ((T_ATTRIBUTE) reduce 156) ((T_BOOL_CAST) reduce 156) ((T_BREAK) reduce 156) ((T_CLASS) reduce 156) ((T_CLASS_C) reduce 156) ((T_CLONE) reduce 156) ((T_CONST) reduce 156) ((T_CONSTANT_ENCAPSED_STRING) reduce 156) ((T_CONTINUE) reduce 156) ((T_DEC) reduce 156) ((T_DECLARE) reduce 156) ((T_DIR) reduce 156) ((T_DNUMBER) reduce 156) ((T_DO) reduce 156) ((T_DOUBLE_CAST) reduce 156) ((T_ECHO) reduce 156) ((T_ELSE) reduce 156) ((T_ELSEIF) reduce 156) ((T_EMPTY) reduce 156) ((T_ENUM) reduce 156) ((T_EVAL) reduce 156) ((T_EXIT) reduce 156) ((T_FILE) reduce 156) ((T_FINAL) reduce 156) ((T_FN) reduce 156) ((T_FOR) reduce 156) ((T_FOREACH) reduce 156) ((T_FUNCTION) reduce 156) ((T_FUNC_C) reduce 156) ((T_GLOBAL) reduce 156) ((T_GOTO) reduce 156) ((T_HALT_COMPILER) reduce 156) ((T_IF) reduce 156) ((T_INC) reduce 156) ((T_INCLUDE) reduce 156) ((T_INCLUDE_ONCE) reduce 156) ((T_INLINE_HTML) reduce 156) ((T_INTERFACE) reduce 156) ((T_INT_CAST) reduce 156) ((T_ISSET) reduce 156) ((T_LINE) reduce 156) ((T_LIST) reduce 156) ((T_LNUMBER) reduce 156) ((T_MATCH) reduce 156) ((T_METHOD_C) reduce 156) ((T_NAMESPACE) reduce 156) ((T_NAME_FULLY_QUALIFIED) reduce 156) ((T_NAME_QUALIFIED) reduce 156) ((T_NAME_RELATIVE) reduce 156) ((T_NEW) reduce 156) ((T_NS_C) reduce 156) ((T_OBJECT_CAST) reduce 156) ((T_PRINT) reduce 156) ((T_READONLY) reduce 156) ((T_REQUIRE) reduce 156) ((T_REQUIRE_ONCE) reduce 156) ((T_RETURN) reduce 156) ((T_START_HEREDOC) reduce 156) ((T_STATIC) reduce 156) ((T_STRING) reduce 156) ((T_STRING_CAST) reduce 156) ((T_SWITCH) reduce 156) ((T_THROW) reduce 156) ((T_TRAIT) reduce 156) ((T_TRAIT_C) reduce 156) ((T_TRY) reduce 156) ((T_UNSET) reduce 156) ((T_UNSET_CAST) reduce 156) ((T_USE) reduce 156) ((T_VARIABLE) reduce 156) ((T_WHILE) reduce 156) ((T_YIELD) reduce 156) ((T_YIELD_FROM) reduce 156) (("[") reduce 156) (("`") reduce 156) (("{") reduce 156) (("~") reduce 156)) 25871 ((("!") reduce 154) (("\"") reduce 154) (($) reduce 154) (("$") reduce 154) (("(") reduce 154) (("+") reduce 154) (("-") reduce 154) ((";") reduce 154) (("@") reduce 154) ((T_ABSTRACT) reduce 154) ((T_ARRAY) reduce 154) ((T_ARRAY_CAST) reduce 154) ((T_ATTRIBUTE) reduce 154) ((T_BOOL_CAST) reduce 154) ((T_BREAK) reduce 154) ((T_CLASS) reduce 154) ((T_CLASS_C) reduce 154) ((T_CLONE) reduce 154) ((T_CONST) reduce 154) ((T_CONSTANT_ENCAPSED_STRING) reduce 154) ((T_CONTINUE) reduce 154) ((T_DEC) reduce 154) ((T_DECLARE) reduce 154) ((T_DIR) reduce 154) ((T_DNUMBER) reduce 154) ((T_DO) reduce 154) ((T_DOUBLE_CAST) reduce 154) ((T_ECHO) reduce 154) ((T_ELSE) reduce 154) ((T_ELSEIF) reduce 154) ((T_EMPTY) reduce 154) ((T_ENUM) reduce 154) ((T_EVAL) reduce 154) ((T_EXIT) reduce 154) ((T_FILE) reduce 154) ((T_FINAL) reduce 154) ((T_FN) reduce 154) ((T_FOR) reduce 154) ((T_FOREACH) reduce 154) ((T_FUNCTION) reduce 154) ((T_FUNC_C) reduce 154) ((T_GLOBAL) reduce 154) ((T_GOTO) reduce 154) ((T_HALT_COMPILER) reduce 154) ((T_IF) reduce 154) ((T_INC) reduce 154) ((T_INCLUDE) reduce 154) ((T_INCLUDE_ONCE) reduce 154) ((T_INLINE_HTML) reduce 154) ((T_INTERFACE) reduce 154) ((T_INT_CAST) reduce 154) ((T_ISSET) reduce 154) ((T_LINE) reduce 154) ((T_LIST) reduce 154) ((T_LNUMBER) reduce 154) ((T_MATCH) reduce 154) ((T_METHOD_C) reduce 154) ((T_NAMESPACE) reduce 154) ((T_NAME_FULLY_QUALIFIED) reduce 154) ((T_NAME_QUALIFIED) reduce 154) ((T_NAME_RELATIVE) reduce 154) ((T_NEW) reduce 154) ((T_NS_C) reduce 154) ((T_OBJECT_CAST) reduce 154) ((T_PRINT) reduce 154) ((T_READONLY) reduce 154) ((T_REQUIRE) reduce 154) ((T_REQUIRE_ONCE) reduce 154) ((T_RETURN) reduce 154) ((T_START_HEREDOC) reduce 154) ((T_STATIC) reduce 154) ((T_STRING) reduce 154) ((T_STRING_CAST) reduce 154) ((T_SWITCH) reduce 154) ((T_THROW) reduce 154) ((T_TRAIT) reduce 154) ((T_TRAIT_C) reduce 154) ((T_TRY) reduce 154) ((T_UNSET) reduce 154) ((T_UNSET_CAST) reduce 154) ((T_USE) reduce 154) ((T_VARIABLE) reduce 154) ((T_WHILE) reduce 154) ((T_YIELD) reduce 154) ((T_YIELD_FROM) reduce 154) (("[") reduce 154) (("`") reduce 154) (("{") reduce 154) (("~") reduce 154)) 25873 ((("!") reduce 166) (("\"") reduce 166) (($) reduce 166) (("$") reduce 166) (("(") reduce 166) (("+") reduce 166) (("-") reduce 166) ((";") reduce 166) (("@") reduce 166) ((T_ABSTRACT) reduce 166) ((T_ARRAY) reduce 166) ((T_ARRAY_CAST) reduce 166) ((T_ATTRIBUTE) reduce 166) ((T_BOOL_CAST) reduce 166) ((T_BREAK) reduce 166) ((T_CLASS) reduce 166) ((T_CLASS_C) reduce 166) ((T_CLONE) reduce 166) ((T_CONST) reduce 166) ((T_CONSTANT_ENCAPSED_STRING) reduce 166) ((T_CONTINUE) reduce 166) ((T_DEC) reduce 166) ((T_DECLARE) reduce 166) ((T_DIR) reduce 166) ((T_DNUMBER) reduce 166) ((T_DO) reduce 166) ((T_DOUBLE_CAST) reduce 166) ((T_ECHO) reduce 166) ((T_ELSE) reduce 166) ((T_ELSEIF) reduce 166) ((T_EMPTY) reduce 166) ((T_ENUM) reduce 166) ((T_EVAL) reduce 166) ((T_EXIT) reduce 166) ((T_FILE) reduce 166) ((T_FINAL) reduce 166) ((T_FN) reduce 166) ((T_FOR) reduce 166) ((T_FOREACH) reduce 166) ((T_FUNCTION) reduce 166) ((T_FUNC_C) reduce 166) ((T_GLOBAL) reduce 166) ((T_GOTO) reduce 166) ((T_HALT_COMPILER) reduce 166) ((T_IF) reduce 166) ((T_INC) reduce 166) ((T_INCLUDE) reduce 166) ((T_INCLUDE_ONCE) reduce 166) ((T_INLINE_HTML) reduce 166) ((T_INTERFACE) reduce 166) ((T_INT_CAST) reduce 166) ((T_ISSET) reduce 166) ((T_LINE) reduce 166) ((T_LIST) reduce 166) ((T_LNUMBER) reduce 166) ((T_MATCH) reduce 166) ((T_METHOD_C) reduce 166) ((T_NAMESPACE) reduce 166) ((T_NAME_FULLY_QUALIFIED) reduce 166) ((T_NAME_QUALIFIED) reduce 166) ((T_NAME_RELATIVE) reduce 166) ((T_NEW) reduce 166) ((T_NS_C) reduce 166) ((T_OBJECT_CAST) reduce 166) ((T_PRINT) reduce 166) ((T_READONLY) reduce 166) ((T_REQUIRE) reduce 166) ((T_REQUIRE_ONCE) reduce 166) ((T_RETURN) reduce 166) ((T_START_HEREDOC) reduce 166) ((T_STATIC) reduce 166) ((T_STRING) reduce 166) ((T_STRING_CAST) reduce 166) ((T_SWITCH) reduce 166) ((T_THROW) reduce 166) ((T_TRAIT) reduce 166) ((T_TRAIT_C) reduce 166) ((T_TRY) reduce 166) ((T_UNSET) reduce 166) ((T_UNSET_CAST) reduce 166) ((T_USE) reduce 166) ((T_VARIABLE) reduce 166) ((T_WHILE) reduce 166) ((T_YIELD) reduce 166) ((T_YIELD_FROM) reduce 166) (("[") reduce 166) (("`") reduce 166) (("{") reduce 166) (("~") reduce 166)) 25875 ((("!") reduce 155) (("\"") reduce 155) (($) reduce 155) (("$") reduce 155) (("(") reduce 155) (("+") reduce 155) (("-") reduce 155) ((";") reduce 155) (("@") reduce 155) ((T_ABSTRACT) reduce 155) ((T_ARRAY) reduce 155) ((T_ARRAY_CAST) reduce 155) ((T_ATTRIBUTE) reduce 155) ((T_BOOL_CAST) reduce 155) ((T_BREAK) reduce 155) ((T_CLASS) reduce 155) ((T_CLASS_C) reduce 155) ((T_CLONE) reduce 155) ((T_CONST) reduce 155) ((T_CONSTANT_ENCAPSED_STRING) reduce 155) ((T_CONTINUE) reduce 155) ((T_DEC) reduce 155) ((T_DECLARE) reduce 155) ((T_DIR) reduce 155) ((T_DNUMBER) reduce 155) ((T_DO) reduce 155) ((T_DOUBLE_CAST) reduce 155) ((T_ECHO) reduce 155) ((T_ELSE) reduce 155) ((T_ELSEIF) reduce 155) ((T_EMPTY) reduce 155) ((T_ENUM) reduce 155) ((T_EVAL) reduce 155) ((T_EXIT) reduce 155) ((T_FILE) reduce 155) ((T_FINAL) reduce 155) ((T_FN) reduce 155) ((T_FOR) reduce 155) ((T_FOREACH) reduce 155) ((T_FUNCTION) reduce 155) ((T_FUNC_C) reduce 155) ((T_GLOBAL) reduce 155) ((T_GOTO) reduce 155) ((T_HALT_COMPILER) reduce 155) ((T_IF) reduce 155) ((T_INC) reduce 155) ((T_INCLUDE) reduce 155) ((T_INCLUDE_ONCE) reduce 155) ((T_INLINE_HTML) reduce 155) ((T_INTERFACE) reduce 155) ((T_INT_CAST) reduce 155) ((T_ISSET) reduce 155) ((T_LINE) reduce 155) ((T_LIST) reduce 155) ((T_LNUMBER) reduce 155) ((T_MATCH) reduce 155) ((T_METHOD_C) reduce 155) ((T_NAMESPACE) reduce 155) ((T_NAME_FULLY_QUALIFIED) reduce 155) ((T_NAME_QUALIFIED) reduce 155) ((T_NAME_RELATIVE) reduce 155) ((T_NEW) reduce 155) ((T_NS_C) reduce 155) ((T_OBJECT_CAST) reduce 155) ((T_PRINT) reduce 155) ((T_READONLY) reduce 155) ((T_REQUIRE) reduce 155) ((T_REQUIRE_ONCE) reduce 155) ((T_RETURN) reduce 155) ((T_START_HEREDOC) reduce 155) ((T_STATIC) reduce 155) ((T_STRING) reduce 155) ((T_STRING_CAST) reduce 155) ((T_SWITCH) reduce 155) ((T_THROW) reduce 155) ((T_TRAIT) reduce 155) ((T_TRAIT_C) reduce 155) ((T_TRY) reduce 155) ((T_UNSET) reduce 155) ((T_UNSET_CAST) reduce 155) ((T_USE) reduce 155) ((T_VARIABLE) reduce 155) ((T_WHILE) reduce 155) ((T_YIELD) reduce 155) ((T_YIELD_FROM) reduce 155) (("[") reduce 155) (("`") reduce 155) (("{") reduce 155) (("~") reduce 155)) 25885 ((("!") reduce 162) (("\"") reduce 162) (($) reduce 162) (("$") reduce 162) (("(") reduce 162) (("+") reduce 162) (("-") reduce 162) ((";") reduce 162) (("@") reduce 162) ((T_ABSTRACT) reduce 162) ((T_ARRAY) reduce 162) ((T_ARRAY_CAST) reduce 162) ((T_ATTRIBUTE) reduce 162) ((T_BOOL_CAST) reduce 162) ((T_BREAK) reduce 162) ((T_CLASS) reduce 162) ((T_CLASS_C) reduce 162) ((T_CLONE) reduce 162) ((T_CONST) reduce 162) ((T_CONSTANT_ENCAPSED_STRING) reduce 162) ((T_CONTINUE) reduce 162) ((T_DEC) reduce 162) ((T_DECLARE) reduce 162) ((T_DIR) reduce 162) ((T_DNUMBER) reduce 162) ((T_DO) reduce 162) ((T_DOUBLE_CAST) reduce 162) ((T_ECHO) reduce 162) ((T_ELSE) reduce 162) ((T_ELSEIF) reduce 162) ((T_EMPTY) reduce 162) ((T_ENUM) reduce 162) ((T_EVAL) reduce 162) ((T_EXIT) reduce 162) ((T_FILE) reduce 162) ((T_FINAL) reduce 162) ((T_FN) reduce 162) ((T_FOR) reduce 162) ((T_FOREACH) reduce 162) ((T_FUNCTION) reduce 162) ((T_FUNC_C) reduce 162) ((T_GLOBAL) reduce 162) ((T_GOTO) reduce 162) ((T_HALT_COMPILER) reduce 162) ((T_IF) reduce 162) ((T_INC) reduce 162) ((T_INCLUDE) reduce 162) ((T_INCLUDE_ONCE) reduce 162) ((T_INLINE_HTML) reduce 162) ((T_INTERFACE) reduce 162) ((T_INT_CAST) reduce 162) ((T_ISSET) reduce 162) ((T_LINE) reduce 162) ((T_LIST) reduce 162) ((T_LNUMBER) reduce 162) ((T_MATCH) reduce 162) ((T_METHOD_C) reduce 162) ((T_NAMESPACE) reduce 162) ((T_NAME_FULLY_QUALIFIED) reduce 162) ((T_NAME_QUALIFIED) reduce 162) ((T_NAME_RELATIVE) reduce 162) ((T_NEW) reduce 162) ((T_NS_C) reduce 162) ((T_OBJECT_CAST) reduce 162) ((T_PRINT) reduce 162) ((T_READONLY) reduce 162) ((T_REQUIRE) reduce 162) ((T_REQUIRE_ONCE) reduce 162) ((T_RETURN) reduce 162) ((T_START_HEREDOC) reduce 162) ((T_STATIC) reduce 162) ((T_STRING) reduce 162) ((T_STRING_CAST) reduce 162) ((T_SWITCH) reduce 162) ((T_THROW) reduce 162) ((T_TRAIT) reduce 162) ((T_TRAIT_C) reduce 162) ((T_TRY) reduce 162) ((T_UNSET) reduce 162) ((T_UNSET_CAST) reduce 162) ((T_USE) reduce 162) ((T_VARIABLE) reduce 162) ((T_WHILE) reduce 162) ((T_YIELD) reduce 162) ((T_YIELD_FROM) reduce 162) (("[") reduce 162) (("`") reduce 162) (("{") reduce 162) (("~") reduce 162)) 25886 ((("!") reduce 217) (("\"") reduce 217) (("$") reduce 217) (($) reduce 217) (("(") reduce 217) (("+") reduce 217) (("-") reduce 217) ((";") reduce 217) (("@") reduce 217) ((T_ABSTRACT) reduce 217) ((T_ARRAY) reduce 217) ((T_ARRAY_CAST) reduce 217) ((T_ATTRIBUTE) reduce 217) ((T_BOOL_CAST) reduce 217) ((T_BREAK) reduce 217) ((T_CLASS) reduce 217) ((T_CLASS_C) reduce 217) ((T_CLONE) reduce 217) ((T_CONST) reduce 217) ((T_CONSTANT_ENCAPSED_STRING) reduce 217) ((T_CONTINUE) reduce 217) ((T_DEC) reduce 217) ((T_DECLARE) reduce 217) ((T_DIR) reduce 217) ((T_DNUMBER) reduce 217) ((T_DO) reduce 217) ((T_DOUBLE_CAST) reduce 217) ((T_ECHO) reduce 217) ((T_ELSE) reduce 217) ((T_ELSEIF) reduce 217) ((T_EMPTY) reduce 217) ((T_ENUM) reduce 217) ((T_EVAL) reduce 217) ((T_EXIT) reduce 217) ((T_FILE) reduce 217) ((T_FINAL) reduce 217) ((T_FN) reduce 217) ((T_FOR) reduce 217) ((T_FOREACH) reduce 217) ((T_FUNCTION) reduce 217) ((T_FUNC_C) reduce 217) ((T_GLOBAL) reduce 217) ((T_GOTO) reduce 217) ((T_HALT_COMPILER) reduce 217) ((T_IF) reduce 217) ((T_INC) reduce 217) ((T_INCLUDE) reduce 217) ((T_INCLUDE_ONCE) reduce 217) ((T_INLINE_HTML) reduce 217) ((T_INTERFACE) reduce 217) ((T_INT_CAST) reduce 217) ((T_ISSET) reduce 217) ((T_LINE) reduce 217) ((T_LIST) reduce 217) ((T_LNUMBER) reduce 217) ((T_MATCH) reduce 217) ((T_METHOD_C) reduce 217) ((T_NAMESPACE) reduce 217) ((T_NAME_FULLY_QUALIFIED) reduce 217) ((T_NAME_QUALIFIED) reduce 217) ((T_NAME_RELATIVE) reduce 217) ((T_NEW) reduce 217) ((T_NS_C) reduce 217) ((T_OBJECT_CAST) reduce 217) ((T_PRINT) reduce 217) ((T_READONLY) reduce 217) ((T_REQUIRE) reduce 217) ((T_REQUIRE_ONCE) reduce 217) ((T_RETURN) reduce 217) ((T_START_HEREDOC) reduce 217) ((T_STATIC) reduce 217) ((T_STRING) reduce 217) ((T_STRING_CAST) reduce 217) ((T_SWITCH) reduce 217) ((T_THROW) reduce 217) ((T_TRAIT) reduce 217) ((T_TRAIT_C) reduce 217) ((T_TRY) reduce 217) ((T_UNSET) reduce 217) ((T_UNSET_CAST) reduce 217) ((T_USE) reduce 217) ((T_VARIABLE) reduce 217) ((T_WHILE) reduce 217) ((T_YIELD) reduce 217) ((T_YIELD_FROM) reduce 217) (("[") reduce 217) (("`") reduce 217) (("{") reduce 217) (("~") reduce 217)) 25889 ((("!") reduce 218) (("\"") reduce 218) (($) reduce 218) (("$") reduce 218) (("(") reduce 218) (("+") reduce 218) (("-") reduce 218) ((";") reduce 218) (("@") reduce 218) ((T_ABSTRACT) reduce 218) ((T_ARRAY) reduce 218) ((T_ARRAY_CAST) reduce 218) ((T_ATTRIBUTE) reduce 218) ((T_BOOL_CAST) reduce 218) ((T_BREAK) reduce 218) ((T_CLASS) reduce 218) ((T_CLASS_C) reduce 218) ((T_CLONE) reduce 218) ((T_CONST) reduce 218) ((T_CONSTANT_ENCAPSED_STRING) reduce 218) ((T_CONTINUE) reduce 218) ((T_DEC) reduce 218) ((T_DECLARE) reduce 218) ((T_DIR) reduce 218) ((T_DNUMBER) reduce 218) ((T_DO) reduce 218) ((T_DOUBLE_CAST) reduce 218) ((T_ECHO) reduce 218) ((T_ELSE) reduce 218) ((T_ELSEIF) reduce 218) ((T_EMPTY) reduce 218) ((T_ENUM) reduce 218) ((T_EVAL) reduce 218) ((T_EXIT) reduce 218) ((T_FILE) reduce 218) ((T_FINAL) reduce 218) ((T_FN) reduce 218) ((T_FOR) reduce 218) ((T_FOREACH) reduce 218) ((T_FUNCTION) reduce 218) ((T_FUNC_C) reduce 218) ((T_GLOBAL) reduce 218) ((T_GOTO) reduce 218) ((T_HALT_COMPILER) reduce 218) ((T_IF) reduce 218) ((T_INC) reduce 218) ((T_INCLUDE) reduce 218) ((T_INCLUDE_ONCE) reduce 218) ((T_INLINE_HTML) reduce 218) ((T_INTERFACE) reduce 218) ((T_INT_CAST) reduce 218) ((T_ISSET) reduce 218) ((T_LINE) reduce 218) ((T_LIST) reduce 218) ((T_LNUMBER) reduce 218) ((T_MATCH) reduce 218) ((T_METHOD_C) reduce 218) ((T_NAMESPACE) reduce 218) ((T_NAME_FULLY_QUALIFIED) reduce 218) ((T_NAME_QUALIFIED) reduce 218) ((T_NAME_RELATIVE) reduce 218) ((T_NEW) reduce 218) ((T_NS_C) reduce 218) ((T_OBJECT_CAST) reduce 218) ((T_PRINT) reduce 218) ((T_READONLY) reduce 218) ((T_REQUIRE) reduce 218) ((T_REQUIRE_ONCE) reduce 218) ((T_RETURN) reduce 218) ((T_START_HEREDOC) reduce 218) ((T_STATIC) reduce 218) ((T_STRING) reduce 218) ((T_STRING_CAST) reduce 218) ((T_SWITCH) reduce 218) ((T_THROW) reduce 218) ((T_TRAIT) reduce 218) ((T_TRAIT_C) reduce 218) ((T_TRY) reduce 218) ((T_UNSET) reduce 218) ((T_UNSET_CAST) reduce 218) ((T_USE) reduce 218) ((T_VARIABLE) reduce 218) ((T_WHILE) reduce 218) ((T_YIELD) reduce 218) ((T_YIELD_FROM) reduce 218) (("[") reduce 218) (("`") reduce 218) (("{") reduce 218) (("~") reduce 218)) 25890 ((("!") reduce 161) (("\"") reduce 161) (($) reduce 161) (("$") reduce 161) (("(") reduce 161) (("+") reduce 161) (("-") reduce 161) ((";") reduce 161) (("@") reduce 161) ((T_ABSTRACT) reduce 161) ((T_ARRAY) reduce 161) ((T_ARRAY_CAST) reduce 161) ((T_ATTRIBUTE) reduce 161) ((T_BOOL_CAST) reduce 161) ((T_BREAK) reduce 161) ((T_CLASS) reduce 161) ((T_CLASS_C) reduce 161) ((T_CLONE) reduce 161) ((T_CONST) reduce 161) ((T_CONSTANT_ENCAPSED_STRING) reduce 161) ((T_CONTINUE) reduce 161) ((T_DEC) reduce 161) ((T_DECLARE) reduce 161) ((T_DIR) reduce 161) ((T_DNUMBER) reduce 161) ((T_DO) reduce 161) ((T_DOUBLE_CAST) reduce 161) ((T_ECHO) reduce 161) ((T_ELSE) reduce 161) ((T_ELSEIF) reduce 161) ((T_EMPTY) reduce 161) ((T_ENUM) reduce 161) ((T_EVAL) reduce 161) ((T_EXIT) reduce 161) ((T_FILE) reduce 161) ((T_FINAL) reduce 161) ((T_FN) reduce 161) ((T_FOR) reduce 161) ((T_FOREACH) reduce 161) ((T_FUNCTION) reduce 161) ((T_FUNC_C) reduce 161) ((T_GLOBAL) reduce 161) ((T_GOTO) reduce 161) ((T_HALT_COMPILER) reduce 161) ((T_IF) reduce 161) ((T_INC) reduce 161) ((T_INCLUDE) reduce 161) ((T_INCLUDE_ONCE) reduce 161) ((T_INLINE_HTML) reduce 161) ((T_INTERFACE) reduce 161) ((T_INT_CAST) reduce 161) ((T_ISSET) reduce 161) ((T_LINE) reduce 161) ((T_LIST) reduce 161) ((T_LNUMBER) reduce 161) ((T_MATCH) reduce 161) ((T_METHOD_C) reduce 161) ((T_NAMESPACE) reduce 161) ((T_NAME_FULLY_QUALIFIED) reduce 161) ((T_NAME_QUALIFIED) reduce 161) ((T_NAME_RELATIVE) reduce 161) ((T_NEW) reduce 161) ((T_NS_C) reduce 161) ((T_OBJECT_CAST) reduce 161) ((T_PRINT) reduce 161) ((T_READONLY) reduce 161) ((T_REQUIRE) reduce 161) ((T_REQUIRE_ONCE) reduce 161) ((T_RETURN) reduce 161) ((T_START_HEREDOC) reduce 161) ((T_STATIC) reduce 161) ((T_STRING) reduce 161) ((T_STRING_CAST) reduce 161) ((T_SWITCH) reduce 161) ((T_THROW) reduce 161) ((T_TRAIT) reduce 161) ((T_TRAIT_C) reduce 161) ((T_TRY) reduce 161) ((T_UNSET) reduce 161) ((T_UNSET_CAST) reduce 161) ((T_USE) reduce 161) ((T_VARIABLE) reduce 161) ((T_WHILE) reduce 161) ((T_YIELD) reduce 161) ((T_YIELD_FROM) reduce 161) (("[") reduce 161) (("`") reduce 161) (("{") reduce 161) (("~") reduce 161)) 25899 ((("!") reduce 150) (("\"") reduce 150) (($) reduce 150) (("$") reduce 150) (("(") reduce 150) (("+") reduce 150) (("-") reduce 150) ((";") reduce 150) (("@") reduce 150) ((T_ABSTRACT) reduce 150) ((T_ARRAY) reduce 150) ((T_ARRAY_CAST) reduce 150) ((T_ATTRIBUTE) reduce 150) ((T_BOOL_CAST) reduce 150) ((T_BREAK) reduce 150) ((T_CLASS) reduce 150) ((T_CLASS_C) reduce 150) ((T_CLONE) reduce 150) ((T_CONST) reduce 150) ((T_CONSTANT_ENCAPSED_STRING) reduce 150) ((T_CONTINUE) reduce 150) ((T_DEC) reduce 150) ((T_DECLARE) reduce 150) ((T_DIR) reduce 150) ((T_DNUMBER) reduce 150) ((T_DO) reduce 150) ((T_DOUBLE_CAST) reduce 150) ((T_ECHO) reduce 150) ((T_ELSE) reduce 150) ((T_ELSEIF) reduce 150) ((T_EMPTY) reduce 150) ((T_ENUM) reduce 150) ((T_EVAL) reduce 150) ((T_EXIT) reduce 150) ((T_FILE) reduce 150) ((T_FINAL) reduce 150) ((T_FN) reduce 150) ((T_FOR) reduce 150) ((T_FOREACH) reduce 150) ((T_FUNCTION) reduce 150) ((T_FUNC_C) reduce 150) ((T_GLOBAL) reduce 150) ((T_GOTO) reduce 150) ((T_HALT_COMPILER) reduce 150) ((T_IF) reduce 150) ((T_INC) reduce 150) ((T_INCLUDE) reduce 150) ((T_INCLUDE_ONCE) reduce 150) ((T_INLINE_HTML) reduce 150) ((T_INTERFACE) reduce 150) ((T_INT_CAST) reduce 150) ((T_ISSET) reduce 150) ((T_LINE) reduce 150) ((T_LIST) reduce 150) ((T_LNUMBER) reduce 150) ((T_MATCH) reduce 150) ((T_METHOD_C) reduce 150) ((T_NAMESPACE) reduce 150) ((T_NAME_FULLY_QUALIFIED) reduce 150) ((T_NAME_QUALIFIED) reduce 150) ((T_NAME_RELATIVE) reduce 150) ((T_NEW) reduce 150) ((T_NS_C) reduce 150) ((T_OBJECT_CAST) reduce 150) ((T_PRINT) reduce 150) ((T_READONLY) reduce 150) ((T_REQUIRE) reduce 150) ((T_REQUIRE_ONCE) reduce 150) ((T_RETURN) reduce 150) ((T_START_HEREDOC) reduce 150) ((T_STATIC) reduce 150) ((T_STRING) reduce 150) ((T_STRING_CAST) reduce 150) ((T_SWITCH) reduce 150) ((T_THROW) reduce 150) ((T_TRAIT) reduce 150) ((T_TRAIT_C) reduce 150) ((T_TRY) reduce 150) ((T_UNSET) reduce 150) ((T_UNSET_CAST) reduce 150) ((T_USE) reduce 150) ((T_VARIABLE) reduce 150) ((T_WHILE) reduce 150) ((T_YIELD) reduce 150) ((T_YIELD_FROM) reduce 150) (("[") reduce 150) (("`") reduce 150) (("{") reduce 150) (("~") reduce 150)) 25900 ((("!") reduce 215) (("\"") reduce 215) (("$") reduce 215) (($) reduce 215) (("(") reduce 215) (("+") reduce 215) (("-") reduce 215) ((";") reduce 215) (("@") reduce 215) ((T_ABSTRACT) reduce 215) ((T_ARRAY) reduce 215) ((T_ARRAY_CAST) reduce 215) ((T_ATTRIBUTE) reduce 215) ((T_BOOL_CAST) reduce 215) ((T_BREAK) reduce 215) ((T_CLASS) reduce 215) ((T_CLASS_C) reduce 215) ((T_CLONE) reduce 215) ((T_CONST) reduce 215) ((T_CONSTANT_ENCAPSED_STRING) reduce 215) ((T_CONTINUE) reduce 215) ((T_DEC) reduce 215) ((T_DECLARE) reduce 215) ((T_DIR) reduce 215) ((T_DNUMBER) reduce 215) ((T_DO) reduce 215) ((T_DOUBLE_CAST) reduce 215) ((T_ECHO) reduce 215) ((T_ELSE) reduce 215) ((T_ELSEIF) reduce 215) ((T_EMPTY) reduce 215) ((T_ENUM) reduce 215) ((T_EVAL) reduce 215) ((T_EXIT) reduce 215) ((T_FILE) reduce 215) ((T_FINAL) reduce 215) ((T_FN) reduce 215) ((T_FOR) reduce 215) ((T_FOREACH) reduce 215) ((T_FUNCTION) reduce 215) ((T_FUNC_C) reduce 215) ((T_GLOBAL) reduce 215) ((T_GOTO) reduce 215) ((T_HALT_COMPILER) reduce 215) ((T_IF) reduce 215) ((T_INC) reduce 215) ((T_INCLUDE) reduce 215) ((T_INCLUDE_ONCE) reduce 215) ((T_INLINE_HTML) reduce 215) ((T_INTERFACE) reduce 215) ((T_INT_CAST) reduce 215) ((T_ISSET) reduce 215) ((T_LINE) reduce 215) ((T_LIST) reduce 215) ((T_LNUMBER) reduce 215) ((T_MATCH) reduce 215) ((T_METHOD_C) reduce 215) ((T_NAMESPACE) reduce 215) ((T_NAME_FULLY_QUALIFIED) reduce 215) ((T_NAME_QUALIFIED) reduce 215) ((T_NAME_RELATIVE) reduce 215) ((T_NEW) reduce 215) ((T_NS_C) reduce 215) ((T_OBJECT_CAST) reduce 215) ((T_PRINT) reduce 215) ((T_READONLY) reduce 215) ((T_REQUIRE) reduce 215) ((T_REQUIRE_ONCE) reduce 215) ((T_RETURN) reduce 215) ((T_START_HEREDOC) reduce 215) ((T_STATIC) reduce 215) ((T_STRING) reduce 215) ((T_STRING_CAST) reduce 215) ((T_SWITCH) reduce 215) ((T_THROW) reduce 215) ((T_TRAIT) reduce 215) ((T_TRAIT_C) reduce 215) ((T_TRY) reduce 215) ((T_UNSET) reduce 215) ((T_UNSET_CAST) reduce 215) ((T_USE) reduce 215) ((T_VARIABLE) reduce 215) ((T_WHILE) reduce 215) ((T_YIELD) reduce 215) ((T_YIELD_FROM) reduce 215) (("[") reduce 215) (("`") reduce 215) (("{") reduce 215) (("~") reduce 215)) 25903 ((("!") reduce 216) (("\"") reduce 216) (($) reduce 216) (("$") reduce 216) (("(") reduce 216) (("+") reduce 216) (("-") reduce 216) ((";") reduce 216) (("@") reduce 216) ((T_ABSTRACT) reduce 216) ((T_ARRAY) reduce 216) ((T_ARRAY_CAST) reduce 216) ((T_ATTRIBUTE) reduce 216) ((T_BOOL_CAST) reduce 216) ((T_BREAK) reduce 216) ((T_CLASS) reduce 216) ((T_CLASS_C) reduce 216) ((T_CLONE) reduce 216) ((T_CONST) reduce 216) ((T_CONSTANT_ENCAPSED_STRING) reduce 216) ((T_CONTINUE) reduce 216) ((T_DEC) reduce 216) ((T_DECLARE) reduce 216) ((T_DIR) reduce 216) ((T_DNUMBER) reduce 216) ((T_DO) reduce 216) ((T_DOUBLE_CAST) reduce 216) ((T_ECHO) reduce 216) ((T_ELSE) reduce 216) ((T_ELSEIF) reduce 216) ((T_EMPTY) reduce 216) ((T_ENUM) reduce 216) ((T_EVAL) reduce 216) ((T_EXIT) reduce 216) ((T_FILE) reduce 216) ((T_FINAL) reduce 216) ((T_FN) reduce 216) ((T_FOR) reduce 216) ((T_FOREACH) reduce 216) ((T_FUNCTION) reduce 216) ((T_FUNC_C) reduce 216) ((T_GLOBAL) reduce 216) ((T_GOTO) reduce 216) ((T_HALT_COMPILER) reduce 216) ((T_IF) reduce 216) ((T_INC) reduce 216) ((T_INCLUDE) reduce 216) ((T_INCLUDE_ONCE) reduce 216) ((T_INLINE_HTML) reduce 216) ((T_INTERFACE) reduce 216) ((T_INT_CAST) reduce 216) ((T_ISSET) reduce 216) ((T_LINE) reduce 216) ((T_LIST) reduce 216) ((T_LNUMBER) reduce 216) ((T_MATCH) reduce 216) ((T_METHOD_C) reduce 216) ((T_NAMESPACE) reduce 216) ((T_NAME_FULLY_QUALIFIED) reduce 216) ((T_NAME_QUALIFIED) reduce 216) ((T_NAME_RELATIVE) reduce 216) ((T_NEW) reduce 216) ((T_NS_C) reduce 216) ((T_OBJECT_CAST) reduce 216) ((T_PRINT) reduce 216) ((T_READONLY) reduce 216) ((T_REQUIRE) reduce 216) ((T_REQUIRE_ONCE) reduce 216) ((T_RETURN) reduce 216) ((T_START_HEREDOC) reduce 216) ((T_STATIC) reduce 216) ((T_STRING) reduce 216) ((T_STRING_CAST) reduce 216) ((T_SWITCH) reduce 216) ((T_THROW) reduce 216) ((T_TRAIT) reduce 216) ((T_TRAIT_C) reduce 216) ((T_TRY) reduce 216) ((T_UNSET) reduce 216) ((T_UNSET_CAST) reduce 216) ((T_USE) reduce 216) ((T_VARIABLE) reduce 216) ((T_WHILE) reduce 216) ((T_YIELD) reduce 216) ((T_YIELD_FROM) reduce 216) (("[") reduce 216) (("`") reduce 216) (("{") reduce 216) (("~") reduce 216)) 25905 ((("!") reduce 157) (("\"") reduce 157) (($) reduce 157) (("$") reduce 157) (("(") reduce 157) (("+") reduce 157) (("-") reduce 157) ((";") reduce 157) (("@") reduce 157) ((T_ABSTRACT) reduce 157) ((T_ARRAY) reduce 157) ((T_ARRAY_CAST) reduce 157) ((T_ATTRIBUTE) reduce 157) ((T_BOOL_CAST) reduce 157) ((T_BREAK) reduce 157) ((T_CLASS) reduce 157) ((T_CLASS_C) reduce 157) ((T_CLONE) reduce 157) ((T_CONST) reduce 157) ((T_CONSTANT_ENCAPSED_STRING) reduce 157) ((T_CONTINUE) reduce 157) ((T_DEC) reduce 157) ((T_DECLARE) reduce 157) ((T_DIR) reduce 157) ((T_DNUMBER) reduce 157) ((T_DO) reduce 157) ((T_DOUBLE_CAST) reduce 157) ((T_ECHO) reduce 157) ((T_ELSE) reduce 157) ((T_ELSEIF) reduce 157) ((T_EMPTY) reduce 157) ((T_ENUM) reduce 157) ((T_EVAL) reduce 157) ((T_EXIT) reduce 157) ((T_FILE) reduce 157) ((T_FINAL) reduce 157) ((T_FN) reduce 157) ((T_FOR) reduce 157) ((T_FOREACH) reduce 157) ((T_FUNCTION) reduce 157) ((T_FUNC_C) reduce 157) ((T_GLOBAL) reduce 157) ((T_GOTO) reduce 157) ((T_HALT_COMPILER) reduce 157) ((T_IF) reduce 157) ((T_INC) reduce 157) ((T_INCLUDE) reduce 157) ((T_INCLUDE_ONCE) reduce 157) ((T_INLINE_HTML) reduce 157) ((T_INTERFACE) reduce 157) ((T_INT_CAST) reduce 157) ((T_ISSET) reduce 157) ((T_LINE) reduce 157) ((T_LIST) reduce 157) ((T_LNUMBER) reduce 157) ((T_MATCH) reduce 157) ((T_METHOD_C) reduce 157) ((T_NAMESPACE) reduce 157) ((T_NAME_FULLY_QUALIFIED) reduce 157) ((T_NAME_QUALIFIED) reduce 157) ((T_NAME_RELATIVE) reduce 157) ((T_NEW) reduce 157) ((T_NS_C) reduce 157) ((T_OBJECT_CAST) reduce 157) ((T_PRINT) reduce 157) ((T_READONLY) reduce 157) ((T_REQUIRE) reduce 157) ((T_REQUIRE_ONCE) reduce 157) ((T_RETURN) reduce 157) ((T_START_HEREDOC) reduce 157) ((T_STATIC) reduce 157) ((T_STRING) reduce 157) ((T_STRING_CAST) reduce 157) ((T_SWITCH) reduce 157) ((T_THROW) reduce 157) ((T_TRAIT) reduce 157) ((T_TRAIT_C) reduce 157) ((T_TRY) reduce 157) ((T_UNSET) reduce 157) ((T_UNSET_CAST) reduce 157) ((T_USE) reduce 157) ((T_VARIABLE) reduce 157) ((T_WHILE) reduce 157) ((T_YIELD) reduce 157) ((T_YIELD_FROM) reduce 157) (("[") reduce 157) (("`") reduce 157) (("{") reduce 157) (("~") reduce 157)) 25911 ((("!") reduce 149) (("\"") reduce 149) (($) reduce 149) (("$") reduce 149) (("(") reduce 149) (("+") reduce 149) (("-") reduce 149) ((";") reduce 149) (("@") reduce 149) ((T_ABSTRACT) reduce 149) ((T_ARRAY) reduce 149) ((T_ARRAY_CAST) reduce 149) ((T_ATTRIBUTE) reduce 149) ((T_BOOL_CAST) reduce 149) ((T_BREAK) reduce 149) ((T_CLASS) reduce 149) ((T_CLASS_C) reduce 149) ((T_CLONE) reduce 149) ((T_CONST) reduce 149) ((T_CONSTANT_ENCAPSED_STRING) reduce 149) ((T_CONTINUE) reduce 149) ((T_DEC) reduce 149) ((T_DECLARE) reduce 149) ((T_DIR) reduce 149) ((T_DNUMBER) reduce 149) ((T_DO) reduce 149) ((T_DOUBLE_CAST) reduce 149) ((T_ECHO) reduce 149) ((T_ELSE) reduce 149) ((T_ELSEIF) reduce 149) ((T_EMPTY) reduce 149) ((T_ENUM) reduce 149) ((T_EVAL) reduce 149) ((T_EXIT) reduce 149) ((T_FILE) reduce 149) ((T_FINAL) reduce 149) ((T_FN) reduce 149) ((T_FOR) reduce 149) ((T_FOREACH) reduce 149) ((T_FUNCTION) reduce 149) ((T_FUNC_C) reduce 149) ((T_GLOBAL) reduce 149) ((T_GOTO) reduce 149) ((T_HALT_COMPILER) reduce 149) ((T_IF) reduce 149) ((T_INC) reduce 149) ((T_INCLUDE) reduce 149) ((T_INCLUDE_ONCE) reduce 149) ((T_INLINE_HTML) reduce 149) ((T_INTERFACE) reduce 149) ((T_INT_CAST) reduce 149) ((T_ISSET) reduce 149) ((T_LINE) reduce 149) ((T_LIST) reduce 149) ((T_LNUMBER) reduce 149) ((T_MATCH) reduce 149) ((T_METHOD_C) reduce 149) ((T_NAMESPACE) reduce 149) ((T_NAME_FULLY_QUALIFIED) reduce 149) ((T_NAME_QUALIFIED) reduce 149) ((T_NAME_RELATIVE) reduce 149) ((T_NEW) reduce 149) ((T_NS_C) reduce 149) ((T_OBJECT_CAST) reduce 149) ((T_PRINT) reduce 149) ((T_READONLY) reduce 149) ((T_REQUIRE) reduce 149) ((T_REQUIRE_ONCE) reduce 149) ((T_RETURN) reduce 149) ((T_START_HEREDOC) reduce 149) ((T_STATIC) reduce 149) ((T_STRING) reduce 149) ((T_STRING_CAST) reduce 149) ((T_SWITCH) reduce 149) ((T_THROW) reduce 149) ((T_TRAIT) reduce 149) ((T_TRAIT_C) reduce 149) ((T_TRY) reduce 149) ((T_UNSET) reduce 149) ((T_UNSET_CAST) reduce 149) ((T_USE) reduce 149) ((T_VARIABLE) reduce 149) ((T_WHILE) reduce 149) ((T_YIELD) reduce 149) ((T_YIELD_FROM) reduce 149) (("[") reduce 149) (("`") reduce 149) (("{") reduce 149) (("~") reduce 149)) 25916 ((("!") reduce 163) (("\"") reduce 163) (($) reduce 163) (("$") reduce 163) (("(") reduce 163) (("+") reduce 163) (("-") reduce 163) ((";") reduce 163) (("@") reduce 163) ((T_ABSTRACT) reduce 163) ((T_ARRAY) reduce 163) ((T_ARRAY_CAST) reduce 163) ((T_ATTRIBUTE) reduce 163) ((T_BOOL_CAST) reduce 163) ((T_BREAK) reduce 163) ((T_CLASS) reduce 163) ((T_CLASS_C) reduce 163) ((T_CLONE) reduce 163) ((T_CONST) reduce 163) ((T_CONSTANT_ENCAPSED_STRING) reduce 163) ((T_CONTINUE) reduce 163) ((T_DEC) reduce 163) ((T_DECLARE) reduce 163) ((T_DIR) reduce 163) ((T_DNUMBER) reduce 163) ((T_DO) reduce 163) ((T_DOUBLE_CAST) reduce 163) ((T_ECHO) reduce 163) ((T_ELSE) reduce 163) ((T_ELSEIF) reduce 163) ((T_EMPTY) reduce 163) ((T_ENUM) reduce 163) ((T_EVAL) reduce 163) ((T_EXIT) reduce 163) ((T_FILE) reduce 163) ((T_FINAL) reduce 163) ((T_FN) reduce 163) ((T_FOR) reduce 163) ((T_FOREACH) reduce 163) ((T_FUNCTION) reduce 163) ((T_FUNC_C) reduce 163) ((T_GLOBAL) reduce 163) ((T_GOTO) reduce 163) ((T_HALT_COMPILER) reduce 163) ((T_IF) reduce 163) ((T_INC) reduce 163) ((T_INCLUDE) reduce 163) ((T_INCLUDE_ONCE) reduce 163) ((T_INLINE_HTML) reduce 163) ((T_INTERFACE) reduce 163) ((T_INT_CAST) reduce 163) ((T_ISSET) reduce 163) ((T_LINE) reduce 163) ((T_LIST) reduce 163) ((T_LNUMBER) reduce 163) ((T_MATCH) reduce 163) ((T_METHOD_C) reduce 163) ((T_NAMESPACE) reduce 163) ((T_NAME_FULLY_QUALIFIED) reduce 163) ((T_NAME_QUALIFIED) reduce 163) ((T_NAME_RELATIVE) reduce 163) ((T_NEW) reduce 163) ((T_NS_C) reduce 163) ((T_OBJECT_CAST) reduce 163) ((T_PRINT) reduce 163) ((T_READONLY) reduce 163) ((T_REQUIRE) reduce 163) ((T_REQUIRE_ONCE) reduce 163) ((T_RETURN) reduce 163) ((T_START_HEREDOC) reduce 163) ((T_STATIC) reduce 163) ((T_STRING) reduce 163) ((T_STRING_CAST) reduce 163) ((T_SWITCH) reduce 163) ((T_THROW) reduce 163) ((T_TRAIT) reduce 163) ((T_TRAIT_C) reduce 163) ((T_TRY) reduce 163) ((T_UNSET) reduce 163) ((T_UNSET_CAST) reduce 163) ((T_USE) reduce 163) ((T_VARIABLE) reduce 163) ((T_WHILE) reduce 163) ((T_YIELD) reduce 163) ((T_YIELD_FROM) reduce 163) (("[") reduce 163) (("`") reduce 163) (("{") reduce 163) (("~") reduce 163)) 25917 ((("!") reduce 219) (("\"") reduce 219) (("$") reduce 219) (($) reduce 219) (("(") reduce 219) (("+") reduce 219) (("-") reduce 219) ((";") reduce 219) (("@") reduce 219) ((T_ABSTRACT) reduce 219) ((T_ARRAY) reduce 219) ((T_ARRAY_CAST) reduce 219) ((T_ATTRIBUTE) reduce 219) ((T_BOOL_CAST) reduce 219) ((T_BREAK) reduce 219) ((T_CLASS) reduce 219) ((T_CLASS_C) reduce 219) ((T_CLONE) reduce 219) ((T_CONST) reduce 219) ((T_CONSTANT_ENCAPSED_STRING) reduce 219) ((T_CONTINUE) reduce 219) ((T_DEC) reduce 219) ((T_DECLARE) reduce 219) ((T_DIR) reduce 219) ((T_DNUMBER) reduce 219) ((T_DO) reduce 219) ((T_DOUBLE_CAST) reduce 219) ((T_ECHO) reduce 219) ((T_ELSE) reduce 219) ((T_ELSEIF) reduce 219) ((T_EMPTY) reduce 219) ((T_ENUM) reduce 219) ((T_EVAL) reduce 219) ((T_EXIT) reduce 219) ((T_FILE) reduce 219) ((T_FINAL) reduce 219) ((T_FN) reduce 219) ((T_FOR) reduce 219) ((T_FOREACH) reduce 219) ((T_FUNCTION) reduce 219) ((T_FUNC_C) reduce 219) ((T_GLOBAL) reduce 219) ((T_GOTO) reduce 219) ((T_HALT_COMPILER) reduce 219) ((T_IF) reduce 219) ((T_INC) reduce 219) ((T_INCLUDE) reduce 219) ((T_INCLUDE_ONCE) reduce 219) ((T_INLINE_HTML) reduce 219) ((T_INTERFACE) reduce 219) ((T_INT_CAST) reduce 219) ((T_ISSET) reduce 219) ((T_LINE) reduce 219) ((T_LIST) reduce 219) ((T_LNUMBER) reduce 219) ((T_MATCH) reduce 219) ((T_METHOD_C) reduce 219) ((T_NAMESPACE) reduce 219) ((T_NAME_FULLY_QUALIFIED) reduce 219) ((T_NAME_QUALIFIED) reduce 219) ((T_NAME_RELATIVE) reduce 219) ((T_NEW) reduce 219) ((T_NS_C) reduce 219) ((T_OBJECT_CAST) reduce 219) ((T_PRINT) reduce 219) ((T_READONLY) reduce 219) ((T_REQUIRE) reduce 219) ((T_REQUIRE_ONCE) reduce 219) ((T_RETURN) reduce 219) ((T_START_HEREDOC) reduce 219) ((T_STATIC) reduce 219) ((T_STRING) reduce 219) ((T_STRING_CAST) reduce 219) ((T_SWITCH) reduce 219) ((T_THROW) reduce 219) ((T_TRAIT) reduce 219) ((T_TRAIT_C) reduce 219) ((T_TRY) reduce 219) ((T_UNSET) reduce 219) ((T_UNSET_CAST) reduce 219) ((T_USE) reduce 219) ((T_VARIABLE) reduce 219) ((T_WHILE) reduce 219) ((T_YIELD) reduce 219) ((T_YIELD_FROM) reduce 219) (("[") reduce 219) (("`") reduce 219) (("{") reduce 219) (("~") reduce 219)) 25920 ((("!") reduce 220) (("\"") reduce 220) (($) reduce 220) (("$") reduce 220) (("(") reduce 220) (("+") reduce 220) (("-") reduce 220) ((";") reduce 220) (("@") reduce 220) ((T_ABSTRACT) reduce 220) ((T_ARRAY) reduce 220) ((T_ARRAY_CAST) reduce 220) ((T_ATTRIBUTE) reduce 220) ((T_BOOL_CAST) reduce 220) ((T_BREAK) reduce 220) ((T_CLASS) reduce 220) ((T_CLASS_C) reduce 220) ((T_CLONE) reduce 220) ((T_CONST) reduce 220) ((T_CONSTANT_ENCAPSED_STRING) reduce 220) ((T_CONTINUE) reduce 220) ((T_DEC) reduce 220) ((T_DECLARE) reduce 220) ((T_DIR) reduce 220) ((T_DNUMBER) reduce 220) ((T_DO) reduce 220) ((T_DOUBLE_CAST) reduce 220) ((T_ECHO) reduce 220) ((T_ELSE) reduce 220) ((T_ELSEIF) reduce 220) ((T_EMPTY) reduce 220) ((T_ENUM) reduce 220) ((T_EVAL) reduce 220) ((T_EXIT) reduce 220) ((T_FILE) reduce 220) ((T_FINAL) reduce 220) ((T_FN) reduce 220) ((T_FOR) reduce 220) ((T_FOREACH) reduce 220) ((T_FUNCTION) reduce 220) ((T_FUNC_C) reduce 220) ((T_GLOBAL) reduce 220) ((T_GOTO) reduce 220) ((T_HALT_COMPILER) reduce 220) ((T_IF) reduce 220) ((T_INC) reduce 220) ((T_INCLUDE) reduce 220) ((T_INCLUDE_ONCE) reduce 220) ((T_INLINE_HTML) reduce 220) ((T_INTERFACE) reduce 220) ((T_INT_CAST) reduce 220) ((T_ISSET) reduce 220) ((T_LINE) reduce 220) ((T_LIST) reduce 220) ((T_LNUMBER) reduce 220) ((T_MATCH) reduce 220) ((T_METHOD_C) reduce 220) ((T_NAMESPACE) reduce 220) ((T_NAME_FULLY_QUALIFIED) reduce 220) ((T_NAME_QUALIFIED) reduce 220) ((T_NAME_RELATIVE) reduce 220) ((T_NEW) reduce 220) ((T_NS_C) reduce 220) ((T_OBJECT_CAST) reduce 220) ((T_PRINT) reduce 220) ((T_READONLY) reduce 220) ((T_REQUIRE) reduce 220) ((T_REQUIRE_ONCE) reduce 220) ((T_RETURN) reduce 220) ((T_START_HEREDOC) reduce 220) ((T_STATIC) reduce 220) ((T_STRING) reduce 220) ((T_STRING_CAST) reduce 220) ((T_SWITCH) reduce 220) ((T_THROW) reduce 220) ((T_TRAIT) reduce 220) ((T_TRAIT_C) reduce 220) ((T_TRY) reduce 220) ((T_UNSET) reduce 220) ((T_UNSET_CAST) reduce 220) ((T_USE) reduce 220) ((T_VARIABLE) reduce 220) ((T_WHILE) reduce 220) ((T_YIELD) reduce 220) ((T_YIELD_FROM) reduce 220) (("[") reduce 220) (("`") reduce 220) (("{") reduce 220) (("~") reduce 220)) 25922 ((("!") reduce 153) (("\"") reduce 153) (($) reduce 153) (("$") reduce 153) (("(") reduce 153) (("+") reduce 153) (("-") reduce 153) ((";") reduce 153) (("@") reduce 153) ((T_ABSTRACT) reduce 153) ((T_ARRAY) reduce 153) ((T_ARRAY_CAST) reduce 153) ((T_ATTRIBUTE) reduce 153) ((T_BOOL_CAST) reduce 153) ((T_BREAK) reduce 153) ((T_CLASS) reduce 153) ((T_CLASS_C) reduce 153) ((T_CLONE) reduce 153) ((T_CONST) reduce 153) ((T_CONSTANT_ENCAPSED_STRING) reduce 153) ((T_CONTINUE) reduce 153) ((T_DEC) reduce 153) ((T_DECLARE) reduce 153) ((T_DIR) reduce 153) ((T_DNUMBER) reduce 153) ((T_DO) reduce 153) ((T_DOUBLE_CAST) reduce 153) ((T_ECHO) reduce 153) ((T_ELSE) reduce 153) ((T_ELSEIF) reduce 153) ((T_EMPTY) reduce 153) ((T_ENUM) reduce 153) ((T_EVAL) reduce 153) ((T_EXIT) reduce 153) ((T_FILE) reduce 153) ((T_FINAL) reduce 153) ((T_FN) reduce 153) ((T_FOR) reduce 153) ((T_FOREACH) reduce 153) ((T_FUNCTION) reduce 153) ((T_FUNC_C) reduce 153) ((T_GLOBAL) reduce 153) ((T_GOTO) reduce 153) ((T_HALT_COMPILER) reduce 153) ((T_IF) reduce 153) ((T_INC) reduce 153) ((T_INCLUDE) reduce 153) ((T_INCLUDE_ONCE) reduce 153) ((T_INLINE_HTML) reduce 153) ((T_INTERFACE) reduce 153) ((T_INT_CAST) reduce 153) ((T_ISSET) reduce 153) ((T_LINE) reduce 153) ((T_LIST) reduce 153) ((T_LNUMBER) reduce 153) ((T_MATCH) reduce 153) ((T_METHOD_C) reduce 153) ((T_NAMESPACE) reduce 153) ((T_NAME_FULLY_QUALIFIED) reduce 153) ((T_NAME_QUALIFIED) reduce 153) ((T_NAME_RELATIVE) reduce 153) ((T_NEW) reduce 153) ((T_NS_C) reduce 153) ((T_OBJECT_CAST) reduce 153) ((T_PRINT) reduce 153) ((T_READONLY) reduce 153) ((T_REQUIRE) reduce 153) ((T_REQUIRE_ONCE) reduce 153) ((T_RETURN) reduce 153) ((T_START_HEREDOC) reduce 153) ((T_STATIC) reduce 153) ((T_STRING) reduce 153) ((T_STRING_CAST) reduce 153) ((T_SWITCH) reduce 153) ((T_THROW) reduce 153) ((T_TRAIT) reduce 153) ((T_TRAIT_C) reduce 153) ((T_TRY) reduce 153) ((T_UNSET) reduce 153) ((T_UNSET_CAST) reduce 153) ((T_USE) reduce 153) ((T_VARIABLE) reduce 153) ((T_WHILE) reduce 153) ((T_YIELD) reduce 153) ((T_YIELD_FROM) reduce 153) (("[") reduce 153) (("`") reduce 153) (("{") reduce 153) (("~") reduce 153)) 25924 ((("!") reduce 152) (("\"") reduce 152) (($) reduce 152) (("$") reduce 152) (("(") reduce 152) (("+") reduce 152) (("-") reduce 152) ((";") reduce 152) (("@") reduce 152) ((T_ABSTRACT) reduce 152) ((T_ARRAY) reduce 152) ((T_ARRAY_CAST) reduce 152) ((T_ATTRIBUTE) reduce 152) ((T_BOOL_CAST) reduce 152) ((T_BREAK) reduce 152) ((T_CLASS) reduce 152) ((T_CLASS_C) reduce 152) ((T_CLONE) reduce 152) ((T_CONST) reduce 152) ((T_CONSTANT_ENCAPSED_STRING) reduce 152) ((T_CONTINUE) reduce 152) ((T_DEC) reduce 152) ((T_DECLARE) reduce 152) ((T_DIR) reduce 152) ((T_DNUMBER) reduce 152) ((T_DO) reduce 152) ((T_DOUBLE_CAST) reduce 152) ((T_ECHO) reduce 152) ((T_ELSE) reduce 152) ((T_ELSEIF) reduce 152) ((T_EMPTY) reduce 152) ((T_ENUM) reduce 152) ((T_EVAL) reduce 152) ((T_EXIT) reduce 152) ((T_FILE) reduce 152) ((T_FINAL) reduce 152) ((T_FN) reduce 152) ((T_FOR) reduce 152) ((T_FOREACH) reduce 152) ((T_FUNCTION) reduce 152) ((T_FUNC_C) reduce 152) ((T_GLOBAL) reduce 152) ((T_GOTO) reduce 152) ((T_HALT_COMPILER) reduce 152) ((T_IF) reduce 152) ((T_INC) reduce 152) ((T_INCLUDE) reduce 152) ((T_INCLUDE_ONCE) reduce 152) ((T_INLINE_HTML) reduce 152) ((T_INTERFACE) reduce 152) ((T_INT_CAST) reduce 152) ((T_ISSET) reduce 152) ((T_LINE) reduce 152) ((T_LIST) reduce 152) ((T_LNUMBER) reduce 152) ((T_MATCH) reduce 152) ((T_METHOD_C) reduce 152) ((T_NAMESPACE) reduce 152) ((T_NAME_FULLY_QUALIFIED) reduce 152) ((T_NAME_QUALIFIED) reduce 152) ((T_NAME_RELATIVE) reduce 152) ((T_NEW) reduce 152) ((T_NS_C) reduce 152) ((T_OBJECT_CAST) reduce 152) ((T_PRINT) reduce 152) ((T_READONLY) reduce 152) ((T_REQUIRE) reduce 152) ((T_REQUIRE_ONCE) reduce 152) ((T_RETURN) reduce 152) ((T_START_HEREDOC) reduce 152) ((T_STATIC) reduce 152) ((T_STRING) reduce 152) ((T_STRING_CAST) reduce 152) ((T_SWITCH) reduce 152) ((T_THROW) reduce 152) ((T_TRAIT) reduce 152) ((T_TRAIT_C) reduce 152) ((T_TRY) reduce 152) ((T_UNSET) reduce 152) ((T_UNSET_CAST) reduce 152) ((T_USE) reduce 152) ((T_VARIABLE) reduce 152) ((T_WHILE) reduce 152) ((T_YIELD) reduce 152) ((T_YIELD_FROM) reduce 152) (("[") reduce 152) (("`") reduce 152) (("{") reduce 152) (("~") reduce 152)) 25925 ((("!") reduce 244) (("\"") reduce 244) (("$") reduce 244) (($) reduce 244) (("(") reduce 244) (("+") reduce 244) (("-") reduce 244) ((";") reduce 244) (("@") reduce 244) ((T_ABSTRACT) reduce 244) ((T_ARRAY) reduce 244) ((T_ARRAY_CAST) reduce 244) ((T_ATTRIBUTE) reduce 244) ((T_BOOL_CAST) reduce 244) ((T_BREAK) reduce 244) ((T_CLASS) reduce 244) ((T_CLASS_C) reduce 244) ((T_CLONE) reduce 244) ((T_CONST) reduce 244) ((T_CONSTANT_ENCAPSED_STRING) reduce 244) ((T_CONTINUE) reduce 244) ((T_DEC) reduce 244) ((T_DECLARE) reduce 244) ((T_DIR) reduce 244) ((T_DNUMBER) reduce 244) ((T_DO) reduce 244) ((T_DOUBLE_CAST) reduce 244) ((T_ECHO) reduce 244) ((T_EMPTY) reduce 244) ((T_ENUM) reduce 244) ((T_EVAL) reduce 244) ((T_EXIT) reduce 244) ((T_FILE) reduce 244) ((T_FINAL) reduce 244) ((T_FN) reduce 244) ((T_FOR) reduce 244) ((T_FOREACH) reduce 244) ((T_FUNCTION) reduce 244) ((T_FUNC_C) reduce 244) ((T_GLOBAL) reduce 244) ((T_GOTO) reduce 244) ((T_HALT_COMPILER) reduce 244) ((T_IF) reduce 244) ((T_INC) reduce 244) ((T_INCLUDE) reduce 244) ((T_INCLUDE_ONCE) reduce 244) ((T_INLINE_HTML) reduce 244) ((T_INTERFACE) reduce 244) ((T_INT_CAST) reduce 244) ((T_ISSET) reduce 244) ((T_LINE) reduce 244) ((T_LIST) reduce 244) ((T_LNUMBER) reduce 244) ((T_MATCH) reduce 244) ((T_METHOD_C) reduce 244) ((T_NAMESPACE) reduce 244) ((T_NAME_FULLY_QUALIFIED) reduce 244) ((T_NAME_QUALIFIED) reduce 244) ((T_NAME_RELATIVE) reduce 244) ((T_NEW) reduce 244) ((T_NS_C) reduce 244) ((T_OBJECT_CAST) reduce 244) ((T_PRINT) reduce 244) ((T_READONLY) reduce 244) ((T_REQUIRE) reduce 244) ((T_REQUIRE_ONCE) reduce 244) ((T_RETURN) reduce 244) ((T_START_HEREDOC) reduce 244) ((T_STATIC) reduce 244) ((T_STRING) reduce 244) ((T_STRING_CAST) reduce 244) ((T_SWITCH) reduce 244) ((T_THROW) reduce 244) ((T_TRAIT) reduce 244) ((T_TRAIT_C) reduce 244) ((T_TRY) reduce 244) ((T_UNSET) reduce 244) ((T_UNSET_CAST) reduce 244) ((T_USE) reduce 244) ((T_VARIABLE) reduce 244) ((T_WHILE) reduce 244) ((T_YIELD) reduce 244) ((T_YIELD_FROM) reduce 244) (("[") reduce 244) (("`") reduce 244) (("{") reduce 244) (("~") reduce 244)) 25936 ((("!") reduce 455) (("\"") reduce 455) (("$") reduce 455) (($) reduce 455) (("(") reduce 455) (("+") reduce 455) (("-") reduce 455) ((";") reduce 455) (("@") reduce 455) ((T_ABSTRACT) reduce 455) ((T_ARRAY) reduce 455) ((T_ARRAY_CAST) reduce 455) ((T_ATTRIBUTE) reduce 455) ((T_BOOL_CAST) reduce 455) ((T_BREAK) reduce 455) ((T_CLASS) reduce 455) ((T_CLASS_C) reduce 455) ((T_CLONE) reduce 455) ((T_CONST) reduce 455) ((T_CONSTANT_ENCAPSED_STRING) reduce 455) ((T_CONTINUE) reduce 455) ((T_DEC) reduce 455) ((T_DECLARE) reduce 455) ((T_DIR) reduce 455) ((T_DNUMBER) reduce 455) ((T_DO) reduce 455) ((T_DOUBLE_CAST) reduce 455) ((T_ECHO) reduce 455) ((T_EMPTY) reduce 455) ((T_ENUM) reduce 455) ((T_EVAL) reduce 455) ((T_EXIT) reduce 455) ((T_FILE) reduce 455) ((T_FINAL) reduce 455) ((T_FN) reduce 455) ((T_FOR) reduce 455) ((T_FOREACH) reduce 455) ((T_FUNCTION) reduce 455) ((T_FUNC_C) reduce 455) ((T_GLOBAL) reduce 455) ((T_GOTO) reduce 455) ((T_HALT_COMPILER) reduce 455) ((T_IF) reduce 455) ((T_INC) reduce 455) ((T_INCLUDE) reduce 455) ((T_INCLUDE_ONCE) reduce 455) ((T_INLINE_HTML) reduce 455) ((T_INTERFACE) reduce 455) ((T_INT_CAST) reduce 455) ((T_ISSET) reduce 455) ((T_LINE) reduce 455) ((T_LIST) reduce 455) ((T_LNUMBER) reduce 455) ((T_MATCH) reduce 455) ((T_METHOD_C) reduce 455) ((T_NAMESPACE) reduce 455) ((T_NAME_FULLY_QUALIFIED) reduce 455) ((T_NAME_QUALIFIED) reduce 455) ((T_NAME_RELATIVE) reduce 455) ((T_NEW) reduce 455) ((T_NS_C) reduce 455) ((T_OBJECT_CAST) reduce 455) ((T_PRINT) reduce 455) ((T_READONLY) reduce 455) ((T_REQUIRE) reduce 455) ((T_REQUIRE_ONCE) reduce 455) ((T_RETURN) reduce 455) ((T_START_HEREDOC) reduce 455) ((T_STATIC) reduce 455) ((T_STRING) reduce 455) ((T_STRING_CAST) reduce 455) ((T_SWITCH) reduce 455) ((T_THROW) reduce 455) ((T_TRAIT) reduce 455) ((T_TRAIT_C) reduce 455) ((T_TRY) reduce 455) ((T_UNSET) reduce 455) ((T_UNSET_CAST) reduce 455) ((T_USE) reduce 455) ((T_VARIABLE) reduce 455) ((T_WHILE) reduce 455) ((T_YIELD) reduce 455) ((T_YIELD_FROM) reduce 455) (("[") reduce 455) (("`") reduce 455) (("{") reduce 455) (("~") reduce 455)) 25937 ((("!") reduce 181) (("\"") reduce 181) (("$") reduce 181) (($) reduce 181) (("(") reduce 181) (("+") reduce 181) (("-") reduce 181) ((";") reduce 181) (("@") reduce 181) ((T_ABSTRACT) reduce 181) ((T_ARRAY) reduce 181) ((T_ARRAY_CAST) reduce 181) ((T_ATTRIBUTE) reduce 181) ((T_BOOL_CAST) reduce 181) ((T_BREAK) reduce 181) ((T_CLASS) reduce 181) ((T_CLASS_C) reduce 181) ((T_CLONE) reduce 181) ((T_CONST) reduce 181) ((T_CONSTANT_ENCAPSED_STRING) reduce 181) ((T_CONTINUE) reduce 181) ((T_DEC) reduce 181) ((T_DECLARE) reduce 181) ((T_DIR) reduce 181) ((T_DNUMBER) reduce 181) ((T_DO) reduce 181) ((T_DOUBLE_CAST) reduce 181) ((T_ECHO) reduce 181) ((T_EMPTY) reduce 181) ((T_ENUM) reduce 181) ((T_EVAL) reduce 181) ((T_EXIT) reduce 181) ((T_FILE) reduce 181) ((T_FINAL) reduce 181) ((T_FN) reduce 181) ((T_FOR) reduce 181) ((T_FOREACH) reduce 181) ((T_FUNCTION) reduce 181) ((T_FUNC_C) reduce 181) ((T_GLOBAL) reduce 181) ((T_GOTO) reduce 181) ((T_HALT_COMPILER) reduce 181) ((T_IF) reduce 181) ((T_INC) reduce 181) ((T_INCLUDE) reduce 181) ((T_INCLUDE_ONCE) reduce 181) ((T_INLINE_HTML) reduce 181) ((T_INTERFACE) reduce 181) ((T_INT_CAST) reduce 181) ((T_ISSET) reduce 181) ((T_LINE) reduce 181) ((T_LIST) reduce 181) ((T_LNUMBER) reduce 181) ((T_MATCH) reduce 181) ((T_METHOD_C) reduce 181) ((T_NAMESPACE) reduce 181) ((T_NAME_FULLY_QUALIFIED) reduce 181) ((T_NAME_QUALIFIED) reduce 181) ((T_NAME_RELATIVE) reduce 181) ((T_NEW) reduce 181) ((T_NS_C) reduce 181) ((T_OBJECT_CAST) reduce 181) ((T_PRINT) reduce 181) ((T_READONLY) reduce 181) ((T_REQUIRE) reduce 181) ((T_REQUIRE_ONCE) reduce 181) ((T_RETURN) reduce 181) ((T_START_HEREDOC) reduce 181) ((T_STATIC) reduce 181) ((T_STRING) reduce 181) ((T_STRING_CAST) reduce 181) ((T_SWITCH) reduce 181) ((T_THROW) reduce 181) ((T_TRAIT) reduce 181) ((T_TRAIT_C) reduce 181) ((T_TRY) reduce 181) ((T_UNSET) reduce 181) ((T_UNSET_CAST) reduce 181) ((T_USE) reduce 181) ((T_VARIABLE) reduce 181) ((T_WHILE) reduce 181) ((T_YIELD) reduce 181) ((T_YIELD_FROM) reduce 181) (("[") reduce 181) (("`") reduce 181) (("{") reduce 181) (("~") reduce 181)) 26009 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 455) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26327 ((("%") reduce 451) (("*") reduce 451) (("+") reduce 451) (("-") reduce 451) ((".") reduce 451) (("/") reduce 451) ((";") reduce 451) (("<") reduce 451) ((">") reduce 451) (("?") reduce 451) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_BOOLEAN_AND) reduce 451) ((T_BOOLEAN_OR) reduce 451) ((T_COALESCE) reduce 451) ((T_INSTANCEOF) reduce 451) ((T_IS_EQUAL) reduce 451) ((T_IS_GREATER_OR_EQUAL) reduce 451) ((T_IS_IDENTICAL) reduce 451) ((T_IS_NOT_EQUAL) reduce 451) ((T_IS_NOT_IDENTICAL) reduce 451) ((T_IS_SMALLER_OR_EQUAL) reduce 451) ((T_LOGICAL_AND) reduce 451) ((T_LOGICAL_OR) reduce 451) ((T_LOGICAL_XOR) reduce 451) ((T_POW) reduce 451) ((T_SL) reduce 451) ((T_SPACESHIP) reduce 451) ((T_SR) reduce 451) (("^") reduce 451) (("|") reduce 451)) 26330 ((("%") reduce 503) (("(") reduce 541) (("*") reduce 503) (("+") reduce 503) (("-") reduce 503) ((".") reduce 503) (("/") reduce 503) ((";") reduce 503) (("<") reduce 503) ((">") reduce 503) (("?") reduce 503) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_BOOLEAN_AND) reduce 503) ((T_BOOLEAN_OR) reduce 503) ((T_COALESCE) reduce 503) ((T_INSTANCEOF) reduce 503) ((T_IS_EQUAL) reduce 503) ((T_IS_GREATER_OR_EQUAL) reduce 503) ((T_IS_IDENTICAL) reduce 503) ((T_IS_NOT_EQUAL) reduce 503) ((T_IS_NOT_IDENTICAL) reduce 503) ((T_IS_SMALLER_OR_EQUAL) reduce 503) ((T_LOGICAL_AND) reduce 503) ((T_LOGICAL_OR) reduce 503) ((T_LOGICAL_XOR) reduce 503) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 503) ((T_OBJECT_OPERATOR) reduce 503) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 503) ((T_POW) reduce 503) ((T_SL) reduce 503) ((T_SPACESHIP) reduce 503) ((T_SR) reduce 503) (("[") reduce 503) (("^") reduce 503) (("{") reduce 503) (("|") reduce 503)) 26332 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) ((";") reduce 532) (("<") reduce 532) (("=") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AND_EQUAL) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_COALESCE_EQUAL) reduce 532) ((T_CONCAT_EQUAL) reduce 532) ((T_DEC) reduce 532) ((T_DIV_EQUAL) reduce 532) ((T_INC) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_MINUS_EQUAL) reduce 532) ((T_MOD_EQUAL) reduce 532) ((T_MUL_EQUAL) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_OR_EQUAL) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_PLUS_EQUAL) reduce 532) ((T_POW) reduce 532) ((T_POW_EQUAL) reduce 532) ((T_SL) reduce 532) ((T_SL_EQUAL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) ((T_SR_EQUAL) reduce 532) ((T_XOR_EQUAL) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 26335 ((("%") reduce 505) (("(") reduce 542) (("*") reduce 505) (("+") reduce 505) (("-") reduce 505) ((".") reduce 505) (("/") reduce 505) ((";") reduce 505) (("<") reduce 505) ((">") reduce 505) (("?") reduce 505) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_BOOLEAN_AND) reduce 505) ((T_BOOLEAN_OR) reduce 505) ((T_COALESCE) reduce 505) ((T_INSTANCEOF) reduce 505) ((T_IS_EQUAL) reduce 505) ((T_IS_GREATER_OR_EQUAL) reduce 505) ((T_IS_IDENTICAL) reduce 505) ((T_IS_NOT_EQUAL) reduce 505) ((T_IS_NOT_IDENTICAL) reduce 505) ((T_IS_SMALLER_OR_EQUAL) reduce 505) ((T_LOGICAL_AND) reduce 505) ((T_LOGICAL_OR) reduce 505) ((T_LOGICAL_XOR) reduce 505) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 505) ((T_OBJECT_OPERATOR) reduce 505) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 505) ((T_POW) reduce 505) ((T_SL) reduce 505) ((T_SPACESHIP) reduce 505) ((T_SR) reduce 505) (("[") reduce 505) (("^") reduce 505) (("{") reduce 505) (("|") reduce 505)) 26336 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) ((";") reduce 467) (("<") reduce 467) (("=") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AND_EQUAL) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_COALESCE_EQUAL) reduce 467) ((T_CONCAT_EQUAL) reduce 467) ((T_DEC) reduce 467) ((T_DIV_EQUAL) reduce 467) ((T_INC) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_MINUS_EQUAL) reduce 467) ((T_MOD_EQUAL) reduce 467) ((T_MUL_EQUAL) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_OR_EQUAL) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_PLUS_EQUAL) reduce 467) ((T_POW) reduce 467) ((T_POW_EQUAL) reduce 467) ((T_SL) reduce 467) ((T_SL_EQUAL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) ((T_SR_EQUAL) reduce 467) ((T_XOR_EQUAL) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 26337 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) ((";") reduce 469) (("<") reduce 469) (("=") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AND_EQUAL) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_COALESCE_EQUAL) reduce 469) ((T_CONCAT_EQUAL) reduce 469) ((T_DEC) reduce 469) ((T_DIV_EQUAL) reduce 469) ((T_INC) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_MINUS_EQUAL) reduce 469) ((T_MOD_EQUAL) reduce 469) ((T_MUL_EQUAL) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_OR_EQUAL) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_PLUS_EQUAL) reduce 469) ((T_POW) reduce 469) ((T_POW_EQUAL) reduce 469) ((T_SL) reduce 469) ((T_SL_EQUAL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) ((T_SR_EQUAL) reduce 469) ((T_XOR_EQUAL) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 26346 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) ((";") reduce 521) (("<") reduce 521) (("=") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AND_EQUAL) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_COALESCE_EQUAL) reduce 521) ((T_CONCAT_EQUAL) reduce 521) ((T_DEC) reduce 521) ((T_DIV_EQUAL) reduce 521) ((T_INC) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_MINUS_EQUAL) reduce 521) ((T_MOD_EQUAL) reduce 521) ((T_MUL_EQUAL) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_OR_EQUAL) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_PLUS_EQUAL) reduce 521) ((T_POW) reduce 521) ((T_POW_EQUAL) reduce 521) ((T_SL) reduce 521) ((T_SL_EQUAL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) ((T_SR_EQUAL) reduce 521) ((T_XOR_EQUAL) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 26348 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) ((";") reduce 520) (("<") reduce 520) (("=") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AND_EQUAL) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_COALESCE_EQUAL) reduce 520) ((T_CONCAT_EQUAL) reduce 520) ((T_DEC) reduce 520) ((T_DIV_EQUAL) reduce 520) ((T_INC) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_MINUS_EQUAL) reduce 520) ((T_MOD_EQUAL) reduce 520) ((T_MUL_EQUAL) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_OR_EQUAL) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_PLUS_EQUAL) reduce 520) ((T_POW) reduce 520) ((T_POW_EQUAL) reduce 520) ((T_SL) reduce 520) ((T_SL_EQUAL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) ((T_SR_EQUAL) reduce 520) ((T_XOR_EQUAL) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 26349 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) ((";") reduce 544) (("<") reduce 544) (("=") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AND_EQUAL) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_COALESCE_EQUAL) reduce 544) ((T_CONCAT_EQUAL) reduce 544) ((T_DEC) reduce 544) ((T_DIV_EQUAL) reduce 544) ((T_INC) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_MINUS_EQUAL) reduce 544) ((T_MOD_EQUAL) reduce 544) ((T_MUL_EQUAL) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_OR_EQUAL) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_PLUS_EQUAL) reduce 544) ((T_POW) reduce 544) ((T_POW_EQUAL) reduce 544) ((T_SL) reduce 544) ((T_SL_EQUAL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) ((T_SR_EQUAL) reduce 544) ((T_XOR_EQUAL) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 26350 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) ((";") reduce 527) (("<") reduce 527) (("=") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AND_EQUAL) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_COALESCE_EQUAL) reduce 527) ((T_CONCAT_EQUAL) reduce 527) ((T_DEC) reduce 527) ((T_DIV_EQUAL) reduce 527) ((T_INC) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_MINUS_EQUAL) reduce 527) ((T_MOD_EQUAL) reduce 527) ((T_MUL_EQUAL) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_OR_EQUAL) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_PLUS_EQUAL) reduce 527) ((T_POW) reduce 527) ((T_POW_EQUAL) reduce 527) ((T_SL) reduce 527) ((T_SL_EQUAL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) ((T_SR_EQUAL) reduce 527) ((T_XOR_EQUAL) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 26351 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) ((";") reduce 546) (("<") reduce 546) (("=") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AND_EQUAL) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_COALESCE_EQUAL) reduce 546) ((T_CONCAT_EQUAL) reduce 546) ((T_DEC) reduce 546) ((T_DIV_EQUAL) reduce 546) ((T_INC) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_MINUS_EQUAL) reduce 546) ((T_MOD_EQUAL) reduce 546) ((T_MUL_EQUAL) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_OR_EQUAL) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_PLUS_EQUAL) reduce 546) ((T_POW) reduce 546) ((T_POW_EQUAL) reduce 546) ((T_SL) reduce 546) ((T_SL_EQUAL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) ((T_SR_EQUAL) reduce 546) ((T_XOR_EQUAL) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 26354 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) ((";") reduce 545) (("<") reduce 545) (("=") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AND_EQUAL) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_COALESCE_EQUAL) reduce 545) ((T_CONCAT_EQUAL) reduce 545) ((T_DEC) reduce 545) ((T_DIV_EQUAL) reduce 545) ((T_INC) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_MINUS_EQUAL) reduce 545) ((T_MOD_EQUAL) reduce 545) ((T_MUL_EQUAL) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_OR_EQUAL) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_PLUS_EQUAL) reduce 545) ((T_POW) reduce 545) ((T_POW_EQUAL) reduce 545) ((T_SL) reduce 545) ((T_SL_EQUAL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) ((T_SR_EQUAL) reduce 545) ((T_XOR_EQUAL) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 26355 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) ((";") reduce 522) (("<") reduce 522) (("=") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AND_EQUAL) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_COALESCE_EQUAL) reduce 522) ((T_CONCAT_EQUAL) reduce 522) ((T_DEC) reduce 522) ((T_DIV_EQUAL) reduce 522) ((T_INC) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_MINUS_EQUAL) reduce 522) ((T_MOD_EQUAL) reduce 522) ((T_MUL_EQUAL) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_OR_EQUAL) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_PLUS_EQUAL) reduce 522) ((T_POW) reduce 522) ((T_POW_EQUAL) reduce 522) ((T_SL) reduce 522) ((T_SL_EQUAL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) ((T_SR_EQUAL) reduce 522) ((T_XOR_EQUAL) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 26356 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) ((";") reduce 528) (("<") reduce 528) (("=") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AND_EQUAL) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_COALESCE_EQUAL) reduce 528) ((T_CONCAT_EQUAL) reduce 528) ((T_DEC) reduce 528) ((T_DIV_EQUAL) reduce 528) ((T_INC) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_MINUS_EQUAL) reduce 528) ((T_MOD_EQUAL) reduce 528) ((T_MUL_EQUAL) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_OR_EQUAL) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_PLUS_EQUAL) reduce 528) ((T_POW) reduce 528) ((T_POW_EQUAL) reduce 528) ((T_SL) reduce 528) ((T_SL_EQUAL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) ((T_SR_EQUAL) reduce 528) ((T_XOR_EQUAL) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 26357 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) ((";") reduce 523) (("<") reduce 523) (("=") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AND_EQUAL) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_COALESCE_EQUAL) reduce 523) ((T_CONCAT_EQUAL) reduce 523) ((T_DEC) reduce 523) ((T_DIV_EQUAL) reduce 523) ((T_INC) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_MINUS_EQUAL) reduce 523) ((T_MOD_EQUAL) reduce 523) ((T_MUL_EQUAL) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_OR_EQUAL) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_PLUS_EQUAL) reduce 523) ((T_POW) reduce 523) ((T_POW_EQUAL) reduce 523) ((T_SL) reduce 523) ((T_SL_EQUAL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) ((T_SR_EQUAL) reduce 523) ((T_XOR_EQUAL) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 26359 ((("%") reduce 438) (("*") reduce 438) (("+") reduce 438) (("-") reduce 438) ((".") reduce 438) (("/") reduce 438) ((";") reduce 438) (("<") reduce 438) ((">") reduce 438) (("?") reduce 438) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_BOOLEAN_AND) reduce 438) ((T_BOOLEAN_OR) reduce 438) ((T_COALESCE) reduce 438) ((T_INSTANCEOF) reduce 438) ((T_IS_EQUAL) reduce 438) ((T_IS_GREATER_OR_EQUAL) reduce 438) ((T_IS_IDENTICAL) reduce 438) ((T_IS_NOT_EQUAL) reduce 438) ((T_IS_NOT_IDENTICAL) reduce 438) ((T_IS_SMALLER_OR_EQUAL) reduce 438) ((T_LOGICAL_AND) reduce 438) ((T_LOGICAL_OR) reduce 438) ((T_LOGICAL_XOR) reduce 438) ((T_POW) reduce 438) ((T_SL) reduce 438) ((T_SPACESHIP) reduce 438) ((T_SR) reduce 438) (("^") reduce 438) (("|") reduce 438)) 26361 ((("%") reduce 483) (("(") reduce 483) (("*") reduce 483) (("+") reduce 483) (("-") reduce 483) ((".") reduce 483) (("/") reduce 483) ((";") reduce 483) (("<") reduce 483) (("=") shift) ((">") reduce 483) (("?") reduce 483) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_BOOLEAN_AND) reduce 483) ((T_BOOLEAN_OR) reduce 483) ((T_COALESCE) reduce 483) ((T_INSTANCEOF) reduce 483) ((T_IS_EQUAL) reduce 483) ((T_IS_GREATER_OR_EQUAL) reduce 483) ((T_IS_IDENTICAL) reduce 483) ((T_IS_NOT_EQUAL) reduce 483) ((T_IS_NOT_IDENTICAL) reduce 483) ((T_IS_SMALLER_OR_EQUAL) reduce 483) ((T_LOGICAL_AND) reduce 483) ((T_LOGICAL_OR) reduce 483) ((T_LOGICAL_XOR) reduce 483) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 483) ((T_OBJECT_OPERATOR) reduce 483) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 483) ((T_POW) reduce 483) ((T_SL) reduce 483) ((T_SPACESHIP) reduce 483) ((T_SR) reduce 483) (("[") reduce 483) (("^") reduce 483) (("{") reduce 483) (("|") reduce 483)) 26363 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 369) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 369) ((T_LOGICAL_OR) reduce 369) ((T_LOGICAL_XOR) reduce 369) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26364 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 443) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 443) ((T_LOGICAL_OR) reduce 443) ((T_LOGICAL_XOR) reduce 443) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26375 ((("%") reduce 502) (("*") reduce 502) (("+") reduce 502) (("-") reduce 502) ((".") reduce 502) (("/") reduce 502) ((";") reduce 502) (("<") reduce 502) ((">") reduce 502) (("?") reduce 502) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 502) ((T_BOOLEAN_AND) reduce 502) ((T_BOOLEAN_OR) reduce 502) ((T_COALESCE) reduce 502) ((T_DOUBLE_ARROW) reduce 502) ((T_INSTANCEOF) reduce 502) ((T_IS_EQUAL) reduce 502) ((T_IS_GREATER_OR_EQUAL) reduce 502) ((T_IS_IDENTICAL) reduce 502) ((T_IS_NOT_EQUAL) reduce 502) ((T_IS_NOT_IDENTICAL) reduce 502) ((T_IS_SMALLER_OR_EQUAL) reduce 502) ((T_LOGICAL_AND) reduce 502) ((T_LOGICAL_OR) reduce 502) ((T_LOGICAL_XOR) reduce 502) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 502) ((T_OBJECT_OPERATOR) reduce 502) ((T_POW) reduce 502) ((T_SL) reduce 502) ((T_SPACESHIP) reduce 502) ((T_SR) reduce 502) (("[") reduce 502) (("^") reduce 502) (("{") reduce 502) (("|") reduce 502)) 26377 ((("%") reduce 484) (("(") reduce 484) (("*") reduce 484) (("+") reduce 484) (("-") reduce 484) ((".") reduce 484) (("/") reduce 484) ((";") reduce 484) (("<") reduce 484) ((">") reduce 484) (("?") reduce 484) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 484) ((T_BOOLEAN_AND) reduce 484) ((T_BOOLEAN_OR) reduce 484) ((T_COALESCE) reduce 484) ((T_DOUBLE_ARROW) reduce 484) ((T_INSTANCEOF) reduce 484) ((T_IS_EQUAL) reduce 484) ((T_IS_GREATER_OR_EQUAL) reduce 484) ((T_IS_IDENTICAL) reduce 484) ((T_IS_NOT_EQUAL) reduce 484) ((T_IS_NOT_IDENTICAL) reduce 484) ((T_IS_SMALLER_OR_EQUAL) reduce 484) ((T_LOGICAL_AND) reduce 484) ((T_LOGICAL_OR) reduce 484) ((T_LOGICAL_XOR) reduce 484) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 484) ((T_OBJECT_OPERATOR) reduce 484) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 484) ((T_POW) reduce 484) ((T_SL) reduce 484) ((T_SPACESHIP) reduce 484) ((T_SR) reduce 484) (("[") reduce 484) (("^") reduce 484) (("{") reduce 484) (("|") reduce 484)) 26379 ((("%") reduce 497) (("*") reduce 497) (("+") reduce 497) (("-") reduce 497) ((".") reduce 497) (("/") reduce 497) ((";") reduce 497) (("<") reduce 497) ((">") reduce 497) (("?") reduce 497) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 497) ((T_BOOLEAN_AND) reduce 497) ((T_BOOLEAN_OR) reduce 497) ((T_COALESCE) reduce 497) ((T_DOUBLE_ARROW) reduce 497) ((T_INSTANCEOF) reduce 497) ((T_IS_EQUAL) reduce 497) ((T_IS_GREATER_OR_EQUAL) reduce 497) ((T_IS_IDENTICAL) reduce 497) ((T_IS_NOT_EQUAL) reduce 497) ((T_IS_NOT_IDENTICAL) reduce 497) ((T_IS_SMALLER_OR_EQUAL) reduce 497) ((T_LOGICAL_AND) reduce 497) ((T_LOGICAL_OR) reduce 497) ((T_LOGICAL_XOR) reduce 497) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 497) ((T_OBJECT_OPERATOR) reduce 497) ((T_POW) reduce 497) ((T_SL) reduce 497) ((T_SPACESHIP) reduce 497) ((T_SR) reduce 497) (("[") reduce 497) (("^") reduce 497) (("{") reduce 497) (("|") reduce 497)) 26380 ((("%") reduce 487) (("*") reduce 487) (("+") reduce 487) (("-") reduce 487) ((".") reduce 487) (("/") reduce 487) ((";") reduce 487) (("<") reduce 487) ((">") reduce 487) (("?") reduce 487) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 487) ((T_BOOLEAN_AND) reduce 487) ((T_BOOLEAN_OR) reduce 487) ((T_COALESCE) reduce 487) ((T_DOUBLE_ARROW) reduce 487) ((T_INSTANCEOF) reduce 487) ((T_IS_EQUAL) reduce 487) ((T_IS_GREATER_OR_EQUAL) reduce 487) ((T_IS_IDENTICAL) reduce 487) ((T_IS_NOT_EQUAL) reduce 487) ((T_IS_NOT_IDENTICAL) reduce 487) ((T_IS_SMALLER_OR_EQUAL) reduce 487) ((T_LOGICAL_AND) reduce 487) ((T_LOGICAL_OR) reduce 487) ((T_LOGICAL_XOR) reduce 487) ((T_POW) reduce 487) ((T_SL) reduce 487) ((T_SPACESHIP) reduce 487) ((T_SR) reduce 487) (("^") reduce 487) (("|") reduce 487)) 26384 ((("%") reduce 475) (("(") shift) (("*") reduce 475) (("+") reduce 475) (("-") reduce 475) ((".") reduce 475) (("/") reduce 475) ((";") reduce 475) (("<") reduce 475) ((">") reduce 475) (("?") reduce 475) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 475) ((T_BOOLEAN_AND) reduce 475) ((T_BOOLEAN_OR) reduce 475) ((T_COALESCE) reduce 475) ((T_DOUBLE_ARROW) reduce 475) ((T_INSTANCEOF) reduce 475) ((T_IS_EQUAL) reduce 475) ((T_IS_GREATER_OR_EQUAL) reduce 475) ((T_IS_IDENTICAL) reduce 475) ((T_IS_NOT_EQUAL) reduce 475) ((T_IS_NOT_IDENTICAL) reduce 475) ((T_IS_SMALLER_OR_EQUAL) reduce 475) ((T_LOGICAL_AND) reduce 475) ((T_LOGICAL_OR) reduce 475) ((T_LOGICAL_XOR) reduce 475) ((T_POW) reduce 475) ((T_SL) reduce 475) ((T_SPACESHIP) reduce 475) ((T_SR) reduce 475) (("^") reduce 475) (("|") reduce 475)) 26385 ((("%") reduce 496) (("*") reduce 496) (("+") reduce 496) (("-") reduce 496) ((".") reduce 496) (("/") reduce 496) ((";") reduce 496) (("<") reduce 496) ((">") reduce 496) (("?") reduce 496) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 496) ((T_BOOLEAN_AND) reduce 496) ((T_BOOLEAN_OR) reduce 496) ((T_COALESCE) reduce 496) ((T_DOUBLE_ARROW) reduce 496) ((T_INSTANCEOF) reduce 496) ((T_IS_EQUAL) reduce 496) ((T_IS_GREATER_OR_EQUAL) reduce 496) ((T_IS_IDENTICAL) reduce 496) ((T_IS_NOT_EQUAL) reduce 496) ((T_IS_NOT_IDENTICAL) reduce 496) ((T_IS_SMALLER_OR_EQUAL) reduce 496) ((T_LOGICAL_AND) reduce 496) ((T_LOGICAL_OR) reduce 496) ((T_LOGICAL_XOR) reduce 496) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 496) ((T_OBJECT_OPERATOR) reduce 496) ((T_POW) reduce 496) ((T_SL) reduce 496) ((T_SPACESHIP) reduce 496) ((T_SR) reduce 496) (("[") reduce 496) (("^") reduce 496) (("{") reduce 496) (("|") reduce 496)) 26386 ((("%") reduce 500) (("*") reduce 500) (("+") reduce 500) (("-") reduce 500) ((".") reduce 500) (("/") reduce 500) ((";") reduce 500) (("<") reduce 500) ((">") reduce 500) (("?") reduce 500) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 500) ((T_BOOLEAN_AND) reduce 500) ((T_BOOLEAN_OR) reduce 500) ((T_COALESCE) reduce 500) ((T_DOUBLE_ARROW) reduce 500) ((T_INSTANCEOF) reduce 500) ((T_IS_EQUAL) reduce 500) ((T_IS_GREATER_OR_EQUAL) reduce 500) ((T_IS_IDENTICAL) reduce 500) ((T_IS_NOT_EQUAL) reduce 500) ((T_IS_NOT_IDENTICAL) reduce 500) ((T_IS_SMALLER_OR_EQUAL) reduce 500) ((T_LOGICAL_AND) reduce 500) ((T_LOGICAL_OR) reduce 500) ((T_LOGICAL_XOR) reduce 500) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 500) ((T_OBJECT_OPERATOR) reduce 500) ((T_POW) reduce 500) ((T_SL) reduce 500) ((T_SPACESHIP) reduce 500) ((T_SR) reduce 500) (("[") reduce 500) (("^") reduce 500) (("{") reduce 500) (("|") reduce 500)) 26392 ((("%") reduce 495) (("*") reduce 495) (("+") reduce 495) (("-") reduce 495) ((".") reduce 495) (("/") reduce 495) ((";") reduce 495) (("<") reduce 495) ((">") reduce 495) (("?") reduce 495) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 495) ((T_BOOLEAN_AND) reduce 495) ((T_BOOLEAN_OR) reduce 495) ((T_COALESCE) reduce 495) ((T_DOUBLE_ARROW) reduce 495) ((T_INSTANCEOF) reduce 495) ((T_IS_EQUAL) reduce 495) ((T_IS_GREATER_OR_EQUAL) reduce 495) ((T_IS_IDENTICAL) reduce 495) ((T_IS_NOT_EQUAL) reduce 495) ((T_IS_NOT_IDENTICAL) reduce 495) ((T_IS_SMALLER_OR_EQUAL) reduce 495) ((T_LOGICAL_AND) reduce 495) ((T_LOGICAL_OR) reduce 495) ((T_LOGICAL_XOR) reduce 495) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 495) ((T_OBJECT_OPERATOR) reduce 495) ((T_POW) reduce 495) ((T_SL) reduce 495) ((T_SPACESHIP) reduce 495) ((T_SR) reduce 495) (("[") reduce 495) (("^") reduce 495) (("{") reduce 495) (("|") reduce 495)) 26394 ((("%") reduce 486) (("*") reduce 486) (("+") reduce 486) (("-") reduce 486) ((".") reduce 486) (("/") reduce 486) ((";") reduce 486) (("<") reduce 486) ((">") reduce 486) (("?") reduce 486) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 486) ((T_BOOLEAN_AND) reduce 486) ((T_BOOLEAN_OR) reduce 486) ((T_COALESCE) reduce 486) ((T_DOUBLE_ARROW) reduce 486) ((T_INSTANCEOF) reduce 486) ((T_IS_EQUAL) reduce 486) ((T_IS_GREATER_OR_EQUAL) reduce 486) ((T_IS_IDENTICAL) reduce 486) ((T_IS_NOT_EQUAL) reduce 486) ((T_IS_NOT_IDENTICAL) reduce 486) ((T_IS_SMALLER_OR_EQUAL) reduce 486) ((T_LOGICAL_AND) reduce 486) ((T_LOGICAL_OR) reduce 486) ((T_LOGICAL_XOR) reduce 486) ((T_POW) reduce 486) ((T_SL) reduce 486) ((T_SPACESHIP) reduce 486) ((T_SR) reduce 486) (("^") reduce 486) (("|") reduce 486)) 26396 ((("%") reduce 499) (("*") reduce 499) (("+") reduce 499) (("-") reduce 499) ((".") reduce 499) (("/") reduce 499) ((";") reduce 499) (("<") reduce 499) ((">") reduce 499) (("?") reduce 499) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 499) ((T_BOOLEAN_AND) reduce 499) ((T_BOOLEAN_OR) reduce 499) ((T_COALESCE) reduce 499) ((T_DOUBLE_ARROW) reduce 499) ((T_INSTANCEOF) reduce 499) ((T_IS_EQUAL) reduce 499) ((T_IS_GREATER_OR_EQUAL) reduce 499) ((T_IS_IDENTICAL) reduce 499) ((T_IS_NOT_EQUAL) reduce 499) ((T_IS_NOT_IDENTICAL) reduce 499) ((T_IS_SMALLER_OR_EQUAL) reduce 499) ((T_LOGICAL_AND) reduce 499) ((T_LOGICAL_OR) reduce 499) ((T_LOGICAL_XOR) reduce 499) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 499) ((T_OBJECT_OPERATOR) reduce 499) ((T_POW) reduce 499) ((T_SL) reduce 499) ((T_SPACESHIP) reduce 499) ((T_SR) reduce 499) (("[") reduce 499) (("^") reduce 499) (("{") reduce 499) (("|") reduce 499)) 26397 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) ((";") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 93) ((T_OBJECT_OPERATOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("[") reduce 93) (("^") reduce 93) (("{") reduce 93) (("|") reduce 93)) 26398 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) ((";") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 92) ((T_OBJECT_OPERATOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("[") reduce 92) (("^") reduce 92) (("{") reduce 92) (("|") reduce 92)) 26399 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) ((";") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 94) ((T_OBJECT_OPERATOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("[") reduce 94) (("^") reduce 94) (("{") reduce 94) (("|") reduce 94)) 26401 ((("%") reduce 501) (("*") reduce 501) (("+") reduce 501) (("-") reduce 501) ((".") reduce 501) (("/") reduce 501) ((";") reduce 501) (("<") reduce 501) ((">") reduce 501) (("?") reduce 501) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 501) ((T_BOOLEAN_AND) reduce 501) ((T_BOOLEAN_OR) reduce 501) ((T_COALESCE) reduce 501) ((T_DOUBLE_ARROW) reduce 501) ((T_INSTANCEOF) reduce 501) ((T_IS_EQUAL) reduce 501) ((T_IS_GREATER_OR_EQUAL) reduce 501) ((T_IS_IDENTICAL) reduce 501) ((T_IS_NOT_EQUAL) reduce 501) ((T_IS_NOT_IDENTICAL) reduce 501) ((T_IS_SMALLER_OR_EQUAL) reduce 501) ((T_LOGICAL_AND) reduce 501) ((T_LOGICAL_OR) reduce 501) ((T_LOGICAL_XOR) reduce 501) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 501) ((T_OBJECT_OPERATOR) reduce 501) ((T_POW) reduce 501) ((T_SL) reduce 501) ((T_SPACESHIP) reduce 501) ((T_SR) reduce 501) (("[") reduce 501) (("^") reduce 501) (("{") reduce 501) (("|") reduce 501)) 26409 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) ((";") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 91) ((T_OBJECT_OPERATOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("[") reduce 91) (("^") reduce 91) (("{") reduce 91) (("|") reduce 91)) 26412 ((("%") reduce 498) (("*") reduce 498) (("+") reduce 498) (("-") reduce 498) ((".") reduce 498) (("/") reduce 498) ((";") reduce 498) (("<") reduce 498) ((">") reduce 498) (("?") reduce 498) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 498) ((T_BOOLEAN_AND) reduce 498) ((T_BOOLEAN_OR) reduce 498) ((T_COALESCE) reduce 498) ((T_DOUBLE_ARROW) reduce 498) ((T_INSTANCEOF) reduce 498) ((T_IS_EQUAL) reduce 498) ((T_IS_GREATER_OR_EQUAL) reduce 498) ((T_IS_IDENTICAL) reduce 498) ((T_IS_NOT_EQUAL) reduce 498) ((T_IS_NOT_IDENTICAL) reduce 498) ((T_IS_SMALLER_OR_EQUAL) reduce 498) ((T_LOGICAL_AND) reduce 498) ((T_LOGICAL_OR) reduce 498) ((T_LOGICAL_XOR) reduce 498) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 498) ((T_OBJECT_OPERATOR) reduce 498) ((T_POW) reduce 498) ((T_SL) reduce 498) ((T_SPACESHIP) reduce 498) ((T_SR) reduce 498) (("[") reduce 498) (("^") reduce 498) (("{") reduce 498) (("|") reduce 498)) 26414 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) ((";") reduce 529) (("<") reduce 529) (("=") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AND_EQUAL) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_COALESCE_EQUAL) reduce 529) ((T_CONCAT_EQUAL) reduce 529) ((T_DEC) reduce 529) ((T_DIV_EQUAL) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INC) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_MINUS_EQUAL) reduce 529) ((T_MOD_EQUAL) reduce 529) ((T_MUL_EQUAL) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_OR_EQUAL) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_PLUS_EQUAL) reduce 529) ((T_POW) reduce 529) ((T_POW_EQUAL) reduce 529) ((T_SL) reduce 529) ((T_SL_EQUAL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) ((T_SR_EQUAL) reduce 529) ((T_XOR_EQUAL) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 26415 ((("!") shift) (("\"") shift) (("$") shift) (("%") reduce 440) (("(") shift) (("*") reduce 440) (("+") shift) (("-") shift) ((".") reduce 440) (("/") reduce 440) ((";") reduce 440) (("<") reduce 440) ((">") reduce 440) (("?") reduce 440) (("@") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 440) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOLEAN_AND) reduce 440) ((T_BOOLEAN_OR) reduce 440) ((T_BOOL_CAST) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_COALESCE) reduce 440) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_DEC) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DOUBLE_ARROW) reduce 440) ((T_DOUBLE_CAST) shift) ((T_EMPTY) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FN) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INSTANCEOF) reduce 440) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_IS_EQUAL) reduce 440) ((T_IS_GREATER_OR_EQUAL) reduce 440) ((T_IS_IDENTICAL) reduce 440) ((T_IS_NOT_EQUAL) reduce 440) ((T_IS_NOT_IDENTICAL) reduce 440) ((T_IS_SMALLER_OR_EQUAL) reduce 440) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_LOGICAL_AND) reduce 440) ((T_LOGICAL_OR) reduce 440) ((T_LOGICAL_XOR) reduce 440) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_POW) reduce 440) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_SL) reduce 440) ((T_SPACESHIP) reduce 440) ((T_SR) reduce 440) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_THROW) shift) ((T_TRAIT_C) shift) ((T_UNSET_CAST) shift) ((T_VARIABLE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("^") reduce 440) (("`") shift) (("|") reduce 440) (("~") shift)) 26422 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) ((";") reduce 525) (("<") reduce 525) (("=") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AND_EQUAL) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_COALESCE_EQUAL) reduce 525) ((T_CONCAT_EQUAL) reduce 525) ((T_DEC) reduce 525) ((T_DIV_EQUAL) reduce 525) ((T_DOUBLE_ARROW) reduce 525) ((T_INC) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_MINUS_EQUAL) reduce 525) ((T_MOD_EQUAL) reduce 525) ((T_MUL_EQUAL) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_OR_EQUAL) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_PLUS_EQUAL) reduce 525) ((T_POW) reduce 525) ((T_POW_EQUAL) reduce 525) ((T_SL) reduce 525) ((T_SL_EQUAL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) ((T_SR_EQUAL) reduce 525) ((T_XOR_EQUAL) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 26423 ((("%") reduce 493) (("*") reduce 493) (("+") reduce 493) (("-") reduce 493) ((".") reduce 493) (("/") reduce 493) ((";") reduce 493) (("<") reduce 493) ((">") reduce 493) (("?") reduce 493) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 493) ((T_BOOLEAN_AND) reduce 493) ((T_BOOLEAN_OR) reduce 493) ((T_COALESCE) reduce 493) ((T_DOUBLE_ARROW) reduce 493) ((T_INSTANCEOF) reduce 493) ((T_IS_EQUAL) reduce 493) ((T_IS_GREATER_OR_EQUAL) reduce 493) ((T_IS_IDENTICAL) reduce 493) ((T_IS_NOT_EQUAL) reduce 493) ((T_IS_NOT_IDENTICAL) reduce 493) ((T_IS_SMALLER_OR_EQUAL) reduce 493) ((T_LOGICAL_AND) reduce 493) ((T_LOGICAL_OR) reduce 493) ((T_LOGICAL_XOR) reduce 493) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 513) ((T_OBJECT_OPERATOR) reduce 513) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 513) ((T_POW) reduce 493) ((T_SL) reduce 493) ((T_SPACESHIP) reduce 493) ((T_SR) reduce 493) (("[") reduce 513) (("^") reduce 493) (("{") reduce 513) (("|") reduce 493)) 26425 ((("%") reduce 492) (("*") reduce 492) (("+") reduce 492) (("-") reduce 492) ((".") reduce 492) (("/") reduce 492) ((";") reduce 492) (("<") reduce 492) ((">") reduce 492) (("?") reduce 492) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 492) ((T_BOOLEAN_AND) reduce 492) ((T_BOOLEAN_OR) reduce 492) ((T_COALESCE) reduce 492) ((T_DOUBLE_ARROW) reduce 492) ((T_INSTANCEOF) reduce 492) ((T_IS_EQUAL) reduce 492) ((T_IS_GREATER_OR_EQUAL) reduce 492) ((T_IS_IDENTICAL) reduce 492) ((T_IS_NOT_EQUAL) reduce 492) ((T_IS_NOT_IDENTICAL) reduce 492) ((T_IS_SMALLER_OR_EQUAL) reduce 492) ((T_LOGICAL_AND) reduce 492) ((T_LOGICAL_OR) reduce 492) ((T_LOGICAL_XOR) reduce 492) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 515) ((T_OBJECT_OPERATOR) reduce 515) ((T_POW) reduce 492) ((T_SL) reduce 492) ((T_SPACESHIP) reduce 492) ((T_SR) reduce 492) (("[") reduce 515) (("^") reduce 492) (("{") reduce 515) (("|") reduce 492)) 26426 ((("%") reduce 491) (("(") reduce 518) (("*") reduce 491) (("+") reduce 491) (("-") reduce 491) ((".") reduce 491) (("/") reduce 491) ((";") reduce 491) (("<") reduce 491) ((">") reduce 491) (("?") reduce 491) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 491) ((T_BOOLEAN_AND) reduce 491) ((T_BOOLEAN_OR) reduce 491) ((T_COALESCE) reduce 491) ((T_DOUBLE_ARROW) reduce 491) ((T_INSTANCEOF) reduce 491) ((T_IS_EQUAL) reduce 491) ((T_IS_GREATER_OR_EQUAL) reduce 491) ((T_IS_IDENTICAL) reduce 491) ((T_IS_NOT_EQUAL) reduce 491) ((T_IS_NOT_IDENTICAL) reduce 491) ((T_IS_SMALLER_OR_EQUAL) reduce 491) ((T_LOGICAL_AND) reduce 491) ((T_LOGICAL_OR) reduce 491) ((T_LOGICAL_XOR) reduce 491) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 512) ((T_OBJECT_OPERATOR) reduce 512) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 512) ((T_POW) reduce 491) ((T_SL) reduce 491) ((T_SPACESHIP) reduce 491) ((T_SR) reduce 491) (("[") reduce 512) (("^") reduce 491) (("{") reduce 512) (("|") reduce 491)) 26427 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 441) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 441) ((T_LOGICAL_OR) reduce 441) ((T_LOGICAL_XOR) reduce 441) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26430 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) ((";") reduce 524) (("<") reduce 524) (("=") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AND_EQUAL) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_COALESCE_EQUAL) reduce 524) ((T_CONCAT_EQUAL) reduce 524) ((T_DEC) reduce 524) ((T_DIV_EQUAL) reduce 524) ((T_DOUBLE_ARROW) reduce 524) ((T_INC) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_MINUS_EQUAL) reduce 524) ((T_MOD_EQUAL) reduce 524) ((T_MUL_EQUAL) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_OR_EQUAL) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_PLUS_EQUAL) reduce 524) ((T_POW) reduce 524) ((T_POW_EQUAL) reduce 524) ((T_SL) reduce 524) ((T_SL_EQUAL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) ((T_SR_EQUAL) reduce 524) ((T_XOR_EQUAL) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 26431 ((("%") reduce 445) (("*") reduce 445) (("+") reduce 445) (("-") reduce 445) ((".") reduce 445) (("/") reduce 445) ((";") reduce 445) (("<") reduce 445) ((">") reduce 445) (("?") reduce 445) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 445) ((T_BOOLEAN_AND) reduce 445) ((T_BOOLEAN_OR) reduce 445) ((T_COALESCE) reduce 445) ((T_DOUBLE_ARROW) reduce 445) ((T_INSTANCEOF) reduce 445) ((T_IS_EQUAL) reduce 445) ((T_IS_GREATER_OR_EQUAL) reduce 445) ((T_IS_IDENTICAL) reduce 445) ((T_IS_NOT_EQUAL) reduce 445) ((T_IS_NOT_IDENTICAL) reduce 445) ((T_IS_SMALLER_OR_EQUAL) reduce 445) ((T_LOGICAL_AND) reduce 445) ((T_LOGICAL_OR) reduce 445) ((T_LOGICAL_XOR) reduce 445) ((T_POW) reduce 445) ((T_SL) reduce 445) ((T_SPACESHIP) reduce 445) ((T_SR) reduce 445) (("^") reduce 445) (("|") reduce 445)) 26432 ((("%") reduce 427) (("*") reduce 427) (("+") reduce 427) (("-") reduce 427) ((".") reduce 427) (("/") reduce 427) ((";") reduce 427) (("<") reduce 427) ((">") reduce 427) (("?") reduce 427) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 427) ((T_BOOLEAN_AND) reduce 427) ((T_BOOLEAN_OR) reduce 427) ((T_COALESCE) reduce 427) ((T_DOUBLE_ARROW) reduce 427) ((T_INSTANCEOF) reduce 427) ((T_IS_EQUAL) reduce 427) ((T_IS_GREATER_OR_EQUAL) reduce 427) ((T_IS_IDENTICAL) reduce 427) ((T_IS_NOT_EQUAL) reduce 427) ((T_IS_NOT_IDENTICAL) reduce 427) ((T_IS_SMALLER_OR_EQUAL) reduce 427) ((T_LOGICAL_AND) reduce 427) ((T_LOGICAL_OR) reduce 427) ((T_LOGICAL_XOR) reduce 427) ((T_POW) reduce 427) ((T_SL) reduce 427) ((T_SPACESHIP) reduce 427) ((T_SR) reduce 427) (("^") reduce 427) (("|") reduce 427)) 26433 ((("%") reduce 449) (("*") reduce 449) (("+") reduce 449) (("-") reduce 449) ((".") reduce 449) (("/") reduce 449) ((";") reduce 449) (("<") reduce 449) ((">") reduce 449) (("?") reduce 449) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 449) ((T_BOOLEAN_AND) reduce 449) ((T_BOOLEAN_OR) reduce 449) ((T_COALESCE) reduce 449) ((T_DOUBLE_ARROW) reduce 449) ((T_INSTANCEOF) reduce 449) ((T_IS_EQUAL) reduce 449) ((T_IS_GREATER_OR_EQUAL) reduce 449) ((T_IS_IDENTICAL) reduce 449) ((T_IS_NOT_EQUAL) reduce 449) ((T_IS_NOT_IDENTICAL) reduce 449) ((T_IS_SMALLER_OR_EQUAL) reduce 449) ((T_LOGICAL_AND) reduce 449) ((T_LOGICAL_OR) reduce 449) ((T_LOGICAL_XOR) reduce 449) ((T_POW) reduce 449) ((T_SL) reduce 449) ((T_SPACESHIP) reduce 449) ((T_SR) reduce 449) (("^") reduce 449) (("|") reduce 449)) 26434 ((("%") reduce 494) (("(") shift) (("*") reduce 494) (("+") reduce 494) (("-") reduce 494) ((".") reduce 494) (("/") reduce 494) ((";") reduce 494) (("<") reduce 494) ((">") reduce 494) (("?") reduce 494) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 494) ((T_BOOLEAN_AND) reduce 494) ((T_BOOLEAN_OR) reduce 494) ((T_COALESCE) reduce 494) ((T_DOUBLE_ARROW) reduce 494) ((T_INSTANCEOF) reduce 494) ((T_IS_EQUAL) reduce 494) ((T_IS_GREATER_OR_EQUAL) reduce 494) ((T_IS_IDENTICAL) reduce 494) ((T_IS_NOT_EQUAL) reduce 494) ((T_IS_NOT_IDENTICAL) reduce 494) ((T_IS_SMALLER_OR_EQUAL) reduce 494) ((T_LOGICAL_AND) reduce 494) ((T_LOGICAL_OR) reduce 494) ((T_LOGICAL_XOR) reduce 494) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 494) ((T_OBJECT_OPERATOR) reduce 494) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 494) ((T_SL) reduce 494) ((T_SPACESHIP) reduce 494) ((T_SR) reduce 494) (("[") reduce 494) (("^") reduce 494) (("{") reduce 494) (("|") reduce 494)) 26435 ((("%") reduce 423) (("*") reduce 423) (("+") reduce 423) (("-") reduce 423) ((".") reduce 423) (("/") reduce 423) ((";") reduce 423) (("<") reduce 423) ((">") reduce 423) (("?") reduce 423) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 423) ((T_BOOLEAN_AND) reduce 423) ((T_BOOLEAN_OR) reduce 423) ((T_COALESCE) reduce 423) ((T_DOUBLE_ARROW) reduce 423) ((T_INSTANCEOF) reduce 423) ((T_IS_EQUAL) reduce 423) ((T_IS_GREATER_OR_EQUAL) reduce 423) ((T_IS_IDENTICAL) reduce 423) ((T_IS_NOT_EQUAL) reduce 423) ((T_IS_NOT_IDENTICAL) reduce 423) ((T_IS_SMALLER_OR_EQUAL) reduce 423) ((T_LOGICAL_AND) reduce 423) ((T_LOGICAL_OR) reduce 423) ((T_LOGICAL_XOR) reduce 423) ((T_POW) reduce 423) ((T_SL) reduce 423) ((T_SPACESHIP) reduce 423) ((T_SR) reduce 423) (("^") reduce 423) (("|") reduce 423)) 26436 ((("%") reduce 437) (("*") reduce 437) (("+") reduce 437) (("-") reduce 437) ((".") reduce 437) (("/") reduce 437) ((";") reduce 437) (("<") reduce 437) ((">") reduce 437) (("?") reduce 437) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 437) ((T_BOOLEAN_AND) reduce 437) ((T_BOOLEAN_OR) reduce 437) ((T_COALESCE) reduce 437) ((T_DOUBLE_ARROW) reduce 437) ((T_INSTANCEOF) reduce 437) ((T_IS_EQUAL) reduce 437) ((T_IS_GREATER_OR_EQUAL) reduce 437) ((T_IS_IDENTICAL) reduce 437) ((T_IS_NOT_EQUAL) reduce 437) ((T_IS_NOT_IDENTICAL) reduce 437) ((T_IS_SMALLER_OR_EQUAL) reduce 437) ((T_LOGICAL_AND) reduce 437) ((T_LOGICAL_OR) reduce 437) ((T_LOGICAL_XOR) reduce 437) ((T_POW) reduce 437) ((T_SL) reduce 437) ((T_SPACESHIP) reduce 437) ((T_SR) reduce 437) (("^") reduce 437) (("|") reduce 437)) 26437 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) ((";") reduce 519) (("<") reduce 519) (("=") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AND_EQUAL) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_COALESCE_EQUAL) reduce 519) ((T_CONCAT_EQUAL) reduce 519) ((T_DEC) reduce 519) ((T_DIV_EQUAL) reduce 519) ((T_DOUBLE_ARROW) reduce 519) ((T_INC) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_MINUS_EQUAL) reduce 519) ((T_MOD_EQUAL) reduce 519) ((T_MUL_EQUAL) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_OR_EQUAL) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_PLUS_EQUAL) reduce 519) ((T_POW) reduce 519) ((T_POW_EQUAL) reduce 519) ((T_SL) reduce 519) ((T_SL_EQUAL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) ((T_SR_EQUAL) reduce 519) ((T_XOR_EQUAL) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 26438 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) ((";") reduce 526) (("<") reduce 526) (("=") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AND_EQUAL) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_COALESCE_EQUAL) reduce 526) ((T_CONCAT_EQUAL) reduce 526) ((T_DEC) reduce 526) ((T_DIV_EQUAL) reduce 526) ((T_DOUBLE_ARROW) reduce 526) ((T_INC) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_MINUS_EQUAL) reduce 526) ((T_MOD_EQUAL) reduce 526) ((T_MUL_EQUAL) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_OR_EQUAL) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_PLUS_EQUAL) reduce 526) ((T_POW) reduce 526) ((T_POW_EQUAL) reduce 526) ((T_SL) reduce 526) ((T_SL_EQUAL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) ((T_SR_EQUAL) reduce 526) ((T_XOR_EQUAL) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 26439 ((("%") reduce 367) (("*") reduce 367) (("+") reduce 367) (("-") reduce 367) ((".") reduce 367) (("/") reduce 367) ((";") reduce 367) (("<") reduce 367) (("=") shift) ((">") reduce 367) (("?") reduce 367) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 367) ((T_AND_EQUAL) shift) ((T_BOOLEAN_AND) reduce 367) ((T_BOOLEAN_OR) reduce 367) ((T_COALESCE) reduce 367) ((T_COALESCE_EQUAL) shift) ((T_CONCAT_EQUAL) shift) ((T_DEC) shift) ((T_DIV_EQUAL) shift) ((T_DOUBLE_ARROW) reduce 367) ((T_INC) shift) ((T_INSTANCEOF) reduce 367) ((T_IS_EQUAL) reduce 367) ((T_IS_GREATER_OR_EQUAL) reduce 367) ((T_IS_IDENTICAL) reduce 367) ((T_IS_NOT_EQUAL) reduce 367) ((T_IS_NOT_IDENTICAL) reduce 367) ((T_IS_SMALLER_OR_EQUAL) reduce 367) ((T_LOGICAL_AND) reduce 367) ((T_LOGICAL_OR) reduce 367) ((T_LOGICAL_XOR) reduce 367) ((T_MINUS_EQUAL) shift) ((T_MOD_EQUAL) shift) ((T_MUL_EQUAL) shift) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_OR_EQUAL) shift) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_PLUS_EQUAL) shift) ((T_POW) reduce 367) ((T_POW_EQUAL) shift) ((T_SL) reduce 367) ((T_SL_EQUAL) shift) ((T_SPACESHIP) reduce 367) ((T_SR) reduce 367) ((T_SR_EQUAL) shift) ((T_XOR_EQUAL) shift) (("[") reduce 510) (("^") reduce 367) (("{") reduce 510) (("|") reduce 367)) 26442 ((("%") reduce 411) (("*") reduce 411) (("+") reduce 411) (("-") reduce 411) ((".") reduce 411) (("/") reduce 411) ((";") reduce 411) (("<") reduce 411) ((">") reduce 411) (("?") reduce 411) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 411) ((T_BOOLEAN_AND) reduce 411) ((T_BOOLEAN_OR) reduce 411) ((T_COALESCE) reduce 411) ((T_DOUBLE_ARROW) reduce 411) ((T_INSTANCEOF) reduce 411) ((T_IS_EQUAL) reduce 411) ((T_IS_GREATER_OR_EQUAL) reduce 411) ((T_IS_IDENTICAL) reduce 411) ((T_IS_NOT_EQUAL) reduce 411) ((T_IS_NOT_IDENTICAL) reduce 411) ((T_IS_SMALLER_OR_EQUAL) reduce 411) ((T_LOGICAL_AND) reduce 411) ((T_LOGICAL_OR) reduce 411) ((T_LOGICAL_XOR) reduce 411) ((T_POW) shift) ((T_SL) reduce 411) ((T_SPACESHIP) reduce 411) ((T_SR) reduce 411) (("^") reduce 411) (("|") reduce 411)) 26473 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 395) (("<") shift) ((">") shift) (("?") reduce 395) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 395) ((T_BOOLEAN_OR) reduce 395) ((T_COALESCE) reduce 395) ((T_DOUBLE_ARROW) reduce 395) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 395) ((T_LOGICAL_OR) reduce 395) ((T_LOGICAL_XOR) reduce 395) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") reduce 395)) 26474 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 398) (("<") shift) ((">") shift) (("?") reduce 398) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 398) ((T_BOOLEAN_OR) reduce 398) ((T_COALESCE) reduce 398) ((T_DOUBLE_ARROW) reduce 398) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 398) ((T_LOGICAL_OR) reduce 398) ((T_LOGICAL_XOR) reduce 398) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 398) (("|") reduce 398)) 26475 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 407) (("/") shift) ((";") reduce 407) (("<") reduce 407) ((">") reduce 407) (("?") reduce 407) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 407) ((T_BOOLEAN_AND) reduce 407) ((T_BOOLEAN_OR) reduce 407) ((T_COALESCE) reduce 407) ((T_DOUBLE_ARROW) reduce 407) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 407) ((T_IS_GREATER_OR_EQUAL) reduce 407) ((T_IS_IDENTICAL) reduce 407) ((T_IS_NOT_EQUAL) reduce 407) ((T_IS_NOT_IDENTICAL) reduce 407) ((T_IS_SMALLER_OR_EQUAL) reduce 407) ((T_LOGICAL_AND) reduce 407) ((T_LOGICAL_OR) reduce 407) ((T_LOGICAL_XOR) reduce 407) ((T_POW) shift) ((T_SL) reduce 407) ((T_SPACESHIP) reduce 407) ((T_SR) reduce 407) (("^") reduce 407) (("|") reduce 407)) 26476 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 420) (("<") shift) ((">") shift) (("?") reduce 420) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 420) ((T_BOOLEAN_AND) reduce 420) ((T_BOOLEAN_OR) reduce 420) ((T_COALESCE) reduce 420) ((T_DOUBLE_ARROW) reduce 420) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 420) ((T_LOGICAL_OR) reduce 420) ((T_LOGICAL_XOR) reduce 420) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 420) (("|") reduce 420)) 26477 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 406) (("/") shift) ((";") reduce 406) (("<") reduce 406) ((">") reduce 406) (("?") reduce 406) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 406) ((T_BOOLEAN_AND) reduce 406) ((T_BOOLEAN_OR) reduce 406) ((T_COALESCE) reduce 406) ((T_DOUBLE_ARROW) reduce 406) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 406) ((T_IS_GREATER_OR_EQUAL) reduce 406) ((T_IS_IDENTICAL) reduce 406) ((T_IS_NOT_EQUAL) reduce 406) ((T_IS_NOT_IDENTICAL) reduce 406) ((T_IS_SMALLER_OR_EQUAL) reduce 406) ((T_LOGICAL_AND) reduce 406) ((T_LOGICAL_OR) reduce 406) ((T_LOGICAL_XOR) reduce 406) ((T_POW) shift) ((T_SL) reduce 406) ((T_SPACESHIP) reduce 406) ((T_SR) reduce 406) (("^") reduce 406) (("|") reduce 406)) 26478 ((("%") reduce 403) (("*") reduce 403) (("+") reduce 403) (("-") reduce 403) ((".") reduce 403) (("/") reduce 403) ((";") reduce 403) (("<") reduce 403) ((">") reduce 403) (("?") reduce 403) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 403) ((T_BOOLEAN_AND) reduce 403) ((T_BOOLEAN_OR) reduce 403) ((T_COALESCE) reduce 403) ((T_DOUBLE_ARROW) reduce 403) ((T_INSTANCEOF) reduce 403) ((T_IS_EQUAL) reduce 403) ((T_IS_GREATER_OR_EQUAL) reduce 403) ((T_IS_IDENTICAL) reduce 403) ((T_IS_NOT_EQUAL) reduce 403) ((T_IS_NOT_IDENTICAL) reduce 403) ((T_IS_SMALLER_OR_EQUAL) reduce 403) ((T_LOGICAL_AND) reduce 403) ((T_LOGICAL_OR) reduce 403) ((T_LOGICAL_XOR) reduce 403) ((T_POW) shift) ((T_SL) reduce 403) ((T_SPACESHIP) reduce 403) ((T_SR) reduce 403) (("^") reduce 403) (("|") reduce 403)) 26479 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 394) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 394) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 394) ((T_LOGICAL_XOR) reduce 394) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26480 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 392) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 392) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) reduce 392) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26481 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 393) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 393) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 393) ((T_LOGICAL_OR) reduce 393) ((T_LOGICAL_XOR) reduce 393) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26482 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 417) (("<") shift) ((">") shift) (("?") reduce 417) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 417) ((T_BOOLEAN_AND) reduce 417) ((T_BOOLEAN_OR) reduce 417) ((T_COALESCE) reduce 417) ((T_DOUBLE_ARROW) reduce 417) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 417) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 417) ((T_IS_NOT_EQUAL) reduce 417) ((T_IS_NOT_IDENTICAL) reduce 417) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 417) ((T_LOGICAL_OR) reduce 417) ((T_LOGICAL_XOR) reduce 417) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 417) ((T_SR) shift) (("^") reduce 417) (("|") reduce 417)) 26483 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 413) (("<") shift) ((">") shift) (("?") reduce 413) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 413) ((T_BOOLEAN_AND) reduce 413) ((T_BOOLEAN_OR) reduce 413) ((T_COALESCE) reduce 413) ((T_DOUBLE_ARROW) reduce 413) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 413) ((T_LOGICAL_OR) reduce 413) ((T_LOGICAL_XOR) reduce 413) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 413) (("|") reduce 413)) 26484 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 415) (("<") shift) ((">") shift) (("?") reduce 415) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 415) ((T_BOOLEAN_AND) reduce 415) ((T_BOOLEAN_OR) reduce 415) ((T_COALESCE) reduce 415) ((T_DOUBLE_ARROW) reduce 415) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 415) ((T_LOGICAL_OR) reduce 415) ((T_LOGICAL_XOR) reduce 415) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 415) (("|") reduce 415)) 26485 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 412) (("<") shift) ((">") shift) (("?") reduce 412) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 412) ((T_BOOLEAN_AND) reduce 412) ((T_BOOLEAN_OR) reduce 412) ((T_COALESCE) reduce 412) ((T_DOUBLE_ARROW) reduce 412) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 412) ((T_LOGICAL_OR) reduce 412) ((T_LOGICAL_XOR) reduce 412) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 412) (("|") reduce 412)) 26486 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 419) (("<") shift) ((">") shift) (("?") reduce 419) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 419) ((T_BOOLEAN_AND) reduce 419) ((T_BOOLEAN_OR) reduce 419) ((T_COALESCE) reduce 419) ((T_DOUBLE_ARROW) reduce 419) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 419) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 419) ((T_IS_NOT_EQUAL) reduce 419) ((T_IS_NOT_IDENTICAL) reduce 419) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 419) ((T_LOGICAL_OR) reduce 419) ((T_LOGICAL_XOR) reduce 419) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 419) ((T_SR) shift) (("^") reduce 419) (("|") reduce 419)) 26487 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 414) (("<") shift) ((">") shift) (("?") reduce 414) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 414) ((T_BOOLEAN_AND) reduce 414) ((T_BOOLEAN_OR) reduce 414) ((T_COALESCE) reduce 414) ((T_DOUBLE_ARROW) reduce 414) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 414) ((T_LOGICAL_OR) reduce 414) ((T_LOGICAL_XOR) reduce 414) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 414) (("|") reduce 414)) 26490 ((("%") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) ((";") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93)) 26491 ((("%") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) ((";") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92)) 26492 ((("%") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) ((";") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94)) 26493 ((("%") reduce 470) (("*") reduce 470) (("+") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) ((";") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_DOUBLE_ARROW) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470)) 26494 ((("%") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) ((";") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91)) 26495 ((("%") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) ((";") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 26496 ((("%") reduce 472) (("*") reduce 472) (("+") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) ((";") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_DOUBLE_ARROW) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472)) 26497 ((("%") reduce 421) (("*") reduce 421) (("+") reduce 421) (("-") reduce 421) ((".") reduce 421) (("/") reduce 421) ((";") reduce 421) (("<") reduce 421) ((">") reduce 421) (("?") reduce 421) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 421) ((T_BOOLEAN_AND) reduce 421) ((T_BOOLEAN_OR) reduce 421) ((T_COALESCE) reduce 421) ((T_DOUBLE_ARROW) reduce 421) ((T_INSTANCEOF) reduce 421) ((T_IS_EQUAL) reduce 421) ((T_IS_GREATER_OR_EQUAL) reduce 421) ((T_IS_IDENTICAL) reduce 421) ((T_IS_NOT_EQUAL) reduce 421) ((T_IS_NOT_IDENTICAL) reduce 421) ((T_IS_SMALLER_OR_EQUAL) reduce 421) ((T_LOGICAL_AND) reduce 421) ((T_LOGICAL_OR) reduce 421) ((T_LOGICAL_XOR) reduce 421) ((T_POW) reduce 421) ((T_SL) reduce 421) ((T_SPACESHIP) reduce 421) ((T_SR) reduce 421) (("^") reduce 421) (("|") reduce 421)) 26498 ((("%") reduce 471) (("*") reduce 471) (("+") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) ((";") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_DOUBLE_ARROW) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471)) 26499 ((("%") reduce 473) (("*") reduce 473) (("+") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) ((";") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_DOUBLE_ARROW) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 26500 ((("%") reduce 534) (("*") reduce 534) (("+") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) ((";") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_DOUBLE_ARROW) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 26507 ((("%") reduce 536) (("*") reduce 536) (("+") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) ((";") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_DOUBLE_ARROW) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 26509 ((("%") reduce 535) (("*") reduce 535) (("+") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) ((";") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_DOUBLE_ARROW) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 26510 ((("%") reduce 540) (("*") reduce 540) (("+") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) ((";") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_DOUBLE_ARROW) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 26511 ((("%") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) ((";") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 26512 ((("%") reduce 537) (("*") reduce 537) (("+") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) ((";") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_DOUBLE_ARROW) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 26513 ((("%") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) ((";") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 26516 ((("%") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) ((";") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 26517 ((("%") reduce 538) (("*") reduce 538) (("+") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) ((";") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_DOUBLE_ARROW) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 26519 ((("%") reduce 539) (("*") reduce 539) (("+") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) ((";") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_DOUBLE_ARROW) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 26521 ((("%") reduce 474) (("*") reduce 474) (("+") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) ((";") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_DOUBLE_ARROW) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474)) 26522 ((("%") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) ((";") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 26525 ((("%") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) ((";") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 26526 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 426) (("<") shift) ((">") shift) (("?") reduce 426) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 426) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 426) ((T_LOGICAL_OR) reduce 426) ((T_LOGICAL_XOR) reduce 426) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26527 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 390) (("<") shift) ((">") shift) (("?") reduce 390) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) reduce 390) ((T_COALESCE) reduce 390) ((T_DOUBLE_ARROW) reduce 390) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 390) ((T_LOGICAL_OR) reduce 390) ((T_LOGICAL_XOR) reduce 390) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26528 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 391) (("<") shift) ((">") shift) (("?") reduce 391) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) reduce 391) ((T_BOOLEAN_OR) reduce 391) ((T_COALESCE) reduce 391) ((T_DOUBLE_ARROW) reduce 391) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 391) ((T_LOGICAL_OR) reduce 391) ((T_LOGICAL_XOR) reduce 391) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26529 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 396) (("<") shift) ((">") shift) (("?") reduce 396) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 396) ((T_BOOLEAN_AND) reduce 396) ((T_BOOLEAN_OR) reduce 396) ((T_COALESCE) reduce 396) ((T_DOUBLE_ARROW) reduce 396) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 396) ((T_LOGICAL_OR) reduce 396) ((T_LOGICAL_XOR) reduce 396) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 396) (("|") reduce 396)) 26530 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 397) (("<") shift) ((">") shift) (("?") reduce 397) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 397) ((T_BOOLEAN_AND) reduce 397) ((T_BOOLEAN_OR) reduce 397) ((T_COALESCE) reduce 397) ((T_DOUBLE_ARROW) reduce 397) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 397) ((T_LOGICAL_OR) reduce 397) ((T_LOGICAL_XOR) reduce 397) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") reduce 397) (("|") reduce 397)) 26534 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 424) (("<") shift) ((">") shift) (("?") reduce 424) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 424) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 424) ((T_LOGICAL_OR) reduce 424) ((T_LOGICAL_XOR) reduce 424) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26535 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 425) (("<") shift) ((">") shift) (("?") reduce 425) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 425) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 425) ((T_LOGICAL_OR) reduce 425) ((T_LOGICAL_XOR) reduce 425) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26536 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 418) (("<") shift) ((">") shift) (("?") reduce 418) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 418) ((T_BOOLEAN_AND) reduce 418) ((T_BOOLEAN_OR) reduce 418) ((T_COALESCE) reduce 418) ((T_DOUBLE_ARROW) reduce 418) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 418) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 418) ((T_IS_NOT_EQUAL) reduce 418) ((T_IS_NOT_IDENTICAL) reduce 418) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 418) ((T_LOGICAL_OR) reduce 418) ((T_LOGICAL_XOR) reduce 418) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 418) ((T_SR) shift) (("^") reduce 418) (("|") reduce 418)) 26537 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 416) (("<") shift) ((">") shift) (("?") reduce 416) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 416) ((T_BOOLEAN_AND) reduce 416) ((T_BOOLEAN_OR) reduce 416) ((T_COALESCE) reduce 416) ((T_DOUBLE_ARROW) reduce 416) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 416) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) reduce 416) ((T_IS_NOT_EQUAL) reduce 416) ((T_IS_NOT_IDENTICAL) reduce 416) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 416) ((T_LOGICAL_OR) reduce 416) ((T_LOGICAL_XOR) reduce 416) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 416) ((T_SR) shift) (("^") reduce 416) (("|") reduce 416)) 26538 ((("%") reduce 404) (("*") reduce 404) (("+") reduce 404) (("-") reduce 404) ((".") reduce 404) (("/") reduce 404) ((";") reduce 404) (("<") reduce 404) ((">") reduce 404) (("?") reduce 404) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 404) ((T_BOOLEAN_AND) reduce 404) ((T_BOOLEAN_OR) reduce 404) ((T_COALESCE) reduce 404) ((T_DOUBLE_ARROW) reduce 404) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 404) ((T_IS_GREATER_OR_EQUAL) reduce 404) ((T_IS_IDENTICAL) reduce 404) ((T_IS_NOT_EQUAL) reduce 404) ((T_IS_NOT_IDENTICAL) reduce 404) ((T_IS_SMALLER_OR_EQUAL) reduce 404) ((T_LOGICAL_AND) reduce 404) ((T_LOGICAL_OR) reduce 404) ((T_LOGICAL_XOR) reduce 404) ((T_POW) shift) ((T_SL) reduce 404) ((T_SPACESHIP) reduce 404) ((T_SR) reduce 404) (("^") reduce 404) (("|") reduce 404)) 26539 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") reduce 399) (("/") shift) ((";") reduce 399) (("<") reduce 399) ((">") reduce 399) (("?") reduce 399) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 399) ((T_BOOLEAN_AND) reduce 399) ((T_BOOLEAN_OR) reduce 399) ((T_COALESCE) reduce 399) ((T_DOUBLE_ARROW) reduce 399) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 399) ((T_IS_GREATER_OR_EQUAL) reduce 399) ((T_IS_IDENTICAL) reduce 399) ((T_IS_NOT_EQUAL) reduce 399) ((T_IS_NOT_IDENTICAL) reduce 399) ((T_IS_SMALLER_OR_EQUAL) reduce 399) ((T_LOGICAL_AND) reduce 399) ((T_LOGICAL_OR) reduce 399) ((T_LOGICAL_XOR) reduce 399) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) reduce 399) ((T_SR) shift) (("^") reduce 399) (("|") reduce 399)) 26540 ((("%") shift) (("*") shift) (("+") reduce 401) (("-") reduce 401) ((".") reduce 401) (("/") shift) ((";") reduce 401) (("<") reduce 401) ((">") reduce 401) (("?") reduce 401) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 401) ((T_BOOLEAN_AND) reduce 401) ((T_BOOLEAN_OR) reduce 401) ((T_COALESCE) reduce 401) ((T_DOUBLE_ARROW) reduce 401) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 401) ((T_IS_GREATER_OR_EQUAL) reduce 401) ((T_IS_IDENTICAL) reduce 401) ((T_IS_NOT_EQUAL) reduce 401) ((T_IS_NOT_IDENTICAL) reduce 401) ((T_IS_SMALLER_OR_EQUAL) reduce 401) ((T_LOGICAL_AND) reduce 401) ((T_LOGICAL_OR) reduce 401) ((T_LOGICAL_XOR) reduce 401) ((T_POW) shift) ((T_SL) reduce 401) ((T_SPACESHIP) reduce 401) ((T_SR) reduce 401) (("^") reduce 401) (("|") reduce 401)) 26541 ((("%") shift) (("*") shift) (("+") reduce 400) (("-") reduce 400) ((".") reduce 400) (("/") shift) ((";") reduce 400) (("<") reduce 400) ((">") reduce 400) (("?") reduce 400) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 400) ((T_BOOLEAN_AND) reduce 400) ((T_BOOLEAN_OR) reduce 400) ((T_COALESCE) reduce 400) ((T_DOUBLE_ARROW) reduce 400) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 400) ((T_IS_GREATER_OR_EQUAL) reduce 400) ((T_IS_IDENTICAL) reduce 400) ((T_IS_NOT_EQUAL) reduce 400) ((T_IS_NOT_IDENTICAL) reduce 400) ((T_IS_SMALLER_OR_EQUAL) reduce 400) ((T_LOGICAL_AND) reduce 400) ((T_LOGICAL_OR) reduce 400) ((T_LOGICAL_XOR) reduce 400) ((T_POW) shift) ((T_SL) reduce 400) ((T_SPACESHIP) reduce 400) ((T_SR) reduce 400) (("^") reduce 400) (("|") reduce 400)) 26542 ((("%") reduce 402) (("*") reduce 402) (("+") reduce 402) (("-") reduce 402) ((".") reduce 402) (("/") reduce 402) ((";") reduce 402) (("<") reduce 402) ((">") reduce 402) (("?") reduce 402) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 402) ((T_BOOLEAN_AND) reduce 402) ((T_BOOLEAN_OR) reduce 402) ((T_COALESCE) reduce 402) ((T_DOUBLE_ARROW) reduce 402) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 402) ((T_IS_GREATER_OR_EQUAL) reduce 402) ((T_IS_IDENTICAL) reduce 402) ((T_IS_NOT_EQUAL) reduce 402) ((T_IS_NOT_IDENTICAL) reduce 402) ((T_IS_SMALLER_OR_EQUAL) reduce 402) ((T_LOGICAL_AND) reduce 402) ((T_LOGICAL_OR) reduce 402) ((T_LOGICAL_XOR) reduce 402) ((T_POW) shift) ((T_SL) reduce 402) ((T_SPACESHIP) reduce 402) ((T_SR) reduce 402) (("^") reduce 402) (("|") reduce 402)) 26543 ((("%") reduce 405) (("*") reduce 405) (("+") reduce 405) (("-") reduce 405) ((".") reduce 405) (("/") reduce 405) ((";") reduce 405) (("<") reduce 405) ((">") reduce 405) (("?") reduce 405) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 405) ((T_BOOLEAN_AND) reduce 405) ((T_BOOLEAN_OR) reduce 405) ((T_COALESCE) reduce 405) ((T_DOUBLE_ARROW) reduce 405) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 405) ((T_IS_GREATER_OR_EQUAL) reduce 405) ((T_IS_IDENTICAL) reduce 405) ((T_IS_NOT_EQUAL) reduce 405) ((T_IS_NOT_IDENTICAL) reduce 405) ((T_IS_SMALLER_OR_EQUAL) reduce 405) ((T_LOGICAL_AND) reduce 405) ((T_LOGICAL_OR) reduce 405) ((T_LOGICAL_XOR) reduce 405) ((T_POW) shift) ((T_SL) reduce 405) ((T_SPACESHIP) reduce 405) ((T_SR) reduce 405) (("^") reduce 405) (("|") reduce 405)) 26545 ((("%") reduce 73) (("(") reduce 73) (("*") reduce 73) (("+") reduce 73) (("-") reduce 73) ((".") reduce 73) (("/") reduce 73) ((";") reduce 73) (("<") reduce 73) ((">") reduce 73) (("?") reduce 73) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 73) ((T_BOOLEAN_AND) reduce 73) ((T_BOOLEAN_OR) reduce 73) ((T_COALESCE) reduce 73) ((T_DOUBLE_ARROW) reduce 73) ((T_INSTANCEOF) reduce 73) ((T_IS_EQUAL) reduce 73) ((T_IS_GREATER_OR_EQUAL) reduce 73) ((T_IS_IDENTICAL) reduce 73) ((T_IS_NOT_EQUAL) reduce 73) ((T_IS_NOT_IDENTICAL) reduce 73) ((T_IS_SMALLER_OR_EQUAL) reduce 73) ((T_LOGICAL_AND) reduce 73) ((T_LOGICAL_OR) reduce 73) ((T_LOGICAL_XOR) reduce 73) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 73) ((T_OBJECT_OPERATOR) reduce 73) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 73) ((T_POW) reduce 73) ((T_SL) reduce 73) ((T_SPACESHIP) reduce 73) ((T_SR) reduce 73) (("[") reduce 73) (("^") reduce 73) (("{") reduce 73) (("|") reduce 73)) 26546 ((("%") reduce 52) (("(") reduce 52) (("*") reduce 52) (("+") reduce 52) (("-") reduce 52) ((".") reduce 52) (("/") reduce 52) ((";") reduce 52) (("<") reduce 52) ((">") reduce 52) (("?") reduce 52) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 52) ((T_BOOLEAN_AND) reduce 52) ((T_BOOLEAN_OR) reduce 52) ((T_COALESCE) reduce 52) ((T_DOUBLE_ARROW) reduce 52) ((T_INSTANCEOF) reduce 52) ((T_IS_EQUAL) reduce 52) ((T_IS_GREATER_OR_EQUAL) reduce 52) ((T_IS_IDENTICAL) reduce 52) ((T_IS_NOT_EQUAL) reduce 52) ((T_IS_NOT_IDENTICAL) reduce 52) ((T_IS_SMALLER_OR_EQUAL) reduce 52) ((T_LOGICAL_AND) reduce 52) ((T_LOGICAL_OR) reduce 52) ((T_LOGICAL_XOR) reduce 52) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 52) ((T_OBJECT_OPERATOR) reduce 52) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 52) ((T_POW) reduce 52) ((T_SL) reduce 52) ((T_SPACESHIP) reduce 52) ((T_SR) reduce 52) (("[") reduce 52) (("^") reduce 52) (("{") reduce 52) (("|") reduce 52)) 26547 ((("%") reduce 27) (("(") reduce 27) (("*") reduce 27) (("+") reduce 27) (("-") reduce 27) ((".") reduce 27) (("/") reduce 27) ((";") reduce 27) (("<") reduce 27) ((">") reduce 27) (("?") reduce 27) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 27) ((T_BOOLEAN_AND) reduce 27) ((T_BOOLEAN_OR) reduce 27) ((T_COALESCE) reduce 27) ((T_DOUBLE_ARROW) reduce 27) ((T_INSTANCEOF) reduce 27) ((T_IS_EQUAL) reduce 27) ((T_IS_GREATER_OR_EQUAL) reduce 27) ((T_IS_IDENTICAL) reduce 27) ((T_IS_NOT_EQUAL) reduce 27) ((T_IS_NOT_IDENTICAL) reduce 27) ((T_IS_SMALLER_OR_EQUAL) reduce 27) ((T_LOGICAL_AND) reduce 27) ((T_LOGICAL_OR) reduce 27) ((T_LOGICAL_XOR) reduce 27) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 27) ((T_OBJECT_OPERATOR) reduce 27) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 27) ((T_POW) reduce 27) ((T_SL) reduce 27) ((T_SPACESHIP) reduce 27) ((T_SR) reduce 27) (("[") reduce 27) (("^") reduce 27) (("{") reduce 27) (("|") reduce 27)) 26548 ((("%") reduce 51) (("(") reduce 51) (("*") reduce 51) (("+") reduce 51) (("-") reduce 51) ((".") reduce 51) (("/") reduce 51) ((";") reduce 51) (("<") reduce 51) ((">") reduce 51) (("?") reduce 51) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 51) ((T_BOOLEAN_AND) reduce 51) ((T_BOOLEAN_OR) reduce 51) ((T_COALESCE) reduce 51) ((T_DOUBLE_ARROW) reduce 51) ((T_INSTANCEOF) reduce 51) ((T_IS_EQUAL) reduce 51) ((T_IS_GREATER_OR_EQUAL) reduce 51) ((T_IS_IDENTICAL) reduce 51) ((T_IS_NOT_EQUAL) reduce 51) ((T_IS_NOT_IDENTICAL) reduce 51) ((T_IS_SMALLER_OR_EQUAL) reduce 51) ((T_LOGICAL_AND) reduce 51) ((T_LOGICAL_OR) reduce 51) ((T_LOGICAL_XOR) reduce 51) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 51) ((T_OBJECT_OPERATOR) reduce 51) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 51) ((T_POW) reduce 51) ((T_SL) reduce 51) ((T_SPACESHIP) reduce 51) ((T_SR) reduce 51) (("[") reduce 51) (("^") reduce 51) (("{") reduce 51) (("|") reduce 51)) 26549 ((("%") reduce 53) (("(") reduce 53) (("*") reduce 53) (("+") reduce 53) (("-") reduce 53) ((".") reduce 53) (("/") reduce 53) ((";") reduce 53) (("<") reduce 53) ((">") reduce 53) (("?") reduce 53) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 53) ((T_BOOLEAN_AND) reduce 53) ((T_BOOLEAN_OR) reduce 53) ((T_COALESCE) reduce 53) ((T_DOUBLE_ARROW) reduce 53) ((T_INSTANCEOF) reduce 53) ((T_IS_EQUAL) reduce 53) ((T_IS_GREATER_OR_EQUAL) reduce 53) ((T_IS_IDENTICAL) reduce 53) ((T_IS_NOT_EQUAL) reduce 53) ((T_IS_NOT_IDENTICAL) reduce 53) ((T_IS_SMALLER_OR_EQUAL) reduce 53) ((T_LOGICAL_AND) reduce 53) ((T_LOGICAL_OR) reduce 53) ((T_LOGICAL_XOR) reduce 53) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 53) ((T_OBJECT_OPERATOR) reduce 53) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 53) ((T_POW) reduce 53) ((T_SL) reduce 53) ((T_SPACESHIP) reduce 53) ((T_SR) reduce 53) (("[") reduce 53) (("^") reduce 53) (("{") reduce 53) (("|") reduce 53)) 26550 ((("%") reduce 49) (("(") reduce 49) (("*") reduce 49) (("+") reduce 49) (("-") reduce 49) ((".") reduce 49) (("/") reduce 49) ((";") reduce 49) (("<") reduce 49) ((">") reduce 49) (("?") reduce 49) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 49) ((T_BOOLEAN_AND) reduce 49) ((T_BOOLEAN_OR) reduce 49) ((T_COALESCE) reduce 49) ((T_DOUBLE_ARROW) reduce 49) ((T_INSTANCEOF) reduce 49) ((T_IS_EQUAL) reduce 49) ((T_IS_GREATER_OR_EQUAL) reduce 49) ((T_IS_IDENTICAL) reduce 49) ((T_IS_NOT_EQUAL) reduce 49) ((T_IS_NOT_IDENTICAL) reduce 49) ((T_IS_SMALLER_OR_EQUAL) reduce 49) ((T_LOGICAL_AND) reduce 49) ((T_LOGICAL_OR) reduce 49) ((T_LOGICAL_XOR) reduce 49) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 49) ((T_OBJECT_OPERATOR) reduce 49) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 49) ((T_POW) reduce 49) ((T_SL) reduce 49) ((T_SPACESHIP) reduce 49) ((T_SR) reduce 49) (("[") reduce 49) (("^") reduce 49) (("{") reduce 49) (("|") reduce 49)) 26551 ((("%") reduce 29) (("(") reduce 29) (("*") reduce 29) (("+") reduce 29) (("-") reduce 29) ((".") reduce 29) (("/") reduce 29) ((";") reduce 29) (("<") reduce 29) ((">") reduce 29) (("?") reduce 29) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 29) ((T_BOOLEAN_AND) reduce 29) ((T_BOOLEAN_OR) reduce 29) ((T_COALESCE) reduce 29) ((T_DOUBLE_ARROW) reduce 29) ((T_INSTANCEOF) reduce 29) ((T_IS_EQUAL) reduce 29) ((T_IS_GREATER_OR_EQUAL) reduce 29) ((T_IS_IDENTICAL) reduce 29) ((T_IS_NOT_EQUAL) reduce 29) ((T_IS_NOT_IDENTICAL) reduce 29) ((T_IS_SMALLER_OR_EQUAL) reduce 29) ((T_LOGICAL_AND) reduce 29) ((T_LOGICAL_OR) reduce 29) ((T_LOGICAL_XOR) reduce 29) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 29) ((T_OBJECT_OPERATOR) reduce 29) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 29) ((T_POW) reduce 29) ((T_SL) reduce 29) ((T_SPACESHIP) reduce 29) ((T_SR) reduce 29) (("[") reduce 29) (("^") reduce 29) (("{") reduce 29) (("|") reduce 29)) 26552 ((("%") reduce 59) (("(") reduce 59) (("*") reduce 59) (("+") reduce 59) (("-") reduce 59) ((".") reduce 59) (("/") reduce 59) ((";") reduce 59) (("<") reduce 59) ((">") reduce 59) (("?") reduce 59) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 59) ((T_BOOLEAN_AND) reduce 59) ((T_BOOLEAN_OR) reduce 59) ((T_COALESCE) reduce 59) ((T_DOUBLE_ARROW) reduce 59) ((T_INSTANCEOF) reduce 59) ((T_IS_EQUAL) reduce 59) ((T_IS_GREATER_OR_EQUAL) reduce 59) ((T_IS_IDENTICAL) reduce 59) ((T_IS_NOT_EQUAL) reduce 59) ((T_IS_NOT_IDENTICAL) reduce 59) ((T_IS_SMALLER_OR_EQUAL) reduce 59) ((T_LOGICAL_AND) reduce 59) ((T_LOGICAL_OR) reduce 59) ((T_LOGICAL_XOR) reduce 59) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 59) ((T_OBJECT_OPERATOR) reduce 59) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 59) ((T_POW) reduce 59) ((T_SL) reduce 59) ((T_SPACESHIP) reduce 59) ((T_SR) reduce 59) (("[") reduce 59) (("^") reduce 59) (("{") reduce 59) (("|") reduce 59)) 26553 ((("%") reduce 60) (("(") reduce 60) (("*") reduce 60) (("+") reduce 60) (("-") reduce 60) ((".") reduce 60) (("/") reduce 60) ((";") reduce 60) (("<") reduce 60) ((">") reduce 60) (("?") reduce 60) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 60) ((T_BOOLEAN_AND) reduce 60) ((T_BOOLEAN_OR) reduce 60) ((T_COALESCE) reduce 60) ((T_DOUBLE_ARROW) reduce 60) ((T_INSTANCEOF) reduce 60) ((T_IS_EQUAL) reduce 60) ((T_IS_GREATER_OR_EQUAL) reduce 60) ((T_IS_IDENTICAL) reduce 60) ((T_IS_NOT_EQUAL) reduce 60) ((T_IS_NOT_IDENTICAL) reduce 60) ((T_IS_SMALLER_OR_EQUAL) reduce 60) ((T_LOGICAL_AND) reduce 60) ((T_LOGICAL_OR) reduce 60) ((T_LOGICAL_XOR) reduce 60) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 60) ((T_OBJECT_OPERATOR) reduce 60) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 60) ((T_POW) reduce 60) ((T_SL) reduce 60) ((T_SPACESHIP) reduce 60) ((T_SR) reduce 60) (("[") reduce 60) (("^") reduce 60) (("{") reduce 60) (("|") reduce 60)) 26554 ((("%") reduce 11) (("(") reduce 11) (("*") reduce 11) (("+") reduce 11) (("-") reduce 11) ((".") reduce 11) (("/") reduce 11) ((";") reduce 11) (("<") reduce 11) ((">") reduce 11) (("?") reduce 11) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 11) ((T_BOOLEAN_AND) reduce 11) ((T_BOOLEAN_OR) reduce 11) ((T_COALESCE) reduce 11) ((T_DOUBLE_ARROW) reduce 11) ((T_INSTANCEOF) reduce 11) ((T_IS_EQUAL) reduce 11) ((T_IS_GREATER_OR_EQUAL) reduce 11) ((T_IS_IDENTICAL) reduce 11) ((T_IS_NOT_EQUAL) reduce 11) ((T_IS_NOT_IDENTICAL) reduce 11) ((T_IS_SMALLER_OR_EQUAL) reduce 11) ((T_LOGICAL_AND) reduce 11) ((T_LOGICAL_OR) reduce 11) ((T_LOGICAL_XOR) reduce 11) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 11) ((T_OBJECT_OPERATOR) reduce 11) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 11) ((T_POW) reduce 11) ((T_SL) reduce 11) ((T_SPACESHIP) reduce 11) ((T_SR) reduce 11) (("[") reduce 11) (("^") reduce 11) (("{") reduce 11) (("|") reduce 11)) 26555 ((("%") reduce 42) (("(") reduce 42) (("*") reduce 42) (("+") reduce 42) (("-") reduce 42) ((".") reduce 42) (("/") reduce 42) ((";") reduce 42) (("<") reduce 42) ((">") reduce 42) (("?") reduce 42) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 42) ((T_BOOLEAN_AND) reduce 42) ((T_BOOLEAN_OR) reduce 42) ((T_COALESCE) reduce 42) ((T_DOUBLE_ARROW) reduce 42) ((T_INSTANCEOF) reduce 42) ((T_IS_EQUAL) reduce 42) ((T_IS_GREATER_OR_EQUAL) reduce 42) ((T_IS_IDENTICAL) reduce 42) ((T_IS_NOT_EQUAL) reduce 42) ((T_IS_NOT_IDENTICAL) reduce 42) ((T_IS_SMALLER_OR_EQUAL) reduce 42) ((T_LOGICAL_AND) reduce 42) ((T_LOGICAL_OR) reduce 42) ((T_LOGICAL_XOR) reduce 42) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 42) ((T_OBJECT_OPERATOR) reduce 42) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 42) ((T_POW) reduce 42) ((T_SL) reduce 42) ((T_SPACESHIP) reduce 42) ((T_SR) reduce 42) (("[") reduce 42) (("^") reduce 42) (("{") reduce 42) (("|") reduce 42)) 26556 ((("%") reduce 39) (("(") reduce 39) (("*") reduce 39) (("+") reduce 39) (("-") reduce 39) ((".") reduce 39) (("/") reduce 39) ((";") reduce 39) (("<") reduce 39) ((">") reduce 39) (("?") reduce 39) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 39) ((T_BOOLEAN_AND) reduce 39) ((T_BOOLEAN_OR) reduce 39) ((T_COALESCE) reduce 39) ((T_DOUBLE_ARROW) reduce 39) ((T_INSTANCEOF) reduce 39) ((T_IS_EQUAL) reduce 39) ((T_IS_GREATER_OR_EQUAL) reduce 39) ((T_IS_IDENTICAL) reduce 39) ((T_IS_NOT_EQUAL) reduce 39) ((T_IS_NOT_IDENTICAL) reduce 39) ((T_IS_SMALLER_OR_EQUAL) reduce 39) ((T_LOGICAL_AND) reduce 39) ((T_LOGICAL_OR) reduce 39) ((T_LOGICAL_XOR) reduce 39) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 39) ((T_OBJECT_OPERATOR) reduce 39) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 39) ((T_POW) reduce 39) ((T_SL) reduce 39) ((T_SPACESHIP) reduce 39) ((T_SR) reduce 39) (("[") reduce 39) (("^") reduce 39) (("{") reduce 39) (("|") reduce 39)) 26557 ((("%") reduce 25) (("(") reduce 25) (("*") reduce 25) (("+") reduce 25) (("-") reduce 25) ((".") reduce 25) (("/") reduce 25) ((";") reduce 25) (("<") reduce 25) ((">") reduce 25) (("?") reduce 25) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 25) ((T_BOOLEAN_AND) reduce 25) ((T_BOOLEAN_OR) reduce 25) ((T_COALESCE) reduce 25) ((T_DOUBLE_ARROW) reduce 25) ((T_INSTANCEOF) reduce 25) ((T_IS_EQUAL) reduce 25) ((T_IS_GREATER_OR_EQUAL) reduce 25) ((T_IS_IDENTICAL) reduce 25) ((T_IS_NOT_EQUAL) reduce 25) ((T_IS_NOT_IDENTICAL) reduce 25) ((T_IS_SMALLER_OR_EQUAL) reduce 25) ((T_LOGICAL_AND) reduce 25) ((T_LOGICAL_OR) reduce 25) ((T_LOGICAL_XOR) reduce 25) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 25) ((T_OBJECT_OPERATOR) reduce 25) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 25) ((T_POW) reduce 25) ((T_SL) reduce 25) ((T_SPACESHIP) reduce 25) ((T_SR) reduce 25) (("[") reduce 25) (("^") reduce 25) (("{") reduce 25) (("|") reduce 25)) 26558 ((("%") reduce 50) (("(") reduce 50) (("*") reduce 50) (("+") reduce 50) (("-") reduce 50) ((".") reduce 50) (("/") reduce 50) ((";") reduce 50) (("<") reduce 50) ((">") reduce 50) (("?") reduce 50) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 50) ((T_BOOLEAN_AND) reduce 50) ((T_BOOLEAN_OR) reduce 50) ((T_COALESCE) reduce 50) ((T_DOUBLE_ARROW) reduce 50) ((T_INSTANCEOF) reduce 50) ((T_IS_EQUAL) reduce 50) ((T_IS_GREATER_OR_EQUAL) reduce 50) ((T_IS_IDENTICAL) reduce 50) ((T_IS_NOT_EQUAL) reduce 50) ((T_IS_NOT_IDENTICAL) reduce 50) ((T_IS_SMALLER_OR_EQUAL) reduce 50) ((T_LOGICAL_AND) reduce 50) ((T_LOGICAL_OR) reduce 50) ((T_LOGICAL_XOR) reduce 50) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 50) ((T_OBJECT_OPERATOR) reduce 50) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 50) ((T_POW) reduce 50) ((T_SL) reduce 50) ((T_SPACESHIP) reduce 50) ((T_SR) reduce 50) (("[") reduce 50) (("^") reduce 50) (("{") reduce 50) (("|") reduce 50)) 26559 ((("%") reduce 66) (("(") reduce 66) (("*") reduce 66) (("+") reduce 66) (("-") reduce 66) ((".") reduce 66) (("/") reduce 66) ((";") reduce 66) (("<") reduce 66) ((">") reduce 66) (("?") reduce 66) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 66) ((T_BOOLEAN_AND) reduce 66) ((T_BOOLEAN_OR) reduce 66) ((T_COALESCE) reduce 66) ((T_DOUBLE_ARROW) reduce 66) ((T_INSTANCEOF) reduce 66) ((T_IS_EQUAL) reduce 66) ((T_IS_GREATER_OR_EQUAL) reduce 66) ((T_IS_IDENTICAL) reduce 66) ((T_IS_NOT_EQUAL) reduce 66) ((T_IS_NOT_IDENTICAL) reduce 66) ((T_IS_SMALLER_OR_EQUAL) reduce 66) ((T_LOGICAL_AND) reduce 66) ((T_LOGICAL_OR) reduce 66) ((T_LOGICAL_XOR) reduce 66) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 66) ((T_OBJECT_OPERATOR) reduce 66) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 66) ((T_POW) reduce 66) ((T_SL) reduce 66) ((T_SPACESHIP) reduce 66) ((T_SR) reduce 66) (("[") reduce 66) (("^") reduce 66) (("{") reduce 66) (("|") reduce 66)) 26560 ((("%") reduce 18) (("(") reduce 18) (("*") reduce 18) (("+") reduce 18) (("-") reduce 18) ((".") reduce 18) (("/") reduce 18) ((";") reduce 18) (("<") reduce 18) ((">") reduce 18) (("?") reduce 18) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 18) ((T_BOOLEAN_AND) reduce 18) ((T_BOOLEAN_OR) reduce 18) ((T_COALESCE) reduce 18) ((T_DOUBLE_ARROW) reduce 18) ((T_INSTANCEOF) reduce 18) ((T_IS_EQUAL) reduce 18) ((T_IS_GREATER_OR_EQUAL) reduce 18) ((T_IS_IDENTICAL) reduce 18) ((T_IS_NOT_EQUAL) reduce 18) ((T_IS_NOT_IDENTICAL) reduce 18) ((T_IS_SMALLER_OR_EQUAL) reduce 18) ((T_LOGICAL_AND) reduce 18) ((T_LOGICAL_OR) reduce 18) ((T_LOGICAL_XOR) reduce 18) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 18) ((T_OBJECT_OPERATOR) reduce 18) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 18) ((T_POW) reduce 18) ((T_SL) reduce 18) ((T_SPACESHIP) reduce 18) ((T_SR) reduce 18) (("[") reduce 18) (("^") reduce 18) (("{") reduce 18) (("|") reduce 18)) 26561 ((("%") reduce 17) (("(") reduce 17) (("*") reduce 17) (("+") reduce 17) (("-") reduce 17) ((".") reduce 17) (("/") reduce 17) ((";") reduce 17) (("<") reduce 17) ((">") reduce 17) (("?") reduce 17) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 17) ((T_BOOLEAN_AND) reduce 17) ((T_BOOLEAN_OR) reduce 17) ((T_COALESCE) reduce 17) ((T_DOUBLE_ARROW) reduce 17) ((T_INSTANCEOF) reduce 17) ((T_IS_EQUAL) reduce 17) ((T_IS_GREATER_OR_EQUAL) reduce 17) ((T_IS_IDENTICAL) reduce 17) ((T_IS_NOT_EQUAL) reduce 17) ((T_IS_NOT_IDENTICAL) reduce 17) ((T_IS_SMALLER_OR_EQUAL) reduce 17) ((T_LOGICAL_AND) reduce 17) ((T_LOGICAL_OR) reduce 17) ((T_LOGICAL_XOR) reduce 17) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 17) ((T_OBJECT_OPERATOR) reduce 17) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 17) ((T_POW) reduce 17) ((T_SL) reduce 17) ((T_SPACESHIP) reduce 17) ((T_SR) reduce 17) (("[") reduce 17) (("^") reduce 17) (("{") reduce 17) (("|") reduce 17)) 26562 ((("%") reduce 15) (("(") reduce 15) (("*") reduce 15) (("+") reduce 15) (("-") reduce 15) ((".") reduce 15) (("/") reduce 15) ((";") reduce 15) (("<") reduce 15) ((">") reduce 15) (("?") reduce 15) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 15) ((T_BOOLEAN_AND) reduce 15) ((T_BOOLEAN_OR) reduce 15) ((T_COALESCE) reduce 15) ((T_DOUBLE_ARROW) reduce 15) ((T_INSTANCEOF) reduce 15) ((T_IS_EQUAL) reduce 15) ((T_IS_GREATER_OR_EQUAL) reduce 15) ((T_IS_IDENTICAL) reduce 15) ((T_IS_NOT_EQUAL) reduce 15) ((T_IS_NOT_IDENTICAL) reduce 15) ((T_IS_SMALLER_OR_EQUAL) reduce 15) ((T_LOGICAL_AND) reduce 15) ((T_LOGICAL_OR) reduce 15) ((T_LOGICAL_XOR) reduce 15) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 15) ((T_OBJECT_OPERATOR) reduce 15) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 15) ((T_POW) reduce 15) ((T_SL) reduce 15) ((T_SPACESHIP) reduce 15) ((T_SR) reduce 15) (("[") reduce 15) (("^") reduce 15) (("{") reduce 15) (("|") reduce 15)) 26563 ((("%") reduce 14) (("(") reduce 14) (("*") reduce 14) (("+") reduce 14) (("-") reduce 14) ((".") reduce 14) (("/") reduce 14) ((";") reduce 14) (("<") reduce 14) ((">") reduce 14) (("?") reduce 14) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 14) ((T_BOOLEAN_AND) reduce 14) ((T_BOOLEAN_OR) reduce 14) ((T_COALESCE) reduce 14) ((T_DOUBLE_ARROW) reduce 14) ((T_INSTANCEOF) reduce 14) ((T_IS_EQUAL) reduce 14) ((T_IS_GREATER_OR_EQUAL) reduce 14) ((T_IS_IDENTICAL) reduce 14) ((T_IS_NOT_EQUAL) reduce 14) ((T_IS_NOT_IDENTICAL) reduce 14) ((T_IS_SMALLER_OR_EQUAL) reduce 14) ((T_LOGICAL_AND) reduce 14) ((T_LOGICAL_OR) reduce 14) ((T_LOGICAL_XOR) reduce 14) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 14) ((T_OBJECT_OPERATOR) reduce 14) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 14) ((T_POW) reduce 14) ((T_SL) reduce 14) ((T_SPACESHIP) reduce 14) ((T_SR) reduce 14) (("[") reduce 14) (("^") reduce 14) (("{") reduce 14) (("|") reduce 14)) 26564 ((("%") reduce 38) (("(") reduce 38) (("*") reduce 38) (("+") reduce 38) (("-") reduce 38) ((".") reduce 38) (("/") reduce 38) ((";") reduce 38) (("<") reduce 38) ((">") reduce 38) (("?") reduce 38) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 38) ((T_BOOLEAN_AND) reduce 38) ((T_BOOLEAN_OR) reduce 38) ((T_COALESCE) reduce 38) ((T_DOUBLE_ARROW) reduce 38) ((T_INSTANCEOF) reduce 38) ((T_IS_EQUAL) reduce 38) ((T_IS_GREATER_OR_EQUAL) reduce 38) ((T_IS_IDENTICAL) reduce 38) ((T_IS_NOT_EQUAL) reduce 38) ((T_IS_NOT_IDENTICAL) reduce 38) ((T_IS_SMALLER_OR_EQUAL) reduce 38) ((T_LOGICAL_AND) reduce 38) ((T_LOGICAL_OR) reduce 38) ((T_LOGICAL_XOR) reduce 38) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 38) ((T_OBJECT_OPERATOR) reduce 38) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 38) ((T_POW) reduce 38) ((T_SL) reduce 38) ((T_SPACESHIP) reduce 38) ((T_SR) reduce 38) (("[") reduce 38) (("^") reduce 38) (("{") reduce 38) (("|") reduce 38)) 26565 ((("%") reduce 26) (("(") reduce 26) (("*") reduce 26) (("+") reduce 26) (("-") reduce 26) ((".") reduce 26) (("/") reduce 26) ((";") reduce 26) (("<") reduce 26) ((">") reduce 26) (("?") reduce 26) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 26) ((T_BOOLEAN_AND) reduce 26) ((T_BOOLEAN_OR) reduce 26) ((T_COALESCE) reduce 26) ((T_DOUBLE_ARROW) reduce 26) ((T_INSTANCEOF) reduce 26) ((T_IS_EQUAL) reduce 26) ((T_IS_GREATER_OR_EQUAL) reduce 26) ((T_IS_IDENTICAL) reduce 26) ((T_IS_NOT_EQUAL) reduce 26) ((T_IS_NOT_IDENTICAL) reduce 26) ((T_IS_SMALLER_OR_EQUAL) reduce 26) ((T_LOGICAL_AND) reduce 26) ((T_LOGICAL_OR) reduce 26) ((T_LOGICAL_XOR) reduce 26) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 26) ((T_OBJECT_OPERATOR) reduce 26) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 26) ((T_POW) reduce 26) ((T_SL) reduce 26) ((T_SPACESHIP) reduce 26) ((T_SR) reduce 26) (("[") reduce 26) (("^") reduce 26) (("{") reduce 26) (("|") reduce 26)) 26566 ((("%") reduce 22) (("(") reduce 22) (("*") reduce 22) (("+") reduce 22) (("-") reduce 22) ((".") reduce 22) (("/") reduce 22) ((";") reduce 22) (("<") reduce 22) ((">") reduce 22) (("?") reduce 22) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 22) ((T_BOOLEAN_AND) reduce 22) ((T_BOOLEAN_OR) reduce 22) ((T_COALESCE) reduce 22) ((T_DOUBLE_ARROW) reduce 22) ((T_INSTANCEOF) reduce 22) ((T_IS_EQUAL) reduce 22) ((T_IS_GREATER_OR_EQUAL) reduce 22) ((T_IS_IDENTICAL) reduce 22) ((T_IS_NOT_EQUAL) reduce 22) ((T_IS_NOT_IDENTICAL) reduce 22) ((T_IS_SMALLER_OR_EQUAL) reduce 22) ((T_LOGICAL_AND) reduce 22) ((T_LOGICAL_OR) reduce 22) ((T_LOGICAL_XOR) reduce 22) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 22) ((T_OBJECT_OPERATOR) reduce 22) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 22) ((T_POW) reduce 22) ((T_SL) reduce 22) ((T_SPACESHIP) reduce 22) ((T_SR) reduce 22) (("[") reduce 22) (("^") reduce 22) (("{") reduce 22) (("|") reduce 22)) 26567 ((("%") reduce 24) (("(") reduce 24) (("*") reduce 24) (("+") reduce 24) (("-") reduce 24) ((".") reduce 24) (("/") reduce 24) ((";") reduce 24) (("<") reduce 24) ((">") reduce 24) (("?") reduce 24) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 24) ((T_BOOLEAN_AND) reduce 24) ((T_BOOLEAN_OR) reduce 24) ((T_COALESCE) reduce 24) ((T_DOUBLE_ARROW) reduce 24) ((T_INSTANCEOF) reduce 24) ((T_IS_EQUAL) reduce 24) ((T_IS_GREATER_OR_EQUAL) reduce 24) ((T_IS_IDENTICAL) reduce 24) ((T_IS_NOT_EQUAL) reduce 24) ((T_IS_NOT_IDENTICAL) reduce 24) ((T_IS_SMALLER_OR_EQUAL) reduce 24) ((T_LOGICAL_AND) reduce 24) ((T_LOGICAL_OR) reduce 24) ((T_LOGICAL_XOR) reduce 24) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 24) ((T_OBJECT_OPERATOR) reduce 24) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 24) ((T_POW) reduce 24) ((T_SL) reduce 24) ((T_SPACESHIP) reduce 24) ((T_SR) reduce 24) (("[") reduce 24) (("^") reduce 24) (("{") reduce 24) (("|") reduce 24)) 26568 ((("%") reduce 16) (("(") reduce 16) (("*") reduce 16) (("+") reduce 16) (("-") reduce 16) ((".") reduce 16) (("/") reduce 16) ((";") reduce 16) (("<") reduce 16) ((">") reduce 16) (("?") reduce 16) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 16) ((T_BOOLEAN_AND) reduce 16) ((T_BOOLEAN_OR) reduce 16) ((T_COALESCE) reduce 16) ((T_DOUBLE_ARROW) reduce 16) ((T_INSTANCEOF) reduce 16) ((T_IS_EQUAL) reduce 16) ((T_IS_GREATER_OR_EQUAL) reduce 16) ((T_IS_IDENTICAL) reduce 16) ((T_IS_NOT_EQUAL) reduce 16) ((T_IS_NOT_IDENTICAL) reduce 16) ((T_IS_SMALLER_OR_EQUAL) reduce 16) ((T_LOGICAL_AND) reduce 16) ((T_LOGICAL_OR) reduce 16) ((T_LOGICAL_XOR) reduce 16) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 16) ((T_OBJECT_OPERATOR) reduce 16) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 16) ((T_POW) reduce 16) ((T_SL) reduce 16) ((T_SPACESHIP) reduce 16) ((T_SR) reduce 16) (("[") reduce 16) (("^") reduce 16) (("{") reduce 16) (("|") reduce 16)) 26569 ((("%") reduce 48) (("(") reduce 48) (("*") reduce 48) (("+") reduce 48) (("-") reduce 48) ((".") reduce 48) (("/") reduce 48) ((";") reduce 48) (("<") reduce 48) ((">") reduce 48) (("?") reduce 48) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 48) ((T_BOOLEAN_AND) reduce 48) ((T_BOOLEAN_OR) reduce 48) ((T_COALESCE) reduce 48) ((T_DOUBLE_ARROW) reduce 48) ((T_INSTANCEOF) reduce 48) ((T_IS_EQUAL) reduce 48) ((T_IS_GREATER_OR_EQUAL) reduce 48) ((T_IS_IDENTICAL) reduce 48) ((T_IS_NOT_EQUAL) reduce 48) ((T_IS_NOT_IDENTICAL) reduce 48) ((T_IS_SMALLER_OR_EQUAL) reduce 48) ((T_LOGICAL_AND) reduce 48) ((T_LOGICAL_OR) reduce 48) ((T_LOGICAL_XOR) reduce 48) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 48) ((T_OBJECT_OPERATOR) reduce 48) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 48) ((T_POW) reduce 48) ((T_SL) reduce 48) ((T_SPACESHIP) reduce 48) ((T_SR) reduce 48) (("[") reduce 48) (("^") reduce 48) (("{") reduce 48) (("|") reduce 48)) 26570 ((("%") reduce 20) (("(") reduce 20) (("*") reduce 20) (("+") reduce 20) (("-") reduce 20) ((".") reduce 20) (("/") reduce 20) ((";") reduce 20) (("<") reduce 20) ((">") reduce 20) (("?") reduce 20) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 20) ((T_BOOLEAN_AND) reduce 20) ((T_BOOLEAN_OR) reduce 20) ((T_COALESCE) reduce 20) ((T_DOUBLE_ARROW) reduce 20) ((T_INSTANCEOF) reduce 20) ((T_IS_EQUAL) reduce 20) ((T_IS_GREATER_OR_EQUAL) reduce 20) ((T_IS_IDENTICAL) reduce 20) ((T_IS_NOT_EQUAL) reduce 20) ((T_IS_NOT_IDENTICAL) reduce 20) ((T_IS_SMALLER_OR_EQUAL) reduce 20) ((T_LOGICAL_AND) reduce 20) ((T_LOGICAL_OR) reduce 20) ((T_LOGICAL_XOR) reduce 20) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 20) ((T_OBJECT_OPERATOR) reduce 20) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 20) ((T_POW) reduce 20) ((T_SL) reduce 20) ((T_SPACESHIP) reduce 20) ((T_SR) reduce 20) (("[") reduce 20) (("^") reduce 20) (("{") reduce 20) (("|") reduce 20)) 26571 ((("%") reduce 70) (("(") reduce 70) (("*") reduce 70) (("+") reduce 70) (("-") reduce 70) ((".") reduce 70) (("/") reduce 70) ((";") reduce 70) (("<") reduce 70) ((">") reduce 70) (("?") reduce 70) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 70) ((T_BOOLEAN_AND) reduce 70) ((T_BOOLEAN_OR) reduce 70) ((T_COALESCE) reduce 70) ((T_DOUBLE_ARROW) reduce 70) ((T_INSTANCEOF) reduce 70) ((T_IS_EQUAL) reduce 70) ((T_IS_GREATER_OR_EQUAL) reduce 70) ((T_IS_IDENTICAL) reduce 70) ((T_IS_NOT_EQUAL) reduce 70) ((T_IS_NOT_IDENTICAL) reduce 70) ((T_IS_SMALLER_OR_EQUAL) reduce 70) ((T_LOGICAL_AND) reduce 70) ((T_LOGICAL_OR) reduce 70) ((T_LOGICAL_XOR) reduce 70) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 70) ((T_OBJECT_OPERATOR) reduce 70) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 70) ((T_POW) reduce 70) ((T_SL) reduce 70) ((T_SPACESHIP) reduce 70) ((T_SR) reduce 70) (("[") reduce 70) (("^") reduce 70) (("{") reduce 70) (("|") reduce 70)) 26572 ((("%") reduce 3) (("(") reduce 3) (("*") reduce 3) (("+") reduce 3) (("-") reduce 3) ((".") reduce 3) (("/") reduce 3) ((";") reduce 3) (("<") reduce 3) ((">") reduce 3) (("?") reduce 3) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 3) ((T_BOOLEAN_AND) reduce 3) ((T_BOOLEAN_OR) reduce 3) ((T_COALESCE) reduce 3) ((T_DOUBLE_ARROW) reduce 3) ((T_INSTANCEOF) reduce 3) ((T_IS_EQUAL) reduce 3) ((T_IS_GREATER_OR_EQUAL) reduce 3) ((T_IS_IDENTICAL) reduce 3) ((T_IS_NOT_EQUAL) reduce 3) ((T_IS_NOT_IDENTICAL) reduce 3) ((T_IS_SMALLER_OR_EQUAL) reduce 3) ((T_LOGICAL_AND) reduce 3) ((T_LOGICAL_OR) reduce 3) ((T_LOGICAL_XOR) reduce 3) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 3) ((T_OBJECT_OPERATOR) reduce 3) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 3) ((T_POW) reduce 3) ((T_SL) reduce 3) ((T_SPACESHIP) reduce 3) ((T_SR) reduce 3) (("[") reduce 3) (("^") reduce 3) (("{") reduce 3) (("|") reduce 3)) 26573 ((("%") reduce 12) (("(") reduce 12) (("*") reduce 12) (("+") reduce 12) (("-") reduce 12) ((".") reduce 12) (("/") reduce 12) ((";") reduce 12) (("<") reduce 12) ((">") reduce 12) (("?") reduce 12) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 12) ((T_BOOLEAN_AND) reduce 12) ((T_BOOLEAN_OR) reduce 12) ((T_COALESCE) reduce 12) ((T_DOUBLE_ARROW) reduce 12) ((T_INSTANCEOF) reduce 12) ((T_IS_EQUAL) reduce 12) ((T_IS_GREATER_OR_EQUAL) reduce 12) ((T_IS_IDENTICAL) reduce 12) ((T_IS_NOT_EQUAL) reduce 12) ((T_IS_NOT_IDENTICAL) reduce 12) ((T_IS_SMALLER_OR_EQUAL) reduce 12) ((T_LOGICAL_AND) reduce 12) ((T_LOGICAL_OR) reduce 12) ((T_LOGICAL_XOR) reduce 12) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 12) ((T_OBJECT_OPERATOR) reduce 12) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 12) ((T_POW) reduce 12) ((T_SL) reduce 12) ((T_SPACESHIP) reduce 12) ((T_SR) reduce 12) (("[") reduce 12) (("^") reduce 12) (("{") reduce 12) (("|") reduce 12)) 26574 ((("%") reduce 54) (("(") reduce 54) (("*") reduce 54) (("+") reduce 54) (("-") reduce 54) ((".") reduce 54) (("/") reduce 54) ((";") reduce 54) (("<") reduce 54) ((">") reduce 54) (("?") reduce 54) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 54) ((T_BOOLEAN_AND) reduce 54) ((T_BOOLEAN_OR) reduce 54) ((T_COALESCE) reduce 54) ((T_DOUBLE_ARROW) reduce 54) ((T_INSTANCEOF) reduce 54) ((T_IS_EQUAL) reduce 54) ((T_IS_GREATER_OR_EQUAL) reduce 54) ((T_IS_IDENTICAL) reduce 54) ((T_IS_NOT_EQUAL) reduce 54) ((T_IS_NOT_IDENTICAL) reduce 54) ((T_IS_SMALLER_OR_EQUAL) reduce 54) ((T_LOGICAL_AND) reduce 54) ((T_LOGICAL_OR) reduce 54) ((T_LOGICAL_XOR) reduce 54) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 54) ((T_OBJECT_OPERATOR) reduce 54) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 54) ((T_POW) reduce 54) ((T_SL) reduce 54) ((T_SPACESHIP) reduce 54) ((T_SR) reduce 54) (("[") reduce 54) (("^") reduce 54) (("{") reduce 54) (("|") reduce 54)) 26575 ((("%") reduce 65) (("(") reduce 65) (("*") reduce 65) (("+") reduce 65) (("-") reduce 65) ((".") reduce 65) (("/") reduce 65) ((";") reduce 65) (("<") reduce 65) ((">") reduce 65) (("?") reduce 65) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 65) ((T_BOOLEAN_AND) reduce 65) ((T_BOOLEAN_OR) reduce 65) ((T_COALESCE) reduce 65) ((T_DOUBLE_ARROW) reduce 65) ((T_INSTANCEOF) reduce 65) ((T_IS_EQUAL) reduce 65) ((T_IS_GREATER_OR_EQUAL) reduce 65) ((T_IS_IDENTICAL) reduce 65) ((T_IS_NOT_EQUAL) reduce 65) ((T_IS_NOT_IDENTICAL) reduce 65) ((T_IS_SMALLER_OR_EQUAL) reduce 65) ((T_LOGICAL_AND) reduce 65) ((T_LOGICAL_OR) reduce 65) ((T_LOGICAL_XOR) reduce 65) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 65) ((T_OBJECT_OPERATOR) reduce 65) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 65) ((T_POW) reduce 65) ((T_SL) reduce 65) ((T_SPACESHIP) reduce 65) ((T_SR) reduce 65) (("[") reduce 65) (("^") reduce 65) (("{") reduce 65) (("|") reduce 65)) 26576 ((("%") reduce 74) (("(") reduce 74) (("*") reduce 74) (("+") reduce 74) (("-") reduce 74) ((".") reduce 74) (("/") reduce 74) ((";") reduce 74) (("<") reduce 74) ((">") reduce 74) (("?") reduce 74) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 74) ((T_BOOLEAN_AND) reduce 74) ((T_BOOLEAN_OR) reduce 74) ((T_COALESCE) reduce 74) ((T_DOUBLE_ARROW) reduce 74) ((T_INSTANCEOF) reduce 74) ((T_IS_EQUAL) reduce 74) ((T_IS_GREATER_OR_EQUAL) reduce 74) ((T_IS_IDENTICAL) reduce 74) ((T_IS_NOT_EQUAL) reduce 74) ((T_IS_NOT_IDENTICAL) reduce 74) ((T_IS_SMALLER_OR_EQUAL) reduce 74) ((T_LOGICAL_AND) reduce 74) ((T_LOGICAL_OR) reduce 74) ((T_LOGICAL_XOR) reduce 74) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 74) ((T_OBJECT_OPERATOR) reduce 74) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 74) ((T_POW) reduce 74) ((T_SL) reduce 74) ((T_SPACESHIP) reduce 74) ((T_SR) reduce 74) (("[") reduce 74) (("^") reduce 74) (("{") reduce 74) (("|") reduce 74)) 26577 ((("%") reduce 30) (("(") reduce 30) (("*") reduce 30) (("+") reduce 30) (("-") reduce 30) ((".") reduce 30) (("/") reduce 30) ((";") reduce 30) (("<") reduce 30) ((">") reduce 30) (("?") reduce 30) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 30) ((T_BOOLEAN_AND) reduce 30) ((T_BOOLEAN_OR) reduce 30) ((T_COALESCE) reduce 30) ((T_DOUBLE_ARROW) reduce 30) ((T_INSTANCEOF) reduce 30) ((T_IS_EQUAL) reduce 30) ((T_IS_GREATER_OR_EQUAL) reduce 30) ((T_IS_IDENTICAL) reduce 30) ((T_IS_NOT_EQUAL) reduce 30) ((T_IS_NOT_IDENTICAL) reduce 30) ((T_IS_SMALLER_OR_EQUAL) reduce 30) ((T_LOGICAL_AND) reduce 30) ((T_LOGICAL_OR) reduce 30) ((T_LOGICAL_XOR) reduce 30) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 30) ((T_OBJECT_OPERATOR) reduce 30) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 30) ((T_POW) reduce 30) ((T_SL) reduce 30) ((T_SPACESHIP) reduce 30) ((T_SR) reduce 30) (("[") reduce 30) (("^") reduce 30) (("{") reduce 30) (("|") reduce 30)) 26578 ((("%") reduce 68) (("(") reduce 68) (("*") reduce 68) (("+") reduce 68) (("-") reduce 68) ((".") reduce 68) (("/") reduce 68) ((";") reduce 68) (("<") reduce 68) ((">") reduce 68) (("?") reduce 68) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 68) ((T_BOOLEAN_AND) reduce 68) ((T_BOOLEAN_OR) reduce 68) ((T_COALESCE) reduce 68) ((T_DOUBLE_ARROW) reduce 68) ((T_INSTANCEOF) reduce 68) ((T_IS_EQUAL) reduce 68) ((T_IS_GREATER_OR_EQUAL) reduce 68) ((T_IS_IDENTICAL) reduce 68) ((T_IS_NOT_EQUAL) reduce 68) ((T_IS_NOT_IDENTICAL) reduce 68) ((T_IS_SMALLER_OR_EQUAL) reduce 68) ((T_LOGICAL_AND) reduce 68) ((T_LOGICAL_OR) reduce 68) ((T_LOGICAL_XOR) reduce 68) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 68) ((T_OBJECT_OPERATOR) reduce 68) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 68) ((T_POW) reduce 68) ((T_SL) reduce 68) ((T_SPACESHIP) reduce 68) ((T_SR) reduce 68) (("[") reduce 68) (("^") reduce 68) (("{") reduce 68) (("|") reduce 68)) 26579 ((("%") reduce 21) (("(") reduce 21) (("*") reduce 21) (("+") reduce 21) (("-") reduce 21) ((".") reduce 21) (("/") reduce 21) ((";") reduce 21) (("<") reduce 21) ((">") reduce 21) (("?") reduce 21) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 21) ((T_BOOLEAN_AND) reduce 21) ((T_BOOLEAN_OR) reduce 21) ((T_COALESCE) reduce 21) ((T_DOUBLE_ARROW) reduce 21) ((T_INSTANCEOF) reduce 21) ((T_IS_EQUAL) reduce 21) ((T_IS_GREATER_OR_EQUAL) reduce 21) ((T_IS_IDENTICAL) reduce 21) ((T_IS_NOT_EQUAL) reduce 21) ((T_IS_NOT_IDENTICAL) reduce 21) ((T_IS_SMALLER_OR_EQUAL) reduce 21) ((T_LOGICAL_AND) reduce 21) ((T_LOGICAL_OR) reduce 21) ((T_LOGICAL_XOR) reduce 21) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 21) ((T_OBJECT_OPERATOR) reduce 21) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 21) ((T_POW) reduce 21) ((T_SL) reduce 21) ((T_SPACESHIP) reduce 21) ((T_SR) reduce 21) (("[") reduce 21) (("^") reduce 21) (("{") reduce 21) (("|") reduce 21)) 26580 ((("%") reduce 23) (("(") reduce 23) (("*") reduce 23) (("+") reduce 23) (("-") reduce 23) ((".") reduce 23) (("/") reduce 23) ((";") reduce 23) (("<") reduce 23) ((">") reduce 23) (("?") reduce 23) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 23) ((T_BOOLEAN_AND) reduce 23) ((T_BOOLEAN_OR) reduce 23) ((T_COALESCE) reduce 23) ((T_DOUBLE_ARROW) reduce 23) ((T_INSTANCEOF) reduce 23) ((T_IS_EQUAL) reduce 23) ((T_IS_GREATER_OR_EQUAL) reduce 23) ((T_IS_IDENTICAL) reduce 23) ((T_IS_NOT_EQUAL) reduce 23) ((T_IS_NOT_IDENTICAL) reduce 23) ((T_IS_SMALLER_OR_EQUAL) reduce 23) ((T_LOGICAL_AND) reduce 23) ((T_LOGICAL_OR) reduce 23) ((T_LOGICAL_XOR) reduce 23) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 23) ((T_OBJECT_OPERATOR) reduce 23) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 23) ((T_POW) reduce 23) ((T_SL) reduce 23) ((T_SPACESHIP) reduce 23) ((T_SR) reduce 23) (("[") reduce 23) (("^") reduce 23) (("{") reduce 23) (("|") reduce 23)) 26581 ((("%") reduce 41) (("(") reduce 41) (("*") reduce 41) (("+") reduce 41) (("-") reduce 41) ((".") reduce 41) (("/") reduce 41) ((";") reduce 41) (("<") reduce 41) ((">") reduce 41) (("?") reduce 41) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 41) ((T_BOOLEAN_AND) reduce 41) ((T_BOOLEAN_OR) reduce 41) ((T_COALESCE) reduce 41) ((T_DOUBLE_ARROW) reduce 41) ((T_INSTANCEOF) reduce 41) ((T_IS_EQUAL) reduce 41) ((T_IS_GREATER_OR_EQUAL) reduce 41) ((T_IS_IDENTICAL) reduce 41) ((T_IS_NOT_EQUAL) reduce 41) ((T_IS_NOT_IDENTICAL) reduce 41) ((T_IS_SMALLER_OR_EQUAL) reduce 41) ((T_LOGICAL_AND) reduce 41) ((T_LOGICAL_OR) reduce 41) ((T_LOGICAL_XOR) reduce 41) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 41) ((T_OBJECT_OPERATOR) reduce 41) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 41) ((T_POW) reduce 41) ((T_SL) reduce 41) ((T_SPACESHIP) reduce 41) ((T_SR) reduce 41) (("[") reduce 41) (("^") reduce 41) (("{") reduce 41) (("|") reduce 41)) 26582 ((("%") reduce 62) (("(") reduce 62) (("*") reduce 62) (("+") reduce 62) (("-") reduce 62) ((".") reduce 62) (("/") reduce 62) ((";") reduce 62) (("<") reduce 62) ((">") reduce 62) (("?") reduce 62) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 62) ((T_BOOLEAN_AND) reduce 62) ((T_BOOLEAN_OR) reduce 62) ((T_COALESCE) reduce 62) ((T_DOUBLE_ARROW) reduce 62) ((T_INSTANCEOF) reduce 62) ((T_IS_EQUAL) reduce 62) ((T_IS_GREATER_OR_EQUAL) reduce 62) ((T_IS_IDENTICAL) reduce 62) ((T_IS_NOT_EQUAL) reduce 62) ((T_IS_NOT_IDENTICAL) reduce 62) ((T_IS_SMALLER_OR_EQUAL) reduce 62) ((T_LOGICAL_AND) reduce 62) ((T_LOGICAL_OR) reduce 62) ((T_LOGICAL_XOR) reduce 62) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 62) ((T_OBJECT_OPERATOR) reduce 62) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 62) ((T_POW) reduce 62) ((T_SL) reduce 62) ((T_SPACESHIP) reduce 62) ((T_SR) reduce 62) (("[") reduce 62) (("^") reduce 62) (("{") reduce 62) (("|") reduce 62)) 26583 ((("%") reduce 34) (("(") reduce 34) (("*") reduce 34) (("+") reduce 34) (("-") reduce 34) ((".") reduce 34) (("/") reduce 34) ((";") reduce 34) (("<") reduce 34) ((">") reduce 34) (("?") reduce 34) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 34) ((T_BOOLEAN_AND) reduce 34) ((T_BOOLEAN_OR) reduce 34) ((T_COALESCE) reduce 34) ((T_DOUBLE_ARROW) reduce 34) ((T_INSTANCEOF) reduce 34) ((T_IS_EQUAL) reduce 34) ((T_IS_GREATER_OR_EQUAL) reduce 34) ((T_IS_IDENTICAL) reduce 34) ((T_IS_NOT_EQUAL) reduce 34) ((T_IS_NOT_IDENTICAL) reduce 34) ((T_IS_SMALLER_OR_EQUAL) reduce 34) ((T_LOGICAL_AND) reduce 34) ((T_LOGICAL_OR) reduce 34) ((T_LOGICAL_XOR) reduce 34) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 34) ((T_OBJECT_OPERATOR) reduce 34) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 34) ((T_POW) reduce 34) ((T_SL) reduce 34) ((T_SPACESHIP) reduce 34) ((T_SR) reduce 34) (("[") reduce 34) (("^") reduce 34) (("{") reduce 34) (("|") reduce 34)) 26584 ((("%") reduce 40) (("(") reduce 40) (("*") reduce 40) (("+") reduce 40) (("-") reduce 40) ((".") reduce 40) (("/") reduce 40) ((";") reduce 40) (("<") reduce 40) ((">") reduce 40) (("?") reduce 40) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 40) ((T_BOOLEAN_AND) reduce 40) ((T_BOOLEAN_OR) reduce 40) ((T_COALESCE) reduce 40) ((T_DOUBLE_ARROW) reduce 40) ((T_INSTANCEOF) reduce 40) ((T_IS_EQUAL) reduce 40) ((T_IS_GREATER_OR_EQUAL) reduce 40) ((T_IS_IDENTICAL) reduce 40) ((T_IS_NOT_EQUAL) reduce 40) ((T_IS_NOT_IDENTICAL) reduce 40) ((T_IS_SMALLER_OR_EQUAL) reduce 40) ((T_LOGICAL_AND) reduce 40) ((T_LOGICAL_OR) reduce 40) ((T_LOGICAL_XOR) reduce 40) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 40) ((T_OBJECT_OPERATOR) reduce 40) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 40) ((T_POW) reduce 40) ((T_SL) reduce 40) ((T_SPACESHIP) reduce 40) ((T_SR) reduce 40) (("[") reduce 40) (("^") reduce 40) (("{") reduce 40) (("|") reduce 40)) 26585 ((("%") reduce 13) (("(") reduce 13) (("*") reduce 13) (("+") reduce 13) (("-") reduce 13) ((".") reduce 13) (("/") reduce 13) ((";") reduce 13) (("<") reduce 13) ((">") reduce 13) (("?") reduce 13) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 13) ((T_BOOLEAN_AND) reduce 13) ((T_BOOLEAN_OR) reduce 13) ((T_COALESCE) reduce 13) ((T_DOUBLE_ARROW) reduce 13) ((T_INSTANCEOF) reduce 13) ((T_IS_EQUAL) reduce 13) ((T_IS_GREATER_OR_EQUAL) reduce 13) ((T_IS_IDENTICAL) reduce 13) ((T_IS_NOT_EQUAL) reduce 13) ((T_IS_NOT_IDENTICAL) reduce 13) ((T_IS_SMALLER_OR_EQUAL) reduce 13) ((T_LOGICAL_AND) reduce 13) ((T_LOGICAL_OR) reduce 13) ((T_LOGICAL_XOR) reduce 13) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 13) ((T_OBJECT_OPERATOR) reduce 13) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 13) ((T_POW) reduce 13) ((T_SL) reduce 13) ((T_SPACESHIP) reduce 13) ((T_SR) reduce 13) (("[") reduce 13) (("^") reduce 13) (("{") reduce 13) (("|") reduce 13)) 26586 ((("%") reduce 55) (("(") reduce 55) (("*") reduce 55) (("+") reduce 55) (("-") reduce 55) ((".") reduce 55) (("/") reduce 55) ((";") reduce 55) (("<") reduce 55) ((">") reduce 55) (("?") reduce 55) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 55) ((T_BOOLEAN_AND) reduce 55) ((T_BOOLEAN_OR) reduce 55) ((T_COALESCE) reduce 55) ((T_DOUBLE_ARROW) reduce 55) ((T_INSTANCEOF) reduce 55) ((T_IS_EQUAL) reduce 55) ((T_IS_GREATER_OR_EQUAL) reduce 55) ((T_IS_IDENTICAL) reduce 55) ((T_IS_NOT_EQUAL) reduce 55) ((T_IS_NOT_IDENTICAL) reduce 55) ((T_IS_SMALLER_OR_EQUAL) reduce 55) ((T_LOGICAL_AND) reduce 55) ((T_LOGICAL_OR) reduce 55) ((T_LOGICAL_XOR) reduce 55) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 55) ((T_OBJECT_OPERATOR) reduce 55) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 55) ((T_POW) reduce 55) ((T_SL) reduce 55) ((T_SPACESHIP) reduce 55) ((T_SR) reduce 55) (("[") reduce 55) (("^") reduce 55) (("{") reduce 55) (("|") reduce 55)) 26587 ((("%") reduce 1) (("(") reduce 1) (("*") reduce 1) (("+") reduce 1) (("-") reduce 1) ((".") reduce 1) (("/") reduce 1) ((";") reduce 1) (("<") reduce 1) ((">") reduce 1) (("?") reduce 1) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 1) ((T_BOOLEAN_AND) reduce 1) ((T_BOOLEAN_OR) reduce 1) ((T_COALESCE) reduce 1) ((T_DOUBLE_ARROW) reduce 1) ((T_INSTANCEOF) reduce 1) ((T_IS_EQUAL) reduce 1) ((T_IS_GREATER_OR_EQUAL) reduce 1) ((T_IS_IDENTICAL) reduce 1) ((T_IS_NOT_EQUAL) reduce 1) ((T_IS_NOT_IDENTICAL) reduce 1) ((T_IS_SMALLER_OR_EQUAL) reduce 1) ((T_LOGICAL_AND) reduce 1) ((T_LOGICAL_OR) reduce 1) ((T_LOGICAL_XOR) reduce 1) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 1) ((T_OBJECT_OPERATOR) reduce 1) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 1) ((T_POW) reduce 1) ((T_SL) reduce 1) ((T_SPACESHIP) reduce 1) ((T_SR) reduce 1) (("[") reduce 1) (("^") reduce 1) (("{") reduce 1) (("|") reduce 1)) 26588 ((("%") reduce 2) (("(") reduce 2) (("*") reduce 2) (("+") reduce 2) (("-") reduce 2) ((".") reduce 2) (("/") reduce 2) ((";") reduce 2) (("<") reduce 2) ((">") reduce 2) (("?") reduce 2) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 2) ((T_BOOLEAN_AND) reduce 2) ((T_BOOLEAN_OR) reduce 2) ((T_COALESCE) reduce 2) ((T_DOUBLE_ARROW) reduce 2) ((T_INSTANCEOF) reduce 2) ((T_IS_EQUAL) reduce 2) ((T_IS_GREATER_OR_EQUAL) reduce 2) ((T_IS_IDENTICAL) reduce 2) ((T_IS_NOT_EQUAL) reduce 2) ((T_IS_NOT_IDENTICAL) reduce 2) ((T_IS_SMALLER_OR_EQUAL) reduce 2) ((T_LOGICAL_AND) reduce 2) ((T_LOGICAL_OR) reduce 2) ((T_LOGICAL_XOR) reduce 2) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 2) ((T_OBJECT_OPERATOR) reduce 2) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 2) ((T_POW) reduce 2) ((T_SL) reduce 2) ((T_SPACESHIP) reduce 2) ((T_SR) reduce 2) (("[") reduce 2) (("^") reduce 2) (("{") reduce 2) (("|") reduce 2)) 26589 ((("%") reduce 9) (("(") reduce 9) (("*") reduce 9) (("+") reduce 9) (("-") reduce 9) ((".") reduce 9) (("/") reduce 9) ((";") reduce 9) (("<") reduce 9) ((">") reduce 9) (("?") reduce 9) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 9) ((T_BOOLEAN_AND) reduce 9) ((T_BOOLEAN_OR) reduce 9) ((T_COALESCE) reduce 9) ((T_DOUBLE_ARROW) reduce 9) ((T_INSTANCEOF) reduce 9) ((T_IS_EQUAL) reduce 9) ((T_IS_GREATER_OR_EQUAL) reduce 9) ((T_IS_IDENTICAL) reduce 9) ((T_IS_NOT_EQUAL) reduce 9) ((T_IS_NOT_IDENTICAL) reduce 9) ((T_IS_SMALLER_OR_EQUAL) reduce 9) ((T_LOGICAL_AND) reduce 9) ((T_LOGICAL_OR) reduce 9) ((T_LOGICAL_XOR) reduce 9) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 9) ((T_OBJECT_OPERATOR) reduce 9) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 9) ((T_POW) reduce 9) ((T_SL) reduce 9) ((T_SPACESHIP) reduce 9) ((T_SR) reduce 9) (("[") reduce 9) (("^") reduce 9) (("{") reduce 9) (("|") reduce 9)) 26590 ((("%") reduce 33) (("(") reduce 33) (("*") reduce 33) (("+") reduce 33) (("-") reduce 33) ((".") reduce 33) (("/") reduce 33) ((";") reduce 33) (("<") reduce 33) ((">") reduce 33) (("?") reduce 33) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 33) ((T_BOOLEAN_AND) reduce 33) ((T_BOOLEAN_OR) reduce 33) ((T_COALESCE) reduce 33) ((T_DOUBLE_ARROW) reduce 33) ((T_INSTANCEOF) reduce 33) ((T_IS_EQUAL) reduce 33) ((T_IS_GREATER_OR_EQUAL) reduce 33) ((T_IS_IDENTICAL) reduce 33) ((T_IS_NOT_EQUAL) reduce 33) ((T_IS_NOT_IDENTICAL) reduce 33) ((T_IS_SMALLER_OR_EQUAL) reduce 33) ((T_LOGICAL_AND) reduce 33) ((T_LOGICAL_OR) reduce 33) ((T_LOGICAL_XOR) reduce 33) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 33) ((T_OBJECT_OPERATOR) reduce 33) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 33) ((T_POW) reduce 33) ((T_SL) reduce 33) ((T_SPACESHIP) reduce 33) ((T_SR) reduce 33) (("[") reduce 33) (("^") reduce 33) (("{") reduce 33) (("|") reduce 33)) 26591 ((("%") reduce 58) (("(") reduce 58) (("*") reduce 58) (("+") reduce 58) (("-") reduce 58) ((".") reduce 58) (("/") reduce 58) ((";") reduce 58) (("<") reduce 58) ((">") reduce 58) (("?") reduce 58) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 58) ((T_BOOLEAN_AND) reduce 58) ((T_BOOLEAN_OR) reduce 58) ((T_COALESCE) reduce 58) ((T_DOUBLE_ARROW) reduce 58) ((T_INSTANCEOF) reduce 58) ((T_IS_EQUAL) reduce 58) ((T_IS_GREATER_OR_EQUAL) reduce 58) ((T_IS_IDENTICAL) reduce 58) ((T_IS_NOT_EQUAL) reduce 58) ((T_IS_NOT_IDENTICAL) reduce 58) ((T_IS_SMALLER_OR_EQUAL) reduce 58) ((T_LOGICAL_AND) reduce 58) ((T_LOGICAL_OR) reduce 58) ((T_LOGICAL_XOR) reduce 58) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 58) ((T_OBJECT_OPERATOR) reduce 58) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 58) ((T_POW) reduce 58) ((T_SL) reduce 58) ((T_SPACESHIP) reduce 58) ((T_SR) reduce 58) (("[") reduce 58) (("^") reduce 58) (("{") reduce 58) (("|") reduce 58)) 26592 ((("%") reduce 37) (("(") reduce 37) (("*") reduce 37) (("+") reduce 37) (("-") reduce 37) ((".") reduce 37) (("/") reduce 37) ((";") reduce 37) (("<") reduce 37) ((">") reduce 37) (("?") reduce 37) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 37) ((T_BOOLEAN_AND) reduce 37) ((T_BOOLEAN_OR) reduce 37) ((T_COALESCE) reduce 37) ((T_DOUBLE_ARROW) reduce 37) ((T_INSTANCEOF) reduce 37) ((T_IS_EQUAL) reduce 37) ((T_IS_GREATER_OR_EQUAL) reduce 37) ((T_IS_IDENTICAL) reduce 37) ((T_IS_NOT_EQUAL) reduce 37) ((T_IS_NOT_IDENTICAL) reduce 37) ((T_IS_SMALLER_OR_EQUAL) reduce 37) ((T_LOGICAL_AND) reduce 37) ((T_LOGICAL_OR) reduce 37) ((T_LOGICAL_XOR) reduce 37) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 37) ((T_OBJECT_OPERATOR) reduce 37) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 37) ((T_POW) reduce 37) ((T_SL) reduce 37) ((T_SPACESHIP) reduce 37) ((T_SR) reduce 37) (("[") reduce 37) (("^") reduce 37) (("{") reduce 37) (("|") reduce 37)) 26593 ((("%") reduce 64) (("(") reduce 64) (("*") reduce 64) (("+") reduce 64) (("-") reduce 64) ((".") reduce 64) (("/") reduce 64) ((";") reduce 64) (("<") reduce 64) ((">") reduce 64) (("?") reduce 64) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 64) ((T_BOOLEAN_AND) reduce 64) ((T_BOOLEAN_OR) reduce 64) ((T_COALESCE) reduce 64) ((T_DOUBLE_ARROW) reduce 64) ((T_INSTANCEOF) reduce 64) ((T_IS_EQUAL) reduce 64) ((T_IS_GREATER_OR_EQUAL) reduce 64) ((T_IS_IDENTICAL) reduce 64) ((T_IS_NOT_EQUAL) reduce 64) ((T_IS_NOT_IDENTICAL) reduce 64) ((T_IS_SMALLER_OR_EQUAL) reduce 64) ((T_LOGICAL_AND) reduce 64) ((T_LOGICAL_OR) reduce 64) ((T_LOGICAL_XOR) reduce 64) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 64) ((T_OBJECT_OPERATOR) reduce 64) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 64) ((T_POW) reduce 64) ((T_SL) reduce 64) ((T_SPACESHIP) reduce 64) ((T_SR) reduce 64) (("[") reduce 64) (("^") reduce 64) (("{") reduce 64) (("|") reduce 64)) 26594 ((("%") reduce 46) (("(") reduce 46) (("*") reduce 46) (("+") reduce 46) (("-") reduce 46) ((".") reduce 46) (("/") reduce 46) ((";") reduce 46) (("<") reduce 46) ((">") reduce 46) (("?") reduce 46) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 46) ((T_BOOLEAN_AND) reduce 46) ((T_BOOLEAN_OR) reduce 46) ((T_COALESCE) reduce 46) ((T_DOUBLE_ARROW) reduce 46) ((T_INSTANCEOF) reduce 46) ((T_IS_EQUAL) reduce 46) ((T_IS_GREATER_OR_EQUAL) reduce 46) ((T_IS_IDENTICAL) reduce 46) ((T_IS_NOT_EQUAL) reduce 46) ((T_IS_NOT_IDENTICAL) reduce 46) ((T_IS_SMALLER_OR_EQUAL) reduce 46) ((T_LOGICAL_AND) reduce 46) ((T_LOGICAL_OR) reduce 46) ((T_LOGICAL_XOR) reduce 46) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 46) ((T_OBJECT_OPERATOR) reduce 46) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 46) ((T_POW) reduce 46) ((T_SL) reduce 46) ((T_SPACESHIP) reduce 46) ((T_SR) reduce 46) (("[") reduce 46) (("^") reduce 46) (("{") reduce 46) (("|") reduce 46)) 26595 ((("%") reduce 8) (("(") reduce 8) (("*") reduce 8) (("+") reduce 8) (("-") reduce 8) ((".") reduce 8) (("/") reduce 8) ((";") reduce 8) (("<") reduce 8) ((">") reduce 8) (("?") reduce 8) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 8) ((T_BOOLEAN_AND) reduce 8) ((T_BOOLEAN_OR) reduce 8) ((T_COALESCE) reduce 8) ((T_DOUBLE_ARROW) reduce 8) ((T_INSTANCEOF) reduce 8) ((T_IS_EQUAL) reduce 8) ((T_IS_GREATER_OR_EQUAL) reduce 8) ((T_IS_IDENTICAL) reduce 8) ((T_IS_NOT_EQUAL) reduce 8) ((T_IS_NOT_IDENTICAL) reduce 8) ((T_IS_SMALLER_OR_EQUAL) reduce 8) ((T_LOGICAL_AND) reduce 8) ((T_LOGICAL_OR) reduce 8) ((T_LOGICAL_XOR) reduce 8) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 8) ((T_OBJECT_OPERATOR) reduce 8) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 8) ((T_POW) reduce 8) ((T_SL) reduce 8) ((T_SPACESHIP) reduce 8) ((T_SR) reduce 8) (("[") reduce 8) (("^") reduce 8) (("{") reduce 8) (("|") reduce 8)) 26596 ((("%") reduce 6) (("(") reduce 6) (("*") reduce 6) (("+") reduce 6) (("-") reduce 6) ((".") reduce 6) (("/") reduce 6) ((";") reduce 6) (("<") reduce 6) ((">") reduce 6) (("?") reduce 6) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 6) ((T_BOOLEAN_AND) reduce 6) ((T_BOOLEAN_OR) reduce 6) ((T_COALESCE) reduce 6) ((T_DOUBLE_ARROW) reduce 6) ((T_INSTANCEOF) reduce 6) ((T_IS_EQUAL) reduce 6) ((T_IS_GREATER_OR_EQUAL) reduce 6) ((T_IS_IDENTICAL) reduce 6) ((T_IS_NOT_EQUAL) reduce 6) ((T_IS_NOT_IDENTICAL) reduce 6) ((T_IS_SMALLER_OR_EQUAL) reduce 6) ((T_LOGICAL_AND) reduce 6) ((T_LOGICAL_OR) reduce 6) ((T_LOGICAL_XOR) reduce 6) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 6) ((T_OBJECT_OPERATOR) reduce 6) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 6) ((T_POW) reduce 6) ((T_SL) reduce 6) ((T_SPACESHIP) reduce 6) ((T_SR) reduce 6) (("[") reduce 6) (("^") reduce 6) (("{") reduce 6) (("|") reduce 6)) 26597 ((("%") reduce 7) (("(") reduce 7) (("*") reduce 7) (("+") reduce 7) (("-") reduce 7) ((".") reduce 7) (("/") reduce 7) ((";") reduce 7) (("<") reduce 7) ((">") reduce 7) (("?") reduce 7) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 7) ((T_BOOLEAN_AND) reduce 7) ((T_BOOLEAN_OR) reduce 7) ((T_COALESCE) reduce 7) ((T_DOUBLE_ARROW) reduce 7) ((T_INSTANCEOF) reduce 7) ((T_IS_EQUAL) reduce 7) ((T_IS_GREATER_OR_EQUAL) reduce 7) ((T_IS_IDENTICAL) reduce 7) ((T_IS_NOT_EQUAL) reduce 7) ((T_IS_NOT_IDENTICAL) reduce 7) ((T_IS_SMALLER_OR_EQUAL) reduce 7) ((T_LOGICAL_AND) reduce 7) ((T_LOGICAL_OR) reduce 7) ((T_LOGICAL_XOR) reduce 7) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 7) ((T_OBJECT_OPERATOR) reduce 7) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 7) ((T_POW) reduce 7) ((T_SL) reduce 7) ((T_SPACESHIP) reduce 7) ((T_SR) reduce 7) (("[") reduce 7) (("^") reduce 7) (("{") reduce 7) (("|") reduce 7)) 26598 ((("%") reduce 69) (("(") reduce 69) (("*") reduce 69) (("+") reduce 69) (("-") reduce 69) ((".") reduce 69) (("/") reduce 69) ((";") reduce 69) (("<") reduce 69) ((">") reduce 69) (("?") reduce 69) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 69) ((T_BOOLEAN_AND) reduce 69) ((T_BOOLEAN_OR) reduce 69) ((T_COALESCE) reduce 69) ((T_DOUBLE_ARROW) reduce 69) ((T_INSTANCEOF) reduce 69) ((T_IS_EQUAL) reduce 69) ((T_IS_GREATER_OR_EQUAL) reduce 69) ((T_IS_IDENTICAL) reduce 69) ((T_IS_NOT_EQUAL) reduce 69) ((T_IS_NOT_IDENTICAL) reduce 69) ((T_IS_SMALLER_OR_EQUAL) reduce 69) ((T_LOGICAL_AND) reduce 69) ((T_LOGICAL_OR) reduce 69) ((T_LOGICAL_XOR) reduce 69) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 69) ((T_OBJECT_OPERATOR) reduce 69) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 69) ((T_POW) reduce 69) ((T_SL) reduce 69) ((T_SPACESHIP) reduce 69) ((T_SR) reduce 69) (("[") reduce 69) (("^") reduce 69) (("{") reduce 69) (("|") reduce 69)) 26599 ((("%") reduce 63) (("(") reduce 63) (("*") reduce 63) (("+") reduce 63) (("-") reduce 63) ((".") reduce 63) (("/") reduce 63) ((";") reduce 63) (("<") reduce 63) ((">") reduce 63) (("?") reduce 63) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 63) ((T_BOOLEAN_AND) reduce 63) ((T_BOOLEAN_OR) reduce 63) ((T_COALESCE) reduce 63) ((T_DOUBLE_ARROW) reduce 63) ((T_INSTANCEOF) reduce 63) ((T_IS_EQUAL) reduce 63) ((T_IS_GREATER_OR_EQUAL) reduce 63) ((T_IS_IDENTICAL) reduce 63) ((T_IS_NOT_EQUAL) reduce 63) ((T_IS_NOT_IDENTICAL) reduce 63) ((T_IS_SMALLER_OR_EQUAL) reduce 63) ((T_LOGICAL_AND) reduce 63) ((T_LOGICAL_OR) reduce 63) ((T_LOGICAL_XOR) reduce 63) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 63) ((T_OBJECT_OPERATOR) reduce 63) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 63) ((T_POW) reduce 63) ((T_SL) reduce 63) ((T_SPACESHIP) reduce 63) ((T_SR) reduce 63) (("[") reduce 63) (("^") reduce 63) (("{") reduce 63) (("|") reduce 63)) 26600 ((("%") reduce 56) (("(") reduce 56) (("*") reduce 56) (("+") reduce 56) (("-") reduce 56) ((".") reduce 56) (("/") reduce 56) ((";") reduce 56) (("<") reduce 56) ((">") reduce 56) (("?") reduce 56) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 56) ((T_BOOLEAN_AND) reduce 56) ((T_BOOLEAN_OR) reduce 56) ((T_COALESCE) reduce 56) ((T_DOUBLE_ARROW) reduce 56) ((T_INSTANCEOF) reduce 56) ((T_IS_EQUAL) reduce 56) ((T_IS_GREATER_OR_EQUAL) reduce 56) ((T_IS_IDENTICAL) reduce 56) ((T_IS_NOT_EQUAL) reduce 56) ((T_IS_NOT_IDENTICAL) reduce 56) ((T_IS_SMALLER_OR_EQUAL) reduce 56) ((T_LOGICAL_AND) reduce 56) ((T_LOGICAL_OR) reduce 56) ((T_LOGICAL_XOR) reduce 56) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 56) ((T_OBJECT_OPERATOR) reduce 56) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 56) ((T_POW) reduce 56) ((T_SL) reduce 56) ((T_SPACESHIP) reduce 56) ((T_SR) reduce 56) (("[") reduce 56) (("^") reduce 56) (("{") reduce 56) (("|") reduce 56)) 26601 ((("%") reduce 10) (("(") reduce 10) (("*") reduce 10) (("+") reduce 10) (("-") reduce 10) ((".") reduce 10) (("/") reduce 10) ((";") reduce 10) (("<") reduce 10) ((">") reduce 10) (("?") reduce 10) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 10) ((T_BOOLEAN_AND) reduce 10) ((T_BOOLEAN_OR) reduce 10) ((T_COALESCE) reduce 10) ((T_DOUBLE_ARROW) reduce 10) ((T_INSTANCEOF) reduce 10) ((T_IS_EQUAL) reduce 10) ((T_IS_GREATER_OR_EQUAL) reduce 10) ((T_IS_IDENTICAL) reduce 10) ((T_IS_NOT_EQUAL) reduce 10) ((T_IS_NOT_IDENTICAL) reduce 10) ((T_IS_SMALLER_OR_EQUAL) reduce 10) ((T_LOGICAL_AND) reduce 10) ((T_LOGICAL_OR) reduce 10) ((T_LOGICAL_XOR) reduce 10) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 10) ((T_OBJECT_OPERATOR) reduce 10) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 10) ((T_POW) reduce 10) ((T_SL) reduce 10) ((T_SPACESHIP) reduce 10) ((T_SR) reduce 10) (("[") reduce 10) (("^") reduce 10) (("{") reduce 10) (("|") reduce 10)) 26602 ((("%") reduce 67) (("(") reduce 67) (("*") reduce 67) (("+") reduce 67) (("-") reduce 67) ((".") reduce 67) (("/") reduce 67) ((";") reduce 67) (("<") reduce 67) ((">") reduce 67) (("?") reduce 67) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 67) ((T_BOOLEAN_AND) reduce 67) ((T_BOOLEAN_OR) reduce 67) ((T_COALESCE) reduce 67) ((T_DOUBLE_ARROW) reduce 67) ((T_INSTANCEOF) reduce 67) ((T_IS_EQUAL) reduce 67) ((T_IS_GREATER_OR_EQUAL) reduce 67) ((T_IS_IDENTICAL) reduce 67) ((T_IS_NOT_EQUAL) reduce 67) ((T_IS_NOT_IDENTICAL) reduce 67) ((T_IS_SMALLER_OR_EQUAL) reduce 67) ((T_LOGICAL_AND) reduce 67) ((T_LOGICAL_OR) reduce 67) ((T_LOGICAL_XOR) reduce 67) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 67) ((T_OBJECT_OPERATOR) reduce 67) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 67) ((T_POW) reduce 67) ((T_SL) reduce 67) ((T_SPACESHIP) reduce 67) ((T_SR) reduce 67) (("[") reduce 67) (("^") reduce 67) (("{") reduce 67) (("|") reduce 67)) 26603 ((("%") reduce 44) (("(") reduce 44) (("*") reduce 44) (("+") reduce 44) (("-") reduce 44) ((".") reduce 44) (("/") reduce 44) ((";") reduce 44) (("<") reduce 44) ((">") reduce 44) (("?") reduce 44) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 44) ((T_BOOLEAN_AND) reduce 44) ((T_BOOLEAN_OR) reduce 44) ((T_COALESCE) reduce 44) ((T_DOUBLE_ARROW) reduce 44) ((T_INSTANCEOF) reduce 44) ((T_IS_EQUAL) reduce 44) ((T_IS_GREATER_OR_EQUAL) reduce 44) ((T_IS_IDENTICAL) reduce 44) ((T_IS_NOT_EQUAL) reduce 44) ((T_IS_NOT_IDENTICAL) reduce 44) ((T_IS_SMALLER_OR_EQUAL) reduce 44) ((T_LOGICAL_AND) reduce 44) ((T_LOGICAL_OR) reduce 44) ((T_LOGICAL_XOR) reduce 44) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 44) ((T_OBJECT_OPERATOR) reduce 44) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 44) ((T_POW) reduce 44) ((T_SL) reduce 44) ((T_SPACESHIP) reduce 44) ((T_SR) reduce 44) (("[") reduce 44) (("^") reduce 44) (("{") reduce 44) (("|") reduce 44)) 26604 ((("%") reduce 75) (("(") reduce 75) (("*") reduce 75) (("+") reduce 75) (("-") reduce 75) ((".") reduce 75) (("/") reduce 75) ((";") reduce 75) (("<") reduce 75) ((">") reduce 75) (("?") reduce 75) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 75) ((T_BOOLEAN_AND) reduce 75) ((T_BOOLEAN_OR) reduce 75) ((T_COALESCE) reduce 75) ((T_DOUBLE_ARROW) reduce 75) ((T_INSTANCEOF) reduce 75) ((T_IS_EQUAL) reduce 75) ((T_IS_GREATER_OR_EQUAL) reduce 75) ((T_IS_IDENTICAL) reduce 75) ((T_IS_NOT_EQUAL) reduce 75) ((T_IS_NOT_IDENTICAL) reduce 75) ((T_IS_SMALLER_OR_EQUAL) reduce 75) ((T_LOGICAL_AND) reduce 75) ((T_LOGICAL_OR) reduce 75) ((T_LOGICAL_XOR) reduce 75) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 75) ((T_OBJECT_OPERATOR) reduce 75) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 75) ((T_POW) reduce 75) ((T_SL) reduce 75) ((T_SPACESHIP) reduce 75) ((T_SR) reduce 75) (("[") reduce 75) (("^") reduce 75) (("{") reduce 75) (("|") reduce 75)) 26605 ((("%") reduce 76) (("(") reduce 76) (("*") reduce 76) (("+") reduce 76) (("-") reduce 76) ((".") reduce 76) (("/") reduce 76) ((";") reduce 76) (("<") reduce 76) ((">") reduce 76) (("?") reduce 76) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 76) ((T_BOOLEAN_AND) reduce 76) ((T_BOOLEAN_OR) reduce 76) ((T_COALESCE) reduce 76) ((T_DOUBLE_ARROW) reduce 76) ((T_INSTANCEOF) reduce 76) ((T_IS_EQUAL) reduce 76) ((T_IS_GREATER_OR_EQUAL) reduce 76) ((T_IS_IDENTICAL) reduce 76) ((T_IS_NOT_EQUAL) reduce 76) ((T_IS_NOT_IDENTICAL) reduce 76) ((T_IS_SMALLER_OR_EQUAL) reduce 76) ((T_LOGICAL_AND) reduce 76) ((T_LOGICAL_OR) reduce 76) ((T_LOGICAL_XOR) reduce 76) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 76) ((T_OBJECT_OPERATOR) reduce 76) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 76) ((T_POW) reduce 76) ((T_SL) reduce 76) ((T_SPACESHIP) reduce 76) ((T_SR) reduce 76) (("[") reduce 76) (("^") reduce 76) (("{") reduce 76) (("|") reduce 76)) 26606 ((("%") reduce 77) (("(") reduce 77) (("*") reduce 77) (("+") reduce 77) (("-") reduce 77) ((".") reduce 77) (("/") reduce 77) ((";") reduce 77) (("<") reduce 77) ((">") reduce 77) (("?") reduce 77) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 77) ((T_BOOLEAN_AND) reduce 77) ((T_BOOLEAN_OR) reduce 77) ((T_COALESCE) reduce 77) ((T_DOUBLE_ARROW) reduce 77) ((T_INSTANCEOF) reduce 77) ((T_IS_EQUAL) reduce 77) ((T_IS_GREATER_OR_EQUAL) reduce 77) ((T_IS_IDENTICAL) reduce 77) ((T_IS_NOT_EQUAL) reduce 77) ((T_IS_NOT_IDENTICAL) reduce 77) ((T_IS_SMALLER_OR_EQUAL) reduce 77) ((T_LOGICAL_AND) reduce 77) ((T_LOGICAL_OR) reduce 77) ((T_LOGICAL_XOR) reduce 77) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 77) ((T_OBJECT_OPERATOR) reduce 77) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 77) ((T_POW) reduce 77) ((T_SL) reduce 77) ((T_SPACESHIP) reduce 77) ((T_SR) reduce 77) (("[") reduce 77) (("^") reduce 77) (("{") reduce 77) (("|") reduce 77)) 26607 ((("%") reduce 78) (("(") reduce 78) (("*") reduce 78) (("+") reduce 78) (("-") reduce 78) ((".") reduce 78) (("/") reduce 78) ((";") reduce 78) (("<") reduce 78) ((">") reduce 78) (("?") reduce 78) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 78) ((T_BOOLEAN_AND) reduce 78) ((T_BOOLEAN_OR) reduce 78) ((T_COALESCE) reduce 78) ((T_DOUBLE_ARROW) reduce 78) ((T_INSTANCEOF) reduce 78) ((T_IS_EQUAL) reduce 78) ((T_IS_GREATER_OR_EQUAL) reduce 78) ((T_IS_IDENTICAL) reduce 78) ((T_IS_NOT_EQUAL) reduce 78) ((T_IS_NOT_IDENTICAL) reduce 78) ((T_IS_SMALLER_OR_EQUAL) reduce 78) ((T_LOGICAL_AND) reduce 78) ((T_LOGICAL_OR) reduce 78) ((T_LOGICAL_XOR) reduce 78) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 78) ((T_OBJECT_OPERATOR) reduce 78) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 78) ((T_POW) reduce 78) ((T_SL) reduce 78) ((T_SPACESHIP) reduce 78) ((T_SR) reduce 78) (("[") reduce 78) (("^") reduce 78) (("{") reduce 78) (("|") reduce 78)) 26608 ((("%") reduce 4) (("(") reduce 4) (("*") reduce 4) (("+") reduce 4) (("-") reduce 4) ((".") reduce 4) (("/") reduce 4) ((";") reduce 4) (("<") reduce 4) ((">") reduce 4) (("?") reduce 4) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 4) ((T_BOOLEAN_AND) reduce 4) ((T_BOOLEAN_OR) reduce 4) ((T_COALESCE) reduce 4) ((T_DOUBLE_ARROW) reduce 4) ((T_INSTANCEOF) reduce 4) ((T_IS_EQUAL) reduce 4) ((T_IS_GREATER_OR_EQUAL) reduce 4) ((T_IS_IDENTICAL) reduce 4) ((T_IS_NOT_EQUAL) reduce 4) ((T_IS_NOT_IDENTICAL) reduce 4) ((T_IS_SMALLER_OR_EQUAL) reduce 4) ((T_LOGICAL_AND) reduce 4) ((T_LOGICAL_OR) reduce 4) ((T_LOGICAL_XOR) reduce 4) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 4) ((T_OBJECT_OPERATOR) reduce 4) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 4) ((T_POW) reduce 4) ((T_SL) reduce 4) ((T_SPACESHIP) reduce 4) ((T_SR) reduce 4) (("[") reduce 4) (("^") reduce 4) (("{") reduce 4) (("|") reduce 4)) 26609 ((("%") reduce 5) (("(") reduce 5) (("*") reduce 5) (("+") reduce 5) (("-") reduce 5) ((".") reduce 5) (("/") reduce 5) ((";") reduce 5) (("<") reduce 5) ((">") reduce 5) (("?") reduce 5) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 5) ((T_BOOLEAN_AND) reduce 5) ((T_BOOLEAN_OR) reduce 5) ((T_COALESCE) reduce 5) ((T_DOUBLE_ARROW) reduce 5) ((T_INSTANCEOF) reduce 5) ((T_IS_EQUAL) reduce 5) ((T_IS_GREATER_OR_EQUAL) reduce 5) ((T_IS_IDENTICAL) reduce 5) ((T_IS_NOT_EQUAL) reduce 5) ((T_IS_NOT_IDENTICAL) reduce 5) ((T_IS_SMALLER_OR_EQUAL) reduce 5) ((T_LOGICAL_AND) reduce 5) ((T_LOGICAL_OR) reduce 5) ((T_LOGICAL_XOR) reduce 5) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 5) ((T_OBJECT_OPERATOR) reduce 5) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 5) ((T_POW) reduce 5) ((T_SL) reduce 5) ((T_SPACESHIP) reduce 5) ((T_SR) reduce 5) (("[") reduce 5) (("^") reduce 5) (("{") reduce 5) (("|") reduce 5)) 26610 ((("%") reduce 43) (("(") reduce 43) (("*") reduce 43) (("+") reduce 43) (("-") reduce 43) ((".") reduce 43) (("/") reduce 43) ((";") reduce 43) (("<") reduce 43) ((">") reduce 43) (("?") reduce 43) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 43) ((T_BOOLEAN_AND) reduce 43) ((T_BOOLEAN_OR) reduce 43) ((T_COALESCE) reduce 43) ((T_DOUBLE_ARROW) reduce 43) ((T_INSTANCEOF) reduce 43) ((T_IS_EQUAL) reduce 43) ((T_IS_GREATER_OR_EQUAL) reduce 43) ((T_IS_IDENTICAL) reduce 43) ((T_IS_NOT_EQUAL) reduce 43) ((T_IS_NOT_IDENTICAL) reduce 43) ((T_IS_SMALLER_OR_EQUAL) reduce 43) ((T_LOGICAL_AND) reduce 43) ((T_LOGICAL_OR) reduce 43) ((T_LOGICAL_XOR) reduce 43) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 43) ((T_OBJECT_OPERATOR) reduce 43) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 43) ((T_POW) reduce 43) ((T_SL) reduce 43) ((T_SPACESHIP) reduce 43) ((T_SR) reduce 43) (("[") reduce 43) (("^") reduce 43) (("{") reduce 43) (("|") reduce 43)) 26611 ((("%") reduce 72) (("(") reduce 72) (("*") reduce 72) (("+") reduce 72) (("-") reduce 72) ((".") reduce 72) (("/") reduce 72) ((";") reduce 72) (("<") reduce 72) ((">") reduce 72) (("?") reduce 72) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 72) ((T_BOOLEAN_AND) reduce 72) ((T_BOOLEAN_OR) reduce 72) ((T_COALESCE) reduce 72) ((T_DOUBLE_ARROW) reduce 72) ((T_INSTANCEOF) reduce 72) ((T_IS_EQUAL) reduce 72) ((T_IS_GREATER_OR_EQUAL) reduce 72) ((T_IS_IDENTICAL) reduce 72) ((T_IS_NOT_EQUAL) reduce 72) ((T_IS_NOT_IDENTICAL) reduce 72) ((T_IS_SMALLER_OR_EQUAL) reduce 72) ((T_LOGICAL_AND) reduce 72) ((T_LOGICAL_OR) reduce 72) ((T_LOGICAL_XOR) reduce 72) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 72) ((T_OBJECT_OPERATOR) reduce 72) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 72) ((T_POW) reduce 72) ((T_SL) reduce 72) ((T_SPACESHIP) reduce 72) ((T_SR) reduce 72) (("[") reduce 72) (("^") reduce 72) (("{") reduce 72) (("|") reduce 72)) 26612 ((("%") reduce 81) (("(") reduce 81) (("*") reduce 81) (("+") reduce 81) (("-") reduce 81) ((".") reduce 81) (("/") reduce 81) ((";") reduce 81) (("<") reduce 81) ((">") reduce 81) (("?") reduce 81) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 81) ((T_BOOLEAN_AND) reduce 81) ((T_BOOLEAN_OR) reduce 81) ((T_COALESCE) reduce 81) ((T_DOUBLE_ARROW) reduce 81) ((T_INSTANCEOF) reduce 81) ((T_IS_EQUAL) reduce 81) ((T_IS_GREATER_OR_EQUAL) reduce 81) ((T_IS_IDENTICAL) reduce 81) ((T_IS_NOT_EQUAL) reduce 81) ((T_IS_NOT_IDENTICAL) reduce 81) ((T_IS_SMALLER_OR_EQUAL) reduce 81) ((T_LOGICAL_AND) reduce 81) ((T_LOGICAL_OR) reduce 81) ((T_LOGICAL_XOR) reduce 81) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 81) ((T_OBJECT_OPERATOR) reduce 81) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 81) ((T_POW) reduce 81) ((T_SL) reduce 81) ((T_SPACESHIP) reduce 81) ((T_SR) reduce 81) (("[") reduce 81) (("^") reduce 81) (("{") reduce 81) (("|") reduce 81)) 26613 ((("%") reduce 47) (("(") reduce 47) (("*") reduce 47) (("+") reduce 47) (("-") reduce 47) ((".") reduce 47) (("/") reduce 47) ((";") reduce 47) (("<") reduce 47) ((">") reduce 47) (("?") reduce 47) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 47) ((T_BOOLEAN_AND) reduce 47) ((T_BOOLEAN_OR) reduce 47) ((T_COALESCE) reduce 47) ((T_DOUBLE_ARROW) reduce 47) ((T_INSTANCEOF) reduce 47) ((T_IS_EQUAL) reduce 47) ((T_IS_GREATER_OR_EQUAL) reduce 47) ((T_IS_IDENTICAL) reduce 47) ((T_IS_NOT_EQUAL) reduce 47) ((T_IS_NOT_IDENTICAL) reduce 47) ((T_IS_SMALLER_OR_EQUAL) reduce 47) ((T_LOGICAL_AND) reduce 47) ((T_LOGICAL_OR) reduce 47) ((T_LOGICAL_XOR) reduce 47) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 47) ((T_OBJECT_OPERATOR) reduce 47) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 47) ((T_POW) reduce 47) ((T_SL) reduce 47) ((T_SPACESHIP) reduce 47) ((T_SR) reduce 47) (("[") reduce 47) (("^") reduce 47) (("{") reduce 47) (("|") reduce 47)) 26614 ((("%") reduce 31) (("(") reduce 31) (("*") reduce 31) (("+") reduce 31) (("-") reduce 31) ((".") reduce 31) (("/") reduce 31) ((";") reduce 31) (("<") reduce 31) ((">") reduce 31) (("?") reduce 31) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 31) ((T_BOOLEAN_AND) reduce 31) ((T_BOOLEAN_OR) reduce 31) ((T_COALESCE) reduce 31) ((T_DOUBLE_ARROW) reduce 31) ((T_INSTANCEOF) reduce 31) ((T_IS_EQUAL) reduce 31) ((T_IS_GREATER_OR_EQUAL) reduce 31) ((T_IS_IDENTICAL) reduce 31) ((T_IS_NOT_EQUAL) reduce 31) ((T_IS_NOT_IDENTICAL) reduce 31) ((T_IS_SMALLER_OR_EQUAL) reduce 31) ((T_LOGICAL_AND) reduce 31) ((T_LOGICAL_OR) reduce 31) ((T_LOGICAL_XOR) reduce 31) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 31) ((T_OBJECT_OPERATOR) reduce 31) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 31) ((T_POW) reduce 31) ((T_SL) reduce 31) ((T_SPACESHIP) reduce 31) ((T_SR) reduce 31) (("[") reduce 31) (("^") reduce 31) (("{") reduce 31) (("|") reduce 31)) 26615 ((("%") reduce 57) (("(") reduce 57) (("*") reduce 57) (("+") reduce 57) (("-") reduce 57) ((".") reduce 57) (("/") reduce 57) ((";") reduce 57) (("<") reduce 57) ((">") reduce 57) (("?") reduce 57) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 57) ((T_BOOLEAN_AND) reduce 57) ((T_BOOLEAN_OR) reduce 57) ((T_COALESCE) reduce 57) ((T_DOUBLE_ARROW) reduce 57) ((T_INSTANCEOF) reduce 57) ((T_IS_EQUAL) reduce 57) ((T_IS_GREATER_OR_EQUAL) reduce 57) ((T_IS_IDENTICAL) reduce 57) ((T_IS_NOT_EQUAL) reduce 57) ((T_IS_NOT_IDENTICAL) reduce 57) ((T_IS_SMALLER_OR_EQUAL) reduce 57) ((T_LOGICAL_AND) reduce 57) ((T_LOGICAL_OR) reduce 57) ((T_LOGICAL_XOR) reduce 57) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 57) ((T_OBJECT_OPERATOR) reduce 57) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 57) ((T_POW) reduce 57) ((T_SL) reduce 57) ((T_SPACESHIP) reduce 57) ((T_SR) reduce 57) (("[") reduce 57) (("^") reduce 57) (("{") reduce 57) (("|") reduce 57)) 26616 ((("%") reduce 61) (("(") reduce 61) (("*") reduce 61) (("+") reduce 61) (("-") reduce 61) ((".") reduce 61) (("/") reduce 61) ((";") reduce 61) (("<") reduce 61) ((">") reduce 61) (("?") reduce 61) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 61) ((T_BOOLEAN_AND) reduce 61) ((T_BOOLEAN_OR) reduce 61) ((T_COALESCE) reduce 61) ((T_DOUBLE_ARROW) reduce 61) ((T_INSTANCEOF) reduce 61) ((T_IS_EQUAL) reduce 61) ((T_IS_GREATER_OR_EQUAL) reduce 61) ((T_IS_IDENTICAL) reduce 61) ((T_IS_NOT_EQUAL) reduce 61) ((T_IS_NOT_IDENTICAL) reduce 61) ((T_IS_SMALLER_OR_EQUAL) reduce 61) ((T_LOGICAL_AND) reduce 61) ((T_LOGICAL_OR) reduce 61) ((T_LOGICAL_XOR) reduce 61) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 61) ((T_OBJECT_OPERATOR) reduce 61) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 61) ((T_POW) reduce 61) ((T_SL) reduce 61) ((T_SPACESHIP) reduce 61) ((T_SR) reduce 61) (("[") reduce 61) (("^") reduce 61) (("{") reduce 61) (("|") reduce 61)) 26617 ((("%") reduce 28) (("(") reduce 28) (("*") reduce 28) (("+") reduce 28) (("-") reduce 28) ((".") reduce 28) (("/") reduce 28) ((";") reduce 28) (("<") reduce 28) ((">") reduce 28) (("?") reduce 28) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 28) ((T_BOOLEAN_AND) reduce 28) ((T_BOOLEAN_OR) reduce 28) ((T_COALESCE) reduce 28) ((T_DOUBLE_ARROW) reduce 28) ((T_INSTANCEOF) reduce 28) ((T_IS_EQUAL) reduce 28) ((T_IS_GREATER_OR_EQUAL) reduce 28) ((T_IS_IDENTICAL) reduce 28) ((T_IS_NOT_EQUAL) reduce 28) ((T_IS_NOT_IDENTICAL) reduce 28) ((T_IS_SMALLER_OR_EQUAL) reduce 28) ((T_LOGICAL_AND) reduce 28) ((T_LOGICAL_OR) reduce 28) ((T_LOGICAL_XOR) reduce 28) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 28) ((T_OBJECT_OPERATOR) reduce 28) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 28) ((T_POW) reduce 28) ((T_SL) reduce 28) ((T_SPACESHIP) reduce 28) ((T_SR) reduce 28) (("[") reduce 28) (("^") reduce 28) (("{") reduce 28) (("|") reduce 28)) 26618 ((("%") reduce 36) (("(") reduce 36) (("*") reduce 36) (("+") reduce 36) (("-") reduce 36) ((".") reduce 36) (("/") reduce 36) ((";") reduce 36) (("<") reduce 36) ((">") reduce 36) (("?") reduce 36) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 36) ((T_BOOLEAN_AND) reduce 36) ((T_BOOLEAN_OR) reduce 36) ((T_COALESCE) reduce 36) ((T_DOUBLE_ARROW) reduce 36) ((T_INSTANCEOF) reduce 36) ((T_IS_EQUAL) reduce 36) ((T_IS_GREATER_OR_EQUAL) reduce 36) ((T_IS_IDENTICAL) reduce 36) ((T_IS_NOT_EQUAL) reduce 36) ((T_IS_NOT_IDENTICAL) reduce 36) ((T_IS_SMALLER_OR_EQUAL) reduce 36) ((T_LOGICAL_AND) reduce 36) ((T_LOGICAL_OR) reduce 36) ((T_LOGICAL_XOR) reduce 36) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 36) ((T_OBJECT_OPERATOR) reduce 36) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 36) ((T_POW) reduce 36) ((T_SL) reduce 36) ((T_SPACESHIP) reduce 36) ((T_SR) reduce 36) (("[") reduce 36) (("^") reduce 36) (("{") reduce 36) (("|") reduce 36)) 26619 ((("%") reduce 32) (("(") reduce 32) (("*") reduce 32) (("+") reduce 32) (("-") reduce 32) ((".") reduce 32) (("/") reduce 32) ((";") reduce 32) (("<") reduce 32) ((">") reduce 32) (("?") reduce 32) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 32) ((T_BOOLEAN_AND) reduce 32) ((T_BOOLEAN_OR) reduce 32) ((T_COALESCE) reduce 32) ((T_DOUBLE_ARROW) reduce 32) ((T_INSTANCEOF) reduce 32) ((T_IS_EQUAL) reduce 32) ((T_IS_GREATER_OR_EQUAL) reduce 32) ((T_IS_IDENTICAL) reduce 32) ((T_IS_NOT_EQUAL) reduce 32) ((T_IS_NOT_IDENTICAL) reduce 32) ((T_IS_SMALLER_OR_EQUAL) reduce 32) ((T_LOGICAL_AND) reduce 32) ((T_LOGICAL_OR) reduce 32) ((T_LOGICAL_XOR) reduce 32) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 32) ((T_OBJECT_OPERATOR) reduce 32) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 32) ((T_POW) reduce 32) ((T_SL) reduce 32) ((T_SPACESHIP) reduce 32) ((T_SR) reduce 32) (("[") reduce 32) (("^") reduce 32) (("{") reduce 32) (("|") reduce 32)) 26620 ((("%") reduce 35) (("(") reduce 35) (("*") reduce 35) (("+") reduce 35) (("-") reduce 35) ((".") reduce 35) (("/") reduce 35) ((";") reduce 35) (("<") reduce 35) ((">") reduce 35) (("?") reduce 35) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 35) ((T_BOOLEAN_AND) reduce 35) ((T_BOOLEAN_OR) reduce 35) ((T_COALESCE) reduce 35) ((T_DOUBLE_ARROW) reduce 35) ((T_INSTANCEOF) reduce 35) ((T_IS_EQUAL) reduce 35) ((T_IS_GREATER_OR_EQUAL) reduce 35) ((T_IS_IDENTICAL) reduce 35) ((T_IS_NOT_EQUAL) reduce 35) ((T_IS_NOT_IDENTICAL) reduce 35) ((T_IS_SMALLER_OR_EQUAL) reduce 35) ((T_LOGICAL_AND) reduce 35) ((T_LOGICAL_OR) reduce 35) ((T_LOGICAL_XOR) reduce 35) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 35) ((T_OBJECT_OPERATOR) reduce 35) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 35) ((T_POW) reduce 35) ((T_SL) reduce 35) ((T_SPACESHIP) reduce 35) ((T_SR) reduce 35) (("[") reduce 35) (("^") reduce 35) (("{") reduce 35) (("|") reduce 35)) 26621 ((("%") reduce 19) (("(") reduce 19) (("*") reduce 19) (("+") reduce 19) (("-") reduce 19) ((".") reduce 19) (("/") reduce 19) ((";") reduce 19) (("<") reduce 19) ((">") reduce 19) (("?") reduce 19) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 19) ((T_BOOLEAN_AND) reduce 19) ((T_BOOLEAN_OR) reduce 19) ((T_COALESCE) reduce 19) ((T_DOUBLE_ARROW) reduce 19) ((T_INSTANCEOF) reduce 19) ((T_IS_EQUAL) reduce 19) ((T_IS_GREATER_OR_EQUAL) reduce 19) ((T_IS_IDENTICAL) reduce 19) ((T_IS_NOT_EQUAL) reduce 19) ((T_IS_NOT_IDENTICAL) reduce 19) ((T_IS_SMALLER_OR_EQUAL) reduce 19) ((T_LOGICAL_AND) reduce 19) ((T_LOGICAL_OR) reduce 19) ((T_LOGICAL_XOR) reduce 19) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 19) ((T_OBJECT_OPERATOR) reduce 19) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 19) ((T_POW) reduce 19) ((T_SL) reduce 19) ((T_SPACESHIP) reduce 19) ((T_SR) reduce 19) (("[") reduce 19) (("^") reduce 19) (("{") reduce 19) (("|") reduce 19)) 26622 ((("%") reduce 45) (("(") reduce 45) (("*") reduce 45) (("+") reduce 45) (("-") reduce 45) ((".") reduce 45) (("/") reduce 45) ((";") reduce 45) (("<") reduce 45) ((">") reduce 45) (("?") reduce 45) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 45) ((T_BOOLEAN_AND) reduce 45) ((T_BOOLEAN_OR) reduce 45) ((T_COALESCE) reduce 45) ((T_DOUBLE_ARROW) reduce 45) ((T_INSTANCEOF) reduce 45) ((T_IS_EQUAL) reduce 45) ((T_IS_GREATER_OR_EQUAL) reduce 45) ((T_IS_IDENTICAL) reduce 45) ((T_IS_NOT_EQUAL) reduce 45) ((T_IS_NOT_IDENTICAL) reduce 45) ((T_IS_SMALLER_OR_EQUAL) reduce 45) ((T_LOGICAL_AND) reduce 45) ((T_LOGICAL_OR) reduce 45) ((T_LOGICAL_XOR) reduce 45) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 45) ((T_OBJECT_OPERATOR) reduce 45) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 45) ((T_POW) reduce 45) ((T_SL) reduce 45) ((T_SPACESHIP) reduce 45) ((T_SR) reduce 45) (("[") reduce 45) (("^") reduce 45) (("{") reduce 45) (("|") reduce 45)) 26623 ((("%") reduce 504) (("(") reduce 541) (("*") reduce 504) (("+") reduce 504) (("-") reduce 504) ((".") reduce 504) (("/") reduce 504) ((";") reduce 504) (("<") reduce 504) ((">") reduce 504) (("?") reduce 504) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 504) ((T_BOOLEAN_AND) reduce 504) ((T_BOOLEAN_OR) reduce 504) ((T_COALESCE) reduce 504) ((T_DOUBLE_ARROW) reduce 504) ((T_INSTANCEOF) reduce 504) ((T_IS_EQUAL) reduce 504) ((T_IS_GREATER_OR_EQUAL) reduce 504) ((T_IS_IDENTICAL) reduce 504) ((T_IS_NOT_EQUAL) reduce 504) ((T_IS_NOT_IDENTICAL) reduce 504) ((T_IS_SMALLER_OR_EQUAL) reduce 504) ((T_LOGICAL_AND) reduce 504) ((T_LOGICAL_OR) reduce 504) ((T_LOGICAL_XOR) reduce 504) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 504) ((T_OBJECT_OPERATOR) reduce 504) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 504) ((T_POW) reduce 504) ((T_SL) reduce 504) ((T_SPACESHIP) reduce 504) ((T_SR) reduce 504) (("[") reduce 504) (("^") reduce 504) (("{") reduce 504) (("|") reduce 504)) 26625 ((("%") reduce 71) (("(") reduce 71) (("*") reduce 71) (("+") reduce 71) (("-") reduce 71) ((".") reduce 71) (("/") reduce 71) ((";") reduce 71) (("<") reduce 71) ((">") reduce 71) (("?") reduce 71) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 71) ((T_BOOLEAN_AND) reduce 71) ((T_BOOLEAN_OR) reduce 71) ((T_COALESCE) reduce 71) ((T_DOUBLE_ARROW) reduce 71) ((T_INSTANCEOF) reduce 71) ((T_IS_EQUAL) reduce 71) ((T_IS_GREATER_OR_EQUAL) reduce 71) ((T_IS_IDENTICAL) reduce 71) ((T_IS_NOT_EQUAL) reduce 71) ((T_IS_NOT_IDENTICAL) reduce 71) ((T_IS_SMALLER_OR_EQUAL) reduce 71) ((T_LOGICAL_AND) reduce 71) ((T_LOGICAL_OR) reduce 71) ((T_LOGICAL_XOR) reduce 71) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 71) ((T_OBJECT_OPERATOR) reduce 71) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 71) ((T_POW) reduce 71) ((T_SL) reduce 71) ((T_SPACESHIP) reduce 71) ((T_SR) reduce 71) (("[") reduce 71) (("^") reduce 71) (("{") reduce 71) (("|") reduce 71)) 26626 ((("%") reduce 82) (("(") reduce 82) (("*") reduce 82) (("+") reduce 82) (("-") reduce 82) ((".") reduce 82) (("/") reduce 82) ((";") reduce 82) (("<") reduce 82) ((">") reduce 82) (("?") reduce 82) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 82) ((T_BOOLEAN_AND) reduce 82) ((T_BOOLEAN_OR) reduce 82) ((T_COALESCE) reduce 82) ((T_DOUBLE_ARROW) reduce 82) ((T_INSTANCEOF) reduce 82) ((T_IS_EQUAL) reduce 82) ((T_IS_GREATER_OR_EQUAL) reduce 82) ((T_IS_IDENTICAL) reduce 82) ((T_IS_NOT_EQUAL) reduce 82) ((T_IS_NOT_IDENTICAL) reduce 82) ((T_IS_SMALLER_OR_EQUAL) reduce 82) ((T_LOGICAL_AND) reduce 82) ((T_LOGICAL_OR) reduce 82) ((T_LOGICAL_XOR) reduce 82) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 82) ((T_OBJECT_OPERATOR) reduce 82) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 82) ((T_POW) reduce 82) ((T_SL) reduce 82) ((T_SPACESHIP) reduce 82) ((T_SR) reduce 82) (("[") reduce 82) (("^") reduce 82) (("{") reduce 82) (("|") reduce 82)) 26627 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) ((";") reduce 533) (("<") reduce 533) (("=") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AND_EQUAL) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_COALESCE_EQUAL) reduce 533) ((T_CONCAT_EQUAL) reduce 533) ((T_DEC) reduce 533) ((T_DIV_EQUAL) reduce 533) ((T_DOUBLE_ARROW) reduce 533) ((T_INC) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_MINUS_EQUAL) reduce 533) ((T_MOD_EQUAL) reduce 533) ((T_MUL_EQUAL) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_OR_EQUAL) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_PLUS_EQUAL) reduce 533) ((T_POW) reduce 533) ((T_POW_EQUAL) reduce 533) ((T_SL) reduce 533) ((T_SL_EQUAL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) ((T_SR_EQUAL) reduce 533) ((T_XOR_EQUAL) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 26630 ((("%") reduce 506) (("(") reduce 542) (("*") reduce 506) (("+") reduce 506) (("-") reduce 506) ((".") reduce 506) (("/") reduce 506) ((";") reduce 506) (("<") reduce 506) ((">") reduce 506) (("?") reduce 506) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 506) ((T_BOOLEAN_AND) reduce 506) ((T_BOOLEAN_OR) reduce 506) ((T_COALESCE) reduce 506) ((T_DOUBLE_ARROW) reduce 506) ((T_INSTANCEOF) reduce 506) ((T_IS_EQUAL) reduce 506) ((T_IS_GREATER_OR_EQUAL) reduce 506) ((T_IS_IDENTICAL) reduce 506) ((T_IS_NOT_EQUAL) reduce 506) ((T_IS_NOT_IDENTICAL) reduce 506) ((T_IS_SMALLER_OR_EQUAL) reduce 506) ((T_LOGICAL_AND) reduce 506) ((T_LOGICAL_OR) reduce 506) ((T_LOGICAL_XOR) reduce 506) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 506) ((T_OBJECT_OPERATOR) reduce 506) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 506) ((T_POW) reduce 506) ((T_SL) reduce 506) ((T_SPACESHIP) reduce 506) ((T_SR) reduce 506) (("[") reduce 506) (("^") reduce 506) (("{") reduce 506) (("|") reduce 506)) 26632 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) ((";") reduce 468) (("<") reduce 468) (("=") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AND_EQUAL) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_COALESCE_EQUAL) reduce 468) ((T_CONCAT_EQUAL) reduce 468) ((T_DEC) reduce 468) ((T_DIV_EQUAL) reduce 468) ((T_DOUBLE_ARROW) reduce 468) ((T_INC) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_MINUS_EQUAL) reduce 468) ((T_MOD_EQUAL) reduce 468) ((T_MUL_EQUAL) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_OR_EQUAL) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_PLUS_EQUAL) reduce 468) ((T_POW) reduce 468) ((T_POW_EQUAL) reduce 468) ((T_SL) reduce 468) ((T_SL_EQUAL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) ((T_SR_EQUAL) reduce 468) ((T_XOR_EQUAL) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 26633 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) ((";") reduce 288) (("<") reduce 288) (("=") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AND_EQUAL) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_COALESCE_EQUAL) reduce 288) ((T_CONCAT_EQUAL) reduce 288) ((T_DEC) reduce 288) ((T_DIV_EQUAL) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INC) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_MINUS_EQUAL) reduce 288) ((T_MOD_EQUAL) reduce 288) ((T_MUL_EQUAL) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_OR_EQUAL) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_PLUS_EQUAL) reduce 288) ((T_POW) reduce 288) ((T_POW_EQUAL) reduce 288) ((T_SL) reduce 288) ((T_SL_EQUAL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) ((T_SR_EQUAL) reduce 288) ((T_XOR_EQUAL) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 26637 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) ((";") reduce 289) (("<") reduce 289) (("=") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AND_EQUAL) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_COALESCE_EQUAL) reduce 289) ((T_CONCAT_EQUAL) reduce 289) ((T_DEC) reduce 289) ((T_DIV_EQUAL) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INC) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_MINUS_EQUAL) reduce 289) ((T_MOD_EQUAL) reduce 289) ((T_MUL_EQUAL) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_OR_EQUAL) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_PLUS_EQUAL) reduce 289) ((T_POW) reduce 289) ((T_POW_EQUAL) reduce 289) ((T_SL) reduce 289) ((T_SL_EQUAL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) ((T_SR_EQUAL) reduce 289) ((T_XOR_EQUAL) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 26638 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) ((";") reduce 290) (("<") reduce 290) (("=") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AND_EQUAL) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_COALESCE_EQUAL) reduce 290) ((T_CONCAT_EQUAL) reduce 290) ((T_DEC) reduce 290) ((T_DIV_EQUAL) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INC) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_MINUS_EQUAL) reduce 290) ((T_MOD_EQUAL) reduce 290) ((T_MUL_EQUAL) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_OR_EQUAL) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_PLUS_EQUAL) reduce 290) ((T_POW) reduce 290) ((T_POW_EQUAL) reduce 290) ((T_SL) reduce 290) ((T_SL_EQUAL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) ((T_SR_EQUAL) reduce 290) ((T_XOR_EQUAL) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 26643 ((("%") reduce 388) (("*") reduce 388) (("+") reduce 388) (("-") reduce 388) ((".") reduce 388) (("/") reduce 388) ((";") reduce 388) (("<") reduce 388) ((">") reduce 388) (("?") reduce 388) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 388) ((T_BOOLEAN_AND) reduce 388) ((T_BOOLEAN_OR) reduce 388) ((T_COALESCE) reduce 388) ((T_DOUBLE_ARROW) reduce 388) ((T_INSTANCEOF) reduce 388) ((T_IS_EQUAL) reduce 388) ((T_IS_GREATER_OR_EQUAL) reduce 388) ((T_IS_IDENTICAL) reduce 388) ((T_IS_NOT_EQUAL) reduce 388) ((T_IS_NOT_IDENTICAL) reduce 388) ((T_IS_SMALLER_OR_EQUAL) reduce 388) ((T_LOGICAL_AND) reduce 388) ((T_LOGICAL_OR) reduce 388) ((T_LOGICAL_XOR) reduce 388) ((T_POW) reduce 388) ((T_SL) reduce 388) ((T_SPACESHIP) reduce 388) ((T_SR) reduce 388) (("^") reduce 388) (("|") reduce 388)) 26645 ((("%") reduce 386) (("*") reduce 386) (("+") reduce 386) (("-") reduce 386) ((".") reduce 386) (("/") reduce 386) ((";") reduce 386) (("<") reduce 386) ((">") reduce 386) (("?") reduce 386) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 386) ((T_BOOLEAN_AND) reduce 386) ((T_BOOLEAN_OR) reduce 386) ((T_COALESCE) reduce 386) ((T_DOUBLE_ARROW) reduce 386) ((T_INSTANCEOF) reduce 386) ((T_IS_EQUAL) reduce 386) ((T_IS_GREATER_OR_EQUAL) reduce 386) ((T_IS_IDENTICAL) reduce 386) ((T_IS_NOT_EQUAL) reduce 386) ((T_IS_NOT_IDENTICAL) reduce 386) ((T_IS_SMALLER_OR_EQUAL) reduce 386) ((T_LOGICAL_AND) reduce 386) ((T_LOGICAL_OR) reduce 386) ((T_LOGICAL_XOR) reduce 386) ((T_POW) reduce 386) ((T_SL) reduce 386) ((T_SPACESHIP) reduce 386) ((T_SR) reduce 386) (("^") reduce 386) (("|") reduce 386)) 26655 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 382) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 382) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 382) ((T_LOGICAL_OR) reduce 382) ((T_LOGICAL_XOR) reduce 382) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26656 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 384) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 384) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 384) ((T_LOGICAL_OR) reduce 384) ((T_LOGICAL_XOR) reduce 384) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26657 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 383) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 383) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 383) ((T_LOGICAL_OR) reduce 383) ((T_LOGICAL_XOR) reduce 383) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26658 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 376) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 376) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 376) ((T_LOGICAL_OR) reduce 376) ((T_LOGICAL_XOR) reduce 376) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26659 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 373) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 373) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 373) ((T_LOGICAL_OR) reduce 373) ((T_LOGICAL_XOR) reduce 373) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26660 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 381) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 381) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 381) ((T_LOGICAL_OR) reduce 381) ((T_LOGICAL_XOR) reduce 381) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26661 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 375) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 375) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 375) ((T_LOGICAL_OR) reduce 375) ((T_LOGICAL_XOR) reduce 375) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26662 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 379) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 379) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 379) ((T_LOGICAL_OR) reduce 379) ((T_LOGICAL_XOR) reduce 379) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26663 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 374) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 374) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 374) ((T_LOGICAL_OR) reduce 374) ((T_LOGICAL_XOR) reduce 374) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26664 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 377) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 377) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 377) ((T_LOGICAL_OR) reduce 377) ((T_LOGICAL_XOR) reduce 377) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26665 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 378) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 378) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 378) ((T_LOGICAL_OR) reduce 378) ((T_LOGICAL_XOR) reduce 378) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26666 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 385) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 385) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 385) ((T_LOGICAL_OR) reduce 385) ((T_LOGICAL_XOR) reduce 385) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26667 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 380) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 380) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 380) ((T_LOGICAL_OR) reduce 380) ((T_LOGICAL_XOR) reduce 380) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26669 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 370) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 370) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 370) ((T_LOGICAL_OR) reduce 370) ((T_LOGICAL_XOR) reduce 370) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26672 ((("%") reduce 529) (("(") reduce 529) (("*") reduce 529) (("+") reduce 529) (("-") reduce 529) ((".") reduce 529) (("/") reduce 529) ((";") reduce 529) (("<") reduce 529) ((">") reduce 529) (("?") reduce 529) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 529) ((T_BOOLEAN_AND) reduce 529) ((T_BOOLEAN_OR) reduce 529) ((T_COALESCE) reduce 529) ((T_DOUBLE_ARROW) reduce 529) ((T_INSTANCEOF) reduce 529) ((T_IS_EQUAL) reduce 529) ((T_IS_GREATER_OR_EQUAL) reduce 529) ((T_IS_IDENTICAL) reduce 529) ((T_IS_NOT_EQUAL) reduce 529) ((T_IS_NOT_IDENTICAL) reduce 529) ((T_IS_SMALLER_OR_EQUAL) reduce 529) ((T_LOGICAL_AND) reduce 529) ((T_LOGICAL_OR) reduce 529) ((T_LOGICAL_XOR) reduce 529) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 529) ((T_OBJECT_OPERATOR) reduce 529) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 529) ((T_POW) reduce 529) ((T_SL) reduce 529) ((T_SPACESHIP) reduce 529) ((T_SR) reduce 529) (("[") reduce 529) (("^") reduce 529) (("{") reduce 529) (("|") reduce 529)) 26675 ((("%") reduce 525) (("(") reduce 516) (("*") reduce 525) (("+") reduce 525) (("-") reduce 525) ((".") reduce 525) (("/") reduce 525) ((";") reduce 525) (("<") reduce 525) ((">") reduce 525) (("?") reduce 525) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 525) ((T_BOOLEAN_AND) reduce 525) ((T_BOOLEAN_OR) reduce 525) ((T_COALESCE) reduce 525) ((T_DOUBLE_ARROW) reduce 525) ((T_INSTANCEOF) reduce 525) ((T_IS_EQUAL) reduce 525) ((T_IS_GREATER_OR_EQUAL) reduce 525) ((T_IS_IDENTICAL) reduce 525) ((T_IS_NOT_EQUAL) reduce 525) ((T_IS_NOT_IDENTICAL) reduce 525) ((T_IS_SMALLER_OR_EQUAL) reduce 525) ((T_LOGICAL_AND) reduce 525) ((T_LOGICAL_OR) reduce 525) ((T_LOGICAL_XOR) reduce 525) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 525) ((T_OBJECT_OPERATOR) reduce 525) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 525) ((T_POW) reduce 525) ((T_SL) reduce 525) ((T_SPACESHIP) reduce 525) ((T_SR) reduce 525) (("[") reduce 525) (("^") reduce 525) (("{") reduce 525) (("|") reduce 525)) 26677 ((("%") reduce 524) (("(") reduce 524) (("*") reduce 524) (("+") reduce 524) (("-") reduce 524) ((".") reduce 524) (("/") reduce 524) ((";") reduce 524) (("<") reduce 524) ((">") reduce 524) (("?") reduce 524) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 524) ((T_BOOLEAN_AND) reduce 524) ((T_BOOLEAN_OR) reduce 524) ((T_COALESCE) reduce 524) ((T_DOUBLE_ARROW) reduce 524) ((T_INSTANCEOF) reduce 524) ((T_IS_EQUAL) reduce 524) ((T_IS_GREATER_OR_EQUAL) reduce 524) ((T_IS_IDENTICAL) reduce 524) ((T_IS_NOT_EQUAL) reduce 524) ((T_IS_NOT_IDENTICAL) reduce 524) ((T_IS_SMALLER_OR_EQUAL) reduce 524) ((T_LOGICAL_AND) reduce 524) ((T_LOGICAL_OR) reduce 524) ((T_LOGICAL_XOR) reduce 524) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 524) ((T_OBJECT_OPERATOR) reduce 524) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 524) ((T_POW) reduce 524) ((T_SL) reduce 524) ((T_SPACESHIP) reduce 524) ((T_SR) reduce 524) (("[") reduce 524) (("^") reduce 524) (("{") reduce 524) (("|") reduce 524)) 26679 ((("%") reduce 519) (("(") reduce 519) (("*") reduce 519) (("+") reduce 519) (("-") reduce 519) ((".") reduce 519) (("/") reduce 519) ((";") reduce 519) (("<") reduce 519) ((">") reduce 519) (("?") reduce 519) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 519) ((T_BOOLEAN_AND) reduce 519) ((T_BOOLEAN_OR) reduce 519) ((T_COALESCE) reduce 519) ((T_DOUBLE_ARROW) reduce 519) ((T_INSTANCEOF) reduce 519) ((T_IS_EQUAL) reduce 519) ((T_IS_GREATER_OR_EQUAL) reduce 519) ((T_IS_IDENTICAL) reduce 519) ((T_IS_NOT_EQUAL) reduce 519) ((T_IS_NOT_IDENTICAL) reduce 519) ((T_IS_SMALLER_OR_EQUAL) reduce 519) ((T_LOGICAL_AND) reduce 519) ((T_LOGICAL_OR) reduce 519) ((T_LOGICAL_XOR) reduce 519) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 519) ((T_OBJECT_OPERATOR) reduce 519) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 519) ((T_POW) reduce 519) ((T_SL) reduce 519) ((T_SPACESHIP) reduce 519) ((T_SR) reduce 519) (("[") reduce 519) (("^") reduce 519) (("{") reduce 519) (("|") reduce 519)) 26680 ((("%") reduce 526) (("*") reduce 526) (("+") reduce 526) (("-") reduce 526) ((".") reduce 526) (("/") reduce 526) ((";") reduce 526) (("<") reduce 526) ((">") reduce 526) (("?") reduce 526) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 526) ((T_BOOLEAN_AND) reduce 526) ((T_BOOLEAN_OR) reduce 526) ((T_COALESCE) reduce 526) ((T_DOUBLE_ARROW) reduce 526) ((T_INSTANCEOF) reduce 526) ((T_IS_EQUAL) reduce 526) ((T_IS_GREATER_OR_EQUAL) reduce 526) ((T_IS_IDENTICAL) reduce 526) ((T_IS_NOT_EQUAL) reduce 526) ((T_IS_NOT_IDENTICAL) reduce 526) ((T_IS_SMALLER_OR_EQUAL) reduce 526) ((T_LOGICAL_AND) reduce 526) ((T_LOGICAL_OR) reduce 526) ((T_LOGICAL_XOR) reduce 526) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 526) ((T_OBJECT_OPERATOR) reduce 526) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 526) ((T_POW) reduce 526) ((T_SL) reduce 526) ((T_SPACESHIP) reduce 526) ((T_SR) reduce 526) (("[") reduce 526) (("^") reduce 526) (("{") reduce 526) (("|") reduce 526)) 26681 ((("%") reduce 371) (("*") reduce 371) (("+") reduce 371) (("-") reduce 371) ((".") reduce 371) (("/") reduce 371) ((";") reduce 371) (("<") reduce 371) ((">") reduce 371) (("?") reduce 371) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 371) ((T_BOOLEAN_AND) reduce 371) ((T_BOOLEAN_OR) reduce 371) ((T_COALESCE) reduce 371) ((T_DOUBLE_ARROW) reduce 371) ((T_INSTANCEOF) reduce 371) ((T_IS_EQUAL) reduce 371) ((T_IS_GREATER_OR_EQUAL) reduce 371) ((T_IS_IDENTICAL) reduce 371) ((T_IS_NOT_EQUAL) reduce 371) ((T_IS_NOT_IDENTICAL) reduce 371) ((T_IS_SMALLER_OR_EQUAL) reduce 371) ((T_LOGICAL_AND) reduce 371) ((T_LOGICAL_OR) reduce 371) ((T_LOGICAL_XOR) reduce 371) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 371) ((T_SL) reduce 371) ((T_SPACESHIP) reduce 371) ((T_SR) reduce 371) (("[") reduce 510) (("^") reduce 371) (("{") reduce 510) (("|") reduce 371)) 26685 ((("%") reduce 533) (("(") reduce 543) (("*") reduce 533) (("+") reduce 533) (("-") reduce 533) ((".") reduce 533) (("/") reduce 533) ((";") reduce 533) (("<") reduce 533) ((">") reduce 533) (("?") reduce 533) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 533) ((T_BOOLEAN_AND) reduce 533) ((T_BOOLEAN_OR) reduce 533) ((T_COALESCE) reduce 533) ((T_DOUBLE_ARROW) reduce 533) ((T_INSTANCEOF) reduce 533) ((T_IS_EQUAL) reduce 533) ((T_IS_GREATER_OR_EQUAL) reduce 533) ((T_IS_IDENTICAL) reduce 533) ((T_IS_NOT_EQUAL) reduce 533) ((T_IS_NOT_IDENTICAL) reduce 533) ((T_IS_SMALLER_OR_EQUAL) reduce 533) ((T_LOGICAL_AND) reduce 533) ((T_LOGICAL_OR) reduce 533) ((T_LOGICAL_XOR) reduce 533) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 533) ((T_OBJECT_OPERATOR) reduce 533) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 533) ((T_POW) reduce 533) ((T_SL) reduce 533) ((T_SPACESHIP) reduce 533) ((T_SR) reduce 533) (("[") reduce 533) (("^") reduce 533) (("{") reduce 533) (("|") reduce 533)) 26687 ((("%") reduce 468) (("(") reduce 468) (("*") reduce 468) (("+") reduce 468) (("-") reduce 468) ((".") reduce 468) (("/") reduce 468) ((";") reduce 468) (("<") reduce 468) ((">") reduce 468) (("?") reduce 468) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 468) ((T_BOOLEAN_AND) reduce 468) ((T_BOOLEAN_OR) reduce 468) ((T_COALESCE) reduce 468) ((T_DOUBLE_ARROW) reduce 468) ((T_INSTANCEOF) reduce 468) ((T_IS_EQUAL) reduce 468) ((T_IS_GREATER_OR_EQUAL) reduce 468) ((T_IS_IDENTICAL) reduce 468) ((T_IS_NOT_EQUAL) reduce 468) ((T_IS_NOT_IDENTICAL) reduce 468) ((T_IS_SMALLER_OR_EQUAL) reduce 468) ((T_LOGICAL_AND) reduce 468) ((T_LOGICAL_OR) reduce 468) ((T_LOGICAL_XOR) reduce 468) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 468) ((T_OBJECT_OPERATOR) reduce 468) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 468) ((T_POW) reduce 468) ((T_SL) reduce 468) ((T_SPACESHIP) reduce 468) ((T_SR) reduce 468) (("[") reduce 468) (("^") reduce 468) (("{") reduce 468) (("|") reduce 468)) 26688 ((("%") reduce 288) (("(") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) ((";") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 288) ((T_OBJECT_OPERATOR) reduce 288) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("[") reduce 288) (("^") reduce 288) (("{") reduce 288) (("|") reduce 288)) 26692 ((("%") reduce 289) (("(") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) ((";") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 289) ((T_OBJECT_OPERATOR) reduce 289) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("[") reduce 289) (("^") reduce 289) (("{") reduce 289) (("|") reduce 289)) 26693 ((("%") reduce 290) (("(") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) ((";") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 290) ((T_OBJECT_OPERATOR) reduce 290) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("[") reduce 290) (("^") reduce 290) (("{") reduce 290) (("|") reduce 290)) 26694 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) ((";") reduce 465) (("<") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_DOUBLE_ARROW) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_POW) reduce 465) ((T_SL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 26697 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) ((";") reduce 532) (("<") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_DOUBLE_ARROW) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_POW) reduce 532) ((T_SL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 26698 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) ((";") reduce 467) (("<") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_DOUBLE_ARROW) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_POW) reduce 467) ((T_SL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 26699 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) ((";") reduce 469) (("<") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_DOUBLE_ARROW) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_POW) reduce 469) ((T_SL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 26705 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) ((";") reduce 521) (("<") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_DOUBLE_ARROW) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_POW) reduce 521) ((T_SL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 26707 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) ((";") reduce 520) (("<") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_DOUBLE_ARROW) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_POW) reduce 520) ((T_SL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 26708 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) ((";") reduce 544) (("<") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_POW) reduce 544) ((T_SL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 26709 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) ((";") reduce 527) (("<") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_DOUBLE_ARROW) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_POW) reduce 527) ((T_SL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 26710 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) ((";") reduce 546) (("<") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_POW) reduce 546) ((T_SL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 26713 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) ((";") reduce 545) (("<") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_POW) reduce 545) ((T_SL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 26714 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) ((";") reduce 522) (("<") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_DOUBLE_ARROW) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_POW) reduce 522) ((T_SL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 26715 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) ((";") reduce 528) (("<") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_DOUBLE_ARROW) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_POW) reduce 528) ((T_SL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 26716 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) ((";") reduce 523) (("<") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_DOUBLE_ARROW) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_POW) reduce 523) ((T_SL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 26717 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) ((";") reduce 466) (("<") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_DOUBLE_ARROW) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_POW) reduce 466) ((T_SL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 26718 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) ((";") reduce 531) (("<") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_POW) reduce 531) ((T_SL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 26721 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) ((";") reduce 530) (("<") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_POW) reduce 530) ((T_SL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 26722 ((("%") reduce 465) (("(") reduce 465) (("*") reduce 465) (("+") reduce 465) (("-") reduce 465) ((".") reduce 465) (("/") reduce 465) ((";") reduce 465) (("<") reduce 465) (("=") reduce 465) ((">") reduce 465) (("?") reduce 465) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 465) ((T_AND_EQUAL) reduce 465) ((T_BOOLEAN_AND) reduce 465) ((T_BOOLEAN_OR) reduce 465) ((T_COALESCE) reduce 465) ((T_COALESCE_EQUAL) reduce 465) ((T_CONCAT_EQUAL) reduce 465) ((T_DEC) reduce 465) ((T_DIV_EQUAL) reduce 465) ((T_DOUBLE_ARROW) reduce 465) ((T_INC) reduce 465) ((T_INSTANCEOF) reduce 465) ((T_IS_EQUAL) reduce 465) ((T_IS_GREATER_OR_EQUAL) reduce 465) ((T_IS_IDENTICAL) reduce 465) ((T_IS_NOT_EQUAL) reduce 465) ((T_IS_NOT_IDENTICAL) reduce 465) ((T_IS_SMALLER_OR_EQUAL) reduce 465) ((T_LOGICAL_AND) reduce 465) ((T_LOGICAL_OR) reduce 465) ((T_LOGICAL_XOR) reduce 465) ((T_MINUS_EQUAL) reduce 465) ((T_MOD_EQUAL) reduce 465) ((T_MUL_EQUAL) reduce 465) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 465) ((T_OBJECT_OPERATOR) reduce 465) ((T_OR_EQUAL) reduce 465) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 465) ((T_PLUS_EQUAL) reduce 465) ((T_POW) reduce 465) ((T_POW_EQUAL) reduce 465) ((T_SL) reduce 465) ((T_SL_EQUAL) reduce 465) ((T_SPACESHIP) reduce 465) ((T_SR) reduce 465) ((T_SR_EQUAL) reduce 465) ((T_XOR_EQUAL) reduce 465) (("[") reduce 465) (("^") reduce 465) (("{") reduce 465) (("|") reduce 465)) 26733 ((("%") reduce 455) (("*") reduce 455) (("+") reduce 455) (("-") reduce 455) ((".") reduce 455) (("/") reduce 455) ((";") reduce 455) (("<") reduce 455) ((">") reduce 455) (("?") reduce 455) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 455) ((T_BOOLEAN_AND) reduce 455) ((T_BOOLEAN_OR) reduce 455) ((T_COALESCE) reduce 455) ((T_DOUBLE_ARROW) reduce 455) ((T_INSTANCEOF) reduce 455) ((T_IS_EQUAL) reduce 455) ((T_IS_GREATER_OR_EQUAL) reduce 455) ((T_IS_IDENTICAL) reduce 455) ((T_IS_NOT_EQUAL) reduce 455) ((T_IS_NOT_IDENTICAL) reduce 455) ((T_IS_SMALLER_OR_EQUAL) reduce 455) ((T_LOGICAL_AND) reduce 455) ((T_LOGICAL_OR) reduce 455) ((T_LOGICAL_XOR) reduce 455) ((T_POW) reduce 455) ((T_SL) reduce 455) ((T_SPACESHIP) reduce 455) ((T_SR) reduce 455) (("^") reduce 455) (("|") reduce 455)) 26734 ((("%") reduce 450) (("*") reduce 450) (("+") reduce 450) (("-") reduce 450) ((".") reduce 450) (("/") reduce 450) ((";") reduce 450) (("<") reduce 450) ((">") reduce 450) (("?") reduce 450) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 450) ((T_BOOLEAN_AND) reduce 450) ((T_BOOLEAN_OR) reduce 450) ((T_COALESCE) reduce 450) ((T_DOUBLE_ARROW) reduce 450) ((T_INSTANCEOF) reduce 450) ((T_IS_EQUAL) reduce 450) ((T_IS_GREATER_OR_EQUAL) reduce 450) ((T_IS_IDENTICAL) reduce 450) ((T_IS_NOT_EQUAL) reduce 450) ((T_IS_NOT_IDENTICAL) reduce 450) ((T_IS_SMALLER_OR_EQUAL) reduce 450) ((T_LOGICAL_AND) reduce 450) ((T_LOGICAL_OR) reduce 450) ((T_LOGICAL_XOR) reduce 450) ((T_POW) reduce 450) ((T_SL) reduce 450) ((T_SPACESHIP) reduce 450) ((T_SR) reduce 450) (("^") reduce 450) (("|") reduce 450)) 26744 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 455) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 455) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26745 ((("%") reduce 451) (("*") reduce 451) (("+") reduce 451) (("-") reduce 451) ((".") reduce 451) (("/") reduce 451) ((";") reduce 451) (("<") reduce 451) ((">") reduce 451) (("?") reduce 451) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 451) ((T_BOOLEAN_AND) reduce 451) ((T_BOOLEAN_OR) reduce 451) ((T_COALESCE) reduce 451) ((T_DOUBLE_ARROW) reduce 451) ((T_INSTANCEOF) reduce 451) ((T_IS_EQUAL) reduce 451) ((T_IS_GREATER_OR_EQUAL) reduce 451) ((T_IS_IDENTICAL) reduce 451) ((T_IS_NOT_EQUAL) reduce 451) ((T_IS_NOT_IDENTICAL) reduce 451) ((T_IS_SMALLER_OR_EQUAL) reduce 451) ((T_LOGICAL_AND) reduce 451) ((T_LOGICAL_OR) reduce 451) ((T_LOGICAL_XOR) reduce 451) ((T_POW) reduce 451) ((T_SL) reduce 451) ((T_SPACESHIP) reduce 451) ((T_SR) reduce 451) (("^") reduce 451) (("|") reduce 451)) 26747 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 442) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 442) ((T_LOGICAL_OR) reduce 442) ((T_LOGICAL_XOR) reduce 442) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26749 ((("%") reduce 503) (("(") reduce 541) (("*") reduce 503) (("+") reduce 503) (("-") reduce 503) ((".") reduce 503) (("/") reduce 503) ((";") reduce 503) (("<") reduce 503) ((">") reduce 503) (("?") reduce 503) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 503) ((T_BOOLEAN_AND) reduce 503) ((T_BOOLEAN_OR) reduce 503) ((T_COALESCE) reduce 503) ((T_DOUBLE_ARROW) reduce 503) ((T_INSTANCEOF) reduce 503) ((T_IS_EQUAL) reduce 503) ((T_IS_GREATER_OR_EQUAL) reduce 503) ((T_IS_IDENTICAL) reduce 503) ((T_IS_NOT_EQUAL) reduce 503) ((T_IS_NOT_IDENTICAL) reduce 503) ((T_IS_SMALLER_OR_EQUAL) reduce 503) ((T_LOGICAL_AND) reduce 503) ((T_LOGICAL_OR) reduce 503) ((T_LOGICAL_XOR) reduce 503) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 503) ((T_OBJECT_OPERATOR) reduce 503) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 503) ((T_POW) reduce 503) ((T_SL) reduce 503) ((T_SPACESHIP) reduce 503) ((T_SR) reduce 503) (("[") reduce 503) (("^") reduce 503) (("{") reduce 503) (("|") reduce 503)) 26751 ((("%") reduce 532) (("(") reduce 543) (("*") reduce 532) (("+") reduce 532) (("-") reduce 532) ((".") reduce 532) (("/") reduce 532) ((";") reduce 532) (("<") reduce 532) (("=") reduce 532) ((">") reduce 532) (("?") reduce 532) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 532) ((T_AND_EQUAL) reduce 532) ((T_BOOLEAN_AND) reduce 532) ((T_BOOLEAN_OR) reduce 532) ((T_COALESCE) reduce 532) ((T_COALESCE_EQUAL) reduce 532) ((T_CONCAT_EQUAL) reduce 532) ((T_DEC) reduce 532) ((T_DIV_EQUAL) reduce 532) ((T_DOUBLE_ARROW) reduce 532) ((T_INC) reduce 532) ((T_INSTANCEOF) reduce 532) ((T_IS_EQUAL) reduce 532) ((T_IS_GREATER_OR_EQUAL) reduce 532) ((T_IS_IDENTICAL) reduce 532) ((T_IS_NOT_EQUAL) reduce 532) ((T_IS_NOT_IDENTICAL) reduce 532) ((T_IS_SMALLER_OR_EQUAL) reduce 532) ((T_LOGICAL_AND) reduce 532) ((T_LOGICAL_OR) reduce 532) ((T_LOGICAL_XOR) reduce 532) ((T_MINUS_EQUAL) reduce 532) ((T_MOD_EQUAL) reduce 532) ((T_MUL_EQUAL) reduce 532) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 532) ((T_OBJECT_OPERATOR) reduce 532) ((T_OR_EQUAL) reduce 532) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 532) ((T_PLUS_EQUAL) reduce 532) ((T_POW) reduce 532) ((T_POW_EQUAL) reduce 532) ((T_SL) reduce 532) ((T_SL_EQUAL) reduce 532) ((T_SPACESHIP) reduce 532) ((T_SR) reduce 532) ((T_SR_EQUAL) reduce 532) ((T_XOR_EQUAL) reduce 532) (("[") reduce 532) (("^") reduce 532) (("{") reduce 532) (("|") reduce 532)) 26754 ((("%") reduce 505) (("(") reduce 542) (("*") reduce 505) (("+") reduce 505) (("-") reduce 505) ((".") reduce 505) (("/") reduce 505) ((";") reduce 505) (("<") reduce 505) ((">") reduce 505) (("?") reduce 505) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 505) ((T_BOOLEAN_AND) reduce 505) ((T_BOOLEAN_OR) reduce 505) ((T_COALESCE) reduce 505) ((T_DOUBLE_ARROW) reduce 505) ((T_INSTANCEOF) reduce 505) ((T_IS_EQUAL) reduce 505) ((T_IS_GREATER_OR_EQUAL) reduce 505) ((T_IS_IDENTICAL) reduce 505) ((T_IS_NOT_EQUAL) reduce 505) ((T_IS_NOT_IDENTICAL) reduce 505) ((T_IS_SMALLER_OR_EQUAL) reduce 505) ((T_LOGICAL_AND) reduce 505) ((T_LOGICAL_OR) reduce 505) ((T_LOGICAL_XOR) reduce 505) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 505) ((T_OBJECT_OPERATOR) reduce 505) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 505) ((T_POW) reduce 505) ((T_SL) reduce 505) ((T_SPACESHIP) reduce 505) ((T_SR) reduce 505) (("[") reduce 505) (("^") reduce 505) (("{") reduce 505) (("|") reduce 505)) 26755 ((("%") reduce 467) (("(") reduce 467) (("*") reduce 467) (("+") reduce 467) (("-") reduce 467) ((".") reduce 467) (("/") reduce 467) ((";") reduce 467) (("<") reduce 467) (("=") reduce 467) ((">") reduce 467) (("?") reduce 467) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 467) ((T_AND_EQUAL) reduce 467) ((T_BOOLEAN_AND) reduce 467) ((T_BOOLEAN_OR) reduce 467) ((T_COALESCE) reduce 467) ((T_COALESCE_EQUAL) reduce 467) ((T_CONCAT_EQUAL) reduce 467) ((T_DEC) reduce 467) ((T_DIV_EQUAL) reduce 467) ((T_DOUBLE_ARROW) reduce 467) ((T_INC) reduce 467) ((T_INSTANCEOF) reduce 467) ((T_IS_EQUAL) reduce 467) ((T_IS_GREATER_OR_EQUAL) reduce 467) ((T_IS_IDENTICAL) reduce 467) ((T_IS_NOT_EQUAL) reduce 467) ((T_IS_NOT_IDENTICAL) reduce 467) ((T_IS_SMALLER_OR_EQUAL) reduce 467) ((T_LOGICAL_AND) reduce 467) ((T_LOGICAL_OR) reduce 467) ((T_LOGICAL_XOR) reduce 467) ((T_MINUS_EQUAL) reduce 467) ((T_MOD_EQUAL) reduce 467) ((T_MUL_EQUAL) reduce 467) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 467) ((T_OBJECT_OPERATOR) reduce 467) ((T_OR_EQUAL) reduce 467) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 467) ((T_PLUS_EQUAL) reduce 467) ((T_POW) reduce 467) ((T_POW_EQUAL) reduce 467) ((T_SL) reduce 467) ((T_SL_EQUAL) reduce 467) ((T_SPACESHIP) reduce 467) ((T_SR) reduce 467) ((T_SR_EQUAL) reduce 467) ((T_XOR_EQUAL) reduce 467) (("[") reduce 467) (("^") reduce 467) (("{") reduce 467) (("|") reduce 467)) 26756 ((("%") reduce 469) (("(") reduce 469) (("*") reduce 469) (("+") reduce 469) (("-") reduce 469) ((".") reduce 469) (("/") reduce 469) ((";") reduce 469) (("<") reduce 469) (("=") reduce 469) ((">") reduce 469) (("?") reduce 469) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 469) ((T_AND_EQUAL) reduce 469) ((T_BOOLEAN_AND) reduce 469) ((T_BOOLEAN_OR) reduce 469) ((T_COALESCE) reduce 469) ((T_COALESCE_EQUAL) reduce 469) ((T_CONCAT_EQUAL) reduce 469) ((T_DEC) reduce 469) ((T_DIV_EQUAL) reduce 469) ((T_DOUBLE_ARROW) reduce 469) ((T_INC) reduce 469) ((T_INSTANCEOF) reduce 469) ((T_IS_EQUAL) reduce 469) ((T_IS_GREATER_OR_EQUAL) reduce 469) ((T_IS_IDENTICAL) reduce 469) ((T_IS_NOT_EQUAL) reduce 469) ((T_IS_NOT_IDENTICAL) reduce 469) ((T_IS_SMALLER_OR_EQUAL) reduce 469) ((T_LOGICAL_AND) reduce 469) ((T_LOGICAL_OR) reduce 469) ((T_LOGICAL_XOR) reduce 469) ((T_MINUS_EQUAL) reduce 469) ((T_MOD_EQUAL) reduce 469) ((T_MUL_EQUAL) reduce 469) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 469) ((T_OBJECT_OPERATOR) reduce 469) ((T_OR_EQUAL) reduce 469) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 469) ((T_PLUS_EQUAL) reduce 469) ((T_POW) reduce 469) ((T_POW_EQUAL) reduce 469) ((T_SL) reduce 469) ((T_SL_EQUAL) reduce 469) ((T_SPACESHIP) reduce 469) ((T_SR) reduce 469) ((T_SR_EQUAL) reduce 469) ((T_XOR_EQUAL) reduce 469) (("[") reduce 469) (("^") reduce 469) (("{") reduce 469) (("|") reduce 469)) 26758 ((("%") reduce 446) (("*") reduce 446) (("+") reduce 446) (("-") reduce 446) ((".") reduce 446) (("/") reduce 446) ((";") reduce 446) (("<") reduce 446) ((">") reduce 446) (("?") reduce 446) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 446) ((T_BOOLEAN_AND) reduce 446) ((T_BOOLEAN_OR) reduce 446) ((T_COALESCE) reduce 446) ((T_DOUBLE_ARROW) reduce 446) ((T_INSTANCEOF) reduce 446) ((T_IS_EQUAL) reduce 446) ((T_IS_GREATER_OR_EQUAL) reduce 446) ((T_IS_IDENTICAL) reduce 446) ((T_IS_NOT_EQUAL) reduce 446) ((T_IS_NOT_IDENTICAL) reduce 446) ((T_IS_SMALLER_OR_EQUAL) reduce 446) ((T_LOGICAL_AND) reduce 446) ((T_LOGICAL_OR) reduce 446) ((T_LOGICAL_XOR) reduce 446) ((T_POW) reduce 446) ((T_SL) reduce 446) ((T_SPACESHIP) reduce 446) ((T_SR) reduce 446) (("^") reduce 446) (("|") reduce 446)) 26759 ((("%") reduce 448) (("*") reduce 448) (("+") reduce 448) (("-") reduce 448) ((".") reduce 448) (("/") reduce 448) ((";") reduce 448) (("<") reduce 448) ((">") reduce 448) (("?") reduce 448) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 448) ((T_BOOLEAN_AND) reduce 448) ((T_BOOLEAN_OR) reduce 448) ((T_COALESCE) reduce 448) ((T_DOUBLE_ARROW) reduce 448) ((T_INSTANCEOF) reduce 448) ((T_IS_EQUAL) reduce 448) ((T_IS_GREATER_OR_EQUAL) reduce 448) ((T_IS_IDENTICAL) reduce 448) ((T_IS_NOT_EQUAL) reduce 448) ((T_IS_NOT_IDENTICAL) reduce 448) ((T_IS_SMALLER_OR_EQUAL) reduce 448) ((T_LOGICAL_AND) reduce 448) ((T_LOGICAL_OR) reduce 448) ((T_LOGICAL_XOR) reduce 448) ((T_POW) reduce 448) ((T_SL) reduce 448) ((T_SPACESHIP) reduce 448) ((T_SR) reduce 448) (("^") reduce 448) (("|") reduce 448)) 26765 ((("%") reduce 521) (("(") reduce 521) (("*") reduce 521) (("+") reduce 521) (("-") reduce 521) ((".") reduce 521) (("/") reduce 521) ((";") reduce 521) (("<") reduce 521) (("=") reduce 521) ((">") reduce 521) (("?") reduce 521) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 521) ((T_AND_EQUAL) reduce 521) ((T_BOOLEAN_AND) reduce 521) ((T_BOOLEAN_OR) reduce 521) ((T_COALESCE) reduce 521) ((T_COALESCE_EQUAL) reduce 521) ((T_CONCAT_EQUAL) reduce 521) ((T_DEC) reduce 521) ((T_DIV_EQUAL) reduce 521) ((T_DOUBLE_ARROW) reduce 521) ((T_INC) reduce 521) ((T_INSTANCEOF) reduce 521) ((T_IS_EQUAL) reduce 521) ((T_IS_GREATER_OR_EQUAL) reduce 521) ((T_IS_IDENTICAL) reduce 521) ((T_IS_NOT_EQUAL) reduce 521) ((T_IS_NOT_IDENTICAL) reduce 521) ((T_IS_SMALLER_OR_EQUAL) reduce 521) ((T_LOGICAL_AND) reduce 521) ((T_LOGICAL_OR) reduce 521) ((T_LOGICAL_XOR) reduce 521) ((T_MINUS_EQUAL) reduce 521) ((T_MOD_EQUAL) reduce 521) ((T_MUL_EQUAL) reduce 521) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 521) ((T_OBJECT_OPERATOR) reduce 521) ((T_OR_EQUAL) reduce 521) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 521) ((T_PLUS_EQUAL) reduce 521) ((T_POW) reduce 521) ((T_POW_EQUAL) reduce 521) ((T_SL) reduce 521) ((T_SL_EQUAL) reduce 521) ((T_SPACESHIP) reduce 521) ((T_SR) reduce 521) ((T_SR_EQUAL) reduce 521) ((T_XOR_EQUAL) reduce 521) (("[") reduce 521) (("^") reduce 521) (("{") reduce 521) (("|") reduce 521)) 26767 ((("%") reduce 520) (("(") reduce 520) (("*") reduce 520) (("+") reduce 520) (("-") reduce 520) ((".") reduce 520) (("/") reduce 520) ((";") reduce 520) (("<") reduce 520) (("=") reduce 520) ((">") reduce 520) (("?") reduce 520) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 520) ((T_AND_EQUAL) reduce 520) ((T_BOOLEAN_AND) reduce 520) ((T_BOOLEAN_OR) reduce 520) ((T_COALESCE) reduce 520) ((T_COALESCE_EQUAL) reduce 520) ((T_CONCAT_EQUAL) reduce 520) ((T_DEC) reduce 520) ((T_DIV_EQUAL) reduce 520) ((T_DOUBLE_ARROW) reduce 520) ((T_INC) reduce 520) ((T_INSTANCEOF) reduce 520) ((T_IS_EQUAL) reduce 520) ((T_IS_GREATER_OR_EQUAL) reduce 520) ((T_IS_IDENTICAL) reduce 520) ((T_IS_NOT_EQUAL) reduce 520) ((T_IS_NOT_IDENTICAL) reduce 520) ((T_IS_SMALLER_OR_EQUAL) reduce 520) ((T_LOGICAL_AND) reduce 520) ((T_LOGICAL_OR) reduce 520) ((T_LOGICAL_XOR) reduce 520) ((T_MINUS_EQUAL) reduce 520) ((T_MOD_EQUAL) reduce 520) ((T_MUL_EQUAL) reduce 520) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 520) ((T_OBJECT_OPERATOR) reduce 520) ((T_OR_EQUAL) reduce 520) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 520) ((T_PLUS_EQUAL) reduce 520) ((T_POW) reduce 520) ((T_POW_EQUAL) reduce 520) ((T_SL) reduce 520) ((T_SL_EQUAL) reduce 520) ((T_SPACESHIP) reduce 520) ((T_SR) reduce 520) ((T_SR_EQUAL) reduce 520) ((T_XOR_EQUAL) reduce 520) (("[") reduce 520) (("^") reduce 520) (("{") reduce 520) (("|") reduce 520)) 26768 ((("%") reduce 544) (("(") reduce 544) (("*") reduce 544) (("+") reduce 544) (("-") reduce 544) ((".") reduce 544) (("/") reduce 544) ((";") reduce 544) (("<") reduce 544) (("=") reduce 544) ((">") reduce 544) (("?") reduce 544) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 544) ((T_AND_EQUAL) reduce 544) ((T_BOOLEAN_AND) reduce 544) ((T_BOOLEAN_OR) reduce 544) ((T_COALESCE) reduce 544) ((T_COALESCE_EQUAL) reduce 544) ((T_CONCAT_EQUAL) reduce 544) ((T_DEC) reduce 544) ((T_DIV_EQUAL) reduce 544) ((T_DOUBLE_ARROW) reduce 544) ((T_INC) reduce 544) ((T_INSTANCEOF) reduce 544) ((T_IS_EQUAL) reduce 544) ((T_IS_GREATER_OR_EQUAL) reduce 544) ((T_IS_IDENTICAL) reduce 544) ((T_IS_NOT_EQUAL) reduce 544) ((T_IS_NOT_IDENTICAL) reduce 544) ((T_IS_SMALLER_OR_EQUAL) reduce 544) ((T_LOGICAL_AND) reduce 544) ((T_LOGICAL_OR) reduce 544) ((T_LOGICAL_XOR) reduce 544) ((T_MINUS_EQUAL) reduce 544) ((T_MOD_EQUAL) reduce 544) ((T_MUL_EQUAL) reduce 544) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 544) ((T_OBJECT_OPERATOR) reduce 544) ((T_OR_EQUAL) reduce 544) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 544) ((T_PLUS_EQUAL) reduce 544) ((T_POW) reduce 544) ((T_POW_EQUAL) reduce 544) ((T_SL) reduce 544) ((T_SL_EQUAL) reduce 544) ((T_SPACESHIP) reduce 544) ((T_SR) reduce 544) ((T_SR_EQUAL) reduce 544) ((T_XOR_EQUAL) reduce 544) (("[") reduce 544) (("^") reduce 544) (("{") reduce 544) (("|") reduce 544)) 26769 ((("%") reduce 527) (("(") shift) (("*") reduce 527) (("+") reduce 527) (("-") reduce 527) ((".") reduce 527) (("/") reduce 527) ((";") reduce 527) (("<") reduce 527) (("=") reduce 527) ((">") reduce 527) (("?") reduce 527) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 527) ((T_AND_EQUAL) reduce 527) ((T_BOOLEAN_AND) reduce 527) ((T_BOOLEAN_OR) reduce 527) ((T_COALESCE) reduce 527) ((T_COALESCE_EQUAL) reduce 527) ((T_CONCAT_EQUAL) reduce 527) ((T_DEC) reduce 527) ((T_DIV_EQUAL) reduce 527) ((T_DOUBLE_ARROW) reduce 527) ((T_INC) reduce 527) ((T_INSTANCEOF) reduce 527) ((T_IS_EQUAL) reduce 527) ((T_IS_GREATER_OR_EQUAL) reduce 527) ((T_IS_IDENTICAL) reduce 527) ((T_IS_NOT_EQUAL) reduce 527) ((T_IS_NOT_IDENTICAL) reduce 527) ((T_IS_SMALLER_OR_EQUAL) reduce 527) ((T_LOGICAL_AND) reduce 527) ((T_LOGICAL_OR) reduce 527) ((T_LOGICAL_XOR) reduce 527) ((T_MINUS_EQUAL) reduce 527) ((T_MOD_EQUAL) reduce 527) ((T_MUL_EQUAL) reduce 527) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 527) ((T_OBJECT_OPERATOR) reduce 527) ((T_OR_EQUAL) reduce 527) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 527) ((T_PLUS_EQUAL) reduce 527) ((T_POW) reduce 527) ((T_POW_EQUAL) reduce 527) ((T_SL) reduce 527) ((T_SL_EQUAL) reduce 527) ((T_SPACESHIP) reduce 527) ((T_SR) reduce 527) ((T_SR_EQUAL) reduce 527) ((T_XOR_EQUAL) reduce 527) (("[") reduce 527) (("^") reduce 527) (("{") reduce 527) (("|") reduce 527)) 26770 ((("%") reduce 546) (("(") reduce 546) (("*") reduce 546) (("+") reduce 546) (("-") reduce 546) ((".") reduce 546) (("/") reduce 546) ((";") reduce 546) (("<") reduce 546) (("=") reduce 546) ((">") reduce 546) (("?") reduce 546) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 546) ((T_AND_EQUAL) reduce 546) ((T_BOOLEAN_AND) reduce 546) ((T_BOOLEAN_OR) reduce 546) ((T_COALESCE) reduce 546) ((T_COALESCE_EQUAL) reduce 546) ((T_CONCAT_EQUAL) reduce 546) ((T_DEC) reduce 546) ((T_DIV_EQUAL) reduce 546) ((T_DOUBLE_ARROW) reduce 546) ((T_INC) reduce 546) ((T_INSTANCEOF) reduce 546) ((T_IS_EQUAL) reduce 546) ((T_IS_GREATER_OR_EQUAL) reduce 546) ((T_IS_IDENTICAL) reduce 546) ((T_IS_NOT_EQUAL) reduce 546) ((T_IS_NOT_IDENTICAL) reduce 546) ((T_IS_SMALLER_OR_EQUAL) reduce 546) ((T_LOGICAL_AND) reduce 546) ((T_LOGICAL_OR) reduce 546) ((T_LOGICAL_XOR) reduce 546) ((T_MINUS_EQUAL) reduce 546) ((T_MOD_EQUAL) reduce 546) ((T_MUL_EQUAL) reduce 546) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 546) ((T_OBJECT_OPERATOR) reduce 546) ((T_OR_EQUAL) reduce 546) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 546) ((T_PLUS_EQUAL) reduce 546) ((T_POW) reduce 546) ((T_POW_EQUAL) reduce 546) ((T_SL) reduce 546) ((T_SL_EQUAL) reduce 546) ((T_SPACESHIP) reduce 546) ((T_SR) reduce 546) ((T_SR_EQUAL) reduce 546) ((T_XOR_EQUAL) reduce 546) (("[") reduce 546) (("^") reduce 546) (("{") reduce 546) (("|") reduce 546)) 26773 ((("%") reduce 545) (("(") reduce 545) (("*") reduce 545) (("+") reduce 545) (("-") reduce 545) ((".") reduce 545) (("/") reduce 545) ((";") reduce 545) (("<") reduce 545) (("=") reduce 545) ((">") reduce 545) (("?") reduce 545) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 545) ((T_AND_EQUAL) reduce 545) ((T_BOOLEAN_AND) reduce 545) ((T_BOOLEAN_OR) reduce 545) ((T_COALESCE) reduce 545) ((T_COALESCE_EQUAL) reduce 545) ((T_CONCAT_EQUAL) reduce 545) ((T_DEC) reduce 545) ((T_DIV_EQUAL) reduce 545) ((T_DOUBLE_ARROW) reduce 545) ((T_INC) reduce 545) ((T_INSTANCEOF) reduce 545) ((T_IS_EQUAL) reduce 545) ((T_IS_GREATER_OR_EQUAL) reduce 545) ((T_IS_IDENTICAL) reduce 545) ((T_IS_NOT_EQUAL) reduce 545) ((T_IS_NOT_IDENTICAL) reduce 545) ((T_IS_SMALLER_OR_EQUAL) reduce 545) ((T_LOGICAL_AND) reduce 545) ((T_LOGICAL_OR) reduce 545) ((T_LOGICAL_XOR) reduce 545) ((T_MINUS_EQUAL) reduce 545) ((T_MOD_EQUAL) reduce 545) ((T_MUL_EQUAL) reduce 545) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 545) ((T_OBJECT_OPERATOR) reduce 545) ((T_OR_EQUAL) reduce 545) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 545) ((T_PLUS_EQUAL) reduce 545) ((T_POW) reduce 545) ((T_POW_EQUAL) reduce 545) ((T_SL) reduce 545) ((T_SL_EQUAL) reduce 545) ((T_SPACESHIP) reduce 545) ((T_SR) reduce 545) ((T_SR_EQUAL) reduce 545) ((T_XOR_EQUAL) reduce 545) (("[") reduce 545) (("^") reduce 545) (("{") reduce 545) (("|") reduce 545)) 26774 ((("%") reduce 522) (("(") reduce 522) (("*") reduce 522) (("+") reduce 522) (("-") reduce 522) ((".") reduce 522) (("/") reduce 522) ((";") reduce 522) (("<") reduce 522) (("=") reduce 522) ((">") reduce 522) (("?") reduce 522) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 522) ((T_AND_EQUAL) reduce 522) ((T_BOOLEAN_AND) reduce 522) ((T_BOOLEAN_OR) reduce 522) ((T_COALESCE) reduce 522) ((T_COALESCE_EQUAL) reduce 522) ((T_CONCAT_EQUAL) reduce 522) ((T_DEC) reduce 522) ((T_DIV_EQUAL) reduce 522) ((T_DOUBLE_ARROW) reduce 522) ((T_INC) reduce 522) ((T_INSTANCEOF) reduce 522) ((T_IS_EQUAL) reduce 522) ((T_IS_GREATER_OR_EQUAL) reduce 522) ((T_IS_IDENTICAL) reduce 522) ((T_IS_NOT_EQUAL) reduce 522) ((T_IS_NOT_IDENTICAL) reduce 522) ((T_IS_SMALLER_OR_EQUAL) reduce 522) ((T_LOGICAL_AND) reduce 522) ((T_LOGICAL_OR) reduce 522) ((T_LOGICAL_XOR) reduce 522) ((T_MINUS_EQUAL) reduce 522) ((T_MOD_EQUAL) reduce 522) ((T_MUL_EQUAL) reduce 522) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 522) ((T_OBJECT_OPERATOR) reduce 522) ((T_OR_EQUAL) reduce 522) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 522) ((T_PLUS_EQUAL) reduce 522) ((T_POW) reduce 522) ((T_POW_EQUAL) reduce 522) ((T_SL) reduce 522) ((T_SL_EQUAL) reduce 522) ((T_SPACESHIP) reduce 522) ((T_SR) reduce 522) ((T_SR_EQUAL) reduce 522) ((T_XOR_EQUAL) reduce 522) (("[") reduce 522) (("^") reduce 522) (("{") reduce 522) (("|") reduce 522)) 26775 ((("%") reduce 528) (("(") shift) (("*") reduce 528) (("+") reduce 528) (("-") reduce 528) ((".") reduce 528) (("/") reduce 528) ((";") reduce 528) (("<") reduce 528) (("=") reduce 528) ((">") reduce 528) (("?") reduce 528) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 528) ((T_AND_EQUAL) reduce 528) ((T_BOOLEAN_AND) reduce 528) ((T_BOOLEAN_OR) reduce 528) ((T_COALESCE) reduce 528) ((T_COALESCE_EQUAL) reduce 528) ((T_CONCAT_EQUAL) reduce 528) ((T_DEC) reduce 528) ((T_DIV_EQUAL) reduce 528) ((T_DOUBLE_ARROW) reduce 528) ((T_INC) reduce 528) ((T_INSTANCEOF) reduce 528) ((T_IS_EQUAL) reduce 528) ((T_IS_GREATER_OR_EQUAL) reduce 528) ((T_IS_IDENTICAL) reduce 528) ((T_IS_NOT_EQUAL) reduce 528) ((T_IS_NOT_IDENTICAL) reduce 528) ((T_IS_SMALLER_OR_EQUAL) reduce 528) ((T_LOGICAL_AND) reduce 528) ((T_LOGICAL_OR) reduce 528) ((T_LOGICAL_XOR) reduce 528) ((T_MINUS_EQUAL) reduce 528) ((T_MOD_EQUAL) reduce 528) ((T_MUL_EQUAL) reduce 528) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 528) ((T_OBJECT_OPERATOR) reduce 528) ((T_OR_EQUAL) reduce 528) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 528) ((T_PLUS_EQUAL) reduce 528) ((T_POW) reduce 528) ((T_POW_EQUAL) reduce 528) ((T_SL) reduce 528) ((T_SL_EQUAL) reduce 528) ((T_SPACESHIP) reduce 528) ((T_SR) reduce 528) ((T_SR_EQUAL) reduce 528) ((T_XOR_EQUAL) reduce 528) (("[") reduce 528) (("^") reduce 528) (("{") reduce 528) (("|") reduce 528)) 26776 ((("%") reduce 523) (("(") reduce 523) (("*") reduce 523) (("+") reduce 523) (("-") reduce 523) ((".") reduce 523) (("/") reduce 523) ((";") reduce 523) (("<") reduce 523) (("=") reduce 523) ((">") reduce 523) (("?") reduce 523) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 523) ((T_AND_EQUAL) reduce 523) ((T_BOOLEAN_AND) reduce 523) ((T_BOOLEAN_OR) reduce 523) ((T_COALESCE) reduce 523) ((T_COALESCE_EQUAL) reduce 523) ((T_CONCAT_EQUAL) reduce 523) ((T_DEC) reduce 523) ((T_DIV_EQUAL) reduce 523) ((T_DOUBLE_ARROW) reduce 523) ((T_INC) reduce 523) ((T_INSTANCEOF) reduce 523) ((T_IS_EQUAL) reduce 523) ((T_IS_GREATER_OR_EQUAL) reduce 523) ((T_IS_IDENTICAL) reduce 523) ((T_IS_NOT_EQUAL) reduce 523) ((T_IS_NOT_IDENTICAL) reduce 523) ((T_IS_SMALLER_OR_EQUAL) reduce 523) ((T_LOGICAL_AND) reduce 523) ((T_LOGICAL_OR) reduce 523) ((T_LOGICAL_XOR) reduce 523) ((T_MINUS_EQUAL) reduce 523) ((T_MOD_EQUAL) reduce 523) ((T_MUL_EQUAL) reduce 523) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 523) ((T_OBJECT_OPERATOR) reduce 523) ((T_OR_EQUAL) reduce 523) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 523) ((T_PLUS_EQUAL) reduce 523) ((T_POW) reduce 523) ((T_POW_EQUAL) reduce 523) ((T_SL) reduce 523) ((T_SL_EQUAL) reduce 523) ((T_SPACESHIP) reduce 523) ((T_SR) reduce 523) ((T_SR_EQUAL) reduce 523) ((T_XOR_EQUAL) reduce 523) (("[") reduce 523) (("^") reduce 523) (("{") reduce 523) (("|") reduce 523)) 26778 ((("%") reduce 438) (("*") reduce 438) (("+") reduce 438) (("-") reduce 438) ((".") reduce 438) (("/") reduce 438) ((";") reduce 438) (("<") reduce 438) ((">") reduce 438) (("?") reduce 438) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 438) ((T_BOOLEAN_AND) reduce 438) ((T_BOOLEAN_OR) reduce 438) ((T_COALESCE) reduce 438) ((T_DOUBLE_ARROW) reduce 438) ((T_INSTANCEOF) reduce 438) ((T_IS_EQUAL) reduce 438) ((T_IS_GREATER_OR_EQUAL) reduce 438) ((T_IS_IDENTICAL) reduce 438) ((T_IS_NOT_EQUAL) reduce 438) ((T_IS_NOT_IDENTICAL) reduce 438) ((T_IS_SMALLER_OR_EQUAL) reduce 438) ((T_LOGICAL_AND) reduce 438) ((T_LOGICAL_OR) reduce 438) ((T_LOGICAL_XOR) reduce 438) ((T_POW) reduce 438) ((T_SL) reduce 438) ((T_SPACESHIP) reduce 438) ((T_SR) reduce 438) (("^") reduce 438) (("|") reduce 438)) 26780 ((("%") reduce 483) (("(") reduce 483) (("*") reduce 483) (("+") reduce 483) (("-") reduce 483) ((".") reduce 483) (("/") reduce 483) ((";") reduce 483) (("<") reduce 483) (("=") shift) ((">") reduce 483) (("?") reduce 483) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 483) ((T_BOOLEAN_AND) reduce 483) ((T_BOOLEAN_OR) reduce 483) ((T_COALESCE) reduce 483) ((T_DOUBLE_ARROW) reduce 483) ((T_INSTANCEOF) reduce 483) ((T_IS_EQUAL) reduce 483) ((T_IS_GREATER_OR_EQUAL) reduce 483) ((T_IS_IDENTICAL) reduce 483) ((T_IS_NOT_EQUAL) reduce 483) ((T_IS_NOT_IDENTICAL) reduce 483) ((T_IS_SMALLER_OR_EQUAL) reduce 483) ((T_LOGICAL_AND) reduce 483) ((T_LOGICAL_OR) reduce 483) ((T_LOGICAL_XOR) reduce 483) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 483) ((T_OBJECT_OPERATOR) reduce 483) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 483) ((T_POW) reduce 483) ((T_SL) reduce 483) ((T_SPACESHIP) reduce 483) ((T_SR) reduce 483) (("[") reduce 483) (("^") reduce 483) (("{") reduce 483) (("|") reduce 483)) 26782 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 369) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 369) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 369) ((T_LOGICAL_OR) reduce 369) ((T_LOGICAL_XOR) reduce 369) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26783 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 443) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 443) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 443) ((T_LOGICAL_OR) reduce 443) ((T_LOGICAL_XOR) reduce 443) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26786 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 442) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 442) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 442) ((T_LOGICAL_OR) reduce 442) ((T_LOGICAL_XOR) reduce 442) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26787 ((("%") reduce 434) (("*") reduce 434) (("+") reduce 434) (("-") reduce 434) ((".") reduce 434) (("/") reduce 434) ((";") reduce 434) (("<") reduce 434) ((">") reduce 434) (("?") reduce 434) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_BOOLEAN_AND) reduce 434) ((T_BOOLEAN_OR) reduce 434) ((T_COALESCE) reduce 434) ((T_DOUBLE_ARROW) reduce 434) ((T_INSTANCEOF) reduce 434) ((T_IS_EQUAL) reduce 434) ((T_IS_GREATER_OR_EQUAL) reduce 434) ((T_IS_IDENTICAL) reduce 434) ((T_IS_NOT_EQUAL) reduce 434) ((T_IS_NOT_IDENTICAL) reduce 434) ((T_IS_SMALLER_OR_EQUAL) reduce 434) ((T_LOGICAL_AND) reduce 434) ((T_LOGICAL_OR) reduce 434) ((T_LOGICAL_XOR) reduce 434) ((T_POW) shift) ((T_SL) reduce 434) ((T_SPACESHIP) reduce 434) ((T_SR) reduce 434) (("^") reduce 434) (("|") reduce 434)) 26788 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 444) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 444) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26789 ((("%") reduce 430) (("*") reduce 430) (("+") reduce 430) (("-") reduce 430) ((".") reduce 430) (("/") reduce 430) ((";") reduce 430) (("<") reduce 430) ((">") reduce 430) (("?") reduce 430) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_BOOLEAN_AND) reduce 430) ((T_BOOLEAN_OR) reduce 430) ((T_COALESCE) reduce 430) ((T_DOUBLE_ARROW) reduce 430) ((T_INSTANCEOF) reduce 430) ((T_IS_EQUAL) reduce 430) ((T_IS_GREATER_OR_EQUAL) reduce 430) ((T_IS_IDENTICAL) reduce 430) ((T_IS_NOT_EQUAL) reduce 430) ((T_IS_NOT_IDENTICAL) reduce 430) ((T_IS_SMALLER_OR_EQUAL) reduce 430) ((T_LOGICAL_AND) reduce 430) ((T_LOGICAL_OR) reduce 430) ((T_LOGICAL_XOR) reduce 430) ((T_POW) shift) ((T_SL) reduce 430) ((T_SPACESHIP) reduce 430) ((T_SR) reduce 430) (("^") reduce 430) (("|") reduce 430)) 26790 ((("%") reduce 447) (("*") reduce 447) (("+") reduce 447) (("-") reduce 447) ((".") reduce 447) (("/") reduce 447) ((";") reduce 447) (("<") reduce 447) ((">") reduce 447) (("?") reduce 447) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 447) ((T_BOOLEAN_AND) reduce 447) ((T_BOOLEAN_OR) reduce 447) ((T_COALESCE) reduce 447) ((T_DOUBLE_ARROW) reduce 447) ((T_INSTANCEOF) reduce 447) ((T_IS_EQUAL) reduce 447) ((T_IS_GREATER_OR_EQUAL) reduce 447) ((T_IS_IDENTICAL) reduce 447) ((T_IS_NOT_EQUAL) reduce 447) ((T_IS_NOT_IDENTICAL) reduce 447) ((T_IS_SMALLER_OR_EQUAL) reduce 447) ((T_LOGICAL_AND) reduce 447) ((T_LOGICAL_OR) reduce 447) ((T_LOGICAL_XOR) reduce 447) ((T_POW) reduce 447) ((T_SL) reduce 447) ((T_SPACESHIP) reduce 447) ((T_SR) reduce 447) (("^") reduce 447) (("|") reduce 447)) 26792 ((("%") reduce 489) (("*") reduce 489) (("+") reduce 489) (("-") reduce 489) ((".") reduce 489) (("/") reduce 489) ((";") reduce 489) (("<") reduce 489) ((">") reduce 489) (("?") reduce 489) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_BOOLEAN_AND) reduce 489) ((T_BOOLEAN_OR) reduce 489) ((T_COALESCE) reduce 489) ((T_DOUBLE_ARROW) reduce 489) ((T_INSTANCEOF) reduce 489) ((T_IS_EQUAL) reduce 489) ((T_IS_GREATER_OR_EQUAL) reduce 489) ((T_IS_IDENTICAL) reduce 489) ((T_IS_NOT_EQUAL) reduce 489) ((T_IS_NOT_IDENTICAL) reduce 489) ((T_IS_SMALLER_OR_EQUAL) reduce 489) ((T_LOGICAL_AND) reduce 489) ((T_LOGICAL_OR) reduce 489) ((T_LOGICAL_XOR) reduce 489) ((T_POW) reduce 489) ((T_SL) reduce 489) ((T_SPACESHIP) reduce 489) ((T_SR) reduce 489) (("^") reduce 489) (("|") reduce 489)) 26794 ((("%") reduce 490) (("*") reduce 490) (("+") reduce 490) (("-") reduce 490) ((".") reduce 490) (("/") reduce 490) ((";") reduce 490) (("<") reduce 490) ((">") reduce 490) (("?") reduce 490) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_BOOLEAN_AND) reduce 490) ((T_BOOLEAN_OR) reduce 490) ((T_COALESCE) reduce 490) ((T_DOUBLE_ARROW) reduce 490) ((T_INSTANCEOF) reduce 490) ((T_IS_EQUAL) reduce 490) ((T_IS_GREATER_OR_EQUAL) reduce 490) ((T_IS_IDENTICAL) reduce 490) ((T_IS_NOT_EQUAL) reduce 490) ((T_IS_NOT_IDENTICAL) reduce 490) ((T_IS_SMALLER_OR_EQUAL) reduce 490) ((T_LOGICAL_AND) reduce 490) ((T_LOGICAL_OR) reduce 490) ((T_LOGICAL_XOR) reduce 490) ((T_POW) reduce 490) ((T_SL) reduce 490) ((T_SPACESHIP) reduce 490) ((T_SR) reduce 490) (("^") reduce 490) (("|") reduce 490)) 26795 ((("%") reduce 488) (("*") reduce 488) (("+") reduce 488) (("-") reduce 488) ((".") reduce 488) (("/") reduce 488) ((";") reduce 488) (("<") reduce 488) ((">") reduce 488) (("?") reduce 488) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_BOOLEAN_AND) reduce 488) ((T_BOOLEAN_OR) reduce 488) ((T_COALESCE) reduce 488) ((T_DOUBLE_ARROW) reduce 488) ((T_INSTANCEOF) reduce 488) ((T_IS_EQUAL) reduce 488) ((T_IS_GREATER_OR_EQUAL) reduce 488) ((T_IS_IDENTICAL) reduce 488) ((T_IS_NOT_EQUAL) reduce 488) ((T_IS_NOT_IDENTICAL) reduce 488) ((T_IS_SMALLER_OR_EQUAL) reduce 488) ((T_LOGICAL_AND) reduce 488) ((T_LOGICAL_OR) reduce 488) ((T_LOGICAL_XOR) reduce 488) ((T_POW) reduce 488) ((T_SL) reduce 488) ((T_SPACESHIP) reduce 488) ((T_SR) reduce 488) (("^") reduce 488) (("|") reduce 488)) 26796 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 581) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 581) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26797 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 580) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 580) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26798 ((("%") reduce 466) (("(") reduce 466) (("*") reduce 466) (("+") reduce 466) (("-") reduce 466) ((".") reduce 466) (("/") reduce 466) ((";") reduce 466) (("<") reduce 466) (("=") reduce 466) ((">") reduce 466) (("?") reduce 466) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 466) ((T_AND_EQUAL) reduce 466) ((T_BOOLEAN_AND) reduce 466) ((T_BOOLEAN_OR) reduce 466) ((T_COALESCE) reduce 466) ((T_COALESCE_EQUAL) reduce 466) ((T_CONCAT_EQUAL) reduce 466) ((T_DEC) reduce 466) ((T_DIV_EQUAL) reduce 466) ((T_DOUBLE_ARROW) reduce 466) ((T_INC) reduce 466) ((T_INSTANCEOF) reduce 466) ((T_IS_EQUAL) reduce 466) ((T_IS_GREATER_OR_EQUAL) reduce 466) ((T_IS_IDENTICAL) reduce 466) ((T_IS_NOT_EQUAL) reduce 466) ((T_IS_NOT_IDENTICAL) reduce 466) ((T_IS_SMALLER_OR_EQUAL) reduce 466) ((T_LOGICAL_AND) reduce 466) ((T_LOGICAL_OR) reduce 466) ((T_LOGICAL_XOR) reduce 466) ((T_MINUS_EQUAL) reduce 466) ((T_MOD_EQUAL) reduce 466) ((T_MUL_EQUAL) reduce 466) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 466) ((T_OBJECT_OPERATOR) reduce 466) ((T_OR_EQUAL) reduce 466) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 466) ((T_PLUS_EQUAL) reduce 466) ((T_POW) reduce 466) ((T_POW_EQUAL) reduce 466) ((T_SL) reduce 466) ((T_SL_EQUAL) reduce 466) ((T_SPACESHIP) reduce 466) ((T_SR) reduce 466) ((T_SR_EQUAL) reduce 466) ((T_XOR_EQUAL) reduce 466) (("[") reduce 466) (("^") reduce 466) (("{") reduce 466) (("|") reduce 466)) 26799 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 439) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 439) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 439) ((T_LOGICAL_OR) reduce 439) ((T_LOGICAL_XOR) reduce 439) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26800 ((("%") reduce 432) (("*") reduce 432) (("+") reduce 432) (("-") reduce 432) ((".") reduce 432) (("/") reduce 432) ((";") reduce 432) (("<") reduce 432) ((">") reduce 432) (("?") reduce 432) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_BOOLEAN_AND) reduce 432) ((T_BOOLEAN_OR) reduce 432) ((T_COALESCE) reduce 432) ((T_DOUBLE_ARROW) reduce 432) ((T_INSTANCEOF) reduce 432) ((T_IS_EQUAL) reduce 432) ((T_IS_GREATER_OR_EQUAL) reduce 432) ((T_IS_IDENTICAL) reduce 432) ((T_IS_NOT_EQUAL) reduce 432) ((T_IS_NOT_IDENTICAL) reduce 432) ((T_IS_SMALLER_OR_EQUAL) reduce 432) ((T_LOGICAL_AND) reduce 432) ((T_LOGICAL_OR) reduce 432) ((T_LOGICAL_XOR) reduce 432) ((T_POW) shift) ((T_SL) reduce 432) ((T_SPACESHIP) reduce 432) ((T_SR) reduce 432) (("^") reduce 432) (("|") reduce 432)) 26802 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) ((";") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_DOUBLE_ARROW) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93)) 26803 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) ((";") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_DOUBLE_ARROW) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92)) 26804 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) ((";") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_DOUBLE_ARROW) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94)) 26805 ((("%") reduce 470) (("(") reduce 470) (("*") reduce 470) (("+") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) ((";") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_DOUBLE_ARROW) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470)) 26806 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) ((";") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_DOUBLE_ARROW) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91)) 26807 ((("%") reduce 365) (("*") reduce 365) (("+") reduce 365) (("-") reduce 365) ((".") reduce 365) (("/") reduce 365) ((";") reduce 365) (("<") reduce 365) ((">") reduce 365) (("?") reduce 365) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_BOOLEAN_AND) reduce 365) ((T_BOOLEAN_OR) reduce 365) ((T_COALESCE) reduce 365) ((T_DOUBLE_ARROW) reduce 365) ((T_INSTANCEOF) reduce 365) ((T_IS_EQUAL) reduce 365) ((T_IS_GREATER_OR_EQUAL) reduce 365) ((T_IS_IDENTICAL) reduce 365) ((T_IS_NOT_EQUAL) reduce 365) ((T_IS_NOT_IDENTICAL) reduce 365) ((T_IS_SMALLER_OR_EQUAL) reduce 365) ((T_LOGICAL_AND) reduce 365) ((T_LOGICAL_OR) reduce 365) ((T_LOGICAL_XOR) reduce 365) ((T_POW) reduce 365) ((T_SL) reduce 365) ((T_SPACESHIP) reduce 365) ((T_SR) reduce 365) (("^") reduce 365) (("|") reduce 365)) 26810 ((("%") reduce 472) (("(") reduce 472) (("*") reduce 472) (("+") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) ((";") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_DOUBLE_ARROW) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472)) 26811 ((("%") reduce 480) (("(") shift) (("*") reduce 480) (("+") reduce 480) (("-") reduce 480) ((".") reduce 480) (("/") reduce 480) ((";") reduce 480) (("<") reduce 480) ((">") reduce 480) (("?") reduce 480) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_BOOLEAN_AND) reduce 480) ((T_BOOLEAN_OR) reduce 480) ((T_COALESCE) reduce 480) ((T_DOUBLE_ARROW) reduce 480) ((T_INSTANCEOF) reduce 480) ((T_IS_EQUAL) reduce 480) ((T_IS_GREATER_OR_EQUAL) reduce 480) ((T_IS_IDENTICAL) reduce 480) ((T_IS_NOT_EQUAL) reduce 480) ((T_IS_NOT_IDENTICAL) reduce 480) ((T_IS_SMALLER_OR_EQUAL) reduce 480) ((T_LOGICAL_AND) reduce 480) ((T_LOGICAL_OR) reduce 480) ((T_LOGICAL_XOR) reduce 480) ((T_POW) reduce 480) ((T_SL) reduce 480) ((T_SPACESHIP) reduce 480) ((T_SR) reduce 480) (("^") reduce 480) (("|") reduce 480)) 26812 ((("%") reduce 471) (("(") reduce 471) (("*") reduce 471) (("+") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) ((";") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_DOUBLE_ARROW) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471)) 26813 ((("%") reduce 473) (("(") reduce 473) (("*") reduce 473) (("+") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) ((";") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_DOUBLE_ARROW) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 26814 ((("%") reduce 534) (("(") reduce 534) (("*") reduce 534) (("+") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) ((";") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_DOUBLE_ARROW) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 26821 ((("%") reduce 536) (("(") reduce 536) (("*") reduce 536) (("+") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) ((";") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_DOUBLE_ARROW) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 26823 ((("%") reduce 535) (("(") reduce 535) (("*") reduce 535) (("+") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) ((";") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_DOUBLE_ARROW) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 26824 ((("%") reduce 540) (("(") reduce 540) (("*") reduce 540) (("+") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) ((";") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_DOUBLE_ARROW) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 26825 ((("%") reduce 537) (("(") reduce 537) (("*") reduce 537) (("+") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) ((";") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_DOUBLE_ARROW) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 26826 ((("%") reduce 538) (("(") reduce 538) (("*") reduce 538) (("+") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) ((";") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_DOUBLE_ARROW) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 26828 ((("%") reduce 481) (("*") reduce 481) (("+") reduce 481) (("-") reduce 481) ((".") reduce 481) (("/") reduce 481) ((";") reduce 481) (("<") reduce 481) ((">") reduce 481) (("?") reduce 481) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_BOOLEAN_AND) reduce 481) ((T_BOOLEAN_OR) reduce 481) ((T_COALESCE) reduce 481) ((T_DOUBLE_ARROW) reduce 481) ((T_INSTANCEOF) reduce 481) ((T_IS_EQUAL) reduce 481) ((T_IS_GREATER_OR_EQUAL) reduce 481) ((T_IS_IDENTICAL) reduce 481) ((T_IS_NOT_EQUAL) reduce 481) ((T_IS_NOT_IDENTICAL) reduce 481) ((T_IS_SMALLER_OR_EQUAL) reduce 481) ((T_LOGICAL_AND) reduce 481) ((T_LOGICAL_OR) reduce 481) ((T_LOGICAL_XOR) reduce 481) ((T_POW) reduce 481) ((T_SL) reduce 481) ((T_SPACESHIP) reduce 481) ((T_SR) reduce 481) (("^") reduce 481) (("|") reduce 481)) 26829 ((("%") reduce 364) (("*") reduce 364) (("+") reduce 364) (("-") reduce 364) ((".") reduce 364) (("/") reduce 364) ((";") reduce 364) (("<") reduce 364) ((">") reduce 364) (("?") reduce 364) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_BOOLEAN_AND) reduce 364) ((T_BOOLEAN_OR) reduce 364) ((T_COALESCE) reduce 364) ((T_DOUBLE_ARROW) reduce 364) ((T_INSTANCEOF) reduce 364) ((T_IS_EQUAL) reduce 364) ((T_IS_GREATER_OR_EQUAL) reduce 364) ((T_IS_IDENTICAL) reduce 364) ((T_IS_NOT_EQUAL) reduce 364) ((T_IS_NOT_IDENTICAL) reduce 364) ((T_IS_SMALLER_OR_EQUAL) reduce 364) ((T_LOGICAL_AND) reduce 364) ((T_LOGICAL_OR) reduce 364) ((T_LOGICAL_XOR) reduce 364) ((T_POW) reduce 364) ((T_SL) reduce 364) ((T_SPACESHIP) reduce 364) ((T_SR) reduce 364) (("^") reduce 364) (("|") reduce 364)) 26830 ((("%") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) ((";") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_DOUBLE_ARROW) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("^") reduce 288) (("|") reduce 288)) 26834 ((("%") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) ((";") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_DOUBLE_ARROW) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("^") reduce 289) (("|") reduce 289)) 26835 ((("%") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) ((";") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_DOUBLE_ARROW) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("^") reduce 290) (("|") reduce 290)) 26837 ((("%") reduce 539) (("(") reduce 539) (("*") reduce 539) (("+") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) ((";") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_DOUBLE_ARROW) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 26838 ((("%") reduce 366) (("*") reduce 366) (("+") reduce 366) (("-") reduce 366) ((".") reduce 366) (("/") reduce 366) ((";") reduce 366) (("<") reduce 366) ((">") reduce 366) (("?") reduce 366) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_BOOLEAN_AND) reduce 366) ((T_BOOLEAN_OR) reduce 366) ((T_COALESCE) reduce 366) ((T_DOUBLE_ARROW) reduce 366) ((T_INSTANCEOF) reduce 366) ((T_IS_EQUAL) reduce 366) ((T_IS_GREATER_OR_EQUAL) reduce 366) ((T_IS_IDENTICAL) reduce 366) ((T_IS_NOT_EQUAL) reduce 366) ((T_IS_NOT_IDENTICAL) reduce 366) ((T_IS_SMALLER_OR_EQUAL) reduce 366) ((T_LOGICAL_AND) reduce 366) ((T_LOGICAL_OR) reduce 366) ((T_LOGICAL_XOR) reduce 366) ((T_POW) reduce 366) ((T_SL) reduce 366) ((T_SPACESHIP) reduce 366) ((T_SR) reduce 366) (("^") reduce 366) (("|") reduce 366)) 26846 ((("%") reduce 363) (("*") reduce 363) (("+") reduce 363) (("-") reduce 363) ((".") reduce 363) (("/") reduce 363) ((";") reduce 363) (("<") reduce 363) ((">") reduce 363) (("?") reduce 363) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_BOOLEAN_AND) reduce 363) ((T_BOOLEAN_OR) reduce 363) ((T_COALESCE) reduce 363) ((T_DOUBLE_ARROW) reduce 363) ((T_INSTANCEOF) reduce 363) ((T_IS_EQUAL) reduce 363) ((T_IS_GREATER_OR_EQUAL) reduce 363) ((T_IS_IDENTICAL) reduce 363) ((T_IS_NOT_EQUAL) reduce 363) ((T_IS_NOT_IDENTICAL) reduce 363) ((T_IS_SMALLER_OR_EQUAL) reduce 363) ((T_LOGICAL_AND) reduce 363) ((T_LOGICAL_OR) reduce 363) ((T_LOGICAL_XOR) reduce 363) ((T_POW) reduce 363) ((T_SL) reduce 363) ((T_SPACESHIP) reduce 363) ((T_SR) reduce 363) (("^") reduce 363) (("|") reduce 363)) 26848 ((("%") reduce 474) (("(") reduce 474) (("*") reduce 474) (("+") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) ((";") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_DOUBLE_ARROW) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474)) 26854 ((("%") reduce 230) (("*") reduce 230) (("+") reduce 230) (("-") reduce 230) ((".") reduce 230) (("/") reduce 230) ((";") reduce 230) (("<") reduce 230) ((">") reduce 230) (("?") reduce 230) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_BOOLEAN_AND) reduce 230) ((T_BOOLEAN_OR) reduce 230) ((T_COALESCE) reduce 230) ((T_DOUBLE_ARROW) reduce 230) ((T_INSTANCEOF) reduce 230) ((T_IS_EQUAL) reduce 230) ((T_IS_GREATER_OR_EQUAL) reduce 230) ((T_IS_IDENTICAL) reduce 230) ((T_IS_NOT_EQUAL) reduce 230) ((T_IS_NOT_IDENTICAL) reduce 230) ((T_IS_SMALLER_OR_EQUAL) reduce 230) ((T_LOGICAL_AND) reduce 230) ((T_LOGICAL_OR) reduce 230) ((T_LOGICAL_XOR) reduce 230) ((T_POW) reduce 230) ((T_SL) reduce 230) ((T_SPACESHIP) reduce 230) ((T_SR) reduce 230) (("^") reduce 230) (("|") reduce 230)) 26859 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 368) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 368) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 368) ((T_LOGICAL_OR) reduce 368) ((T_LOGICAL_XOR) reduce 368) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26863 ((("%") reduce 575) (("*") reduce 575) (("+") reduce 575) (("-") reduce 575) ((".") reduce 575) (("/") reduce 575) ((";") reduce 575) (("<") reduce 575) ((">") reduce 575) (("?") reduce 575) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_BOOLEAN_AND) reduce 575) ((T_BOOLEAN_OR) reduce 575) ((T_COALESCE) reduce 575) ((T_DOUBLE_ARROW) reduce 575) ((T_INSTANCEOF) reduce 575) ((T_IS_EQUAL) reduce 575) ((T_IS_GREATER_OR_EQUAL) reduce 575) ((T_IS_IDENTICAL) reduce 575) ((T_IS_NOT_EQUAL) reduce 575) ((T_IS_NOT_IDENTICAL) reduce 575) ((T_IS_SMALLER_OR_EQUAL) reduce 575) ((T_LOGICAL_AND) reduce 575) ((T_LOGICAL_OR) reduce 575) ((T_LOGICAL_XOR) reduce 575) ((T_POW) reduce 575) ((T_SL) reduce 575) ((T_SPACESHIP) reduce 575) ((T_SR) reduce 575) (("^") reduce 575) (("|") reduce 575)) 26864 ((("%") reduce 428) (("*") reduce 428) (("+") reduce 428) (("-") reduce 428) ((".") reduce 428) (("/") reduce 428) ((";") reduce 428) (("<") reduce 428) ((">") reduce 428) (("?") reduce 428) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_BOOLEAN_AND) reduce 428) ((T_BOOLEAN_OR) reduce 428) ((T_COALESCE) reduce 428) ((T_DOUBLE_ARROW) reduce 428) ((T_INSTANCEOF) reduce 428) ((T_IS_EQUAL) reduce 428) ((T_IS_GREATER_OR_EQUAL) reduce 428) ((T_IS_IDENTICAL) reduce 428) ((T_IS_NOT_EQUAL) reduce 428) ((T_IS_NOT_IDENTICAL) reduce 428) ((T_IS_SMALLER_OR_EQUAL) reduce 428) ((T_LOGICAL_AND) reduce 428) ((T_LOGICAL_OR) reduce 428) ((T_LOGICAL_XOR) reduce 428) ((T_POW) shift) ((T_SL) reduce 428) ((T_SPACESHIP) reduce 428) ((T_SR) reduce 428) (("^") reduce 428) (("|") reduce 428)) 26865 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 578) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 578) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26866 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 577) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_DOUBLE_ARROW) reduce 577) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26867 ((("%") reduce 387) (("*") reduce 387) (("+") reduce 387) (("-") reduce 387) ((".") reduce 387) (("/") reduce 387) ((";") reduce 387) (("<") reduce 387) ((">") reduce 387) (("?") reduce 387) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_BOOLEAN_AND) reduce 387) ((T_BOOLEAN_OR) reduce 387) ((T_COALESCE) reduce 387) ((T_DOUBLE_ARROW) reduce 387) ((T_INSTANCEOF) reduce 387) ((T_IS_EQUAL) reduce 387) ((T_IS_GREATER_OR_EQUAL) reduce 387) ((T_IS_IDENTICAL) reduce 387) ((T_IS_NOT_EQUAL) reduce 387) ((T_IS_NOT_IDENTICAL) reduce 387) ((T_IS_SMALLER_OR_EQUAL) reduce 387) ((T_LOGICAL_AND) reduce 387) ((T_LOGICAL_OR) reduce 387) ((T_LOGICAL_XOR) reduce 387) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 387) ((T_SL) reduce 387) ((T_SPACESHIP) reduce 387) ((T_SR) reduce 387) (("[") reduce 510) (("^") reduce 387) (("{") reduce 510) (("|") reduce 387)) 26869 ((("%") reduce 435) (("*") reduce 435) (("+") reduce 435) (("-") reduce 435) ((".") reduce 435) (("/") reduce 435) ((";") reduce 435) (("<") reduce 435) ((">") reduce 435) (("?") reduce 435) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_BOOLEAN_AND) reduce 435) ((T_BOOLEAN_OR) reduce 435) ((T_COALESCE) reduce 435) ((T_DOUBLE_ARROW) reduce 435) ((T_INSTANCEOF) reduce 435) ((T_IS_EQUAL) reduce 435) ((T_IS_GREATER_OR_EQUAL) reduce 435) ((T_IS_IDENTICAL) reduce 435) ((T_IS_NOT_EQUAL) reduce 435) ((T_IS_NOT_IDENTICAL) reduce 435) ((T_IS_SMALLER_OR_EQUAL) reduce 435) ((T_LOGICAL_AND) reduce 435) ((T_LOGICAL_OR) reduce 435) ((T_LOGICAL_XOR) reduce 435) ((T_POW) reduce 435) ((T_SL) reduce 435) ((T_SPACESHIP) reduce 435) ((T_SR) reduce 435) (("^") reduce 435) (("|") reduce 435)) 26871 ((("%") reduce 476) (("*") reduce 476) (("+") reduce 476) (("-") reduce 476) ((".") reduce 476) (("/") reduce 476) ((";") reduce 476) (("<") reduce 476) ((">") reduce 476) (("?") reduce 476) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_BOOLEAN_AND) reduce 476) ((T_BOOLEAN_OR) reduce 476) ((T_COALESCE) reduce 476) ((T_DOUBLE_ARROW) reduce 476) ((T_INSTANCEOF) reduce 476) ((T_IS_EQUAL) reduce 476) ((T_IS_GREATER_OR_EQUAL) reduce 476) ((T_IS_IDENTICAL) reduce 476) ((T_IS_NOT_EQUAL) reduce 476) ((T_IS_NOT_IDENTICAL) reduce 476) ((T_IS_SMALLER_OR_EQUAL) reduce 476) ((T_LOGICAL_AND) reduce 476) ((T_LOGICAL_OR) reduce 476) ((T_LOGICAL_XOR) reduce 476) ((T_POW) reduce 476) ((T_SL) reduce 476) ((T_SPACESHIP) reduce 476) ((T_SR) reduce 476) (("^") reduce 476) (("|") reduce 476)) 26874 ((("%") reduce 579) (("*") reduce 579) (("+") reduce 579) (("-") reduce 579) ((".") reduce 579) (("/") reduce 579) ((";") reduce 579) (("<") reduce 579) ((">") reduce 579) (("?") reduce 579) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_BOOLEAN_AND) reduce 579) ((T_BOOLEAN_OR) reduce 579) ((T_COALESCE) reduce 579) ((T_DOUBLE_ARROW) reduce 579) ((T_INSTANCEOF) reduce 579) ((T_IS_EQUAL) reduce 579) ((T_IS_GREATER_OR_EQUAL) reduce 579) ((T_IS_IDENTICAL) reduce 579) ((T_IS_NOT_EQUAL) reduce 579) ((T_IS_NOT_IDENTICAL) reduce 579) ((T_IS_SMALLER_OR_EQUAL) reduce 579) ((T_LOGICAL_AND) reduce 579) ((T_LOGICAL_OR) reduce 579) ((T_LOGICAL_XOR) reduce 579) ((T_POW) reduce 579) ((T_SL) reduce 579) ((T_SPACESHIP) reduce 579) ((T_SR) reduce 579) (("^") reduce 579) (("|") reduce 579)) 26877 ((("%") reduce 576) (("*") reduce 576) (("+") reduce 576) (("-") reduce 576) ((".") reduce 576) (("/") reduce 576) ((";") reduce 576) (("<") reduce 576) ((">") reduce 576) (("?") reduce 576) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_BOOLEAN_AND) reduce 576) ((T_BOOLEAN_OR) reduce 576) ((T_COALESCE) reduce 576) ((T_DOUBLE_ARROW) reduce 576) ((T_INSTANCEOF) reduce 576) ((T_IS_EQUAL) reduce 576) ((T_IS_GREATER_OR_EQUAL) reduce 576) ((T_IS_IDENTICAL) reduce 576) ((T_IS_NOT_EQUAL) reduce 576) ((T_IS_NOT_IDENTICAL) reduce 576) ((T_IS_SMALLER_OR_EQUAL) reduce 576) ((T_LOGICAL_AND) reduce 576) ((T_LOGICAL_OR) reduce 576) ((T_LOGICAL_XOR) reduce 576) ((T_POW) reduce 576) ((T_SL) reduce 576) ((T_SPACESHIP) reduce 576) ((T_SR) reduce 576) (("^") reduce 576) (("|") reduce 576)) 26878 ((("%") reduce 429) (("*") reduce 429) (("+") reduce 429) (("-") reduce 429) ((".") reduce 429) (("/") reduce 429) ((";") reduce 429) (("<") reduce 429) ((">") reduce 429) (("?") reduce 429) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_BOOLEAN_AND) reduce 429) ((T_BOOLEAN_OR) reduce 429) ((T_COALESCE) reduce 429) ((T_DOUBLE_ARROW) reduce 429) ((T_INSTANCEOF) reduce 429) ((T_IS_EQUAL) reduce 429) ((T_IS_GREATER_OR_EQUAL) reduce 429) ((T_IS_IDENTICAL) reduce 429) ((T_IS_NOT_EQUAL) reduce 429) ((T_IS_NOT_IDENTICAL) reduce 429) ((T_IS_SMALLER_OR_EQUAL) reduce 429) ((T_LOGICAL_AND) reduce 429) ((T_LOGICAL_OR) reduce 429) ((T_LOGICAL_XOR) reduce 429) ((T_POW) shift) ((T_SL) reduce 429) ((T_SPACESHIP) reduce 429) ((T_SR) reduce 429) (("^") reduce 429) (("|") reduce 429)) 26879 ((("%") reduce 389) (("*") reduce 389) (("+") reduce 389) (("-") reduce 389) ((".") reduce 389) (("/") reduce 389) ((";") reduce 389) (("<") reduce 389) ((">") reduce 389) (("?") reduce 389) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_BOOLEAN_AND) reduce 389) ((T_BOOLEAN_OR) reduce 389) ((T_COALESCE) reduce 389) ((T_DOUBLE_ARROW) reduce 389) ((T_INSTANCEOF) reduce 389) ((T_IS_EQUAL) reduce 389) ((T_IS_GREATER_OR_EQUAL) reduce 389) ((T_IS_IDENTICAL) reduce 389) ((T_IS_NOT_EQUAL) reduce 389) ((T_IS_NOT_IDENTICAL) reduce 389) ((T_IS_SMALLER_OR_EQUAL) reduce 389) ((T_LOGICAL_AND) reduce 389) ((T_LOGICAL_OR) reduce 389) ((T_LOGICAL_XOR) reduce 389) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 389) ((T_SL) reduce 389) ((T_SPACESHIP) reduce 389) ((T_SR) reduce 389) (("[") reduce 510) (("^") reduce 389) (("{") reduce 510) (("|") reduce 389)) 26880 ((("%") reduce 372) (("*") reduce 372) (("+") reduce 372) (("-") reduce 372) ((".") reduce 372) (("/") reduce 372) ((";") reduce 372) (("<") reduce 372) ((">") reduce 372) (("?") reduce 372) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_BOOLEAN_AND) reduce 372) ((T_BOOLEAN_OR) reduce 372) ((T_COALESCE) reduce 372) ((T_DOUBLE_ARROW) reduce 372) ((T_INSTANCEOF) reduce 372) ((T_IS_EQUAL) reduce 372) ((T_IS_GREATER_OR_EQUAL) reduce 372) ((T_IS_IDENTICAL) reduce 372) ((T_IS_NOT_EQUAL) reduce 372) ((T_IS_NOT_IDENTICAL) reduce 372) ((T_IS_SMALLER_OR_EQUAL) reduce 372) ((T_LOGICAL_AND) reduce 372) ((T_LOGICAL_OR) reduce 372) ((T_LOGICAL_XOR) reduce 372) ((T_POW) reduce 372) ((T_SL) reduce 372) ((T_SPACESHIP) reduce 372) ((T_SR) reduce 372) (("^") reduce 372) (("|") reduce 372)) 26881 ((("%") reduce 433) (("*") reduce 433) (("+") reduce 433) (("-") reduce 433) ((".") reduce 433) (("/") reduce 433) ((";") reduce 433) (("<") reduce 433) ((">") reduce 433) (("?") reduce 433) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_BOOLEAN_AND) reduce 433) ((T_BOOLEAN_OR) reduce 433) ((T_COALESCE) reduce 433) ((T_DOUBLE_ARROW) reduce 433) ((T_INSTANCEOF) reduce 433) ((T_IS_EQUAL) reduce 433) ((T_IS_GREATER_OR_EQUAL) reduce 433) ((T_IS_IDENTICAL) reduce 433) ((T_IS_NOT_EQUAL) reduce 433) ((T_IS_NOT_IDENTICAL) reduce 433) ((T_IS_SMALLER_OR_EQUAL) reduce 433) ((T_LOGICAL_AND) reduce 433) ((T_LOGICAL_OR) reduce 433) ((T_LOGICAL_XOR) reduce 433) ((T_POW) shift) ((T_SL) reduce 433) ((T_SPACESHIP) reduce 433) ((T_SR) reduce 433) (("^") reduce 433) (("|") reduce 433)) 26882 ((("%") reduce 431) (("*") reduce 431) (("+") reduce 431) (("-") reduce 431) ((".") reduce 431) (("/") reduce 431) ((";") reduce 431) (("<") reduce 431) ((">") reduce 431) (("?") reduce 431) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_BOOLEAN_AND) reduce 431) ((T_BOOLEAN_OR) reduce 431) ((T_COALESCE) reduce 431) ((T_DOUBLE_ARROW) reduce 431) ((T_INSTANCEOF) reduce 431) ((T_IS_EQUAL) reduce 431) ((T_IS_GREATER_OR_EQUAL) reduce 431) ((T_IS_IDENTICAL) reduce 431) ((T_IS_NOT_EQUAL) reduce 431) ((T_IS_NOT_IDENTICAL) reduce 431) ((T_IS_SMALLER_OR_EQUAL) reduce 431) ((T_LOGICAL_AND) reduce 431) ((T_LOGICAL_OR) reduce 431) ((T_LOGICAL_XOR) reduce 431) ((T_POW) shift) ((T_SL) reduce 431) ((T_SPACESHIP) reduce 431) ((T_SR) reduce 431) (("^") reduce 431) (("|") reduce 431)) 26885 ((("%") reduce 482) (("(") reduce 482) (("*") reduce 482) (("+") reduce 482) (("-") reduce 482) ((".") reduce 482) (("/") reduce 482) ((";") reduce 482) (("<") reduce 482) ((">") reduce 482) (("?") reduce 482) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_BOOLEAN_AND) reduce 482) ((T_BOOLEAN_OR) reduce 482) ((T_COALESCE) reduce 482) ((T_DOUBLE_ARROW) reduce 482) ((T_INSTANCEOF) reduce 482) ((T_IS_EQUAL) reduce 482) ((T_IS_GREATER_OR_EQUAL) reduce 482) ((T_IS_IDENTICAL) reduce 482) ((T_IS_NOT_EQUAL) reduce 482) ((T_IS_NOT_IDENTICAL) reduce 482) ((T_IS_SMALLER_OR_EQUAL) reduce 482) ((T_LOGICAL_AND) reduce 482) ((T_LOGICAL_OR) reduce 482) ((T_LOGICAL_XOR) reduce 482) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 482) ((T_OBJECT_OPERATOR) reduce 482) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 482) ((T_POW) reduce 482) ((T_SL) reduce 482) ((T_SPACESHIP) reduce 482) ((T_SR) reduce 482) (("[") reduce 482) (("^") reduce 482) (("{") reduce 482) (("|") reduce 482)) 26886 ((("%") reduce 436) (("*") reduce 436) (("+") reduce 436) (("-") reduce 436) ((".") reduce 436) (("/") reduce 436) ((";") reduce 436) (("<") reduce 436) ((">") reduce 436) (("?") reduce 436) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_BOOLEAN_AND) reduce 436) ((T_BOOLEAN_OR) reduce 436) ((T_COALESCE) reduce 436) ((T_DOUBLE_ARROW) reduce 436) ((T_INSTANCEOF) reduce 436) ((T_IS_EQUAL) reduce 436) ((T_IS_GREATER_OR_EQUAL) reduce 436) ((T_IS_IDENTICAL) reduce 436) ((T_IS_NOT_EQUAL) reduce 436) ((T_IS_NOT_IDENTICAL) reduce 436) ((T_IS_SMALLER_OR_EQUAL) reduce 436) ((T_LOGICAL_AND) reduce 436) ((T_LOGICAL_OR) reduce 436) ((T_LOGICAL_XOR) reduce 436) ((T_POW) shift) ((T_SL) reduce 436) ((T_SPACESHIP) reduce 436) ((T_SR) reduce 436) (("^") reduce 436) (("|") reduce 436)) 26887 ((("%") reduce 409) (("*") reduce 409) (("+") reduce 409) (("-") reduce 409) ((".") reduce 409) (("/") reduce 409) ((";") reduce 409) (("<") reduce 409) ((">") reduce 409) (("?") reduce 409) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_BOOLEAN_AND) reduce 409) ((T_BOOLEAN_OR) reduce 409) ((T_COALESCE) reduce 409) ((T_DOUBLE_ARROW) reduce 409) ((T_INSTANCEOF) reduce 409) ((T_IS_EQUAL) reduce 409) ((T_IS_GREATER_OR_EQUAL) reduce 409) ((T_IS_IDENTICAL) reduce 409) ((T_IS_NOT_EQUAL) reduce 409) ((T_IS_NOT_IDENTICAL) reduce 409) ((T_IS_SMALLER_OR_EQUAL) reduce 409) ((T_LOGICAL_AND) reduce 409) ((T_LOGICAL_OR) reduce 409) ((T_LOGICAL_XOR) reduce 409) ((T_POW) shift) ((T_SL) reduce 409) ((T_SPACESHIP) reduce 409) ((T_SR) reduce 409) (("^") reduce 409) (("|") reduce 409)) 26888 ((("%") reduce 408) (("*") reduce 408) (("+") reduce 408) (("-") reduce 408) ((".") reduce 408) (("/") reduce 408) ((";") reduce 408) (("<") reduce 408) ((">") reduce 408) (("?") reduce 408) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_BOOLEAN_AND) reduce 408) ((T_BOOLEAN_OR) reduce 408) ((T_COALESCE) reduce 408) ((T_DOUBLE_ARROW) reduce 408) ((T_INSTANCEOF) reduce 408) ((T_IS_EQUAL) reduce 408) ((T_IS_GREATER_OR_EQUAL) reduce 408) ((T_IS_IDENTICAL) reduce 408) ((T_IS_NOT_EQUAL) reduce 408) ((T_IS_NOT_IDENTICAL) reduce 408) ((T_IS_SMALLER_OR_EQUAL) reduce 408) ((T_LOGICAL_AND) reduce 408) ((T_LOGICAL_OR) reduce 408) ((T_LOGICAL_XOR) reduce 408) ((T_POW) shift) ((T_SL) reduce 408) ((T_SPACESHIP) reduce 408) ((T_SR) reduce 408) (("^") reduce 408) (("|") reduce 408)) 26890 ((("%") reduce 422) (("(") reduce 517) (("*") reduce 422) (("+") reduce 422) (("-") reduce 422) ((".") reduce 422) (("/") reduce 422) ((";") reduce 422) (("<") reduce 422) ((">") reduce 422) (("?") reduce 422) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_BOOLEAN_AND) reduce 422) ((T_BOOLEAN_OR) reduce 422) ((T_COALESCE) reduce 422) ((T_DOUBLE_ARROW) reduce 422) ((T_INSTANCEOF) reduce 422) ((T_IS_EQUAL) reduce 422) ((T_IS_GREATER_OR_EQUAL) reduce 422) ((T_IS_IDENTICAL) reduce 422) ((T_IS_NOT_EQUAL) reduce 422) ((T_IS_NOT_IDENTICAL) reduce 422) ((T_IS_SMALLER_OR_EQUAL) reduce 422) ((T_LOGICAL_AND) reduce 422) ((T_LOGICAL_OR) reduce 422) ((T_LOGICAL_XOR) reduce 422) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 511) ((T_OBJECT_OPERATOR) reduce 511) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 511) ((T_POW) reduce 422) ((T_SL) reduce 422) ((T_SPACESHIP) reduce 422) ((T_SR) reduce 422) (("[") reduce 511) (("^") reduce 422) (("{") reduce 511) (("|") reduce 422)) 26891 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) ((";") reduce 531) (("<") reduce 531) (("=") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AND_EQUAL) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_COALESCE_EQUAL) reduce 531) ((T_CONCAT_EQUAL) reduce 531) ((T_DEC) reduce 531) ((T_DIV_EQUAL) reduce 531) ((T_DOUBLE_ARROW) reduce 531) ((T_INC) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_MINUS_EQUAL) reduce 531) ((T_MOD_EQUAL) reduce 531) ((T_MUL_EQUAL) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_OR_EQUAL) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_PLUS_EQUAL) reduce 531) ((T_POW) reduce 531) ((T_POW_EQUAL) reduce 531) ((T_SL) reduce 531) ((T_SL_EQUAL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) ((T_SR_EQUAL) reduce 531) ((T_XOR_EQUAL) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 26894 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) ((";") reduce 530) (("<") reduce 530) (("=") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AND_EQUAL) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_COALESCE_EQUAL) reduce 530) ((T_CONCAT_EQUAL) reduce 530) ((T_DEC) reduce 530) ((T_DIV_EQUAL) reduce 530) ((T_DOUBLE_ARROW) reduce 530) ((T_INC) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_MINUS_EQUAL) reduce 530) ((T_MOD_EQUAL) reduce 530) ((T_MUL_EQUAL) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_OR_EQUAL) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_PLUS_EQUAL) reduce 530) ((T_POW) reduce 530) ((T_POW_EQUAL) reduce 530) ((T_SL) reduce 530) ((T_SL_EQUAL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) ((T_SR_EQUAL) reduce 530) ((T_XOR_EQUAL) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 26896 ((("%") reduce 485) (("(") reduce 485) (("*") reduce 485) (("+") reduce 485) (("-") reduce 485) ((".") reduce 485) (("/") reduce 485) ((";") reduce 485) (("<") reduce 485) ((">") reduce 485) (("?") reduce 485) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_BOOLEAN_AND) reduce 485) ((T_BOOLEAN_OR) reduce 485) ((T_COALESCE) reduce 485) ((T_DOUBLE_ARROW) reduce 485) ((T_INSTANCEOF) reduce 485) ((T_IS_EQUAL) reduce 485) ((T_IS_GREATER_OR_EQUAL) reduce 485) ((T_IS_IDENTICAL) reduce 485) ((T_IS_NOT_EQUAL) reduce 485) ((T_IS_NOT_IDENTICAL) reduce 485) ((T_IS_SMALLER_OR_EQUAL) reduce 485) ((T_LOGICAL_AND) reduce 485) ((T_LOGICAL_OR) reduce 485) ((T_LOGICAL_XOR) reduce 485) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 485) ((T_OBJECT_OPERATOR) reduce 485) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 485) ((T_POW) reduce 485) ((T_SL) reduce 485) ((T_SPACESHIP) reduce 485) ((T_SR) reduce 485) (("[") reduce 485) (("^") reduce 485) (("{") reduce 485) (("|") reduce 485)) 26897 ((("%") reduce 410) (("*") reduce 410) (("+") reduce 410) (("-") reduce 410) ((".") reduce 410) (("/") reduce 410) ((";") reduce 410) (("<") reduce 410) ((">") reduce 410) (("?") reduce 410) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_BOOLEAN_AND) reduce 410) ((T_BOOLEAN_OR) reduce 410) ((T_COALESCE) reduce 410) ((T_DOUBLE_ARROW) reduce 410) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 410) ((T_IS_GREATER_OR_EQUAL) reduce 410) ((T_IS_IDENTICAL) reduce 410) ((T_IS_NOT_EQUAL) reduce 410) ((T_IS_NOT_IDENTICAL) reduce 410) ((T_IS_SMALLER_OR_EQUAL) reduce 410) ((T_LOGICAL_AND) reduce 410) ((T_LOGICAL_OR) reduce 410) ((T_LOGICAL_XOR) reduce 410) ((T_POW) shift) ((T_SL) reduce 410) ((T_SPACESHIP) reduce 410) ((T_SR) reduce 410) (("^") reduce 410) (("|") reduce 410)) 26898 ((("%") reduce 434) (("*") reduce 434) (("+") reduce 434) (("-") reduce 434) ((".") reduce 434) (("/") reduce 434) ((";") reduce 434) (("<") reduce 434) ((">") reduce 434) (("?") reduce 434) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 434) ((T_BOOLEAN_AND) reduce 434) ((T_BOOLEAN_OR) reduce 434) ((T_COALESCE) reduce 434) ((T_INSTANCEOF) reduce 434) ((T_IS_EQUAL) reduce 434) ((T_IS_GREATER_OR_EQUAL) reduce 434) ((T_IS_IDENTICAL) reduce 434) ((T_IS_NOT_EQUAL) reduce 434) ((T_IS_NOT_IDENTICAL) reduce 434) ((T_IS_SMALLER_OR_EQUAL) reduce 434) ((T_LOGICAL_AND) reduce 434) ((T_LOGICAL_OR) reduce 434) ((T_LOGICAL_XOR) reduce 434) ((T_POW) shift) ((T_SL) reduce 434) ((T_SPACESHIP) reduce 434) ((T_SR) reduce 434) (("^") reduce 434) (("|") reduce 434)) 26899 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 444) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26900 ((("%") reduce 430) (("*") reduce 430) (("+") reduce 430) (("-") reduce 430) ((".") reduce 430) (("/") reduce 430) ((";") reduce 430) (("<") reduce 430) ((">") reduce 430) (("?") reduce 430) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 430) ((T_BOOLEAN_AND) reduce 430) ((T_BOOLEAN_OR) reduce 430) ((T_COALESCE) reduce 430) ((T_INSTANCEOF) reduce 430) ((T_IS_EQUAL) reduce 430) ((T_IS_GREATER_OR_EQUAL) reduce 430) ((T_IS_IDENTICAL) reduce 430) ((T_IS_NOT_EQUAL) reduce 430) ((T_IS_NOT_IDENTICAL) reduce 430) ((T_IS_SMALLER_OR_EQUAL) reduce 430) ((T_LOGICAL_AND) reduce 430) ((T_LOGICAL_OR) reduce 430) ((T_LOGICAL_XOR) reduce 430) ((T_POW) shift) ((T_SL) reduce 430) ((T_SPACESHIP) reduce 430) ((T_SR) reduce 430) (("^") reduce 430) (("|") reduce 430)) 26903 ((("%") reduce 489) (("*") reduce 489) (("+") reduce 489) (("-") reduce 489) ((".") reduce 489) (("/") reduce 489) ((";") reduce 489) (("<") reduce 489) ((">") reduce 489) (("?") reduce 489) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 489) ((T_BOOLEAN_AND) reduce 489) ((T_BOOLEAN_OR) reduce 489) ((T_COALESCE) reduce 489) ((T_INSTANCEOF) reduce 489) ((T_IS_EQUAL) reduce 489) ((T_IS_GREATER_OR_EQUAL) reduce 489) ((T_IS_IDENTICAL) reduce 489) ((T_IS_NOT_EQUAL) reduce 489) ((T_IS_NOT_IDENTICAL) reduce 489) ((T_IS_SMALLER_OR_EQUAL) reduce 489) ((T_LOGICAL_AND) reduce 489) ((T_LOGICAL_OR) reduce 489) ((T_LOGICAL_XOR) reduce 489) ((T_POW) reduce 489) ((T_SL) reduce 489) ((T_SPACESHIP) reduce 489) ((T_SR) reduce 489) (("^") reduce 489) (("|") reduce 489)) 26905 ((("%") reduce 490) (("*") reduce 490) (("+") reduce 490) (("-") reduce 490) ((".") reduce 490) (("/") reduce 490) ((";") reduce 490) (("<") reduce 490) ((">") reduce 490) (("?") reduce 490) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 490) ((T_BOOLEAN_AND) reduce 490) ((T_BOOLEAN_OR) reduce 490) ((T_COALESCE) reduce 490) ((T_INSTANCEOF) reduce 490) ((T_IS_EQUAL) reduce 490) ((T_IS_GREATER_OR_EQUAL) reduce 490) ((T_IS_IDENTICAL) reduce 490) ((T_IS_NOT_EQUAL) reduce 490) ((T_IS_NOT_IDENTICAL) reduce 490) ((T_IS_SMALLER_OR_EQUAL) reduce 490) ((T_LOGICAL_AND) reduce 490) ((T_LOGICAL_OR) reduce 490) ((T_LOGICAL_XOR) reduce 490) ((T_POW) reduce 490) ((T_SL) reduce 490) ((T_SPACESHIP) reduce 490) ((T_SR) reduce 490) (("^") reduce 490) (("|") reduce 490)) 26906 ((("%") reduce 488) (("*") reduce 488) (("+") reduce 488) (("-") reduce 488) ((".") reduce 488) (("/") reduce 488) ((";") reduce 488) (("<") reduce 488) ((">") reduce 488) (("?") reduce 488) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 488) ((T_BOOLEAN_AND) reduce 488) ((T_BOOLEAN_OR) reduce 488) ((T_COALESCE) reduce 488) ((T_INSTANCEOF) reduce 488) ((T_IS_EQUAL) reduce 488) ((T_IS_GREATER_OR_EQUAL) reduce 488) ((T_IS_IDENTICAL) reduce 488) ((T_IS_NOT_EQUAL) reduce 488) ((T_IS_NOT_IDENTICAL) reduce 488) ((T_IS_SMALLER_OR_EQUAL) reduce 488) ((T_LOGICAL_AND) reduce 488) ((T_LOGICAL_OR) reduce 488) ((T_LOGICAL_XOR) reduce 488) ((T_POW) reduce 488) ((T_SL) reduce 488) ((T_SPACESHIP) reduce 488) ((T_SR) reduce 488) (("^") reduce 488) (("|") reduce 488)) 26907 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 581) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26908 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 580) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26910 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 439) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 439) ((T_LOGICAL_OR) reduce 439) ((T_LOGICAL_XOR) reduce 439) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26911 ((("%") reduce 432) (("*") reduce 432) (("+") reduce 432) (("-") reduce 432) ((".") reduce 432) (("/") reduce 432) ((";") reduce 432) (("<") reduce 432) ((">") reduce 432) (("?") reduce 432) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 432) ((T_BOOLEAN_AND) reduce 432) ((T_BOOLEAN_OR) reduce 432) ((T_COALESCE) reduce 432) ((T_INSTANCEOF) reduce 432) ((T_IS_EQUAL) reduce 432) ((T_IS_GREATER_OR_EQUAL) reduce 432) ((T_IS_IDENTICAL) reduce 432) ((T_IS_NOT_EQUAL) reduce 432) ((T_IS_NOT_IDENTICAL) reduce 432) ((T_IS_SMALLER_OR_EQUAL) reduce 432) ((T_LOGICAL_AND) reduce 432) ((T_LOGICAL_OR) reduce 432) ((T_LOGICAL_XOR) reduce 432) ((T_POW) shift) ((T_SL) reduce 432) ((T_SPACESHIP) reduce 432) ((T_SR) reduce 432) (("^") reduce 432) (("|") reduce 432)) 26913 ((("%") reduce 93) (("(") reduce 93) (("*") reduce 93) (("+") reduce 93) (("-") reduce 93) ((".") reduce 93) (("/") reduce 93) ((";") reduce 93) (("<") reduce 93) ((">") reduce 93) (("?") reduce 93) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 93) ((T_BOOLEAN_AND) reduce 93) ((T_BOOLEAN_OR) reduce 93) ((T_COALESCE) reduce 93) ((T_INSTANCEOF) reduce 93) ((T_IS_EQUAL) reduce 93) ((T_IS_GREATER_OR_EQUAL) reduce 93) ((T_IS_IDENTICAL) reduce 93) ((T_IS_NOT_EQUAL) reduce 93) ((T_IS_NOT_IDENTICAL) reduce 93) ((T_IS_SMALLER_OR_EQUAL) reduce 93) ((T_LOGICAL_AND) reduce 93) ((T_LOGICAL_OR) reduce 93) ((T_LOGICAL_XOR) reduce 93) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 93) ((T_POW) reduce 93) ((T_SL) reduce 93) ((T_SPACESHIP) reduce 93) ((T_SR) reduce 93) (("^") reduce 93) (("|") reduce 93)) 26914 ((("%") reduce 92) (("(") reduce 92) (("*") reduce 92) (("+") reduce 92) (("-") reduce 92) ((".") reduce 92) (("/") reduce 92) ((";") reduce 92) (("<") reduce 92) ((">") reduce 92) (("?") reduce 92) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 92) ((T_BOOLEAN_AND) reduce 92) ((T_BOOLEAN_OR) reduce 92) ((T_COALESCE) reduce 92) ((T_INSTANCEOF) reduce 92) ((T_IS_EQUAL) reduce 92) ((T_IS_GREATER_OR_EQUAL) reduce 92) ((T_IS_IDENTICAL) reduce 92) ((T_IS_NOT_EQUAL) reduce 92) ((T_IS_NOT_IDENTICAL) reduce 92) ((T_IS_SMALLER_OR_EQUAL) reduce 92) ((T_LOGICAL_AND) reduce 92) ((T_LOGICAL_OR) reduce 92) ((T_LOGICAL_XOR) reduce 92) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 92) ((T_POW) reduce 92) ((T_SL) reduce 92) ((T_SPACESHIP) reduce 92) ((T_SR) reduce 92) (("^") reduce 92) (("|") reduce 92)) 26915 ((("%") reduce 94) (("(") reduce 94) (("*") reduce 94) (("+") reduce 94) (("-") reduce 94) ((".") reduce 94) (("/") reduce 94) ((";") reduce 94) (("<") reduce 94) ((">") reduce 94) (("?") reduce 94) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 94) ((T_BOOLEAN_AND) reduce 94) ((T_BOOLEAN_OR) reduce 94) ((T_COALESCE) reduce 94) ((T_INSTANCEOF) reduce 94) ((T_IS_EQUAL) reduce 94) ((T_IS_GREATER_OR_EQUAL) reduce 94) ((T_IS_IDENTICAL) reduce 94) ((T_IS_NOT_EQUAL) reduce 94) ((T_IS_NOT_IDENTICAL) reduce 94) ((T_IS_SMALLER_OR_EQUAL) reduce 94) ((T_LOGICAL_AND) reduce 94) ((T_LOGICAL_OR) reduce 94) ((T_LOGICAL_XOR) reduce 94) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 94) ((T_POW) reduce 94) ((T_SL) reduce 94) ((T_SPACESHIP) reduce 94) ((T_SR) reduce 94) (("^") reduce 94) (("|") reduce 94)) 26916 ((("%") reduce 470) (("(") reduce 470) (("*") reduce 470) (("+") reduce 470) (("-") reduce 470) ((".") reduce 470) (("/") reduce 470) ((";") reduce 470) (("<") reduce 470) ((">") reduce 470) (("?") reduce 470) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 470) ((T_BOOLEAN_AND) reduce 470) ((T_BOOLEAN_OR) reduce 470) ((T_COALESCE) reduce 470) ((T_INSTANCEOF) reduce 470) ((T_IS_EQUAL) reduce 470) ((T_IS_GREATER_OR_EQUAL) reduce 470) ((T_IS_IDENTICAL) reduce 470) ((T_IS_NOT_EQUAL) reduce 470) ((T_IS_NOT_IDENTICAL) reduce 470) ((T_IS_SMALLER_OR_EQUAL) reduce 470) ((T_LOGICAL_AND) reduce 470) ((T_LOGICAL_OR) reduce 470) ((T_LOGICAL_XOR) reduce 470) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 470) ((T_POW) reduce 470) ((T_SL) reduce 470) ((T_SPACESHIP) reduce 470) ((T_SR) reduce 470) (("^") reduce 470) (("|") reduce 470)) 26917 ((("%") reduce 91) (("(") reduce 91) (("*") reduce 91) (("+") reduce 91) (("-") reduce 91) ((".") reduce 91) (("/") reduce 91) ((";") reduce 91) (("<") reduce 91) ((">") reduce 91) (("?") reduce 91) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 91) ((T_BOOLEAN_AND) reduce 91) ((T_BOOLEAN_OR) reduce 91) ((T_COALESCE) reduce 91) ((T_INSTANCEOF) reduce 91) ((T_IS_EQUAL) reduce 91) ((T_IS_GREATER_OR_EQUAL) reduce 91) ((T_IS_IDENTICAL) reduce 91) ((T_IS_NOT_EQUAL) reduce 91) ((T_IS_NOT_IDENTICAL) reduce 91) ((T_IS_SMALLER_OR_EQUAL) reduce 91) ((T_LOGICAL_AND) reduce 91) ((T_LOGICAL_OR) reduce 91) ((T_LOGICAL_XOR) reduce 91) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 91) ((T_POW) reduce 91) ((T_SL) reduce 91) ((T_SPACESHIP) reduce 91) ((T_SR) reduce 91) (("^") reduce 91) (("|") reduce 91)) 26918 ((("%") reduce 365) (("*") reduce 365) (("+") reduce 365) (("-") reduce 365) ((".") reduce 365) (("/") reduce 365) ((";") reduce 365) (("<") reduce 365) ((">") reduce 365) (("?") reduce 365) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 365) ((T_BOOLEAN_AND) reduce 365) ((T_BOOLEAN_OR) reduce 365) ((T_COALESCE) reduce 365) ((T_INSTANCEOF) reduce 365) ((T_IS_EQUAL) reduce 365) ((T_IS_GREATER_OR_EQUAL) reduce 365) ((T_IS_IDENTICAL) reduce 365) ((T_IS_NOT_EQUAL) reduce 365) ((T_IS_NOT_IDENTICAL) reduce 365) ((T_IS_SMALLER_OR_EQUAL) reduce 365) ((T_LOGICAL_AND) reduce 365) ((T_LOGICAL_OR) reduce 365) ((T_LOGICAL_XOR) reduce 365) ((T_POW) reduce 365) ((T_SL) reduce 365) ((T_SPACESHIP) reduce 365) ((T_SR) reduce 365) (("^") reduce 365) (("|") reduce 365)) 26921 ((("%") reduce 472) (("(") reduce 472) (("*") reduce 472) (("+") reduce 472) (("-") reduce 472) ((".") reduce 472) (("/") reduce 472) ((";") reduce 472) (("<") reduce 472) ((">") reduce 472) (("?") reduce 472) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 472) ((T_BOOLEAN_AND) reduce 472) ((T_BOOLEAN_OR) reduce 472) ((T_COALESCE) reduce 472) ((T_INSTANCEOF) reduce 472) ((T_IS_EQUAL) reduce 472) ((T_IS_GREATER_OR_EQUAL) reduce 472) ((T_IS_IDENTICAL) reduce 472) ((T_IS_NOT_EQUAL) reduce 472) ((T_IS_NOT_IDENTICAL) reduce 472) ((T_IS_SMALLER_OR_EQUAL) reduce 472) ((T_LOGICAL_AND) reduce 472) ((T_LOGICAL_OR) reduce 472) ((T_LOGICAL_XOR) reduce 472) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 472) ((T_SL) reduce 472) ((T_SPACESHIP) reduce 472) ((T_SR) reduce 472) (("^") reduce 472) (("|") reduce 472)) 26922 ((("%") reduce 480) (("(") shift) (("*") reduce 480) (("+") reduce 480) (("-") reduce 480) ((".") reduce 480) (("/") reduce 480) ((";") reduce 480) (("<") reduce 480) ((">") reduce 480) (("?") reduce 480) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 480) ((T_BOOLEAN_AND) reduce 480) ((T_BOOLEAN_OR) reduce 480) ((T_COALESCE) reduce 480) ((T_INSTANCEOF) reduce 480) ((T_IS_EQUAL) reduce 480) ((T_IS_GREATER_OR_EQUAL) reduce 480) ((T_IS_IDENTICAL) reduce 480) ((T_IS_NOT_EQUAL) reduce 480) ((T_IS_NOT_IDENTICAL) reduce 480) ((T_IS_SMALLER_OR_EQUAL) reduce 480) ((T_LOGICAL_AND) reduce 480) ((T_LOGICAL_OR) reduce 480) ((T_LOGICAL_XOR) reduce 480) ((T_POW) reduce 480) ((T_SL) reduce 480) ((T_SPACESHIP) reduce 480) ((T_SR) reduce 480) (("^") reduce 480) (("|") reduce 480)) 26923 ((("%") reduce 471) (("(") reduce 471) (("*") reduce 471) (("+") reduce 471) (("-") reduce 471) ((".") reduce 471) (("/") reduce 471) ((";") reduce 471) (("<") reduce 471) ((">") reduce 471) (("?") reduce 471) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 471) ((T_BOOLEAN_AND) reduce 471) ((T_BOOLEAN_OR) reduce 471) ((T_COALESCE) reduce 471) ((T_INSTANCEOF) reduce 471) ((T_IS_EQUAL) reduce 471) ((T_IS_GREATER_OR_EQUAL) reduce 471) ((T_IS_IDENTICAL) reduce 471) ((T_IS_NOT_EQUAL) reduce 471) ((T_IS_NOT_IDENTICAL) reduce 471) ((T_IS_SMALLER_OR_EQUAL) reduce 471) ((T_LOGICAL_AND) reduce 471) ((T_LOGICAL_OR) reduce 471) ((T_LOGICAL_XOR) reduce 471) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 471) ((T_POW) reduce 471) ((T_SL) reduce 471) ((T_SPACESHIP) reduce 471) ((T_SR) reduce 471) (("^") reduce 471) (("|") reduce 471)) 26924 ((("%") reduce 473) (("(") reduce 473) (("*") reduce 473) (("+") reduce 473) (("-") reduce 473) ((".") reduce 473) (("/") reduce 473) ((";") reduce 473) (("<") reduce 473) ((">") reduce 473) (("?") reduce 473) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 473) ((T_BOOLEAN_AND) reduce 473) ((T_BOOLEAN_OR) reduce 473) ((T_COALESCE) reduce 473) ((T_INSTANCEOF) reduce 473) ((T_IS_EQUAL) reduce 473) ((T_IS_GREATER_OR_EQUAL) reduce 473) ((T_IS_IDENTICAL) reduce 473) ((T_IS_NOT_EQUAL) reduce 473) ((T_IS_NOT_IDENTICAL) reduce 473) ((T_IS_SMALLER_OR_EQUAL) reduce 473) ((T_LOGICAL_AND) reduce 473) ((T_LOGICAL_OR) reduce 473) ((T_LOGICAL_XOR) reduce 473) ((T_NULLSAFE_OBJECT_OPERATOR) shift) ((T_OBJECT_OPERATOR) shift) ((T_PAAMAYIM_NEKUDOTAYIM) shift) ((T_POW) reduce 473) ((T_SL) reduce 473) ((T_SPACESHIP) reduce 473) ((T_SR) reduce 473) (("[") shift) (("^") reduce 473) (("{") shift) (("|") reduce 473)) 26925 ((("%") reduce 534) (("(") reduce 534) (("*") reduce 534) (("+") reduce 534) (("-") reduce 534) ((".") reduce 534) (("/") reduce 534) ((";") reduce 534) (("<") reduce 534) ((">") reduce 534) (("?") reduce 534) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 534) ((T_BOOLEAN_AND) reduce 534) ((T_BOOLEAN_OR) reduce 534) ((T_COALESCE) reduce 534) ((T_INSTANCEOF) reduce 534) ((T_IS_EQUAL) reduce 534) ((T_IS_GREATER_OR_EQUAL) reduce 534) ((T_IS_IDENTICAL) reduce 534) ((T_IS_NOT_EQUAL) reduce 534) ((T_IS_NOT_IDENTICAL) reduce 534) ((T_IS_SMALLER_OR_EQUAL) reduce 534) ((T_LOGICAL_AND) reduce 534) ((T_LOGICAL_OR) reduce 534) ((T_LOGICAL_XOR) reduce 534) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 534) ((T_OBJECT_OPERATOR) reduce 534) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 534) ((T_POW) reduce 534) ((T_SL) reduce 534) ((T_SPACESHIP) reduce 534) ((T_SR) reduce 534) (("[") reduce 534) (("^") reduce 534) (("{") reduce 534) (("|") reduce 534)) 26932 ((("%") reduce 536) (("(") reduce 536) (("*") reduce 536) (("+") reduce 536) (("-") reduce 536) ((".") reduce 536) (("/") reduce 536) ((";") reduce 536) (("<") reduce 536) ((">") reduce 536) (("?") reduce 536) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 536) ((T_BOOLEAN_AND) reduce 536) ((T_BOOLEAN_OR) reduce 536) ((T_COALESCE) reduce 536) ((T_INSTANCEOF) reduce 536) ((T_IS_EQUAL) reduce 536) ((T_IS_GREATER_OR_EQUAL) reduce 536) ((T_IS_IDENTICAL) reduce 536) ((T_IS_NOT_EQUAL) reduce 536) ((T_IS_NOT_IDENTICAL) reduce 536) ((T_IS_SMALLER_OR_EQUAL) reduce 536) ((T_LOGICAL_AND) reduce 536) ((T_LOGICAL_OR) reduce 536) ((T_LOGICAL_XOR) reduce 536) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 536) ((T_OBJECT_OPERATOR) reduce 536) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 536) ((T_POW) reduce 536) ((T_SL) reduce 536) ((T_SPACESHIP) reduce 536) ((T_SR) reduce 536) (("[") reduce 536) (("^") reduce 536) (("{") reduce 536) (("|") reduce 536)) 26934 ((("%") reduce 535) (("(") reduce 535) (("*") reduce 535) (("+") reduce 535) (("-") reduce 535) ((".") reduce 535) (("/") reduce 535) ((";") reduce 535) (("<") reduce 535) ((">") reduce 535) (("?") reduce 535) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 535) ((T_BOOLEAN_AND) reduce 535) ((T_BOOLEAN_OR) reduce 535) ((T_COALESCE) reduce 535) ((T_INSTANCEOF) reduce 535) ((T_IS_EQUAL) reduce 535) ((T_IS_GREATER_OR_EQUAL) reduce 535) ((T_IS_IDENTICAL) reduce 535) ((T_IS_NOT_EQUAL) reduce 535) ((T_IS_NOT_IDENTICAL) reduce 535) ((T_IS_SMALLER_OR_EQUAL) reduce 535) ((T_LOGICAL_AND) reduce 535) ((T_LOGICAL_OR) reduce 535) ((T_LOGICAL_XOR) reduce 535) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 535) ((T_OBJECT_OPERATOR) reduce 535) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 535) ((T_POW) reduce 535) ((T_SL) reduce 535) ((T_SPACESHIP) reduce 535) ((T_SR) reduce 535) (("[") reduce 535) (("^") reduce 535) (("{") reduce 535) (("|") reduce 535)) 26935 ((("%") reduce 540) (("(") reduce 540) (("*") reduce 540) (("+") reduce 540) (("-") reduce 540) ((".") reduce 540) (("/") reduce 540) ((";") reduce 540) (("<") reduce 540) ((">") reduce 540) (("?") reduce 540) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 540) ((T_BOOLEAN_AND) reduce 540) ((T_BOOLEAN_OR) reduce 540) ((T_COALESCE) reduce 540) ((T_INSTANCEOF) reduce 540) ((T_IS_EQUAL) reduce 540) ((T_IS_GREATER_OR_EQUAL) reduce 540) ((T_IS_IDENTICAL) reduce 540) ((T_IS_NOT_EQUAL) reduce 540) ((T_IS_NOT_IDENTICAL) reduce 540) ((T_IS_SMALLER_OR_EQUAL) reduce 540) ((T_LOGICAL_AND) reduce 540) ((T_LOGICAL_OR) reduce 540) ((T_LOGICAL_XOR) reduce 540) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 540) ((T_OBJECT_OPERATOR) reduce 540) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 540) ((T_POW) reduce 540) ((T_SL) reduce 540) ((T_SPACESHIP) reduce 540) ((T_SR) reduce 540) (("[") reduce 540) (("^") reduce 540) (("{") reduce 540) (("|") reduce 540)) 26936 ((("%") reduce 537) (("(") reduce 537) (("*") reduce 537) (("+") reduce 537) (("-") reduce 537) ((".") reduce 537) (("/") reduce 537) ((";") reduce 537) (("<") reduce 537) ((">") reduce 537) (("?") reduce 537) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 537) ((T_BOOLEAN_AND) reduce 537) ((T_BOOLEAN_OR) reduce 537) ((T_COALESCE) reduce 537) ((T_INSTANCEOF) reduce 537) ((T_IS_EQUAL) reduce 537) ((T_IS_GREATER_OR_EQUAL) reduce 537) ((T_IS_IDENTICAL) reduce 537) ((T_IS_NOT_EQUAL) reduce 537) ((T_IS_NOT_IDENTICAL) reduce 537) ((T_IS_SMALLER_OR_EQUAL) reduce 537) ((T_LOGICAL_AND) reduce 537) ((T_LOGICAL_OR) reduce 537) ((T_LOGICAL_XOR) reduce 537) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 537) ((T_OBJECT_OPERATOR) reduce 537) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 537) ((T_POW) reduce 537) ((T_SL) reduce 537) ((T_SPACESHIP) reduce 537) ((T_SR) reduce 537) (("[") reduce 537) (("^") reduce 537) (("{") reduce 537) (("|") reduce 537)) 26937 ((("%") reduce 538) (("(") reduce 538) (("*") reduce 538) (("+") reduce 538) (("-") reduce 538) ((".") reduce 538) (("/") reduce 538) ((";") reduce 538) (("<") reduce 538) ((">") reduce 538) (("?") reduce 538) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 538) ((T_BOOLEAN_AND) reduce 538) ((T_BOOLEAN_OR) reduce 538) ((T_COALESCE) reduce 538) ((T_INSTANCEOF) reduce 538) ((T_IS_EQUAL) reduce 538) ((T_IS_GREATER_OR_EQUAL) reduce 538) ((T_IS_IDENTICAL) reduce 538) ((T_IS_NOT_EQUAL) reduce 538) ((T_IS_NOT_IDENTICAL) reduce 538) ((T_IS_SMALLER_OR_EQUAL) reduce 538) ((T_LOGICAL_AND) reduce 538) ((T_LOGICAL_OR) reduce 538) ((T_LOGICAL_XOR) reduce 538) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 538) ((T_OBJECT_OPERATOR) reduce 538) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 538) ((T_POW) reduce 538) ((T_SL) reduce 538) ((T_SPACESHIP) reduce 538) ((T_SR) reduce 538) (("[") reduce 538) (("^") reduce 538) (("{") reduce 538) (("|") reduce 538)) 26939 ((("%") reduce 481) (("*") reduce 481) (("+") reduce 481) (("-") reduce 481) ((".") reduce 481) (("/") reduce 481) ((";") reduce 481) (("<") reduce 481) ((">") reduce 481) (("?") reduce 481) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 481) ((T_BOOLEAN_AND) reduce 481) ((T_BOOLEAN_OR) reduce 481) ((T_COALESCE) reduce 481) ((T_INSTANCEOF) reduce 481) ((T_IS_EQUAL) reduce 481) ((T_IS_GREATER_OR_EQUAL) reduce 481) ((T_IS_IDENTICAL) reduce 481) ((T_IS_NOT_EQUAL) reduce 481) ((T_IS_NOT_IDENTICAL) reduce 481) ((T_IS_SMALLER_OR_EQUAL) reduce 481) ((T_LOGICAL_AND) reduce 481) ((T_LOGICAL_OR) reduce 481) ((T_LOGICAL_XOR) reduce 481) ((T_POW) reduce 481) ((T_SL) reduce 481) ((T_SPACESHIP) reduce 481) ((T_SR) reduce 481) (("^") reduce 481) (("|") reduce 481)) 26940 ((("%") reduce 364) (("*") reduce 364) (("+") reduce 364) (("-") reduce 364) ((".") reduce 364) (("/") reduce 364) ((";") reduce 364) (("<") reduce 364) ((">") reduce 364) (("?") reduce 364) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 364) ((T_BOOLEAN_AND) reduce 364) ((T_BOOLEAN_OR) reduce 364) ((T_COALESCE) reduce 364) ((T_INSTANCEOF) reduce 364) ((T_IS_EQUAL) reduce 364) ((T_IS_GREATER_OR_EQUAL) reduce 364) ((T_IS_IDENTICAL) reduce 364) ((T_IS_NOT_EQUAL) reduce 364) ((T_IS_NOT_IDENTICAL) reduce 364) ((T_IS_SMALLER_OR_EQUAL) reduce 364) ((T_LOGICAL_AND) reduce 364) ((T_LOGICAL_OR) reduce 364) ((T_LOGICAL_XOR) reduce 364) ((T_POW) reduce 364) ((T_SL) reduce 364) ((T_SPACESHIP) reduce 364) ((T_SR) reduce 364) (("^") reduce 364) (("|") reduce 364)) 26941 ((("%") reduce 288) (("*") reduce 288) (("+") reduce 288) (("-") reduce 288) ((".") reduce 288) (("/") reduce 288) ((";") reduce 288) (("<") reduce 288) ((">") reduce 288) (("?") reduce 288) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 288) ((T_BOOLEAN_AND) reduce 288) ((T_BOOLEAN_OR) reduce 288) ((T_COALESCE) reduce 288) ((T_INSTANCEOF) reduce 288) ((T_IS_EQUAL) reduce 288) ((T_IS_GREATER_OR_EQUAL) reduce 288) ((T_IS_IDENTICAL) reduce 288) ((T_IS_NOT_EQUAL) reduce 288) ((T_IS_NOT_IDENTICAL) reduce 288) ((T_IS_SMALLER_OR_EQUAL) reduce 288) ((T_LOGICAL_AND) reduce 288) ((T_LOGICAL_OR) reduce 288) ((T_LOGICAL_XOR) reduce 288) ((T_POW) reduce 288) ((T_SL) reduce 288) ((T_SPACESHIP) reduce 288) ((T_SR) reduce 288) (("^") reduce 288) (("|") reduce 288)) 26945 ((("%") reduce 289) (("*") reduce 289) (("+") reduce 289) (("-") reduce 289) ((".") reduce 289) (("/") reduce 289) ((";") reduce 289) (("<") reduce 289) ((">") reduce 289) (("?") reduce 289) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 289) ((T_BOOLEAN_AND) reduce 289) ((T_BOOLEAN_OR) reduce 289) ((T_COALESCE) reduce 289) ((T_INSTANCEOF) reduce 289) ((T_IS_EQUAL) reduce 289) ((T_IS_GREATER_OR_EQUAL) reduce 289) ((T_IS_IDENTICAL) reduce 289) ((T_IS_NOT_EQUAL) reduce 289) ((T_IS_NOT_IDENTICAL) reduce 289) ((T_IS_SMALLER_OR_EQUAL) reduce 289) ((T_LOGICAL_AND) reduce 289) ((T_LOGICAL_OR) reduce 289) ((T_LOGICAL_XOR) reduce 289) ((T_POW) reduce 289) ((T_SL) reduce 289) ((T_SPACESHIP) reduce 289) ((T_SR) reduce 289) (("^") reduce 289) (("|") reduce 289)) 26946 ((("%") reduce 290) (("*") reduce 290) (("+") reduce 290) (("-") reduce 290) ((".") reduce 290) (("/") reduce 290) ((";") reduce 290) (("<") reduce 290) ((">") reduce 290) (("?") reduce 290) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 290) ((T_BOOLEAN_AND) reduce 290) ((T_BOOLEAN_OR) reduce 290) ((T_COALESCE) reduce 290) ((T_INSTANCEOF) reduce 290) ((T_IS_EQUAL) reduce 290) ((T_IS_GREATER_OR_EQUAL) reduce 290) ((T_IS_IDENTICAL) reduce 290) ((T_IS_NOT_EQUAL) reduce 290) ((T_IS_NOT_IDENTICAL) reduce 290) ((T_IS_SMALLER_OR_EQUAL) reduce 290) ((T_LOGICAL_AND) reduce 290) ((T_LOGICAL_OR) reduce 290) ((T_LOGICAL_XOR) reduce 290) ((T_POW) reduce 290) ((T_SL) reduce 290) ((T_SPACESHIP) reduce 290) ((T_SR) reduce 290) (("^") reduce 290) (("|") reduce 290)) 26948 ((("%") reduce 539) (("(") reduce 539) (("*") reduce 539) (("+") reduce 539) (("-") reduce 539) ((".") reduce 539) (("/") reduce 539) ((";") reduce 539) (("<") reduce 539) ((">") reduce 539) (("?") reduce 539) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 539) ((T_BOOLEAN_AND) reduce 539) ((T_BOOLEAN_OR) reduce 539) ((T_COALESCE) reduce 539) ((T_INSTANCEOF) reduce 539) ((T_IS_EQUAL) reduce 539) ((T_IS_GREATER_OR_EQUAL) reduce 539) ((T_IS_IDENTICAL) reduce 539) ((T_IS_NOT_EQUAL) reduce 539) ((T_IS_NOT_IDENTICAL) reduce 539) ((T_IS_SMALLER_OR_EQUAL) reduce 539) ((T_LOGICAL_AND) reduce 539) ((T_LOGICAL_OR) reduce 539) ((T_LOGICAL_XOR) reduce 539) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 539) ((T_OBJECT_OPERATOR) reduce 539) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 539) ((T_POW) reduce 539) ((T_SL) reduce 539) ((T_SPACESHIP) reduce 539) ((T_SR) reduce 539) (("[") reduce 539) (("^") reduce 539) (("{") reduce 539) (("|") reduce 539)) 26949 ((("%") reduce 366) (("*") reduce 366) (("+") reduce 366) (("-") reduce 366) ((".") reduce 366) (("/") reduce 366) ((";") reduce 366) (("<") reduce 366) ((">") reduce 366) (("?") reduce 366) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 366) ((T_BOOLEAN_AND) reduce 366) ((T_BOOLEAN_OR) reduce 366) ((T_COALESCE) reduce 366) ((T_INSTANCEOF) reduce 366) ((T_IS_EQUAL) reduce 366) ((T_IS_GREATER_OR_EQUAL) reduce 366) ((T_IS_IDENTICAL) reduce 366) ((T_IS_NOT_EQUAL) reduce 366) ((T_IS_NOT_IDENTICAL) reduce 366) ((T_IS_SMALLER_OR_EQUAL) reduce 366) ((T_LOGICAL_AND) reduce 366) ((T_LOGICAL_OR) reduce 366) ((T_LOGICAL_XOR) reduce 366) ((T_POW) reduce 366) ((T_SL) reduce 366) ((T_SPACESHIP) reduce 366) ((T_SR) reduce 366) (("^") reduce 366) (("|") reduce 366)) 26957 ((("%") reduce 363) (("*") reduce 363) (("+") reduce 363) (("-") reduce 363) ((".") reduce 363) (("/") reduce 363) ((";") reduce 363) (("<") reduce 363) ((">") reduce 363) (("?") reduce 363) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 363) ((T_BOOLEAN_AND) reduce 363) ((T_BOOLEAN_OR) reduce 363) ((T_COALESCE) reduce 363) ((T_INSTANCEOF) reduce 363) ((T_IS_EQUAL) reduce 363) ((T_IS_GREATER_OR_EQUAL) reduce 363) ((T_IS_IDENTICAL) reduce 363) ((T_IS_NOT_EQUAL) reduce 363) ((T_IS_NOT_IDENTICAL) reduce 363) ((T_IS_SMALLER_OR_EQUAL) reduce 363) ((T_LOGICAL_AND) reduce 363) ((T_LOGICAL_OR) reduce 363) ((T_LOGICAL_XOR) reduce 363) ((T_POW) reduce 363) ((T_SL) reduce 363) ((T_SPACESHIP) reduce 363) ((T_SR) reduce 363) (("^") reduce 363) (("|") reduce 363)) 26959 ((("%") reduce 474) (("(") reduce 474) (("*") reduce 474) (("+") reduce 474) (("-") reduce 474) ((".") reduce 474) (("/") reduce 474) ((";") reduce 474) (("<") reduce 474) ((">") reduce 474) (("?") reduce 474) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 474) ((T_BOOLEAN_AND) reduce 474) ((T_BOOLEAN_OR) reduce 474) ((T_COALESCE) reduce 474) ((T_INSTANCEOF) reduce 474) ((T_IS_EQUAL) reduce 474) ((T_IS_GREATER_OR_EQUAL) reduce 474) ((T_IS_IDENTICAL) reduce 474) ((T_IS_NOT_EQUAL) reduce 474) ((T_IS_NOT_IDENTICAL) reduce 474) ((T_IS_SMALLER_OR_EQUAL) reduce 474) ((T_LOGICAL_AND) reduce 474) ((T_LOGICAL_OR) reduce 474) ((T_LOGICAL_XOR) reduce 474) ((T_POW) reduce 474) ((T_SL) reduce 474) ((T_SPACESHIP) reduce 474) ((T_SR) reduce 474) (("^") reduce 474) (("|") reduce 474)) 26965 ((("%") reduce 230) (("*") reduce 230) (("+") reduce 230) (("-") reduce 230) ((".") reduce 230) (("/") reduce 230) ((";") reduce 230) (("<") reduce 230) ((">") reduce 230) (("?") reduce 230) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 230) ((T_BOOLEAN_AND) reduce 230) ((T_BOOLEAN_OR) reduce 230) ((T_COALESCE) reduce 230) ((T_INSTANCEOF) reduce 230) ((T_IS_EQUAL) reduce 230) ((T_IS_GREATER_OR_EQUAL) reduce 230) ((T_IS_IDENTICAL) reduce 230) ((T_IS_NOT_EQUAL) reduce 230) ((T_IS_NOT_IDENTICAL) reduce 230) ((T_IS_SMALLER_OR_EQUAL) reduce 230) ((T_LOGICAL_AND) reduce 230) ((T_LOGICAL_OR) reduce 230) ((T_LOGICAL_XOR) reduce 230) ((T_POW) reduce 230) ((T_SL) reduce 230) ((T_SPACESHIP) reduce 230) ((T_SR) reduce 230) (("^") reduce 230) (("|") reduce 230)) 26970 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 368) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) reduce 368) ((T_LOGICAL_OR) reduce 368) ((T_LOGICAL_XOR) reduce 368) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26974 ((("%") reduce 575) (("*") reduce 575) (("+") reduce 575) (("-") reduce 575) ((".") reduce 575) (("/") reduce 575) ((";") reduce 575) (("<") reduce 575) ((">") reduce 575) (("?") reduce 575) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 575) ((T_BOOLEAN_AND) reduce 575) ((T_BOOLEAN_OR) reduce 575) ((T_COALESCE) reduce 575) ((T_INSTANCEOF) reduce 575) ((T_IS_EQUAL) reduce 575) ((T_IS_GREATER_OR_EQUAL) reduce 575) ((T_IS_IDENTICAL) reduce 575) ((T_IS_NOT_EQUAL) reduce 575) ((T_IS_NOT_IDENTICAL) reduce 575) ((T_IS_SMALLER_OR_EQUAL) reduce 575) ((T_LOGICAL_AND) reduce 575) ((T_LOGICAL_OR) reduce 575) ((T_LOGICAL_XOR) reduce 575) ((T_POW) reduce 575) ((T_SL) reduce 575) ((T_SPACESHIP) reduce 575) ((T_SR) reduce 575) (("^") reduce 575) (("|") reduce 575)) 26975 ((("%") reduce 428) (("*") reduce 428) (("+") reduce 428) (("-") reduce 428) ((".") reduce 428) (("/") reduce 428) ((";") reduce 428) (("<") reduce 428) ((">") reduce 428) (("?") reduce 428) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 428) ((T_BOOLEAN_AND) reduce 428) ((T_BOOLEAN_OR) reduce 428) ((T_COALESCE) reduce 428) ((T_INSTANCEOF) reduce 428) ((T_IS_EQUAL) reduce 428) ((T_IS_GREATER_OR_EQUAL) reduce 428) ((T_IS_IDENTICAL) reduce 428) ((T_IS_NOT_EQUAL) reduce 428) ((T_IS_NOT_IDENTICAL) reduce 428) ((T_IS_SMALLER_OR_EQUAL) reduce 428) ((T_LOGICAL_AND) reduce 428) ((T_LOGICAL_OR) reduce 428) ((T_LOGICAL_XOR) reduce 428) ((T_POW) shift) ((T_SL) reduce 428) ((T_SPACESHIP) reduce 428) ((T_SR) reduce 428) (("^") reduce 428) (("|") reduce 428)) 26976 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 578) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26977 ((("%") shift) (("*") shift) (("+") shift) (("-") shift) ((".") shift) (("/") shift) ((";") reduce 577) (("<") shift) ((">") shift) (("?") shift) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) shift) ((T_BOOLEAN_AND) shift) ((T_BOOLEAN_OR) shift) ((T_COALESCE) shift) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) shift) ((T_IS_GREATER_OR_EQUAL) shift) ((T_IS_IDENTICAL) shift) ((T_IS_NOT_EQUAL) shift) ((T_IS_NOT_IDENTICAL) shift) ((T_IS_SMALLER_OR_EQUAL) shift) ((T_LOGICAL_AND) shift) ((T_LOGICAL_OR) shift) ((T_LOGICAL_XOR) shift) ((T_POW) shift) ((T_SL) shift) ((T_SPACESHIP) shift) ((T_SR) shift) (("^") shift) (("|") shift)) 26978 ((("%") reduce 387) (("*") reduce 387) (("+") reduce 387) (("-") reduce 387) ((".") reduce 387) (("/") reduce 387) ((";") reduce 387) (("<") reduce 387) ((">") reduce 387) (("?") reduce 387) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 387) ((T_BOOLEAN_AND) reduce 387) ((T_BOOLEAN_OR) reduce 387) ((T_COALESCE) reduce 387) ((T_INSTANCEOF) reduce 387) ((T_IS_EQUAL) reduce 387) ((T_IS_GREATER_OR_EQUAL) reduce 387) ((T_IS_IDENTICAL) reduce 387) ((T_IS_NOT_EQUAL) reduce 387) ((T_IS_NOT_IDENTICAL) reduce 387) ((T_IS_SMALLER_OR_EQUAL) reduce 387) ((T_LOGICAL_AND) reduce 387) ((T_LOGICAL_OR) reduce 387) ((T_LOGICAL_XOR) reduce 387) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 387) ((T_SL) reduce 387) ((T_SPACESHIP) reduce 387) ((T_SR) reduce 387) (("[") reduce 510) (("^") reduce 387) (("{") reduce 510) (("|") reduce 387)) 26980 ((("%") reduce 435) (("*") reduce 435) (("+") reduce 435) (("-") reduce 435) ((".") reduce 435) (("/") reduce 435) ((";") reduce 435) (("<") reduce 435) ((">") reduce 435) (("?") reduce 435) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 435) ((T_BOOLEAN_AND) reduce 435) ((T_BOOLEAN_OR) reduce 435) ((T_COALESCE) reduce 435) ((T_INSTANCEOF) reduce 435) ((T_IS_EQUAL) reduce 435) ((T_IS_GREATER_OR_EQUAL) reduce 435) ((T_IS_IDENTICAL) reduce 435) ((T_IS_NOT_EQUAL) reduce 435) ((T_IS_NOT_IDENTICAL) reduce 435) ((T_IS_SMALLER_OR_EQUAL) reduce 435) ((T_LOGICAL_AND) reduce 435) ((T_LOGICAL_OR) reduce 435) ((T_LOGICAL_XOR) reduce 435) ((T_POW) reduce 435) ((T_SL) reduce 435) ((T_SPACESHIP) reduce 435) ((T_SR) reduce 435) (("^") reduce 435) (("|") reduce 435)) 26982 ((("%") reduce 476) (("*") reduce 476) (("+") reduce 476) (("-") reduce 476) ((".") reduce 476) (("/") reduce 476) ((";") reduce 476) (("<") reduce 476) ((">") reduce 476) (("?") reduce 476) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 476) ((T_BOOLEAN_AND) reduce 476) ((T_BOOLEAN_OR) reduce 476) ((T_COALESCE) reduce 476) ((T_INSTANCEOF) reduce 476) ((T_IS_EQUAL) reduce 476) ((T_IS_GREATER_OR_EQUAL) reduce 476) ((T_IS_IDENTICAL) reduce 476) ((T_IS_NOT_EQUAL) reduce 476) ((T_IS_NOT_IDENTICAL) reduce 476) ((T_IS_SMALLER_OR_EQUAL) reduce 476) ((T_LOGICAL_AND) reduce 476) ((T_LOGICAL_OR) reduce 476) ((T_LOGICAL_XOR) reduce 476) ((T_POW) reduce 476) ((T_SL) reduce 476) ((T_SPACESHIP) reduce 476) ((T_SR) reduce 476) (("^") reduce 476) (("|") reduce 476)) 26985 ((("%") reduce 579) (("*") reduce 579) (("+") reduce 579) (("-") reduce 579) ((".") reduce 579) (("/") reduce 579) ((";") reduce 579) (("<") reduce 579) ((">") reduce 579) (("?") reduce 579) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 579) ((T_BOOLEAN_AND) reduce 579) ((T_BOOLEAN_OR) reduce 579) ((T_COALESCE) reduce 579) ((T_INSTANCEOF) reduce 579) ((T_IS_EQUAL) reduce 579) ((T_IS_GREATER_OR_EQUAL) reduce 579) ((T_IS_IDENTICAL) reduce 579) ((T_IS_NOT_EQUAL) reduce 579) ((T_IS_NOT_IDENTICAL) reduce 579) ((T_IS_SMALLER_OR_EQUAL) reduce 579) ((T_LOGICAL_AND) reduce 579) ((T_LOGICAL_OR) reduce 579) ((T_LOGICAL_XOR) reduce 579) ((T_POW) reduce 579) ((T_SL) reduce 579) ((T_SPACESHIP) reduce 579) ((T_SR) reduce 579) (("^") reduce 579) (("|") reduce 579)) 26988 ((("%") reduce 576) (("*") reduce 576) (("+") reduce 576) (("-") reduce 576) ((".") reduce 576) (("/") reduce 576) ((";") reduce 576) (("<") reduce 576) ((">") reduce 576) (("?") reduce 576) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 576) ((T_BOOLEAN_AND) reduce 576) ((T_BOOLEAN_OR) reduce 576) ((T_COALESCE) reduce 576) ((T_INSTANCEOF) reduce 576) ((T_IS_EQUAL) reduce 576) ((T_IS_GREATER_OR_EQUAL) reduce 576) ((T_IS_IDENTICAL) reduce 576) ((T_IS_NOT_EQUAL) reduce 576) ((T_IS_NOT_IDENTICAL) reduce 576) ((T_IS_SMALLER_OR_EQUAL) reduce 576) ((T_LOGICAL_AND) reduce 576) ((T_LOGICAL_OR) reduce 576) ((T_LOGICAL_XOR) reduce 576) ((T_POW) reduce 576) ((T_SL) reduce 576) ((T_SPACESHIP) reduce 576) ((T_SR) reduce 576) (("^") reduce 576) (("|") reduce 576)) 26989 ((("%") reduce 429) (("*") reduce 429) (("+") reduce 429) (("-") reduce 429) ((".") reduce 429) (("/") reduce 429) ((";") reduce 429) (("<") reduce 429) ((">") reduce 429) (("?") reduce 429) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 429) ((T_BOOLEAN_AND) reduce 429) ((T_BOOLEAN_OR) reduce 429) ((T_COALESCE) reduce 429) ((T_INSTANCEOF) reduce 429) ((T_IS_EQUAL) reduce 429) ((T_IS_GREATER_OR_EQUAL) reduce 429) ((T_IS_IDENTICAL) reduce 429) ((T_IS_NOT_EQUAL) reduce 429) ((T_IS_NOT_IDENTICAL) reduce 429) ((T_IS_SMALLER_OR_EQUAL) reduce 429) ((T_LOGICAL_AND) reduce 429) ((T_LOGICAL_OR) reduce 429) ((T_LOGICAL_XOR) reduce 429) ((T_POW) shift) ((T_SL) reduce 429) ((T_SPACESHIP) reduce 429) ((T_SR) reduce 429) (("^") reduce 429) (("|") reduce 429)) 26990 ((("%") reduce 389) (("*") reduce 389) (("+") reduce 389) (("-") reduce 389) ((".") reduce 389) (("/") reduce 389) ((";") reduce 389) (("<") reduce 389) ((">") reduce 389) (("?") reduce 389) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 389) ((T_BOOLEAN_AND) reduce 389) ((T_BOOLEAN_OR) reduce 389) ((T_COALESCE) reduce 389) ((T_INSTANCEOF) reduce 389) ((T_IS_EQUAL) reduce 389) ((T_IS_GREATER_OR_EQUAL) reduce 389) ((T_IS_IDENTICAL) reduce 389) ((T_IS_NOT_EQUAL) reduce 389) ((T_IS_NOT_IDENTICAL) reduce 389) ((T_IS_SMALLER_OR_EQUAL) reduce 389) ((T_LOGICAL_AND) reduce 389) ((T_LOGICAL_OR) reduce 389) ((T_LOGICAL_XOR) reduce 389) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 510) ((T_OBJECT_OPERATOR) reduce 510) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 510) ((T_POW) reduce 389) ((T_SL) reduce 389) ((T_SPACESHIP) reduce 389) ((T_SR) reduce 389) (("[") reduce 510) (("^") reduce 389) (("{") reduce 510) (("|") reduce 389)) 26991 ((("%") reduce 372) (("*") reduce 372) (("+") reduce 372) (("-") reduce 372) ((".") reduce 372) (("/") reduce 372) ((";") reduce 372) (("<") reduce 372) ((">") reduce 372) (("?") reduce 372) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 372) ((T_BOOLEAN_AND) reduce 372) ((T_BOOLEAN_OR) reduce 372) ((T_COALESCE) reduce 372) ((T_INSTANCEOF) reduce 372) ((T_IS_EQUAL) reduce 372) ((T_IS_GREATER_OR_EQUAL) reduce 372) ((T_IS_IDENTICAL) reduce 372) ((T_IS_NOT_EQUAL) reduce 372) ((T_IS_NOT_IDENTICAL) reduce 372) ((T_IS_SMALLER_OR_EQUAL) reduce 372) ((T_LOGICAL_AND) reduce 372) ((T_LOGICAL_OR) reduce 372) ((T_LOGICAL_XOR) reduce 372) ((T_POW) reduce 372) ((T_SL) reduce 372) ((T_SPACESHIP) reduce 372) ((T_SR) reduce 372) (("^") reduce 372) (("|") reduce 372)) 26992 ((("%") reduce 433) (("*") reduce 433) (("+") reduce 433) (("-") reduce 433) ((".") reduce 433) (("/") reduce 433) ((";") reduce 433) (("<") reduce 433) ((">") reduce 433) (("?") reduce 433) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 433) ((T_BOOLEAN_AND) reduce 433) ((T_BOOLEAN_OR) reduce 433) ((T_COALESCE) reduce 433) ((T_INSTANCEOF) reduce 433) ((T_IS_EQUAL) reduce 433) ((T_IS_GREATER_OR_EQUAL) reduce 433) ((T_IS_IDENTICAL) reduce 433) ((T_IS_NOT_EQUAL) reduce 433) ((T_IS_NOT_IDENTICAL) reduce 433) ((T_IS_SMALLER_OR_EQUAL) reduce 433) ((T_LOGICAL_AND) reduce 433) ((T_LOGICAL_OR) reduce 433) ((T_LOGICAL_XOR) reduce 433) ((T_POW) shift) ((T_SL) reduce 433) ((T_SPACESHIP) reduce 433) ((T_SR) reduce 433) (("^") reduce 433) (("|") reduce 433)) 26993 ((("%") reduce 431) (("*") reduce 431) (("+") reduce 431) (("-") reduce 431) ((".") reduce 431) (("/") reduce 431) ((";") reduce 431) (("<") reduce 431) ((">") reduce 431) (("?") reduce 431) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 431) ((T_BOOLEAN_AND) reduce 431) ((T_BOOLEAN_OR) reduce 431) ((T_COALESCE) reduce 431) ((T_INSTANCEOF) reduce 431) ((T_IS_EQUAL) reduce 431) ((T_IS_GREATER_OR_EQUAL) reduce 431) ((T_IS_IDENTICAL) reduce 431) ((T_IS_NOT_EQUAL) reduce 431) ((T_IS_NOT_IDENTICAL) reduce 431) ((T_IS_SMALLER_OR_EQUAL) reduce 431) ((T_LOGICAL_AND) reduce 431) ((T_LOGICAL_OR) reduce 431) ((T_LOGICAL_XOR) reduce 431) ((T_POW) shift) ((T_SL) reduce 431) ((T_SPACESHIP) reduce 431) ((T_SR) reduce 431) (("^") reduce 431) (("|") reduce 431)) 26996 ((("%") reduce 482) (("(") reduce 482) (("*") reduce 482) (("+") reduce 482) (("-") reduce 482) ((".") reduce 482) (("/") reduce 482) ((";") reduce 482) (("<") reduce 482) ((">") reduce 482) (("?") reduce 482) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 482) ((T_BOOLEAN_AND) reduce 482) ((T_BOOLEAN_OR) reduce 482) ((T_COALESCE) reduce 482) ((T_INSTANCEOF) reduce 482) ((T_IS_EQUAL) reduce 482) ((T_IS_GREATER_OR_EQUAL) reduce 482) ((T_IS_IDENTICAL) reduce 482) ((T_IS_NOT_EQUAL) reduce 482) ((T_IS_NOT_IDENTICAL) reduce 482) ((T_IS_SMALLER_OR_EQUAL) reduce 482) ((T_LOGICAL_AND) reduce 482) ((T_LOGICAL_OR) reduce 482) ((T_LOGICAL_XOR) reduce 482) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 482) ((T_OBJECT_OPERATOR) reduce 482) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 482) ((T_POW) reduce 482) ((T_SL) reduce 482) ((T_SPACESHIP) reduce 482) ((T_SR) reduce 482) (("[") reduce 482) (("^") reduce 482) (("{") reduce 482) (("|") reduce 482)) 26997 ((("%") reduce 436) (("*") reduce 436) (("+") reduce 436) (("-") reduce 436) ((".") reduce 436) (("/") reduce 436) ((";") reduce 436) (("<") reduce 436) ((">") reduce 436) (("?") reduce 436) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 436) ((T_BOOLEAN_AND) reduce 436) ((T_BOOLEAN_OR) reduce 436) ((T_COALESCE) reduce 436) ((T_INSTANCEOF) reduce 436) ((T_IS_EQUAL) reduce 436) ((T_IS_GREATER_OR_EQUAL) reduce 436) ((T_IS_IDENTICAL) reduce 436) ((T_IS_NOT_EQUAL) reduce 436) ((T_IS_NOT_IDENTICAL) reduce 436) ((T_IS_SMALLER_OR_EQUAL) reduce 436) ((T_LOGICAL_AND) reduce 436) ((T_LOGICAL_OR) reduce 436) ((T_LOGICAL_XOR) reduce 436) ((T_POW) shift) ((T_SL) reduce 436) ((T_SPACESHIP) reduce 436) ((T_SR) reduce 436) (("^") reduce 436) (("|") reduce 436)) 26998 ((("%") reduce 409) (("*") reduce 409) (("+") reduce 409) (("-") reduce 409) ((".") reduce 409) (("/") reduce 409) ((";") reduce 409) (("<") reduce 409) ((">") reduce 409) (("?") reduce 409) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 409) ((T_BOOLEAN_AND) reduce 409) ((T_BOOLEAN_OR) reduce 409) ((T_COALESCE) reduce 409) ((T_INSTANCEOF) reduce 409) ((T_IS_EQUAL) reduce 409) ((T_IS_GREATER_OR_EQUAL) reduce 409) ((T_IS_IDENTICAL) reduce 409) ((T_IS_NOT_EQUAL) reduce 409) ((T_IS_NOT_IDENTICAL) reduce 409) ((T_IS_SMALLER_OR_EQUAL) reduce 409) ((T_LOGICAL_AND) reduce 409) ((T_LOGICAL_OR) reduce 409) ((T_LOGICAL_XOR) reduce 409) ((T_POW) shift) ((T_SL) reduce 409) ((T_SPACESHIP) reduce 409) ((T_SR) reduce 409) (("^") reduce 409) (("|") reduce 409)) 26999 ((("%") reduce 408) (("*") reduce 408) (("+") reduce 408) (("-") reduce 408) ((".") reduce 408) (("/") reduce 408) ((";") reduce 408) (("<") reduce 408) ((">") reduce 408) (("?") reduce 408) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 408) ((T_BOOLEAN_AND) reduce 408) ((T_BOOLEAN_OR) reduce 408) ((T_COALESCE) reduce 408) ((T_INSTANCEOF) reduce 408) ((T_IS_EQUAL) reduce 408) ((T_IS_GREATER_OR_EQUAL) reduce 408) ((T_IS_IDENTICAL) reduce 408) ((T_IS_NOT_EQUAL) reduce 408) ((T_IS_NOT_IDENTICAL) reduce 408) ((T_IS_SMALLER_OR_EQUAL) reduce 408) ((T_LOGICAL_AND) reduce 408) ((T_LOGICAL_OR) reduce 408) ((T_LOGICAL_XOR) reduce 408) ((T_POW) shift) ((T_SL) reduce 408) ((T_SPACESHIP) reduce 408) ((T_SR) reduce 408) (("^") reduce 408) (("|") reduce 408)) 27001 ((("%") reduce 422) (("(") reduce 517) (("*") reduce 422) (("+") reduce 422) (("-") reduce 422) ((".") reduce 422) (("/") reduce 422) ((";") reduce 422) (("<") reduce 422) ((">") reduce 422) (("?") reduce 422) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 422) ((T_BOOLEAN_AND) reduce 422) ((T_BOOLEAN_OR) reduce 422) ((T_COALESCE) reduce 422) ((T_INSTANCEOF) reduce 422) ((T_IS_EQUAL) reduce 422) ((T_IS_GREATER_OR_EQUAL) reduce 422) ((T_IS_IDENTICAL) reduce 422) ((T_IS_NOT_EQUAL) reduce 422) ((T_IS_NOT_IDENTICAL) reduce 422) ((T_IS_SMALLER_OR_EQUAL) reduce 422) ((T_LOGICAL_AND) reduce 422) ((T_LOGICAL_OR) reduce 422) ((T_LOGICAL_XOR) reduce 422) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 511) ((T_OBJECT_OPERATOR) reduce 511) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 511) ((T_POW) reduce 422) ((T_SL) reduce 422) ((T_SPACESHIP) reduce 422) ((T_SR) reduce 422) (("[") reduce 511) (("^") reduce 422) (("{") reduce 511) (("|") reduce 422)) 27002 ((("%") reduce 531) (("(") reduce 531) (("*") reduce 531) (("+") reduce 531) (("-") reduce 531) ((".") reduce 531) (("/") reduce 531) ((";") reduce 531) (("<") reduce 531) (("=") reduce 531) ((">") reduce 531) (("?") reduce 531) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 531) ((T_AND_EQUAL) reduce 531) ((T_BOOLEAN_AND) reduce 531) ((T_BOOLEAN_OR) reduce 531) ((T_COALESCE) reduce 531) ((T_COALESCE_EQUAL) reduce 531) ((T_CONCAT_EQUAL) reduce 531) ((T_DEC) reduce 531) ((T_DIV_EQUAL) reduce 531) ((T_INC) reduce 531) ((T_INSTANCEOF) reduce 531) ((T_IS_EQUAL) reduce 531) ((T_IS_GREATER_OR_EQUAL) reduce 531) ((T_IS_IDENTICAL) reduce 531) ((T_IS_NOT_EQUAL) reduce 531) ((T_IS_NOT_IDENTICAL) reduce 531) ((T_IS_SMALLER_OR_EQUAL) reduce 531) ((T_LOGICAL_AND) reduce 531) ((T_LOGICAL_OR) reduce 531) ((T_LOGICAL_XOR) reduce 531) ((T_MINUS_EQUAL) reduce 531) ((T_MOD_EQUAL) reduce 531) ((T_MUL_EQUAL) reduce 531) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 531) ((T_OBJECT_OPERATOR) reduce 531) ((T_OR_EQUAL) reduce 531) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 531) ((T_PLUS_EQUAL) reduce 531) ((T_POW) reduce 531) ((T_POW_EQUAL) reduce 531) ((T_SL) reduce 531) ((T_SL_EQUAL) reduce 531) ((T_SPACESHIP) reduce 531) ((T_SR) reduce 531) ((T_SR_EQUAL) reduce 531) ((T_XOR_EQUAL) reduce 531) (("[") reduce 531) (("^") reduce 531) (("{") reduce 531) (("|") reduce 531)) 27005 ((("%") reduce 530) (("(") reduce 530) (("*") reduce 530) (("+") reduce 530) (("-") reduce 530) ((".") reduce 530) (("/") reduce 530) ((";") reduce 530) (("<") reduce 530) (("=") reduce 530) ((">") reduce 530) (("?") reduce 530) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 530) ((T_AND_EQUAL) reduce 530) ((T_BOOLEAN_AND) reduce 530) ((T_BOOLEAN_OR) reduce 530) ((T_COALESCE) reduce 530) ((T_COALESCE_EQUAL) reduce 530) ((T_CONCAT_EQUAL) reduce 530) ((T_DEC) reduce 530) ((T_DIV_EQUAL) reduce 530) ((T_INC) reduce 530) ((T_INSTANCEOF) reduce 530) ((T_IS_EQUAL) reduce 530) ((T_IS_GREATER_OR_EQUAL) reduce 530) ((T_IS_IDENTICAL) reduce 530) ((T_IS_NOT_EQUAL) reduce 530) ((T_IS_NOT_IDENTICAL) reduce 530) ((T_IS_SMALLER_OR_EQUAL) reduce 530) ((T_LOGICAL_AND) reduce 530) ((T_LOGICAL_OR) reduce 530) ((T_LOGICAL_XOR) reduce 530) ((T_MINUS_EQUAL) reduce 530) ((T_MOD_EQUAL) reduce 530) ((T_MUL_EQUAL) reduce 530) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 530) ((T_OBJECT_OPERATOR) reduce 530) ((T_OR_EQUAL) reduce 530) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 530) ((T_PLUS_EQUAL) reduce 530) ((T_POW) reduce 530) ((T_POW_EQUAL) reduce 530) ((T_SL) reduce 530) ((T_SL_EQUAL) reduce 530) ((T_SPACESHIP) reduce 530) ((T_SR) reduce 530) ((T_SR_EQUAL) reduce 530) ((T_XOR_EQUAL) reduce 530) (("[") reduce 530) (("^") reduce 530) (("{") reduce 530) (("|") reduce 530)) 27007 ((("%") reduce 485) (("(") reduce 485) (("*") reduce 485) (("+") reduce 485) (("-") reduce 485) ((".") reduce 485) (("/") reduce 485) ((";") reduce 485) (("<") reduce 485) ((">") reduce 485) (("?") reduce 485) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 485) ((T_BOOLEAN_AND) reduce 485) ((T_BOOLEAN_OR) reduce 485) ((T_COALESCE) reduce 485) ((T_INSTANCEOF) reduce 485) ((T_IS_EQUAL) reduce 485) ((T_IS_GREATER_OR_EQUAL) reduce 485) ((T_IS_IDENTICAL) reduce 485) ((T_IS_NOT_EQUAL) reduce 485) ((T_IS_NOT_IDENTICAL) reduce 485) ((T_IS_SMALLER_OR_EQUAL) reduce 485) ((T_LOGICAL_AND) reduce 485) ((T_LOGICAL_OR) reduce 485) ((T_LOGICAL_XOR) reduce 485) ((T_NULLSAFE_OBJECT_OPERATOR) reduce 485) ((T_OBJECT_OPERATOR) reduce 485) ((T_PAAMAYIM_NEKUDOTAYIM) reduce 485) ((T_POW) reduce 485) ((T_SL) reduce 485) ((T_SPACESHIP) reduce 485) ((T_SR) reduce 485) (("[") reduce 485) (("^") reduce 485) (("{") reduce 485) (("|") reduce 485)) 27008 ((("%") reduce 410) (("*") reduce 410) (("+") reduce 410) (("-") reduce 410) ((".") reduce 410) (("/") reduce 410) ((";") reduce 410) (("<") reduce 410) ((">") reduce 410) (("?") reduce 410) ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) reduce 410) ((T_BOOLEAN_AND) reduce 410) ((T_BOOLEAN_OR) reduce 410) ((T_COALESCE) reduce 410) ((T_INSTANCEOF) shift) ((T_IS_EQUAL) reduce 410) ((T_IS_GREATER_OR_EQUAL) reduce 410) ((T_IS_IDENTICAL) reduce 410) ((T_IS_NOT_EQUAL) reduce 410) ((T_IS_NOT_IDENTICAL) reduce 410) ((T_IS_SMALLER_OR_EQUAL) reduce 410) ((T_LOGICAL_AND) reduce 410) ((T_LOGICAL_OR) reduce 410) ((T_LOGICAL_XOR) reduce 410) ((T_POW) shift) ((T_SL) reduce 410) ((T_SPACESHIP) reduce 410) ((T_SR) reduce 410) (("^") reduce 410) (("|") reduce 410)) 27009 ((("!") reduce 159) (("\"") reduce 159) (("$") reduce 159) (($) reduce 159) (("(") reduce 159) (("+") reduce 159) (("-") reduce 159) ((";") reduce 159) (("@") reduce 159) ((T_ABSTRACT) reduce 159) ((T_ARRAY) reduce 159) ((T_ARRAY_CAST) reduce 159) ((T_ATTRIBUTE) reduce 159) ((T_BOOL_CAST) reduce 159) ((T_BREAK) reduce 159) ((T_CLASS) reduce 159) ((T_CLASS_C) reduce 159) ((T_CLONE) reduce 159) ((T_CONST) reduce 159) ((T_CONSTANT_ENCAPSED_STRING) reduce 159) ((T_CONTINUE) reduce 159) ((T_DEC) reduce 159) ((T_DECLARE) reduce 159) ((T_DIR) reduce 159) ((T_DNUMBER) reduce 159) ((T_DO) reduce 159) ((T_DOUBLE_CAST) reduce 159) ((T_ECHO) reduce 159) ((T_EMPTY) reduce 159) ((T_ENUM) reduce 159) ((T_EVAL) reduce 159) ((T_EXIT) reduce 159) ((T_FILE) reduce 159) ((T_FINAL) reduce 159) ((T_FN) reduce 159) ((T_FOR) reduce 159) ((T_FOREACH) reduce 159) ((T_FUNCTION) reduce 159) ((T_FUNC_C) reduce 159) ((T_GLOBAL) reduce 159) ((T_GOTO) reduce 159) ((T_HALT_COMPILER) reduce 159) ((T_IF) reduce 159) ((T_INC) reduce 159) ((T_INCLUDE) reduce 159) ((T_INCLUDE_ONCE) reduce 159) ((T_INLINE_HTML) reduce 159) ((T_INTERFACE) reduce 159) ((T_INT_CAST) reduce 159) ((T_ISSET) reduce 159) ((T_LINE) reduce 159) ((T_LIST) reduce 159) ((T_LNUMBER) reduce 159) ((T_MATCH) reduce 159) ((T_METHOD_C) reduce 159) ((T_NAMESPACE) reduce 159) ((T_NAME_FULLY_QUALIFIED) reduce 159) ((T_NAME_QUALIFIED) reduce 159) ((T_NAME_RELATIVE) reduce 159) ((T_NEW) reduce 159) ((T_NS_C) reduce 159) ((T_OBJECT_CAST) reduce 159) ((T_PRINT) reduce 159) ((T_READONLY) reduce 159) ((T_REQUIRE) reduce 159) ((T_REQUIRE_ONCE) reduce 159) ((T_RETURN) reduce 159) ((T_START_HEREDOC) reduce 159) ((T_STATIC) reduce 159) ((T_STRING) reduce 159) ((T_STRING_CAST) reduce 159) ((T_SWITCH) reduce 159) ((T_THROW) reduce 159) ((T_TRAIT) reduce 159) ((T_TRAIT_C) reduce 159) ((T_TRY) reduce 159) ((T_UNSET) reduce 159) ((T_UNSET_CAST) reduce 159) ((T_USE) reduce 159) ((T_VARIABLE) reduce 159) ((T_WHILE) reduce 159) ((T_YIELD) reduce 159) ((T_YIELD_FROM) reduce 159) (("[") reduce 159) (("`") reduce 159) (("{") reduce 159) (("~") reduce 159)) 27025 ((("!") reduce 186) (("\"") reduce 186) (("$") reduce 186) (($) reduce 186) (("(") reduce 186) (("+") reduce 186) (("-") reduce 186) ((";") reduce 186) (("@") reduce 186) ((T_ABSTRACT) reduce 186) ((T_ARRAY) reduce 186) ((T_ARRAY_CAST) reduce 186) ((T_ATTRIBUTE) reduce 186) ((T_BOOL_CAST) reduce 186) ((T_BREAK) reduce 186) ((T_CLASS) reduce 186) ((T_CLASS_C) reduce 186) ((T_CLONE) reduce 186) ((T_CONST) reduce 186) ((T_CONSTANT_ENCAPSED_STRING) reduce 186) ((T_CONTINUE) reduce 186) ((T_DEC) reduce 186) ((T_DECLARE) reduce 186) ((T_DIR) reduce 186) ((T_DNUMBER) reduce 186) ((T_DO) reduce 186) ((T_DOUBLE_CAST) reduce 186) ((T_ECHO) reduce 186) ((T_EMPTY) reduce 186) ((T_ENUM) reduce 186) ((T_EVAL) reduce 186) ((T_EXIT) reduce 186) ((T_FILE) reduce 186) ((T_FINAL) reduce 186) ((T_FN) reduce 186) ((T_FOR) reduce 186) ((T_FOREACH) reduce 186) ((T_FUNCTION) reduce 186) ((T_FUNC_C) reduce 186) ((T_GLOBAL) reduce 186) ((T_GOTO) reduce 186) ((T_HALT_COMPILER) reduce 186) ((T_IF) reduce 186) ((T_INC) reduce 186) ((T_INCLUDE) reduce 186) ((T_INCLUDE_ONCE) reduce 186) ((T_INLINE_HTML) reduce 186) ((T_INTERFACE) reduce 186) ((T_INT_CAST) reduce 186) ((T_ISSET) reduce 186) ((T_LINE) reduce 186) ((T_LIST) reduce 186) ((T_LNUMBER) reduce 186) ((T_MATCH) reduce 186) ((T_METHOD_C) reduce 186) ((T_NAMESPACE) reduce 186) ((T_NAME_FULLY_QUALIFIED) reduce 186) ((T_NAME_QUALIFIED) reduce 186) ((T_NAME_RELATIVE) reduce 186) ((T_NEW) reduce 186) ((T_NS_C) reduce 186) ((T_OBJECT_CAST) reduce 186) ((T_PRINT) reduce 186) ((T_READONLY) reduce 186) ((T_REQUIRE) reduce 186) ((T_REQUIRE_ONCE) reduce 186) ((T_RETURN) reduce 186) ((T_START_HEREDOC) reduce 186) ((T_STATIC) reduce 186) ((T_STRING) reduce 186) ((T_STRING_CAST) reduce 186) ((T_SWITCH) reduce 186) ((T_THROW) reduce 186) ((T_TRAIT) reduce 186) ((T_TRAIT_C) reduce 186) ((T_TRY) reduce 186) ((T_UNSET) reduce 186) ((T_UNSET_CAST) reduce 186) ((T_USE) reduce 186) ((T_VARIABLE) reduce 186) ((T_WHILE) reduce 186) ((T_YIELD) reduce 186) ((T_YIELD_FROM) reduce 186) (("[") reduce 186) (("`") reduce 186) (("{") reduce 186) (("~") reduce 186)) 27031 ((("!") reduce 109) (("\"") reduce 109) (($) reduce 109) (("$") reduce 109) (("(") reduce 109) (("+") reduce 109) (("-") reduce 109) ((";") reduce 109) (("@") reduce 109) ((T_ABSTRACT) reduce 109) ((T_ARRAY) reduce 109) ((T_ARRAY_CAST) reduce 109) ((T_ATTRIBUTE) reduce 109) ((T_BOOL_CAST) reduce 109) ((T_BREAK) reduce 109) ((T_CLASS) reduce 109) ((T_CLASS_C) reduce 109) ((T_CLONE) reduce 109) ((T_CONST) reduce 109) ((T_CONSTANT_ENCAPSED_STRING) reduce 109) ((T_CONTINUE) reduce 109) ((T_DEC) reduce 109) ((T_DECLARE) reduce 109) ((T_DIR) reduce 109) ((T_DNUMBER) reduce 109) ((T_DO) reduce 109) ((T_DOUBLE_CAST) reduce 109) ((T_ECHO) reduce 109) ((T_EMPTY) reduce 109) ((T_ENUM) reduce 109) ((T_EVAL) reduce 109) ((T_EXIT) reduce 109) ((T_FILE) reduce 109) ((T_FINAL) reduce 109) ((T_FN) reduce 109) ((T_FOR) reduce 109) ((T_FOREACH) reduce 109) ((T_FUNCTION) reduce 109) ((T_FUNC_C) reduce 109) ((T_GLOBAL) reduce 109) ((T_GOTO) reduce 109) ((T_HALT_COMPILER) reduce 109) ((T_IF) reduce 109) ((T_INC) reduce 109) ((T_INCLUDE) reduce 109) ((T_INCLUDE_ONCE) reduce 109) ((T_INLINE_HTML) reduce 109) ((T_INTERFACE) reduce 109) ((T_INT_CAST) reduce 109) ((T_ISSET) reduce 109) ((T_LINE) reduce 109) ((T_LIST) reduce 109) ((T_LNUMBER) reduce 109) ((T_MATCH) reduce 109) ((T_METHOD_C) reduce 109) ((T_NAMESPACE) reduce 109) ((T_NAME_FULLY_QUALIFIED) reduce 109) ((T_NAME_QUALIFIED) reduce 109) ((T_NAME_RELATIVE) reduce 109) ((T_NEW) reduce 109) ((T_NS_C) reduce 109) ((T_OBJECT_CAST) reduce 109) ((T_PRINT) reduce 109) ((T_READONLY) reduce 109) ((T_REQUIRE) reduce 109) ((T_REQUIRE_ONCE) reduce 109) ((T_RETURN) reduce 109) ((T_START_HEREDOC) reduce 109) ((T_STATIC) reduce 109) ((T_STRING) reduce 109) ((T_STRING_CAST) reduce 109) ((T_SWITCH) reduce 109) ((T_THROW) reduce 109) ((T_TRAIT) reduce 109) ((T_TRAIT_C) reduce 109) ((T_TRY) reduce 109) ((T_UNSET) reduce 109) ((T_UNSET_CAST) reduce 109) ((T_USE) reduce 109) ((T_VARIABLE) reduce 109) ((T_WHILE) reduce 109) ((T_YIELD) reduce 109) ((T_YIELD_FROM) reduce 109) (("[") reduce 109) (("`") reduce 109) (("{") reduce 109) (("~") reduce 109)) 27032 ((("!") reduce 103) (("\"") reduce 103) (("$") reduce 103) (($) reduce 103) (("(") reduce 103) (("+") reduce 103) (("-") reduce 103) ((";") reduce 103) (("@") reduce 103) ((T_ABSTRACT) reduce 103) ((T_ARRAY) reduce 103) ((T_ARRAY_CAST) reduce 103) ((T_ATTRIBUTE) reduce 103) ((T_BOOL_CAST) reduce 103) ((T_BREAK) reduce 103) ((T_CLASS) reduce 103) ((T_CLASS_C) reduce 103) ((T_CLONE) reduce 103) ((T_CONST) reduce 103) ((T_CONSTANT_ENCAPSED_STRING) reduce 103) ((T_CONTINUE) reduce 103) ((T_DEC) reduce 103) ((T_DECLARE) reduce 103) ((T_DIR) reduce 103) ((T_DNUMBER) reduce 103) ((T_DO) reduce 103) ((T_DOUBLE_CAST) reduce 103) ((T_ECHO) reduce 103) ((T_EMPTY) reduce 103) ((T_ENUM) reduce 103) ((T_EVAL) reduce 103) ((T_EXIT) reduce 103) ((T_FILE) reduce 103) ((T_FINAL) reduce 103) ((T_FN) reduce 103) ((T_FOR) reduce 103) ((T_FOREACH) reduce 103) ((T_FUNCTION) reduce 103) ((T_FUNC_C) reduce 103) ((T_GLOBAL) reduce 103) ((T_GOTO) reduce 103) ((T_HALT_COMPILER) reduce 103) ((T_IF) reduce 103) ((T_INC) reduce 103) ((T_INCLUDE) reduce 103) ((T_INCLUDE_ONCE) reduce 103) ((T_INLINE_HTML) reduce 103) ((T_INTERFACE) reduce 103) ((T_INT_CAST) reduce 103) ((T_ISSET) reduce 103) ((T_LINE) reduce 103) ((T_LIST) reduce 103) ((T_LNUMBER) reduce 103) ((T_MATCH) reduce 103) ((T_METHOD_C) reduce 103) ((T_NAMESPACE) reduce 103) ((T_NAME_FULLY_QUALIFIED) reduce 103) ((T_NAME_QUALIFIED) reduce 103) ((T_NAME_RELATIVE) reduce 103) ((T_NEW) reduce 103) ((T_NS_C) reduce 103) ((T_OBJECT_CAST) reduce 103) ((T_PRINT) reduce 103) ((T_READONLY) reduce 103) ((T_REQUIRE) reduce 103) ((T_REQUIRE_ONCE) reduce 103) ((T_RETURN) reduce 103) ((T_START_HEREDOC) reduce 103) ((T_STATIC) reduce 103) ((T_STRING) reduce 103) ((T_STRING_CAST) reduce 103) ((T_SWITCH) reduce 103) ((T_THROW) reduce 103) ((T_TRAIT) reduce 103) ((T_TRAIT_C) reduce 103) ((T_TRY) reduce 103) ((T_UNSET) reduce 103) ((T_UNSET_CAST) reduce 103) ((T_USE) reduce 103) ((T_VARIABLE) reduce 103) ((T_WHILE) reduce 103) ((T_YIELD) reduce 103) ((T_YIELD_FROM) reduce 103) (("[") reduce 103) (("`") reduce 103) (("{") reduce 103) (("~") reduce 103)) 27034 ((("!") reduce 106) (("\"") reduce 106) (("$") reduce 106) (($) reduce 106) (("(") reduce 106) (("+") reduce 106) (("-") reduce 106) ((";") reduce 106) (("@") reduce 106) ((T_ABSTRACT) reduce 106) ((T_ARRAY) reduce 106) ((T_ARRAY_CAST) reduce 106) ((T_ATTRIBUTE) reduce 106) ((T_BOOL_CAST) reduce 106) ((T_BREAK) reduce 106) ((T_CLASS) reduce 106) ((T_CLASS_C) reduce 106) ((T_CLONE) reduce 106) ((T_CONST) reduce 106) ((T_CONSTANT_ENCAPSED_STRING) reduce 106) ((T_CONTINUE) reduce 106) ((T_DEC) reduce 106) ((T_DECLARE) reduce 106) ((T_DIR) reduce 106) ((T_DNUMBER) reduce 106) ((T_DO) reduce 106) ((T_DOUBLE_CAST) reduce 106) ((T_ECHO) reduce 106) ((T_EMPTY) reduce 106) ((T_ENUM) reduce 106) ((T_EVAL) reduce 106) ((T_EXIT) reduce 106) ((T_FILE) reduce 106) ((T_FINAL) reduce 106) ((T_FN) reduce 106) ((T_FOR) reduce 106) ((T_FOREACH) reduce 106) ((T_FUNCTION) reduce 106) ((T_FUNC_C) reduce 106) ((T_GLOBAL) reduce 106) ((T_GOTO) reduce 106) ((T_HALT_COMPILER) reduce 106) ((T_IF) reduce 106) ((T_INC) reduce 106) ((T_INCLUDE) reduce 106) ((T_INCLUDE_ONCE) reduce 106) ((T_INLINE_HTML) reduce 106) ((T_INTERFACE) reduce 106) ((T_INT_CAST) reduce 106) ((T_ISSET) reduce 106) ((T_LINE) reduce 106) ((T_LIST) reduce 106) ((T_LNUMBER) reduce 106) ((T_MATCH) reduce 106) ((T_METHOD_C) reduce 106) ((T_NAMESPACE) reduce 106) ((T_NAME_FULLY_QUALIFIED) reduce 106) ((T_NAME_QUALIFIED) reduce 106) ((T_NAME_RELATIVE) reduce 106) ((T_NEW) reduce 106) ((T_NS_C) reduce 106) ((T_OBJECT_CAST) reduce 106) ((T_PRINT) reduce 106) ((T_READONLY) reduce 106) ((T_REQUIRE) reduce 106) ((T_REQUIRE_ONCE) reduce 106) ((T_RETURN) reduce 106) ((T_START_HEREDOC) reduce 106) ((T_STATIC) reduce 106) ((T_STRING) reduce 106) ((T_STRING_CAST) reduce 106) ((T_SWITCH) reduce 106) ((T_THROW) reduce 106) ((T_TRAIT) reduce 106) ((T_TRAIT_C) reduce 106) ((T_TRY) reduce 106) ((T_UNSET) reduce 106) ((T_UNSET_CAST) reduce 106) ((T_USE) reduce 106) ((T_VARIABLE) reduce 106) ((T_WHILE) reduce 106) ((T_YIELD) reduce 106) ((T_YIELD_FROM) reduce 106) (("[") reduce 106) (("`") reduce 106) (("{") reduce 106) (("~") reduce 106)) 27036 ((("!") reduce 102) (("\"") reduce 102) (("$") reduce 102) (($) reduce 102) (("(") reduce 102) (("+") reduce 102) (("-") reduce 102) ((";") reduce 102) (("@") reduce 102) ((T_ABSTRACT) reduce 102) ((T_ARRAY) reduce 102) ((T_ARRAY_CAST) reduce 102) ((T_ATTRIBUTE) reduce 102) ((T_BOOL_CAST) reduce 102) ((T_BREAK) reduce 102) ((T_CLASS) reduce 102) ((T_CLASS_C) reduce 102) ((T_CLONE) reduce 102) ((T_CONST) reduce 102) ((T_CONSTANT_ENCAPSED_STRING) reduce 102) ((T_CONTINUE) reduce 102) ((T_DEC) reduce 102) ((T_DECLARE) reduce 102) ((T_DIR) reduce 102) ((T_DNUMBER) reduce 102) ((T_DO) reduce 102) ((T_DOUBLE_CAST) reduce 102) ((T_ECHO) reduce 102) ((T_EMPTY) reduce 102) ((T_ENUM) reduce 102) ((T_EVAL) reduce 102) ((T_EXIT) reduce 102) ((T_FILE) reduce 102) ((T_FINAL) reduce 102) ((T_FN) reduce 102) ((T_FOR) reduce 102) ((T_FOREACH) reduce 102) ((T_FUNCTION) reduce 102) ((T_FUNC_C) reduce 102) ((T_GLOBAL) reduce 102) ((T_GOTO) reduce 102) ((T_HALT_COMPILER) reduce 102) ((T_IF) reduce 102) ((T_INC) reduce 102) ((T_INCLUDE) reduce 102) ((T_INCLUDE_ONCE) reduce 102) ((T_INLINE_HTML) reduce 102) ((T_INTERFACE) reduce 102) ((T_INT_CAST) reduce 102) ((T_ISSET) reduce 102) ((T_LINE) reduce 102) ((T_LIST) reduce 102) ((T_LNUMBER) reduce 102) ((T_MATCH) reduce 102) ((T_METHOD_C) reduce 102) ((T_NAMESPACE) reduce 102) ((T_NAME_FULLY_QUALIFIED) reduce 102) ((T_NAME_QUALIFIED) reduce 102) ((T_NAME_RELATIVE) reduce 102) ((T_NEW) reduce 102) ((T_NS_C) reduce 102) ((T_OBJECT_CAST) reduce 102) ((T_PRINT) reduce 102) ((T_READONLY) reduce 102) ((T_REQUIRE) reduce 102) ((T_REQUIRE_ONCE) reduce 102) ((T_RETURN) reduce 102) ((T_START_HEREDOC) reduce 102) ((T_STATIC) reduce 102) ((T_STRING) reduce 102) ((T_STRING_CAST) reduce 102) ((T_SWITCH) reduce 102) ((T_THROW) reduce 102) ((T_TRAIT) reduce 102) ((T_TRAIT_C) reduce 102) ((T_TRY) reduce 102) ((T_UNSET) reduce 102) ((T_UNSET_CAST) reduce 102) ((T_USE) reduce 102) ((T_VARIABLE) reduce 102) ((T_WHILE) reduce 102) ((T_YIELD) reduce 102) ((T_YIELD_FROM) reduce 102) (("[") reduce 102) (("`") reduce 102) (("{") reduce 102) (("~") reduce 102)) 27037 ((("!") reduce 105) (("\"") reduce 105) (("$") reduce 105) (($) reduce 105) (("(") reduce 105) (("+") reduce 105) (("-") reduce 105) ((";") reduce 105) (("@") reduce 105) ((T_ABSTRACT) reduce 105) ((T_ARRAY) reduce 105) ((T_ARRAY_CAST) reduce 105) ((T_ATTRIBUTE) reduce 105) ((T_BOOL_CAST) reduce 105) ((T_BREAK) reduce 105) ((T_CLASS) reduce 105) ((T_CLASS_C) reduce 105) ((T_CLONE) reduce 105) ((T_CONST) reduce 105) ((T_CONSTANT_ENCAPSED_STRING) reduce 105) ((T_CONTINUE) reduce 105) ((T_DEC) reduce 105) ((T_DECLARE) reduce 105) ((T_DIR) reduce 105) ((T_DNUMBER) reduce 105) ((T_DO) reduce 105) ((T_DOUBLE_CAST) reduce 105) ((T_ECHO) reduce 105) ((T_EMPTY) reduce 105) ((T_ENUM) reduce 105) ((T_EVAL) reduce 105) ((T_EXIT) reduce 105) ((T_FILE) reduce 105) ((T_FINAL) reduce 105) ((T_FN) reduce 105) ((T_FOR) reduce 105) ((T_FOREACH) reduce 105) ((T_FUNCTION) reduce 105) ((T_FUNC_C) reduce 105) ((T_GLOBAL) reduce 105) ((T_GOTO) reduce 105) ((T_HALT_COMPILER) reduce 105) ((T_IF) reduce 105) ((T_INC) reduce 105) ((T_INCLUDE) reduce 105) ((T_INCLUDE_ONCE) reduce 105) ((T_INLINE_HTML) reduce 105) ((T_INTERFACE) reduce 105) ((T_INT_CAST) reduce 105) ((T_ISSET) reduce 105) ((T_LINE) reduce 105) ((T_LIST) reduce 105) ((T_LNUMBER) reduce 105) ((T_MATCH) reduce 105) ((T_METHOD_C) reduce 105) ((T_NAMESPACE) reduce 105) ((T_NAME_FULLY_QUALIFIED) reduce 105) ((T_NAME_QUALIFIED) reduce 105) ((T_NAME_RELATIVE) reduce 105) ((T_NEW) reduce 105) ((T_NS_C) reduce 105) ((T_OBJECT_CAST) reduce 105) ((T_PRINT) reduce 105) ((T_READONLY) reduce 105) ((T_REQUIRE) reduce 105) ((T_REQUIRE_ONCE) reduce 105) ((T_RETURN) reduce 105) ((T_START_HEREDOC) reduce 105) ((T_STATIC) reduce 105) ((T_STRING) reduce 105) ((T_STRING_CAST) reduce 105) ((T_SWITCH) reduce 105) ((T_THROW) reduce 105) ((T_TRAIT) reduce 105) ((T_TRAIT_C) reduce 105) ((T_TRY) reduce 105) ((T_UNSET) reduce 105) ((T_UNSET_CAST) reduce 105) ((T_USE) reduce 105) ((T_VARIABLE) reduce 105) ((T_WHILE) reduce 105) ((T_YIELD) reduce 105) ((T_YIELD_FROM) reduce 105) (("[") reduce 105) (("`") reduce 105) (("{") reduce 105) (("~") reduce 105)) 27038 ((("!") reduce 104) (("\"") reduce 104) (("$") reduce 104) (($) reduce 104) (("(") reduce 104) (("+") reduce 104) (("-") reduce 104) ((";") reduce 104) (("@") reduce 104) ((T_ABSTRACT) reduce 104) ((T_ARRAY) reduce 104) ((T_ARRAY_CAST) reduce 104) ((T_ATTRIBUTE) reduce 104) ((T_BOOL_CAST) reduce 104) ((T_BREAK) reduce 104) ((T_CLASS) reduce 104) ((T_CLASS_C) reduce 104) ((T_CLONE) reduce 104) ((T_CONST) reduce 104) ((T_CONSTANT_ENCAPSED_STRING) reduce 104) ((T_CONTINUE) reduce 104) ((T_DEC) reduce 104) ((T_DECLARE) reduce 104) ((T_DIR) reduce 104) ((T_DNUMBER) reduce 104) ((T_DO) reduce 104) ((T_DOUBLE_CAST) reduce 104) ((T_ECHO) reduce 104) ((T_EMPTY) reduce 104) ((T_ENUM) reduce 104) ((T_EVAL) reduce 104) ((T_EXIT) reduce 104) ((T_FILE) reduce 104) ((T_FINAL) reduce 104) ((T_FN) reduce 104) ((T_FOR) reduce 104) ((T_FOREACH) reduce 104) ((T_FUNCTION) reduce 104) ((T_FUNC_C) reduce 104) ((T_GLOBAL) reduce 104) ((T_GOTO) reduce 104) ((T_HALT_COMPILER) reduce 104) ((T_IF) reduce 104) ((T_INC) reduce 104) ((T_INCLUDE) reduce 104) ((T_INCLUDE_ONCE) reduce 104) ((T_INLINE_HTML) reduce 104) ((T_INTERFACE) reduce 104) ((T_INT_CAST) reduce 104) ((T_ISSET) reduce 104) ((T_LINE) reduce 104) ((T_LIST) reduce 104) ((T_LNUMBER) reduce 104) ((T_MATCH) reduce 104) ((T_METHOD_C) reduce 104) ((T_NAMESPACE) reduce 104) ((T_NAME_FULLY_QUALIFIED) reduce 104) ((T_NAME_QUALIFIED) reduce 104) ((T_NAME_RELATIVE) reduce 104) ((T_NEW) reduce 104) ((T_NS_C) reduce 104) ((T_OBJECT_CAST) reduce 104) ((T_PRINT) reduce 104) ((T_READONLY) reduce 104) ((T_REQUIRE) reduce 104) ((T_REQUIRE_ONCE) reduce 104) ((T_RETURN) reduce 104) ((T_START_HEREDOC) reduce 104) ((T_STATIC) reduce 104) ((T_STRING) reduce 104) ((T_STRING_CAST) reduce 104) ((T_SWITCH) reduce 104) ((T_THROW) reduce 104) ((T_TRAIT) reduce 104) ((T_TRAIT_C) reduce 104) ((T_TRY) reduce 104) ((T_UNSET) reduce 104) ((T_UNSET_CAST) reduce 104) ((T_USE) reduce 104) ((T_VARIABLE) reduce 104) ((T_WHILE) reduce 104) ((T_YIELD) reduce 104) ((T_YIELD_FROM) reduce 104) (("[") reduce 104) (("`") reduce 104) (("{") reduce 104) (("~") reduce 104)) 27049 ((("!") reduce 455) (("\"") reduce 455) (($) reduce 455) (("$") reduce 455) (("(") reduce 455) (("+") reduce 455) (("-") reduce 455) ((";") reduce 455) (("@") reduce 455) ((T_ABSTRACT) reduce 455) ((T_ARRAY) reduce 455) ((T_ARRAY_CAST) reduce 455) ((T_ATTRIBUTE) reduce 455) ((T_BOOL_CAST) reduce 455) ((T_BREAK) reduce 455) ((T_CLASS) reduce 455) ((T_CLASS_C) reduce 455) ((T_CLONE) reduce 455) ((T_CONST) reduce 455) ((T_CONSTANT_ENCAPSED_STRING) reduce 455) ((T_CONTINUE) reduce 455) ((T_DEC) reduce 455) ((T_DECLARE) reduce 455) ((T_DIR) reduce 455) ((T_DNUMBER) reduce 455) ((T_DO) reduce 455) ((T_DOUBLE_CAST) reduce 455) ((T_ECHO) reduce 455) ((T_EMPTY) reduce 455) ((T_ENUM) reduce 455) ((T_EVAL) reduce 455) ((T_EXIT) reduce 455) ((T_FILE) reduce 455) ((T_FINAL) reduce 455) ((T_FN) reduce 455) ((T_FOR) reduce 455) ((T_FOREACH) reduce 455) ((T_FUNCTION) reduce 455) ((T_FUNC_C) reduce 455) ((T_GLOBAL) reduce 455) ((T_GOTO) reduce 455) ((T_HALT_COMPILER) reduce 455) ((T_IF) reduce 455) ((T_INC) reduce 455) ((T_INCLUDE) reduce 455) ((T_INCLUDE_ONCE) reduce 455) ((T_INLINE_HTML) reduce 455) ((T_INTERFACE) reduce 455) ((T_INT_CAST) reduce 455) ((T_ISSET) reduce 455) ((T_LINE) reduce 455) ((T_LIST) reduce 455) ((T_LNUMBER) reduce 455) ((T_MATCH) reduce 455) ((T_METHOD_C) reduce 455) ((T_NAMESPACE) reduce 455) ((T_NAME_FULLY_QUALIFIED) reduce 455) ((T_NAME_QUALIFIED) reduce 455) ((T_NAME_RELATIVE) reduce 455) ((T_NEW) reduce 455) ((T_NS_C) reduce 455) ((T_OBJECT_CAST) reduce 455) ((T_PRINT) reduce 455) ((T_READONLY) reduce 455) ((T_REQUIRE) reduce 455) ((T_REQUIRE_ONCE) reduce 455) ((T_RETURN) reduce 455) ((T_START_HEREDOC) reduce 455) ((T_STATIC) reduce 455) ((T_STRING) reduce 455) ((T_STRING_CAST) reduce 455) ((T_SWITCH) reduce 455) ((T_THROW) reduce 455) ((T_TRAIT) reduce 455) ((T_TRAIT_C) reduce 455) ((T_TRY) reduce 455) ((T_UNSET) reduce 455) ((T_UNSET_CAST) reduce 455) ((T_USE) reduce 455) ((T_VARIABLE) reduce 455) ((T_WHILE) reduce 455) ((T_YIELD) reduce 455) ((T_YIELD_FROM) reduce 455) (("[") reduce 455) (("`") reduce 455) (("{") reduce 455) (("~") reduce 455)) 27050 ((("!") reduce 181) (("\"") reduce 181) (($) reduce 181) (("$") reduce 181) (("(") reduce 181) (("+") reduce 181) (("-") reduce 181) ((";") reduce 181) (("@") reduce 181) ((T_ABSTRACT) reduce 181) ((T_ARRAY) reduce 181) ((T_ARRAY_CAST) reduce 181) ((T_ATTRIBUTE) reduce 181) ((T_BOOL_CAST) reduce 181) ((T_BREAK) reduce 181) ((T_CLASS) reduce 181) ((T_CLASS_C) reduce 181) ((T_CLONE) reduce 181) ((T_CONST) reduce 181) ((T_CONSTANT_ENCAPSED_STRING) reduce 181) ((T_CONTINUE) reduce 181) ((T_DEC) reduce 181) ((T_DECLARE) reduce 181) ((T_DIR) reduce 181) ((T_DNUMBER) reduce 181) ((T_DO) reduce 181) ((T_DOUBLE_CAST) reduce 181) ((T_ECHO) reduce 181) ((T_EMPTY) reduce 181) ((T_ENUM) reduce 181) ((T_EVAL) reduce 181) ((T_EXIT) reduce 181) ((T_FILE) reduce 181) ((T_FINAL) reduce 181) ((T_FN) reduce 181) ((T_FOR) reduce 181) ((T_FOREACH) reduce 181) ((T_FUNCTION) reduce 181) ((T_FUNC_C) reduce 181) ((T_GLOBAL) reduce 181) ((T_GOTO) reduce 181) ((T_HALT_COMPILER) reduce 181) ((T_IF) reduce 181) ((T_INC) reduce 181) ((T_INCLUDE) reduce 181) ((T_INCLUDE_ONCE) reduce 181) ((T_INLINE_HTML) reduce 181) ((T_INTERFACE) reduce 181) ((T_INT_CAST) reduce 181) ((T_ISSET) reduce 181) ((T_LINE) reduce 181) ((T_LIST) reduce 181) ((T_LNUMBER) reduce 181) ((T_MATCH) reduce 181) ((T_METHOD_C) reduce 181) ((T_NAMESPACE) reduce 181) ((T_NAME_FULLY_QUALIFIED) reduce 181) ((T_NAME_QUALIFIED) reduce 181) ((T_NAME_RELATIVE) reduce 181) ((T_NEW) reduce 181) ((T_NS_C) reduce 181) ((T_OBJECT_CAST) reduce 181) ((T_PRINT) reduce 181) ((T_READONLY) reduce 181) ((T_REQUIRE) reduce 181) ((T_REQUIRE_ONCE) reduce 181) ((T_RETURN) reduce 181) ((T_START_HEREDOC) reduce 181) ((T_STATIC) reduce 181) ((T_STRING) reduce 181) ((T_STRING_CAST) reduce 181) ((T_SWITCH) reduce 181) ((T_THROW) reduce 181) ((T_TRAIT) reduce 181) ((T_TRAIT_C) reduce 181) ((T_TRY) reduce 181) ((T_UNSET) reduce 181) ((T_UNSET_CAST) reduce 181) ((T_USE) reduce 181) ((T_VARIABLE) reduce 181) ((T_WHILE) reduce 181) ((T_YIELD) reduce 181) ((T_YIELD_FROM) reduce 181) (("[") reduce 181) (("`") reduce 181) (("{") reduce 181) (("~") reduce 181)) 27058 ((("!") reduce 186) (("\"") reduce 186) (($) reduce 186) (("$") reduce 186) (("(") reduce 186) (("+") reduce 186) (("-") reduce 186) ((";") reduce 186) (("@") reduce 186) ((T_ABSTRACT) reduce 186) ((T_ARRAY) reduce 186) ((T_ARRAY_CAST) reduce 186) ((T_ATTRIBUTE) reduce 186) ((T_BOOL_CAST) reduce 186) ((T_BREAK) reduce 186) ((T_CLASS) reduce 186) ((T_CLASS_C) reduce 186) ((T_CLONE) reduce 186) ((T_CONST) reduce 186) ((T_CONSTANT_ENCAPSED_STRING) reduce 186) ((T_CONTINUE) reduce 186) ((T_DEC) reduce 186) ((T_DECLARE) reduce 186) ((T_DIR) reduce 186) ((T_DNUMBER) reduce 186) ((T_DO) reduce 186) ((T_DOUBLE_CAST) reduce 186) ((T_ECHO) reduce 186) ((T_EMPTY) reduce 186) ((T_ENUM) reduce 186) ((T_EVAL) reduce 186) ((T_EXIT) reduce 186) ((T_FILE) reduce 186) ((T_FINAL) reduce 186) ((T_FN) reduce 186) ((T_FOR) reduce 186) ((T_FOREACH) reduce 186) ((T_FUNCTION) reduce 186) ((T_FUNC_C) reduce 186) ((T_GLOBAL) reduce 186) ((T_GOTO) reduce 186) ((T_HALT_COMPILER) reduce 186) ((T_IF) reduce 186) ((T_INC) reduce 186) ((T_INCLUDE) reduce 186) ((T_INCLUDE_ONCE) reduce 186) ((T_INLINE_HTML) reduce 186) ((T_INTERFACE) reduce 186) ((T_INT_CAST) reduce 186) ((T_ISSET) reduce 186) ((T_LINE) reduce 186) ((T_LIST) reduce 186) ((T_LNUMBER) reduce 186) ((T_MATCH) reduce 186) ((T_METHOD_C) reduce 186) ((T_NAMESPACE) reduce 186) ((T_NAME_FULLY_QUALIFIED) reduce 186) ((T_NAME_QUALIFIED) reduce 186) ((T_NAME_RELATIVE) reduce 186) ((T_NEW) reduce 186) ((T_NS_C) reduce 186) ((T_OBJECT_CAST) reduce 186) ((T_PRINT) reduce 186) ((T_READONLY) reduce 186) ((T_REQUIRE) reduce 186) ((T_REQUIRE_ONCE) reduce 186) ((T_RETURN) reduce 186) ((T_START_HEREDOC) reduce 186) ((T_STATIC) reduce 186) ((T_STRING) reduce 186) ((T_STRING_CAST) reduce 186) ((T_SWITCH) reduce 186) ((T_THROW) reduce 186) ((T_TRAIT) reduce 186) ((T_TRAIT_C) reduce 186) ((T_TRY) reduce 186) ((T_UNSET) reduce 186) ((T_UNSET_CAST) reduce 186) ((T_USE) reduce 186) ((T_VARIABLE) reduce 186) ((T_WHILE) reduce 186) ((T_YIELD) reduce 186) ((T_YIELD_FROM) reduce 186) (("[") reduce 186) (("`") reduce 186) (("{") reduce 186) (("~") reduce 186)) 27063 ((("!") reduce 197) (("\"") reduce 197) (("$") reduce 197) (($) reduce 197) (("(") reduce 197) (("+") reduce 197) (("-") reduce 197) ((";") reduce 197) (("@") reduce 197) ((T_ABSTRACT) reduce 197) ((T_ARRAY) reduce 197) ((T_ARRAY_CAST) reduce 197) ((T_ATTRIBUTE) reduce 197) ((T_BOOL_CAST) reduce 197) ((T_BREAK) reduce 197) ((T_CLASS) reduce 197) ((T_CLASS_C) reduce 197) ((T_CLONE) reduce 197) ((T_CONST) reduce 197) ((T_CONSTANT_ENCAPSED_STRING) reduce 197) ((T_CONTINUE) reduce 197) ((T_DEC) reduce 197) ((T_DECLARE) reduce 197) ((T_DIR) reduce 197) ((T_DNUMBER) reduce 197) ((T_DO) reduce 197) ((T_DOUBLE_CAST) reduce 197) ((T_ECHO) reduce 197) ((T_EMPTY) reduce 197) ((T_ENUM) reduce 197) ((T_EVAL) reduce 197) ((T_EXIT) reduce 197) ((T_FILE) reduce 197) ((T_FINAL) reduce 197) ((T_FN) reduce 197) ((T_FOR) reduce 197) ((T_FOREACH) reduce 197) ((T_FUNCTION) reduce 197) ((T_FUNC_C) reduce 197) ((T_GLOBAL) reduce 197) ((T_GOTO) reduce 197) ((T_HALT_COMPILER) reduce 197) ((T_IF) reduce 197) ((T_INC) reduce 197) ((T_INCLUDE) reduce 197) ((T_INCLUDE_ONCE) reduce 197) ((T_INLINE_HTML) reduce 197) ((T_INTERFACE) reduce 197) ((T_INT_CAST) reduce 197) ((T_ISSET) reduce 197) ((T_LINE) reduce 197) ((T_LIST) reduce 197) ((T_LNUMBER) reduce 197) ((T_MATCH) reduce 197) ((T_METHOD_C) reduce 197) ((T_NAMESPACE) reduce 197) ((T_NAME_FULLY_QUALIFIED) reduce 197) ((T_NAME_QUALIFIED) reduce 197) ((T_NAME_RELATIVE) reduce 197) ((T_NEW) reduce 197) ((T_NS_C) reduce 197) ((T_OBJECT_CAST) reduce 197) ((T_PRINT) reduce 197) ((T_READONLY) reduce 197) ((T_REQUIRE) reduce 197) ((T_REQUIRE_ONCE) reduce 197) ((T_RETURN) reduce 197) ((T_START_HEREDOC) reduce 197) ((T_STATIC) reduce 197) ((T_STRING) reduce 197) ((T_STRING_CAST) reduce 197) ((T_SWITCH) reduce 197) ((T_THROW) reduce 197) ((T_TRAIT) reduce 197) ((T_TRAIT_C) reduce 197) ((T_TRY) reduce 197) ((T_UNSET) reduce 197) ((T_UNSET_CAST) reduce 197) ((T_USE) reduce 197) ((T_VARIABLE) reduce 197) ((T_WHILE) reduce 197) ((T_YIELD) reduce 197) ((T_YIELD_FROM) reduce 197) (("[") reduce 197) (("`") reduce 197) (("{") reduce 197) (("~") reduce 197)) 27069 ((("!") reduce 198) (("\"") reduce 198) (($) reduce 198) (("$") reduce 198) (("(") reduce 198) (("+") reduce 198) (("-") reduce 198) ((";") reduce 198) (("@") reduce 198) ((T_ABSTRACT) reduce 198) ((T_ARRAY) reduce 198) ((T_ARRAY_CAST) reduce 198) ((T_ATTRIBUTE) reduce 198) ((T_BOOL_CAST) reduce 198) ((T_BREAK) reduce 198) ((T_CLASS) reduce 198) ((T_CLASS_C) reduce 198) ((T_CLONE) reduce 198) ((T_CONST) reduce 198) ((T_CONSTANT_ENCAPSED_STRING) reduce 198) ((T_CONTINUE) reduce 198) ((T_DEC) reduce 198) ((T_DECLARE) reduce 198) ((T_DIR) reduce 198) ((T_DNUMBER) reduce 198) ((T_DO) reduce 198) ((T_DOUBLE_CAST) reduce 198) ((T_ECHO) reduce 198) ((T_EMPTY) reduce 198) ((T_ENUM) reduce 198) ((T_EVAL) reduce 198) ((T_EXIT) reduce 198) ((T_FILE) reduce 198) ((T_FINAL) reduce 198) ((T_FN) reduce 198) ((T_FOR) reduce 198) ((T_FOREACH) reduce 198) ((T_FUNCTION) reduce 198) ((T_FUNC_C) reduce 198) ((T_GLOBAL) reduce 198) ((T_GOTO) reduce 198) ((T_HALT_COMPILER) reduce 198) ((T_IF) reduce 198) ((T_INC) reduce 198) ((T_INCLUDE) reduce 198) ((T_INCLUDE_ONCE) reduce 198) ((T_INLINE_HTML) reduce 198) ((T_INTERFACE) reduce 198) ((T_INT_CAST) reduce 198) ((T_ISSET) reduce 198) ((T_LINE) reduce 198) ((T_LIST) reduce 198) ((T_LNUMBER) reduce 198) ((T_MATCH) reduce 198) ((T_METHOD_C) reduce 198) ((T_NAMESPACE) reduce 198) ((T_NAME_FULLY_QUALIFIED) reduce 198) ((T_NAME_QUALIFIED) reduce 198) ((T_NAME_RELATIVE) reduce 198) ((T_NEW) reduce 198) ((T_NS_C) reduce 198) ((T_OBJECT_CAST) reduce 198) ((T_PRINT) reduce 198) ((T_READONLY) reduce 198) ((T_REQUIRE) reduce 198) ((T_REQUIRE_ONCE) reduce 198) ((T_RETURN) reduce 198) ((T_START_HEREDOC) reduce 198) ((T_STATIC) reduce 198) ((T_STRING) reduce 198) ((T_STRING_CAST) reduce 198) ((T_SWITCH) reduce 198) ((T_THROW) reduce 198) ((T_TRAIT) reduce 198) ((T_TRAIT_C) reduce 198) ((T_TRY) reduce 198) ((T_UNSET) reduce 198) ((T_UNSET_CAST) reduce 198) ((T_USE) reduce 198) ((T_VARIABLE) reduce 198) ((T_WHILE) reduce 198) ((T_YIELD) reduce 198) ((T_YIELD_FROM) reduce 198) (("[") reduce 198) (("`") reduce 198) (("{") reduce 198) (("~") reduce 198)) 27076 ((("!") reduce 199) (("\"") reduce 199) (("$") reduce 199) (($) reduce 199) (("(") reduce 199) (("+") reduce 199) (("-") reduce 199) ((";") reduce 199) (("@") reduce 199) ((T_ABSTRACT) reduce 199) ((T_ARRAY) reduce 199) ((T_ARRAY_CAST) reduce 199) ((T_ATTRIBUTE) reduce 199) ((T_BOOL_CAST) reduce 199) ((T_BREAK) reduce 199) ((T_CLASS) reduce 199) ((T_CLASS_C) reduce 199) ((T_CLONE) reduce 199) ((T_CONST) reduce 199) ((T_CONSTANT_ENCAPSED_STRING) reduce 199) ((T_CONTINUE) reduce 199) ((T_DEC) reduce 199) ((T_DECLARE) reduce 199) ((T_DIR) reduce 199) ((T_DNUMBER) reduce 199) ((T_DO) reduce 199) ((T_DOUBLE_CAST) reduce 199) ((T_ECHO) reduce 199) ((T_EMPTY) reduce 199) ((T_ENUM) reduce 199) ((T_EVAL) reduce 199) ((T_EXIT) reduce 199) ((T_FILE) reduce 199) ((T_FINAL) reduce 199) ((T_FN) reduce 199) ((T_FOR) reduce 199) ((T_FOREACH) reduce 199) ((T_FUNCTION) reduce 199) ((T_FUNC_C) reduce 199) ((T_GLOBAL) reduce 199) ((T_GOTO) reduce 199) ((T_HALT_COMPILER) reduce 199) ((T_IF) reduce 199) ((T_INC) reduce 199) ((T_INCLUDE) reduce 199) ((T_INCLUDE_ONCE) reduce 199) ((T_INLINE_HTML) reduce 199) ((T_INTERFACE) reduce 199) ((T_INT_CAST) reduce 199) ((T_ISSET) reduce 199) ((T_LINE) reduce 199) ((T_LIST) reduce 199) ((T_LNUMBER) reduce 199) ((T_MATCH) reduce 199) ((T_METHOD_C) reduce 199) ((T_NAMESPACE) reduce 199) ((T_NAME_FULLY_QUALIFIED) reduce 199) ((T_NAME_QUALIFIED) reduce 199) ((T_NAME_RELATIVE) reduce 199) ((T_NEW) reduce 199) ((T_NS_C) reduce 199) ((T_OBJECT_CAST) reduce 199) ((T_PRINT) reduce 199) ((T_READONLY) reduce 199) ((T_REQUIRE) reduce 199) ((T_REQUIRE_ONCE) reduce 199) ((T_RETURN) reduce 199) ((T_START_HEREDOC) reduce 199) ((T_STATIC) reduce 199) ((T_STRING) reduce 199) ((T_STRING_CAST) reduce 199) ((T_SWITCH) reduce 199) ((T_THROW) reduce 199) ((T_TRAIT) reduce 199) ((T_TRAIT_C) reduce 199) ((T_TRY) reduce 199) ((T_UNSET) reduce 199) ((T_UNSET_CAST) reduce 199) ((T_USE) reduce 199) ((T_VARIABLE) reduce 199) ((T_WHILE) reduce 199) ((T_YIELD) reduce 199) ((T_YIELD_FROM) reduce 199) (("[") reduce 199) (("`") reduce 199) (("{") reduce 199) (("~") reduce 199)) 27083 ((("!") reduce 187) (("\"") reduce 187) (("$") reduce 187) (($) reduce 187) (("(") reduce 187) (("+") reduce 187) (("-") reduce 187) ((";") reduce 187) (("@") reduce 187) ((T_ABSTRACT) reduce 187) ((T_ARRAY) reduce 187) ((T_ARRAY_CAST) reduce 187) ((T_ATTRIBUTE) reduce 187) ((T_BOOL_CAST) reduce 187) ((T_BREAK) reduce 187) ((T_CLASS) reduce 187) ((T_CLASS_C) reduce 187) ((T_CLONE) reduce 187) ((T_CONST) reduce 187) ((T_CONSTANT_ENCAPSED_STRING) reduce 187) ((T_CONTINUE) reduce 187) ((T_DEC) reduce 187) ((T_DECLARE) reduce 187) ((T_DIR) reduce 187) ((T_DNUMBER) reduce 187) ((T_DO) reduce 187) ((T_DOUBLE_CAST) reduce 187) ((T_ECHO) reduce 187) ((T_EMPTY) reduce 187) ((T_ENUM) reduce 187) ((T_EVAL) reduce 187) ((T_EXIT) reduce 187) ((T_FILE) reduce 187) ((T_FINAL) reduce 187) ((T_FN) reduce 187) ((T_FOR) reduce 187) ((T_FOREACH) reduce 187) ((T_FUNCTION) reduce 187) ((T_FUNC_C) reduce 187) ((T_GLOBAL) reduce 187) ((T_GOTO) reduce 187) ((T_HALT_COMPILER) reduce 187) ((T_IF) reduce 187) ((T_INC) reduce 187) ((T_INCLUDE) reduce 187) ((T_INCLUDE_ONCE) reduce 187) ((T_INLINE_HTML) reduce 187) ((T_INTERFACE) reduce 187) ((T_INT_CAST) reduce 187) ((T_ISSET) reduce 187) ((T_LINE) reduce 187) ((T_LIST) reduce 187) ((T_LNUMBER) reduce 187) ((T_MATCH) reduce 187) ((T_METHOD_C) reduce 187) ((T_NAMESPACE) reduce 187) ((T_NAME_FULLY_QUALIFIED) reduce 187) ((T_NAME_QUALIFIED) reduce 187) ((T_NAME_RELATIVE) reduce 187) ((T_NEW) reduce 187) ((T_NS_C) reduce 187) ((T_OBJECT_CAST) reduce 187) ((T_PRINT) reduce 187) ((T_READONLY) reduce 187) ((T_REQUIRE) reduce 187) ((T_REQUIRE_ONCE) reduce 187) ((T_RETURN) reduce 187) ((T_START_HEREDOC) reduce 187) ((T_STATIC) reduce 187) ((T_STRING) reduce 187) ((T_STRING_CAST) reduce 187) ((T_SWITCH) reduce 187) ((T_THROW) reduce 187) ((T_TRAIT) reduce 187) ((T_TRAIT_C) reduce 187) ((T_TRY) reduce 187) ((T_UNSET) reduce 187) ((T_UNSET_CAST) reduce 187) ((T_USE) reduce 187) ((T_VARIABLE) reduce 187) ((T_WHILE) reduce 187) ((T_YIELD) reduce 187) ((T_YIELD_FROM) reduce 187) (("[") reduce 187) (("`") reduce 187) (("{") reduce 187) (("~") reduce 187)) 27103 ((("!") reduce 247) (("\"") reduce 247) (("$") reduce 247) (($) reduce 247) (("(") reduce 247) (("+") reduce 247) (("-") reduce 247) ((";") reduce 247) (("@") reduce 247) ((T_ABSTRACT) reduce 247) ((T_ARRAY) reduce 247) ((T_ARRAY_CAST) reduce 247) ((T_ATTRIBUTE) reduce 247) ((T_BOOL_CAST) reduce 247) ((T_BREAK) reduce 247) ((T_CLASS) reduce 247) ((T_CLASS_C) reduce 247) ((T_CLONE) reduce 247) ((T_CONST) reduce 247) ((T_CONSTANT_ENCAPSED_STRING) reduce 247) ((T_CONTINUE) reduce 247) ((T_DEC) reduce 247) ((T_DECLARE) reduce 247) ((T_DIR) reduce 247) ((T_DNUMBER) reduce 247) ((T_DO) reduce 247) ((T_DOUBLE_CAST) reduce 247) ((T_ECHO) reduce 247) ((T_EMPTY) reduce 247) ((T_ENUM) reduce 247) ((T_EVAL) reduce 247) ((T_EXIT) reduce 247) ((T_FILE) reduce 247) ((T_FINAL) reduce 247) ((T_FN) reduce 247) ((T_FOR) reduce 247) ((T_FOREACH) reduce 247) ((T_FUNCTION) reduce 247) ((T_FUNC_C) reduce 247) ((T_GLOBAL) reduce 247) ((T_GOTO) reduce 247) ((T_HALT_COMPILER) reduce 247) ((T_IF) reduce 247) ((T_INC) reduce 247) ((T_INCLUDE) reduce 247) ((T_INCLUDE_ONCE) reduce 247) ((T_INLINE_HTML) reduce 247) ((T_INTERFACE) reduce 247) ((T_INT_CAST) reduce 247) ((T_ISSET) reduce 247) ((T_LINE) reduce 247) ((T_LIST) reduce 247) ((T_LNUMBER) reduce 247) ((T_MATCH) reduce 247) ((T_METHOD_C) reduce 247) ((T_NAMESPACE) reduce 247) ((T_NAME_FULLY_QUALIFIED) reduce 247) ((T_NAME_QUALIFIED) reduce 247) ((T_NAME_RELATIVE) reduce 247) ((T_NEW) reduce 247) ((T_NS_C) reduce 247) ((T_OBJECT_CAST) reduce 247) ((T_PRINT) reduce 247) ((T_READONLY) reduce 247) ((T_REQUIRE) reduce 247) ((T_REQUIRE_ONCE) reduce 247) ((T_RETURN) reduce 247) ((T_START_HEREDOC) reduce 247) ((T_STATIC) reduce 247) ((T_STRING) reduce 247) ((T_STRING_CAST) reduce 247) ((T_SWITCH) reduce 247) ((T_THROW) reduce 247) ((T_TRAIT) reduce 247) ((T_TRAIT_C) reduce 247) ((T_TRY) reduce 247) ((T_UNSET) reduce 247) ((T_UNSET_CAST) reduce 247) ((T_USE) reduce 247) ((T_VARIABLE) reduce 247) ((T_WHILE) reduce 247) ((T_YIELD) reduce 247) ((T_YIELD_FROM) reduce 247) (("[") reduce 247) (("`") reduce 247) (("{") reduce 247) (("~") reduce 247)) 27107 ((("!") reduce 248) (("\"") reduce 248) (($) reduce 248) (("$") reduce 248) (("(") reduce 248) (("+") reduce 248) (("-") reduce 248) ((";") reduce 248) (("@") reduce 248) ((T_ABSTRACT) reduce 248) ((T_ARRAY) reduce 248) ((T_ARRAY_CAST) reduce 248) ((T_ATTRIBUTE) reduce 248) ((T_BOOL_CAST) reduce 248) ((T_BREAK) reduce 248) ((T_CLASS) reduce 248) ((T_CLASS_C) reduce 248) ((T_CLONE) reduce 248) ((T_CONST) reduce 248) ((T_CONSTANT_ENCAPSED_STRING) reduce 248) ((T_CONTINUE) reduce 248) ((T_DEC) reduce 248) ((T_DECLARE) reduce 248) ((T_DIR) reduce 248) ((T_DNUMBER) reduce 248) ((T_DO) reduce 248) ((T_DOUBLE_CAST) reduce 248) ((T_ECHO) reduce 248) ((T_EMPTY) reduce 248) ((T_ENUM) reduce 248) ((T_EVAL) reduce 248) ((T_EXIT) reduce 248) ((T_FILE) reduce 248) ((T_FINAL) reduce 248) ((T_FN) reduce 248) ((T_FOR) reduce 248) ((T_FOREACH) reduce 248) ((T_FUNCTION) reduce 248) ((T_FUNC_C) reduce 248) ((T_GLOBAL) reduce 248) ((T_GOTO) reduce 248) ((T_HALT_COMPILER) reduce 248) ((T_IF) reduce 248) ((T_INC) reduce 248) ((T_INCLUDE) reduce 248) ((T_INCLUDE_ONCE) reduce 248) ((T_INLINE_HTML) reduce 248) ((T_INTERFACE) reduce 248) ((T_INT_CAST) reduce 248) ((T_ISSET) reduce 248) ((T_LINE) reduce 248) ((T_LIST) reduce 248) ((T_LNUMBER) reduce 248) ((T_MATCH) reduce 248) ((T_METHOD_C) reduce 248) ((T_NAMESPACE) reduce 248) ((T_NAME_FULLY_QUALIFIED) reduce 248) ((T_NAME_QUALIFIED) reduce 248) ((T_NAME_RELATIVE) reduce 248) ((T_NEW) reduce 248) ((T_NS_C) reduce 248) ((T_OBJECT_CAST) reduce 248) ((T_PRINT) reduce 248) ((T_READONLY) reduce 248) ((T_REQUIRE) reduce 248) ((T_REQUIRE_ONCE) reduce 248) ((T_RETURN) reduce 248) ((T_START_HEREDOC) reduce 248) ((T_STATIC) reduce 248) ((T_STRING) reduce 248) ((T_STRING_CAST) reduce 248) ((T_SWITCH) reduce 248) ((T_THROW) reduce 248) ((T_TRAIT) reduce 248) ((T_TRAIT_C) reduce 248) ((T_TRY) reduce 248) ((T_UNSET) reduce 248) ((T_UNSET_CAST) reduce 248) ((T_USE) reduce 248) ((T_VARIABLE) reduce 248) ((T_WHILE) reduce 248) ((T_YIELD) reduce 248) ((T_YIELD_FROM) reduce 248) (("[") reduce 248) (("`") reduce 248) (("{") reduce 248) (("~") reduce 248)) 27626 ((("!") reduce 239) (("\"") reduce 239) (("$") reduce 239) (($) reduce 239) (("(") reduce 239) (("+") reduce 239) (("-") reduce 239) ((";") reduce 239) (("@") reduce 239) ((T_ABSTRACT) reduce 239) ((T_ARRAY) reduce 239) ((T_ARRAY_CAST) reduce 239) ((T_ATTRIBUTE) reduce 239) ((T_BOOL_CAST) reduce 239) ((T_BREAK) reduce 239) ((T_CLASS) reduce 239) ((T_CLASS_C) reduce 239) ((T_CLONE) reduce 239) ((T_CONST) reduce 239) ((T_CONSTANT_ENCAPSED_STRING) reduce 239) ((T_CONTINUE) reduce 239) ((T_DEC) reduce 239) ((T_DECLARE) reduce 239) ((T_DIR) reduce 239) ((T_DNUMBER) reduce 239) ((T_DO) reduce 239) ((T_DOUBLE_CAST) reduce 239) ((T_ECHO) reduce 239) ((T_EMPTY) reduce 239) ((T_ENUM) reduce 239) ((T_EVAL) reduce 239) ((T_EXIT) reduce 239) ((T_FILE) reduce 239) ((T_FINAL) reduce 239) ((T_FN) reduce 239) ((T_FOR) reduce 239) ((T_FOREACH) reduce 239) ((T_FUNCTION) reduce 239) ((T_FUNC_C) reduce 239) ((T_GLOBAL) reduce 239) ((T_GOTO) reduce 239) ((T_HALT_COMPILER) reduce 239) ((T_IF) reduce 239) ((T_INC) reduce 239) ((T_INCLUDE) reduce 239) ((T_INCLUDE_ONCE) reduce 239) ((T_INLINE_HTML) reduce 239) ((T_INTERFACE) reduce 239) ((T_INT_CAST) reduce 239) ((T_ISSET) reduce 239) ((T_LINE) reduce 239) ((T_LIST) reduce 239) ((T_LNUMBER) reduce 239) ((T_MATCH) reduce 239) ((T_METHOD_C) reduce 239) ((T_NAMESPACE) reduce 239) ((T_NAME_FULLY_QUALIFIED) reduce 239) ((T_NAME_QUALIFIED) reduce 239) ((T_NAME_RELATIVE) reduce 239) ((T_NEW) reduce 239) ((T_NS_C) reduce 239) ((T_OBJECT_CAST) reduce 239) ((T_PRINT) reduce 239) ((T_READONLY) reduce 239) ((T_REQUIRE) reduce 239) ((T_REQUIRE_ONCE) reduce 239) ((T_RETURN) reduce 239) ((T_START_HEREDOC) reduce 239) ((T_STATIC) reduce 239) ((T_STRING) reduce 239) ((T_STRING_CAST) reduce 239) ((T_SWITCH) reduce 239) ((T_THROW) reduce 239) ((T_TRAIT) reduce 239) ((T_TRAIT_C) reduce 239) ((T_TRY) reduce 239) ((T_UNSET) reduce 239) ((T_UNSET_CAST) reduce 239) ((T_USE) reduce 239) ((T_VARIABLE) reduce 239) ((T_WHILE) reduce 239) ((T_YIELD) reduce 239) ((T_YIELD_FROM) reduce 239) (("[") reduce 239) (("`") reduce 239) (("{") reduce 239) (("~") reduce 239)) 27627 ((("!") reduce 148) (("\"") reduce 148) (($) reduce 148) (("$") reduce 148) (("(") reduce 148) (("+") reduce 148) (("-") reduce 148) ((";") reduce 148) (("@") reduce 148) ((T_ABSTRACT) reduce 148) ((T_ARRAY) reduce 148) ((T_ARRAY_CAST) reduce 148) ((T_ATTRIBUTE) reduce 148) ((T_BOOL_CAST) reduce 148) ((T_BREAK) reduce 148) ((T_CLASS) reduce 148) ((T_CLASS_C) reduce 148) ((T_CLONE) reduce 148) ((T_CONST) reduce 148) ((T_CONSTANT_ENCAPSED_STRING) reduce 148) ((T_CONTINUE) reduce 148) ((T_DEC) reduce 148) ((T_DECLARE) reduce 148) ((T_DIR) reduce 148) ((T_DNUMBER) reduce 148) ((T_DO) reduce 148) ((T_DOUBLE_CAST) reduce 148) ((T_ECHO) reduce 148) ((T_EMPTY) reduce 148) ((T_ENUM) reduce 148) ((T_EVAL) reduce 148) ((T_EXIT) reduce 148) ((T_FILE) reduce 148) ((T_FINAL) reduce 148) ((T_FN) reduce 148) ((T_FOR) reduce 148) ((T_FOREACH) reduce 148) ((T_FUNCTION) reduce 148) ((T_FUNC_C) reduce 148) ((T_GLOBAL) reduce 148) ((T_GOTO) reduce 148) ((T_HALT_COMPILER) reduce 148) ((T_IF) reduce 148) ((T_INC) reduce 148) ((T_INCLUDE) reduce 148) ((T_INCLUDE_ONCE) reduce 148) ((T_INLINE_HTML) reduce 148) ((T_INTERFACE) reduce 148) ((T_INT_CAST) reduce 148) ((T_ISSET) reduce 148) ((T_LINE) reduce 148) ((T_LIST) reduce 148) ((T_LNUMBER) reduce 148) ((T_MATCH) reduce 148) ((T_METHOD_C) reduce 148) ((T_NAMESPACE) reduce 148) ((T_NAME_FULLY_QUALIFIED) reduce 148) ((T_NAME_QUALIFIED) reduce 148) ((T_NAME_RELATIVE) reduce 148) ((T_NEW) reduce 148) ((T_NS_C) reduce 148) ((T_OBJECT_CAST) reduce 148) ((T_PRINT) reduce 148) ((T_READONLY) reduce 148) ((T_REQUIRE) reduce 148) ((T_REQUIRE_ONCE) reduce 148) ((T_RETURN) reduce 148) ((T_START_HEREDOC) reduce 148) ((T_STATIC) reduce 148) ((T_STRING) reduce 148) ((T_STRING_CAST) reduce 148) ((T_SWITCH) reduce 148) ((T_THROW) reduce 148) ((T_TRAIT) reduce 148) ((T_TRAIT_C) reduce 148) ((T_TRY) reduce 148) ((T_UNSET) reduce 148) ((T_UNSET_CAST) reduce 148) ((T_USE) reduce 148) ((T_VARIABLE) reduce 148) ((T_WHILE) reduce 148) ((T_YIELD) reduce 148) ((T_YIELD_FROM) reduce 148) (("[") reduce 148) (("`") reduce 148) (("{") reduce 148) (("~") reduce 148)) 27630 ((("!") reduce 240) (("\"") reduce 240) (($) reduce 240) (("$") reduce 240) (("(") reduce 240) (("+") reduce 240) (("-") reduce 240) ((";") reduce 240) (("@") reduce 240) ((T_ABSTRACT) reduce 240) ((T_ARRAY) reduce 240) ((T_ARRAY_CAST) reduce 240) ((T_ATTRIBUTE) reduce 240) ((T_BOOL_CAST) reduce 240) ((T_BREAK) reduce 240) ((T_CLASS) reduce 240) ((T_CLASS_C) reduce 240) ((T_CLONE) reduce 240) ((T_CONST) reduce 240) ((T_CONSTANT_ENCAPSED_STRING) reduce 240) ((T_CONTINUE) reduce 240) ((T_DEC) reduce 240) ((T_DECLARE) reduce 240) ((T_DIR) reduce 240) ((T_DNUMBER) reduce 240) ((T_DO) reduce 240) ((T_DOUBLE_CAST) reduce 240) ((T_ECHO) reduce 240) ((T_EMPTY) reduce 240) ((T_ENUM) reduce 240) ((T_EVAL) reduce 240) ((T_EXIT) reduce 240) ((T_FILE) reduce 240) ((T_FINAL) reduce 240) ((T_FN) reduce 240) ((T_FOR) reduce 240) ((T_FOREACH) reduce 240) ((T_FUNCTION) reduce 240) ((T_FUNC_C) reduce 240) ((T_GLOBAL) reduce 240) ((T_GOTO) reduce 240) ((T_HALT_COMPILER) reduce 240) ((T_IF) reduce 240) ((T_INC) reduce 240) ((T_INCLUDE) reduce 240) ((T_INCLUDE_ONCE) reduce 240) ((T_INLINE_HTML) reduce 240) ((T_INTERFACE) reduce 240) ((T_INT_CAST) reduce 240) ((T_ISSET) reduce 240) ((T_LINE) reduce 240) ((T_LIST) reduce 240) ((T_LNUMBER) reduce 240) ((T_MATCH) reduce 240) ((T_METHOD_C) reduce 240) ((T_NAMESPACE) reduce 240) ((T_NAME_FULLY_QUALIFIED) reduce 240) ((T_NAME_QUALIFIED) reduce 240) ((T_NAME_RELATIVE) reduce 240) ((T_NEW) reduce 240) ((T_NS_C) reduce 240) ((T_OBJECT_CAST) reduce 240) ((T_PRINT) reduce 240) ((T_READONLY) reduce 240) ((T_REQUIRE) reduce 240) ((T_REQUIRE_ONCE) reduce 240) ((T_RETURN) reduce 240) ((T_START_HEREDOC) reduce 240) ((T_STATIC) reduce 240) ((T_STRING) reduce 240) ((T_STRING_CAST) reduce 240) ((T_SWITCH) reduce 240) ((T_THROW) reduce 240) ((T_TRAIT) reduce 240) ((T_TRAIT_C) reduce 240) ((T_TRY) reduce 240) ((T_UNSET) reduce 240) ((T_UNSET_CAST) reduce 240) ((T_USE) reduce 240) ((T_VARIABLE) reduce 240) ((T_WHILE) reduce 240) ((T_YIELD) reduce 240) ((T_YIELD_FROM) reduce 240) (("[") reduce 240) (("`") reduce 240) (("{") reduce 240) (("~") reduce 240)) 27631 (((T_NAME_FULLY_QUALIFIED) reduce 120) ((T_NAME_QUALIFIED) reduce 120) ((T_STRING) reduce 120)) 27632 (((T_NAME_FULLY_QUALIFIED) reduce 119) ((T_NAME_QUALIFIED) reduce 119) ((T_STRING) reduce 119)) 27633 (((",") reduce 90) ((";") reduce 90) ((T_AS) reduce 90) ((T_NS_SEPARATOR) reduce 90)) 27634 (((",") reduce 88) ((";") reduce 88) ((T_AS) reduce 88) ((T_NS_SEPARATOR) reduce 88)) 27635 (((",") reduce 87) ((";") reduce 87) ((T_AS) reduce 87) ((T_NS_SEPARATOR) reduce 87)) 27636 (((",") reduce 135) ((";") reduce 135) ((T_AS) shift) ((T_NS_SEPARATOR) shift)) 27638 (((",") reduce 89) ((";") reduce 89) ((T_AS) reduce 89) ((T_NS_SEPARATOR) reduce 89)) 27639 (((",") reduce 130) ((";") reduce 130)) 27641 (((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_STRING) shift)) 27646 ((("!") reduce 117) (("\"") reduce 117) (($) reduce 117) (("$") reduce 117) (("(") reduce 117) (("+") reduce 117) (("-") reduce 117) ((";") reduce 117) (("@") reduce 117) ((T_ABSTRACT) reduce 117) ((T_ARRAY) reduce 117) ((T_ARRAY_CAST) reduce 117) ((T_ATTRIBUTE) reduce 117) ((T_BOOL_CAST) reduce 117) ((T_BREAK) reduce 117) ((T_CLASS) reduce 117) ((T_CLASS_C) reduce 117) ((T_CLONE) reduce 117) ((T_CONST) reduce 117) ((T_CONSTANT_ENCAPSED_STRING) reduce 117) ((T_CONTINUE) reduce 117) ((T_DEC) reduce 117) ((T_DECLARE) reduce 117) ((T_DIR) reduce 117) ((T_DNUMBER) reduce 117) ((T_DO) reduce 117) ((T_DOUBLE_CAST) reduce 117) ((T_ECHO) reduce 117) ((T_EMPTY) reduce 117) ((T_ENUM) reduce 117) ((T_EVAL) reduce 117) ((T_EXIT) reduce 117) ((T_FILE) reduce 117) ((T_FINAL) reduce 117) ((T_FN) reduce 117) ((T_FOR) reduce 117) ((T_FOREACH) reduce 117) ((T_FUNCTION) reduce 117) ((T_FUNC_C) reduce 117) ((T_GLOBAL) reduce 117) ((T_GOTO) reduce 117) ((T_HALT_COMPILER) reduce 117) ((T_IF) reduce 117) ((T_INC) reduce 117) ((T_INCLUDE) reduce 117) ((T_INCLUDE_ONCE) reduce 117) ((T_INLINE_HTML) reduce 117) ((T_INTERFACE) reduce 117) ((T_INT_CAST) reduce 117) ((T_ISSET) reduce 117) ((T_LINE) reduce 117) ((T_LIST) reduce 117) ((T_LNUMBER) reduce 117) ((T_MATCH) reduce 117) ((T_METHOD_C) reduce 117) ((T_NAMESPACE) reduce 117) ((T_NAME_FULLY_QUALIFIED) reduce 117) ((T_NAME_QUALIFIED) reduce 117) ((T_NAME_RELATIVE) reduce 117) ((T_NEW) reduce 117) ((T_NS_C) reduce 117) ((T_OBJECT_CAST) reduce 117) ((T_PRINT) reduce 117) ((T_READONLY) reduce 117) ((T_REQUIRE) reduce 117) ((T_REQUIRE_ONCE) reduce 117) ((T_RETURN) reduce 117) ((T_START_HEREDOC) reduce 117) ((T_STATIC) reduce 117) ((T_STRING) reduce 117) ((T_STRING_CAST) reduce 117) ((T_SWITCH) reduce 117) ((T_THROW) reduce 117) ((T_TRAIT) reduce 117) ((T_TRAIT_C) reduce 117) ((T_TRY) reduce 117) ((T_UNSET) reduce 117) ((T_UNSET_CAST) reduce 117) ((T_USE) reduce 117) ((T_VARIABLE) reduce 117) ((T_WHILE) reduce 117) ((T_YIELD) reduce 117) ((T_YIELD_FROM) reduce 117) (("[") reduce 117) (("`") reduce 117) (("{") reduce 117) (("~") reduce 117)) 27647 (((",") reduce 90) ((";") reduce 90) ((T_AS) reduce 90)) 27648 (((",") reduce 88) ((";") reduce 88) ((T_AS) reduce 88)) 27649 (((",") reduce 87) ((";") reduce 87) ((T_AS) reduce 87)) 27650 (((",") reduce 135) ((";") reduce 135) ((T_AS) shift)) 27651 (((",") reduce 89) ((";") reduce 89) ((T_AS) reduce 89)) 27652 (((",") reduce 129) ((";") reduce 129)) 27654 (((",") reduce 136) ((";") reduce 136)) 27656 (((T_NAME_QUALIFIED) shift) ((T_STRING) shift)) 27657 (((",") reduce 88) ((T_AS) reduce 88) (("}") reduce 88)) 27658 (((",") reduce 87) ((T_AS) reduce 87) (("}") reduce 87)) 27659 (((",") reduce 133) ((T_AS) shift) (("}") reduce 133)) 27660 (((",") reduce 128) (("}") reduce 128)) 27662 (((T_NAME_QUALIFIED) shift) ((T_STRING) shift) (("}") reduce 124)) 27664 (((";") reduce 121)) 27665 (((",") reduce 127) (("}") reduce 127)) 27667 (((",") reduce 134) (("}") reduce 134)) 27668 ((("!") reduce 115) (("\"") reduce 115) (($) reduce 115) (("$") reduce 115) (("(") reduce 115) (("+") reduce 115) (("-") reduce 115) ((";") reduce 115) (("@") reduce 115) ((T_ABSTRACT) reduce 115) ((T_ARRAY) reduce 115) ((T_ARRAY_CAST) reduce 115) ((T_ATTRIBUTE) reduce 115) ((T_BOOL_CAST) reduce 115) ((T_BREAK) reduce 115) ((T_CLASS) reduce 115) ((T_CLASS_C) reduce 115) ((T_CLONE) reduce 115) ((T_CONST) reduce 115) ((T_CONSTANT_ENCAPSED_STRING) reduce 115) ((T_CONTINUE) reduce 115) ((T_DEC) reduce 115) ((T_DECLARE) reduce 115) ((T_DIR) reduce 115) ((T_DNUMBER) reduce 115) ((T_DO) reduce 115) ((T_DOUBLE_CAST) reduce 115) ((T_ECHO) reduce 115) ((T_EMPTY) reduce 115) ((T_ENUM) reduce 115) ((T_EVAL) reduce 115) ((T_EXIT) reduce 115) ((T_FILE) reduce 115) ((T_FINAL) reduce 115) ((T_FN) reduce 115) ((T_FOR) reduce 115) ((T_FOREACH) reduce 115) ((T_FUNCTION) reduce 115) ((T_FUNC_C) reduce 115) ((T_GLOBAL) reduce 115) ((T_GOTO) reduce 115) ((T_HALT_COMPILER) reduce 115) ((T_IF) reduce 115) ((T_INC) reduce 115) ((T_INCLUDE) reduce 115) ((T_INCLUDE_ONCE) reduce 115) ((T_INLINE_HTML) reduce 115) ((T_INTERFACE) reduce 115) ((T_INT_CAST) reduce 115) ((T_ISSET) reduce 115) ((T_LINE) reduce 115) ((T_LIST) reduce 115) ((T_LNUMBER) reduce 115) ((T_MATCH) reduce 115) ((T_METHOD_C) reduce 115) ((T_NAMESPACE) reduce 115) ((T_NAME_FULLY_QUALIFIED) reduce 115) ((T_NAME_QUALIFIED) reduce 115) ((T_NAME_RELATIVE) reduce 115) ((T_NEW) reduce 115) ((T_NS_C) reduce 115) ((T_OBJECT_CAST) reduce 115) ((T_PRINT) reduce 115) ((T_READONLY) reduce 115) ((T_REQUIRE) reduce 115) ((T_REQUIRE_ONCE) reduce 115) ((T_RETURN) reduce 115) ((T_START_HEREDOC) reduce 115) ((T_STATIC) reduce 115) ((T_STRING) reduce 115) ((T_STRING_CAST) reduce 115) ((T_SWITCH) reduce 115) ((T_THROW) reduce 115) ((T_TRAIT) reduce 115) ((T_TRAIT_C) reduce 115) ((T_TRY) reduce 115) ((T_UNSET) reduce 115) ((T_UNSET_CAST) reduce 115) ((T_USE) reduce 115) ((T_VARIABLE) reduce 115) ((T_WHILE) reduce 115) ((T_YIELD) reduce 115) ((T_YIELD_FROM) reduce 115) (("[") reduce 115) (("`") reduce 115) (("{") reduce 115) (("~") reduce 115)) 27669 ((("!") reduce 116) (("\"") reduce 116) (("$") reduce 116) (($) reduce 116) (("(") reduce 116) (("+") reduce 116) (("-") reduce 116) ((";") reduce 116) (("@") reduce 116) ((T_ABSTRACT) reduce 116) ((T_ARRAY) reduce 116) ((T_ARRAY_CAST) reduce 116) ((T_ATTRIBUTE) reduce 116) ((T_BOOL_CAST) reduce 116) ((T_BREAK) reduce 116) ((T_CLASS) reduce 116) ((T_CLASS_C) reduce 116) ((T_CLONE) reduce 116) ((T_CONST) reduce 116) ((T_CONSTANT_ENCAPSED_STRING) reduce 116) ((T_CONTINUE) reduce 116) ((T_DEC) reduce 116) ((T_DECLARE) reduce 116) ((T_DIR) reduce 116) ((T_DNUMBER) reduce 116) ((T_DO) reduce 116) ((T_DOUBLE_CAST) reduce 116) ((T_ECHO) reduce 116) ((T_EMPTY) reduce 116) ((T_ENUM) reduce 116) ((T_EVAL) reduce 116) ((T_EXIT) reduce 116) ((T_FILE) reduce 116) ((T_FINAL) reduce 116) ((T_FN) reduce 116) ((T_FOR) reduce 116) ((T_FOREACH) reduce 116) ((T_FUNCTION) reduce 116) ((T_FUNC_C) reduce 116) ((T_GLOBAL) reduce 116) ((T_GOTO) reduce 116) ((T_HALT_COMPILER) reduce 116) ((T_IF) reduce 116) ((T_INC) reduce 116) ((T_INCLUDE) reduce 116) ((T_INCLUDE_ONCE) reduce 116) ((T_INLINE_HTML) reduce 116) ((T_INTERFACE) reduce 116) ((T_INT_CAST) reduce 116) ((T_ISSET) reduce 116) ((T_LINE) reduce 116) ((T_LIST) reduce 116) ((T_LNUMBER) reduce 116) ((T_MATCH) reduce 116) ((T_METHOD_C) reduce 116) ((T_NAMESPACE) reduce 116) ((T_NAME_FULLY_QUALIFIED) reduce 116) ((T_NAME_QUALIFIED) reduce 116) ((T_NAME_RELATIVE) reduce 116) ((T_NEW) reduce 116) ((T_NS_C) reduce 116) ((T_OBJECT_CAST) reduce 116) ((T_PRINT) reduce 116) ((T_READONLY) reduce 116) ((T_REQUIRE) reduce 116) ((T_REQUIRE_ONCE) reduce 116) ((T_RETURN) reduce 116) ((T_START_HEREDOC) reduce 116) ((T_STATIC) reduce 116) ((T_STRING) reduce 116) ((T_STRING_CAST) reduce 116) ((T_SWITCH) reduce 116) ((T_THROW) reduce 116) ((T_TRAIT) reduce 116) ((T_TRAIT_C) reduce 116) ((T_TRY) reduce 116) ((T_UNSET) reduce 116) ((T_UNSET_CAST) reduce 116) ((T_USE) reduce 116) ((T_VARIABLE) reduce 116) ((T_WHILE) reduce 116) ((T_YIELD) reduce 116) ((T_YIELD_FROM) reduce 116) (("[") reduce 116) (("`") reduce 116) (("{") reduce 116) (("~") reduce 116)) 27670 ((("!") reduce 114) (("\"") reduce 114) (("$") reduce 114) (($) reduce 114) (("(") reduce 114) (("+") reduce 114) (("-") reduce 114) ((";") reduce 114) (("@") reduce 114) ((T_ABSTRACT) reduce 114) ((T_ARRAY) reduce 114) ((T_ARRAY_CAST) reduce 114) ((T_ATTRIBUTE) reduce 114) ((T_BOOL_CAST) reduce 114) ((T_BREAK) reduce 114) ((T_CLASS) reduce 114) ((T_CLASS_C) reduce 114) ((T_CLONE) reduce 114) ((T_CONST) reduce 114) ((T_CONSTANT_ENCAPSED_STRING) reduce 114) ((T_CONTINUE) reduce 114) ((T_DEC) reduce 114) ((T_DECLARE) reduce 114) ((T_DIR) reduce 114) ((T_DNUMBER) reduce 114) ((T_DO) reduce 114) ((T_DOUBLE_CAST) reduce 114) ((T_ECHO) reduce 114) ((T_EMPTY) reduce 114) ((T_ENUM) reduce 114) ((T_EVAL) reduce 114) ((T_EXIT) reduce 114) ((T_FILE) reduce 114) ((T_FINAL) reduce 114) ((T_FN) reduce 114) ((T_FOR) reduce 114) ((T_FOREACH) reduce 114) ((T_FUNCTION) reduce 114) ((T_FUNC_C) reduce 114) ((T_GLOBAL) reduce 114) ((T_GOTO) reduce 114) ((T_HALT_COMPILER) reduce 114) ((T_IF) reduce 114) ((T_INC) reduce 114) ((T_INCLUDE) reduce 114) ((T_INCLUDE_ONCE) reduce 114) ((T_INLINE_HTML) reduce 114) ((T_INTERFACE) reduce 114) ((T_INT_CAST) reduce 114) ((T_ISSET) reduce 114) ((T_LINE) reduce 114) ((T_LIST) reduce 114) ((T_LNUMBER) reduce 114) ((T_MATCH) reduce 114) ((T_METHOD_C) reduce 114) ((T_NAMESPACE) reduce 114) ((T_NAME_FULLY_QUALIFIED) reduce 114) ((T_NAME_QUALIFIED) reduce 114) ((T_NAME_RELATIVE) reduce 114) ((T_NEW) reduce 114) ((T_NS_C) reduce 114) ((T_OBJECT_CAST) reduce 114) ((T_PRINT) reduce 114) ((T_READONLY) reduce 114) ((T_REQUIRE) reduce 114) ((T_REQUIRE_ONCE) reduce 114) ((T_RETURN) reduce 114) ((T_START_HEREDOC) reduce 114) ((T_STATIC) reduce 114) ((T_STRING) reduce 114) ((T_STRING_CAST) reduce 114) ((T_SWITCH) reduce 114) ((T_THROW) reduce 114) ((T_TRAIT) reduce 114) ((T_TRAIT_C) reduce 114) ((T_TRY) reduce 114) ((T_UNSET) reduce 114) ((T_UNSET_CAST) reduce 114) ((T_USE) reduce 114) ((T_VARIABLE) reduce 114) ((T_WHILE) reduce 114) ((T_YIELD) reduce 114) ((T_YIELD_FROM) reduce 114) (("[") reduce 114) (("`") reduce 114) (("{") reduce 114) (("~") reduce 114)) 27672 (((T_CONST) shift) ((T_FUNCTION) shift) ((T_NAME_QUALIFIED) shift) ((T_STRING) shift)) 27673 (((T_NAME_QUALIFIED) reduce 120) ((T_STRING) reduce 120)) 27674 (((T_NAME_QUALIFIED) reduce 119) ((T_STRING) reduce 119)) 27675 (((",") reduce 126) (("}") reduce 126)) 27677 (((",") reduce 131) (("}") reduce 131)) 27679 (((",") reduce 132) (("}") reduce 132)) 27680 (((T_CONST) shift) ((T_FUNCTION) shift) ((T_NAME_QUALIFIED) shift) ((T_STRING) shift) (("}") reduce 124)) 27682 (((";") reduce 122)) 27683 (((",") reduce 125) (("}") reduce 125)) 27689 ((("!") reduce 160) (("\"") reduce 160) (("$") reduce 160) (($) reduce 160) (("(") reduce 160) (("+") reduce 160) (("-") reduce 160) ((";") reduce 160) (("@") reduce 160) ((T_ABSTRACT) reduce 160) ((T_ARRAY) reduce 160) ((T_ARRAY_CAST) reduce 160) ((T_ATTRIBUTE) reduce 160) ((T_BOOL_CAST) reduce 160) ((T_BREAK) reduce 160) ((T_CLASS) reduce 160) ((T_CLASS_C) reduce 160) ((T_CLONE) reduce 160) ((T_CONST) reduce 160) ((T_CONSTANT_ENCAPSED_STRING) reduce 160) ((T_CONTINUE) reduce 160) ((T_DEC) reduce 160) ((T_DECLARE) reduce 160) ((T_DIR) reduce 160) ((T_DNUMBER) reduce 160) ((T_DO) reduce 160) ((T_DOUBLE_CAST) reduce 160) ((T_ECHO) reduce 160) ((T_EMPTY) reduce 160) ((T_ENUM) reduce 160) ((T_EVAL) reduce 160) ((T_EXIT) reduce 160) ((T_FILE) reduce 160) ((T_FINAL) reduce 160) ((T_FN) reduce 160) ((T_FOR) reduce 160) ((T_FOREACH) reduce 160) ((T_FUNCTION) reduce 160) ((T_FUNC_C) reduce 160) ((T_GLOBAL) reduce 160) ((T_GOTO) reduce 160) ((T_HALT_COMPILER) reduce 160) ((T_IF) reduce 160) ((T_INC) reduce 160) ((T_INCLUDE) reduce 160) ((T_INCLUDE_ONCE) reduce 160) ((T_INLINE_HTML) reduce 160) ((T_INTERFACE) reduce 160) ((T_INT_CAST) reduce 160) ((T_ISSET) reduce 160) ((T_LINE) reduce 160) ((T_LIST) reduce 160) ((T_LNUMBER) reduce 160) ((T_MATCH) reduce 160) ((T_METHOD_C) reduce 160) ((T_NAMESPACE) reduce 160) ((T_NAME_FULLY_QUALIFIED) reduce 160) ((T_NAME_QUALIFIED) reduce 160) ((T_NAME_RELATIVE) reduce 160) ((T_NEW) reduce 160) ((T_NS_C) reduce 160) ((T_OBJECT_CAST) reduce 160) ((T_PRINT) reduce 160) ((T_READONLY) reduce 160) ((T_REQUIRE) reduce 160) ((T_REQUIRE_ONCE) reduce 160) ((T_RETURN) reduce 160) ((T_START_HEREDOC) reduce 160) ((T_STATIC) reduce 160) ((T_STRING) reduce 160) ((T_STRING_CAST) reduce 160) ((T_SWITCH) reduce 160) ((T_THROW) reduce 160) ((T_TRAIT) reduce 160) ((T_TRAIT_C) reduce 160) ((T_TRY) reduce 160) ((T_UNSET) reduce 160) ((T_UNSET_CAST) reduce 160) ((T_USE) reduce 160) ((T_VARIABLE) reduce 160) ((T_WHILE) reduce 160) ((T_YIELD) reduce 160) ((T_YIELD_FROM) reduce 160) (("[") reduce 160) (("`") reduce 160) (("{") reduce 160) (("~") reduce 160)) 27692 ((("!") reduce 168) (("\"") reduce 168) (($) reduce 168) (("$") reduce 168) (("(") reduce 168) (("+") reduce 168) (("-") reduce 168) ((";") reduce 168) (("@") reduce 168) ((T_ABSTRACT) reduce 168) ((T_ARRAY) reduce 168) ((T_ARRAY_CAST) reduce 168) ((T_ATTRIBUTE) reduce 168) ((T_BOOL_CAST) reduce 168) ((T_BREAK) reduce 168) ((T_CATCH) reduce 168) ((T_CLASS) reduce 168) ((T_CLASS_C) reduce 168) ((T_CLONE) reduce 168) ((T_CONST) reduce 168) ((T_CONSTANT_ENCAPSED_STRING) reduce 168) ((T_CONTINUE) reduce 168) ((T_DEC) reduce 168) ((T_DECLARE) reduce 168) ((T_DIR) reduce 168) ((T_DNUMBER) reduce 168) ((T_DO) reduce 168) ((T_DOUBLE_CAST) reduce 168) ((T_ECHO) reduce 168) ((T_EMPTY) reduce 168) ((T_ENUM) reduce 168) ((T_EVAL) reduce 168) ((T_EXIT) reduce 168) ((T_FILE) reduce 168) ((T_FINAL) reduce 168) ((T_FINALLY) reduce 168) ((T_FN) reduce 168) ((T_FOR) reduce 168) ((T_FOREACH) reduce 168) ((T_FUNCTION) reduce 168) ((T_FUNC_C) reduce 168) ((T_GLOBAL) reduce 168) ((T_GOTO) reduce 168) ((T_HALT_COMPILER) reduce 168) ((T_IF) reduce 168) ((T_INC) reduce 168) ((T_INCLUDE) reduce 168) ((T_INCLUDE_ONCE) reduce 168) ((T_INLINE_HTML) reduce 168) ((T_INTERFACE) reduce 168) ((T_INT_CAST) reduce 168) ((T_ISSET) reduce 168) ((T_LINE) reduce 168) ((T_LIST) reduce 168) ((T_LNUMBER) reduce 168) ((T_MATCH) reduce 168) ((T_METHOD_C) reduce 168) ((T_NAMESPACE) reduce 168) ((T_NAME_FULLY_QUALIFIED) reduce 168) ((T_NAME_QUALIFIED) reduce 168) ((T_NAME_RELATIVE) reduce 168) ((T_NEW) reduce 168) ((T_NS_C) reduce 168) ((T_OBJECT_CAST) reduce 168) ((T_PRINT) reduce 168) ((T_READONLY) reduce 168) ((T_REQUIRE) reduce 168) ((T_REQUIRE_ONCE) reduce 168) ((T_RETURN) reduce 168) ((T_START_HEREDOC) reduce 168) ((T_STATIC) reduce 168) ((T_STRING) reduce 168) ((T_STRING_CAST) reduce 168) ((T_SWITCH) reduce 168) ((T_THROW) reduce 168) ((T_TRAIT) reduce 168) ((T_TRAIT_C) reduce 168) ((T_TRY) reduce 168) ((T_UNSET) reduce 168) ((T_UNSET_CAST) reduce 168) ((T_USE) reduce 168) ((T_VARIABLE) reduce 168) ((T_WHILE) reduce 168) ((T_YIELD) reduce 168) ((T_YIELD_FROM) reduce 168) (("[") reduce 168) (("`") reduce 168) (("{") reduce 168) (("~") reduce 168)) 27693 ((("!") reduce 174) (("\"") reduce 174) (("$") reduce 174) (($) reduce 174) (("(") reduce 174) (("+") reduce 174) (("-") reduce 174) ((";") reduce 174) (("@") reduce 174) ((T_ABSTRACT) reduce 174) ((T_ARRAY) reduce 174) ((T_ARRAY_CAST) reduce 174) ((T_ATTRIBUTE) reduce 174) ((T_BOOL_CAST) reduce 174) ((T_BREAK) reduce 174) ((T_CATCH) shift) ((T_CLASS) reduce 174) ((T_CLASS_C) reduce 174) ((T_CLONE) reduce 174) ((T_CONST) reduce 174) ((T_CONSTANT_ENCAPSED_STRING) reduce 174) ((T_CONTINUE) reduce 174) ((T_DEC) reduce 174) ((T_DECLARE) reduce 174) ((T_DIR) reduce 174) ((T_DNUMBER) reduce 174) ((T_DO) reduce 174) ((T_DOUBLE_CAST) reduce 174) ((T_ECHO) reduce 174) ((T_EMPTY) reduce 174) ((T_ENUM) reduce 174) ((T_EVAL) reduce 174) ((T_EXIT) reduce 174) ((T_FILE) reduce 174) ((T_FINAL) reduce 174) ((T_FINALLY) shift) ((T_FN) reduce 174) ((T_FOR) reduce 174) ((T_FOREACH) reduce 174) ((T_FUNCTION) reduce 174) ((T_FUNC_C) reduce 174) ((T_GLOBAL) reduce 174) ((T_GOTO) reduce 174) ((T_HALT_COMPILER) reduce 174) ((T_IF) reduce 174) ((T_INC) reduce 174) ((T_INCLUDE) reduce 174) ((T_INCLUDE_ONCE) reduce 174) ((T_INLINE_HTML) reduce 174) ((T_INTERFACE) reduce 174) ((T_INT_CAST) reduce 174) ((T_ISSET) reduce 174) ((T_LINE) reduce 174) ((T_LIST) reduce 174) ((T_LNUMBER) reduce 174) ((T_MATCH) reduce 174) ((T_METHOD_C) reduce 174) ((T_NAMESPACE) reduce 174) ((T_NAME_FULLY_QUALIFIED) reduce 174) ((T_NAME_QUALIFIED) reduce 174) ((T_NAME_RELATIVE) reduce 174) ((T_NEW) reduce 174) ((T_NS_C) reduce 174) ((T_OBJECT_CAST) reduce 174) ((T_PRINT) reduce 174) ((T_READONLY) reduce 174) ((T_REQUIRE) reduce 174) ((T_REQUIRE_ONCE) reduce 174) ((T_RETURN) reduce 174) ((T_START_HEREDOC) reduce 174) ((T_STATIC) reduce 174) ((T_STRING) reduce 174) ((T_STRING_CAST) reduce 174) ((T_SWITCH) reduce 174) ((T_THROW) reduce 174) ((T_TRAIT) reduce 174) ((T_TRAIT_C) reduce 174) ((T_TRY) reduce 174) ((T_UNSET) reduce 174) ((T_UNSET_CAST) reduce 174) ((T_USE) reduce 174) ((T_VARIABLE) reduce 174) ((T_WHILE) reduce 174) ((T_YIELD) reduce 174) ((T_YIELD_FROM) reduce 174) (("[") reduce 174) (("`") reduce 174) (("{") reduce 174) (("~") reduce 174)) 27696 ((("!") reduce 165) (("\"") reduce 165) (("$") reduce 165) (($) reduce 165) (("(") reduce 165) (("+") reduce 165) (("-") reduce 165) ((";") reduce 165) (("@") reduce 165) ((T_ABSTRACT) reduce 165) ((T_ARRAY) reduce 165) ((T_ARRAY_CAST) reduce 165) ((T_ATTRIBUTE) reduce 165) ((T_BOOL_CAST) reduce 165) ((T_BREAK) reduce 165) ((T_CLASS) reduce 165) ((T_CLASS_C) reduce 165) ((T_CLONE) reduce 165) ((T_CONST) reduce 165) ((T_CONSTANT_ENCAPSED_STRING) reduce 165) ((T_CONTINUE) reduce 165) ((T_DEC) reduce 165) ((T_DECLARE) reduce 165) ((T_DIR) reduce 165) ((T_DNUMBER) reduce 165) ((T_DO) reduce 165) ((T_DOUBLE_CAST) reduce 165) ((T_ECHO) reduce 165) ((T_EMPTY) reduce 165) ((T_ENUM) reduce 165) ((T_EVAL) reduce 165) ((T_EXIT) reduce 165) ((T_FILE) reduce 165) ((T_FINAL) reduce 165) ((T_FN) reduce 165) ((T_FOR) reduce 165) ((T_FOREACH) reduce 165) ((T_FUNCTION) reduce 165) ((T_FUNC_C) reduce 165) ((T_GLOBAL) reduce 165) ((T_GOTO) reduce 165) ((T_HALT_COMPILER) reduce 165) ((T_IF) reduce 165) ((T_INC) reduce 165) ((T_INCLUDE) reduce 165) ((T_INCLUDE_ONCE) reduce 165) ((T_INLINE_HTML) reduce 165) ((T_INTERFACE) reduce 165) ((T_INT_CAST) reduce 165) ((T_ISSET) reduce 165) ((T_LINE) reduce 165) ((T_LIST) reduce 165) ((T_LNUMBER) reduce 165) ((T_MATCH) reduce 165) ((T_METHOD_C) reduce 165) ((T_NAMESPACE) reduce 165) ((T_NAME_FULLY_QUALIFIED) reduce 165) ((T_NAME_QUALIFIED) reduce 165) ((T_NAME_RELATIVE) reduce 165) ((T_NEW) reduce 165) ((T_NS_C) reduce 165) ((T_OBJECT_CAST) reduce 165) ((T_PRINT) reduce 165) ((T_READONLY) reduce 165) ((T_REQUIRE) reduce 165) ((T_REQUIRE_ONCE) reduce 165) ((T_RETURN) reduce 165) ((T_START_HEREDOC) reduce 165) ((T_STATIC) reduce 165) ((T_STRING) reduce 165) ((T_STRING_CAST) reduce 165) ((T_SWITCH) reduce 165) ((T_THROW) reduce 165) ((T_TRAIT) reduce 165) ((T_TRAIT_C) reduce 165) ((T_TRY) reduce 165) ((T_UNSET) reduce 165) ((T_UNSET_CAST) reduce 165) ((T_USE) reduce 165) ((T_VARIABLE) reduce 165) ((T_WHILE) reduce 165) ((T_YIELD) reduce 165) ((T_YIELD_FROM) reduce 165) (("[") reduce 165) (("`") reduce 165) (("{") reduce 165) (("~") reduce 165)) 27699 ((("!") reduce 175) (("\"") reduce 175) (("$") reduce 175) (($) reduce 175) (("(") reduce 175) (("+") reduce 175) (("-") reduce 175) ((";") reduce 175) (("@") reduce 175) ((T_ABSTRACT) reduce 175) ((T_ARRAY) reduce 175) ((T_ARRAY_CAST) reduce 175) ((T_ATTRIBUTE) reduce 175) ((T_BOOL_CAST) reduce 175) ((T_BREAK) reduce 175) ((T_CLASS) reduce 175) ((T_CLASS_C) reduce 175) ((T_CLONE) reduce 175) ((T_CONST) reduce 175) ((T_CONSTANT_ENCAPSED_STRING) reduce 175) ((T_CONTINUE) reduce 175) ((T_DEC) reduce 175) ((T_DECLARE) reduce 175) ((T_DIR) reduce 175) ((T_DNUMBER) reduce 175) ((T_DO) reduce 175) ((T_DOUBLE_CAST) reduce 175) ((T_ECHO) reduce 175) ((T_EMPTY) reduce 175) ((T_ENUM) reduce 175) ((T_EVAL) reduce 175) ((T_EXIT) reduce 175) ((T_FILE) reduce 175) ((T_FINAL) reduce 175) ((T_FN) reduce 175) ((T_FOR) reduce 175) ((T_FOREACH) reduce 175) ((T_FUNCTION) reduce 175) ((T_FUNC_C) reduce 175) ((T_GLOBAL) reduce 175) ((T_GOTO) reduce 175) ((T_HALT_COMPILER) reduce 175) ((T_IF) reduce 175) ((T_INC) reduce 175) ((T_INCLUDE) reduce 175) ((T_INCLUDE_ONCE) reduce 175) ((T_INLINE_HTML) reduce 175) ((T_INTERFACE) reduce 175) ((T_INT_CAST) reduce 175) ((T_ISSET) reduce 175) ((T_LINE) reduce 175) ((T_LIST) reduce 175) ((T_LNUMBER) reduce 175) ((T_MATCH) reduce 175) ((T_METHOD_C) reduce 175) ((T_NAMESPACE) reduce 175) ((T_NAME_FULLY_QUALIFIED) reduce 175) ((T_NAME_QUALIFIED) reduce 175) ((T_NAME_RELATIVE) reduce 175) ((T_NEW) reduce 175) ((T_NS_C) reduce 175) ((T_OBJECT_CAST) reduce 175) ((T_PRINT) reduce 175) ((T_READONLY) reduce 175) ((T_REQUIRE) reduce 175) ((T_REQUIRE_ONCE) reduce 175) ((T_RETURN) reduce 175) ((T_START_HEREDOC) reduce 175) ((T_STATIC) reduce 175) ((T_STRING) reduce 175) ((T_STRING_CAST) reduce 175) ((T_SWITCH) reduce 175) ((T_THROW) reduce 175) ((T_TRAIT) reduce 175) ((T_TRAIT_C) reduce 175) ((T_TRY) reduce 175) ((T_UNSET) reduce 175) ((T_UNSET_CAST) reduce 175) ((T_USE) reduce 175) ((T_VARIABLE) reduce 175) ((T_WHILE) reduce 175) ((T_YIELD) reduce 175) ((T_YIELD_FROM) reduce 175) (("[") reduce 175) (("`") reduce 175) (("{") reduce 175) (("~") reduce 175)) 27706 ((("!") reduce 169) (("\"") reduce 169) (("$") reduce 169) (($) reduce 169) (("(") reduce 169) (("+") reduce 169) (("-") reduce 169) ((";") reduce 169) (("@") reduce 169) ((T_ABSTRACT) reduce 169) ((T_ARRAY) reduce 169) ((T_ARRAY_CAST) reduce 169) ((T_ATTRIBUTE) reduce 169) ((T_BOOL_CAST) reduce 169) ((T_BREAK) reduce 169) ((T_CATCH) reduce 169) ((T_CLASS) reduce 169) ((T_CLASS_C) reduce 169) ((T_CLONE) reduce 169) ((T_CONST) reduce 169) ((T_CONSTANT_ENCAPSED_STRING) reduce 169) ((T_CONTINUE) reduce 169) ((T_DEC) reduce 169) ((T_DECLARE) reduce 169) ((T_DIR) reduce 169) ((T_DNUMBER) reduce 169) ((T_DO) reduce 169) ((T_DOUBLE_CAST) reduce 169) ((T_ECHO) reduce 169) ((T_EMPTY) reduce 169) ((T_ENUM) reduce 169) ((T_EVAL) reduce 169) ((T_EXIT) reduce 169) ((T_FILE) reduce 169) ((T_FINAL) reduce 169) ((T_FINALLY) reduce 169) ((T_FN) reduce 169) ((T_FOR) reduce 169) ((T_FOREACH) reduce 169) ((T_FUNCTION) reduce 169) ((T_FUNC_C) reduce 169) ((T_GLOBAL) reduce 169) ((T_GOTO) reduce 169) ((T_HALT_COMPILER) reduce 169) ((T_IF) reduce 169) ((T_INC) reduce 169) ((T_INCLUDE) reduce 169) ((T_INCLUDE_ONCE) reduce 169) ((T_INLINE_HTML) reduce 169) ((T_INTERFACE) reduce 169) ((T_INT_CAST) reduce 169) ((T_ISSET) reduce 169) ((T_LINE) reduce 169) ((T_LIST) reduce 169) ((T_LNUMBER) reduce 169) ((T_MATCH) reduce 169) ((T_METHOD_C) reduce 169) ((T_NAMESPACE) reduce 169) ((T_NAME_FULLY_QUALIFIED) reduce 169) ((T_NAME_QUALIFIED) reduce 169) ((T_NAME_RELATIVE) reduce 169) ((T_NEW) reduce 169) ((T_NS_C) reduce 169) ((T_OBJECT_CAST) reduce 169) ((T_PRINT) reduce 169) ((T_READONLY) reduce 169) ((T_REQUIRE) reduce 169) ((T_REQUIRE_ONCE) reduce 169) ((T_RETURN) reduce 169) ((T_START_HEREDOC) reduce 169) ((T_STATIC) reduce 169) ((T_STRING) reduce 169) ((T_STRING_CAST) reduce 169) ((T_SWITCH) reduce 169) ((T_THROW) reduce 169) ((T_TRAIT) reduce 169) ((T_TRAIT_C) reduce 169) ((T_TRY) reduce 169) ((T_UNSET) reduce 169) ((T_UNSET_CAST) reduce 169) ((T_USE) reduce 169) ((T_VARIABLE) reduce 169) ((T_WHILE) reduce 169) ((T_YIELD) reduce 169) ((T_YIELD_FROM) reduce 169) (("[") reduce 169) (("`") reduce 169) (("{") reduce 169) (("~") reduce 169)) 27711 ((("!") reduce 197) (("\"") reduce 197) (($) reduce 197) (("$") reduce 197) (("(") reduce 197) (("+") reduce 197) (("-") reduce 197) ((";") reduce 197) (("@") reduce 197) ((T_ABSTRACT) reduce 197) ((T_ARRAY) reduce 197) ((T_ARRAY_CAST) reduce 197) ((T_ATTRIBUTE) reduce 197) ((T_BOOL_CAST) reduce 197) ((T_BREAK) reduce 197) ((T_CLASS) reduce 197) ((T_CLASS_C) reduce 197) ((T_CLONE) reduce 197) ((T_CONST) reduce 197) ((T_CONSTANT_ENCAPSED_STRING) reduce 197) ((T_CONTINUE) reduce 197) ((T_DEC) reduce 197) ((T_DECLARE) reduce 197) ((T_DIR) reduce 197) ((T_DNUMBER) reduce 197) ((T_DO) reduce 197) ((T_DOUBLE_CAST) reduce 197) ((T_ECHO) reduce 197) ((T_EMPTY) reduce 197) ((T_ENUM) reduce 197) ((T_EVAL) reduce 197) ((T_EXIT) reduce 197) ((T_FILE) reduce 197) ((T_FINAL) reduce 197) ((T_FN) reduce 197) ((T_FOR) reduce 197) ((T_FOREACH) reduce 197) ((T_FUNCTION) reduce 197) ((T_FUNC_C) reduce 197) ((T_GLOBAL) reduce 197) ((T_GOTO) reduce 197) ((T_HALT_COMPILER) reduce 197) ((T_IF) reduce 197) ((T_INC) reduce 197) ((T_INCLUDE) reduce 197) ((T_INCLUDE_ONCE) reduce 197) ((T_INLINE_HTML) reduce 197) ((T_INTERFACE) reduce 197) ((T_INT_CAST) reduce 197) ((T_ISSET) reduce 197) ((T_LINE) reduce 197) ((T_LIST) reduce 197) ((T_LNUMBER) reduce 197) ((T_MATCH) reduce 197) ((T_METHOD_C) reduce 197) ((T_NAMESPACE) reduce 197) ((T_NAME_FULLY_QUALIFIED) reduce 197) ((T_NAME_QUALIFIED) reduce 197) ((T_NAME_RELATIVE) reduce 197) ((T_NEW) reduce 197) ((T_NS_C) reduce 197) ((T_OBJECT_CAST) reduce 197) ((T_PRINT) reduce 197) ((T_READONLY) reduce 197) ((T_REQUIRE) reduce 197) ((T_REQUIRE_ONCE) reduce 197) ((T_RETURN) reduce 197) ((T_START_HEREDOC) reduce 197) ((T_STATIC) reduce 197) ((T_STRING) reduce 197) ((T_STRING_CAST) reduce 197) ((T_SWITCH) reduce 197) ((T_THROW) reduce 197) ((T_TRAIT) reduce 197) ((T_TRAIT_C) reduce 197) ((T_TRY) reduce 197) ((T_UNSET) reduce 197) ((T_UNSET_CAST) reduce 197) ((T_USE) reduce 197) ((T_VARIABLE) reduce 197) ((T_WHILE) reduce 197) ((T_YIELD) reduce 197) ((T_YIELD_FROM) reduce 197) (("[") reduce 197) (("`") reduce 197) (("{") reduce 197) (("~") reduce 197)) 27717 ((("!") reduce 151) (("\"") reduce 151) (($) reduce 151) (("$") reduce 151) (("(") reduce 151) (("+") reduce 151) (("-") reduce 151) ((";") reduce 151) (("@") reduce 151) ((T_ABSTRACT) reduce 151) ((T_ARRAY) reduce 151) ((T_ARRAY_CAST) reduce 151) ((T_ATTRIBUTE) reduce 151) ((T_BOOL_CAST) reduce 151) ((T_BREAK) reduce 151) ((T_CLASS) reduce 151) ((T_CLASS_C) reduce 151) ((T_CLONE) reduce 151) ((T_CONST) reduce 151) ((T_CONSTANT_ENCAPSED_STRING) reduce 151) ((T_CONTINUE) reduce 151) ((T_DEC) reduce 151) ((T_DECLARE) reduce 151) ((T_DIR) reduce 151) ((T_DNUMBER) reduce 151) ((T_DO) reduce 151) ((T_DOUBLE_CAST) reduce 151) ((T_ECHO) reduce 151) ((T_EMPTY) reduce 151) ((T_ENUM) reduce 151) ((T_EVAL) reduce 151) ((T_EXIT) reduce 151) ((T_FILE) reduce 151) ((T_FINAL) reduce 151) ((T_FN) reduce 151) ((T_FOR) reduce 151) ((T_FOREACH) reduce 151) ((T_FUNCTION) reduce 151) ((T_FUNC_C) reduce 151) ((T_GLOBAL) reduce 151) ((T_GOTO) reduce 151) ((T_HALT_COMPILER) reduce 151) ((T_IF) reduce 151) ((T_INC) reduce 151) ((T_INCLUDE) reduce 151) ((T_INCLUDE_ONCE) reduce 151) ((T_INLINE_HTML) reduce 151) ((T_INTERFACE) reduce 151) ((T_INT_CAST) reduce 151) ((T_ISSET) reduce 151) ((T_LINE) reduce 151) ((T_LIST) reduce 151) ((T_LNUMBER) reduce 151) ((T_MATCH) reduce 151) ((T_METHOD_C) reduce 151) ((T_NAMESPACE) reduce 151) ((T_NAME_FULLY_QUALIFIED) reduce 151) ((T_NAME_QUALIFIED) reduce 151) ((T_NAME_RELATIVE) reduce 151) ((T_NEW) reduce 151) ((T_NS_C) reduce 151) ((T_OBJECT_CAST) reduce 151) ((T_PRINT) reduce 151) ((T_READONLY) reduce 151) ((T_REQUIRE) reduce 151) ((T_REQUIRE_ONCE) reduce 151) ((T_RETURN) reduce 151) ((T_START_HEREDOC) reduce 151) ((T_STATIC) reduce 151) ((T_STRING) reduce 151) ((T_STRING_CAST) reduce 151) ((T_SWITCH) reduce 151) ((T_THROW) reduce 151) ((T_TRAIT) reduce 151) ((T_TRAIT_C) reduce 151) ((T_TRY) reduce 151) ((T_UNSET) reduce 151) ((T_UNSET_CAST) reduce 151) ((T_USE) reduce 151) ((T_VARIABLE) reduce 151) ((T_WHILE) reduce 151) ((T_YIELD) reduce 151) ((T_YIELD_FROM) reduce 151) (("[") reduce 151) (("`") reduce 151) (("{") reduce 151) (("~") reduce 151)) 27721 ((("!") reduce 221) (("\"") reduce 221) (("$") reduce 221) (($) reduce 221) (("(") reduce 221) (("+") reduce 221) (("-") reduce 221) ((";") reduce 221) (("@") reduce 221) ((T_ABSTRACT) reduce 221) ((T_ARRAY) reduce 221) ((T_ARRAY_CAST) reduce 221) ((T_ATTRIBUTE) reduce 221) ((T_BOOL_CAST) reduce 221) ((T_BREAK) reduce 221) ((T_CLASS) reduce 221) ((T_CLASS_C) reduce 221) ((T_CLONE) reduce 221) ((T_CONST) reduce 221) ((T_CONSTANT_ENCAPSED_STRING) reduce 221) ((T_CONTINUE) reduce 221) ((T_DEC) reduce 221) ((T_DECLARE) reduce 221) ((T_DIR) reduce 221) ((T_DNUMBER) reduce 221) ((T_DO) reduce 221) ((T_DOUBLE_CAST) reduce 221) ((T_ECHO) reduce 221) ((T_EMPTY) reduce 221) ((T_ENUM) reduce 221) ((T_EVAL) reduce 221) ((T_EXIT) reduce 221) ((T_FILE) reduce 221) ((T_FINAL) reduce 221) ((T_FN) reduce 221) ((T_FOR) reduce 221) ((T_FOREACH) reduce 221) ((T_FUNCTION) reduce 221) ((T_FUNC_C) reduce 221) ((T_GLOBAL) reduce 221) ((T_GOTO) reduce 221) ((T_HALT_COMPILER) reduce 221) ((T_IF) reduce 221) ((T_INC) reduce 221) ((T_INCLUDE) reduce 221) ((T_INCLUDE_ONCE) reduce 221) ((T_INLINE_HTML) reduce 221) ((T_INTERFACE) reduce 221) ((T_INT_CAST) reduce 221) ((T_ISSET) reduce 221) ((T_LINE) reduce 221) ((T_LIST) reduce 221) ((T_LNUMBER) reduce 221) ((T_MATCH) reduce 221) ((T_METHOD_C) reduce 221) ((T_NAMESPACE) reduce 221) ((T_NAME_FULLY_QUALIFIED) reduce 221) ((T_NAME_QUALIFIED) reduce 221) ((T_NAME_RELATIVE) reduce 221) ((T_NEW) reduce 221) ((T_NS_C) reduce 221) ((T_OBJECT_CAST) reduce 221) ((T_PRINT) reduce 221) ((T_READONLY) reduce 221) ((T_REQUIRE) reduce 221) ((T_REQUIRE_ONCE) reduce 221) ((T_RETURN) reduce 221) ((T_START_HEREDOC) reduce 221) ((T_STATIC) reduce 221) ((T_STRING) reduce 221) ((T_STRING_CAST) reduce 221) ((T_SWITCH) reduce 221) ((T_THROW) reduce 221) ((T_TRAIT) reduce 221) ((T_TRAIT_C) reduce 221) ((T_TRY) reduce 221) ((T_UNSET) reduce 221) ((T_UNSET_CAST) reduce 221) ((T_USE) reduce 221) ((T_VARIABLE) reduce 221) ((T_WHILE) reduce 221) ((T_YIELD) reduce 221) ((T_YIELD_FROM) reduce 221) (("[") reduce 221) (("`") reduce 221) (("{") reduce 221) (("~") reduce 221)) 27723 ((("!") reduce 222) (("\"") reduce 222) (($) reduce 222) (("$") reduce 222) (("(") reduce 222) (("+") reduce 222) (("-") reduce 222) ((";") reduce 222) (("@") reduce 222) ((T_ABSTRACT) reduce 222) ((T_ARRAY) reduce 222) ((T_ARRAY_CAST) reduce 222) ((T_ATTRIBUTE) reduce 222) ((T_BOOL_CAST) reduce 222) ((T_BREAK) reduce 222) ((T_CLASS) reduce 222) ((T_CLASS_C) reduce 222) ((T_CLONE) reduce 222) ((T_CONST) reduce 222) ((T_CONSTANT_ENCAPSED_STRING) reduce 222) ((T_CONTINUE) reduce 222) ((T_DEC) reduce 222) ((T_DECLARE) reduce 222) ((T_DIR) reduce 222) ((T_DNUMBER) reduce 222) ((T_DO) reduce 222) ((T_DOUBLE_CAST) reduce 222) ((T_ECHO) reduce 222) ((T_EMPTY) reduce 222) ((T_ENUM) reduce 222) ((T_EVAL) reduce 222) ((T_EXIT) reduce 222) ((T_FILE) reduce 222) ((T_FINAL) reduce 222) ((T_FN) reduce 222) ((T_FOR) reduce 222) ((T_FOREACH) reduce 222) ((T_FUNCTION) reduce 222) ((T_FUNC_C) reduce 222) ((T_GLOBAL) reduce 222) ((T_GOTO) reduce 222) ((T_HALT_COMPILER) reduce 222) ((T_IF) reduce 222) ((T_INC) reduce 222) ((T_INCLUDE) reduce 222) ((T_INCLUDE_ONCE) reduce 222) ((T_INLINE_HTML) reduce 222) ((T_INTERFACE) reduce 222) ((T_INT_CAST) reduce 222) ((T_ISSET) reduce 222) ((T_LINE) reduce 222) ((T_LIST) reduce 222) ((T_LNUMBER) reduce 222) ((T_MATCH) reduce 222) ((T_METHOD_C) reduce 222) ((T_NAMESPACE) reduce 222) ((T_NAME_FULLY_QUALIFIED) reduce 222) ((T_NAME_QUALIFIED) reduce 222) ((T_NAME_RELATIVE) reduce 222) ((T_NEW) reduce 222) ((T_NS_C) reduce 222) ((T_OBJECT_CAST) reduce 222) ((T_PRINT) reduce 222) ((T_READONLY) reduce 222) ((T_REQUIRE) reduce 222) ((T_REQUIRE_ONCE) reduce 222) ((T_RETURN) reduce 222) ((T_START_HEREDOC) reduce 222) ((T_STATIC) reduce 222) ((T_STRING) reduce 222) ((T_STRING_CAST) reduce 222) ((T_SWITCH) reduce 222) ((T_THROW) reduce 222) ((T_TRAIT) reduce 222) ((T_TRAIT_C) reduce 222) ((T_TRY) reduce 222) ((T_UNSET) reduce 222) ((T_UNSET_CAST) reduce 222) ((T_USE) reduce 222) ((T_VARIABLE) reduce 222) ((T_WHILE) reduce 222) ((T_YIELD) reduce 222) ((T_YIELD_FROM) reduce 222) (("[") reduce 222) (("`") reduce 222) (("{") reduce 222) (("~") reduce 222)) 27727 ((("!") reduce 223) (("\"") reduce 223) (($) reduce 223) (("$") reduce 223) (("(") reduce 223) (("+") reduce 223) (("-") reduce 223) ((";") reduce 223) (("@") reduce 223) ((T_ABSTRACT) reduce 223) ((T_ARRAY) reduce 223) ((T_ARRAY_CAST) reduce 223) ((T_ATTRIBUTE) reduce 223) ((T_BOOL_CAST) reduce 223) ((T_BREAK) reduce 223) ((T_CLASS) reduce 223) ((T_CLASS_C) reduce 223) ((T_CLONE) reduce 223) ((T_CONST) reduce 223) ((T_CONSTANT_ENCAPSED_STRING) reduce 223) ((T_CONTINUE) reduce 223) ((T_DEC) reduce 223) ((T_DECLARE) reduce 223) ((T_DIR) reduce 223) ((T_DNUMBER) reduce 223) ((T_DO) reduce 223) ((T_DOUBLE_CAST) reduce 223) ((T_ECHO) reduce 223) ((T_EMPTY) reduce 223) ((T_ENUM) reduce 223) ((T_EVAL) reduce 223) ((T_EXIT) reduce 223) ((T_FILE) reduce 223) ((T_FINAL) reduce 223) ((T_FN) reduce 223) ((T_FOR) reduce 223) ((T_FOREACH) reduce 223) ((T_FUNCTION) reduce 223) ((T_FUNC_C) reduce 223) ((T_GLOBAL) reduce 223) ((T_GOTO) reduce 223) ((T_HALT_COMPILER) reduce 223) ((T_IF) reduce 223) ((T_INC) reduce 223) ((T_INCLUDE) reduce 223) ((T_INCLUDE_ONCE) reduce 223) ((T_INLINE_HTML) reduce 223) ((T_INTERFACE) reduce 223) ((T_INT_CAST) reduce 223) ((T_ISSET) reduce 223) ((T_LINE) reduce 223) ((T_LIST) reduce 223) ((T_LNUMBER) reduce 223) ((T_MATCH) reduce 223) ((T_METHOD_C) reduce 223) ((T_NAMESPACE) reduce 223) ((T_NAME_FULLY_QUALIFIED) reduce 223) ((T_NAME_QUALIFIED) reduce 223) ((T_NAME_RELATIVE) reduce 223) ((T_NEW) reduce 223) ((T_NS_C) reduce 223) ((T_OBJECT_CAST) reduce 223) ((T_PRINT) reduce 223) ((T_READONLY) reduce 223) ((T_REQUIRE) reduce 223) ((T_REQUIRE_ONCE) reduce 223) ((T_RETURN) reduce 223) ((T_START_HEREDOC) reduce 223) ((T_STATIC) reduce 223) ((T_STRING) reduce 223) ((T_STRING_CAST) reduce 223) ((T_SWITCH) reduce 223) ((T_THROW) reduce 223) ((T_TRAIT) reduce 223) ((T_TRAIT_C) reduce 223) ((T_TRY) reduce 223) ((T_UNSET) reduce 223) ((T_UNSET_CAST) reduce 223) ((T_USE) reduce 223) ((T_VARIABLE) reduce 223) ((T_WHILE) reduce 223) ((T_YIELD) reduce 223) ((T_YIELD_FROM) reduce 223) (("[") reduce 223) (("`") reduce 223) (("{") reduce 223) (("~") reduce 223)) 27730 ((("!") reduce 224) (("\"") reduce 224) (("$") reduce 224) (($) reduce 224) (("(") reduce 224) (("+") reduce 224) (("-") reduce 224) ((";") reduce 224) (("@") reduce 224) ((T_ABSTRACT) reduce 224) ((T_ARRAY) reduce 224) ((T_ARRAY_CAST) reduce 224) ((T_ATTRIBUTE) reduce 224) ((T_BOOL_CAST) reduce 224) ((T_BREAK) reduce 224) ((T_CLASS) reduce 224) ((T_CLASS_C) reduce 224) ((T_CLONE) reduce 224) ((T_CONST) reduce 224) ((T_CONSTANT_ENCAPSED_STRING) reduce 224) ((T_CONTINUE) reduce 224) ((T_DEC) reduce 224) ((T_DECLARE) reduce 224) ((T_DIR) reduce 224) ((T_DNUMBER) reduce 224) ((T_DO) reduce 224) ((T_DOUBLE_CAST) reduce 224) ((T_ECHO) reduce 224) ((T_EMPTY) reduce 224) ((T_ENUM) reduce 224) ((T_EVAL) reduce 224) ((T_EXIT) reduce 224) ((T_FILE) reduce 224) ((T_FINAL) reduce 224) ((T_FN) reduce 224) ((T_FOR) reduce 224) ((T_FOREACH) reduce 224) ((T_FUNCTION) reduce 224) ((T_FUNC_C) reduce 224) ((T_GLOBAL) reduce 224) ((T_GOTO) reduce 224) ((T_HALT_COMPILER) reduce 224) ((T_IF) reduce 224) ((T_INC) reduce 224) ((T_INCLUDE) reduce 224) ((T_INCLUDE_ONCE) reduce 224) ((T_INLINE_HTML) reduce 224) ((T_INTERFACE) reduce 224) ((T_INT_CAST) reduce 224) ((T_ISSET) reduce 224) ((T_LINE) reduce 224) ((T_LIST) reduce 224) ((T_LNUMBER) reduce 224) ((T_MATCH) reduce 224) ((T_METHOD_C) reduce 224) ((T_NAMESPACE) reduce 224) ((T_NAME_FULLY_QUALIFIED) reduce 224) ((T_NAME_QUALIFIED) reduce 224) ((T_NAME_RELATIVE) reduce 224) ((T_NEW) reduce 224) ((T_NS_C) reduce 224) ((T_OBJECT_CAST) reduce 224) ((T_PRINT) reduce 224) ((T_READONLY) reduce 224) ((T_REQUIRE) reduce 224) ((T_REQUIRE_ONCE) reduce 224) ((T_RETURN) reduce 224) ((T_START_HEREDOC) reduce 224) ((T_STATIC) reduce 224) ((T_STRING) reduce 224) ((T_STRING_CAST) reduce 224) ((T_SWITCH) reduce 224) ((T_THROW) reduce 224) ((T_TRAIT) reduce 224) ((T_TRAIT_C) reduce 224) ((T_TRY) reduce 224) ((T_UNSET) reduce 224) ((T_UNSET_CAST) reduce 224) ((T_USE) reduce 224) ((T_VARIABLE) reduce 224) ((T_WHILE) reduce 224) ((T_YIELD) reduce 224) ((T_YIELD_FROM) reduce 224) (("[") reduce 224) (("`") reduce 224) (("{") reduce 224) (("~") reduce 224)) 27732 ((("!") reduce 167) (("\"") reduce 167) (("$") reduce 167) (($) reduce 167) (("(") reduce 167) (("+") reduce 167) (("-") reduce 167) ((";") reduce 167) (("@") reduce 167) ((T_ABSTRACT) reduce 167) ((T_ARRAY) reduce 167) ((T_ARRAY_CAST) reduce 167) ((T_ATTRIBUTE) reduce 167) ((T_BOOL_CAST) reduce 167) ((T_BREAK) reduce 167) ((T_CLASS) reduce 167) ((T_CLASS_C) reduce 167) ((T_CLONE) reduce 167) ((T_CONST) reduce 167) ((T_CONSTANT_ENCAPSED_STRING) reduce 167) ((T_CONTINUE) reduce 167) ((T_DEC) reduce 167) ((T_DECLARE) reduce 167) ((T_DIR) reduce 167) ((T_DNUMBER) reduce 167) ((T_DO) reduce 167) ((T_DOUBLE_CAST) reduce 167) ((T_ECHO) reduce 167) ((T_EMPTY) reduce 167) ((T_ENUM) reduce 167) ((T_EVAL) reduce 167) ((T_EXIT) reduce 167) ((T_FILE) reduce 167) ((T_FINAL) reduce 167) ((T_FN) reduce 167) ((T_FOR) reduce 167) ((T_FOREACH) reduce 167) ((T_FUNCTION) reduce 167) ((T_FUNC_C) reduce 167) ((T_GLOBAL) reduce 167) ((T_GOTO) reduce 167) ((T_HALT_COMPILER) reduce 167) ((T_IF) reduce 167) ((T_INC) reduce 167) ((T_INCLUDE) reduce 167) ((T_INCLUDE_ONCE) reduce 167) ((T_INLINE_HTML) reduce 167) ((T_INTERFACE) reduce 167) ((T_INT_CAST) reduce 167) ((T_ISSET) reduce 167) ((T_LINE) reduce 167) ((T_LIST) reduce 167) ((T_LNUMBER) reduce 167) ((T_MATCH) reduce 167) ((T_METHOD_C) reduce 167) ((T_NAMESPACE) reduce 167) ((T_NAME_FULLY_QUALIFIED) reduce 167) ((T_NAME_QUALIFIED) reduce 167) ((T_NAME_RELATIVE) reduce 167) ((T_NEW) reduce 167) ((T_NS_C) reduce 167) ((T_OBJECT_CAST) reduce 167) ((T_PRINT) reduce 167) ((T_READONLY) reduce 167) ((T_REQUIRE) reduce 167) ((T_REQUIRE_ONCE) reduce 167) ((T_RETURN) reduce 167) ((T_START_HEREDOC) reduce 167) ((T_STATIC) reduce 167) ((T_STRING) reduce 167) ((T_STRING_CAST) reduce 167) ((T_SWITCH) reduce 167) ((T_THROW) reduce 167) ((T_TRAIT) reduce 167) ((T_TRAIT_C) reduce 167) ((T_TRY) reduce 167) ((T_UNSET) reduce 167) ((T_UNSET_CAST) reduce 167) ((T_USE) reduce 167) ((T_VARIABLE) reduce 167) ((T_WHILE) reduce 167) ((T_YIELD) reduce 167) ((T_YIELD_FROM) reduce 167) (("[") reduce 167) (("`") reduce 167) (("{") reduce 167) (("~") reduce 167)) 27734 ((("!") reduce 156) (("\"") reduce 156) (($) reduce 156) (("$") reduce 156) (("(") reduce 156) (("+") reduce 156) (("-") reduce 156) ((";") reduce 156) (("@") reduce 156) ((T_ABSTRACT) reduce 156) ((T_ARRAY) reduce 156) ((T_ARRAY_CAST) reduce 156) ((T_ATTRIBUTE) reduce 156) ((T_BOOL_CAST) reduce 156) ((T_BREAK) reduce 156) ((T_CLASS) reduce 156) ((T_CLASS_C) reduce 156) ((T_CLONE) reduce 156) ((T_CONST) reduce 156) ((T_CONSTANT_ENCAPSED_STRING) reduce 156) ((T_CONTINUE) reduce 156) ((T_DEC) reduce 156) ((T_DECLARE) reduce 156) ((T_DIR) reduce 156) ((T_DNUMBER) reduce 156) ((T_DO) reduce 156) ((T_DOUBLE_CAST) reduce 156) ((T_ECHO) reduce 156) ((T_EMPTY) reduce 156) ((T_ENUM) reduce 156) ((T_EVAL) reduce 156) ((T_EXIT) reduce 156) ((T_FILE) reduce 156) ((T_FINAL) reduce 156) ((T_FN) reduce 156) ((T_FOR) reduce 156) ((T_FOREACH) reduce 156) ((T_FUNCTION) reduce 156) ((T_FUNC_C) reduce 156) ((T_GLOBAL) reduce 156) ((T_GOTO) reduce 156) ((T_HALT_COMPILER) reduce 156) ((T_IF) reduce 156) ((T_INC) reduce 156) ((T_INCLUDE) reduce 156) ((T_INCLUDE_ONCE) reduce 156) ((T_INLINE_HTML) reduce 156) ((T_INTERFACE) reduce 156) ((T_INT_CAST) reduce 156) ((T_ISSET) reduce 156) ((T_LINE) reduce 156) ((T_LIST) reduce 156) ((T_LNUMBER) reduce 156) ((T_MATCH) reduce 156) ((T_METHOD_C) reduce 156) ((T_NAMESPACE) reduce 156) ((T_NAME_FULLY_QUALIFIED) reduce 156) ((T_NAME_QUALIFIED) reduce 156) ((T_NAME_RELATIVE) reduce 156) ((T_NEW) reduce 156) ((T_NS_C) reduce 156) ((T_OBJECT_CAST) reduce 156) ((T_PRINT) reduce 156) ((T_READONLY) reduce 156) ((T_REQUIRE) reduce 156) ((T_REQUIRE_ONCE) reduce 156) ((T_RETURN) reduce 156) ((T_START_HEREDOC) reduce 156) ((T_STATIC) reduce 156) ((T_STRING) reduce 156) ((T_STRING_CAST) reduce 156) ((T_SWITCH) reduce 156) ((T_THROW) reduce 156) ((T_TRAIT) reduce 156) ((T_TRAIT_C) reduce 156) ((T_TRY) reduce 156) ((T_UNSET) reduce 156) ((T_UNSET_CAST) reduce 156) ((T_USE) reduce 156) ((T_VARIABLE) reduce 156) ((T_WHILE) reduce 156) ((T_YIELD) reduce 156) ((T_YIELD_FROM) reduce 156) (("[") reduce 156) (("`") reduce 156) (("{") reduce 156) (("~") reduce 156)) 27741 ((("!") reduce 154) (("\"") reduce 154) (($) reduce 154) (("$") reduce 154) (("(") reduce 154) (("+") reduce 154) (("-") reduce 154) ((";") reduce 154) (("@") reduce 154) ((T_ABSTRACT) reduce 154) ((T_ARRAY) reduce 154) ((T_ARRAY_CAST) reduce 154) ((T_ATTRIBUTE) reduce 154) ((T_BOOL_CAST) reduce 154) ((T_BREAK) reduce 154) ((T_CLASS) reduce 154) ((T_CLASS_C) reduce 154) ((T_CLONE) reduce 154) ((T_CONST) reduce 154) ((T_CONSTANT_ENCAPSED_STRING) reduce 154) ((T_CONTINUE) reduce 154) ((T_DEC) reduce 154) ((T_DECLARE) reduce 154) ((T_DIR) reduce 154) ((T_DNUMBER) reduce 154) ((T_DO) reduce 154) ((T_DOUBLE_CAST) reduce 154) ((T_ECHO) reduce 154) ((T_EMPTY) reduce 154) ((T_ENUM) reduce 154) ((T_EVAL) reduce 154) ((T_EXIT) reduce 154) ((T_FILE) reduce 154) ((T_FINAL) reduce 154) ((T_FN) reduce 154) ((T_FOR) reduce 154) ((T_FOREACH) reduce 154) ((T_FUNCTION) reduce 154) ((T_FUNC_C) reduce 154) ((T_GLOBAL) reduce 154) ((T_GOTO) reduce 154) ((T_HALT_COMPILER) reduce 154) ((T_IF) reduce 154) ((T_INC) reduce 154) ((T_INCLUDE) reduce 154) ((T_INCLUDE_ONCE) reduce 154) ((T_INLINE_HTML) reduce 154) ((T_INTERFACE) reduce 154) ((T_INT_CAST) reduce 154) ((T_ISSET) reduce 154) ((T_LINE) reduce 154) ((T_LIST) reduce 154) ((T_LNUMBER) reduce 154) ((T_MATCH) reduce 154) ((T_METHOD_C) reduce 154) ((T_NAMESPACE) reduce 154) ((T_NAME_FULLY_QUALIFIED) reduce 154) ((T_NAME_QUALIFIED) reduce 154) ((T_NAME_RELATIVE) reduce 154) ((T_NEW) reduce 154) ((T_NS_C) reduce 154) ((T_OBJECT_CAST) reduce 154) ((T_PRINT) reduce 154) ((T_READONLY) reduce 154) ((T_REQUIRE) reduce 154) ((T_REQUIRE_ONCE) reduce 154) ((T_RETURN) reduce 154) ((T_START_HEREDOC) reduce 154) ((T_STATIC) reduce 154) ((T_STRING) reduce 154) ((T_STRING_CAST) reduce 154) ((T_SWITCH) reduce 154) ((T_THROW) reduce 154) ((T_TRAIT) reduce 154) ((T_TRAIT_C) reduce 154) ((T_TRY) reduce 154) ((T_UNSET) reduce 154) ((T_UNSET_CAST) reduce 154) ((T_USE) reduce 154) ((T_VARIABLE) reduce 154) ((T_WHILE) reduce 154) ((T_YIELD) reduce 154) ((T_YIELD_FROM) reduce 154) (("[") reduce 154) (("`") reduce 154) (("{") reduce 154) (("~") reduce 154)) 27768 (((";") reduce 73) (("{") reduce 73)) 27769 (((";") reduce 52) (("{") reduce 52)) 27770 (((";") reduce 27) (("{") reduce 27)) 27771 (((";") reduce 51) (("{") reduce 51)) 27772 (((";") reduce 53) (("{") reduce 53)) 27773 (((";") reduce 49) (("{") reduce 49)) 27774 (((";") reduce 29) (("{") reduce 29)) 27775 (((";") reduce 59) (("{") reduce 59)) 27776 (((";") reduce 60) (("{") reduce 60)) 27777 (((";") reduce 11) (("{") reduce 11)) 27778 (((";") reduce 42) (("{") reduce 42)) 27779 (((";") reduce 39) (("{") reduce 39)) 27780 (((";") reduce 25) (("{") reduce 25)) 27781 (((";") reduce 50) (("{") reduce 50)) 27782 (((";") reduce 66) (("{") reduce 66)) 27783 (((";") reduce 18) (("{") reduce 18)) 27784 (((";") reduce 17) (("{") reduce 17)) 27785 (((";") reduce 15) (("{") reduce 15)) 27786 (((";") reduce 14) (("{") reduce 14)) 27787 (((";") reduce 38) (("{") reduce 38)) 27788 (((";") reduce 26) (("{") reduce 26)) 27789 (((";") reduce 22) (("{") reduce 22)) 27790 (((";") reduce 24) (("{") reduce 24)) 27791 (((";") reduce 16) (("{") reduce 16)) 27792 (((";") reduce 48) (("{") reduce 48)) 27793 (((";") reduce 20) (("{") reduce 20)) 27794 (((";") reduce 70) (("{") reduce 70)) 27795 (((";") reduce 3) (("{") reduce 3)) 27796 (((";") reduce 12) (("{") reduce 12)) 27797 (((";") reduce 54) (("{") reduce 54)) 27798 (((";") reduce 65) (("{") reduce 65)) 27799 (((";") reduce 74) (("{") reduce 74)) 27800 (((";") reduce 30) (("{") reduce 30)) 27801 (((";") reduce 68) (("{") reduce 68)) 27802 (((";") reduce 21) (("{") reduce 21)) 27803 (((";") reduce 23) (("{") reduce 23)) 27804 (((";") reduce 41) (("{") reduce 41)) 27805 (((";") reduce 62) (("{") reduce 62)) 27806 (((";") reduce 34) (("{") reduce 34)) 27807 (((";") reduce 40) (("{") reduce 40)) 27808 (((";") reduce 13) (("{") reduce 13)) 27809 (((";") reduce 55) (("{") reduce 55)) 27810 (((";") reduce 1) (("{") reduce 1)) 27811 (((";") reduce 2) (("{") reduce 2)) 27812 (((";") reduce 9) (("{") reduce 9)) 27813 (((";") reduce 33) (("{") reduce 33)) 27814 (((";") reduce 58) (("{") reduce 58)) 27815 (((";") reduce 37) (("{") reduce 37)) 27816 (((";") reduce 64) (("{") reduce 64)) 27817 (((";") reduce 46) (("{") reduce 46)) 27818 (((";") reduce 8) (("{") reduce 8)) 27819 (((";") reduce 6) (("{") reduce 6)) 27820 (((";") reduce 7) (("{") reduce 7)) 27821 (((";") reduce 69) (("{") reduce 69)) 27822 (((";") reduce 63) (("{") reduce 63)) 27823 (((";") reduce 56) (("{") reduce 56)) 27824 (((";") reduce 86) (("{") reduce 86)) 27825 (((";") reduce 10) (("{") reduce 10)) 27826 (((";") reduce 67) (("{") reduce 67)) 27827 (((";") reduce 44) (("{") reduce 44)) 27828 (((";") reduce 75) (("{") reduce 75)) 27829 (((";") reduce 76) (("{") reduce 76)) 27830 (((";") reduce 77) (("{") reduce 77)) 27831 (((";") reduce 78) (("{") reduce 78)) 27832 (((";") reduce 4) (("{") reduce 4)) 27833 (((";") reduce 5) (("{") reduce 5)) 27834 (((";") reduce 43) (("{") reduce 43)) 27835 (((";") reduce 72) (("{") reduce 72)) 27836 (((";") reduce 81) (("{") reduce 81)) 27837 (((";") reduce 47) (("{") reduce 47)) 27838 (((";") reduce 31) (("{") reduce 31)) 27839 (((";") reduce 57) (("{") reduce 57)) 27840 (((";") reduce 61) (("{") reduce 61)) 27841 (((";") reduce 28) (("{") reduce 28)) 27842 (((";") reduce 36) (("{") reduce 36)) 27843 (((";") reduce 32) (("{") reduce 32)) 27844 (((";") reduce 35) (("{") reduce 35)) 27845 (((";") reduce 19) (("{") reduce 19)) 27846 (((";") reduce 45) (("{") reduce 45)) 27847 (((";") reduce 85) (("{") reduce 85)) 27849 (((";") reduce 71) (("{") reduce 71)) 27850 (((";") reduce 82) (("{") reduce 82)) 27851 ((("!") reduce 84) (("\"") reduce 84) (("$") reduce 84) (("(") reduce 84) (("+") reduce 84) (("-") reduce 84) ((";") reduce 84) (("@") reduce 84) ((T_ABSTRACT) reduce 84) ((T_ARRAY) reduce 84) ((T_ARRAY_CAST) reduce 84) ((T_ATTRIBUTE) reduce 84) ((T_BOOL_CAST) reduce 84) ((T_BREAK) reduce 84) ((T_CLASS) reduce 84) ((T_CLASS_C) reduce 84) ((T_CLONE) reduce 84) ((T_CONST) reduce 84) ((T_CONSTANT_ENCAPSED_STRING) reduce 84) ((T_CONTINUE) reduce 84) ((T_DEC) reduce 84) ((T_DECLARE) reduce 84) ((T_DIR) reduce 84) ((T_DNUMBER) reduce 84) ((T_DO) reduce 84) ((T_DOUBLE_CAST) reduce 84) ((T_ECHO) reduce 84) ((T_EMPTY) reduce 84) ((T_ENUM) reduce 84) ((T_EVAL) reduce 84) ((T_EXIT) reduce 84) ((T_FILE) reduce 84) ((T_FINAL) reduce 84) ((T_FN) reduce 84) ((T_FOR) reduce 84) ((T_FOREACH) reduce 84) ((T_FUNCTION) reduce 84) ((T_FUNC_C) reduce 84) ((T_GLOBAL) reduce 84) ((T_GOTO) reduce 84) ((T_HALT_COMPILER) reduce 84) ((T_IF) reduce 84) ((T_INC) reduce 84) ((T_INCLUDE) reduce 84) ((T_INCLUDE_ONCE) reduce 84) ((T_INLINE_HTML) reduce 84) ((T_INTERFACE) reduce 84) ((T_INT_CAST) reduce 84) ((T_ISSET) reduce 84) ((T_LINE) reduce 84) ((T_LIST) reduce 84) ((T_LNUMBER) reduce 84) ((T_MATCH) reduce 84) ((T_METHOD_C) reduce 84) ((T_NAMESPACE) reduce 84) ((T_NAME_FULLY_QUALIFIED) reduce 84) ((T_NAME_QUALIFIED) reduce 84) ((T_NAME_RELATIVE) reduce 84) ((T_NEW) reduce 84) ((T_NS_C) reduce 84) ((T_OBJECT_CAST) reduce 84) ((T_PRINT) reduce 84) ((T_READONLY) reduce 84) ((T_REQUIRE) reduce 84) ((T_REQUIRE_ONCE) reduce 84) ((T_RETURN) reduce 84) ((T_START_HEREDOC) reduce 84) ((T_STATIC) reduce 84) ((T_STRING) reduce 84) ((T_STRING_CAST) reduce 84) ((T_SWITCH) reduce 84) ((T_THROW) reduce 84) ((T_TRAIT) reduce 84) ((T_TRAIT_C) reduce 84) ((T_TRY) reduce 84) ((T_UNSET) reduce 84) ((T_UNSET_CAST) reduce 84) ((T_USE) reduce 84) ((T_VARIABLE) reduce 84) ((T_WHILE) reduce 84) ((T_YIELD) reduce 84) ((T_YIELD_FROM) reduce 84) (("[") reduce 84) (("`") reduce 84) (("{") reduce 84) (("}") reduce 84) (("~") reduce 84)) 27852 ((("!") shift) (("\"") shift) (("$") shift) (("(") shift) (("+") shift) (("-") shift) ((";") shift) (("@") shift) ((T_ABSTRACT) shift) ((T_ARRAY) shift) ((T_ARRAY_CAST) shift) ((T_ATTRIBUTE) shift) ((T_BOOL_CAST) shift) ((T_BREAK) shift) ((T_CLASS) shift) ((T_CLASS_C) shift) ((T_CLONE) shift) ((T_CONST) shift) ((T_CONSTANT_ENCAPSED_STRING) shift) ((T_CONTINUE) shift) ((T_DEC) shift) ((T_DECLARE) shift) ((T_DIR) shift) ((T_DNUMBER) shift) ((T_DO) shift) ((T_DOUBLE_CAST) shift) ((T_ECHO) shift) ((T_EMPTY) shift) ((T_ENUM) shift) ((T_EVAL) shift) ((T_EXIT) shift) ((T_FILE) shift) ((T_FINAL) shift) ((T_FN) shift) ((T_FOR) shift) ((T_FOREACH) shift) ((T_FUNCTION) shift) ((T_FUNC_C) shift) ((T_GLOBAL) shift) ((T_GOTO) shift) ((T_HALT_COMPILER) shift) ((T_IF) shift) ((T_INC) shift) ((T_INCLUDE) shift) ((T_INCLUDE_ONCE) shift) ((T_INLINE_HTML) shift) ((T_INTERFACE) shift) ((T_INT_CAST) shift) ((T_ISSET) shift) ((T_LINE) shift) ((T_LIST) shift) ((T_LNUMBER) shift) ((T_MATCH) shift) ((T_METHOD_C) shift) ((T_NAMESPACE) shift) ((T_NAME_FULLY_QUALIFIED) shift) ((T_NAME_QUALIFIED) shift) ((T_NAME_RELATIVE) shift) ((T_NEW) shift) ((T_NS_C) shift) ((T_OBJECT_CAST) shift) ((T_PRINT) shift) ((T_READONLY) shift) ((T_REQUIRE) shift) ((T_REQUIRE_ONCE) shift) ((T_RETURN) shift) ((T_START_HEREDOC) shift) ((T_STATIC) shift) ((T_STRING) shift) ((T_STRING_CAST) shift) ((T_SWITCH) shift) ((T_THROW) shift) ((T_TRAIT) shift) ((T_TRAIT_C) shift) ((T_TRY) shift) ((T_UNSET) shift) ((T_UNSET_CAST) shift) ((T_USE) shift) ((T_VARIABLE) shift) ((T_WHILE) shift) ((T_YIELD) shift) ((T_YIELD_FROM) shift) (("[") shift) (("`") shift) (("{") shift) (("}") shift) (("~") shift)) 27853 ((("!") reduce 164) (("\"") reduce 164) (("$") reduce 164) (("(") reduce 164) (("+") reduce 164) (("-") reduce 164) ((";") reduce 164) (("@") reduce 164) ((T_ABSTRACT) reduce 164) ((T_ARRAY) reduce 164) ((T_ARRAY_CAST) reduce 164) ((T_ATTRIBUTE) reduce 164) ((T_BOOL_CAST) reduce 164) ((T_BREAK) reduce 164) ((T_CLASS) reduce 164) ((T_CLASS_C) reduce 164) ((T_CLONE) reduce 164) ((T_CONST) reduce 164) ((T_CONSTANT_ENCAPSED_STRING) reduce 164) ((T_CONTINUE) reduce 164) ((T_DEC) reduce 164) ((T_DECLARE) reduce 164) ((T_DIR) reduce 164) ((T_DNUMBER) reduce 164) ((T_DO) reduce 164) ((T_DOUBLE_CAST) reduce 164) ((T_ECHO) reduce 164) ((T_EMPTY) reduce 164) ((T_ENUM) reduce 164) ((T_EVAL) reduce 164) ((T_EXIT) reduce 164) ((T_FILE) reduce 164) ((T_FINAL) reduce 164) ((T_FN) reduce 164) ((T_FOR) reduce 164) ((T_FOREACH) reduce 164) ((T_FUNCTION) reduce 164) ((T_FUNC_C) reduce 164) ((T_GLOBAL) reduce 164) ((T_GOTO) reduce 164) ((T_HALT_COMPILER) reduce 164) ((T_IF) reduce 164) ((T_INC) reduce 164) ((T_INCLUDE) reduce 164) ((T_INCLUDE_ONCE) reduce 164) ((T_INLINE_HTML) reduce 164) ((T_INTERFACE) reduce 164) ((T_INT_CAST) reduce 164) ((T_ISSET) reduce 164) ((T_LINE) reduce 164) ((T_LIST) reduce 164) ((T_LNUMBER) reduce 164) ((T_MATCH) reduce 164) ((T_METHOD_C) reduce 164) ((T_NAMESPACE) reduce 164) ((T_NAME_FULLY_QUALIFIED) reduce 164) ((T_NAME_QUALIFIED) reduce 164) ((T_NAME_RELATIVE) reduce 164) ((T_NEW) reduce 164) ((T_NS_C) reduce 164) ((T_OBJECT_CAST) reduce 164) ((T_PRINT) reduce 164) ((T_READONLY) reduce 164) ((T_REQUIRE) reduce 164) ((T_REQUIRE_ONCE) reduce 164) ((T_RETURN) reduce 164) ((T_START_HEREDOC) reduce 164) ((T_STATIC) reduce 164) ((T_STRING) reduce 164) ((T_STRING_CAST) reduce 164) ((T_SWITCH) reduce 164) ((T_THROW) reduce 164) ((T_TRAIT) reduce 164) ((T_TRAIT_C) reduce 164) ((T_TRY) reduce 164) ((T_UNSET) reduce 164) ((T_UNSET_CAST) reduce 164) ((T_USE) reduce 164) ((T_VARIABLE) reduce 164) ((T_WHILE) reduce 164) ((T_YIELD) reduce 164) ((T_YIELD_FROM) reduce 164) (("[") reduce 164) (("`") reduce 164) (("{") reduce 164) (("}") reduce 164) (("~") reduce 164)) 27868 ((("!") reduce 158) (("\"") reduce 158) (("$") reduce 158) (("(") reduce 158) (("+") reduce 158) (("-") reduce 158) ((";") reduce 158) (("@") reduce 158) ((T_ABSTRACT) reduce 158) ((T_ARRAY) reduce 158) ((T_ARRAY_CAST) reduce 158) ((T_ATTRIBUTE) reduce 158) ((T_BOOL_CAST) reduce 158) ((T_BREAK) reduce 158) ((T_CLASS) reduce 158) ((T_CLASS_C) reduce 158) ((T_CLONE) reduce 158) ((T_CONST) reduce 158) ((T_CONSTANT_ENCAPSED_STRING) reduce 158) ((T_CONTINUE) reduce 158) ((T_DEC) reduce 158) ((T_DECLARE) reduce 158) ((T_DIR) reduce 158) ((T_DNUMBER) reduce 158) ((T_DO) reduce 158) ((T_DOUBLE_CAST) reduce 158) ((T_ECHO) reduce 158) ((T_EMPTY) reduce 158) ((T_ENUM) reduce 158) ((T_EVAL) reduce 158) ((T_EXIT) reduce 158) ((T_FILE) reduce 158) ((T_FINAL) reduce 158) ((T_FN) reduce 158) ((T_FOR) reduce 158) ((T_FOREACH) reduce 158) ((T_FUNCTION) reduce 158) ((T_FUNC_C) reduce 158) ((T_GLOBAL) reduce 158) ((T_GOTO) reduce 158) ((T_HALT_COMPILER) reduce 158) ((T_IF) reduce 158) ((T_INC) reduce 158) ((T_INCLUDE) reduce 158) ((T_INCLUDE_ONCE) reduce 158) ((T_INLINE_HTML) reduce 158) ((T_INTERFACE) reduce 158) ((T_INT_CAST) reduce 158) ((T_ISSET) reduce 158) ((T_LINE) reduce 158) ((T_LIST) reduce 158) ((T_LNUMBER) reduce 158) ((T_MATCH) reduce 158) ((T_METHOD_C) reduce 158) ((T_NAMESPACE) reduce 158) ((T_NAME_FULLY_QUALIFIED) reduce 158) ((T_NAME_QUALIFIED) reduce 158) ((T_NAME_RELATIVE) reduce 158) ((T_NEW) reduce 158) ((T_NS_C) reduce 158) ((T_OBJECT_CAST) reduce 158) ((T_PRINT) reduce 158) ((T_READONLY) reduce 158) ((T_REQUIRE) reduce 158) ((T_REQUIRE_ONCE) reduce 158) ((T_RETURN) reduce 158) ((T_START_HEREDOC) reduce 158) ((T_STATIC) reduce 158) ((T_STRING) reduce 158) ((T_STRING_CAST) reduce 158) ((T_SWITCH) reduce 158) ((T_THROW) reduce 158) ((T_TRAIT) reduce 158) ((T_TRAIT_C) reduce 158) ((T_TRY) reduce 158) ((T_UNSET) reduce 158) ((T_UNSET_CAST) reduce 158) ((T_USE) reduce 158) ((T_VARIABLE) reduce 158) ((T_WHILE) reduce 158) ((T_YIELD) reduce 158) ((T_YIELD_FROM) reduce 158) (("[") reduce 158) (("`") reduce 158) (("{") reduce 158) (("}") reduce 158) (("~") reduce 158)) 27880 ((("!") reduce 147) (("\"") reduce 147) (("$") reduce 147) (("(") reduce 147) (("+") reduce 147) (("-") reduce 147) ((";") reduce 147) (("@") reduce 147) ((T_ABSTRACT) reduce 147) ((T_ARRAY) reduce 147) ((T_ARRAY_CAST) reduce 147) ((T_ATTRIBUTE) reduce 147) ((T_BOOL_CAST) reduce 147) ((T_BREAK) reduce 147) ((T_CLASS) reduce 147) ((T_CLASS_C) reduce 147) ((T_CLONE) reduce 147) ((T_CONST) reduce 147) ((T_CONSTANT_ENCAPSED_STRING) reduce 147) ((T_CONTINUE) reduce 147) ((T_DEC) reduce 147) ((T_DECLARE) reduce 147) ((T_DIR) reduce 147) ((T_DNUMBER) reduce 147) ((T_DO) reduce 147) ((T_DOUBLE_CAST) reduce 147) ((T_ECHO) reduce 147) ((T_EMPTY) reduce 147) ((T_ENUM) reduce 147) ((T_EVAL) reduce 147) ((T_EXIT) reduce 147) ((T_FILE) reduce 147) ((T_FINAL) reduce 147) ((T_FN) reduce 147) ((T_FOR) reduce 147) ((T_FOREACH) reduce 147) ((T_FUNCTION) reduce 147) ((T_FUNC_C) reduce 147) ((T_GLOBAL) reduce 147) ((T_GOTO) reduce 147) ((T_HALT_COMPILER) reduce 147) ((T_IF) reduce 147) ((T_INC) reduce 147) ((T_INCLUDE) reduce 147) ((T_INCLUDE_ONCE) reduce 147) ((T_INLINE_HTML) reduce 147) ((T_INTERFACE) reduce 147) ((T_INT_CAST) reduce 147) ((T_ISSET) reduce 147) ((T_LINE) reduce 147) ((T_LIST) reduce 147) ((T_LNUMBER) reduce 147) ((T_MATCH) reduce 147) ((T_METHOD_C) reduce 147) ((T_NAMESPACE) reduce 147) ((T_NAME_FULLY_QUALIFIED) reduce 147) ((T_NAME_QUALIFIED) reduce 147) ((T_NAME_RELATIVE) reduce 147) ((T_NEW) reduce 147) ((T_NS_C) reduce 147) ((T_OBJECT_CAST) reduce 147) ((T_PRINT) reduce 147) ((T_READONLY) reduce 147) ((T_REQUIRE) reduce 147) ((T_REQUIRE_ONCE) reduce 147) ((T_RETURN) reduce 147) ((T_START_HEREDOC) reduce 147) ((T_STATIC) reduce 147) ((T_STRING) reduce 147) ((T_STRING_CAST) reduce 147) ((T_SWITCH) reduce 147) ((T_THROW) reduce 147) ((T_TRAIT) reduce 147) ((T_TRAIT_C) reduce 147) ((T_TRY) reduce 147) ((T_UNSET) reduce 147) ((T_UNSET_CAST) reduce 147) ((T_USE) reduce 147) ((T_VARIABLE) reduce 147) ((T_WHILE) reduce 147) ((T_YIELD) reduce 147) ((T_YIELD_FROM) reduce 147) (("[") reduce 147) (("`") reduce 147) (("{") reduce 147) (("}") reduce 147) (("~") reduce 147)) 27882 ((("!") reduce 108) (("\"") reduce 108) (("$") reduce 108) (("(") reduce 108) (("+") reduce 108) (("-") reduce 108) ((";") reduce 108) (("@") reduce 108) ((T_ABSTRACT) reduce 108) ((T_ARRAY) reduce 108) ((T_ARRAY_CAST) reduce 108) ((T_ATTRIBUTE) reduce 108) ((T_BOOL_CAST) reduce 108) ((T_BREAK) reduce 108) ((T_CLASS) reduce 108) ((T_CLASS_C) reduce 108) ((T_CLONE) reduce 108) ((T_CONST) reduce 108) ((T_CONSTANT_ENCAPSED_STRING) reduce 108) ((T_CONTINUE) reduce 108) ((T_DEC) reduce 108) ((T_DECLARE) reduce 108) ((T_DIR) reduce 108) ((T_DNUMBER) reduce 108) ((T_DO) reduce 108) ((T_DOUBLE_CAST) reduce 108) ((T_ECHO) reduce 108) ((T_EMPTY) reduce 108) ((T_ENUM) reduce 108) ((T_EVAL) reduce 108) ((T_EXIT) reduce 108) ((T_FILE) reduce 108) ((T_FINAL) reduce 108) ((T_FN) reduce 108) ((T_FOR) reduce 108) ((T_FOREACH) reduce 108) ((T_FUNCTION) reduce 108) ((T_FUNC_C) reduce 108) ((T_GLOBAL) reduce 108) ((T_GOTO) reduce 108) ((T_HALT_COMPILER) reduce 108) ((T_IF) reduce 108) ((T_INC) reduce 108) ((T_INCLUDE) reduce 108) ((T_INCLUDE_ONCE) reduce 108) ((T_INLINE_HTML) reduce 108) ((T_INTERFACE) reduce 108) ((T_INT_CAST) reduce 108) ((T_ISSET) reduce 108) ((T_LINE) reduce 108) ((T_LIST) reduce 108) ((T_LNUMBER) reduce 108) ((T_MATCH) reduce 108) ((T_METHOD_C) reduce 108) ((T_NAMESPACE) reduce 108) ((T_NAME_FULLY_QUALIFIED) reduce 108) ((T_NAME_QUALIFIED) reduce 108) ((T_NAME_RELATIVE) reduce 108) ((T_NEW) reduce 108) ((T_NS_C) reduce 108) ((T_OBJECT_CAST) reduce 108) ((T_PRINT) reduce 108) ((T_READONLY) reduce 108) ((T_REQUIRE) reduce 108) ((T_REQUIRE_ONCE) reduce 108) ((T_RETURN) reduce 108) ((T_START_HEREDOC) reduce 108) ((T_STATIC) reduce 108) ((T_STRING) reduce 108) ((T_STRING_CAST) reduce 108) ((T_SWITCH) reduce 108) ((T_THROW) reduce 108) ((T_TRAIT) reduce 108) ((T_TRAIT_C) reduce 108) ((T_TRY) reduce 108) ((T_UNSET) reduce 108) ((T_UNSET_CAST) reduce 108) ((T_USE) reduce 108) ((T_VARIABLE) reduce 108) ((T_WHILE) reduce 108) ((T_YIELD) reduce 108) ((T_YIELD_FROM) reduce 108) (("[") reduce 108) (("`") reduce 108) (("{") reduce 108) (("}") reduce 108) (("~") reduce 108)) 27884 ((("!") reduce 103) (("\"") reduce 103) (("$") reduce 103) (("(") reduce 103) (("+") reduce 103) (("-") reduce 103) ((";") reduce 103) (("@") reduce 103) ((T_ABSTRACT) reduce 103) ((T_ARRAY) reduce 103) ((T_ARRAY_CAST) reduce 103) ((T_ATTRIBUTE) reduce 103) ((T_BOOL_CAST) reduce 103) ((T_BREAK) reduce 103) ((T_CLASS) reduce 103) ((T_CLASS_C) reduce 103) ((T_CLONE) reduce 103) ((T_CONST) reduce 103) ((T_CONSTANT_ENCAPSED_STRING) reduce 103) ((T_CONTINUE) reduce 103) ((T_DEC) reduce 103) ((T_DECLARE) reduce 103) ((T_DIR) reduce 103) ((T_DNUMBER) reduce 103) ((T_DO) reduce 103) ((T_DOUBLE_CAST) reduce 103) ((T_ECHO) reduce 103) ((T_EMPTY) reduce 103) ((T_ENUM) reduce 103) ((T_EVAL) reduce 103) ((T_EXIT) reduce 103) ((T_FILE) reduce 103) ((T_FINAL) reduce 103) ((T_FN) reduce 103) ((T_FOR) reduce 103) ((T_FOREACH) reduce 103) ((T_FUNCTION) reduce 103) ((T_FUNC_C) reduce 103) ((T_GLOBAL) reduce 103) ((T_GOTO) reduce 103) ((T_HALT_COMPILER) reduce 103) ((T_IF) reduce 103) ((T_INC) reduce 103) ((T_INCLUDE) reduce 103) ((T_INCLUDE_ONCE) reduce 103) ((T_INLINE_HTML) reduce 103) ((T_INTERFACE) reduce 103) ((T_INT_CAST) reduce 103) ((T_ISSET) reduce 103) ((T_LINE) reduce 103) ((T_LIST) reduce 103) ((T_LNUMBER) reduce 103) ((T_MATCH) reduce 103) ((T_METHOD_C) reduce 103) ((T_NAMESPACE) reduce 103) ((T_NAME_FULLY_QUALIFIED) reduce 103) ((T_NAME_QUALIFIED) reduce 103) ((T_NAME_RELATIVE) reduce 103) ((T_NEW) reduce 103) ((T_NS_C) reduce 103) ((T_OBJECT_CAST) reduce 103) ((T_PRINT) reduce 103) ((T_READONLY) reduce 103) ((T_REQUIRE) reduce 103) ((T_REQUIRE_ONCE) reduce 103) ((T_RETURN) reduce 103) ((T_START_HEREDOC) reduce 103) ((T_STATIC) reduce 103) ((T_STRING) reduce 103) ((T_STRING_CAST) reduce 103) ((T_SWITCH) reduce 103) ((T_THROW) reduce 103) ((T_TRAIT) reduce 103) ((T_TRAIT_C) reduce 103) ((T_TRY) reduce 103) ((T_UNSET) reduce 103) ((T_UNSET_CAST) reduce 103) ((T_USE) reduce 103) ((T_VARIABLE) reduce 103) ((T_WHILE) reduce 103) ((T_YIELD) reduce 103) ((T_YIELD_FROM) reduce 103) (("[") reduce 103) (("`") reduce 103) (("{") reduce 103) (("}") reduce 103) (("~") reduce 103)) 27886 ((("!") reduce 106) (("\"") reduce 106) (("$") reduce 106) (("(") reduce 106) (("+") reduce 106) (("-") reduce 106) ((";") reduce 106) (("@") reduce 106) ((T_ABSTRACT) reduce 106) ((T_ARRAY) reduce 106) ((T_ARRAY_CAST) reduce 106) ((T_ATTRIBUTE) reduce 106) ((T_BOOL_CAST) reduce 106) ((T_BREAK) reduce 106) ((T_CLASS) reduce 106) ((T_CLASS_C) reduce 106) ((T_CLONE) reduce 106) ((T_CONST) reduce 106) ((T_CONSTANT_ENCAPSED_STRING) reduce 106) ((T_CONTINUE) reduce 106) ((T_DEC) reduce 106) ((T_DECLARE) reduce 106) ((T_DIR) reduce 106) ((T_DNUMBER) reduce 106) ((T_DO) reduce 106) ((T_DOUBLE_CAST) reduce 106) ((T_ECHO) reduce 106) ((T_EMPTY) reduce 106) ((T_ENUM) reduce 106) ((T_EVAL) reduce 106) ((T_EXIT) reduce 106) ((T_FILE) reduce 106) ((T_FINAL) reduce 106) ((T_FN) reduce 106) ((T_FOR) reduce 106) ((T_FOREACH) reduce 106) ((T_FUNCTION) reduce 106) ((T_FUNC_C) reduce 106) ((T_GLOBAL) reduce 106) ((T_GOTO) reduce 106) ((T_HALT_COMPILER) reduce 106) ((T_IF) reduce 106) ((T_INC) reduce 106) ((T_INCLUDE) reduce 106) ((T_INCLUDE_ONCE) reduce 106) ((T_INLINE_HTML) reduce 106) ((T_INTERFACE) reduce 106) ((T_INT_CAST) reduce 106) ((T_ISSET) reduce 106) ((T_LINE) reduce 106) ((T_LIST) reduce 106) ((T_LNUMBER) reduce 106) ((T_MATCH) reduce 106) ((T_METHOD_C) reduce 106) ((T_NAMESPACE) reduce 106) ((T_NAME_FULLY_QUALIFIED) reduce 106) ((T_NAME_QUALIFIED) reduce 106) ((T_NAME_RELATIVE) reduce 106) ((T_NEW) reduce 106) ((T_NS_C) reduce 106) ((T_OBJECT_CAST) reduce 106) ((T_PRINT) reduce 106) ((T_READONLY) reduce 106) ((T_REQUIRE) reduce 106) ((T_REQUIRE_ONCE) reduce 106) ((T_RETURN) reduce 106) ((T_START_HEREDOC) reduce 106) ((T_STATIC) reduce 106) ((T_STRING) reduce 106) ((T_STRING_CAST) reduce 106) ((T_SWITCH) reduce 106) ((T_THROW) reduce 106) ((T_TRAIT) reduce 106) ((T_TRAIT_C) reduce 106) ((T_TRY) reduce 106) ((T_UNSET) reduce 106) ((T_UNSET_CAST) reduce 106) ((T_USE) reduce 106) ((T_VARIABLE) reduce 106) ((T_WHILE) reduce 106) ((T_YIELD) reduce 106) ((T_YIELD_FROM) reduce 106) (("[") reduce 106) (("`") reduce 106) (("{") reduce 106) (("}") reduce 106) (("~") reduce 106)) 27889 ((("!") reduce 102) (("\"") reduce 102) (("$") reduce 102) (("(") reduce 102) (("+") reduce 102) (("-") reduce 102) ((";") reduce 102) (("@") reduce 102) ((T_ABSTRACT) reduce 102) ((T_ARRAY) reduce 102) ((T_ARRAY_CAST) reduce 102) ((T_ATTRIBUTE) reduce 102) ((T_BOOL_CAST) reduce 102) ((T_BREAK) reduce 102) ((T_CLASS) reduce 102) ((T_CLASS_C) reduce 102) ((T_CLONE) reduce 102) ((T_CONST) reduce 102) ((T_CONSTANT_ENCAPSED_STRING) reduce 102) ((T_CONTINUE) reduce 102) ((T_DEC) reduce 102) ((T_DECLARE) reduce 102) ((T_DIR) reduce 102) ((T_DNUMBER) reduce 102) ((T_DO) reduce 102) ((T_DOUBLE_CAST) reduce 102) ((T_ECHO) reduce 102) ((T_EMPTY) reduce 102) ((T_ENUM) reduce 102) ((T_EVAL) reduce 102) ((T_EXIT) reduce 102) ((T_FILE) reduce 102) ((T_FINAL) reduce 102) ((T_FN) reduce 102) ((T_FOR) reduce 102) ((T_FOREACH) reduce 102) ((T_FUNCTION) reduce 102) ((T_FUNC_C) reduce 102) ((T_GLOBAL) reduce 102) ((T_GOTO) reduce 102) ((T_HALT_COMPILER) reduce 102) ((T_IF) reduce 102) ((T_INC) reduce 102) ((T_INCLUDE) reduce 102) ((T_INCLUDE_ONCE) reduce 102) ((T_INLINE_HTML) reduce 102) ((T_INTERFACE) reduce 102) ((T_INT_CAST) reduce 102) ((T_ISSET) reduce 102) ((T_LINE) reduce 102) ((T_LIST) reduce 102) ((T_LNUMBER) reduce 102) ((T_MATCH) reduce 102) ((T_METHOD_C) reduce 102) ((T_NAMESPACE) reduce 102) ((T_NAME_FULLY_QUALIFIED) reduce 102) ((T_NAME_QUALIFIED) reduce 102) ((T_NAME_RELATIVE) reduce 102) ((T_NEW) reduce 102) ((T_NS_C) reduce 102) ((T_OBJECT_CAST) reduce 102) ((T_PRINT) reduce 102) ((T_READONLY) reduce 102) ((T_REQUIRE) reduce 102) ((T_REQUIRE_ONCE) reduce 102) ((T_RETURN) reduce 102) ((T_START_HEREDOC) reduce 102) ((T_STATIC) reduce 102) ((T_STRING) reduce 102) ((T_STRING_CAST) reduce 102) ((T_SWITCH) reduce 102) ((T_THROW) reduce 102) ((T_TRAIT) reduce 102) ((T_TRAIT_C) reduce 102) ((T_TRY) reduce 102) ((T_UNSET) reduce 102) ((T_UNSET_CAST) reduce 102) ((T_USE) reduce 102) ((T_VARIABLE) reduce 102) ((T_WHILE) reduce 102) ((T_YIELD) reduce 102) ((T_YIELD_FROM) reduce 102) (("[") reduce 102) (("`") reduce 102) (("{") reduce 102) (("}") reduce 102) (("~") reduce 102)) 27890 ((("!") reduce 146) (("\"") reduce 146) (("$") reduce 146) (("(") reduce 146) (("+") reduce 146) (("-") reduce 146) ((";") reduce 146) (("@") reduce 146) ((T_ABSTRACT) reduce 146) ((T_ARRAY) reduce 146) ((T_ARRAY_CAST) reduce 146) ((T_ATTRIBUTE) reduce 146) ((T_BOOL_CAST) reduce 146) ((T_BREAK) reduce 146) ((T_CLASS) reduce 146) ((T_CLASS_C) reduce 146) ((T_CLONE) reduce 146) ((T_CONST) reduce 146) ((T_CONSTANT_ENCAPSED_STRING) reduce 146) ((T_CONTINUE) reduce 146) ((T_DEC) reduce 146) ((T_DECLARE) reduce 146) ((T_DIR) reduce 146) ((T_DNUMBER) reduce 146) ((T_DO) reduce 146) ((T_DOUBLE_CAST) reduce 146) ((T_ECHO) reduce 146) ((T_EMPTY) reduce 146) ((T_ENUM) reduce 146) ((T_EVAL) reduce 146) ((T_EXIT) reduce 146) ((T_FILE) reduce 146) ((T_FINAL) reduce 146) ((T_FN) reduce 146) ((T_FOR) reduce 146) ((T_FOREACH) reduce 146) ((T_FUNCTION) reduce 146) ((T_FUNC_C) reduce 146) ((T_GLOBAL) reduce 146) ((T_GOTO) reduce 146) ((T_HALT_COMPILER) reduce 146) ((T_IF) reduce 146) ((T_INC) reduce 146) ((T_INCLUDE) reduce 146) ((T_INCLUDE_ONCE) reduce 146) ((T_INLINE_HTML) reduce 146) ((T_INTERFACE) reduce 146) ((T_INT_CAST) reduce 146) ((T_ISSET) reduce 146) ((T_LINE) reduce 146) ((T_LIST) reduce 146) ((T_LNUMBER) reduce 146) ((T_MATCH) reduce 146) ((T_METHOD_C) reduce 146) ((T_NAMESPACE) reduce 146) ((T_NAME_FULLY_QUALIFIED) reduce 146) ((T_NAME_QUALIFIED) reduce 146) ((T_NAME_RELATIVE) reduce 146) ((T_NEW) reduce 146) ((T_NS_C) reduce 146) ((T_OBJECT_CAST) reduce 146) ((T_PRINT) reduce 146) ((T_READONLY) reduce 146) ((T_REQUIRE) reduce 146) ((T_REQUIRE_ONCE) reduce 146) ((T_RETURN) reduce 146) ((T_START_HEREDOC) reduce 146) ((T_STATIC) reduce 146) ((T_STRING) reduce 146) ((T_STRING_CAST) reduce 146) ((T_SWITCH) reduce 146) ((T_THROW) reduce 146) ((T_TRAIT) reduce 146) ((T_TRAIT_C) reduce 146) ((T_TRY) reduce 146) ((T_UNSET) reduce 146) ((T_UNSET_CAST) reduce 146) ((T_USE) reduce 146) ((T_VARIABLE) reduce 146) ((T_WHILE) reduce 146) ((T_YIELD) reduce 146) ((T_YIELD_FROM) reduce 146) (("[") reduce 146) (("`") reduce 146) (("{") reduce 146) (("}") reduce 146) (("~") reduce 146)) 27891 ((("!") reduce 243) (("\"") reduce 243) (("$") reduce 243) (("(") reduce 243) (("+") reduce 243) (("-") reduce 243) ((";") reduce 243) (("@") reduce 243) ((T_ABSTRACT) reduce 243) ((T_ARRAY) reduce 243) ((T_ARRAY_CAST) reduce 243) ((T_ATTRIBUTE) reduce 243) ((T_BOOL_CAST) reduce 243) ((T_BREAK) reduce 243) ((T_CLASS) reduce 243) ((T_CLASS_C) reduce 243) ((T_CLONE) reduce 243) ((T_CONST) reduce 243) ((T_CONSTANT_ENCAPSED_STRING) reduce 243) ((T_CONTINUE) reduce 243) ((T_DEC) reduce 243) ((T_DECLARE) reduce 243) ((T_DIR) reduce 243) ((T_DNUMBER) reduce 243) ((T_DO) reduce 243) ((T_DOUBLE_CAST) reduce 243) ((T_ECHO) reduce 243) ((T_ELSE) shift) ((T_ELSEIF) shift) ((T_EMPTY) reduce 243) ((T_ENUM) reduce 243) ((T_EVAL) reduce 243) ((T_EXIT) reduce 243) ((T_FILE) reduce 243) ((T_FINAL) reduce 243) ((T_FN) reduce 243) ((T_FOR) reduce 243) ((T_FOREACH) reduce 243) ((T_FUNCTION) reduce 243) ((T_FUNC_C) reduce 243) ((T_GLOBAL) reduce 243) ((T_GOTO) reduce 243) ((T_HALT_COMPILER) reduce 243) ((T_IF) reduce 243) ((T_INC) reduce 243) ((T_INCLUDE) reduce 243) ((T_INCLUDE_ONCE) reduce 243) ((T_INLINE_HTML) reduce 243) ((T_INTERFACE) reduce 243) ((T_INT_CAST) reduce 243) ((T_ISSET) reduce 243) ((T_LINE) reduce 243) ((T_LIST) reduce 243) ((T_LNUMBER) reduce 243) ((T_MATCH) reduce 243) ((T_METHOD_C) reduce 243) ((T_NAMESPACE) reduce 243) ((T_NAME_FULLY_QUALIFIED) reduce 243) ((T_NAME_QUALIFIED) reduce 243) ((T_NAME_RELATIVE) reduce 243) ((T_NEW) reduce 243) ((T_NS_C) reduce 243) ((T_OBJECT_CAST) reduce 243) ((T_PRINT) reduce 243) ((T_READONLY) reduce 243) ((T_REQUIRE) reduce 243) ((T_REQUIRE_ONCE) reduce 243) ((T_RETURN) reduce 243) ((T_START_HEREDOC) reduce 243) ((T_STATIC) reduce 243) ((T_STRING) reduce 243) ((T_STRING_CAST) reduce 243) ((T_SWITCH) reduce 243) ((T_THROW) reduce 243) ((T_TRAIT) reduce 243) ((T_TRAIT_C) reduce 243) ((T_TRY) reduce 243) ((T_UNSET) reduce 243) ((T_UNSET_CAST) reduce 243) ((T_USE) reduce 243) ((T_VARIABLE) reduce 243) ((T_WHILE) reduce 243) ((T_YIELD) reduce 243) ((T_YIELD_FROM) reduce 243) (("[") reduce 243) (("`") reduce 243) (("{") reduce 243) (("}") reduce 243) (("~") reduce 243)) 27892 ((("!") reduce 105) (("\"") reduce 105) (("$") reduce 105) (("(") reduce 105) (("+") reduce 105) (("-") reduce 105) ((";") reduce 105) (("@") reduce 105) ((T_ABSTRACT) reduce 105) ((T_ARRAY) reduce 105) ((T_ARRAY_CAST) reduce 105) ((T_ATTRIBUTE) reduce 105) ((T_BOOL_CAST) reduce 105) ((T_BREAK) reduce 105) ((T_CLASS) reduce 105) ((T_CLASS_C) reduce 105) ((T_CLONE) reduce 105) ((T_CONST) reduce 105) ((T_CONSTANT_ENCAPSED_STRING) reduce 105) ((T_CONTINUE) reduce 105) ((T_DEC) reduce 105) ((T_DECLARE) reduce 105) ((T_DIR) reduce 105) ((T_DNUMBER) reduce 105) ((T_DO) reduce 105) ((T_DOUBLE_CAST) reduce 105) ((T_ECHO) reduce 105) ((T_EMPTY) reduce 105) ((T_ENUM) reduce 105) ((T_EVAL) reduce 105) ((T_EXIT) reduce 105) ((T_FILE) reduce 105) ((T_FINAL) reduce 105) ((T_FN) reduce 105) ((T_FOR) reduce 105) ((T_FOREACH) reduce 105) ((T_FUNCTION) reduce 105) ((T_FUNC_C) reduce 105) ((T_GLOBAL) reduce 105) ((T_GOTO) reduce 105) ((T_HALT_COMPILER) reduce 105) ((T_IF) reduce 105) ((T_INC) reduce 105) ((T_INCLUDE) reduce 105) ((T_INCLUDE_ONCE) reduce 105) ((T_INLINE_HTML) reduce 105) ((T_INTERFACE) reduce 105) ((T_INT_CAST) reduce 105) ((T_ISSET) reduce 105) ((T_LINE) reduce 105) ((T_LIST) reduce 105) ((T_LNUMBER) reduce 105) ((T_MATCH) reduce 105) ((T_METHOD_C) reduce 105) ((T_NAMESPACE) reduce 105) ((T_NAME_FULLY_QUALIFIED) reduce 105) ((T_NAME_QUALIFIED) reduce 105) ((T_NAME_RELATIVE) reduce 105) ((T_NEW) reduce 105) ((T_NS_C) reduce 105) ((T_OBJECT_CAST) reduce 105) ((T_PRINT) reduce 105) ((T_READONLY) reduce 105) ((T_REQUIRE) reduce 105) ((T_REQUIRE_ONCE) reduce 105) ((T_RETURN) reduce 105) ((T_START_HEREDOC) reduce 105) ((T_STATIC) reduce 105) ((T_STRING) reduce 105) ((T_STRING_CAST) reduce 105) ((T_SWITCH) reduce 105) ((T_THROW) reduce 105) ((T_TRAIT) reduce 105) ((T_TRAIT_C) reduce 105) ((T_TRY) reduce 105) ((T_UNSET) reduce 105) ((T_UNSET_CAST) reduce 105) ((T_USE) reduce 105) ((T_VARIABLE) reduce 105) ((T_WHILE) reduce 105) ((T_YIELD) reduce 105) ((T_YIELD_FROM) reduce 105) (("[") reduce 105) (("`") reduce 105) (("{") reduce 105) (("}") reduce 105) (("~") reduce 105)) 27893 ((("!") reduce 107) (("\"") reduce 107) (("$") reduce 107) (("(") reduce 107) (("+") reduce 107) (("-") reduce 107) ((";") reduce 107) (("@") reduce 107) ((T_ABSTRACT) reduce 107) ((T_ARRAY) reduce 107) ((T_ARRAY_CAST) reduce 107) ((T_ATTRIBUTE) reduce 107) ((T_BOOL_CAST) reduce 107) ((T_BREAK) reduce 107) ((T_CLASS) reduce 107) ((T_CLASS_C) reduce 107) ((T_CLONE) reduce 107) ((T_CONST) reduce 107) ((T_CONSTANT_ENCAPSED_STRING) reduce 107) ((T_CONTINUE) reduce 107) ((T_DEC) reduce 107) ((T_DECLARE) reduce 107) ((T_DIR) reduce 107) ((T_DNUMBER) reduce 107) ((T_DO) reduce 107) ((T_DOUBLE_CAST) reduce 107) ((T_ECHO) reduce 107) ((T_EMPTY) reduce 107) ((T_ENUM) reduce 107) ((T_EVAL) reduce 107) ((T_EXIT) reduce 107) ((T_FILE) reduce 107) ((T_FINAL) reduce 107) ((T_FN) reduce 107) ((T_FOR) reduce 107) ((T_FOREACH) reduce 107) ((T_FUNCTION) reduce 107) ((T_FUNC_C) reduce 107) ((T_GLOBAL) reduce 107) ((T_GOTO) reduce 107) ((T_HALT_COMPILER) reduce 107) ((T_IF) reduce 107) ((T_INC) reduce 107) ((T_INCLUDE) reduce 107) ((T_INCLUDE_ONCE) reduce 107) ((T_INLINE_HTML) reduce 107) ((T_INTERFACE) reduce 107) ((T_INT_CAST) reduce 107) ((T_ISSET) reduce 107) ((T_LINE) reduce 107) ((T_LIST) reduce 107) ((T_LNUMBER) reduce 107) ((T_MATCH) reduce 107) ((T_METHOD_C) reduce 107) ((T_NAMESPACE) reduce 107) ((T_NAME_FULLY_QUALIFIED) reduce 107) ((T_NAME_QUALIFIED) reduce 107) ((T_NAME_RELATIVE) reduce 107) ((T_NEW) reduce 107) ((T_NS_C) reduce 107) ((T_OBJECT_CAST) reduce 107) ((T_PRINT) reduce 107) ((T_READONLY) reduce 107) ((T_REQUIRE) reduce 107) ((T_REQUIRE_ONCE) reduce 107) ((T_RETURN) reduce 107) ((T_START_HEREDOC) reduce 107) ((T_STATIC) reduce 107) ((T_STRING) reduce 107) ((T_STRING_CAST) reduce 107) ((T_SWITCH) reduce 107) ((T_THROW) reduce 107) ((T_TRAIT) reduce 107) ((T_TRAIT_C) reduce 107) ((T_TRY) reduce 107) ((T_UNSET) reduce 107) ((T_UNSET_CAST) reduce 107) ((T_USE) reduce 107) ((T_VARIABLE) reduce 107) ((T_WHILE) reduce 107) ((T_YIELD) reduce 107) ((T_YIELD_FROM) reduce 107) (("[") reduce 107) (("`") reduce 107) (("{") reduce 107) (("}") reduce 107) (("~") reduce 107)) 27894 ((("!") reduce 83) (("\"") reduce 83) (("$") reduce 83) (("(") reduce 83) (("+") reduce 83) (("-") reduce 83) ((";") reduce 83) (("@") reduce 83) ((T_ABSTRACT) reduce 83) ((T_ARRAY) reduce 83) ((T_ARRAY_CAST) reduce 83) ((T_ATTRIBUTE) reduce 83) ((T_BOOL_CAST) reduce 83) ((T_BREAK) reduce 83) ((T_CLASS) reduce 83) ((T_CLASS_C) reduce 83) ((T_CLONE) reduce 83) ((T_CONST) reduce 83) ((T_CONSTANT_ENCAPSED_STRING) reduce 83) ((T_CONTINUE) reduce 83) ((T_DEC) reduce 83) ((T_DECLARE) reduce 83) ((T_DIR) reduce 83) ((T_DNUMBER) reduce 83) ((T_DO) reduce 83) ((T_DOUBLE_CAST) reduce 83) ((T_ECHO) reduce 83) ((T_EMPTY) reduce 83) ((T_ENUM) reduce 83) ((T_EVAL) reduce 83) ((T_EXIT) reduce 83) ((T_FILE) reduce 83) ((T_FINAL) reduce 83) ((T_FN) reduce 83) ((T_FOR) reduce 83) ((T_FOREACH) reduce 83) ((T_FUNCTION) reduce 83) ((T_FUNC_C) reduce 83) ((T_GLOBAL) reduce 83) ((T_GOTO) reduce 83) ((T_HALT_COMPILER) reduce 83) ((T_IF) reduce 83) ((T_INC) reduce 83) ((T_INCLUDE) reduce 83) ((T_INCLUDE_ONCE) reduce 83) ((T_INLINE_HTML) reduce 83) ((T_INTERFACE) reduce 83) ((T_INT_CAST) reduce 83) ((T_ISSET) reduce 83) ((T_LINE) reduce 83) ((T_LIST) reduce 83) ((T_LNUMBER) reduce 83) ((T_MATCH) reduce 83) ((T_METHOD_C) reduce 83) ((T_NAMESPACE) reduce 83) ((T_NAME_FULLY_QUALIFIED) reduce 83) ((T_NAME_QUALIFIED) reduce 83) ((T_NAME_RELATIVE) reduce 83) ((T_NEW) reduce 83) ((T_NS_C) reduce 83) ((T_OBJECT_CAST) reduce 83) ((T_PRINT) reduce 83) ((T_READONLY) reduce 83) ((T_REQUIRE) reduce 83) ((T_REQUIRE_ONCE) reduce 83) ((T_RETURN) reduce 83) ((T_START_HEREDOC) reduce 83) ((T_STATIC) reduce 83) ((T_STRING) reduce 83) ((T_STRING_CAST) reduce 83) ((T_SWITCH) reduce 83) ((T_THROW) reduce 83) ((T_TRAIT) reduce 83) ((T_TRAIT_C) reduce 83) ((T_TRY) reduce 83) ((T_UNSET) reduce 83) ((T_UNSET_CAST) reduce 83) ((T_USE) reduce 83) ((T_VARIABLE) reduce 83) ((T_WHILE) reduce 83) ((T_YIELD) reduce 83) ((T_YIELD_FROM) reduce 83) (("[") reduce 83) (("`") reduce 83) (("{") reduce 83) (("}") reduce 83) (("~") reduce 83)) 27895 ((("!") reduce 104) (("\"") reduce 104) (("$") reduce 104) (("(") reduce 104) (("+") reduce 104) (("-") reduce 104) ((";") reduce 104) (("@") reduce 104) ((T_ABSTRACT) reduce 104) ((T_ARRAY) reduce 104) ((T_ARRAY_CAST) reduce 104) ((T_ATTRIBUTE) reduce 104) ((T_BOOL_CAST) reduce 104) ((T_BREAK) reduce 104) ((T_CLASS) reduce 104) ((T_CLASS_C) reduce 104) ((T_CLONE) reduce 104) ((T_CONST) reduce 104) ((T_CONSTANT_ENCAPSED_STRING) reduce 104) ((T_CONTINUE) reduce 104) ((T_DEC) reduce 104) ((T_DECLARE) reduce 104) ((T_DIR) reduce 104) ((T_DNUMBER) reduce 104) ((T_DO) reduce 104) ((T_DOUBLE_CAST) reduce 104) ((T_ECHO) reduce 104) ((T_EMPTY) reduce 104) ((T_ENUM) reduce 104) ((T_EVAL) reduce 104) ((T_EXIT) reduce 104) ((T_FILE) reduce 104) ((T_FINAL) reduce 104) ((T_FN) reduce 104) ((T_FOR) reduce 104) ((T_FOREACH) reduce 104) ((T_FUNCTION) reduce 104) ((T_FUNC_C) reduce 104) ((T_GLOBAL) reduce 104) ((T_GOTO) reduce 104) ((T_HALT_COMPILER) reduce 104) ((T_IF) reduce 104) ((T_INC) reduce 104) ((T_INCLUDE) reduce 104) ((T_INCLUDE_ONCE) reduce 104) ((T_INLINE_HTML) reduce 104) ((T_INTERFACE) reduce 104) ((T_INT_CAST) reduce 104) ((T_ISSET) reduce 104) ((T_LINE) reduce 104) ((T_LIST) reduce 104) ((T_LNUMBER) reduce 104) ((T_MATCH) reduce 104) ((T_METHOD_C) reduce 104) ((T_NAMESPACE) reduce 104) ((T_NAME_FULLY_QUALIFIED) reduce 104) ((T_NAME_QUALIFIED) reduce 104) ((T_NAME_RELATIVE) reduce 104) ((T_NEW) reduce 104) ((T_NS_C) reduce 104) ((T_OBJECT_CAST) reduce 104) ((T_PRINT) reduce 104) ((T_READONLY) reduce 104) ((T_REQUIRE) reduce 104) ((T_REQUIRE_ONCE) reduce 104) ((T_RETURN) reduce 104) ((T_START_HEREDOC) reduce 104) ((T_STATIC) reduce 104) ((T_STRING) reduce 104) ((T_STRING_CAST) reduce 104) ((T_SWITCH) reduce 104) ((T_THROW) reduce 104) ((T_TRAIT) reduce 104) ((T_TRAIT_C) reduce 104) ((T_TRY) reduce 104) ((T_UNSET) reduce 104) ((T_UNSET_CAST) reduce 104) ((T_USE) reduce 104) ((T_VARIABLE) reduce 104) ((T_WHILE) reduce 104) ((T_YIELD) reduce 104) ((T_YIELD_FROM) reduce 104) (("[") reduce 104) (("`") reduce 104) (("{") reduce 104) (("}") reduce 104) (("~") reduce 104)) 27897 ((("!") reduce 113) (("\"") reduce 113) (($) reduce 113) (("$") reduce 113) (("(") reduce 113) (("+") reduce 113) (("-") reduce 113) ((";") reduce 113) (("@") reduce 113) ((T_ABSTRACT) reduce 113) ((T_ARRAY) reduce 113) ((T_ARRAY_CAST) reduce 113) ((T_ATTRIBUTE) reduce 113) ((T_BOOL_CAST) reduce 113) ((T_BREAK) reduce 113) ((T_CLASS) reduce 113) ((T_CLASS_C) reduce 113) ((T_CLONE) reduce 113) ((T_CONST) reduce 113) ((T_CONSTANT_ENCAPSED_STRING) reduce 113) ((T_CONTINUE) reduce 113) ((T_DEC) reduce 113) ((T_DECLARE) reduce 113) ((T_DIR) reduce 113) ((T_DNUMBER) reduce 113) ((T_DO) reduce 113) ((T_DOUBLE_CAST) reduce 113) ((T_ECHO) reduce 113) ((T_EMPTY) reduce 113) ((T_ENUM) reduce 113) ((T_EVAL) reduce 113) ((T_EXIT) reduce 113) ((T_FILE) reduce 113) ((T_FINAL) reduce 113) ((T_FN) reduce 113) ((T_FOR) reduce 113) ((T_FOREACH) reduce 113) ((T_FUNCTION) reduce 113) ((T_FUNC_C) reduce 113) ((T_GLOBAL) reduce 113) ((T_GOTO) reduce 113) ((T_HALT_COMPILER) reduce 113) ((T_IF) reduce 113) ((T_INC) reduce 113) ((T_INCLUDE) reduce 113) ((T_INCLUDE_ONCE) reduce 113) ((T_INLINE_HTML) reduce 113) ((T_INTERFACE) reduce 113) ((T_INT_CAST) reduce 113) ((T_ISSET) reduce 113) ((T_LINE) reduce 113) ((T_LIST) reduce 113) ((T_LNUMBER) reduce 113) ((T_MATCH) reduce 113) ((T_METHOD_C) reduce 113) ((T_NAMESPACE) reduce 113) ((T_NAME_FULLY_QUALIFIED) reduce 113) ((T_NAME_QUALIFIED) reduce 113) ((T_NAME_RELATIVE) reduce 113) ((T_NEW) reduce 113) ((T_NS_C) reduce 113) ((T_OBJECT_CAST) reduce 113) ((T_PRINT) reduce 113) ((T_READONLY) reduce 113) ((T_REQUIRE) reduce 113) ((T_REQUIRE_ONCE) reduce 113) ((T_RETURN) reduce 113) ((T_START_HEREDOC) reduce 113) ((T_STATIC) reduce 113) ((T_STRING) reduce 113) ((T_STRING_CAST) reduce 113) ((T_SWITCH) reduce 113) ((T_THROW) reduce 113) ((T_TRAIT) reduce 113) ((T_TRAIT_C) reduce 113) ((T_TRY) reduce 113) ((T_UNSET) reduce 113) ((T_UNSET_CAST) reduce 113) ((T_USE) reduce 113) ((T_VARIABLE) reduce 113) ((T_WHILE) reduce 113) ((T_YIELD) reduce 113) ((T_YIELD_FROM) reduce 113) (("[") reduce 113) (("`") reduce 113) (("{") reduce 113) (("~") reduce 113)) 27899 ((("!") reduce 145) (("\"") reduce 145) (("$") reduce 145) (("(") reduce 145) (("+") reduce 145) (("-") reduce 145) ((";") reduce 145) (("@") reduce 145) ((T_ABSTRACT) reduce 145) ((T_ARRAY) reduce 145) ((T_ARRAY_CAST) reduce 145) ((T_ATTRIBUTE) reduce 145) ((T_BOOL_CAST) reduce 145) ((T_BREAK) reduce 145) ((T_CLASS) reduce 145) ((T_CLASS_C) reduce 145) ((T_CLONE) reduce 145) ((T_CONST) reduce 145) ((T_CONSTANT_ENCAPSED_STRING) reduce 145) ((T_CONTINUE) reduce 145) ((T_DEC) reduce 145) ((T_DECLARE) reduce 145) ((T_DIR) reduce 145) ((T_DNUMBER) reduce 145) ((T_DO) reduce 145) ((T_DOUBLE_CAST) reduce 145) ((T_ECHO) reduce 145) ((T_EMPTY) reduce 145) ((T_ENUM) reduce 145) ((T_EVAL) reduce 145) ((T_EXIT) reduce 145) ((T_FILE) reduce 145) ((T_FINAL) reduce 145) ((T_FN) reduce 145) ((T_FOR) reduce 145) ((T_FOREACH) reduce 145) ((T_FUNCTION) reduce 145) ((T_FUNC_C) reduce 145) ((T_GLOBAL) reduce 145) ((T_GOTO) reduce 145) ((T_HALT_COMPILER) reduce 145) ((T_IF) reduce 145) ((T_INC) reduce 145) ((T_INCLUDE) reduce 145) ((T_INCLUDE_ONCE) reduce 145) ((T_INLINE_HTML) reduce 145) ((T_INTERFACE) reduce 145) ((T_INT_CAST) reduce 145) ((T_ISSET) reduce 145) ((T_LINE) reduce 145) ((T_LIST) reduce 145) ((T_LNUMBER) reduce 145) ((T_MATCH) reduce 145) ((T_METHOD_C) reduce 145) ((T_NAMESPACE) reduce 145) ((T_NAME_FULLY_QUALIFIED) reduce 145) ((T_NAME_QUALIFIED) reduce 145) ((T_NAME_RELATIVE) reduce 145) ((T_NEW) reduce 145) ((T_NS_C) reduce 145) ((T_OBJECT_CAST) reduce 145) ((T_PRINT) reduce 145) ((T_READONLY) reduce 145) ((T_REQUIRE) reduce 145) ((T_REQUIRE_ONCE) reduce 145) ((T_RETURN) reduce 145) ((T_START_HEREDOC) reduce 145) ((T_STATIC) reduce 145) ((T_STRING) reduce 145) ((T_STRING_CAST) reduce 145) ((T_SWITCH) reduce 145) ((T_THROW) reduce 145) ((T_TRAIT) reduce 145) ((T_TRAIT_C) reduce 145) ((T_TRY) reduce 145) ((T_UNSET) reduce 145) ((T_UNSET_CAST) reduce 145) ((T_USE) reduce 145) ((T_VARIABLE) reduce 145) ((T_WHILE) reduce 145) ((T_YIELD) reduce 145) ((T_YIELD_FROM) reduce 145) (("[") reduce 145) (("`") reduce 145) (("{") reduce 145) (("}") reduce 145) (("~") reduce 145)) 27905 ((("!") reduce 164) (("\"") reduce 164) (("$") reduce 164) (("(") reduce 164) (("+") reduce 164) (("-") reduce 164) ((";") reduce 164) (("@") reduce 164) ((T_ABSTRACT) reduce 164) ((T_ARRAY) reduce 164) ((T_ARRAY_CAST) reduce 164) ((T_ATTRIBUTE) reduce 164) ((T_BOOL_CAST) reduce 164) ((T_BREAK) reduce 164) ((T_CLASS) reduce 164) ((T_CLASS_C) reduce 164) ((T_CLONE) reduce 164) ((T_CONST) reduce 164) ((T_CONSTANT_ENCAPSED_STRING) reduce 164) ((T_CONTINUE) reduce 164) ((T_DEC) reduce 164) ((T_DECLARE) reduce 164) ((T_DIR) reduce 164) ((T_DNUMBER) reduce 164) ((T_DO) reduce 164) ((T_DOUBLE_CAST) reduce 164) ((T_ECHO) reduce 164) ((T_ELSE) reduce 164) ((T_ELSEIF) reduce 164) ((T_EMPTY) reduce 164) ((T_ENUM) reduce 164) ((T_EVAL) reduce 164) ((T_EXIT) reduce 164) ((T_FILE) reduce 164) ((T_FINAL) reduce 164) ((T_FN) reduce 164) ((T_FOR) reduce 164) ((T_FOREACH) reduce 164) ((T_FUNCTION) reduce 164) ((T_FUNC_C) reduce 164) ((T_GLOBAL) reduce 164) ((T_GOTO) reduce 164) ((T_HALT_COMPILER) reduce 164) ((T_IF) reduce 164) ((T_INC) reduce 164) ((T_INCLUDE) reduce 164) ((T_INCLUDE_ONCE) reduce 164) ((T_INLINE_HTML) reduce 164) ((T_INTERFACE) reduce 164) ((T_INT_CAST) reduce 164) ((T_ISSET) reduce 164) ((T_LINE) reduce 164) ((T_LIST) reduce 164) ((T_LNUMBER) reduce 164) ((T_MATCH) reduce 164) ((T_METHOD_C) reduce 164) ((T_NAMESPACE) reduce 164) ((T_NAME_FULLY_QUALIFIED) reduce 164) ((T_NAME_QUALIFIED) reduce 164) ((T_NAME_RELATIVE) reduce 164) ((T_NEW) reduce 164) ((T_NS_C) reduce 164) ((T_OBJECT_CAST) reduce 164) ((T_PRINT) reduce 164) ((T_READONLY) reduce 164) ((T_REQUIRE) reduce 164) ((T_REQUIRE_ONCE) reduce 164) ((T_RETURN) reduce 164) ((T_START_HEREDOC) reduce 164) ((T_STATIC) reduce 164) ((T_STRING) reduce 164) ((T_STRING_CAST) reduce 164) ((T_SWITCH) reduce 164) ((T_THROW) reduce 164) ((T_TRAIT) reduce 164) ((T_TRAIT_C) reduce 164) ((T_TRY) reduce 164) ((T_UNSET) reduce 164) ((T_UNSET_CAST) reduce 164) ((T_USE) reduce 164) ((T_VARIABLE) reduce 164) ((T_WHILE) reduce 164) ((T_YIELD) reduce 164) ((T_YIELD_FROM) reduce 164) (("[") reduce 164) (("`") reduce 164) (("{") reduce 164) (("}") reduce 164) (("~") reduce 164)) 27915 ((("!") reduce 158) (("\"") reduce 158) (("$") reduce 158) (("(") reduce 158) (("+") reduce 158) (("-") reduce 158) ((";") reduce 158) (("@") reduce 158) ((T_ABSTRACT) reduce 158) ((T_ARRAY) reduce 158) ((T_ARRAY_CAST) reduce 158) ((T_ATTRIBUTE) reduce 158) ((T_BOOL_CAST) reduce 158) ((T_BREAK) reduce 158) ((T_CLASS) reduce 158) ((T_CLASS_C) reduce 158) ((T_CLONE) reduce 158) ((T_CONST) reduce 158) ((T_CONSTANT_ENCAPSED_STRING) reduce 158) ((T_CONTINUE) reduce 158) ((T_DEC) reduce 158) ((T_DECLARE) reduce 158) ((T_DIR) reduce 158) ((T_DNUMBER) reduce 158) ((T_DO) reduce 158) ((T_DOUBLE_CAST) reduce 158) ((T_ECHO) reduce 158) ((T_ELSE) reduce 158) ((T_ELSEIF) reduce 158) ((T_EMPTY) reduce 158) ((T_ENUM) reduce 158) ((T_EVAL) reduce 158) ((T_EXIT) reduce 158) ((T_FILE) reduce 158) ((T_FINAL) reduce 158) ((T_FN) reduce 158) ((T_FOR) reduce 158) ((T_FOREACH) reduce 158) ((T_FUNCTION) reduce 158) ((T_FUNC_C) reduce 158) ((T_GLOBAL) reduce 158) ((T_GOTO) reduce 158) ((T_HALT_COMPILER) reduce 158) ((T_IF) reduce 158) ((T_INC) reduce 158) ((T_INCLUDE) reduce 158) ((T_INCLUDE_ONCE) reduce 158) ((T_INLINE_HTML) reduce 158) ((T_INTERFACE) reduce 158) ((T_INT_CAST) reduce 158) ((T_ISSET) reduce 158) ((T_LINE) reduce 158) ((T_LIST) reduce 158) ((T_LNUMBER) reduce 158) ((T_MATCH) reduce 158) ((T_METHOD_C) reduce 158) ((T_NAMESPACE) reduce 158) ((T_NAME_FULLY_QUALIFIED) reduce 158) ((T_NAME_QUALIFIED) reduce 158) ((T_NAME_RELATIVE) reduce 158) ((T_NEW) reduce 158) ((T_NS_C) reduce 158) ((T_OBJECT_CAST) reduce 158) ((T_PRINT) reduce 158) ((T_READONLY) reduce 158) ((T_REQUIRE) reduce 158) ((T_REQUIRE_ONCE) reduce 158) ((T_RETURN) reduce 158) ((T_START_HEREDOC) reduce 158) ((T_STATIC) reduce 158) ((T_STRING) reduce 158) ((T_STRING_CAST) reduce 158) ((T_SWITCH) reduce 158) ((T_THROW) reduce 158) ((T_TRAIT) reduce 158) ((T_TRAIT_C) reduce 158) ((T_TRY) reduce 158) ((T_UNSET) reduce 158) ((T_UNSET_CAST) reduce 158) ((T_USE) reduce 158) ((T_VARIABLE) reduce 158) ((T_WHILE) reduce 158) ((T_YIELD) reduce 158) ((T_YIELD_FROM) reduce 158) (("[") reduce 158) (("`") reduce 158) (("{") reduce 158) (("}") reduce 158) (("~") reduce 158)) 27923 ((("!") reduce 147) (("\"") reduce 147) (("$") reduce 147) (("(") reduce 147) (("+") reduce 147) (("-") reduce 147) ((";") reduce 147) (("@") reduce 147) ((T_ABSTRACT) reduce 147) ((T_ARRAY) reduce 147) ((T_ARRAY_CAST) reduce 147) ((T_ATTRIBUTE) reduce 147) ((T_BOOL_CAST) reduce 147) ((T_BREAK) reduce 147) ((T_CLASS) reduce 147) ((T_CLASS_C) reduce 147) ((T_CLONE) reduce 147) ((T_CONST) reduce 147) ((T_CONSTANT_ENCAPSED_STRING) reduce 147) ((T_CONTINUE) reduce 147) ((T_DEC) reduce 147) ((T_DECLARE) reduce 147) ((T_DIR) reduce 147) ((T_DNUMBER) reduce 147) ((T_DO) reduce 147) ((T_DOUBLE_CAST) reduce 147) ((T_ECHO) reduce 147) ((T_ELSE) reduce 147) ((T_ELSEIF) reduce 147) ((T_EMPTY) reduce 147) ((T_ENUM) reduce 147) ((T_EVAL) reduce 147) ((T_EXIT) reduce 147) ((T_FILE) reduce 147) ((T_FINAL) reduce 147) ((T_FN) reduce 147) ((T_FOR) reduce 147) ((T_FOREACH) reduce 147) ((T_FUNCTION) reduce 147) ((T_FUNC_C) reduce 147) ((T_GLOBAL) reduce 147) ((T_GOTO) reduce 147) ((T_HALT_COMPILER) reduce 147) ((T_IF) reduce 147) ((T_INC) reduce 147) ((T_INCLUDE) reduce 147) ((T_INCLUDE_ONCE) reduce 147) ((T_INLINE_HTML) reduce 147) ((T_INTERFACE) reduce 147) ((T_INT_CAST) reduce 147) ((T_ISSET) reduce 147) ((T_LINE) reduce 147) ((T_LIST) reduce 147) ((T_LNUMBER) reduce 147) ((T_MATCH) reduce 147) ((T_METHOD_C) reduce 147) ((T_NAMESPACE) reduce 147) ((T_NAME_FULLY_QUALIFIED) reduce 147) ((T_NAME_QUALIFIED) reduce 147) ((T_NAME_RELATIVE) reduce 147) ((T_NEW) reduce 147) ((T_NS_C) reduce 147) ((T_OBJECT_CAST) reduce 147) ((T_PRINT) reduce 147) ((T_READONLY) reduce 147) ((T_REQUIRE) reduce 147) ((T_REQUIRE_ONCE) reduce 147) ((T_RETURN) reduce 147) ((T_START_HEREDOC) reduce 147) ((T_STATIC) reduce 147) ((T_STRING) reduce 147) ((T_STRING_CAST) reduce 147) ((T_SWITCH) reduce 147) ((T_THROW) reduce 147) ((T_TRAIT) reduce 147) ((T_TRAIT_C) reduce 147) ((T_TRY) reduce 147) ((T_UNSET) reduce 147) ((T_UNSET_CAST) reduce 147) ((T_USE) reduce 147) ((T_VARIABLE) reduce 147) ((T_WHILE) reduce 147) ((T_YIELD) reduce 147) ((T_YIELD_FROM) reduce 147) (("[") reduce 147) (("`") reduce 147) (("{") reduce 147) (("}") reduce 147) (("~") reduce 147)) 27926 ((("!") reduce 146) (("\"") reduce 146) (("$") reduce 146) (("(") reduce 146) (("+") reduce 146) (("-") reduce 146) ((";") reduce 146) (("@") reduce 146) ((T_ABSTRACT) reduce 146) ((T_ARRAY) reduce 146) ((T_ARRAY_CAST) reduce 146) ((T_ATTRIBUTE) reduce 146) ((T_BOOL_CAST) reduce 146) ((T_BREAK) reduce 146) ((T_CLASS) reduce 146) ((T_CLASS_C) reduce 146) ((T_CLONE) reduce 146) ((T_CONST) reduce 146) ((T_CONSTANT_ENCAPSED_STRING) reduce 146) ((T_CONTINUE) reduce 146) ((T_DEC) reduce 146) ((T_DECLARE) reduce 146) ((T_DIR) reduce 146) ((T_DNUMBER) reduce 146) ((T_DO) reduce 146) ((T_DOUBLE_CAST) reduce 146) ((T_ECHO) reduce 146) ((T_ELSE) reduce 146) ((T_ELSEIF) reduce 146) ((T_EMPTY) reduce 146) ((T_ENUM) reduce 146) ((T_EVAL) reduce 146) ((T_EXIT) reduce 146) ((T_FILE) reduce 146) ((T_FINAL) reduce 146) ((T_FN) reduce 146) ((T_FOR) reduce 146) ((T_FOREACH) reduce 146) ((T_FUNCTION) reduce 146) ((T_FUNC_C) reduce 146) ((T_GLOBAL) reduce 146) ((T_GOTO) reduce 146) ((T_HALT_COMPILER) reduce 146) ((T_IF) reduce 146) ((T_INC) reduce 146) ((T_INCLUDE) reduce 146) ((T_INCLUDE_ONCE) reduce 146) ((T_INLINE_HTML) reduce 146) ((T_INTERFACE) reduce 146) ((T_INT_CAST) reduce 146) ((T_ISSET) reduce 146) ((T_LINE) reduce 146) ((T_LIST) reduce 146) ((T_LNUMBER) reduce 146) ((T_MATCH) reduce 146) ((T_METHOD_C) reduce 146) ((T_NAMESPACE) reduce 146) ((T_NAME_FULLY_QUALIFIED) reduce 146) ((T_NAME_QUALIFIED) reduce 146) ((T_NAME_RELATIVE) reduce 146) ((T_NEW) reduce 146) ((T_NS_C) reduce 146) ((T_OBJECT_CAST) reduce 146) ((T_PRINT) reduce 146) ((T_READONLY) reduce 146) ((T_REQUIRE) reduce 146) ((T_REQUIRE_ONCE) reduce 146) ((T_RETURN) reduce 146) ((T_START_HEREDOC) reduce 146) ((T_STATIC) reduce 146) ((T_STRING) reduce 146) ((T_STRING_CAST) reduce 146) ((T_SWITCH) reduce 146) ((T_THROW) reduce 146) ((T_TRAIT) reduce 146) ((T_TRAIT_C) reduce 146) ((T_TRY) reduce 146) ((T_UNSET) reduce 146) ((T_UNSET_CAST) reduce 146) ((T_USE) reduce 146) ((T_VARIABLE) reduce 146) ((T_WHILE) reduce 146) ((T_YIELD) reduce 146) ((T_YIELD_FROM) reduce 146) (("[") reduce 146) (("`") reduce 146) (("{") reduce 146) (("}") reduce 146) (("~") reduce 146)) 27928 ((("!") reduce 242) (("\"") reduce 242) (("$") reduce 242) (("(") reduce 242) (("+") reduce 242) (("-") reduce 242) ((";") reduce 242) (("@") reduce 242) ((T_ABSTRACT) reduce 242) ((T_ARRAY) reduce 242) ((T_ARRAY_CAST) reduce 242) ((T_ATTRIBUTE) reduce 242) ((T_BOOL_CAST) reduce 242) ((T_BREAK) reduce 242) ((T_CLASS) reduce 242) ((T_CLASS_C) reduce 242) ((T_CLONE) reduce 242) ((T_CONST) reduce 242) ((T_CONSTANT_ENCAPSED_STRING) reduce 242) ((T_CONTINUE) reduce 242) ((T_DEC) reduce 242) ((T_DECLARE) reduce 242) ((T_DIR) reduce 242) ((T_DNUMBER) reduce 242) ((T_DO) reduce 242) ((T_DOUBLE_CAST) reduce 242) ((T_ECHO) reduce 242) ((T_ELSE) reduce 242) ((T_ELSEIF) reduce 242) ((T_EMPTY) reduce 242) ((T_ENUM) reduce 242) ((T_EVAL) reduce 242) ((T_EXIT) reduce 242) ((T_FILE) reduce 242) ((T_FINAL) reduce 242) ((T_FN) reduce 242) ((T_FOR) reduce 242) ((T_FOREACH) reduce 242) ((T_FUNCTION) reduce 242) ((T_FUNC_C) reduce 242) ((T_GLOBAL) reduce 242) ((T_GOTO) reduce 242) ((T_HALT_COMPILER) reduce 242) ((T_IF) reduce 242) ((T_INC) reduce 242) ((T_INCLUDE) reduce 242) ((T_INCLUDE_ONCE) reduce 242) ((T_INLINE_HTML) reduce 242) ((T_INTERFACE) reduce 242) ((T_INT_CAST) reduce 242) ((T_ISSET) reduce 242) ((T_LINE) reduce 242) ((T_LIST) reduce 242) ((T_LNUMBER) reduce 242) ((T_MATCH) reduce 242) ((T_METHOD_C) reduce 242) ((T_NAMESPACE) reduce 242) ((T_NAME_FULLY_QUALIFIED) reduce 242) ((T_NAME_QUALIFIED) reduce 242) ((T_NAME_RELATIVE) reduce 242) ((T_NEW) reduce 242) ((T_NS_C) reduce 242) ((T_OBJECT_CAST) reduce 242) ((T_PRINT) reduce 242) ((T_READONLY) reduce 242) ((T_REQUIRE) reduce 242) ((T_REQUIRE_ONCE) reduce 242) ((T_RETURN) reduce 242) ((T_START_HEREDOC) reduce 242) ((T_STATIC) reduce 242) ((T_STRING) reduce 242) ((T_STRING_CAST) reduce 242) ((T_SWITCH) reduce 242) ((T_THROW) reduce 242) ((T_TRAIT) reduce 242) ((T_TRAIT_C) reduce 242) ((T_TRY) reduce 242) ((T_UNSET) reduce 242) ((T_UNSET_CAST) reduce 242) ((T_USE) reduce 242) ((T_VARIABLE) reduce 242) ((T_WHILE) reduce 242) ((T_YIELD) reduce 242) ((T_YIELD_FROM) reduce 242) (("[") reduce 242) (("`") reduce 242) (("{") reduce 242) (("}") reduce 242) (("~") reduce 242)) 27931 ((("!") reduce 145) (("\"") reduce 145) (("$") reduce 145) (("(") reduce 145) (("+") reduce 145) (("-") reduce 145) ((";") reduce 145) (("@") reduce 145) ((T_ABSTRACT) reduce 145) ((T_ARRAY) reduce 145) ((T_ARRAY_CAST) reduce 145) ((T_ATTRIBUTE) reduce 145) ((T_BOOL_CAST) reduce 145) ((T_BREAK) reduce 145) ((T_CLASS) reduce 145) ((T_CLASS_C) reduce 145) ((T_CLONE) reduce 145) ((T_CONST) reduce 145) ((T_CONSTANT_ENCAPSED_STRING) reduce 145) ((T_CONTINUE) reduce 145) ((T_DEC) reduce 145) ((T_DECLARE) reduce 145) ((T_DIR) reduce 145) ((T_DNUMBER) reduce 145) ((T_DO) reduce 145) ((T_DOUBLE_CAST) reduce 145) ((T_ECHO) reduce 145) ((T_ELSE) reduce 145) ((T_ELSEIF) reduce 145) ((T_EMPTY) reduce 145) ((T_ENUM) reduce 145) ((T_EVAL) reduce 145) ((T_EXIT) reduce 145) ((T_FILE) reduce 145) ((T_FINAL) reduce 145) ((T_FN) reduce 145) ((T_FOR) reduce 145) ((T_FOREACH) reduce 145) ((T_FUNCTION) reduce 145) ((T_FUNC_C) reduce 145) ((T_GLOBAL) reduce 145) ((T_GOTO) reduce 145) ((T_HALT_COMPILER) reduce 145) ((T_IF) reduce 145) ((T_INC) reduce 145) ((T_INCLUDE) reduce 145) ((T_INCLUDE_ONCE) reduce 145) ((T_INLINE_HTML) reduce 145) ((T_INTERFACE) reduce 145) ((T_INT_CAST) reduce 145) ((T_ISSET) reduce 145) ((T_LINE) reduce 145) ((T_LIST) reduce 145) ((T_LNUMBER) reduce 145) ((T_MATCH) reduce 145) ((T_METHOD_C) reduce 145) ((T_NAMESPACE) reduce 145) ((T_NAME_FULLY_QUALIFIED) reduce 145) ((T_NAME_QUALIFIED) reduce 145) ((T_NAME_RELATIVE) reduce 145) ((T_NEW) reduce 145) ((T_NS_C) reduce 145) ((T_OBJECT_CAST) reduce 145) ((T_PRINT) reduce 145) ((T_READONLY) reduce 145) ((T_REQUIRE) reduce 145) ((T_REQUIRE_ONCE) reduce 145) ((T_RETURN) reduce 145) ((T_START_HEREDOC) reduce 145) ((T_STATIC) reduce 145) ((T_STRING) reduce 145) ((T_STRING_CAST) reduce 145) ((T_SWITCH) reduce 145) ((T_THROW) reduce 145) ((T_TRAIT) reduce 145) ((T_TRAIT_C) reduce 145) ((T_TRY) reduce 145) ((T_UNSET) reduce 145) ((T_UNSET_CAST) reduce 145) ((T_USE) reduce 145) ((T_VARIABLE) reduce 145) ((T_WHILE) reduce 145) ((T_YIELD) reduce 145) ((T_YIELD_FROM) reduce 145) (("[") reduce 145) (("`") reduce 145) (("{") reduce 145) (("}") reduce 145) (("~") reduce 145)) 27933 ((("!") reduce 244) (("\"") reduce 244) (("$") reduce 244) (("(") reduce 244) (("+") reduce 244) (("-") reduce 244) ((";") reduce 244) (("@") reduce 244) ((T_ABSTRACT) reduce 244) ((T_ARRAY) reduce 244) ((T_ARRAY_CAST) reduce 244) ((T_ATTRIBUTE) reduce 244) ((T_BOOL_CAST) reduce 244) ((T_BREAK) reduce 244) ((T_CLASS) reduce 244) ((T_CLASS_C) reduce 244) ((T_CLONE) reduce 244) ((T_CONST) reduce 244) ((T_CONSTANT_ENCAPSED_STRING) reduce 244) ((T_CONTINUE) reduce 244) ((T_DEC) reduce 244) ((T_DECLARE) reduce 244) ((T_DIR) reduce 244) ((T_DNUMBER) reduce 244) ((T_DO) reduce 244) ((T_DOUBLE_CAST) reduce 244) ((T_ECHO) reduce 244) ((T_ELSE) reduce 244) ((T_ELSEIF) reduce 244) ((T_EMPTY) reduce 244) ((T_ENUM) reduce 244) ((T_EVAL) reduce 244) ((T_EXIT) reduce 244) ((T_FILE) reduce 244) ((T_FINAL) reduce 244) ((T_FN) reduce 244) ((T_FOR) reduce 244) ((T_FOREACH) reduce 244) ((T_FUNCTION) reduce 244) ((T_FUNC_C) reduce 244) ((T_GLOBAL) reduce 244) ((T_GOTO) reduce 244) ((T_HALT_COMPILER) reduce 244) ((T_IF) reduce 244) ((T_INC) reduce 244) ((T_INCLUDE) reduce 244) ((T_INCLUDE_ONCE) reduce 244) ((T_INLINE_HTML) reduce 244) ((T_INTERFACE) reduce 244) ((T_INT_CAST) reduce 244) ((T_ISSET) reduce 244) ((T_LINE) reduce 244) ((T_LIST) reduce 244) ((T_LNUMBER) reduce 244) ((T_MATCH) reduce 244) ((T_METHOD_C) reduce 244) ((T_NAMESPACE) reduce 244) ((T_NAME_FULLY_QUALIFIED) reduce 244) ((T_NAME_QUALIFIED) reduce 244) ((T_NAME_RELATIVE) reduce 244) ((T_NEW) reduce 244) ((T_NS_C) reduce 244) ((T_OBJECT_CAST) reduce 244) ((T_PRINT) reduce 244) ((T_READONLY) reduce 244) ((T_REQUIRE) reduce 244) ((T_REQUIRE_ONCE) reduce 244) ((T_RETURN) reduce 244) ((T_START_HEREDOC) reduce 244) ((T_STATIC) reduce 244) ((T_STRING) reduce 244) ((T_STRING_CAST) reduce 244) ((T_SWITCH) reduce 244) ((T_THROW) reduce 244) ((T_TRAIT) reduce 244) ((T_TRAIT_C) reduce 244) ((T_TRY) reduce 244) ((T_UNSET) reduce 244) ((T_UNSET_CAST) reduce 244) ((T_USE) reduce 244) ((T_VARIABLE) reduce 244) ((T_WHILE) reduce 244) ((T_YIELD) reduce 244) ((T_YIELD_FROM) reduce 244) (("[") reduce 244) (("`") reduce 244) (("{") reduce 244) (("}") reduce 244) (("~") reduce 244)) 27934 ((("!") reduce 159) (("\"") reduce 159) (("$") reduce 159) (("(") reduce 159) (("+") reduce 159) (("-") reduce 159) ((";") reduce 159) (("@") reduce 159) ((T_ABSTRACT) reduce 159) ((T_ARRAY) reduce 159) ((T_ARRAY_CAST) reduce 159) ((T_ATTRIBUTE) reduce 159) ((T_BOOL_CAST) reduce 159) ((T_BREAK) reduce 159) ((T_CLASS) reduce 159) ((T_CLASS_C) reduce 159) ((T_CLONE) reduce 159) ((T_CONST) reduce 159) ((T_CONSTANT_ENCAPSED_STRING) reduce 159) ((T_CONTINUE) reduce 159) ((T_DEC) reduce 159) ((T_DECLARE) reduce 159) ((T_DIR) reduce 159) ((T_DNUMBER) reduce 159) ((T_DO) reduce 159) ((T_DOUBLE_CAST) reduce 159) ((T_ECHO) reduce 159) ((T_ELSE) reduce 159) ((T_ELSEIF) reduce 159) ((T_EMPTY) reduce 159) ((T_ENUM) reduce 159) ((T_EVAL) reduce 159) ((T_EXIT) reduce 159) ((T_FILE) reduce 159) ((T_FINAL) reduce 159) ((T_FN) reduce 159) ((T_FOR) reduce 159) ((T_FOREACH) reduce 159) ((T_FUNCTION) reduce 159) ((T_FUNC_C) reduce 159) ((T_GLOBAL) reduce 159) ((T_GOTO) reduce 159) ((T_HALT_COMPILER) reduce 159) ((T_IF) reduce 159) ((T_INC) reduce 159) ((T_INCLUDE) reduce 159) ((T_INCLUDE_ONCE) reduce 159) ((T_INLINE_HTML) reduce 159) ((T_INTERFACE) reduce 159) ((T_INT_CAST) reduce 159) ((T_ISSET) reduce 159) ((T_LINE) reduce 159) ((T_LIST) reduce 159) ((T_LNUMBER) reduce 159) ((T_MATCH) reduce 159) ((T_METHOD_C) reduce 159) ((T_NAMESPACE) reduce 159) ((T_NAME_FULLY_QUALIFIED) reduce 159) ((T_NAME_QUALIFIED) reduce 159) ((T_NAME_RELATIVE) reduce 159) ((T_NEW) reduce 159) ((T_NS_C) reduce 159) ((T_OBJECT_CAST) reduce 159) ((T_PRINT) reduce 159) ((T_READONLY) reduce 159) ((T_REQUIRE) reduce 159) ((T_REQUIRE_ONCE) reduce 159) ((T_RETURN) reduce 159) ((T_START_HEREDOC) reduce 159) ((T_STATIC) reduce 159) ((T_STRING) reduce 159) ((T_STRING_CAST) reduce 159) ((T_SWITCH) reduce 159) ((T_THROW) reduce 159) ((T_TRAIT) reduce 159) ((T_TRAIT_C) reduce 159) ((T_TRY) reduce 159) ((T_UNSET) reduce 159) ((T_UNSET_CAST) reduce 159) ((T_USE) reduce 159) ((T_VARIABLE) reduce 159) ((T_WHILE) reduce 159) ((T_YIELD) reduce 159) ((T_YIELD_FROM) reduce 159) (("[") reduce 159) (("`") reduce 159) (("{") reduce 159) (("}") reduce 159) (("~") reduce 159)) 27937 ((("!") reduce 247) (("\"") reduce 247) (("$") reduce 247) (("(") reduce 247) (("+") reduce 247) (("-") reduce 247) ((";") reduce 247) (("@") reduce 247) ((T_ABSTRACT) reduce 247) ((T_ARRAY) reduce 247) ((T_ARRAY_CAST) reduce 247) ((T_ATTRIBUTE) reduce 247) ((T_BOOL_CAST) reduce 247) ((T_BREAK) reduce 247) ((T_CLASS) reduce 247) ((T_CLASS_C) reduce 247) ((T_CLONE) reduce 247) ((T_CONST) reduce 247) ((T_CONSTANT_ENCAPSED_STRING) reduce 247) ((T_CONTINUE) reduce 247) ((T_DEC) reduce 247) ((T_DECLARE) reduce 247) ((T_DIR) reduce 247) ((T_DNUMBER) reduce 247) ((T_DO) reduce 247) ((T_DOUBLE_CAST) reduce 247) ((T_ECHO) reduce 247) ((T_ELSE) reduce 247) ((T_ELSEIF) reduce 247) ((T_EMPTY) reduce 247) ((T_ENUM) reduce 247) ((T_EVAL) reduce 247) ((T_EXIT) reduce 247) ((T_FILE) reduce 247) ((T_FINAL) reduce 247) ((T_FN) reduce 247) ((T_FOR) reduce 247) ((T_FOREACH) reduce 247) ((T_FUNCTION) reduce 247) ((T_FUNC_C) reduce 247) ((T_GLOBAL) reduce 247) ((T_GOTO) reduce 247) ((T_HALT_COMPILER) reduce 247) ((T_IF) reduce 247) ((T_INC) reduce 247) ((T_INCLUDE) reduce 247) ((T_INCLUDE_ONCE) reduce 247) ((T_INLINE_HTML) reduce 247) ((T_INTERFACE) reduce 247) ((T_INT_CAST) reduce 247) ((T_ISSET) reduce 247) ((T_LINE) reduce 247) ((T_LIST) reduce 247) ((T_LNUMBER) reduce 247) ((T_MATCH) reduce 247) ((T_METHOD_C) reduce 247) ((T_NAMESPACE) reduce 247) ((T_NAME_FULLY_QUALIFIED) reduce 247) ((T_NAME_QUALIFIED) reduce 247) ((T_NAME_RELATIVE) reduce 247) ((T_NEW) reduce 247) ((T_NS_C) reduce 247) ((T_OBJECT_CAST) reduce 247) ((T_PRINT) reduce 247) ((T_READONLY) reduce 247) ((T_REQUIRE) reduce 247) ((T_REQUIRE_ONCE) reduce 247) ((T_RETURN) reduce 247) ((T_START_HEREDOC) reduce 247) ((T_STATIC) reduce 247) ((T_STRING) reduce 247) ((T_STRING_CAST) reduce 247) ((T_SWITCH) reduce 247) ((T_THROW) reduce 247) ((T_TRAIT) reduce 247) ((T_TRAIT_C) reduce 247) ((T_TRY) reduce 247) ((T_UNSET) reduce 247) ((T_UNSET_CAST) reduce 247) ((T_USE) reduce 247) ((T_VARIABLE) reduce 247) ((T_WHILE) reduce 247) ((T_YIELD) reduce 247) ((T_YIELD_FROM) reduce 247) (("[") reduce 247) (("`") reduce 247) (("{") reduce 247) (("}") reduce 247) (("~") reduce 247)) 27941 ((("!") reduce 248) (("\"") reduce 248) (("$") reduce 248) (("(") reduce 248) (("+") reduce 248) (("-") reduce 248) ((";") reduce 248) (("@") reduce 248) ((T_ABSTRACT) reduce 248) ((T_ARRAY) reduce 248) ((T_ARRAY_CAST) reduce 248) ((T_ATTRIBUTE) reduce 248) ((T_BOOL_CAST) reduce 248) ((T_BREAK) reduce 248) ((T_CLASS) reduce 248) ((T_CLASS_C) reduce 248) ((T_CLONE) reduce 248) ((T_CONST) reduce 248) ((T_CONSTANT_ENCAPSED_STRING) reduce 248) ((T_CONTINUE) reduce 248) ((T_DEC) reduce 248) ((T_DECLARE) reduce 248) ((T_DIR) reduce 248) ((T_DNUMBER) reduce 248) ((T_DO) reduce 248) ((T_DOUBLE_CAST) reduce 248) ((T_ECHO) reduce 248) ((T_ELSE) reduce 248) ((T_ELSEIF) reduce 248) ((T_EMPTY) reduce 248) ((T_ENUM) reduce 248) ((T_EVAL) reduce 248) ((T_EXIT) reduce 248) ((T_FILE) reduce 248) ((T_FINAL) reduce 248) ((T_FN) reduce 248) ((T_FOR) reduce 248) ((T_FOREACH) reduce 248) ((T_FUNCTION) reduce 248) ((T_FUNC_C) reduce 248) ((T_GLOBAL) reduce 248) ((T_GOTO) reduce 248) ((T_HALT_COMPILER) reduce 248) ((T_IF) reduce 248) ((T_INC) reduce 248) ((T_INCLUDE) reduce 248) ((T_INCLUDE_ONCE) reduce 248) ((T_INLINE_HTML) reduce 248) ((T_INTERFACE) reduce 248) ((T_INT_CAST) reduce 248) ((T_ISSET) reduce 248) ((T_LINE) reduce 248) ((T_LIST) reduce 248) ((T_LNUMBER) reduce 248) ((T_MATCH) reduce 248) ((T_METHOD_C) reduce 248) ((T_NAMESPACE) reduce 248) ((T_NAME_FULLY_QUALIFIED) reduce 248) ((T_NAME_QUALIFIED) reduce 248) ((T_NAME_RELATIVE) reduce 248) ((T_NEW) reduce 248) ((T_NS_C) reduce 248) ((T_OBJECT_CAST) reduce 248) ((T_PRINT) reduce 248) ((T_READONLY) reduce 248) ((T_REQUIRE) reduce 248) ((T_REQUIRE_ONCE) reduce 248) ((T_RETURN) reduce 248) ((T_START_HEREDOC) reduce 248) ((T_STATIC) reduce 248) ((T_STRING) reduce 248) ((T_STRING_CAST) reduce 248) ((T_SWITCH) reduce 248) ((T_THROW) reduce 248) ((T_TRAIT) reduce 248) ((T_TRAIT_C) reduce 248) ((T_TRY) reduce 248) ((T_UNSET) reduce 248) ((T_UNSET_CAST) reduce 248) ((T_USE) reduce 248) ((T_VARIABLE) reduce 248) ((T_WHILE) reduce 248) ((T_YIELD) reduce 248) ((T_YIELD_FROM) reduce 248) (("[") reduce 248) (("`") reduce 248) (("{") reduce 248) (("}") reduce 248) (("~") reduce 248)) 27946 ((("!") reduce 239) (("\"") reduce 239) (("$") reduce 239) (("(") reduce 239) (("+") reduce 239) (("-") reduce 239) ((";") reduce 239) (("@") reduce 239) ((T_ABSTRACT) reduce 239) ((T_ARRAY) reduce 239) ((T_ARRAY_CAST) reduce 239) ((T_ATTRIBUTE) reduce 239) ((T_BOOL_CAST) reduce 239) ((T_BREAK) reduce 239) ((T_CLASS) reduce 239) ((T_CLASS_C) reduce 239) ((T_CLONE) reduce 239) ((T_CONST) reduce 239) ((T_CONSTANT_ENCAPSED_STRING) reduce 239) ((T_CONTINUE) reduce 239) ((T_DEC) reduce 239) ((T_DECLARE) reduce 239) ((T_DIR) reduce 239) ((T_DNUMBER) reduce 239) ((T_DO) reduce 239) ((T_DOUBLE_CAST) reduce 239) ((T_ECHO) reduce 239) ((T_ELSE) reduce 239) ((T_ELSEIF) reduce 239) ((T_EMPTY) reduce 239) ((T_ENUM) reduce 239) ((T_EVAL) reduce 239) ((T_EXIT) reduce 239) ((T_FILE) reduce 239) ((T_FINAL) reduce 239) ((T_FN) reduce 239) ((T_FOR) reduce 239) ((T_FOREACH) reduce 239) ((T_FUNCTION) reduce 239) ((T_FUNC_C) reduce 239) ((T_GLOBAL) reduce 239) ((T_GOTO) reduce 239) ((T_HALT_COMPILER) reduce 239) ((T_IF) reduce 239) ((T_INC) reduce 239) ((T_INCLUDE) reduce 239) ((T_INCLUDE_ONCE) reduce 239) ((T_INLINE_HTML) reduce 239) ((T_INTERFACE) reduce 239) ((T_INT_CAST) reduce 239) ((T_ISSET) reduce 239) ((T_LINE) reduce 239) ((T_LIST) reduce 239) ((T_LNUMBER) reduce 239) ((T_MATCH) reduce 239) ((T_METHOD_C) reduce 239) ((T_NAMESPACE) reduce 239) ((T_NAME_FULLY_QUALIFIED) reduce 239) ((T_NAME_QUALIFIED) reduce 239) ((T_NAME_RELATIVE) reduce 239) ((T_NEW) reduce 239) ((T_NS_C) reduce 239) ((T_OBJECT_CAST) reduce 239) ((T_PRINT) reduce 239) ((T_READONLY) reduce 239) ((T_REQUIRE) reduce 239) ((T_REQUIRE_ONCE) reduce 239) ((T_RETURN) reduce 239) ((T_START_HEREDOC) reduce 239) ((T_STATIC) reduce 239) ((T_STRING) reduce 239) ((T_STRING_CAST) reduce 239) ((T_SWITCH) reduce 239) ((T_THROW) reduce 239) ((T_TRAIT) reduce 239) ((T_TRAIT_C) reduce 239) ((T_TRY) reduce 239) ((T_UNSET) reduce 239) ((T_UNSET_CAST) reduce 239) ((T_USE) reduce 239) ((T_VARIABLE) reduce 239) ((T_WHILE) reduce 239) ((T_YIELD) reduce 239) ((T_YIELD_FROM) reduce 239) (("[") reduce 239) (("`") reduce 239) (("{") reduce 239) (("}") reduce 239) (("~") reduce 239)) 27947 ((("!") reduce 148) (("\"") reduce 148) (("$") reduce 148) (("(") reduce 148) (("+") reduce 148) (("-") reduce 148) ((";") reduce 148) (("@") reduce 148) ((T_ABSTRACT) reduce 148) ((T_ARRAY) reduce 148) ((T_ARRAY_CAST) reduce 148) ((T_ATTRIBUTE) reduce 148) ((T_BOOL_CAST) reduce 148) ((T_BREAK) reduce 148) ((T_CLASS) reduce 148) ((T_CLASS_C) reduce 148) ((T_CLONE) reduce 148) ((T_CONST) reduce 148) ((T_CONSTANT_ENCAPSED_STRING) reduce 148) ((T_CONTINUE) reduce 148) ((T_DEC) reduce 148) ((T_DECLARE) reduce 148) ((T_DIR) reduce 148) ((T_DNUMBER) reduce 148) ((T_DO) reduce 148) ((T_DOUBLE_CAST) reduce 148) ((T_ECHO) reduce 148) ((T_ELSE) reduce 148) ((T_ELSEIF) reduce 148) ((T_EMPTY) reduce 148) ((T_ENUM) reduce 148) ((T_EVAL) reduce 148) ((T_EXIT) reduce 148) ((T_FILE) reduce 148) ((T_FINAL) reduce 148) ((T_FN) reduce 148) ((T_FOR) reduce 148) ((T_FOREACH) reduce 148) ((T_FUNCTION) reduce 148) ((T_FUNC_C) reduce 148) ((T_GLOBAL) reduce 148) ((T_GOTO) reduce 148) ((T_HALT_COMPILER) reduce 148) ((T_IF) reduce 148) ((T_INC) reduce 148) ((T_INCLUDE) reduce 148) ((T_INCLUDE_ONCE) reduce 148) ((T_INLINE_HTML) reduce 148) ((T_INTERFACE) reduce 148) ((T_INT_CAST) reduce 148) ((T_ISSET) reduce 148) ((T_LINE) reduce 148) ((T_LIST) reduce 148) ((T_LNUMBER) reduce 148) ((T_MATCH) reduce 148) ((T_METHOD_C) reduce 148) ((T_NAMESPACE) reduce 148) ((T_NAME_FULLY_QUALIFIED) reduce 148) ((T_NAME_QUALIFIED) reduce 148) ((T_NAME_RELATIVE) reduce 148) ((T_NEW) reduce 148) ((T_NS_C) reduce 148) ((T_OBJECT_CAST) reduce 148) ((T_PRINT) reduce 148) ((T_READONLY) reduce 148) ((T_REQUIRE) reduce 148) ((T_REQUIRE_ONCE) reduce 148) ((T_RETURN) reduce 148) ((T_START_HEREDOC) reduce 148) ((T_STATIC) reduce 148) ((T_STRING) reduce 148) ((T_STRING_CAST) reduce 148) ((T_SWITCH) reduce 148) ((T_THROW) reduce 148) ((T_TRAIT) reduce 148) ((T_TRAIT_C) reduce 148) ((T_TRY) reduce 148) ((T_UNSET) reduce 148) ((T_UNSET_CAST) reduce 148) ((T_USE) reduce 148) ((T_VARIABLE) reduce 148) ((T_WHILE) reduce 148) ((T_YIELD) reduce 148) ((T_YIELD_FROM) reduce 148) (("[") reduce 148) (("`") reduce 148) (("{") reduce 148) (("}") reduce 148) (("~") reduce 148)) 27950 ((("!") reduce 240) (("\"") reduce 240) (("$") reduce 240) (("(") reduce 240) (("+") reduce 240) (("-") reduce 240) ((";") reduce 240) (("@") reduce 240) ((T_ABSTRACT) reduce 240) ((T_ARRAY) reduce 240) ((T_ARRAY_CAST) reduce 240) ((T_ATTRIBUTE) reduce 240) ((T_BOOL_CAST) reduce 240) ((T_BREAK) reduce 240) ((T_CLASS) reduce 240) ((T_CLASS_C) reduce 240) ((T_CLONE) reduce 240) ((T_CONST) reduce 240) ((T_CONSTANT_ENCAPSED_STRING) reduce 240) ((T_CONTINUE) reduce 240) ((T_DEC) reduce 240) ((T_DECLARE) reduce 240) ((T_DIR) reduce 240) ((T_DNUMBER) reduce 240) ((T_DO) reduce 240) ((T_DOUBLE_CAST) reduce 240) ((T_ECHO) reduce 240) ((T_ELSE) reduce 240) ((T_ELSEIF) reduce 240) ((T_EMPTY) reduce 240) ((T_ENUM) reduce 240) ((T_EVAL) reduce 240) ((T_EXIT) reduce 240) ((T_FILE) reduce 240) ((T_FINAL) reduce 240) ((T_FN) reduce 240) ((T_FOR) reduce 240) ((T_FOREACH) reduce 240) ((T_FUNCTION) reduce 240) ((T_FUNC_C) reduce 240) ((T_GLOBAL) reduce 240) ((T_GOTO) reduce 240) ((T_HALT_COMPILER) reduce 240) ((T_IF) reduce 240) ((T_INC) reduce 240) ((T_INCLUDE) reduce 240) ((T_INCLUDE_ONCE) reduce 240) ((T_INLINE_HTML) reduce 240) ((T_INTERFACE) reduce 240) ((T_INT_CAST) reduce 240) ((T_ISSET) reduce 240) ((T_LINE) reduce 240) ((T_LIST) reduce 240) ((T_LNUMBER) reduce 240) ((T_MATCH) reduce 240) ((T_METHOD_C) reduce 240) ((T_NAMESPACE) reduce 240) ((T_NAME_FULLY_QUALIFIED) reduce 240) ((T_NAME_QUALIFIED) reduce 240) ((T_NAME_RELATIVE) reduce 240) ((T_NEW) reduce 240) ((T_NS_C) reduce 240) ((T_OBJECT_CAST) reduce 240) ((T_PRINT) reduce 240) ((T_READONLY) reduce 240) ((T_REQUIRE) reduce 240) ((T_REQUIRE_ONCE) reduce 240) ((T_RETURN) reduce 240) ((T_START_HEREDOC) reduce 240) ((T_STATIC) reduce 240) ((T_STRING) reduce 240) ((T_STRING_CAST) reduce 240) ((T_SWITCH) reduce 240) ((T_THROW) reduce 240) ((T_TRAIT) reduce 240) ((T_TRAIT_C) reduce 240) ((T_TRY) reduce 240) ((T_UNSET) reduce 240) ((T_UNSET_CAST) reduce 240) ((T_USE) reduce 240) ((T_VARIABLE) reduce 240) ((T_WHILE) reduce 240) ((T_YIELD) reduce 240) ((T_YIELD_FROM) reduce 240) (("[") reduce 240) (("`") reduce 240) (("{") reduce 240) (("}") reduce 240) (("~") reduce 240)) 27955 ((("!") reduce 160) (("\"") reduce 160) (("$") reduce 160) (("(") reduce 160) (("+") reduce 160) (("-") reduce 160) ((";") reduce 160) (("@") reduce 160) ((T_ABSTRACT) reduce 160) ((T_ARRAY) reduce 160) ((T_ARRAY_CAST) reduce 160) ((T_ATTRIBUTE) reduce 160) ((T_BOOL_CAST) reduce 160) ((T_BREAK) reduce 160) ((T_CLASS) reduce 160) ((T_CLASS_C) reduce 160) ((T_CLONE) reduce 160) ((T_CONST) reduce 160) ((T_CONSTANT_ENCAPSED_STRING) reduce 160) ((T_CONTINUE) reduce 160) ((T_DEC) reduce 160) ((T_DECLARE) reduce 160) ((T_DIR) reduce 160) ((T_DNUMBER) reduce 160) ((T_DO) reduce 160) ((T_DOUBLE_CAST) reduce 160) ((T_ECHO) reduce 160) ((T_ELSE) reduce 160) ((T_ELSEIF) reduce 160) ((T_EMPTY) reduce 160) ((T_ENUM) reduce 160) ((T_EVAL) reduce 160) ((T_EXIT) reduce 160) ((T_FILE) reduce 160) ((T_FINAL) reduce 160) ((T_FN) reduce 160) ((T_FOR) reduce 160) ((T_FOREACH) reduce 160) ((T_FUNCTION) reduce 160) ((T_FUNC_C) reduce 160) ((T_GLOBAL) reduce 160) ((T_GOTO) reduce 160) ((T_HALT_COMPILER) reduce 160) ((T_IF) reduce 160) ((T_INC) reduce 160) ((T_INCLUDE) reduce 160) ((T_INCLUDE_ONCE) reduce 160) ((T_INLINE_HTML) reduce 160) ((T_INTERFACE) reduce 160) ((T_INT_CAST) reduce 160) ((T_ISSET) reduce 160) ((T_LINE) reduce 160) ((T_LIST) reduce 160) ((T_LNUMBER) reduce 160) ((T_MATCH) reduce 160) ((T_METHOD_C) reduce 160) ((T_NAMESPACE) reduce 160) ((T_NAME_FULLY_QUALIFIED) reduce 160) ((T_NAME_QUALIFIED) reduce 160) ((T_NAME_RELATIVE) reduce 160) ((T_NEW) reduce 160) ((T_NS_C) reduce 160) ((T_OBJECT_CAST) reduce 160) ((T_PRINT) reduce 160) ((T_READONLY) reduce 160) ((T_REQUIRE) reduce 160) ((T_REQUIRE_ONCE) reduce 160) ((T_RETURN) reduce 160) ((T_START_HEREDOC) reduce 160) ((T_STATIC) reduce 160) ((T_STRING) reduce 160) ((T_STRING_CAST) reduce 160) ((T_SWITCH) reduce 160) ((T_THROW) reduce 160) ((T_TRAIT) reduce 160) ((T_TRAIT_C) reduce 160) ((T_TRY) reduce 160) ((T_UNSET) reduce 160) ((T_UNSET_CAST) reduce 160) ((T_USE) reduce 160) ((T_VARIABLE) reduce 160) ((T_WHILE) reduce 160) ((T_YIELD) reduce 160) ((T_YIELD_FROM) reduce 160) (("[") reduce 160) (("`") reduce 160) (("{") reduce 160) (("}") reduce 160) (("~") reduce 160)) 27958 ((("!") reduce 168) (("\"") reduce 168) (("$") reduce 168) (("(") reduce 168) (("+") reduce 168) (("-") reduce 168) ((";") reduce 168) (("@") reduce 168) ((T_ABSTRACT) reduce 168) ((T_ARRAY) reduce 168) ((T_ARRAY_CAST) reduce 168) ((T_ATTRIBUTE) reduce 168) ((T_BOOL_CAST) reduce 168) ((T_BREAK) reduce 168) ((T_CATCH) reduce 168) ((T_CLASS) reduce 168) ((T_CLASS_C) reduce 168) ((T_CLONE) reduce 168) ((T_CONST) reduce 168) ((T_CONSTANT_ENCAPSED_STRING) reduce 168) ((T_CONTINUE) reduce 168) ((T_DEC) reduce 168) ((T_DECLARE) reduce 168) ((T_DIR) reduce 168) ((T_DNUMBER) reduce 168) ((T_DO) reduce 168) ((T_DOUBLE_CAST) reduce 168) ((T_ECHO) reduce 168) ((T_ELSE) reduce 168) ((T_ELSEIF) reduce 168) ((T_EMPTY) reduce 168) ((T_ENUM) reduce 168) ((T_EVAL) reduce 168) ((T_EXIT) reduce 168) ((T_FILE) reduce 168) ((T_FINAL) reduce 168) ((T_FINALLY) reduce 168) ((T_FN) reduce 168) ((T_FOR) reduce 168) ((T_FOREACH) reduce 168) ((T_FUNCTION) reduce 168) ((T_FUNC_C) reduce 168) ((T_GLOBAL) reduce 168) ((T_GOTO) reduce 168) ((T_HALT_COMPILER) reduce 168) ((T_IF) reduce 168) ((T_INC) reduce 168) ((T_INCLUDE) reduce 168) ((T_INCLUDE_ONCE) reduce 168) ((T_INLINE_HTML) reduce 168) ((T_INTERFACE) reduce 168) ((T_INT_CAST) reduce 168) ((T_ISSET) reduce 168) ((T_LINE) reduce 168) ((T_LIST) reduce 168) ((T_LNUMBER) reduce 168) ((T_MATCH) reduce 168) ((T_METHOD_C) reduce 168) ((T_NAMESPACE) reduce 168) ((T_NAME_FULLY_QUALIFIED) reduce 168) ((T_NAME_QUALIFIED) reduce 168) ((T_NAME_RELATIVE) reduce 168) ((T_NEW) reduce 168) ((T_NS_C) reduce 168) ((T_OBJECT_CAST) reduce 168) ((T_PRINT) reduce 168) ((T_READONLY) reduce 168) ((T_REQUIRE) reduce 168) ((T_REQUIRE_ONCE) reduce 168) ((T_RETURN) reduce 168) ((T_START_HEREDOC) reduce 168) ((T_STATIC) reduce 168) ((T_STRING) reduce 168) ((T_STRING_CAST) reduce 168) ((T_SWITCH) reduce 168) ((T_THROW) reduce 168) ((T_TRAIT) reduce 168) ((T_TRAIT_C) reduce 168) ((T_TRY) reduce 168) ((T_UNSET) reduce 168) ((T_UNSET_CAST) reduce 168) ((T_USE) reduce 168) ((T_VARIABLE) reduce 168) ((T_WHILE) reduce 168) ((T_YIELD) reduce 168) ((T_YIELD_FROM) reduce 168) (("[") reduce 168) (("`") reduce 168) (("{") reduce 168) (("}") reduce 168) (("~") reduce 168)) 27959 ((("!") reduce 174) (("\"") reduce 174) (("$") reduce 174) (("(") reduce 174) (("+") reduce 174) (("-") reduce 174) ((";") reduce 174) (("@") reduce 174) ((T_ABSTRACT) reduce 174) ((T_ARRAY) reduce 174) ((T_ARRAY_CAST) reduce 174) ((T_ATTRIBUTE) reduce 174) ((T_BOOL_CAST) reduce 174) ((T_BREAK) reduce 174) ((T_CATCH) shift) ((T_CLASS) reduce 174) ((T_CLASS_C) reduce 174) ((T_CLONE) reduce 174) ((T_CONST) reduce 174) ((T_CONSTANT_ENCAPSED_STRING) reduce 174) ((T_CONTINUE) reduce 174) ((T_DEC) reduce 174) ((T_DECLARE) reduce 174) ((T_DIR) reduce 174) ((T_DNUMBER) reduce 174) ((T_DO) reduce 174) ((T_DOUBLE_CAST) reduce 174) ((T_ECHO) reduce 174) ((T_ELSE) reduce 174) ((T_ELSEIF) reduce 174) ((T_EMPTY) reduce 174) ((T_ENUM) reduce 174) ((T_EVAL) reduce 174) ((T_EXIT) reduce 174) ((T_FILE) reduce 174) ((T_FINAL) reduce 174) ((T_FINALLY) shift) ((T_FN) reduce 174) ((T_FOR) reduce 174) ((T_FOREACH) reduce 174) ((T_FUNCTION) reduce 174) ((T_FUNC_C) reduce 174) ((T_GLOBAL) reduce 174) ((T_GOTO) reduce 174) ((T_HALT_COMPILER) reduce 174) ((T_IF) reduce 174) ((T_INC) reduce 174) ((T_INCLUDE) reduce 174) ((T_INCLUDE_ONCE) reduce 174) ((T_INLINE_HTML) reduce 174) ((T_INTERFACE) reduce 174) ((T_INT_CAST) reduce 174) ((T_ISSET) reduce 174) ((T_LINE) reduce 174) ((T_LIST) reduce 174) ((T_LNUMBER) reduce 174) ((T_MATCH) reduce 174) ((T_METHOD_C) reduce 174) ((T_NAMESPACE) reduce 174) ((T_NAME_FULLY_QUALIFIED) reduce 174) ((T_NAME_QUALIFIED) reduce 174) ((T_NAME_RELATIVE) reduce 174) ((T_NEW) reduce 174) ((T_NS_C) reduce 174) ((T_OBJECT_CAST) reduce 174) ((T_PRINT) reduce 174) ((T_READONLY) reduce 174) ((T_REQUIRE) reduce 174) ((T_REQUIRE_ONCE) reduce 174) ((T_RETURN) reduce 174) ((T_START_HEREDOC) reduce 174) ((T_STATIC) reduce 174) ((T_STRING) reduce 174) ((T_STRING_CAST) reduce 174) ((T_SWITCH) reduce 174) ((T_THROW) reduce 174) ((T_TRAIT) reduce 174) ((T_TRAIT_C) reduce 174) ((T_TRY) reduce 174) ((T_UNSET) reduce 174) ((T_UNSET_CAST) reduce 174) ((T_USE) reduce 174) ((T_VARIABLE) reduce 174) ((T_WHILE) reduce 174) ((T_YIELD) reduce 174) ((T_YIELD_FROM) reduce 174) (("[") reduce 174) (("`") reduce 174) (("{") reduce 174) (("}") reduce 174) (("~") reduce 174)) 27962 ((("!") reduce 165) (("\"") reduce 165) (("$") reduce 165) (("(") reduce 165) (("+") reduce 165) (("-") reduce 165) ((";") reduce 165) (("@") reduce 165) ((T_ABSTRACT) reduce 165) ((T_ARRAY) reduce 165) ((T_ARRAY_CAST) reduce 165) ((T_ATTRIBUTE) reduce 165) ((T_BOOL_CAST) reduce 165) ((T_BREAK) reduce 165) ((T_CLASS) reduce 165) ((T_CLASS_C) reduce 165) ((T_CLONE) reduce 165) ((T_CONST) reduce 165) ((T_CONSTANT_ENCAPSED_STRING) reduce 165) ((T_CONTINUE) reduce 165) ((T_DEC) reduce 165) ((T_DECLARE) reduce 165) ((T_DIR) reduce 165) ((T_DNUMBER) reduce 165) ((T_DO) reduce 165) ((T_DOUBLE_CAST) reduce 165) ((T_ECHO) reduce 165) ((T_ELSE) reduce 165) ((T_ELSEIF) reduce 165) ((T_EMPTY) reduce 165) ((T_ENUM) reduce 165) ((T_EVAL) reduce 165) ((T_EXIT) reduce 165) ((T_FILE) reduce 165) ((T_FINAL) reduce 165) ((T_FN) reduce 165) ((T_FOR) reduce 165) ((T_FOREACH) reduce 165) ((T_FUNCTION) reduce 165) ((T_FUNC_C) reduce 165) ((T_GLOBAL) reduce 165) ((T_GOTO) reduce 165) ((T_HALT_COMPILER) reduce 165) ((T_IF) reduce 165) ((T_INC) reduce 165) ((T_INCLUDE) reduce 165) ((T_INCLUDE_ONCE) reduce 165) ((T_INLINE_HTML) reduce 165) ((T_INTERFACE) reduce 165) ((T_INT_CAST) reduce 165) ((T_ISSET) reduce 165) ((T_LINE) reduce 165) ((T_LIST) reduce 165) ((T_LNUMBER) reduce 165) ((T_MATCH) reduce 165) ((T_METHOD_C) reduce 165) ((T_NAMESPACE) reduce 165) ((T_NAME_FULLY_QUALIFIED) reduce 165) ((T_NAME_QUALIFIED) reduce 165) ((T_NAME_RELATIVE) reduce 165) ((T_NEW) reduce 165) ((T_NS_C) reduce 165) ((T_OBJECT_CAST) reduce 165) ((T_PRINT) reduce 165) ((T_READONLY) reduce 165) ((T_REQUIRE) reduce 165) ((T_REQUIRE_ONCE) reduce 165) ((T_RETURN) reduce 165) ((T_START_HEREDOC) reduce 165) ((T_STATIC) reduce 165) ((T_STRING) reduce 165) ((T_STRING_CAST) reduce 165) ((T_SWITCH) reduce 165) ((T_THROW) reduce 165) ((T_TRAIT) reduce 165) ((T_TRAIT_C) reduce 165) ((T_TRY) reduce 165) ((T_UNSET) reduce 165) ((T_UNSET_CAST) reduce 165) ((T_USE) reduce 165) ((T_VARIABLE) reduce 165) ((T_WHILE) reduce 165) ((T_YIELD) reduce 165) ((T_YIELD_FROM) reduce 165) (("[") reduce 165) (("`") reduce 165) (("{") reduce 165) (("}") reduce 165) (("~") reduce 165)) 27965 ((("!") reduce 175) (("\"") reduce 175) (("$") reduce 175) (("(") reduce 175) (("+") reduce 175) (("-") reduce 175) ((";") reduce 175) (("@") reduce 175) ((T_ABSTRACT) reduce 175) ((T_ARRAY) reduce 175) ((T_ARRAY_CAST) reduce 175) ((T_ATTRIBUTE) reduce 175) ((T_BOOL_CAST) reduce 175) ((T_BREAK) reduce 175) ((T_CLASS) reduce 175) ((T_CLASS_C) reduce 175) ((T_CLONE) reduce 175) ((T_CONST) reduce 175) ((T_CONSTANT_ENCAPSED_STRING) reduce 175) ((T_CONTINUE) reduce 175) ((T_DEC) reduce 175) ((T_DECLARE) reduce 175) ((T_DIR) reduce 175) ((T_DNUMBER) reduce 175) ((T_DO) reduce 175) ((T_DOUBLE_CAST) reduce 175) ((T_ECHO) reduce 175) ((T_ELSE) reduce 175) ((T_ELSEIF) reduce 175) ((T_EMPTY) reduce 175) ((T_ENUM) reduce 175) ((T_EVAL) reduce 175) ((T_EXIT) reduce 175) ((T_FILE) reduce 175) ((T_FINAL) reduce 175) ((T_FN) reduce 175) ((T_FOR) reduce 175) ((T_FOREACH) reduce 175) ((T_FUNCTION) reduce 175) ((T_FUNC_C) reduce 175) ((T_GLOBAL) reduce 175) ((T_GOTO) reduce 175) ((T_HALT_COMPILER) reduce 175) ((T_IF) reduce 175) ((T_INC) reduce 175) ((T_INCLUDE) reduce 175) ((T_INCLUDE_ONCE) reduce 175) ((T_INLINE_HTML) reduce 175) ((T_INTERFACE) reduce 175) ((T_INT_CAST) reduce 175) ((T_ISSET) reduce 175) ((T_LINE) reduce 175) ((T_LIST) reduce 175) ((T_LNUMBER) reduce 175) ((T_MATCH) reduce 175) ((T_METHOD_C) reduce 175) ((T_NAMESPACE) reduce 175) ((T_NAME_FULLY_QUALIFIED) reduce 175) ((T_NAME_QUALIFIED) reduce 175) ((T_NAME_RELATIVE) reduce 175) ((T_NEW) reduce 175) ((T_NS_C) reduce 175) ((T_OBJECT_CAST) reduce 175) ((T_PRINT) reduce 175) ((T_READONLY) reduce 175) ((T_REQUIRE) reduce 175) ((T_REQUIRE_ONCE) reduce 175) ((T_RETURN) reduce 175) ((T_START_HEREDOC) reduce 175) ((T_STATIC) reduce 175) ((T_STRING) reduce 175) ((T_STRING_CAST) reduce 175) ((T_SWITCH) reduce 175) ((T_THROW) reduce 175) ((T_TRAIT) reduce 175) ((T_TRAIT_C) reduce 175) ((T_TRY) reduce 175) ((T_UNSET) reduce 175) ((T_UNSET_CAST) reduce 175) ((T_USE) reduce 175) ((T_VARIABLE) reduce 175) ((T_WHILE) reduce 175) ((T_YIELD) reduce 175) ((T_YIELD_FROM) reduce 175) (("[") reduce 175) (("`") reduce 175) (("{") reduce 175) (("}") reduce 175) (("~") reduce 175)) 27972 ((("!") reduce 169) (("\"") reduce 169) (("$") reduce 169) (("(") reduce 169) (("+") reduce 169) (("-") reduce 169) ((";") reduce 169) (("@") reduce 169) ((T_ABSTRACT) reduce 169) ((T_ARRAY) reduce 169) ((T_ARRAY_CAST) reduce 169) ((T_ATTRIBUTE) reduce 169) ((T_BOOL_CAST) reduce 169) ((T_BREAK) reduce 169) ((T_CATCH) reduce 169) ((T_CLASS) reduce 169) ((T_CLASS_C) reduce 169) ((T_CLONE) reduce 169) ((T_CONST) reduce 169) ((T_CONSTANT_ENCAPSED_STRING) reduce 169) ((T_CONTINUE) reduce 169) ((T_DEC) reduce 169) ((T_DECLARE) reduce 169) ((T_DIR) reduce 169) ((T_DNUMBER) reduce 169) ((T_DO) reduce 169) ((T_DOUBLE_CAST) reduce 169) ((T_ECHO) reduce 169) ((T_ELSE) reduce 169) ((T_ELSEIF) reduce 169) ((T_EMPTY) reduce 169) ((T_ENUM) reduce 169) ((T_EVAL) reduce 169) ((T_EXIT) reduce 169) ((T_FILE) reduce 169) ((T_FINAL) reduce 169) ((T_FINALLY) reduce 169) ((T_FN) reduce 169) ((T_FOR) reduce 169) ((T_FOREACH) reduce 169) ((T_FUNCTION) reduce 169) ((T_FUNC_C) reduce 169) ((T_GLOBAL) reduce 169) ((T_GOTO) reduce 169) ((T_HALT_COMPILER) reduce 169) ((T_IF) reduce 169) ((T_INC) reduce 169) ((T_INCLUDE) reduce 169) ((T_INCLUDE_ONCE) reduce 169) ((T_INLINE_HTML) reduce 169) ((T_INTERFACE) reduce 169) ((T_INT_CAST) reduce 169) ((T_ISSET) reduce 169) ((T_LINE) reduce 169) ((T_LIST) reduce 169) ((T_LNUMBER) reduce 169) ((T_MATCH) reduce 169) ((T_METHOD_C) reduce 169) ((T_NAMESPACE) reduce 169) ((T_NAME_FULLY_QUALIFIED) reduce 169) ((T_NAME_QUALIFIED) reduce 169) ((T_NAME_RELATIVE) reduce 169) ((T_NEW) reduce 169) ((T_NS_C) reduce 169) ((T_OBJECT_CAST) reduce 169) ((T_PRINT) reduce 169) ((T_READONLY) reduce 169) ((T_REQUIRE) reduce 169) ((T_REQUIRE_ONCE) reduce 169) ((T_RETURN) reduce 169) ((T_START_HEREDOC) reduce 169) ((T_STATIC) reduce 169) ((T_STRING) reduce 169) ((T_STRING_CAST) reduce 169) ((T_SWITCH) reduce 169) ((T_THROW) reduce 169) ((T_TRAIT) reduce 169) ((T_TRAIT_C) reduce 169) ((T_TRY) reduce 169) ((T_UNSET) reduce 169) ((T_UNSET_CAST) reduce 169) ((T_USE) reduce 169) ((T_VARIABLE) reduce 169) ((T_WHILE) reduce 169) ((T_YIELD) reduce 169) ((T_YIELD_FROM) reduce 169) (("[") reduce 169) (("`") reduce 169) (("{") reduce 169) (("}") reduce 169) (("~") reduce 169)) 27977 ((("!") reduce 151) (("\"") reduce 151) (("$") reduce 151) (("(") reduce 151) (("+") reduce 151) (("-") reduce 151) ((";") reduce 151) (("@") reduce 151) ((T_ABSTRACT) reduce 151) ((T_ARRAY) reduce 151) ((T_ARRAY_CAST) reduce 151) ((T_ATTRIBUTE) reduce 151) ((T_BOOL_CAST) reduce 151) ((T_BREAK) reduce 151) ((T_CLASS) reduce 151) ((T_CLASS_C) reduce 151) ((T_CLONE) reduce 151) ((T_CONST) reduce 151) ((T_CONSTANT_ENCAPSED_STRING) reduce 151) ((T_CONTINUE) reduce 151) ((T_DEC) reduce 151) ((T_DECLARE) reduce 151) ((T_DIR) reduce 151) ((T_DNUMBER) reduce 151) ((T_DO) reduce 151) ((T_DOUBLE_CAST) reduce 151) ((T_ECHO) reduce 151) ((T_ELSE) reduce 151) ((T_ELSEIF) reduce 151) ((T_EMPTY) reduce 151) ((T_ENUM) reduce 151) ((T_EVAL) reduce 151) ((T_EXIT) reduce 151) ((T_FILE) reduce 151) ((T_FINAL) reduce 151) ((T_FN) reduce 151) ((T_FOR) reduce 151) ((T_FOREACH) reduce 151) ((T_FUNCTION) reduce 151) ((T_FUNC_C) reduce 151) ((T_GLOBAL) reduce 151) ((T_GOTO) reduce 151) ((T_HALT_COMPILER) reduce 151) ((T_IF) reduce 151) ((T_INC) reduce 151) ((T_INCLUDE) reduce 151) ((T_INCLUDE_ONCE) reduce 151) ((T_INLINE_HTML) reduce 151) ((T_INTERFACE) reduce 151) ((T_INT_CAST) reduce 151) ((T_ISSET) reduce 151) ((T_LINE) reduce 151) ((T_LIST) reduce 151) ((T_LNUMBER) reduce 151) ((T_MATCH) reduce 151) ((T_METHOD_C) reduce 151) ((T_NAMESPACE) reduce 151) ((T_NAME_FULLY_QUALIFIED) reduce 151) ((T_NAME_QUALIFIED) reduce 151) ((T_NAME_RELATIVE) reduce 151) ((T_NEW) reduce 151) ((T_NS_C) reduce 151) ((T_OBJECT_CAST) reduce 151) ((T_PRINT) reduce 151) ((T_READONLY) reduce 151) ((T_REQUIRE) reduce 151) ((T_REQUIRE_ONCE) reduce 151) ((T_RETURN) reduce 151) ((T_START_HEREDOC) reduce 151) ((T_STATIC) reduce 151) ((T_STRING) reduce 151) ((T_STRING_CAST) reduce 151) ((T_SWITCH) reduce 151) ((T_THROW) reduce 151) ((T_TRAIT) reduce 151) ((T_TRAIT_C) reduce 151) ((T_TRY) reduce 151) ((T_UNSET) reduce 151) ((T_UNSET_CAST) reduce 151) ((T_USE) reduce 151) ((T_VARIABLE) reduce 151) ((T_WHILE) reduce 151) ((T_YIELD) reduce 151) ((T_YIELD_FROM) reduce 151) (("[") reduce 151) (("`") reduce 151) (("{") reduce 151) (("}") reduce 151) (("~") reduce 151)) 27981 ((("!") reduce 221) (("\"") reduce 221) (("$") reduce 221) (("(") reduce 221) (("+") reduce 221) (("-") reduce 221) ((";") reduce 221) (("@") reduce 221) ((T_ABSTRACT) reduce 221) ((T_ARRAY) reduce 221) ((T_ARRAY_CAST) reduce 221) ((T_ATTRIBUTE) reduce 221) ((T_BOOL_CAST) reduce 221) ((T_BREAK) reduce 221) ((T_CLASS) reduce 221) ((T_CLASS_C) reduce 221) ((T_CLONE) reduce 221) ((T_CONST) reduce 221) ((T_CONSTANT_ENCAPSED_STRING) reduce 221) ((T_CONTINUE) reduce 221) ((T_DEC) reduce 221) ((T_DECLARE) reduce 221) ((T_DIR) reduce 221) ((T_DNUMBER) reduce 221) ((T_DO) reduce 221) ((T_DOUBLE_CAST) reduce 221) ((T_ECHO) reduce 221) ((T_ELSE) reduce 221) ((T_ELSEIF) reduce 221) ((T_EMPTY) reduce 221) ((T_ENUM) reduce 221) ((T_EVAL) reduce 221) ((T_EXIT) reduce 221) ((T_FILE) reduce 221) ((T_FINAL) reduce 221) ((T_FN) reduce 221) ((T_FOR) reduce 221) ((T_FOREACH) reduce 221) ((T_FUNCTION) reduce 221) ((T_FUNC_C) reduce 221) ((T_GLOBAL) reduce 221) ((T_GOTO) reduce 221) ((T_HALT_COMPILER) reduce 221) ((T_IF) reduce 221) ((T_INC) reduce 221) ((T_INCLUDE) reduce 221) ((T_INCLUDE_ONCE) reduce 221) ((T_INLINE_HTML) reduce 221) ((T_INTERFACE) reduce 221) ((T_INT_CAST) reduce 221) ((T_ISSET) reduce 221) ((T_LINE) reduce 221) ((T_LIST) reduce 221) ((T_LNUMBER) reduce 221) ((T_MATCH) reduce 221) ((T_METHOD_C) reduce 221) ((T_NAMESPACE) reduce 221) ((T_NAME_FULLY_QUALIFIED) reduce 221) ((T_NAME_QUALIFIED) reduce 221) ((T_NAME_RELATIVE) reduce 221) ((T_NEW) reduce 221) ((T_NS_C) reduce 221) ((T_OBJECT_CAST) reduce 221) ((T_PRINT) reduce 221) ((T_READONLY) reduce 221) ((T_REQUIRE) reduce 221) ((T_REQUIRE_ONCE) reduce 221) ((T_RETURN) reduce 221) ((T_START_HEREDOC) reduce 221) ((T_STATIC) reduce 221) ((T_STRING) reduce 221) ((T_STRING_CAST) reduce 221) ((T_SWITCH) reduce 221) ((T_THROW) reduce 221) ((T_TRAIT) reduce 221) ((T_TRAIT_C) reduce 221) ((T_TRY) reduce 221) ((T_UNSET) reduce 221) ((T_UNSET_CAST) reduce 221) ((T_USE) reduce 221) ((T_VARIABLE) reduce 221) ((T_WHILE) reduce 221) ((T_YIELD) reduce 221) ((T_YIELD_FROM) reduce 221) (("[") reduce 221) (("`") reduce 221) (("{") reduce 221) (("}") reduce 221) (("~") reduce 221)) 27983 ((("!") reduce 222) (("\"") reduce 222) (("$") reduce 222) (("(") reduce 222) (("+") reduce 222) (("-") reduce 222) ((";") reduce 222) (("@") reduce 222) ((T_ABSTRACT) reduce 222) ((T_ARRAY) reduce 222) ((T_ARRAY_CAST) reduce 222) ((T_ATTRIBUTE) reduce 222) ((T_BOOL_CAST) reduce 222) ((T_BREAK) reduce 222) ((T_CLASS) reduce 222) ((T_CLASS_C) reduce 222) ((T_CLONE) reduce 222) ((T_CONST) reduce 222) ((T_CONSTANT_ENCAPSED_STRING) reduce 222) ((T_CONTINUE) reduce 222) ((T_DEC) reduce 222) ((T_DECLARE) reduce 222) ((T_DIR) reduce 222) ((T_DNUMBER) reduce 222) ((T_DO) reduce 222) ((T_DOUBLE_CAST) reduce 222) ((T_ECHO) reduce 222) ((T_ELSE) reduce 222) ((T_ELSEIF) reduce 222) ((T_EMPTY) reduce 222) ((T_ENUM) reduce 222) ((T_EVAL) reduce 222) ((T_EXIT) reduce 222) ((T_FILE) reduce 222) ((T_FINAL) reduce 222) ((T_FN) reduce 222) ((T_FOR) reduce 222) ((T_FOREACH) reduce 222) ((T_FUNCTION) reduce 222) ((T_FUNC_C) reduce 222) ((T_GLOBAL) reduce 222) ((T_GOTO) reduce 222) ((T_HALT_COMPILER) reduce 222) ((T_IF) reduce 222) ((T_INC) reduce 222) ((T_INCLUDE) reduce 222) ((T_INCLUDE_ONCE) reduce 222) ((T_INLINE_HTML) reduce 222) ((T_INTERFACE) reduce 222) ((T_INT_CAST) reduce 222) ((T_ISSET) reduce 222) ((T_LINE) reduce 222) ((T_LIST) reduce 222) ((T_LNUMBER) reduce 222) ((T_MATCH) reduce 222) ((T_METHOD_C) reduce 222) ((T_NAMESPACE) reduce 222) ((T_NAME_FULLY_QUALIFIED) reduce 222) ((T_NAME_QUALIFIED) reduce 222) ((T_NAME_RELATIVE) reduce 222) ((T_NEW) reduce 222) ((T_NS_C) reduce 222) ((T_OBJECT_CAST) reduce 222) ((T_PRINT) reduce 222) ((T_READONLY) reduce 222) ((T_REQUIRE) reduce 222) ((T_REQUIRE_ONCE) reduce 222) ((T_RETURN) reduce 222) ((T_START_HEREDOC) reduce 222) ((T_STATIC) reduce 222) ((T_STRING) reduce 222) ((T_STRING_CAST) reduce 222) ((T_SWITCH) reduce 222) ((T_THROW) reduce 222) ((T_TRAIT) reduce 222) ((T_TRAIT_C) reduce 222) ((T_TRY) reduce 222) ((T_UNSET) reduce 222) ((T_UNSET_CAST) reduce 222) ((T_USE) reduce 222) ((T_VARIABLE) reduce 222) ((T_WHILE) reduce 222) ((T_YIELD) reduce 222) ((T_YIELD_FROM) reduce 222) (("[") reduce 222) (("`") reduce 222) (("{") reduce 222) (("}") reduce 222) (("~") reduce 222)) 27987 ((("!") reduce 223) (("\"") reduce 223) (("$") reduce 223) (("(") reduce 223) (("+") reduce 223) (("-") reduce 223) ((";") reduce 223) (("@") reduce 223) ((T_ABSTRACT) reduce 223) ((T_ARRAY) reduce 223) ((T_ARRAY_CAST) reduce 223) ((T_ATTRIBUTE) reduce 223) ((T_BOOL_CAST) reduce 223) ((T_BREAK) reduce 223) ((T_CLASS) reduce 223) ((T_CLASS_C) reduce 223) ((T_CLONE) reduce 223) ((T_CONST) reduce 223) ((T_CONSTANT_ENCAPSED_STRING) reduce 223) ((T_CONTINUE) reduce 223) ((T_DEC) reduce 223) ((T_DECLARE) reduce 223) ((T_DIR) reduce 223) ((T_DNUMBER) reduce 223) ((T_DO) reduce 223) ((T_DOUBLE_CAST) reduce 223) ((T_ECHO) reduce 223) ((T_ELSE) reduce 223) ((T_ELSEIF) reduce 223) ((T_EMPTY) reduce 223) ((T_ENUM) reduce 223) ((T_EVAL) reduce 223) ((T_EXIT) reduce 223) ((T_FILE) reduce 223) ((T_FINAL) reduce 223) ((T_FN) reduce 223) ((T_FOR) reduce 223) ((T_FOREACH) reduce 223) ((T_FUNCTION) reduce 223) ((T_FUNC_C) reduce 223) ((T_GLOBAL) reduce 223) ((T_GOTO) reduce 223) ((T_HALT_COMPILER) reduce 223) ((T_IF) reduce 223) ((T_INC) reduce 223) ((T_INCLUDE) reduce 223) ((T_INCLUDE_ONCE) reduce 223) ((T_INLINE_HTML) reduce 223) ((T_INTERFACE) reduce 223) ((T_INT_CAST) reduce 223) ((T_ISSET) reduce 223) ((T_LINE) reduce 223) ((T_LIST) reduce 223) ((T_LNUMBER) reduce 223) ((T_MATCH) reduce 223) ((T_METHOD_C) reduce 223) ((T_NAMESPACE) reduce 223) ((T_NAME_FULLY_QUALIFIED) reduce 223) ((T_NAME_QUALIFIED) reduce 223) ((T_NAME_RELATIVE) reduce 223) ((T_NEW) reduce 223) ((T_NS_C) reduce 223) ((T_OBJECT_CAST) reduce 223) ((T_PRINT) reduce 223) ((T_READONLY) reduce 223) ((T_REQUIRE) reduce 223) ((T_REQUIRE_ONCE) reduce 223) ((T_RETURN) reduce 223) ((T_START_HEREDOC) reduce 223) ((T_STATIC) reduce 223) ((T_STRING) reduce 223) ((T_STRING_CAST) reduce 223) ((T_SWITCH) reduce 223) ((T_THROW) reduce 223) ((T_TRAIT) reduce 223) ((T_TRAIT_C) reduce 223) ((T_TRY) reduce 223) ((T_UNSET) reduce 223) ((T_UNSET_CAST) reduce 223) ((T_USE) reduce 223) ((T_VARIABLE) reduce 223) ((T_WHILE) reduce 223) ((T_YIELD) reduce 223) ((T_YIELD_FROM) reduce 223) (("[") reduce 223) (("`") reduce 223) (("{") reduce 223) (("}") reduce 223) (("~") reduce 223)) 27990 ((("!") reduce 224) (("\"") reduce 224) (("$") reduce 224) (("(") reduce 224) (("+") reduce 224) (("-") reduce 224) ((";") reduce 224) (("@") reduce 224) ((T_ABSTRACT) reduce 224) ((T_ARRAY) reduce 224) ((T_ARRAY_CAST) reduce 224) ((T_ATTRIBUTE) reduce 224) ((T_BOOL_CAST) reduce 224) ((T_BREAK) reduce 224) ((T_CLASS) reduce 224) ((T_CLASS_C) reduce 224) ((T_CLONE) reduce 224) ((T_CONST) reduce 224) ((T_CONSTANT_ENCAPSED_STRING) reduce 224) ((T_CONTINUE) reduce 224) ((T_DEC) reduce 224) ((T_DECLARE) reduce 224) ((T_DIR) reduce 224) ((T_DNUMBER) reduce 224) ((T_DO) reduce 224) ((T_DOUBLE_CAST) reduce 224) ((T_ECHO) reduce 224) ((T_ELSE) reduce 224) ((T_ELSEIF) reduce 224) ((T_EMPTY) reduce 224) ((T_ENUM) reduce 224) ((T_EVAL) reduce 224) ((T_EXIT) reduce 224) ((T_FILE) reduce 224) ((T_FINAL) reduce 224) ((T_FN) reduce 224) ((T_FOR) reduce 224) ((T_FOREACH) reduce 224) ((T_FUNCTION) reduce 224) ((T_FUNC_C) reduce 224) ((T_GLOBAL) reduce 224) ((T_GOTO) reduce 224) ((T_HALT_COMPILER) reduce 224) ((T_IF) reduce 224) ((T_INC) reduce 224) ((T_INCLUDE) reduce 224) ((T_INCLUDE_ONCE) reduce 224) ((T_INLINE_HTML) reduce 224) ((T_INTERFACE) reduce 224) ((T_INT_CAST) reduce 224) ((T_ISSET) reduce 224) ((T_LINE) reduce 224) ((T_LIST) reduce 224) ((T_LNUMBER) reduce 224) ((T_MATCH) reduce 224) ((T_METHOD_C) reduce 224) ((T_NAMESPACE) reduce 224) ((T_NAME_FULLY_QUALIFIED) reduce 224) ((T_NAME_QUALIFIED) reduce 224) ((T_NAME_RELATIVE) reduce 224) ((T_NEW) reduce 224) ((T_NS_C) reduce 224) ((T_OBJECT_CAST) reduce 224) ((T_PRINT) reduce 224) ((T_READONLY) reduce 224) ((T_REQUIRE) reduce 224) ((T_REQUIRE_ONCE) reduce 224) ((T_RETURN) reduce 224) ((T_START_HEREDOC) reduce 224) ((T_STATIC) reduce 224) ((T_STRING) reduce 224) ((T_STRING_CAST) reduce 224) ((T_SWITCH) reduce 224) ((T_THROW) reduce 224) ((T_TRAIT) reduce 224) ((T_TRAIT_C) reduce 224) ((T_TRY) reduce 224) ((T_UNSET) reduce 224) ((T_UNSET_CAST) reduce 224) ((T_USE) reduce 224) ((T_VARIABLE) reduce 224) ((T_WHILE) reduce 224) ((T_YIELD) reduce 224) ((T_YIELD_FROM) reduce 224) (("[") reduce 224) (("`") reduce 224) (("{") reduce 224) (("}") reduce 224) (("~") reduce 224)) 27991 ((("!") reduce 167) (("\"") reduce 167) (("$") reduce 167) (("(") reduce 167) (("+") reduce 167) (("-") reduce 167) ((";") reduce 167) (("@") reduce 167) ((T_ABSTRACT) reduce 167) ((T_ARRAY) reduce 167) ((T_ARRAY_CAST) reduce 167) ((T_ATTRIBUTE) reduce 167) ((T_BOOL_CAST) reduce 167) ((T_BREAK) reduce 167) ((T_CLASS) reduce 167) ((T_CLASS_C) reduce 167) ((T_CLONE) reduce 167) ((T_CONST) reduce 167) ((T_CONSTANT_ENCAPSED_STRING) reduce 167) ((T_CONTINUE) reduce 167) ((T_DEC) reduce 167) ((T_DECLARE) reduce 167) ((T_DIR) reduce 167) ((T_DNUMBER) reduce 167) ((T_DO) reduce 167) ((T_DOUBLE_CAST) reduce 167) ((T_ECHO) reduce 167) ((T_ELSE) reduce 167) ((T_ELSEIF) reduce 167) ((T_EMPTY) reduce 167) ((T_ENUM) reduce 167) ((T_EVAL) reduce 167) ((T_EXIT) reduce 167) ((T_FILE) reduce 167) ((T_FINAL) reduce 167) ((T_FN) reduce 167) ((T_FOR) reduce 167) ((T_FOREACH) reduce 167) ((T_FUNCTION) reduce 167) ((T_FUNC_C) reduce 167) ((T_GLOBAL) reduce 167) ((T_GOTO) reduce 167) ((T_HALT_COMPILER) reduce 167) ((T_IF) reduce 167) ((T_INC) reduce 167) ((T_INCLUDE) reduce 167) ((T_INCLUDE_ONCE) reduce 167) ((T_INLINE_HTML) reduce 167) ((T_INTERFACE) reduce 167) ((T_INT_CAST) reduce 167) ((T_ISSET) reduce 167) ((T_LINE) reduce 167) ((T_LIST) reduce 167) ((T_LNUMBER) reduce 167) ((T_MATCH) reduce 167) ((T_METHOD_C) reduce 167) ((T_NAMESPACE) reduce 167) ((T_NAME_FULLY_QUALIFIED) reduce 167) ((T_NAME_QUALIFIED) reduce 167) ((T_NAME_RELATIVE) reduce 167) ((T_NEW) reduce 167) ((T_NS_C) reduce 167) ((T_OBJECT_CAST) reduce 167) ((T_PRINT) reduce 167) ((T_READONLY) reduce 167) ((T_REQUIRE) reduce 167) ((T_REQUIRE_ONCE) reduce 167) ((T_RETURN) reduce 167) ((T_START_HEREDOC) reduce 167) ((T_STATIC) reduce 167) ((T_STRING) reduce 167) ((T_STRING_CAST) reduce 167) ((T_SWITCH) reduce 167) ((T_THROW) reduce 167) ((T_TRAIT) reduce 167) ((T_TRAIT_C) reduce 167) ((T_TRY) reduce 167) ((T_UNSET) reduce 167) ((T_UNSET_CAST) reduce 167) ((T_USE) reduce 167) ((T_VARIABLE) reduce 167) ((T_WHILE) reduce 167) ((T_YIELD) reduce 167) ((T_YIELD_FROM) reduce 167) (("[") reduce 167) (("`") reduce 167) (("{") reduce 167) (("}") reduce 167) (("~") reduce 167)) 27993 ((("!") reduce 156) (("\"") reduce 156) (("$") reduce 156) (("(") reduce 156) (("+") reduce 156) (("-") reduce 156) ((";") reduce 156) (("@") reduce 156) ((T_ABSTRACT) reduce 156) ((T_ARRAY) reduce 156) ((T_ARRAY_CAST) reduce 156) ((T_ATTRIBUTE) reduce 156) ((T_BOOL_CAST) reduce 156) ((T_BREAK) reduce 156) ((T_CLASS) reduce 156) ((T_CLASS_C) reduce 156) ((T_CLONE) reduce 156) ((T_CONST) reduce 156) ((T_CONSTANT_ENCAPSED_STRING) reduce 156) ((T_CONTINUE) reduce 156) ((T_DEC) reduce 156) ((T_DECLARE) reduce 156) ((T_DIR) reduce 156) ((T_DNUMBER) reduce 156) ((T_DO) reduce 156) ((T_DOUBLE_CAST) reduce 156) ((T_ECHO) reduce 156) ((T_ELSE) reduce 156) ((T_ELSEIF) reduce 156) ((T_EMPTY) reduce 156) ((T_ENUM) reduce 156) ((T_EVAL) reduce 156) ((T_EXIT) reduce 156) ((T_FILE) reduce 156) ((T_FINAL) reduce 156) ((T_FN) reduce 156) ((T_FOR) reduce 156) ((T_FOREACH) reduce 156) ((T_FUNCTION) reduce 156) ((T_FUNC_C) reduce 156) ((T_GLOBAL) reduce 156) ((T_GOTO) reduce 156) ((T_HALT_COMPILER) reduce 156) ((T_IF) reduce 156) ((T_INC) reduce 156) ((T_INCLUDE) reduce 156) ((T_INCLUDE_ONCE) reduce 156) ((T_INLINE_HTML) reduce 156) ((T_INTERFACE) reduce 156) ((T_INT_CAST) reduce 156) ((T_ISSET) reduce 156) ((T_LINE) reduce 156) ((T_LIST) reduce 156) ((T_LNUMBER) reduce 156) ((T_MATCH) reduce 156) ((T_METHOD_C) reduce 156) ((T_NAMESPACE) reduce 156) ((T_NAME_FULLY_QUALIFIED) reduce 156) ((T_NAME_QUALIFIED) reduce 156) ((T_NAME_RELATIVE) reduce 156) ((T_NEW) reduce 156) ((T_NS_C) reduce 156) ((T_OBJECT_CAST) reduce 156) ((T_PRINT) reduce 156) ((T_READONLY) reduce 156) ((T_REQUIRE) reduce 156) ((T_REQUIRE_ONCE) reduce 156) ((T_RETURN) reduce 156) ((T_START_HEREDOC) reduce 156) ((T_STATIC) reduce 156) ((T_STRING) reduce 156) ((T_STRING_CAST) reduce 156) ((T_SWITCH) reduce 156) ((T_THROW) reduce 156) ((T_TRAIT) reduce 156) ((T_TRAIT_C) reduce 156) ((T_TRY) reduce 156) ((T_UNSET) reduce 156) ((T_UNSET_CAST) reduce 156) ((T_USE) reduce 156) ((T_VARIABLE) reduce 156) ((T_WHILE) reduce 156) ((T_YIELD) reduce 156) ((T_YIELD_FROM) reduce 156) (("[") reduce 156) (("`") reduce 156) (("{") reduce 156) (("}") reduce 156) (("~") reduce 156)) 27995 ((("!") reduce 154) (("\"") reduce 154) (("$") reduce 154) (("(") reduce 154) (("+") reduce 154) (("-") reduce 154) ((";") reduce 154) (("@") reduce 154) ((T_ABSTRACT) reduce 154) ((T_ARRAY) reduce 154) ((T_ARRAY_CAST) reduce 154) ((T_ATTRIBUTE) reduce 154) ((T_BOOL_CAST) reduce 154) ((T_BREAK) reduce 154) ((T_CLASS) reduce 154) ((T_CLASS_C) reduce 154) ((T_CLONE) reduce 154) ((T_CONST) reduce 154) ((T_CONSTANT_ENCAPSED_STRING) reduce 154) ((T_CONTINUE) reduce 154) ((T_DEC) reduce 154) ((T_DECLARE) reduce 154) ((T_DIR) reduce 154) ((T_DNUMBER) reduce 154) ((T_DO) reduce 154) ((T_DOUBLE_CAST) reduce 154) ((T_ECHO) reduce 154) ((T_ELSE) reduce 154) ((T_ELSEIF) reduce 154) ((T_EMPTY) reduce 154) ((T_ENUM) reduce 154) ((T_EVAL) reduce 154) ((T_EXIT) reduce 154) ((T_FILE) reduce 154) ((T_FINAL) reduce 154) ((T_FN) reduce 154) ((T_FOR) reduce 154) ((T_FOREACH) reduce 154) ((T_FUNCTION) reduce 154) ((T_FUNC_C) reduce 154) ((T_GLOBAL) reduce 154) ((T_GOTO) reduce 154) ((T_HALT_COMPILER) reduce 154) ((T_IF) reduce 154) ((T_INC) reduce 154) ((T_INCLUDE) reduce 154) ((T_INCLUDE_ONCE) reduce 154) ((T_INLINE_HTML) reduce 154) ((T_INTERFACE) reduce 154) ((T_INT_CAST) reduce 154) ((T_ISSET) reduce 154) ((T_LINE) reduce 154) ((T_LIST) reduce 154) ((T_LNUMBER) reduce 154) ((T_MATCH) reduce 154) ((T_METHOD_C) reduce 154) ((T_NAMESPACE) reduce 154) ((T_NAME_FULLY_QUALIFIED) reduce 154) ((T_NAME_QUALIFIED) reduce 154) ((T_NAME_RELATIVE) reduce 154) ((T_NEW) reduce 154) ((T_NS_C) reduce 154) ((T_OBJECT_CAST) reduce 154) ((T_PRINT) reduce 154) ((T_READONLY) reduce 154) ((T_REQUIRE) reduce 154) ((T_REQUIRE_ONCE) reduce 154) ((T_RETURN) reduce 154) ((T_START_HEREDOC) reduce 154) ((T_STATIC) reduce 154) ((T_STRING) reduce 154) ((T_STRING_CAST) reduce 154) ((T_SWITCH) reduce 154) ((T_THROW) reduce 154) ((T_TRAIT) reduce 154) ((T_TRAIT_C) reduce 154) ((T_TRY) reduce 154) ((T_UNSET) reduce 154) ((T_UNSET_CAST) reduce 154) ((T_USE) reduce 154) ((T_VARIABLE) reduce 154) ((T_WHILE) reduce 154) ((T_YIELD) reduce 154) ((T_YIELD_FROM) reduce 154) (("[") reduce 154) (("`") reduce 154) (("{") reduce 154) (("}") reduce 154) (("~") reduce 154)) 27997 ((("!") reduce 166) (("\"") reduce 166) (("$") reduce 166) (("(") reduce 166) (("+") reduce 166) (("-") reduce 166) ((";") reduce 166) (("@") reduce 166) ((T_ABSTRACT) reduce 166) ((T_ARRAY) reduce 166) ((T_ARRAY_CAST) reduce 166) ((T_ATTRIBUTE) reduce 166) ((T_BOOL_CAST) reduce 166) ((T_BREAK) reduce 166) ((T_CLASS) reduce 166) ((T_CLASS_C) reduce 166) ((T_CLONE) reduce 166) ((T_CONST) reduce 166) ((T_CONSTANT_ENCAPSED_STRING) reduce 166) ((T_CONTINUE) reduce 166) ((T_DEC) reduce 166) ((T_DECLARE) reduce 166) ((T_DIR) reduce 166) ((T_DNUMBER) reduce 166) ((T_DO) reduce 166) ((T_DOUBLE_CAST) reduce 166) ((T_ECHO) reduce 166) ((T_ELSE) reduce 166) ((T_ELSEIF) reduce 166) ((T_EMPTY) reduce 166) ((T_ENUM) reduce 166) ((T_EVAL) reduce 166) ((T_EXIT) reduce 166) ((T_FILE) reduce 166) ((T_FINAL) reduce 166) ((T_FN) reduce 166) ((T_FOR) reduce 166) ((T_FOREACH) reduce 166) ((T_FUNCTION) reduce 166) ((T_FUNC_C) reduce 166) ((T_GLOBAL) reduce 166) ((T_GOTO) reduce 166) ((T_HALT_COMPILER) reduce 166) ((T_IF) reduce 166) ((T_INC) reduce 166) ((T_INCLUDE) reduce 166) ((T_INCLUDE_ONCE) reduce 166) ((T_INLINE_HTML) reduce 166) ((T_INTERFACE) reduce 166) ((T_INT_CAST) reduce 166) ((T_ISSET) reduce 166) ((T_LINE) reduce 166) ((T_LIST) reduce 166) ((T_LNUMBER) reduce 166) ((T_MATCH) reduce 166) ((T_METHOD_C) reduce 166) ((T_NAMESPACE) reduce 166) ((T_NAME_FULLY_QUALIFIED) reduce 166) ((T_NAME_QUALIFIED) reduce 166) ((T_NAME_RELATIVE) reduce 166) ((T_NEW) reduce 166) ((T_NS_C) reduce 166) ((T_OBJECT_CAST) reduce 166) ((T_PRINT) reduce 166) ((T_READONLY) reduce 166) ((T_REQUIRE) reduce 166) ((T_REQUIRE_ONCE) reduce 166) ((T_RETURN) reduce 166) ((T_START_HEREDOC) reduce 166) ((T_STATIC) reduce 166) ((T_STRING) reduce 166) ((T_STRING_CAST) reduce 166) ((T_SWITCH) reduce 166) ((T_THROW) reduce 166) ((T_TRAIT) reduce 166) ((T_TRAIT_C) reduce 166) ((T_TRY) reduce 166) ((T_UNSET) reduce 166) ((T_UNSET_CAST) reduce 166) ((T_USE) reduce 166) ((T_VARIABLE) reduce 166) ((T_WHILE) reduce 166) ((T_YIELD) reduce 166) ((T_YIELD_FROM) reduce 166) (("[") reduce 166) (("`") reduce 166) (("{") reduce 166) (("}") reduce 166) (("~") reduce 166)) 27999 ((("!") reduce 155) (("\"") reduce 155) (("$") reduce 155) (("(") reduce 155) (("+") reduce 155) (("-") reduce 155) ((";") reduce 155) (("@") reduce 155) ((T_ABSTRACT) reduce 155) ((T_ARRAY) reduce 155) ((T_ARRAY_CAST) reduce 155) ((T_ATTRIBUTE) reduce 155) ((T_BOOL_CAST) reduce 155) ((T_BREAK) reduce 155) ((T_CLASS) reduce 155) ((T_CLASS_C) reduce 155) ((T_CLONE) reduce 155) ((T_CONST) reduce 155) ((T_CONSTANT_ENCAPSED_STRING) reduce 155) ((T_CONTINUE) reduce 155) ((T_DEC) reduce 155) ((T_DECLARE) reduce 155) ((T_DIR) reduce 155) ((T_DNUMBER) reduce 155) ((T_DO) reduce 155) ((T_DOUBLE_CAST) reduce 155) ((T_ECHO) reduce 155) ((T_ELSE) reduce 155) ((T_ELSEIF) reduce 155) ((T_EMPTY) reduce 155) ((T_ENUM) reduce 155) ((T_EVAL) reduce 155) ((T_EXIT) reduce 155) ((T_FILE) reduce 155) ((T_FINAL) reduce 155) ((T_FN) reduce 155) ((T_FOR) reduce 155) ((T_FOREACH) reduce 155) ((T_FUNCTION) reduce 155) ((T_FUNC_C) reduce 155) ((T_GLOBAL) reduce 155) ((T_GOTO) reduce 155) ((T_HALT_COMPILER) reduce 155) ((T_IF) reduce 155) ((T_INC) reduce 155) ((T_INCLUDE) reduce 155) ((T_INCLUDE_ONCE) reduce 155) ((T_INLINE_HTML) reduce 155) ((T_INTERFACE) reduce 155) ((T_INT_CAST) reduce 155) ((T_ISSET) reduce 155) ((T_LINE) reduce 155) ((T_LIST) reduce 155) ((T_LNUMBER) reduce 155) ((T_MATCH) reduce 155) ((T_METHOD_C) reduce 155) ((T_NAMESPACE) reduce 155) ((T_NAME_FULLY_QUALIFIED) reduce 155) ((T_NAME_QUALIFIED) reduce 155) ((T_NAME_RELATIVE) reduce 155) ((T_NEW) reduce 155) ((T_NS_C) reduce 155) ((T_OBJECT_CAST) reduce 155) ((T_PRINT) reduce 155) ((T_READONLY) reduce 155) ((T_REQUIRE) reduce 155) ((T_REQUIRE_ONCE) reduce 155) ((T_RETURN) reduce 155) ((T_START_HEREDOC) reduce 155) ((T_STATIC) reduce 155) ((T_STRING) reduce 155) ((T_STRING_CAST) reduce 155) ((T_SWITCH) reduce 155) ((T_THROW) reduce 155) ((T_TRAIT) reduce 155) ((T_TRAIT_C) reduce 155) ((T_TRY) reduce 155) ((T_UNSET) reduce 155) ((T_UNSET_CAST) reduce 155) ((T_USE) reduce 155) ((T_VARIABLE) reduce 155) ((T_WHILE) reduce 155) ((T_YIELD) reduce 155) ((T_YIELD_FROM) reduce 155) (("[") reduce 155) (("`") reduce 155) (("{") reduce 155) (("}") reduce 155) (("~") reduce 155)) 28009 ((("!") reduce 162) (("\"") reduce 162) (("$") reduce 162) (("(") reduce 162) (("+") reduce 162) (("-") reduce 162) ((";") reduce 162) (("@") reduce 162) ((T_ABSTRACT) reduce 162) ((T_ARRAY) reduce 162) ((T_ARRAY_CAST) reduce 162) ((T_ATTRIBUTE) reduce 162) ((T_BOOL_CAST) reduce 162) ((T_BREAK) reduce 162) ((T_CLASS) reduce 162) ((T_CLASS_C) reduce 162) ((T_CLONE) reduce 162) ((T_CONST) reduce 162) ((T_CONSTANT_ENCAPSED_STRING) reduce 162) ((T_CONTINUE) reduce 162) ((T_DEC) reduce 162) ((T_DECLARE) reduce 162) ((T_DIR) reduce 162) ((T_DNUMBER) reduce 162) ((T_DO) reduce 162) ((T_DOUBLE_CAST) reduce 162) ((T_ECHO) reduce 162) ((T_ELSE) reduce 162) ((T_ELSEIF) reduce 162) ((T_EMPTY) reduce 162) ((T_ENUM) reduce 162) ((T_EVAL) reduce 162) ((T_EXIT) reduce 162) ((T_FILE) reduce 162) ((T_FINAL) reduce 162) ((T_FN) reduce 162) ((T_FOR) reduce 162) ((T_FOREACH) reduce 162) ((T_FUNCTION) reduce 162) ((T_FUNC_C) reduce 162) ((T_GLOBAL) reduce 162) ((T_GOTO) reduce 162) ((T_HALT_COMPILER) reduce 162) ((T_IF) reduce 162) ((T_INC) reduce 162) ((T_INCLUDE) reduce 162) ((T_INCLUDE_ONCE) reduce 162) ((T_INLINE_HTML) reduce 162) ((T_INTERFACE) reduce 162) ((T_INT_CAST) reduce 162) ((T_ISSET) reduce 162) ((T_LINE) reduce 162) ((T_LIST) reduce 162) ((T_LNUMBER) reduce 162) ((T_MATCH) reduce 162) ((T_METHOD_C) reduce 162) ((T_NAMESPACE) reduce 162) ((T_NAME_FULLY_QUALIFIED) reduce 162) ((T_NAME_QUALIFIED) reduce 162) ((T_NAME_RELATIVE) reduce 162) ((T_NEW) reduce 162) ((T_NS_C) reduce 162) ((T_OBJECT_CAST) reduce 162) ((T_PRINT) reduce 162) ((T_READONLY) reduce 162) ((T_REQUIRE) reduce 162) ((T_REQUIRE_ONCE) reduce 162) ((T_RETURN) reduce 162) ((T_START_HEREDOC) reduce 162) ((T_STATIC) reduce 162) ((T_STRING) reduce 162) ((T_STRING_CAST) reduce 162) ((T_SWITCH) reduce 162) ((T_THROW) reduce 162) ((T_TRAIT) reduce 162) ((T_TRAIT_C) reduce 162) ((T_TRY) reduce 162) ((T_UNSET) reduce 162) ((T_UNSET_CAST) reduce 162) ((T_USE) reduce 162) ((T_VARIABLE) reduce 162) ((T_WHILE) reduce 162) ((T_YIELD) reduce 162) ((T_YIELD_FROM) reduce 162) (("[") reduce 162) (("`") reduce 162) (("{") reduce 162) (("}") reduce 162) (("~") reduce 162)) 28010 ((("!") reduce 217) (("\"") reduce 217) (("$") reduce 217) (("(") reduce 217) (("+") reduce 217) (("-") reduce 217) ((";") reduce 217) (("@") reduce 217) ((T_ABSTRACT) reduce 217) ((T_ARRAY) reduce 217) ((T_ARRAY_CAST) reduce 217) ((T_ATTRIBUTE) reduce 217) ((T_BOOL_CAST) reduce 217) ((T_BREAK) reduce 217) ((T_CLASS) reduce 217) ((T_CLASS_C) reduce 217) ((T_CLONE) reduce 217) ((T_CONST) reduce 217) ((T_CONSTANT_ENCAPSED_STRING) reduce 217) ((T_CONTINUE) reduce 217) ((T_DEC) reduce 217) ((T_DECLARE) reduce 217) ((T_DIR) reduce 217) ((T_DNUMBER) reduce 217) ((T_DO) reduce 217) ((T_DOUBLE_CAST) reduce 217) ((T_ECHO) reduce 217) ((T_ELSE) reduce 217) ((T_ELSEIF) reduce 217) ((T_EMPTY) reduce 217) ((T_ENUM) reduce 217) ((T_EVAL) reduce 217) ((T_EXIT) reduce 217) ((T_FILE) reduce 217) ((T_FINAL) reduce 217) ((T_FN) reduce 217) ((T_FOR) reduce 217) ((T_FOREACH) reduce 217) ((T_FUNCTION) reduce 217) ((T_FUNC_C) reduce 217) ((T_GLOBAL) reduce 217) ((T_GOTO) reduce 217) ((T_HALT_COMPILER) reduce 217) ((T_IF) reduce 217) ((T_INC) reduce 217) ((T_INCLUDE) reduce 217) ((T_INCLUDE_ONCE) reduce 217) ((T_INLINE_HTML) reduce 217) ((T_INTERFACE) reduce 217) ((T_INT_CAST) reduce 217) ((T_ISSET) reduce 217) ((T_LINE) reduce 217) ((T_LIST) reduce 217) ((T_LNUMBER) reduce 217) ((T_MATCH) reduce 217) ((T_METHOD_C) reduce 217) ((T_NAMESPACE) reduce 217) ((T_NAME_FULLY_QUALIFIED) reduce 217) ((T_NAME_QUALIFIED) reduce 217) ((T_NAME_RELATIVE) reduce 217) ((T_NEW) reduce 217) ((T_NS_C) reduce 217) ((T_OBJECT_CAST) reduce 217) ((T_PRINT) reduce 217) ((T_READONLY) reduce 217) ((T_REQUIRE) reduce 217) ((T_REQUIRE_ONCE) reduce 217) ((T_RETURN) reduce 217) ((T_START_HEREDOC) reduce 217) ((T_STATIC) reduce 217) ((T_STRING) reduce 217) ((T_STRING_CAST) reduce 217) ((T_SWITCH) reduce 217) ((T_THROW) reduce 217) ((T_TRAIT) reduce 217) ((T_TRAIT_C) reduce 217) ((T_TRY) reduce 217) ((T_UNSET) reduce 217) ((T_UNSET_CAST) reduce 217) ((T_USE) reduce 217) ((T_VARIABLE) reduce 217) ((T_WHILE) reduce 217) ((T_YIELD) reduce 217) ((T_YIELD_FROM) reduce 217) (("[") reduce 217) (("`") reduce 217) (("{") reduce 217) (("}") reduce 217) (("~") reduce 217)) 28013 ((("!") reduce 218) (("\"") reduce 218) (("$") reduce 218) (("(") reduce 218) (("+") reduce 218) (("-") reduce 218) ((";") reduce 218) (("@") reduce 218) ((T_ABSTRACT) reduce 218) ((T_ARRAY) reduce 218) ((T_ARRAY_CAST) reduce 218) ((T_ATTRIBUTE) reduce 218) ((T_BOOL_CAST) reduce 218) ((T_BREAK) reduce 218) ((T_CLASS) reduce 218) ((T_CLASS_C) reduce 218) ((T_CLONE) reduce 218) ((T_CONST) reduce 218) ((T_CONSTANT_ENCAPSED_STRING) reduce 218) ((T_CONTINUE) reduce 218) ((T_DEC) reduce 218) ((T_DECLARE) reduce 218) ((T_DIR) reduce 218) ((T_DNUMBER) reduce 218) ((T_DO) reduce 218) ((T_DOUBLE_CAST) reduce 218) ((T_ECHO) reduce 218) ((T_ELSE) reduce 218) ((T_ELSEIF) reduce 218) ((T_EMPTY) reduce 218) ((T_ENUM) reduce 218) ((T_EVAL) reduce 218) ((T_EXIT) reduce 218) ((T_FILE) reduce 218) ((T_FINAL) reduce 218) ((T_FN) reduce 218) ((T_FOR) reduce 218) ((T_FOREACH) reduce 218) ((T_FUNCTION) reduce 218) ((T_FUNC_C) reduce 218) ((T_GLOBAL) reduce 218) ((T_GOTO) reduce 218) ((T_HALT_COMPILER) reduce 218) ((T_IF) reduce 218) ((T_INC) reduce 218) ((T_INCLUDE) reduce 218) ((T_INCLUDE_ONCE) reduce 218) ((T_INLINE_HTML) reduce 218) ((T_INTERFACE) reduce 218) ((T_INT_CAST) reduce 218) ((T_ISSET) reduce 218) ((T_LINE) reduce 218) ((T_LIST) reduce 218) ((T_LNUMBER) reduce 218) ((T_MATCH) reduce 218) ((T_METHOD_C) reduce 218) ((T_NAMESPACE) reduce 218) ((T_NAME_FULLY_QUALIFIED) reduce 218) ((T_NAME_QUALIFIED) reduce 218) ((T_NAME_RELATIVE) reduce 218) ((T_NEW) reduce 218) ((T_NS_C) reduce 218) ((T_OBJECT_CAST) reduce 218) ((T_PRINT) reduce 218) ((T_READONLY) reduce 218) ((T_REQUIRE) reduce 218) ((T_REQUIRE_ONCE) reduce 218) ((T_RETURN) reduce 218) ((T_START_HEREDOC) reduce 218) ((T_STATIC) reduce 218) ((T_STRING) reduce 218) ((T_STRING_CAST) reduce 218) ((T_SWITCH) reduce 218) ((T_THROW) reduce 218) ((T_TRAIT) reduce 218) ((T_TRAIT_C) reduce 218) ((T_TRY) reduce 218) ((T_UNSET) reduce 218) ((T_UNSET_CAST) reduce 218) ((T_USE) reduce 218) ((T_VARIABLE) reduce 218) ((T_WHILE) reduce 218) ((T_YIELD) reduce 218) ((T_YIELD_FROM) reduce 218) (("[") reduce 218) (("`") reduce 218) (("{") reduce 218) (("}") reduce 218) (("~") reduce 218)) 28014 ((("!") reduce 161) (("\"") reduce 161) (("$") reduce 161) (("(") reduce 161) (("+") reduce 161) (("-") reduce 161) ((";") reduce 161) (("@") reduce 161) ((T_ABSTRACT) reduce 161) ((T_ARRAY) reduce 161) ((T_ARRAY_CAST) reduce 161) ((T_ATTRIBUTE) reduce 161) ((T_BOOL_CAST) reduce 161) ((T_BREAK) reduce 161) ((T_CLASS) reduce 161) ((T_CLASS_C) reduce 161) ((T_CLONE) reduce 161) ((T_CONST) reduce 161) ((T_CONSTANT_ENCAPSED_STRING) reduce 161) ((T_CONTINUE) reduce 161) ((T_DEC) reduce 161) ((T_DECLARE) reduce 161) ((T_DIR) reduce 161) ((T_DNUMBER) reduce 161) ((T_DO) reduce 161) ((T_DOUBLE_CAST) reduce 161) ((T_ECHO) reduce 161) ((T_ELSE) reduce 161) ((T_ELSEIF) reduce 161) ((T_EMPTY) reduce 161) ((T_ENUM) reduce 161) ((T_EVAL) reduce 161) ((T_EXIT) reduce 161) ((T_FILE) reduce 161) ((T_FINAL) reduce 161) ((T_FN) reduce 161) ((T_FOR) reduce 161) ((T_FOREACH) reduce 161) ((T_FUNCTION) reduce 161) ((T_FUNC_C) reduce 161) ((T_GLOBAL) reduce 161) ((T_GOTO) reduce 161) ((T_HALT_COMPILER) reduce 161) ((T_IF) reduce 161) ((T_INC) reduce 161) ((T_INCLUDE) reduce 161) ((T_INCLUDE_ONCE) reduce 161) ((T_INLINE_HTML) reduce 161) ((T_INTERFACE) reduce 161) ((T_INT_CAST) reduce 161) ((T_ISSET) reduce 161) ((T_LINE) reduce 161) ((T_LIST) reduce 161) ((T_LNUMBER) reduce 161) ((T_MATCH) reduce 161) ((T_METHOD_C) reduce 161) ((T_NAMESPACE) reduce 161) ((T_NAME_FULLY_QUALIFIED) reduce 161) ((T_NAME_QUALIFIED) reduce 161) ((T_NAME_RELATIVE) reduce 161) ((T_NEW) reduce 161) ((T_NS_C) reduce 161) ((T_OBJECT_CAST) reduce 161) ((T_PRINT) reduce 161) ((T_READONLY) reduce 161) ((T_REQUIRE) reduce 161) ((T_REQUIRE_ONCE) reduce 161) ((T_RETURN) reduce 161) ((T_START_HEREDOC) reduce 161) ((T_STATIC) reduce 161) ((T_STRING) reduce 161) ((T_STRING_CAST) reduce 161) ((T_SWITCH) reduce 161) ((T_THROW) reduce 161) ((T_TRAIT) reduce 161) ((T_TRAIT_C) reduce 161) ((T_TRY) reduce 161) ((T_UNSET) reduce 161) ((T_UNSET_CAST) reduce 161) ((T_USE) reduce 161) ((T_VARIABLE) reduce 161) ((T_WHILE) reduce 161) ((T_YIELD) reduce 161) ((T_YIELD_FROM) reduce 161) (("[") reduce 161) (("`") reduce 161) (("{") reduce 161) (("}") reduce 161) (("~") reduce 161)) 28023 ((("!") reduce 150) (("\"") reduce 150) (("$") reduce 150) (("(") reduce 150) (("+") reduce 150) (("-") reduce 150) ((";") reduce 150) (("@") reduce 150) ((T_ABSTRACT) reduce 150) ((T_ARRAY) reduce 150) ((T_ARRAY_CAST) reduce 150) ((T_ATTRIBUTE) reduce 150) ((T_BOOL_CAST) reduce 150) ((T_BREAK) reduce 150) ((T_CLASS) reduce 150) ((T_CLASS_C) reduce 150) ((T_CLONE) reduce 150) ((T_CONST) reduce 150) ((T_CONSTANT_ENCAPSED_STRING) reduce 150) ((T_CONTINUE) reduce 150) ((T_DEC) reduce 150) ((T_DECLARE) reduce 150) ((T_DIR) reduce 150) ((T_DNUMBER) reduce 150) ((T_DO) reduce 150) ((T_DOUBLE_CAST) reduce 150) ((T_ECHO) reduce 150) ((T_ELSE) reduce 150) ((T_ELSEIF) reduce 150) ((T_EMPTY) reduce 150) ((T_ENUM) reduce 150) ((T_EVAL) reduce 150) ((T_EXIT) reduce 150) ((T_FILE) reduce 150) ((T_FINAL) reduce 150) ((T_FN) reduce 150) ((T_FOR) reduce 150) ((T_FOREACH) reduce 150) ((T_FUNCTION) reduce 150) ((T_FUNC_C) reduce 150) ((T_GLOBAL) reduce 150) ((T_GOTO) reduce 150) ((T_HALT_COMPILER) reduce 150) ((T_IF) reduce 150) ((T_INC) reduce 150) ((T_INCLUDE) reduce 150) ((T_INCLUDE_ONCE) reduce 150) ((T_INLINE_HTML) reduce 150) ((T_INTERFACE) reduce 150) ((T_INT_CAST) reduce 150) ((T_ISSET) reduce 150) ((T_LINE) reduce 150) ((T_LIST) reduce 150) ((T_LNUMBER) reduce 150) ((T_MATCH) reduce 150) ((T_METHOD_C) reduce 150) ((T_NAMESPACE) reduce 150) ((T_NAME_FULLY_QUALIFIED) reduce 150) ((T_NAME_QUALIFIED) reduce 150) ((T_NAME_RELATIVE) reduce 150) ((T_NEW) reduce 150) ((T_NS_C) reduce 150) ((T_OBJECT_CAST) reduce 150) ((T_PRINT) reduce 150) ((T_READONLY) reduce 150) ((T_REQUIRE) reduce 150) ((T_REQUIRE_ONCE) reduce 150) ((T_RETURN) reduce 150) ((T_START_HEREDOC) reduce 150) ((T_STATIC) reduce 150) ((T_STRING) reduce 150) ((T_STRING_CAST) reduce 150) ((T_SWITCH) reduce 150) ((T_THROW) reduce 150) ((T_TRAIT) reduce 150) ((T_TRAIT_C) reduce 150) ((T_TRY) reduce 150) ((T_UNSET) reduce 150) ((T_UNSET_CAST) reduce 150) ((T_USE) reduce 150) ((T_VARIABLE) reduce 150) ((T_WHILE) reduce 150) ((T_YIELD) reduce 150) ((T_YIELD_FROM) reduce 150) (("[") reduce 150) (("`") reduce 150) (("{") reduce 150) (("}") reduce 150) (("~") reduce 150)) 28024 ((("!") reduce 215) (("\"") reduce 215) (("$") reduce 215) (("(") reduce 215) (("+") reduce 215) (("-") reduce 215) ((";") reduce 215) (("@") reduce 215) ((T_ABSTRACT) reduce 215) ((T_ARRAY) reduce 215) ((T_ARRAY_CAST) reduce 215) ((T_ATTRIBUTE) reduce 215) ((T_BOOL_CAST) reduce 215) ((T_BREAK) reduce 215) ((T_CLASS) reduce 215) ((T_CLASS_C) reduce 215) ((T_CLONE) reduce 215) ((T_CONST) reduce 215) ((T_CONSTANT_ENCAPSED_STRING) reduce 215) ((T_CONTINUE) reduce 215) ((T_DEC) reduce 215) ((T_DECLARE) reduce 215) ((T_DIR) reduce 215) ((T_DNUMBER) reduce 215) ((T_DO) reduce 215) ((T_DOUBLE_CAST) reduce 215) ((T_ECHO) reduce 215) ((T_ELSE) reduce 215) ((T_ELSEIF) reduce 215) ((T_EMPTY) reduce 215) ((T_ENUM) reduce 215) ((T_EVAL) reduce 215) ((T_EXIT) reduce 215) ((T_FILE) reduce 215) ((T_FINAL) reduce 215) ((T_FN) reduce 215) ((T_FOR) reduce 215) ((T_FOREACH) reduce 215) ((T_FUNCTION) reduce 215) ((T_FUNC_C) reduce 215) ((T_GLOBAL) reduce 215) ((T_GOTO) reduce 215) ((T_HALT_COMPILER) reduce 215) ((T_IF) reduce 215) ((T_INC) reduce 215) ((T_INCLUDE) reduce 215) ((T_INCLUDE_ONCE) reduce 215) ((T_INLINE_HTML) reduce 215) ((T_INTERFACE) reduce 215) ((T_INT_CAST) reduce 215) ((T_ISSET) reduce 215) ((T_LINE) reduce 215) ((T_LIST) reduce 215) ((T_LNUMBER) reduce 215) ((T_MATCH) reduce 215) ((T_METHOD_C) reduce 215) ((T_NAMESPACE) reduce 215) ((T_NAME_FULLY_QUALIFIED) reduce 215) ((T_NAME_QUALIFIED) reduce 215) ((T_NAME_RELATIVE) reduce 215) ((T_NEW) reduce 215) ((T_NS_C) reduce 215) ((T_OBJECT_CAST) reduce 215) ((T_PRINT) reduce 215) ((T_READONLY) reduce 215) ((T_REQUIRE) reduce 215) ((T_REQUIRE_ONCE) reduce 215) ((T_RETURN) reduce 215) ((T_START_HEREDOC) reduce 215) ((T_STATIC) reduce 215) ((T_STRING) reduce 215) ((T_STRING_CAST) reduce 215) ((T_SWITCH) reduce 215) ((T_THROW) reduce 215) ((T_TRAIT) reduce 215) ((T_TRAIT_C) reduce 215) ((T_TRY) reduce 215) ((T_UNSET) reduce 215) ((T_UNSET_CAST) reduce 215) ((T_USE) reduce 215) ((T_VARIABLE) reduce 215) ((T_WHILE) reduce 215) ((T_YIELD) reduce 215) ((T_YIELD_FROM) reduce 215) (("[") reduce 215) (("`") reduce 215) (("{") reduce 215) (("}") reduce 215) (("~") reduce 215)) 28027 ((("!") reduce 216) (("\"") reduce 216) (("$") reduce 216) (("(") reduce 216) (("+") reduce 216) (("-") reduce 216) ((";") reduce 216) (("@") reduce 216) ((T_ABSTRACT) reduce 216) ((T_ARRAY) reduce 216) ((T_ARRAY_CAST) reduce 216) ((T_ATTRIBUTE) reduce 216) ((T_BOOL_CAST) reduce 216) ((T_BREAK) reduce 216) ((T_CLASS) reduce 216) ((T_CLASS_C) reduce 216) ((T_CLONE) reduce 216) ((T_CONST) reduce 216) ((T_CONSTANT_ENCAPSED_STRING) reduce 216) ((T_CONTINUE) reduce 216) ((T_DEC) reduce 216) ((T_DECLARE) reduce 216) ((T_DIR) reduce 216) ((T_DNUMBER) reduce 216) ((T_DO) reduce 216) ((T_DOUBLE_CAST) reduce 216) ((T_ECHO) reduce 216) ((T_ELSE) reduce 216) ((T_ELSEIF) reduce 216) ((T_EMPTY) reduce 216) ((T_ENUM) reduce 216) ((T_EVAL) reduce 216) ((T_EXIT) reduce 216) ((T_FILE) reduce 216) ((T_FINAL) reduce 216) ((T_FN) reduce 216) ((T_FOR) reduce 216) ((T_FOREACH) reduce 216) ((T_FUNCTION) reduce 216) ((T_FUNC_C) reduce 216) ((T_GLOBAL) reduce 216) ((T_GOTO) reduce 216) ((T_HALT_COMPILER) reduce 216) ((T_IF) reduce 216) ((T_INC) reduce 216) ((T_INCLUDE) reduce 216) ((T_INCLUDE_ONCE) reduce 216) ((T_INLINE_HTML) reduce 216) ((T_INTERFACE) reduce 216) ((T_INT_CAST) reduce 216) ((T_ISSET) reduce 216) ((T_LINE) reduce 216) ((T_LIST) reduce 216) ((T_LNUMBER) reduce 216) ((T_MATCH) reduce 216) ((T_METHOD_C) reduce 216) ((T_NAMESPACE) reduce 216) ((T_NAME_FULLY_QUALIFIED) reduce 216) ((T_NAME_QUALIFIED) reduce 216) ((T_NAME_RELATIVE) reduce 216) ((T_NEW) reduce 216) ((T_NS_C) reduce 216) ((T_OBJECT_CAST) reduce 216) ((T_PRINT) reduce 216) ((T_READONLY) reduce 216) ((T_REQUIRE) reduce 216) ((T_REQUIRE_ONCE) reduce 216) ((T_RETURN) reduce 216) ((T_START_HEREDOC) reduce 216) ((T_STATIC) reduce 216) ((T_STRING) reduce 216) ((T_STRING_CAST) reduce 216) ((T_SWITCH) reduce 216) ((T_THROW) reduce 216) ((T_TRAIT) reduce 216) ((T_TRAIT_C) reduce 216) ((T_TRY) reduce 216) ((T_UNSET) reduce 216) ((T_UNSET_CAST) reduce 216) ((T_USE) reduce 216) ((T_VARIABLE) reduce 216) ((T_WHILE) reduce 216) ((T_YIELD) reduce 216) ((T_YIELD_FROM) reduce 216) (("[") reduce 216) (("`") reduce 216) (("{") reduce 216) (("}") reduce 216) (("~") reduce 216)) 28029 ((("!") reduce 157) (("\"") reduce 157) (("$") reduce 157) (("(") reduce 157) (("+") reduce 157) (("-") reduce 157) ((";") reduce 157) (("@") reduce 157) ((T_ABSTRACT) reduce 157) ((T_ARRAY) reduce 157) ((T_ARRAY_CAST) reduce 157) ((T_ATTRIBUTE) reduce 157) ((T_BOOL_CAST) reduce 157) ((T_BREAK) reduce 157) ((T_CLASS) reduce 157) ((T_CLASS_C) reduce 157) ((T_CLONE) reduce 157) ((T_CONST) reduce 157) ((T_CONSTANT_ENCAPSED_STRING) reduce 157) ((T_CONTINUE) reduce 157) ((T_DEC) reduce 157) ((T_DECLARE) reduce 157) ((T_DIR) reduce 157) ((T_DNUMBER) reduce 157) ((T_DO) reduce 157) ((T_DOUBLE_CAST) reduce 157) ((T_ECHO) reduce 157) ((T_ELSE) reduce 157) ((T_ELSEIF) reduce 157) ((T_EMPTY) reduce 157) ((T_ENUM) reduce 157) ((T_EVAL) reduce 157) ((T_EXIT) reduce 157) ((T_FILE) reduce 157) ((T_FINAL) reduce 157) ((T_FN) reduce 157) ((T_FOR) reduce 157) ((T_FOREACH) reduce 157) ((T_FUNCTION) reduce 157) ((T_FUNC_C) reduce 157) ((T_GLOBAL) reduce 157) ((T_GOTO) reduce 157) ((T_HALT_COMPILER) reduce 157) ((T_IF) reduce 157) ((T_INC) reduce 157) ((T_INCLUDE) reduce 157) ((T_INCLUDE_ONCE) reduce 157) ((T_INLINE_HTML) reduce 157) ((T_INTERFACE) reduce 157) ((T_INT_CAST) reduce 157) ((T_ISSET) reduce 157) ((T_LINE) reduce 157) ((T_LIST) reduce 157) ((T_LNUMBER) reduce 157) ((T_MATCH) reduce 157) ((T_METHOD_C) reduce 157) ((T_NAMESPACE) reduce 157) ((T_NAME_FULLY_QUALIFIED) reduce 157) ((T_NAME_QUALIFIED) reduce 157) ((T_NAME_RELATIVE) reduce 157) ((T_NEW) reduce 157) ((T_NS_C) reduce 157) ((T_OBJECT_CAST) reduce 157) ((T_PRINT) reduce 157) ((T_READONLY) reduce 157) ((T_REQUIRE) reduce 157) ((T_REQUIRE_ONCE) reduce 157) ((T_RETURN) reduce 157) ((T_START_HEREDOC) reduce 157) ((T_STATIC) reduce 157) ((T_STRING) reduce 157) ((T_STRING_CAST) reduce 157) ((T_SWITCH) reduce 157) ((T_THROW) reduce 157) ((T_TRAIT) reduce 157) ((T_TRAIT_C) reduce 157) ((T_TRY) reduce 157) ((T_UNSET) reduce 157) ((T_UNSET_CAST) reduce 157) ((T_USE) reduce 157) ((T_VARIABLE) reduce 157) ((T_WHILE) reduce 157) ((T_YIELD) reduce 157) ((T_YIELD_FROM) reduce 157) (("[") reduce 157) (("`") reduce 157) (("{") reduce 157) (("}") reduce 157) (("~") reduce 157)) 28035 ((("!") reduce 149) (("\"") reduce 149) (("$") reduce 149) (("(") reduce 149) (("+") reduce 149) (("-") reduce 149) ((";") reduce 149) (("@") reduce 149) ((T_ABSTRACT) reduce 149) ((T_ARRAY) reduce 149) ((T_ARRAY_CAST) reduce 149) ((T_ATTRIBUTE) reduce 149) ((T_BOOL_CAST) reduce 149) ((T_BREAK) reduce 149) ((T_CLASS) reduce 149) ((T_CLASS_C) reduce 149) ((T_CLONE) reduce 149) ((T_CONST) reduce 149) ((T_CONSTANT_ENCAPSED_STRING) reduce 149) ((T_CONTINUE) reduce 149) ((T_DEC) reduce 149) ((T_DECLARE) reduce 149) ((T_DIR) reduce 149) ((T_DNUMBER) reduce 149) ((T_DO) reduce 149) ((T_DOUBLE_CAST) reduce 149) ((T_ECHO) reduce 149) ((T_ELSE) reduce 149) ((T_ELSEIF) reduce 149) ((T_EMPTY) reduce 149) ((T_ENUM) reduce 149) ((T_EVAL) reduce 149) ((T_EXIT) reduce 149) ((T_FILE) reduce 149) ((T_FINAL) reduce 149) ((T_FN) reduce 149) ((T_FOR) reduce 149) ((T_FOREACH) reduce 149) ((T_FUNCTION) reduce 149) ((T_FUNC_C) reduce 149) ((T_GLOBAL) reduce 149) ((T_GOTO) reduce 149) ((T_HALT_COMPILER) reduce 149) ((T_IF) reduce 149) ((T_INC) reduce 149) ((T_INCLUDE) reduce 149) ((T_INCLUDE_ONCE) reduce 149) ((T_INLINE_HTML) reduce 149) ((T_INTERFACE) reduce 149) ((T_INT_CAST) reduce 149) ((T_ISSET) reduce 149) ((T_LINE) reduce 149) ((T_LIST) reduce 149) ((T_LNUMBER) reduce 149) ((T_MATCH) reduce 149) ((T_METHOD_C) reduce 149) ((T_NAMESPACE) reduce 149) ((T_NAME_FULLY_QUALIFIED) reduce 149) ((T_NAME_QUALIFIED) reduce 149) ((T_NAME_RELATIVE) reduce 149) ((T_NEW) reduce 149) ((T_NS_C) reduce 149) ((T_OBJECT_CAST) reduce 149) ((T_PRINT) reduce 149) ((T_READONLY) reduce 149) ((T_REQUIRE) reduce 149) ((T_REQUIRE_ONCE) reduce 149) ((T_RETURN) reduce 149) ((T_START_HEREDOC) reduce 149) ((T_STATIC) reduce 149) ((T_STRING) reduce 149) ((T_STRING_CAST) reduce 149) ((T_SWITCH) reduce 149) ((T_THROW) reduce 149) ((T_TRAIT) reduce 149) ((T_TRAIT_C) reduce 149) ((T_TRY) reduce 149) ((T_UNSET) reduce 149) ((T_UNSET_CAST) reduce 149) ((T_USE) reduce 149) ((T_VARIABLE) reduce 149) ((T_WHILE) reduce 149) ((T_YIELD) reduce 149) ((T_YIELD_FROM) reduce 149) (("[") reduce 149) (("`") reduce 149) (("{") reduce 149) (("}") reduce 149) (("~") reduce 149)) 28040 ((("!") reduce 163) (("\"") reduce 163) (("$") reduce 163) (("(") reduce 163) (("+") reduce 163) (("-") reduce 163) ((";") reduce 163) (("@") reduce 163) ((T_ABSTRACT) reduce 163) ((T_ARRAY) reduce 163) ((T_ARRAY_CAST) reduce 163) ((T_ATTRIBUTE) reduce 163) ((T_BOOL_CAST) reduce 163) ((T_BREAK) reduce 163) ((T_CLASS) reduce 163) ((T_CLASS_C) reduce 163) ((T_CLONE) reduce 163) ((T_CONST) reduce 163) ((T_CONSTANT_ENCAPSED_STRING) reduce 163) ((T_CONTINUE) reduce 163) ((T_DEC) reduce 163) ((T_DECLARE) reduce 163) ((T_DIR) reduce 163) ((T_DNUMBER) reduce 163) ((T_DO) reduce 163) ((T_DOUBLE_CAST) reduce 163) ((T_ECHO) reduce 163) ((T_ELSE) reduce 163) ((T_ELSEIF) reduce 163) ((T_EMPTY) reduce 163) ((T_ENUM) reduce 163) ((T_EVAL) reduce 163) ((T_EXIT) reduce 163) ((T_FILE) reduce 163) ((T_FINAL) reduce 163) ((T_FN) reduce 163) ((T_FOR) reduce 163) ((T_FOREACH) reduce 163) ((T_FUNCTION) reduce 163) ((T_FUNC_C) reduce 163) ((T_GLOBAL) reduce 163) ((T_GOTO) reduce 163) ((T_HALT_COMPILER) reduce 163) ((T_IF) reduce 163) ((T_INC) reduce 163) ((T_INCLUDE) reduce 163) ((T_INCLUDE_ONCE) reduce 163) ((T_INLINE_HTML) reduce 163) ((T_INTERFACE) reduce 163) ((T_INT_CAST) reduce 163) ((T_ISSET) reduce 163) ((T_LINE) reduce 163) ((T_LIST) reduce 163) ((T_LNUMBER) reduce 163) ((T_MATCH) reduce 163) ((T_METHOD_C) reduce 163) ((T_NAMESPACE) reduce 163) ((T_NAME_FULLY_QUALIFIED) reduce 163) ((T_NAME_QUALIFIED) reduce 163) ((T_NAME_RELATIVE) reduce 163) ((T_NEW) reduce 163) ((T_NS_C) reduce 163) ((T_OBJECT_CAST) reduce 163) ((T_PRINT) reduce 163) ((T_READONLY) reduce 163) ((T_REQUIRE) reduce 163) ((T_REQUIRE_ONCE) reduce 163) ((T_RETURN) reduce 163) ((T_START_HEREDOC) reduce 163) ((T_STATIC) reduce 163) ((T_STRING) reduce 163) ((T_STRING_CAST) reduce 163) ((T_SWITCH) reduce 163) ((T_THROW) reduce 163) ((T_TRAIT) reduce 163) ((T_TRAIT_C) reduce 163) ((T_TRY) reduce 163) ((T_UNSET) reduce 163) ((T_UNSET_CAST) reduce 163) ((T_USE) reduce 163) ((T_VARIABLE) reduce 163) ((T_WHILE) reduce 163) ((T_YIELD) reduce 163) ((T_YIELD_FROM) reduce 163) (("[") reduce 163) (("`") reduce 163) (("{") reduce 163) (("}") reduce 163) (("~") reduce 163)) 28041 ((("!") reduce 219) (("\"") reduce 219) (("$") reduce 219) (("(") reduce 219) (("+") reduce 219) (("-") reduce 219) ((";") reduce 219) (("@") reduce 219) ((T_ABSTRACT) reduce 219) ((T_ARRAY) reduce 219) ((T_ARRAY_CAST) reduce 219) ((T_ATTRIBUTE) reduce 219) ((T_BOOL_CAST) reduce 219) ((T_BREAK) reduce 219) ((T_CLASS) reduce 219) ((T_CLASS_C) reduce 219) ((T_CLONE) reduce 219) ((T_CONST) reduce 219) ((T_CONSTANT_ENCAPSED_STRING) reduce 219) ((T_CONTINUE) reduce 219) ((T_DEC) reduce 219) ((T_DECLARE) reduce 219) ((T_DIR) reduce 219) ((T_DNUMBER) reduce 219) ((T_DO) reduce 219) ((T_DOUBLE_CAST) reduce 219) ((T_ECHO) reduce 219) ((T_ELSE) reduce 219) ((T_ELSEIF) reduce 219) ((T_EMPTY) reduce 219) ((T_ENUM) reduce 219) ((T_EVAL) reduce 219) ((T_EXIT) reduce 219) ((T_FILE) reduce 219) ((T_FINAL) reduce 219) ((T_FN) reduce 219) ((T_FOR) reduce 219) ((T_FOREACH) reduce 219) ((T_FUNCTION) reduce 219) ((T_FUNC_C) reduce 219) ((T_GLOBAL) reduce 219) ((T_GOTO) reduce 219) ((T_HALT_COMPILER) reduce 219) ((T_IF) reduce 219) ((T_INC) reduce 219) ((T_INCLUDE) reduce 219) ((T_INCLUDE_ONCE) reduce 219) ((T_INLINE_HTML) reduce 219) ((T_INTERFACE) reduce 219) ((T_INT_CAST) reduce 219) ((T_ISSET) reduce 219) ((T_LINE) reduce 219) ((T_LIST) reduce 219) ((T_LNUMBER) reduce 219) ((T_MATCH) reduce 219) ((T_METHOD_C) reduce 219) ((T_NAMESPACE) reduce 219) ((T_NAME_FULLY_QUALIFIED) reduce 219) ((T_NAME_QUALIFIED) reduce 219) ((T_NAME_RELATIVE) reduce 219) ((T_NEW) reduce 219) ((T_NS_C) reduce 219) ((T_OBJECT_CAST) reduce 219) ((T_PRINT) reduce 219) ((T_READONLY) reduce 219) ((T_REQUIRE) reduce 219) ((T_REQUIRE_ONCE) reduce 219) ((T_RETURN) reduce 219) ((T_START_HEREDOC) reduce 219) ((T_STATIC) reduce 219) ((T_STRING) reduce 219) ((T_STRING_CAST) reduce 219) ((T_SWITCH) reduce 219) ((T_THROW) reduce 219) ((T_TRAIT) reduce 219) ((T_TRAIT_C) reduce 219) ((T_TRY) reduce 219) ((T_UNSET) reduce 219) ((T_UNSET_CAST) reduce 219) ((T_USE) reduce 219) ((T_VARIABLE) reduce 219) ((T_WHILE) reduce 219) ((T_YIELD) reduce 219) ((T_YIELD_FROM) reduce 219) (("[") reduce 219) (("`") reduce 219) (("{") reduce 219) (("}") reduce 219) (("~") reduce 219)) 28044 ((("!") reduce 220) (("\"") reduce 220) (("$") reduce 220) (("(") reduce 220) (("+") reduce 220) (("-") reduce 220) ((";") reduce 220) (("@") reduce 220) ((T_ABSTRACT) reduce 220) ((T_ARRAY) reduce 220) ((T_ARRAY_CAST) reduce 220) ((T_ATTRIBUTE) reduce 220) ((T_BOOL_CAST) reduce 220) ((T_BREAK) reduce 220) ((T_CLASS) reduce 220) ((T_CLASS_C) reduce 220) ((T_CLONE) reduce 220) ((T_CONST) reduce 220) ((T_CONSTANT_ENCAPSED_STRING) reduce 220) ((T_CONTINUE) reduce 220) ((T_DEC) reduce 220) ((T_DECLARE) reduce 220) ((T_DIR) reduce 220) ((T_DNUMBER) reduce 220) ((T_DO) reduce 220) ((T_DOUBLE_CAST) reduce 220) ((T_ECHO) reduce 220) ((T_ELSE) reduce 220) ((T_ELSEIF) reduce 220) ((T_EMPTY) reduce 220) ((T_ENUM) reduce 220) ((T_EVAL) reduce 220) ((T_EXIT) reduce 220) ((T_FILE) reduce 220) ((T_FINAL) reduce 220) ((T_FN) reduce 220) ((T_FOR) reduce 220) ((T_FOREACH) reduce 220) ((T_FUNCTION) reduce 220) ((T_FUNC_C) reduce 220) ((T_GLOBAL) reduce 220) ((T_GOTO) reduce 220) ((T_HALT_COMPILER) reduce 220) ((T_IF) reduce 220) ((T_INC) reduce 220) ((T_INCLUDE) reduce 220) ((T_INCLUDE_ONCE) reduce 220) ((T_INLINE_HTML) reduce 220) ((T_INTERFACE) reduce 220) ((T_INT_CAST) reduce 220) ((T_ISSET) reduce 220) ((T_LINE) reduce 220) ((T_LIST) reduce 220) ((T_LNUMBER) reduce 220) ((T_MATCH) reduce 220) ((T_METHOD_C) reduce 220) ((T_NAMESPACE) reduce 220) ((T_NAME_FULLY_QUALIFIED) reduce 220) ((T_NAME_QUALIFIED) reduce 220) ((T_NAME_RELATIVE) reduce 220) ((T_NEW) reduce 220) ((T_NS_C) reduce 220) ((T_OBJECT_CAST) reduce 220) ((T_PRINT) reduce 220) ((T_READONLY) reduce 220) ((T_REQUIRE) reduce 220) ((T_REQUIRE_ONCE) reduce 220) ((T_RETURN) reduce 220) ((T_START_HEREDOC) reduce 220) ((T_STATIC) reduce 220) ((T_STRING) reduce 220) ((T_STRING_CAST) reduce 220) ((T_SWITCH) reduce 220) ((T_THROW) reduce 220) ((T_TRAIT) reduce 220) ((T_TRAIT_C) reduce 220) ((T_TRY) reduce 220) ((T_UNSET) reduce 220) ((T_UNSET_CAST) reduce 220) ((T_USE) reduce 220) ((T_VARIABLE) reduce 220) ((T_WHILE) reduce 220) ((T_YIELD) reduce 220) ((T_YIELD_FROM) reduce 220) (("[") reduce 220) (("`") reduce 220) (("{") reduce 220) (("}") reduce 220) (("~") reduce 220)) 28046 ((("!") reduce 153) (("\"") reduce 153) (("$") reduce 153) (("(") reduce 153) (("+") reduce 153) (("-") reduce 153) ((";") reduce 153) (("@") reduce 153) ((T_ABSTRACT) reduce 153) ((T_ARRAY) reduce 153) ((T_ARRAY_CAST) reduce 153) ((T_ATTRIBUTE) reduce 153) ((T_BOOL_CAST) reduce 153) ((T_BREAK) reduce 153) ((T_CLASS) reduce 153) ((T_CLASS_C) reduce 153) ((T_CLONE) reduce 153) ((T_CONST) reduce 153) ((T_CONSTANT_ENCAPSED_STRING) reduce 153) ((T_CONTINUE) reduce 153) ((T_DEC) reduce 153) ((T_DECLARE) reduce 153) ((T_DIR) reduce 153) ((T_DNUMBER) reduce 153) ((T_DO) reduce 153) ((T_DOUBLE_CAST) reduce 153) ((T_ECHO) reduce 153) ((T_ELSE) reduce 153) ((T_ELSEIF) reduce 153) ((T_EMPTY) reduce 153) ((T_ENUM) reduce 153) ((T_EVAL) reduce 153) ((T_EXIT) reduce 153) ((T_FILE) reduce 153) ((T_FINAL) reduce 153) ((T_FN) reduce 153) ((T_FOR) reduce 153) ((T_FOREACH) reduce 153) ((T_FUNCTION) reduce 153) ((T_FUNC_C) reduce 153) ((T_GLOBAL) reduce 153) ((T_GOTO) reduce 153) ((T_HALT_COMPILER) reduce 153) ((T_IF) reduce 153) ((T_INC) reduce 153) ((T_INCLUDE) reduce 153) ((T_INCLUDE_ONCE) reduce 153) ((T_INLINE_HTML) reduce 153) ((T_INTERFACE) reduce 153) ((T_INT_CAST) reduce 153) ((T_ISSET) reduce 153) ((T_LINE) reduce 153) ((T_LIST) reduce 153) ((T_LNUMBER) reduce 153) ((T_MATCH) reduce 153) ((T_METHOD_C) reduce 153) ((T_NAMESPACE) reduce 153) ((T_NAME_FULLY_QUALIFIED) reduce 153) ((T_NAME_QUALIFIED) reduce 153) ((T_NAME_RELATIVE) reduce 153) ((T_NEW) reduce 153) ((T_NS_C) reduce 153) ((T_OBJECT_CAST) reduce 153) ((T_PRINT) reduce 153) ((T_READONLY) reduce 153) ((T_REQUIRE) reduce 153) ((T_REQUIRE_ONCE) reduce 153) ((T_RETURN) reduce 153) ((T_START_HEREDOC) reduce 153) ((T_STATIC) reduce 153) ((T_STRING) reduce 153) ((T_STRING_CAST) reduce 153) ((T_SWITCH) reduce 153) ((T_THROW) reduce 153) ((T_TRAIT) reduce 153) ((T_TRAIT_C) reduce 153) ((T_TRY) reduce 153) ((T_UNSET) reduce 153) ((T_UNSET_CAST) reduce 153) ((T_USE) reduce 153) ((T_VARIABLE) reduce 153) ((T_WHILE) reduce 153) ((T_YIELD) reduce 153) ((T_YIELD_FROM) reduce 153) (("[") reduce 153) (("`") reduce 153) (("{") reduce 153) (("}") reduce 153) (("~") reduce 153)) 28048 ((("!") reduce 152) (("\"") reduce 152) (("$") reduce 152) (("(") reduce 152) (("+") reduce 152) (("-") reduce 152) ((";") reduce 152) (("@") reduce 152) ((T_ABSTRACT) reduce 152) ((T_ARRAY) reduce 152) ((T_ARRAY_CAST) reduce 152) ((T_ATTRIBUTE) reduce 152) ((T_BOOL_CAST) reduce 152) ((T_BREAK) reduce 152) ((T_CLASS) reduce 152) ((T_CLASS_C) reduce 152) ((T_CLONE) reduce 152) ((T_CONST) reduce 152) ((T_CONSTANT_ENCAPSED_STRING) reduce 152) ((T_CONTINUE) reduce 152) ((T_DEC) reduce 152) ((T_DECLARE) reduce 152) ((T_DIR) reduce 152) ((T_DNUMBER) reduce 152) ((T_DO) reduce 152) ((T_DOUBLE_CAST) reduce 152) ((T_ECHO) reduce 152) ((T_ELSE) reduce 152) ((T_ELSEIF) reduce 152) ((T_EMPTY) reduce 152) ((T_ENUM) reduce 152) ((T_EVAL) reduce 152) ((T_EXIT) reduce 152) ((T_FILE) reduce 152) ((T_FINAL) reduce 152) ((T_FN) reduce 152) ((T_FOR) reduce 152) ((T_FOREACH) reduce 152) ((T_FUNCTION) reduce 152) ((T_FUNC_C) reduce 152) ((T_GLOBAL) reduce 152) ((T_GOTO) reduce 152) ((T_HALT_COMPILER) reduce 152) ((T_IF) reduce 152) ((T_INC) reduce 152) ((T_INCLUDE) reduce 152) ((T_INCLUDE_ONCE) reduce 152) ((T_INLINE_HTML) reduce 152) ((T_INTERFACE) reduce 152) ((T_INT_CAST) reduce 152) ((T_ISSET) reduce 152) ((T_LINE) reduce 152) ((T_LIST) reduce 152) ((T_LNUMBER) reduce 152) ((T_MATCH) reduce 152) ((T_METHOD_C) reduce 152) ((T_NAMESPACE) reduce 152) ((T_NAME_FULLY_QUALIFIED) reduce 152) ((T_NAME_QUALIFIED) reduce 152) ((T_NAME_RELATIVE) reduce 152) ((T_NEW) reduce 152) ((T_NS_C) reduce 152) ((T_OBJECT_CAST) reduce 152) ((T_PRINT) reduce 152) ((T_READONLY) reduce 152) ((T_REQUIRE) reduce 152) ((T_REQUIRE_ONCE) reduce 152) ((T_RETURN) reduce 152) ((T_START_HEREDOC) reduce 152) ((T_STATIC) reduce 152) ((T_STRING) reduce 152) ((T_STRING_CAST) reduce 152) ((T_SWITCH) reduce 152) ((T_THROW) reduce 152) ((T_TRAIT) reduce 152) ((T_TRAIT_C) reduce 152) ((T_TRY) reduce 152) ((T_UNSET) reduce 152) ((T_UNSET_CAST) reduce 152) ((T_USE) reduce 152) ((T_VARIABLE) reduce 152) ((T_WHILE) reduce 152) ((T_YIELD) reduce 152) ((T_YIELD_FROM) reduce 152) (("[") reduce 152) (("`") reduce 152) (("{") reduce 152) (("}") reduce 152) (("~") reduce 152)) 28049 ((("!") reduce 244) (("\"") reduce 244) (("$") reduce 244) (("(") reduce 244) (("+") reduce 244) (("-") reduce 244) ((";") reduce 244) (("@") reduce 244) ((T_ABSTRACT) reduce 244) ((T_ARRAY) reduce 244) ((T_ARRAY_CAST) reduce 244) ((T_ATTRIBUTE) reduce 244) ((T_BOOL_CAST) reduce 244) ((T_BREAK) reduce 244) ((T_CLASS) reduce 244) ((T_CLASS_C) reduce 244) ((T_CLONE) reduce 244) ((T_CONST) reduce 244) ((T_CONSTANT_ENCAPSED_STRING) reduce 244) ((T_CONTINUE) reduce 244) ((T_DEC) reduce 244) ((T_DECLARE) reduce 244) ((T_DIR) reduce 244) ((T_DNUMBER) reduce 244) ((T_DO) reduce 244) ((T_DOUBLE_CAST) reduce 244) ((T_ECHO) reduce 244) ((T_EMPTY) reduce 244) ((T_ENUM) reduce 244) ((T_EVAL) reduce 244) ((T_EXIT) reduce 244) ((T_FILE) reduce 244) ((T_FINAL) reduce 244) ((T_FN) reduce 244) ((T_FOR) reduce 244) ((T_FOREACH) reduce 244) ((T_FUNCTION) reduce 244) ((T_FUNC_C) reduce 244) ((T_GLOBAL) reduce 244) ((T_GOTO) reduce 244) ((T_HALT_COMPILER) reduce 244) ((T_IF) reduce 244) ((T_INC) reduce 244) ((T_INCLUDE) reduce 244) ((T_INCLUDE_ONCE) reduce 244) ((T_INLINE_HTML) reduce 244) ((T_INTERFACE) reduce 244) ((T_INT_CAST) reduce 244) ((T_ISSET) reduce 244) ((T_LINE) reduce 244) ((T_LIST) reduce 244) ((T_LNUMBER) reduce 244) ((T_MATCH) reduce 244) ((T_METHOD_C) reduce 244) ((T_NAMESPACE) reduce 244) ((T_NAME_FULLY_QUALIFIED) reduce 244) ((T_NAME_QUALIFIED) reduce 244) ((T_NAME_RELATIVE) reduce 244) ((T_NEW) reduce 244) ((T_NS_C) reduce 244) ((T_OBJECT_CAST) reduce 244) ((T_PRINT) reduce 244) ((T_READONLY) reduce 244) ((T_REQUIRE) reduce 244) ((T_REQUIRE_ONCE) reduce 244) ((T_RETURN) reduce 244) ((T_START_HEREDOC) reduce 244) ((T_STATIC) reduce 244) ((T_STRING) reduce 244) ((T_STRING_CAST) reduce 244) ((T_SWITCH) reduce 244) ((T_THROW) reduce 244) ((T_TRAIT) reduce 244) ((T_TRAIT_C) reduce 244) ((T_TRY) reduce 244) ((T_UNSET) reduce 244) ((T_UNSET_CAST) reduce 244) ((T_USE) reduce 244) ((T_VARIABLE) reduce 244) ((T_WHILE) reduce 244) ((T_YIELD) reduce 244) ((T_YIELD_FROM) reduce 244) (("[") reduce 244) (("`") reduce 244) (("{") reduce 244) (("}") reduce 244) (("~") reduce 244)) 28060 ((("!") reduce 455) (("\"") reduce 455) (("$") reduce 455) (("(") reduce 455) (("+") reduce 455) (("-") reduce 455) ((";") reduce 455) (("@") reduce 455) ((T_ABSTRACT) reduce 455) ((T_ARRAY) reduce 455) ((T_ARRAY_CAST) reduce 455) ((T_ATTRIBUTE) reduce 455) ((T_BOOL_CAST) reduce 455) ((T_BREAK) reduce 455) ((T_CLASS) reduce 455) ((T_CLASS_C) reduce 455) ((T_CLONE) reduce 455) ((T_CONST) reduce 455) ((T_CONSTANT_ENCAPSED_STRING) reduce 455) ((T_CONTINUE) reduce 455) ((T_DEC) reduce 455) ((T_DECLARE) reduce 455) ((T_DIR) reduce 455) ((T_DNUMBER) reduce 455) ((T_DO) reduce 455) ((T_DOUBLE_CAST) reduce 455) ((T_ECHO) reduce 455) ((T_EMPTY) reduce 455) ((T_ENUM) reduce 455) ((T_EVAL) reduce 455) ((T_EXIT) reduce 455) ((T_FILE) reduce 455) ((T_FINAL) reduce 455) ((T_FN) reduce 455) ((T_FOR) reduce 455) ((T_FOREACH) reduce 455) ((T_FUNCTION) reduce 455) ((T_FUNC_C) reduce 455) ((T_GLOBAL) reduce 455) ((T_GOTO) reduce 455) ((T_HALT_COMPILER) reduce 455) ((T_IF) reduce 455) ((T_INC) reduce 455) ((T_INCLUDE) reduce 455) ((T_INCLUDE_ONCE) reduce 455) ((T_INLINE_HTML) reduce 455) ((T_INTERFACE) reduce 455) ((T_INT_CAST) reduce 455) ((T_ISSET) reduce 455) ((T_LINE) reduce 455) ((T_LIST) reduce 455) ((T_LNUMBER) reduce 455) ((T_MATCH) reduce 455) ((T_METHOD_C) reduce 455) ((T_NAMESPACE) reduce 455) ((T_NAME_FULLY_QUALIFIED) reduce 455) ((T_NAME_QUALIFIED) reduce 455) ((T_NAME_RELATIVE) reduce 455) ((T_NEW) reduce 455) ((T_NS_C) reduce 455) ((T_OBJECT_CAST) reduce 455) ((T_PRINT) reduce 455) ((T_READONLY) reduce 455) ((T_REQUIRE) reduce 455) ((T_REQUIRE_ONCE) reduce 455) ((T_RETURN) reduce 455) ((T_START_HEREDOC) reduce 455) ((T_STATIC) reduce 455) ((T_STRING) reduce 455) ((T_STRING_CAST) reduce 455) ((T_SWITCH) reduce 455) ((T_THROW) reduce 455) ((T_TRAIT) reduce 455) ((T_TRAIT_C) reduce 455) ((T_TRY) reduce 455) ((T_UNSET) reduce 455) ((T_UNSET_CAST) reduce 455) ((T_USE) reduce 455) ((T_VARIABLE) reduce 455) ((T_WHILE) reduce 455) ((T_YIELD) reduce 455) ((T_YIELD_FROM) reduce 455) (("[") reduce 455) (("`") reduce 455) (("{") reduce 455) (("}") reduce 455) (("~") reduce 455)) 28061 ((("!") reduce 181) (("\"") reduce 181) (("$") reduce 181) (("(") reduce 181) (("+") reduce 181) (("-") reduce 181) ((";") reduce 181) (("@") reduce 181) ((T_ABSTRACT) reduce 181) ((T_ARRAY) reduce 181) ((T_ARRAY_CAST) reduce 181) ((T_ATTRIBUTE) reduce 181) ((T_BOOL_CAST) reduce 181) ((T_BREAK) reduce 181) ((T_CLASS) reduce 181) ((T_CLASS_C) reduce 181) ((T_CLONE) reduce 181) ((T_CONST) reduce 181) ((T_CONSTANT_ENCAPSED_STRING) reduce 181) ((T_CONTINUE) reduce 181) ((T_DEC) reduce 181) ((T_DECLARE) reduce 181) ((T_DIR) reduce 181) ((T_DNUMBER) reduce 181) ((T_DO) reduce 181) ((T_DOUBLE_CAST) reduce 181) ((T_ECHO) reduce 181) ((T_EMPTY) reduce 181) ((T_ENUM) reduce 181) ((T_EVAL) reduce 181) ((T_EXIT) reduce 181) ((T_FILE) reduce 181) ((T_FINAL) reduce 181) ((T_FN) reduce 181) ((T_FOR) reduce 181) ((T_FOREACH) reduce 181) ((T_FUNCTION) reduce 181) ((T_FUNC_C) reduce 181) ((T_GLOBAL) reduce 181) ((T_GOTO) reduce 181) ((T_HALT_COMPILER) reduce 181) ((T_IF) reduce 181) ((T_INC) reduce 181) ((T_INCLUDE) reduce 181) ((T_INCLUDE_ONCE) reduce 181) ((T_INLINE_HTML) reduce 181) ((T_INTERFACE) reduce 181) ((T_INT_CAST) reduce 181) ((T_ISSET) reduce 181) ((T_LINE) reduce 181) ((T_LIST) reduce 181) ((T_LNUMBER) reduce 181) ((T_MATCH) reduce 181) ((T_METHOD_C) reduce 181) ((T_NAMESPACE) reduce 181) ((T_NAME_FULLY_QUALIFIED) reduce 181) ((T_NAME_QUALIFIED) reduce 181) ((T_NAME_RELATIVE) reduce 181) ((T_NEW) reduce 181) ((T_NS_C) reduce 181) ((T_OBJECT_CAST) reduce 181) ((T_PRINT) reduce 181) ((T_READONLY) reduce 181) ((T_REQUIRE) reduce 181) ((T_REQUIRE_ONCE) reduce 181) ((T_RETURN) reduce 181) ((T_START_HEREDOC) reduce 181) ((T_STATIC) reduce 181) ((T_STRING) reduce 181) ((T_STRING_CAST) reduce 181) ((T_SWITCH) reduce 181) ((T_THROW) reduce 181) ((T_TRAIT) reduce 181) ((T_TRAIT_C) reduce 181) ((T_TRY) reduce 181) ((T_UNSET) reduce 181) ((T_UNSET_CAST) reduce 181) ((T_USE) reduce 181) ((T_VARIABLE) reduce 181) ((T_WHILE) reduce 181) ((T_YIELD) reduce 181) ((T_YIELD_FROM) reduce 181) (("[") reduce 181) (("`") reduce 181) (("{") reduce 181) (("}") reduce 181) (("~") reduce 181)) 28062 ((("!") reduce 159) (("\"") reduce 159) (("$") reduce 159) (("(") reduce 159) (("+") reduce 159) (("-") reduce 159) ((";") reduce 159) (("@") reduce 159) ((T_ABSTRACT) reduce 159) ((T_ARRAY) reduce 159) ((T_ARRAY_CAST) reduce 159) ((T_ATTRIBUTE) reduce 159) ((T_BOOL_CAST) reduce 159) ((T_BREAK) reduce 159) ((T_CLASS) reduce 159) ((T_CLASS_C) reduce 159) ((T_CLONE) reduce 159) ((T_CONST) reduce 159) ((T_CONSTANT_ENCAPSED_STRING) reduce 159) ((T_CONTINUE) reduce 159) ((T_DEC) reduce 159) ((T_DECLARE) reduce 159) ((T_DIR) reduce 159) ((T_DNUMBER) reduce 159) ((T_DO) reduce 159) ((T_DOUBLE_CAST) reduce 159) ((T_ECHO) reduce 159) ((T_EMPTY) reduce 159) ((T_ENUM) reduce 159) ((T_EVAL) reduce 159) ((T_EXIT) reduce 159) ((T_FILE) reduce 159) ((T_FINAL) reduce 159) ((T_FN) reduce 159) ((T_FOR) reduce 159) ((T_FOREACH) reduce 159) ((T_FUNCTION) reduce 159) ((T_FUNC_C) reduce 159) ((T_GLOBAL) reduce 159) ((T_GOTO) reduce 159) ((T_HALT_COMPILER) reduce 159) ((T_IF) reduce 159) ((T_INC) reduce 159) ((T_INCLUDE) reduce 159) ((T_INCLUDE_ONCE) reduce 159) ((T_INLINE_HTML) reduce 159) ((T_INTERFACE) reduce 159) ((T_INT_CAST) reduce 159) ((T_ISSET) reduce 159) ((T_LINE) reduce 159) ((T_LIST) reduce 159) ((T_LNUMBER) reduce 159) ((T_MATCH) reduce 159) ((T_METHOD_C) reduce 159) ((T_NAMESPACE) reduce 159) ((T_NAME_FULLY_QUALIFIED) reduce 159) ((T_NAME_QUALIFIED) reduce 159) ((T_NAME_RELATIVE) reduce 159) ((T_NEW) reduce 159) ((T_NS_C) reduce 159) ((T_OBJECT_CAST) reduce 159) ((T_PRINT) reduce 159) ((T_READONLY) reduce 159) ((T_REQUIRE) reduce 159) ((T_REQUIRE_ONCE) reduce 159) ((T_RETURN) reduce 159) ((T_START_HEREDOC) reduce 159) ((T_STATIC) reduce 159) ((T_STRING) reduce 159) ((T_STRING_CAST) reduce 159) ((T_SWITCH) reduce 159) ((T_THROW) reduce 159) ((T_TRAIT) reduce 159) ((T_TRAIT_C) reduce 159) ((T_TRY) reduce 159) ((T_UNSET) reduce 159) ((T_UNSET_CAST) reduce 159) ((T_USE) reduce 159) ((T_VARIABLE) reduce 159) ((T_WHILE) reduce 159) ((T_YIELD) reduce 159) ((T_YIELD_FROM) reduce 159) (("[") reduce 159) (("`") reduce 159) (("{") reduce 159) (("}") reduce 159) (("~") reduce 159)) 28070 ((("!") reduce 186) (("\"") reduce 186) (("$") reduce 186) (("(") reduce 186) (("+") reduce 186) (("-") reduce 186) ((";") reduce 186) (("@") reduce 186) ((T_ABSTRACT) reduce 186) ((T_ARRAY) reduce 186) ((T_ARRAY_CAST) reduce 186) ((T_ATTRIBUTE) reduce 186) ((T_BOOL_CAST) reduce 186) ((T_BREAK) reduce 186) ((T_CLASS) reduce 186) ((T_CLASS_C) reduce 186) ((T_CLONE) reduce 186) ((T_CONST) reduce 186) ((T_CONSTANT_ENCAPSED_STRING) reduce 186) ((T_CONTINUE) reduce 186) ((T_DEC) reduce 186) ((T_DECLARE) reduce 186) ((T_DIR) reduce 186) ((T_DNUMBER) reduce 186) ((T_DO) reduce 186) ((T_DOUBLE_CAST) reduce 186) ((T_ECHO) reduce 186) ((T_EMPTY) reduce 186) ((T_ENUM) reduce 186) ((T_EVAL) reduce 186) ((T_EXIT) reduce 186) ((T_FILE) reduce 186) ((T_FINAL) reduce 186) ((T_FN) reduce 186) ((T_FOR) reduce 186) ((T_FOREACH) reduce 186) ((T_FUNCTION) reduce 186) ((T_FUNC_C) reduce 186) ((T_GLOBAL) reduce 186) ((T_GOTO) reduce 186) ((T_HALT_COMPILER) reduce 186) ((T_IF) reduce 186) ((T_INC) reduce 186) ((T_INCLUDE) reduce 186) ((T_INCLUDE_ONCE) reduce 186) ((T_INLINE_HTML) reduce 186) ((T_INTERFACE) reduce 186) ((T_INT_CAST) reduce 186) ((T_ISSET) reduce 186) ((T_LINE) reduce 186) ((T_LIST) reduce 186) ((T_LNUMBER) reduce 186) ((T_MATCH) reduce 186) ((T_METHOD_C) reduce 186) ((T_NAMESPACE) reduce 186) ((T_NAME_FULLY_QUALIFIED) reduce 186) ((T_NAME_QUALIFIED) reduce 186) ((T_NAME_RELATIVE) reduce 186) ((T_NEW) reduce 186) ((T_NS_C) reduce 186) ((T_OBJECT_CAST) reduce 186) ((T_PRINT) reduce 186) ((T_READONLY) reduce 186) ((T_REQUIRE) reduce 186) ((T_REQUIRE_ONCE) reduce 186) ((T_RETURN) reduce 186) ((T_START_HEREDOC) reduce 186) ((T_STATIC) reduce 186) ((T_STRING) reduce 186) ((T_STRING_CAST) reduce 186) ((T_SWITCH) reduce 186) ((T_THROW) reduce 186) ((T_TRAIT) reduce 186) ((T_TRAIT_C) reduce 186) ((T_TRY) reduce 186) ((T_UNSET) reduce 186) ((T_UNSET_CAST) reduce 186) ((T_USE) reduce 186) ((T_VARIABLE) reduce 186) ((T_WHILE) reduce 186) ((T_YIELD) reduce 186) ((T_YIELD_FROM) reduce 186) (("[") reduce 186) (("`") reduce 186) (("{") reduce 186) (("}") reduce 186) (("~") reduce 186)) 28071 ((("!") reduce 109) (("\"") reduce 109) (("$") reduce 109) (("(") reduce 109) (("+") reduce 109) (("-") reduce 109) ((";") reduce 109) (("@") reduce 109) ((T_ABSTRACT) reduce 109) ((T_ARRAY) reduce 109) ((T_ARRAY_CAST) reduce 109) ((T_ATTRIBUTE) reduce 109) ((T_BOOL_CAST) reduce 109) ((T_BREAK) reduce 109) ((T_CLASS) reduce 109) ((T_CLASS_C) reduce 109) ((T_CLONE) reduce 109) ((T_CONST) reduce 109) ((T_CONSTANT_ENCAPSED_STRING) reduce 109) ((T_CONTINUE) reduce 109) ((T_DEC) reduce 109) ((T_DECLARE) reduce 109) ((T_DIR) reduce 109) ((T_DNUMBER) reduce 109) ((T_DO) reduce 109) ((T_DOUBLE_CAST) reduce 109) ((T_ECHO) reduce 109) ((T_EMPTY) reduce 109) ((T_ENUM) reduce 109) ((T_EVAL) reduce 109) ((T_EXIT) reduce 109) ((T_FILE) reduce 109) ((T_FINAL) reduce 109) ((T_FN) reduce 109) ((T_FOR) reduce 109) ((T_FOREACH) reduce 109) ((T_FUNCTION) reduce 109) ((T_FUNC_C) reduce 109) ((T_GLOBAL) reduce 109) ((T_GOTO) reduce 109) ((T_HALT_COMPILER) reduce 109) ((T_IF) reduce 109) ((T_INC) reduce 109) ((T_INCLUDE) reduce 109) ((T_INCLUDE_ONCE) reduce 109) ((T_INLINE_HTML) reduce 109) ((T_INTERFACE) reduce 109) ((T_INT_CAST) reduce 109) ((T_ISSET) reduce 109) ((T_LINE) reduce 109) ((T_LIST) reduce 109) ((T_LNUMBER) reduce 109) ((T_MATCH) reduce 109) ((T_METHOD_C) reduce 109) ((T_NAMESPACE) reduce 109) ((T_NAME_FULLY_QUALIFIED) reduce 109) ((T_NAME_QUALIFIED) reduce 109) ((T_NAME_RELATIVE) reduce 109) ((T_NEW) reduce 109) ((T_NS_C) reduce 109) ((T_OBJECT_CAST) reduce 109) ((T_PRINT) reduce 109) ((T_READONLY) reduce 109) ((T_REQUIRE) reduce 109) ((T_REQUIRE_ONCE) reduce 109) ((T_RETURN) reduce 109) ((T_START_HEREDOC) reduce 109) ((T_STATIC) reduce 109) ((T_STRING) reduce 109) ((T_STRING_CAST) reduce 109) ((T_SWITCH) reduce 109) ((T_THROW) reduce 109) ((T_TRAIT) reduce 109) ((T_TRAIT_C) reduce 109) ((T_TRY) reduce 109) ((T_UNSET) reduce 109) ((T_UNSET_CAST) reduce 109) ((T_USE) reduce 109) ((T_VARIABLE) reduce 109) ((T_WHILE) reduce 109) ((T_YIELD) reduce 109) ((T_YIELD_FROM) reduce 109) (("[") reduce 109) (("`") reduce 109) (("{") reduce 109) (("}") reduce 109) (("~") reduce 109)) 28074 ((("!") reduce 247) (("\"") reduce 247) (("$") reduce 247) (("(") reduce 247) (("+") reduce 247) (("-") reduce 247) ((";") reduce 247) (("@") reduce 247) ((T_ABSTRACT) reduce 247) ((T_ARRAY) reduce 247) ((T_ARRAY_CAST) reduce 247) ((T_ATTRIBUTE) reduce 247) ((T_BOOL_CAST) reduce 247) ((T_BREAK) reduce 247) ((T_CLASS) reduce 247) ((T_CLASS_C) reduce 247) ((T_CLONE) reduce 247) ((T_CONST) reduce 247) ((T_CONSTANT_ENCAPSED_STRING) reduce 247) ((T_CONTINUE) reduce 247) ((T_DEC) reduce 247) ((T_DECLARE) reduce 247) ((T_DIR) reduce 247) ((T_DNUMBER) reduce 247) ((T_DO) reduce 247) ((T_DOUBLE_CAST) reduce 247) ((T_ECHO) reduce 247) ((T_EMPTY) reduce 247) ((T_ENUM) reduce 247) ((T_EVAL) reduce 247) ((T_EXIT) reduce 247) ((T_FILE) reduce 247) ((T_FINAL) reduce 247) ((T_FN) reduce 247) ((T_FOR) reduce 247) ((T_FOREACH) reduce 247) ((T_FUNCTION) reduce 247) ((T_FUNC_C) reduce 247) ((T_GLOBAL) reduce 247) ((T_GOTO) reduce 247) ((T_HALT_COMPILER) reduce 247) ((T_IF) reduce 247) ((T_INC) reduce 247) ((T_INCLUDE) reduce 247) ((T_INCLUDE_ONCE) reduce 247) ((T_INLINE_HTML) reduce 247) ((T_INTERFACE) reduce 247) ((T_INT_CAST) reduce 247) ((T_ISSET) reduce 247) ((T_LINE) reduce 247) ((T_LIST) reduce 247) ((T_LNUMBER) reduce 247) ((T_MATCH) reduce 247) ((T_METHOD_C) reduce 247) ((T_NAMESPACE) reduce 247) ((T_NAME_FULLY_QUALIFIED) reduce 247) ((T_NAME_QUALIFIED) reduce 247) ((T_NAME_RELATIVE) reduce 247) ((T_NEW) reduce 247) ((T_NS_C) reduce 247) ((T_OBJECT_CAST) reduce 247) ((T_PRINT) reduce 247) ((T_READONLY) reduce 247) ((T_REQUIRE) reduce 247) ((T_REQUIRE_ONCE) reduce 247) ((T_RETURN) reduce 247) ((T_START_HEREDOC) reduce 247) ((T_STATIC) reduce 247) ((T_STRING) reduce 247) ((T_STRING_CAST) reduce 247) ((T_SWITCH) reduce 247) ((T_THROW) reduce 247) ((T_TRAIT) reduce 247) ((T_TRAIT_C) reduce 247) ((T_TRY) reduce 247) ((T_UNSET) reduce 247) ((T_UNSET_CAST) reduce 247) ((T_USE) reduce 247) ((T_VARIABLE) reduce 247) ((T_WHILE) reduce 247) ((T_YIELD) reduce 247) ((T_YIELD_FROM) reduce 247) (("[") reduce 247) (("`") reduce 247) (("{") reduce 247) (("}") reduce 247) (("~") reduce 247)) 28078 ((("!") reduce 248) (("\"") reduce 248) (("$") reduce 248) (("(") reduce 248) (("+") reduce 248) (("-") reduce 248) ((";") reduce 248) (("@") reduce 248) ((T_ABSTRACT) reduce 248) ((T_ARRAY) reduce 248) ((T_ARRAY_CAST) reduce 248) ((T_ATTRIBUTE) reduce 248) ((T_BOOL_CAST) reduce 248) ((T_BREAK) reduce 248) ((T_CLASS) reduce 248) ((T_CLASS_C) reduce 248) ((T_CLONE) reduce 248) ((T_CONST) reduce 248) ((T_CONSTANT_ENCAPSED_STRING) reduce 248) ((T_CONTINUE) reduce 248) ((T_DEC) reduce 248) ((T_DECLARE) reduce 248) ((T_DIR) reduce 248) ((T_DNUMBER) reduce 248) ((T_DO) reduce 248) ((T_DOUBLE_CAST) reduce 248) ((T_ECHO) reduce 248) ((T_EMPTY) reduce 248) ((T_ENUM) reduce 248) ((T_EVAL) reduce 248) ((T_EXIT) reduce 248) ((T_FILE) reduce 248) ((T_FINAL) reduce 248) ((T_FN) reduce 248) ((T_FOR) reduce 248) ((T_FOREACH) reduce 248) ((T_FUNCTION) reduce 248) ((T_FUNC_C) reduce 248) ((T_GLOBAL) reduce 248) ((T_GOTO) reduce 248) ((T_HALT_COMPILER) reduce 248) ((T_IF) reduce 248) ((T_INC) reduce 248) ((T_INCLUDE) reduce 248) ((T_INCLUDE_ONCE) reduce 248) ((T_INLINE_HTML) reduce 248) ((T_INTERFACE) reduce 248) ((T_INT_CAST) reduce 248) ((T_ISSET) reduce 248) ((T_LINE) reduce 248) ((T_LIST) reduce 248) ((T_LNUMBER) reduce 248) ((T_MATCH) reduce 248) ((T_METHOD_C) reduce 248) ((T_NAMESPACE) reduce 248) ((T_NAME_FULLY_QUALIFIED) reduce 248) ((T_NAME_QUALIFIED) reduce 248) ((T_NAME_RELATIVE) reduce 248) ((T_NEW) reduce 248) ((T_NS_C) reduce 248) ((T_OBJECT_CAST) reduce 248) ((T_PRINT) reduce 248) ((T_READONLY) reduce 248) ((T_REQUIRE) reduce 248) ((T_REQUIRE_ONCE) reduce 248) ((T_RETURN) reduce 248) ((T_START_HEREDOC) reduce 248) ((T_STATIC) reduce 248) ((T_STRING) reduce 248) ((T_STRING_CAST) reduce 248) ((T_SWITCH) reduce 248) ((T_THROW) reduce 248) ((T_TRAIT) reduce 248) ((T_TRAIT_C) reduce 248) ((T_TRY) reduce 248) ((T_UNSET) reduce 248) ((T_UNSET_CAST) reduce 248) ((T_USE) reduce 248) ((T_VARIABLE) reduce 248) ((T_WHILE) reduce 248) ((T_YIELD) reduce 248) ((T_YIELD_FROM) reduce 248) (("[") reduce 248) (("`") reduce 248) (("{") reduce 248) (("}") reduce 248) (("~") reduce 248)) 28083 ((("!") reduce 239) (("\"") reduce 239) (("$") reduce 239) (("(") reduce 239) (("+") reduce 239) (("-") reduce 239) ((";") reduce 239) (("@") reduce 239) ((T_ABSTRACT) reduce 239) ((T_ARRAY) reduce 239) ((T_ARRAY_CAST) reduce 239) ((T_ATTRIBUTE) reduce 239) ((T_BOOL_CAST) reduce 239) ((T_BREAK) reduce 239) ((T_CLASS) reduce 239) ((T_CLASS_C) reduce 239) ((T_CLONE) reduce 239) ((T_CONST) reduce 239) ((T_CONSTANT_ENCAPSED_STRING) reduce 239) ((T_CONTINUE) reduce 239) ((T_DEC) reduce 239) ((T_DECLARE) reduce 239) ((T_DIR) reduce 239) ((T_DNUMBER) reduce 239) ((T_DO) reduce 239) ((T_DOUBLE_CAST) reduce 239) ((T_ECHO) reduce 239) ((T_EMPTY) reduce 239) ((T_ENUM) reduce 239) ((T_EVAL) reduce 239) ((T_EXIT) reduce 239) ((T_FILE) reduce 239) ((T_FINAL) reduce 239) ((T_FN) reduce 239) ((T_FOR) reduce 239) ((T_FOREACH) reduce 239) ((T_FUNCTION) reduce 239) ((T_FUNC_C) reduce 239) ((T_GLOBAL) reduce 239) ((T_GOTO) reduce 239) ((T_HALT_COMPILER) reduce 239) ((T_IF) reduce 239) ((T_INC) reduce 239) ((T_INCLUDE) reduce 239) ((T_INCLUDE_ONCE) reduce 239) ((T_INLINE_HTML) reduce 239) ((T_INTERFACE) reduce 239) ((T_INT_CAST) reduce 239) ((T_ISSET) reduce 239) ((T_LINE) reduce 239) ((T_LIST) reduce 239) ((T_LNUMBER) reduce 239) ((T_MATCH) reduce 239) ((T_METHOD_C) reduce 239) ((T_NAMESPACE) reduce 239) ((T_NAME_FULLY_QUALIFIED) reduce 239) ((T_NAME_QUALIFIED) reduce 239) ((T_NAME_RELATIVE) reduce 239) ((T_NEW) reduce 239) ((T_NS_C) reduce 239) ((T_OBJECT_CAST) reduce 239) ((T_PRINT) reduce 239) ((T_READONLY) reduce 239) ((T_REQUIRE) reduce 239) ((T_REQUIRE_ONCE) reduce 239) ((T_RETURN) reduce 239) ((T_START_HEREDOC) reduce 239) ((T_STATIC) reduce 239) ((T_STRING) reduce 239) ((T_STRING_CAST) reduce 239) ((T_SWITCH) reduce 239) ((T_THROW) reduce 239) ((T_TRAIT) reduce 239) ((T_TRAIT_C) reduce 239) ((T_TRY) reduce 239) ((T_UNSET) reduce 239) ((T_UNSET_CAST) reduce 239) ((T_USE) reduce 239) ((T_VARIABLE) reduce 239) ((T_WHILE) reduce 239) ((T_YIELD) reduce 239) ((T_YIELD_FROM) reduce 239) (("[") reduce 239) (("`") reduce 239) (("{") reduce 239) (("}") reduce 239) (("~") reduce 239)) 28084 ((("!") reduce 148) (("\"") reduce 148) (("$") reduce 148) (("(") reduce 148) (("+") reduce 148) (("-") reduce 148) ((";") reduce 148) (("@") reduce 148) ((T_ABSTRACT) reduce 148) ((T_ARRAY) reduce 148) ((T_ARRAY_CAST) reduce 148) ((T_ATTRIBUTE) reduce 148) ((T_BOOL_CAST) reduce 148) ((T_BREAK) reduce 148) ((T_CLASS) reduce 148) ((T_CLASS_C) reduce 148) ((T_CLONE) reduce 148) ((T_CONST) reduce 148) ((T_CONSTANT_ENCAPSED_STRING) reduce 148) ((T_CONTINUE) reduce 148) ((T_DEC) reduce 148) ((T_DECLARE) reduce 148) ((T_DIR) reduce 148) ((T_DNUMBER) reduce 148) ((T_DO) reduce 148) ((T_DOUBLE_CAST) reduce 148) ((T_ECHO) reduce 148) ((T_EMPTY) reduce 148) ((T_ENUM) reduce 148) ((T_EVAL) reduce 148) ((T_EXIT) reduce 148) ((T_FILE) reduce 148) ((T_FINAL) reduce 148) ((T_FN) reduce 148) ((T_FOR) reduce 148) ((T_FOREACH) reduce 148) ((T_FUNCTION) reduce 148) ((T_FUNC_C) reduce 148) ((T_GLOBAL) reduce 148) ((T_GOTO) reduce 148) ((T_HALT_COMPILER) reduce 148) ((T_IF) reduce 148) ((T_INC) reduce 148) ((T_INCLUDE) reduce 148) ((T_INCLUDE_ONCE) reduce 148) ((T_INLINE_HTML) reduce 148) ((T_INTERFACE) reduce 148) ((T_INT_CAST) reduce 148) ((T_ISSET) reduce 148) ((T_LINE) reduce 148) ((T_LIST) reduce 148) ((T_LNUMBER) reduce 148) ((T_MATCH) reduce 148) ((T_METHOD_C) reduce 148) ((T_NAMESPACE) reduce 148) ((T_NAME_FULLY_QUALIFIED) reduce 148) ((T_NAME_QUALIFIED) reduce 148) ((T_NAME_RELATIVE) reduce 148) ((T_NEW) reduce 148) ((T_NS_C) reduce 148) ((T_OBJECT_CAST) reduce 148) ((T_PRINT) reduce 148) ((T_READONLY) reduce 148) ((T_REQUIRE) reduce 148) ((T_REQUIRE_ONCE) reduce 148) ((T_RETURN) reduce 148) ((T_START_HEREDOC) reduce 148) ((T_STATIC) reduce 148) ((T_STRING) reduce 148) ((T_STRING_CAST) reduce 148) ((T_SWITCH) reduce 148) ((T_THROW) reduce 148) ((T_TRAIT) reduce 148) ((T_TRAIT_C) reduce 148) ((T_TRY) reduce 148) ((T_UNSET) reduce 148) ((T_UNSET_CAST) reduce 148) ((T_USE) reduce 148) ((T_VARIABLE) reduce 148) ((T_WHILE) reduce 148) ((T_YIELD) reduce 148) ((T_YIELD_FROM) reduce 148) (("[") reduce 148) (("`") reduce 148) (("{") reduce 148) (("}") reduce 148) (("~") reduce 148)) 28087 ((("!") reduce 240) (("\"") reduce 240) (("$") reduce 240) (("(") reduce 240) (("+") reduce 240) (("-") reduce 240) ((";") reduce 240) (("@") reduce 240) ((T_ABSTRACT) reduce 240) ((T_ARRAY) reduce 240) ((T_ARRAY_CAST) reduce 240) ((T_ATTRIBUTE) reduce 240) ((T_BOOL_CAST) reduce 240) ((T_BREAK) reduce 240) ((T_CLASS) reduce 240) ((T_CLASS_C) reduce 240) ((T_CLONE) reduce 240) ((T_CONST) reduce 240) ((T_CONSTANT_ENCAPSED_STRING) reduce 240) ((T_CONTINUE) reduce 240) ((T_DEC) reduce 240) ((T_DECLARE) reduce 240) ((T_DIR) reduce 240) ((T_DNUMBER) reduce 240) ((T_DO) reduce 240) ((T_DOUBLE_CAST) reduce 240) ((T_ECHO) reduce 240) ((T_EMPTY) reduce 240) ((T_ENUM) reduce 240) ((T_EVAL) reduce 240) ((T_EXIT) reduce 240) ((T_FILE) reduce 240) ((T_FINAL) reduce 240) ((T_FN) reduce 240) ((T_FOR) reduce 240) ((T_FOREACH) reduce 240) ((T_FUNCTION) reduce 240) ((T_FUNC_C) reduce 240) ((T_GLOBAL) reduce 240) ((T_GOTO) reduce 240) ((T_HALT_COMPILER) reduce 240) ((T_IF) reduce 240) ((T_INC) reduce 240) ((T_INCLUDE) reduce 240) ((T_INCLUDE_ONCE) reduce 240) ((T_INLINE_HTML) reduce 240) ((T_INTERFACE) reduce 240) ((T_INT_CAST) reduce 240) ((T_ISSET) reduce 240) ((T_LINE) reduce 240) ((T_LIST) reduce 240) ((T_LNUMBER) reduce 240) ((T_MATCH) reduce 240) ((T_METHOD_C) reduce 240) ((T_NAMESPACE) reduce 240) ((T_NAME_FULLY_QUALIFIED) reduce 240) ((T_NAME_QUALIFIED) reduce 240) ((T_NAME_RELATIVE) reduce 240) ((T_NEW) reduce 240) ((T_NS_C) reduce 240) ((T_OBJECT_CAST) reduce 240) ((T_PRINT) reduce 240) ((T_READONLY) reduce 240) ((T_REQUIRE) reduce 240) ((T_REQUIRE_ONCE) reduce 240) ((T_RETURN) reduce 240) ((T_START_HEREDOC) reduce 240) ((T_STATIC) reduce 240) ((T_STRING) reduce 240) ((T_STRING_CAST) reduce 240) ((T_SWITCH) reduce 240) ((T_THROW) reduce 240) ((T_TRAIT) reduce 240) ((T_TRAIT_C) reduce 240) ((T_TRY) reduce 240) ((T_UNSET) reduce 240) ((T_UNSET_CAST) reduce 240) ((T_USE) reduce 240) ((T_VARIABLE) reduce 240) ((T_WHILE) reduce 240) ((T_YIELD) reduce 240) ((T_YIELD_FROM) reduce 240) (("[") reduce 240) (("`") reduce 240) (("{") reduce 240) (("}") reduce 240) (("~") reduce 240)) 28093 ((("!") reduce 117) (("\"") reduce 117) (("$") reduce 117) (("(") reduce 117) (("+") reduce 117) (("-") reduce 117) ((";") reduce 117) (("@") reduce 117) ((T_ABSTRACT) reduce 117) ((T_ARRAY) reduce 117) ((T_ARRAY_CAST) reduce 117) ((T_ATTRIBUTE) reduce 117) ((T_BOOL_CAST) reduce 117) ((T_BREAK) reduce 117) ((T_CLASS) reduce 117) ((T_CLASS_C) reduce 117) ((T_CLONE) reduce 117) ((T_CONST) reduce 117) ((T_CONSTANT_ENCAPSED_STRING) reduce 117) ((T_CONTINUE) reduce 117) ((T_DEC) reduce 117) ((T_DECLARE) reduce 117) ((T_DIR) reduce 117) ((T_DNUMBER) reduce 117) ((T_DO) reduce 117) ((T_DOUBLE_CAST) reduce 117) ((T_ECHO) reduce 117) ((T_EMPTY) reduce 117) ((T_ENUM) reduce 117) ((T_EVAL) reduce 117) ((T_EXIT) reduce 117) ((T_FILE) reduce 117) ((T_FINAL) reduce 117) ((T_FN) reduce 117) ((T_FOR) reduce 117) ((T_FOREACH) reduce 117) ((T_FUNCTION) reduce 117) ((T_FUNC_C) reduce 117) ((T_GLOBAL) reduce 117) ((T_GOTO) reduce 117) ((T_HALT_COMPILER) reduce 117) ((T_IF) reduce 117) ((T_INC) reduce 117) ((T_INCLUDE) reduce 117) ((T_INCLUDE_ONCE) reduce 117) ((T_INLINE_HTML) reduce 117) ((T_INTERFACE) reduce 117) ((T_INT_CAST) reduce 117) ((T_ISSET) reduce 117) ((T_LINE) reduce 117) ((T_LIST) reduce 117) ((T_LNUMBER) reduce 117) ((T_MATCH) reduce 117) ((T_METHOD_C) reduce 117) ((T_NAMESPACE) reduce 117) ((T_NAME_FULLY_QUALIFIED) reduce 117) ((T_NAME_QUALIFIED) reduce 117) ((T_NAME_RELATIVE) reduce 117) ((T_NEW) reduce 117) ((T_NS_C) reduce 117) ((T_OBJECT_CAST) reduce 117) ((T_PRINT) reduce 117) ((T_READONLY) reduce 117) ((T_REQUIRE) reduce 117) ((T_REQUIRE_ONCE) reduce 117) ((T_RETURN) reduce 117) ((T_START_HEREDOC) reduce 117) ((T_STATIC) reduce 117) ((T_STRING) reduce 117) ((T_STRING_CAST) reduce 117) ((T_SWITCH) reduce 117) ((T_THROW) reduce 117) ((T_TRAIT) reduce 117) ((T_TRAIT_C) reduce 117) ((T_TRY) reduce 117) ((T_UNSET) reduce 117) ((T_UNSET_CAST) reduce 117) ((T_USE) reduce 117) ((T_VARIABLE) reduce 117) ((T_WHILE) reduce 117) ((T_YIELD) reduce 117) ((T_YIELD_FROM) reduce 117) (("[") reduce 117) (("`") reduce 117) (("{") reduce 117) (("}") reduce 117) (("~") reduce 117)) 28094 ((("!") reduce 115) (("\"") reduce 115) (("$") reduce 115) (("(") reduce 115) (("+") reduce 115) (("-") reduce 115) ((";") reduce 115) (("@") reduce 115) ((T_ABSTRACT) reduce 115) ((T_ARRAY) reduce 115) ((T_ARRAY_CAST) reduce 115) ((T_ATTRIBUTE) reduce 115) ((T_BOOL_CAST) reduce 115) ((T_BREAK) reduce 115) ((T_CLASS) reduce 115) ((T_CLASS_C) reduce 115) ((T_CLONE) reduce 115) ((T_CONST) reduce 115) ((T_CONSTANT_ENCAPSED_STRING) reduce 115) ((T_CONTINUE) reduce 115) ((T_DEC) reduce 115) ((T_DECLARE) reduce 115) ((T_DIR) reduce 115) ((T_DNUMBER) reduce 115) ((T_DO) reduce 115) ((T_DOUBLE_CAST) reduce 115) ((T_ECHO) reduce 115) ((T_EMPTY) reduce 115) ((T_ENUM) reduce 115) ((T_EVAL) reduce 115) ((T_EXIT) reduce 115) ((T_FILE) reduce 115) ((T_FINAL) reduce 115) ((T_FN) reduce 115) ((T_FOR) reduce 115) ((T_FOREACH) reduce 115) ((T_FUNCTION) reduce 115) ((T_FUNC_C) reduce 115) ((T_GLOBAL) reduce 115) ((T_GOTO) reduce 115) ((T_HALT_COMPILER) reduce 115) ((T_IF) reduce 115) ((T_INC) reduce 115) ((T_INCLUDE) reduce 115) ((T_INCLUDE_ONCE) reduce 115) ((T_INLINE_HTML) reduce 115) ((T_INTERFACE) reduce 115) ((T_INT_CAST) reduce 115) ((T_ISSET) reduce 115) ((T_LINE) reduce 115) ((T_LIST) reduce 115) ((T_LNUMBER) reduce 115) ((T_MATCH) reduce 115) ((T_METHOD_C) reduce 115) ((T_NAMESPACE) reduce 115) ((T_NAME_FULLY_QUALIFIED) reduce 115) ((T_NAME_QUALIFIED) reduce 115) ((T_NAME_RELATIVE) reduce 115) ((T_NEW) reduce 115) ((T_NS_C) reduce 115) ((T_OBJECT_CAST) reduce 115) ((T_PRINT) reduce 115) ((T_READONLY) reduce 115) ((T_REQUIRE) reduce 115) ((T_REQUIRE_ONCE) reduce 115) ((T_RETURN) reduce 115) ((T_START_HEREDOC) reduce 115) ((T_STATIC) reduce 115) ((T_STRING) reduce 115) ((T_STRING_CAST) reduce 115) ((T_SWITCH) reduce 115) ((T_THROW) reduce 115) ((T_TRAIT) reduce 115) ((T_TRAIT_C) reduce 115) ((T_TRY) reduce 115) ((T_UNSET) reduce 115) ((T_UNSET_CAST) reduce 115) ((T_USE) reduce 115) ((T_VARIABLE) reduce 115) ((T_WHILE) reduce 115) ((T_YIELD) reduce 115) ((T_YIELD_FROM) reduce 115) (("[") reduce 115) (("`") reduce 115) (("{") reduce 115) (("}") reduce 115) (("~") reduce 115)) 28095 ((("!") reduce 116) (("\"") reduce 116) (("$") reduce 116) (("(") reduce 116) (("+") reduce 116) (("-") reduce 116) ((";") reduce 116) (("@") reduce 116) ((T_ABSTRACT) reduce 116) ((T_ARRAY) reduce 116) ((T_ARRAY_CAST) reduce 116) ((T_ATTRIBUTE) reduce 116) ((T_BOOL_CAST) reduce 116) ((T_BREAK) reduce 116) ((T_CLASS) reduce 116) ((T_CLASS_C) reduce 116) ((T_CLONE) reduce 116) ((T_CONST) reduce 116) ((T_CONSTANT_ENCAPSED_STRING) reduce 116) ((T_CONTINUE) reduce 116) ((T_DEC) reduce 116) ((T_DECLARE) reduce 116) ((T_DIR) reduce 116) ((T_DNUMBER) reduce 116) ((T_DO) reduce 116) ((T_DOUBLE_CAST) reduce 116) ((T_ECHO) reduce 116) ((T_EMPTY) reduce 116) ((T_ENUM) reduce 116) ((T_EVAL) reduce 116) ((T_EXIT) reduce 116) ((T_FILE) reduce 116) ((T_FINAL) reduce 116) ((T_FN) reduce 116) ((T_FOR) reduce 116) ((T_FOREACH) reduce 116) ((T_FUNCTION) reduce 116) ((T_FUNC_C) reduce 116) ((T_GLOBAL) reduce 116) ((T_GOTO) reduce 116) ((T_HALT_COMPILER) reduce 116) ((T_IF) reduce 116) ((T_INC) reduce 116) ((T_INCLUDE) reduce 116) ((T_INCLUDE_ONCE) reduce 116) ((T_INLINE_HTML) reduce 116) ((T_INTERFACE) reduce 116) ((T_INT_CAST) reduce 116) ((T_ISSET) reduce 116) ((T_LINE) reduce 116) ((T_LIST) reduce 116) ((T_LNUMBER) reduce 116) ((T_MATCH) reduce 116) ((T_METHOD_C) reduce 116) ((T_NAMESPACE) reduce 116) ((T_NAME_FULLY_QUALIFIED) reduce 116) ((T_NAME_QUALIFIED) reduce 116) ((T_NAME_RELATIVE) reduce 116) ((T_NEW) reduce 116) ((T_NS_C) reduce 116) ((T_OBJECT_CAST) reduce 116) ((T_PRINT) reduce 116) ((T_READONLY) reduce 116) ((T_REQUIRE) reduce 116) ((T_REQUIRE_ONCE) reduce 116) ((T_RETURN) reduce 116) ((T_START_HEREDOC) reduce 116) ((T_STATIC) reduce 116) ((T_STRING) reduce 116) ((T_STRING_CAST) reduce 116) ((T_SWITCH) reduce 116) ((T_THROW) reduce 116) ((T_TRAIT) reduce 116) ((T_TRAIT_C) reduce 116) ((T_TRY) reduce 116) ((T_UNSET) reduce 116) ((T_UNSET_CAST) reduce 116) ((T_USE) reduce 116) ((T_VARIABLE) reduce 116) ((T_WHILE) reduce 116) ((T_YIELD) reduce 116) ((T_YIELD_FROM) reduce 116) (("[") reduce 116) (("`") reduce 116) (("{") reduce 116) (("}") reduce 116) (("~") reduce 116)) 28096 ((("!") reduce 114) (("\"") reduce 114) (("$") reduce 114) (("(") reduce 114) (("+") reduce 114) (("-") reduce 114) ((";") reduce 114) (("@") reduce 114) ((T_ABSTRACT) reduce 114) ((T_ARRAY) reduce 114) ((T_ARRAY_CAST) reduce 114) ((T_ATTRIBUTE) reduce 114) ((T_BOOL_CAST) reduce 114) ((T_BREAK) reduce 114) ((T_CLASS) reduce 114) ((T_CLASS_C) reduce 114) ((T_CLONE) reduce 114) ((T_CONST) reduce 114) ((T_CONSTANT_ENCAPSED_STRING) reduce 114) ((T_CONTINUE) reduce 114) ((T_DEC) reduce 114) ((T_DECLARE) reduce 114) ((T_DIR) reduce 114) ((T_DNUMBER) reduce 114) ((T_DO) reduce 114) ((T_DOUBLE_CAST) reduce 114) ((T_ECHO) reduce 114) ((T_EMPTY) reduce 114) ((T_ENUM) reduce 114) ((T_EVAL) reduce 114) ((T_EXIT) reduce 114) ((T_FILE) reduce 114) ((T_FINAL) reduce 114) ((T_FN) reduce 114) ((T_FOR) reduce 114) ((T_FOREACH) reduce 114) ((T_FUNCTION) reduce 114) ((T_FUNC_C) reduce 114) ((T_GLOBAL) reduce 114) ((T_GOTO) reduce 114) ((T_HALT_COMPILER) reduce 114) ((T_IF) reduce 114) ((T_INC) reduce 114) ((T_INCLUDE) reduce 114) ((T_INCLUDE_ONCE) reduce 114) ((T_INLINE_HTML) reduce 114) ((T_INTERFACE) reduce 114) ((T_INT_CAST) reduce 114) ((T_ISSET) reduce 114) ((T_LINE) reduce 114) ((T_LIST) reduce 114) ((T_LNUMBER) reduce 114) ((T_MATCH) reduce 114) ((T_METHOD_C) reduce 114) ((T_NAMESPACE) reduce 114) ((T_NAME_FULLY_QUALIFIED) reduce 114) ((T_NAME_QUALIFIED) reduce 114) ((T_NAME_RELATIVE) reduce 114) ((T_NEW) reduce 114) ((T_NS_C) reduce 114) ((T_OBJECT_CAST) reduce 114) ((T_PRINT) reduce 114) ((T_READONLY) reduce 114) ((T_REQUIRE) reduce 114) ((T_REQUIRE_ONCE) reduce 114) ((T_RETURN) reduce 114) ((T_START_HEREDOC) reduce 114) ((T_STATIC) reduce 114) ((T_STRING) reduce 114) ((T_STRING_CAST) reduce 114) ((T_SWITCH) reduce 114) ((T_THROW) reduce 114) ((T_TRAIT) reduce 114) ((T_TRAIT_C) reduce 114) ((T_TRY) reduce 114) ((T_UNSET) reduce 114) ((T_UNSET_CAST) reduce 114) ((T_USE) reduce 114) ((T_VARIABLE) reduce 114) ((T_WHILE) reduce 114) ((T_YIELD) reduce 114) ((T_YIELD_FROM) reduce 114) (("[") reduce 114) (("`") reduce 114) (("{") reduce 114) (("}") reduce 114) (("~") reduce 114)) 28101 ((("!") reduce 160) (("\"") reduce 160) (("$") reduce 160) (("(") reduce 160) (("+") reduce 160) (("-") reduce 160) ((";") reduce 160) (("@") reduce 160) ((T_ABSTRACT) reduce 160) ((T_ARRAY) reduce 160) ((T_ARRAY_CAST) reduce 160) ((T_ATTRIBUTE) reduce 160) ((T_BOOL_CAST) reduce 160) ((T_BREAK) reduce 160) ((T_CLASS) reduce 160) ((T_CLASS_C) reduce 160) ((T_CLONE) reduce 160) ((T_CONST) reduce 160) ((T_CONSTANT_ENCAPSED_STRING) reduce 160) ((T_CONTINUE) reduce 160) ((T_DEC) reduce 160) ((T_DECLARE) reduce 160) ((T_DIR) reduce 160) ((T_DNUMBER) reduce 160) ((T_DO) reduce 160) ((T_DOUBLE_CAST) reduce 160) ((T_ECHO) reduce 160) ((T_EMPTY) reduce 160) ((T_ENUM) reduce 160) ((T_EVAL) reduce 160) ((T_EXIT) reduce 160) ((T_FILE) reduce 160) ((T_FINAL) reduce 160) ((T_FN) reduce 160) ((T_FOR) reduce 160) ((T_FOREACH) reduce 160) ((T_FUNCTION) reduce 160) ((T_FUNC_C) reduce 160) ((T_GLOBAL) reduce 160) ((T_GOTO) reduce 160) ((T_HALT_COMPILER) reduce 160) ((T_IF) reduce 160) ((T_INC) reduce 160) ((T_INCLUDE) reduce 160) ((T_INCLUDE_ONCE) reduce 160) ((T_INLINE_HTML) reduce 160) ((T_INTERFACE) reduce 160) ((T_INT_CAST) reduce 160) ((T_ISSET) reduce 160) ((T_LINE) reduce 160) ((T_LIST) reduce 160) ((T_LNUMBER) reduce 160) ((T_MATCH) reduce 160) ((T_METHOD_C) reduce 160) ((T_NAMESPACE) reduce 160) ((T_NAME_FULLY_QUALIFIED) reduce 160) ((T_NAME_QUALIFIED) reduce 160) ((T_NAME_RELATIVE) reduce 160) ((T_NEW) reduce 160) ((T_NS_C) reduce 160) ((T_OBJECT_CAST) reduce 160) ((T_PRINT) reduce 160) ((T_READONLY) reduce 160) ((T_REQUIRE) reduce 160) ((T_REQUIRE_ONCE) reduce 160) ((T_RETURN) reduce 160) ((T_START_HEREDOC) reduce 160) ((T_STATIC) reduce 160) ((T_STRING) reduce 160) ((T_STRING_CAST) reduce 160) ((T_SWITCH) reduce 160) ((T_THROW) reduce 160) ((T_TRAIT) reduce 160) ((T_TRAIT_C) reduce 160) ((T_TRY) reduce 160) ((T_UNSET) reduce 160) ((T_UNSET_CAST) reduce 160) ((T_USE) reduce 160) ((T_VARIABLE) reduce 160) ((T_WHILE) reduce 160) ((T_YIELD) reduce 160) ((T_YIELD_FROM) reduce 160) (("[") reduce 160) (("`") reduce 160) (("{") reduce 160) (("}") reduce 160) (("~") reduce 160)) 28104 ((("!") reduce 168) (("\"") reduce 168) (("$") reduce 168) (("(") reduce 168) (("+") reduce 168) (("-") reduce 168) ((";") reduce 168) (("@") reduce 168) ((T_ABSTRACT) reduce 168) ((T_ARRAY) reduce 168) ((T_ARRAY_CAST) reduce 168) ((T_ATTRIBUTE) reduce 168) ((T_BOOL_CAST) reduce 168) ((T_BREAK) reduce 168) ((T_CATCH) reduce 168) ((T_CLASS) reduce 168) ((T_CLASS_C) reduce 168) ((T_CLONE) reduce 168) ((T_CONST) reduce 168) ((T_CONSTANT_ENCAPSED_STRING) reduce 168) ((T_CONTINUE) reduce 168) ((T_DEC) reduce 168) ((T_DECLARE) reduce 168) ((T_DIR) reduce 168) ((T_DNUMBER) reduce 168) ((T_DO) reduce 168) ((T_DOUBLE_CAST) reduce 168) ((T_ECHO) reduce 168) ((T_EMPTY) reduce 168) ((T_ENUM) reduce 168) ((T_EVAL) reduce 168) ((T_EXIT) reduce 168) ((T_FILE) reduce 168) ((T_FINAL) reduce 168) ((T_FINALLY) reduce 168) ((T_FN) reduce 168) ((T_FOR) reduce 168) ((T_FOREACH) reduce 168) ((T_FUNCTION) reduce 168) ((T_FUNC_C) reduce 168) ((T_GLOBAL) reduce 168) ((T_GOTO) reduce 168) ((T_HALT_COMPILER) reduce 168) ((T_IF) reduce 168) ((T_INC) reduce 168) ((T_INCLUDE) reduce 168) ((T_INCLUDE_ONCE) reduce 168) ((T_INLINE_HTML) reduce 168) ((T_INTERFACE) reduce 168) ((T_INT_CAST) reduce 168) ((T_ISSET) reduce 168) ((T_LINE) reduce 168) ((T_LIST) reduce 168) ((T_LNUMBER) reduce 168) ((T_MATCH) reduce 168) ((T_METHOD_C) reduce 168) ((T_NAMESPACE) reduce 168) ((T_NAME_FULLY_QUALIFIED) reduce 168) ((T_NAME_QUALIFIED) reduce 168) ((T_NAME_RELATIVE) reduce 168) ((T_NEW) reduce 168) ((T_NS_C) reduce 168) ((T_OBJECT_CAST) reduce 168) ((T_PRINT) reduce 168) ((T_READONLY) reduce 168) ((T_REQUIRE) reduce 168) ((T_REQUIRE_ONCE) reduce 168) ((T_RETURN) reduce 168) ((T_START_HEREDOC) reduce 168) ((T_STATIC) reduce 168) ((T_STRING) reduce 168) ((T_STRING_CAST) reduce 168) ((T_SWITCH) reduce 168) ((T_THROW) reduce 168) ((T_TRAIT) reduce 168) ((T_TRAIT_C) reduce 168) ((T_TRY) reduce 168) ((T_UNSET) reduce 168) ((T_UNSET_CAST) reduce 168) ((T_USE) reduce 168) ((T_VARIABLE) reduce 168) ((T_WHILE) reduce 168) ((T_YIELD) reduce 168) ((T_YIELD_FROM) reduce 168) (("[") reduce 168) (("`") reduce 168) (("{") reduce 168) (("}") reduce 168) (("~") reduce 168)) 28105 ((("!") reduce 174) (("\"") reduce 174) (("$") reduce 174) (("(") reduce 174) (("+") reduce 174) (("-") reduce 174) ((";") reduce 174) (("@") reduce 174) ((T_ABSTRACT) reduce 174) ((T_ARRAY) reduce 174) ((T_ARRAY_CAST) reduce 174) ((T_ATTRIBUTE) reduce 174) ((T_BOOL_CAST) reduce 174) ((T_BREAK) reduce 174) ((T_CATCH) shift) ((T_CLASS) reduce 174) ((T_CLASS_C) reduce 174) ((T_CLONE) reduce 174) ((T_CONST) reduce 174) ((T_CONSTANT_ENCAPSED_STRING) reduce 174) ((T_CONTINUE) reduce 174) ((T_DEC) reduce 174) ((T_DECLARE) reduce 174) ((T_DIR) reduce 174) ((T_DNUMBER) reduce 174) ((T_DO) reduce 174) ((T_DOUBLE_CAST) reduce 174) ((T_ECHO) reduce 174) ((T_EMPTY) reduce 174) ((T_ENUM) reduce 174) ((T_EVAL) reduce 174) ((T_EXIT) reduce 174) ((T_FILE) reduce 174) ((T_FINAL) reduce 174) ((T_FINALLY) shift) ((T_FN) reduce 174) ((T_FOR) reduce 174) ((T_FOREACH) reduce 174) ((T_FUNCTION) reduce 174) ((T_FUNC_C) reduce 174) ((T_GLOBAL) reduce 174) ((T_GOTO) reduce 174) ((T_HALT_COMPILER) reduce 174) ((T_IF) reduce 174) ((T_INC) reduce 174) ((T_INCLUDE) reduce 174) ((T_INCLUDE_ONCE) reduce 174) ((T_INLINE_HTML) reduce 174) ((T_INTERFACE) reduce 174) ((T_INT_CAST) reduce 174) ((T_ISSET) reduce 174) ((T_LINE) reduce 174) ((T_LIST) reduce 174) ((T_LNUMBER) reduce 174) ((T_MATCH) reduce 174) ((T_METHOD_C) reduce 174) ((T_NAMESPACE) reduce 174) ((T_NAME_FULLY_QUALIFIED) reduce 174) ((T_NAME_QUALIFIED) reduce 174) ((T_NAME_RELATIVE) reduce 174) ((T_NEW) reduce 174) ((T_NS_C) reduce 174) ((T_OBJECT_CAST) reduce 174) ((T_PRINT) reduce 174) ((T_READONLY) reduce 174) ((T_REQUIRE) reduce 174) ((T_REQUIRE_ONCE) reduce 174) ((T_RETURN) reduce 174) ((T_START_HEREDOC) reduce 174) ((T_STATIC) reduce 174) ((T_STRING) reduce 174) ((T_STRING_CAST) reduce 174) ((T_SWITCH) reduce 174) ((T_THROW) reduce 174) ((T_TRAIT) reduce 174) ((T_TRAIT_C) reduce 174) ((T_TRY) reduce 174) ((T_UNSET) reduce 174) ((T_UNSET_CAST) reduce 174) ((T_USE) reduce 174) ((T_VARIABLE) reduce 174) ((T_WHILE) reduce 174) ((T_YIELD) reduce 174) ((T_YIELD_FROM) reduce 174) (("[") reduce 174) (("`") reduce 174) (("{") reduce 174) (("}") reduce 174) (("~") reduce 174)) 28108 ((("!") reduce 165) (("\"") reduce 165) (("$") reduce 165) (("(") reduce 165) (("+") reduce 165) (("-") reduce 165) ((";") reduce 165) (("@") reduce 165) ((T_ABSTRACT) reduce 165) ((T_ARRAY) reduce 165) ((T_ARRAY_CAST) reduce 165) ((T_ATTRIBUTE) reduce 165) ((T_BOOL_CAST) reduce 165) ((T_BREAK) reduce 165) ((T_CLASS) reduce 165) ((T_CLASS_C) reduce 165) ((T_CLONE) reduce 165) ((T_CONST) reduce 165) ((T_CONSTANT_ENCAPSED_STRING) reduce 165) ((T_CONTINUE) reduce 165) ((T_DEC) reduce 165) ((T_DECLARE) reduce 165) ((T_DIR) reduce 165) ((T_DNUMBER) reduce 165) ((T_DO) reduce 165) ((T_DOUBLE_CAST) reduce 165) ((T_ECHO) reduce 165) ((T_EMPTY) reduce 165) ((T_ENUM) reduce 165) ((T_EVAL) reduce 165) ((T_EXIT) reduce 165) ((T_FILE) reduce 165) ((T_FINAL) reduce 165) ((T_FN) reduce 165) ((T_FOR) reduce 165) ((T_FOREACH) reduce 165) ((T_FUNCTION) reduce 165) ((T_FUNC_C) reduce 165) ((T_GLOBAL) reduce 165) ((T_GOTO) reduce 165) ((T_HALT_COMPILER) reduce 165) ((T_IF) reduce 165) ((T_INC) reduce 165) ((T_INCLUDE) reduce 165) ((T_INCLUDE_ONCE) reduce 165) ((T_INLINE_HTML) reduce 165) ((T_INTERFACE) reduce 165) ((T_INT_CAST) reduce 165) ((T_ISSET) reduce 165) ((T_LINE) reduce 165) ((T_LIST) reduce 165) ((T_LNUMBER) reduce 165) ((T_MATCH) reduce 165) ((T_METHOD_C) reduce 165) ((T_NAMESPACE) reduce 165) ((T_NAME_FULLY_QUALIFIED) reduce 165) ((T_NAME_QUALIFIED) reduce 165) ((T_NAME_RELATIVE) reduce 165) ((T_NEW) reduce 165) ((T_NS_C) reduce 165) ((T_OBJECT_CAST) reduce 165) ((T_PRINT) reduce 165) ((T_READONLY) reduce 165) ((T_REQUIRE) reduce 165) ((T_REQUIRE_ONCE) reduce 165) ((T_RETURN) reduce 165) ((T_START_HEREDOC) reduce 165) ((T_STATIC) reduce 165) ((T_STRING) reduce 165) ((T_STRING_CAST) reduce 165) ((T_SWITCH) reduce 165) ((T_THROW) reduce 165) ((T_TRAIT) reduce 165) ((T_TRAIT_C) reduce 165) ((T_TRY) reduce 165) ((T_UNSET) reduce 165) ((T_UNSET_CAST) reduce 165) ((T_USE) reduce 165) ((T_VARIABLE) reduce 165) ((T_WHILE) reduce 165) ((T_YIELD) reduce 165) ((T_YIELD_FROM) reduce 165) (("[") reduce 165) (("`") reduce 165) (("{") reduce 165) (("}") reduce 165) (("~") reduce 165)) 28111 ((("!") reduce 175) (("\"") reduce 175) (("$") reduce 175) (("(") reduce 175) (("+") reduce 175) (("-") reduce 175) ((";") reduce 175) (("@") reduce 175) ((T_ABSTRACT) reduce 175) ((T_ARRAY) reduce 175) ((T_ARRAY_CAST) reduce 175) ((T_ATTRIBUTE) reduce 175) ((T_BOOL_CAST) reduce 175) ((T_BREAK) reduce 175) ((T_CLASS) reduce 175) ((T_CLASS_C) reduce 175) ((T_CLONE) reduce 175) ((T_CONST) reduce 175) ((T_CONSTANT_ENCAPSED_STRING) reduce 175) ((T_CONTINUE) reduce 175) ((T_DEC) reduce 175) ((T_DECLARE) reduce 175) ((T_DIR) reduce 175) ((T_DNUMBER) reduce 175) ((T_DO) reduce 175) ((T_DOUBLE_CAST) reduce 175) ((T_ECHO) reduce 175) ((T_EMPTY) reduce 175) ((T_ENUM) reduce 175) ((T_EVAL) reduce 175) ((T_EXIT) reduce 175) ((T_FILE) reduce 175) ((T_FINAL) reduce 175) ((T_FN) reduce 175) ((T_FOR) reduce 175) ((T_FOREACH) reduce 175) ((T_FUNCTION) reduce 175) ((T_FUNC_C) reduce 175) ((T_GLOBAL) reduce 175) ((T_GOTO) reduce 175) ((T_HALT_COMPILER) reduce 175) ((T_IF) reduce 175) ((T_INC) reduce 175) ((T_INCLUDE) reduce 175) ((T_INCLUDE_ONCE) reduce 175) ((T_INLINE_HTML) reduce 175) ((T_INTERFACE) reduce 175) ((T_INT_CAST) reduce 175) ((T_ISSET) reduce 175) ((T_LINE) reduce 175) ((T_LIST) reduce 175) ((T_LNUMBER) reduce 175) ((T_MATCH) reduce 175) ((T_METHOD_C) reduce 175) ((T_NAMESPACE) reduce 175) ((T_NAME_FULLY_QUALIFIED) reduce 175) ((T_NAME_QUALIFIED) reduce 175) ((T_NAME_RELATIVE) reduce 175) ((T_NEW) reduce 175) ((T_NS_C) reduce 175) ((T_OBJECT_CAST) reduce 175) ((T_PRINT) reduce 175) ((T_READONLY) reduce 175) ((T_REQUIRE) reduce 175) ((T_REQUIRE_ONCE) reduce 175) ((T_RETURN) reduce 175) ((T_START_HEREDOC) reduce 175) ((T_STATIC) reduce 175) ((T_STRING) reduce 175) ((T_STRING_CAST) reduce 175) ((T_SWITCH) reduce 175) ((T_THROW) reduce 175) ((T_TRAIT) reduce 175) ((T_TRAIT_C) reduce 175) ((T_TRY) reduce 175) ((T_UNSET) reduce 175) ((T_UNSET_CAST) reduce 175) ((T_USE) reduce 175) ((T_VARIABLE) reduce 175) ((T_WHILE) reduce 175) ((T_YIELD) reduce 175) ((T_YIELD_FROM) reduce 175) (("[") reduce 175) (("`") reduce 175) (("{") reduce 175) (("}") reduce 175) (("~") reduce 175)) 28118 ((("!") reduce 169) (("\"") reduce 169) (("$") reduce 169) (("(") reduce 169) (("+") reduce 169) (("-") reduce 169) ((";") reduce 169) (("@") reduce 169) ((T_ABSTRACT) reduce 169) ((T_ARRAY) reduce 169) ((T_ARRAY_CAST) reduce 169) ((T_ATTRIBUTE) reduce 169) ((T_BOOL_CAST) reduce 169) ((T_BREAK) reduce 169) ((T_CATCH) reduce 169) ((T_CLASS) reduce 169) ((T_CLASS_C) reduce 169) ((T_CLONE) reduce 169) ((T_CONST) reduce 169) ((T_CONSTANT_ENCAPSED_STRING) reduce 169) ((T_CONTINUE) reduce 169) ((T_DEC) reduce 169) ((T_DECLARE) reduce 169) ((T_DIR) reduce 169) ((T_DNUMBER) reduce 169) ((T_DO) reduce 169) ((T_DOUBLE_CAST) reduce 169) ((T_ECHO) reduce 169) ((T_EMPTY) reduce 169) ((T_ENUM) reduce 169) ((T_EVAL) reduce 169) ((T_EXIT) reduce 169) ((T_FILE) reduce 169) ((T_FINAL) reduce 169) ((T_FINALLY) reduce 169) ((T_FN) reduce 169) ((T_FOR) reduce 169) ((T_FOREACH) reduce 169) ((T_FUNCTION) reduce 169) ((T_FUNC_C) reduce 169) ((T_GLOBAL) reduce 169) ((T_GOTO) reduce 169) ((T_HALT_COMPILER) reduce 169) ((T_IF) reduce 169) ((T_INC) reduce 169) ((T_INCLUDE) reduce 169) ((T_INCLUDE_ONCE) reduce 169) ((T_INLINE_HTML) reduce 169) ((T_INTERFACE) reduce 169) ((T_INT_CAST) reduce 169) ((T_ISSET) reduce 169) ((T_LINE) reduce 169) ((T_LIST) reduce 169) ((T_LNUMBER) reduce 169) ((T_MATCH) reduce 169) ((T_METHOD_C) reduce 169) ((T_NAMESPACE) reduce 169) ((T_NAME_FULLY_QUALIFIED) reduce 169) ((T_NAME_QUALIFIED) reduce 169) ((T_NAME_RELATIVE) reduce 169) ((T_NEW) reduce 169) ((T_NS_C) reduce 169) ((T_OBJECT_CAST) reduce 169) ((T_PRINT) reduce 169) ((T_READONLY) reduce 169) ((T_REQUIRE) reduce 169) ((T_REQUIRE_ONCE) reduce 169) ((T_RETURN) reduce 169) ((T_START_HEREDOC) reduce 169) ((T_STATIC) reduce 169) ((T_STRING) reduce 169) ((T_STRING_CAST) reduce 169) ((T_SWITCH) reduce 169) ((T_THROW) reduce 169) ((T_TRAIT) reduce 169) ((T_TRAIT_C) reduce 169) ((T_TRY) reduce 169) ((T_UNSET) reduce 169) ((T_UNSET_CAST) reduce 169) ((T_USE) reduce 169) ((T_VARIABLE) reduce 169) ((T_WHILE) reduce 169) ((T_YIELD) reduce 169) ((T_YIELD_FROM) reduce 169) (("[") reduce 169) (("`") reduce 169) (("{") reduce 169) (("}") reduce 169) (("~") reduce 169)) 28123 ((("!") reduce 197) (("\"") reduce 197) (("$") reduce 197) (("(") reduce 197) (("+") reduce 197) (("-") reduce 197) ((";") reduce 197) (("@") reduce 197) ((T_ABSTRACT) reduce 197) ((T_ARRAY) reduce 197) ((T_ARRAY_CAST) reduce 197) ((T_ATTRIBUTE) reduce 197) ((T_BOOL_CAST) reduce 197) ((T_BREAK) reduce 197) ((T_CLASS) reduce 197) ((T_CLASS_C) reduce 197) ((T_CLONE) reduce 197) ((T_CONST) reduce 197) ((T_CONSTANT_ENCAPSED_STRING) reduce 197) ((T_CONTINUE) reduce 197) ((T_DEC) reduce 197) ((T_DECLARE) reduce 197) ((T_DIR) reduce 197) ((T_DNUMBER) reduce 197) ((T_DO) reduce 197) ((T_DOUBLE_CAST) reduce 197) ((T_ECHO) reduce 197) ((T_EMPTY) reduce 197) ((T_ENUM) reduce 197) ((T_EVAL) reduce 197) ((T_EXIT) reduce 197) ((T_FILE) reduce 197) ((T_FINAL) reduce 197) ((T_FN) reduce 197) ((T_FOR) reduce 197) ((T_FOREACH) reduce 197) ((T_FUNCTION) reduce 197) ((T_FUNC_C) reduce 197) ((T_GLOBAL) reduce 197) ((T_GOTO) reduce 197) ((T_HALT_COMPILER) reduce 197) ((T_IF) reduce 197) ((T_INC) reduce 197) ((T_INCLUDE) reduce 197) ((T_INCLUDE_ONCE) reduce 197) ((T_INLINE_HTML) reduce 197) ((T_INTERFACE) reduce 197) ((T_INT_CAST) reduce 197) ((T_ISSET) reduce 197) ((T_LINE) reduce 197) ((T_LIST) reduce 197) ((T_LNUMBER) reduce 197) ((T_MATCH) reduce 197) ((T_METHOD_C) reduce 197) ((T_NAMESPACE) reduce 197) ((T_NAME_FULLY_QUALIFIED) reduce 197) ((T_NAME_QUALIFIED) reduce 197) ((T_NAME_RELATIVE) reduce 197) ((T_NEW) reduce 197) ((T_NS_C) reduce 197) ((T_OBJECT_CAST) reduce 197) ((T_PRINT) reduce 197) ((T_READONLY) reduce 197) ((T_REQUIRE) reduce 197) ((T_REQUIRE_ONCE) reduce 197) ((T_RETURN) reduce 197) ((T_START_HEREDOC) reduce 197) ((T_STATIC) reduce 197) ((T_STRING) reduce 197) ((T_STRING_CAST) reduce 197) ((T_SWITCH) reduce 197) ((T_THROW) reduce 197) ((T_TRAIT) reduce 197) ((T_TRAIT_C) reduce 197) ((T_TRY) reduce 197) ((T_UNSET) reduce 197) ((T_UNSET_CAST) reduce 197) ((T_USE) reduce 197) ((T_VARIABLE) reduce 197) ((T_WHILE) reduce 197) ((T_YIELD) reduce 197) ((T_YIELD_FROM) reduce 197) (("[") reduce 197) (("`") reduce 197) (("{") reduce 197) (("}") reduce 197) (("~") reduce 197)) 28128 ((("!") reduce 151) (("\"") reduce 151) (("$") reduce 151) (("(") reduce 151) (("+") reduce 151) (("-") reduce 151) ((";") reduce 151) (("@") reduce 151) ((T_ABSTRACT) reduce 151) ((T_ARRAY) reduce 151) ((T_ARRAY_CAST) reduce 151) ((T_ATTRIBUTE) reduce 151) ((T_BOOL_CAST) reduce 151) ((T_BREAK) reduce 151) ((T_CLASS) reduce 151) ((T_CLASS_C) reduce 151) ((T_CLONE) reduce 151) ((T_CONST) reduce 151) ((T_CONSTANT_ENCAPSED_STRING) reduce 151) ((T_CONTINUE) reduce 151) ((T_DEC) reduce 151) ((T_DECLARE) reduce 151) ((T_DIR) reduce 151) ((T_DNUMBER) reduce 151) ((T_DO) reduce 151) ((T_DOUBLE_CAST) reduce 151) ((T_ECHO) reduce 151) ((T_EMPTY) reduce 151) ((T_ENUM) reduce 151) ((T_EVAL) reduce 151) ((T_EXIT) reduce 151) ((T_FILE) reduce 151) ((T_FINAL) reduce 151) ((T_FN) reduce 151) ((T_FOR) reduce 151) ((T_FOREACH) reduce 151) ((T_FUNCTION) reduce 151) ((T_FUNC_C) reduce 151) ((T_GLOBAL) reduce 151) ((T_GOTO) reduce 151) ((T_HALT_COMPILER) reduce 151) ((T_IF) reduce 151) ((T_INC) reduce 151) ((T_INCLUDE) reduce 151) ((T_INCLUDE_ONCE) reduce 151) ((T_INLINE_HTML) reduce 151) ((T_INTERFACE) reduce 151) ((T_INT_CAST) reduce 151) ((T_ISSET) reduce 151) ((T_LINE) reduce 151) ((T_LIST) reduce 151) ((T_LNUMBER) reduce 151) ((T_MATCH) reduce 151) ((T_METHOD_C) reduce 151) ((T_NAMESPACE) reduce 151) ((T_NAME_FULLY_QUALIFIED) reduce 151) ((T_NAME_QUALIFIED) reduce 151) ((T_NAME_RELATIVE) reduce 151) ((T_NEW) reduce 151) ((T_NS_C) reduce 151) ((T_OBJECT_CAST) reduce 151) ((T_PRINT) reduce 151) ((T_READONLY) reduce 151) ((T_REQUIRE) reduce 151) ((T_REQUIRE_ONCE) reduce 151) ((T_RETURN) reduce 151) ((T_START_HEREDOC) reduce 151) ((T_STATIC) reduce 151) ((T_STRING) reduce 151) ((T_STRING_CAST) reduce 151) ((T_SWITCH) reduce 151) ((T_THROW) reduce 151) ((T_TRAIT) reduce 151) ((T_TRAIT_C) reduce 151) ((T_TRY) reduce 151) ((T_UNSET) reduce 151) ((T_UNSET_CAST) reduce 151) ((T_USE) reduce 151) ((T_VARIABLE) reduce 151) ((T_WHILE) reduce 151) ((T_YIELD) reduce 151) ((T_YIELD_FROM) reduce 151) (("[") reduce 151) (("`") reduce 151) (("{") reduce 151) (("}") reduce 151) (("~") reduce 151)) 28132 ((("!") reduce 221) (("\"") reduce 221) (("$") reduce 221) (("(") reduce 221) (("+") reduce 221) (("-") reduce 221) ((";") reduce 221) (("@") reduce 221) ((T_ABSTRACT) reduce 221) ((T_ARRAY) reduce 221) ((T_ARRAY_CAST) reduce 221) ((T_ATTRIBUTE) reduce 221) ((T_BOOL_CAST) reduce 221) ((T_BREAK) reduce 221) ((T_CLASS) reduce 221) ((T_CLASS_C) reduce 221) ((T_CLONE) reduce 221) ((T_CONST) reduce 221) ((T_CONSTANT_ENCAPSED_STRING) reduce 221) ((T_CONTINUE) reduce 221) ((T_DEC) reduce 221) ((T_DECLARE) reduce 221) ((T_DIR) reduce 221) ((T_DNUMBER) reduce 221) ((T_DO) reduce 221) ((T_DOUBLE_CAST) reduce 221) ((T_ECHO) reduce 221) ((T_EMPTY) reduce 221) ((T_ENUM) reduce 221) ((T_EVAL) reduce 221) ((T_EXIT) reduce 221) ((T_FILE) reduce 221) ((T_FINAL) reduce 221) ((T_FN) reduce 221) ((T_FOR) reduce 221) ((T_FOREACH) reduce 221) ((T_FUNCTION) reduce 221) ((T_FUNC_C) reduce 221) ((T_GLOBAL) reduce 221) ((T_GOTO) reduce 221) ((T_HALT_COMPILER) reduce 221) ((T_IF) reduce 221) ((T_INC) reduce 221) ((T_INCLUDE) reduce 221) ((T_INCLUDE_ONCE) reduce 221) ((T_INLINE_HTML) reduce 221) ((T_INTERFACE) reduce 221) ((T_INT_CAST) reduce 221) ((T_ISSET) reduce 221) ((T_LINE) reduce 221) ((T_LIST) reduce 221) ((T_LNUMBER) reduce 221) ((T_MATCH) reduce 221) ((T_METHOD_C) reduce 221) ((T_NAMESPACE) reduce 221) ((T_NAME_FULLY_QUALIFIED) reduce 221) ((T_NAME_QUALIFIED) reduce 221) ((T_NAME_RELATIVE) reduce 221) ((T_NEW) reduce 221) ((T_NS_C) reduce 221) ((T_OBJECT_CAST) reduce 221) ((T_PRINT) reduce 221) ((T_READONLY) reduce 221) ((T_REQUIRE) reduce 221) ((T_REQUIRE_ONCE) reduce 221) ((T_RETURN) reduce 221) ((T_START_HEREDOC) reduce 221) ((T_STATIC) reduce 221) ((T_STRING) reduce 221) ((T_STRING_CAST) reduce 221) ((T_SWITCH) reduce 221) ((T_THROW) reduce 221) ((T_TRAIT) reduce 221) ((T_TRAIT_C) reduce 221) ((T_TRY) reduce 221) ((T_UNSET) reduce 221) ((T_UNSET_CAST) reduce 221) ((T_USE) reduce 221) ((T_VARIABLE) reduce 221) ((T_WHILE) reduce 221) ((T_YIELD) reduce 221) ((T_YIELD_FROM) reduce 221) (("[") reduce 221) (("`") reduce 221) (("{") reduce 221) (("}") reduce 221) (("~") reduce 221)) 28134 ((("!") reduce 222) (("\"") reduce 222) (("$") reduce 222) (("(") reduce 222) (("+") reduce 222) (("-") reduce 222) ((";") reduce 222) (("@") reduce 222) ((T_ABSTRACT) reduce 222) ((T_ARRAY) reduce 222) ((T_ARRAY_CAST) reduce 222) ((T_ATTRIBUTE) reduce 222) ((T_BOOL_CAST) reduce 222) ((T_BREAK) reduce 222) ((T_CLASS) reduce 222) ((T_CLASS_C) reduce 222) ((T_CLONE) reduce 222) ((T_CONST) reduce 222) ((T_CONSTANT_ENCAPSED_STRING) reduce 222) ((T_CONTINUE) reduce 222) ((T_DEC) reduce 222) ((T_DECLARE) reduce 222) ((T_DIR) reduce 222) ((T_DNUMBER) reduce 222) ((T_DO) reduce 222) ((T_DOUBLE_CAST) reduce 222) ((T_ECHO) reduce 222) ((T_EMPTY) reduce 222) ((T_ENUM) reduce 222) ((T_EVAL) reduce 222) ((T_EXIT) reduce 222) ((T_FILE) reduce 222) ((T_FINAL) reduce 222) ((T_FN) reduce 222) ((T_FOR) reduce 222) ((T_FOREACH) reduce 222) ((T_FUNCTION) reduce 222) ((T_FUNC_C) reduce 222) ((T_GLOBAL) reduce 222) ((T_GOTO) reduce 222) ((T_HALT_COMPILER) reduce 222) ((T_IF) reduce 222) ((T_INC) reduce 222) ((T_INCLUDE) reduce 222) ((T_INCLUDE_ONCE) reduce 222) ((T_INLINE_HTML) reduce 222) ((T_INTERFACE) reduce 222) ((T_INT_CAST) reduce 222) ((T_ISSET) reduce 222) ((T_LINE) reduce 222) ((T_LIST) reduce 222) ((T_LNUMBER) reduce 222) ((T_MATCH) reduce 222) ((T_METHOD_C) reduce 222) ((T_NAMESPACE) reduce 222) ((T_NAME_FULLY_QUALIFIED) reduce 222) ((T_NAME_QUALIFIED) reduce 222) ((T_NAME_RELATIVE) reduce 222) ((T_NEW) reduce 222) ((T_NS_C) reduce 222) ((T_OBJECT_CAST) reduce 222) ((T_PRINT) reduce 222) ((T_READONLY) reduce 222) ((T_REQUIRE) reduce 222) ((T_REQUIRE_ONCE) reduce 222) ((T_RETURN) reduce 222) ((T_START_HEREDOC) reduce 222) ((T_STATIC) reduce 222) ((T_STRING) reduce 222) ((T_STRING_CAST) reduce 222) ((T_SWITCH) reduce 222) ((T_THROW) reduce 222) ((T_TRAIT) reduce 222) ((T_TRAIT_C) reduce 222) ((T_TRY) reduce 222) ((T_UNSET) reduce 222) ((T_UNSET_CAST) reduce 222) ((T_USE) reduce 222) ((T_VARIABLE) reduce 222) ((T_WHILE) reduce 222) ((T_YIELD) reduce 222) ((T_YIELD_FROM) reduce 222) (("[") reduce 222) (("`") reduce 222) (("{") reduce 222) (("}") reduce 222) (("~") reduce 222)) 28138 ((("!") reduce 223) (("\"") reduce 223) (("$") reduce 223) (("(") reduce 223) (("+") reduce 223) (("-") reduce 223) ((";") reduce 223) (("@") reduce 223) ((T_ABSTRACT) reduce 223) ((T_ARRAY) reduce 223) ((T_ARRAY_CAST) reduce 223) ((T_ATTRIBUTE) reduce 223) ((T_BOOL_CAST) reduce 223) ((T_BREAK) reduce 223) ((T_CLASS) reduce 223) ((T_CLASS_C) reduce 223) ((T_CLONE) reduce 223) ((T_CONST) reduce 223) ((T_CONSTANT_ENCAPSED_STRING) reduce 223) ((T_CONTINUE) reduce 223) ((T_DEC) reduce 223) ((T_DECLARE) reduce 223) ((T_DIR) reduce 223) ((T_DNUMBER) reduce 223) ((T_DO) reduce 223) ((T_DOUBLE_CAST) reduce 223) ((T_ECHO) reduce 223) ((T_EMPTY) reduce 223) ((T_ENUM) reduce 223) ((T_EVAL) reduce 223) ((T_EXIT) reduce 223) ((T_FILE) reduce 223) ((T_FINAL) reduce 223) ((T_FN) reduce 223) ((T_FOR) reduce 223) ((T_FOREACH) reduce 223) ((T_FUNCTION) reduce 223) ((T_FUNC_C) reduce 223) ((T_GLOBAL) reduce 223) ((T_GOTO) reduce 223) ((T_HALT_COMPILER) reduce 223) ((T_IF) reduce 223) ((T_INC) reduce 223) ((T_INCLUDE) reduce 223) ((T_INCLUDE_ONCE) reduce 223) ((T_INLINE_HTML) reduce 223) ((T_INTERFACE) reduce 223) ((T_INT_CAST) reduce 223) ((T_ISSET) reduce 223) ((T_LINE) reduce 223) ((T_LIST) reduce 223) ((T_LNUMBER) reduce 223) ((T_MATCH) reduce 223) ((T_METHOD_C) reduce 223) ((T_NAMESPACE) reduce 223) ((T_NAME_FULLY_QUALIFIED) reduce 223) ((T_NAME_QUALIFIED) reduce 223) ((T_NAME_RELATIVE) reduce 223) ((T_NEW) reduce 223) ((T_NS_C) reduce 223) ((T_OBJECT_CAST) reduce 223) ((T_PRINT) reduce 223) ((T_READONLY) reduce 223) ((T_REQUIRE) reduce 223) ((T_REQUIRE_ONCE) reduce 223) ((T_RETURN) reduce 223) ((T_START_HEREDOC) reduce 223) ((T_STATIC) reduce 223) ((T_STRING) reduce 223) ((T_STRING_CAST) reduce 223) ((T_SWITCH) reduce 223) ((T_THROW) reduce 223) ((T_TRAIT) reduce 223) ((T_TRAIT_C) reduce 223) ((T_TRY) reduce 223) ((T_UNSET) reduce 223) ((T_UNSET_CAST) reduce 223) ((T_USE) reduce 223) ((T_VARIABLE) reduce 223) ((T_WHILE) reduce 223) ((T_YIELD) reduce 223) ((T_YIELD_FROM) reduce 223) (("[") reduce 223) (("`") reduce 223) (("{") reduce 223) (("}") reduce 223) (("~") reduce 223)) 28141 ((("!") reduce 224) (("\"") reduce 224) (("$") reduce 224) (("(") reduce 224) (("+") reduce 224) (("-") reduce 224) ((";") reduce 224) (("@") reduce 224) ((T_ABSTRACT) reduce 224) ((T_ARRAY) reduce 224) ((T_ARRAY_CAST) reduce 224) ((T_ATTRIBUTE) reduce 224) ((T_BOOL_CAST) reduce 224) ((T_BREAK) reduce 224) ((T_CLASS) reduce 224) ((T_CLASS_C) reduce 224) ((T_CLONE) reduce 224) ((T_CONST) reduce 224) ((T_CONSTANT_ENCAPSED_STRING) reduce 224) ((T_CONTINUE) reduce 224) ((T_DEC) reduce 224) ((T_DECLARE) reduce 224) ((T_DIR) reduce 224) ((T_DNUMBER) reduce 224) ((T_DO) reduce 224) ((T_DOUBLE_CAST) reduce 224) ((T_ECHO) reduce 224) ((T_EMPTY) reduce 224) ((T_ENUM) reduce 224) ((T_EVAL) reduce 224) ((T_EXIT) reduce 224) ((T_FILE) reduce 224) ((T_FINAL) reduce 224) ((T_FN) reduce 224) ((T_FOR) reduce 224) ((T_FOREACH) reduce 224) ((T_FUNCTION) reduce 224) ((T_FUNC_C) reduce 224) ((T_GLOBAL) reduce 224) ((T_GOTO) reduce 224) ((T_HALT_COMPILER) reduce 224) ((T_IF) reduce 224) ((T_INC) reduce 224) ((T_INCLUDE) reduce 224) ((T_INCLUDE_ONCE) reduce 224) ((T_INLINE_HTML) reduce 224) ((T_INTERFACE) reduce 224) ((T_INT_CAST) reduce 224) ((T_ISSET) reduce 224) ((T_LINE) reduce 224) ((T_LIST) reduce 224) ((T_LNUMBER) reduce 224) ((T_MATCH) reduce 224) ((T_METHOD_C) reduce 224) ((T_NAMESPACE) reduce 224) ((T_NAME_FULLY_QUALIFIED) reduce 224) ((T_NAME_QUALIFIED) reduce 224) ((T_NAME_RELATIVE) reduce 224) ((T_NEW) reduce 224) ((T_NS_C) reduce 224) ((T_OBJECT_CAST) reduce 224) ((T_PRINT) reduce 224) ((T_READONLY) reduce 224) ((T_REQUIRE) reduce 224) ((T_REQUIRE_ONCE) reduce 224) ((T_RETURN) reduce 224) ((T_START_HEREDOC) reduce 224) ((T_STATIC) reduce 224) ((T_STRING) reduce 224) ((T_STRING_CAST) reduce 224) ((T_SWITCH) reduce 224) ((T_THROW) reduce 224) ((T_TRAIT) reduce 224) ((T_TRAIT_C) reduce 224) ((T_TRY) reduce 224) ((T_UNSET) reduce 224) ((T_UNSET_CAST) reduce 224) ((T_USE) reduce 224) ((T_VARIABLE) reduce 224) ((T_WHILE) reduce 224) ((T_YIELD) reduce 224) ((T_YIELD_FROM) reduce 224) (("[") reduce 224) (("`") reduce 224) (("{") reduce 224) (("}") reduce 224) (("~") reduce 224)) 28142 ((("!") reduce 167) (("\"") reduce 167) (("$") reduce 167) (("(") reduce 167) (("+") reduce 167) (("-") reduce 167) ((";") reduce 167) (("@") reduce 167) ((T_ABSTRACT) reduce 167) ((T_ARRAY) reduce 167) ((T_ARRAY_CAST) reduce 167) ((T_ATTRIBUTE) reduce 167) ((T_BOOL_CAST) reduce 167) ((T_BREAK) reduce 167) ((T_CLASS) reduce 167) ((T_CLASS_C) reduce 167) ((T_CLONE) reduce 167) ((T_CONST) reduce 167) ((T_CONSTANT_ENCAPSED_STRING) reduce 167) ((T_CONTINUE) reduce 167) ((T_DEC) reduce 167) ((T_DECLARE) reduce 167) ((T_DIR) reduce 167) ((T_DNUMBER) reduce 167) ((T_DO) reduce 167) ((T_DOUBLE_CAST) reduce 167) ((T_ECHO) reduce 167) ((T_EMPTY) reduce 167) ((T_ENUM) reduce 167) ((T_EVAL) reduce 167) ((T_EXIT) reduce 167) ((T_FILE) reduce 167) ((T_FINAL) reduce 167) ((T_FN) reduce 167) ((T_FOR) reduce 167) ((T_FOREACH) reduce 167) ((T_FUNCTION) reduce 167) ((T_FUNC_C) reduce 167) ((T_GLOBAL) reduce 167) ((T_GOTO) reduce 167) ((T_HALT_COMPILER) reduce 167) ((T_IF) reduce 167) ((T_INC) reduce 167) ((T_INCLUDE) reduce 167) ((T_INCLUDE_ONCE) reduce 167) ((T_INLINE_HTML) reduce 167) ((T_INTERFACE) reduce 167) ((T_INT_CAST) reduce 167) ((T_ISSET) reduce 167) ((T_LINE) reduce 167) ((T_LIST) reduce 167) ((T_LNUMBER) reduce 167) ((T_MATCH) reduce 167) ((T_METHOD_C) reduce 167) ((T_NAMESPACE) reduce 167) ((T_NAME_FULLY_QUALIFIED) reduce 167) ((T_NAME_QUALIFIED) reduce 167) ((T_NAME_RELATIVE) reduce 167) ((T_NEW) reduce 167) ((T_NS_C) reduce 167) ((T_OBJECT_CAST) reduce 167) ((T_PRINT) reduce 167) ((T_READONLY) reduce 167) ((T_REQUIRE) reduce 167) ((T_REQUIRE_ONCE) reduce 167) ((T_RETURN) reduce 167) ((T_START_HEREDOC) reduce 167) ((T_STATIC) reduce 167) ((T_STRING) reduce 167) ((T_STRING_CAST) reduce 167) ((T_SWITCH) reduce 167) ((T_THROW) reduce 167) ((T_TRAIT) reduce 167) ((T_TRAIT_C) reduce 167) ((T_TRY) reduce 167) ((T_UNSET) reduce 167) ((T_UNSET_CAST) reduce 167) ((T_USE) reduce 167) ((T_VARIABLE) reduce 167) ((T_WHILE) reduce 167) ((T_YIELD) reduce 167) ((T_YIELD_FROM) reduce 167) (("[") reduce 167) (("`") reduce 167) (("{") reduce 167) (("}") reduce 167) (("~") reduce 167)) 28144 ((("!") reduce 156) (("\"") reduce 156) (("$") reduce 156) (("(") reduce 156) (("+") reduce 156) (("-") reduce 156) ((";") reduce 156) (("@") reduce 156) ((T_ABSTRACT) reduce 156) ((T_ARRAY) reduce 156) ((T_ARRAY_CAST) reduce 156) ((T_ATTRIBUTE) reduce 156) ((T_BOOL_CAST) reduce 156) ((T_BREAK) reduce 156) ((T_CLASS) reduce 156) ((T_CLASS_C) reduce 156) ((T_CLONE) reduce 156) ((T_CONST) reduce 156) ((T_CONSTANT_ENCAPSED_STRING) reduce 156) ((T_CONTINUE) reduce 156) ((T_DEC) reduce 156) ((T_DECLARE) reduce 156) ((T_DIR) reduce 156) ((T_DNUMBER) reduce 156) ((T_DO) reduce 156) ((T_DOUBLE_CAST) reduce 156) ((T_ECHO) reduce 156) ((T_EMPTY) reduce 156) ((T_ENUM) reduce 156) ((T_EVAL) reduce 156) ((T_EXIT) reduce 156) ((T_FILE) reduce 156) ((T_FINAL) reduce 156) ((T_FN) reduce 156) ((T_FOR) reduce 156) ((T_FOREACH) reduce 156) ((T_FUNCTION) reduce 156) ((T_FUNC_C) reduce 156) ((T_GLOBAL) reduce 156) ((T_GOTO) reduce 156) ((T_HALT_COMPILER) reduce 156) ((T_IF) reduce 156) ((T_INC) reduce 156) ((T_INCLUDE) reduce 156) ((T_INCLUDE_ONCE) reduce 156) ((T_INLINE_HTML) reduce 156) ((T_INTERFACE) reduce 156) ((T_INT_CAST) reduce 156) ((T_ISSET) reduce 156) ((T_LINE) reduce 156) ((T_LIST) reduce 156) ((T_LNUMBER) reduce 156) ((T_MATCH) reduce 156) ((T_METHOD_C) reduce 156) ((T_NAMESPACE) reduce 156) ((T_NAME_FULLY_QUALIFIED) reduce 156) ((T_NAME_QUALIFIED) reduce 156) ((T_NAME_RELATIVE) reduce 156) ((T_NEW) reduce 156) ((T_NS_C) reduce 156) ((T_OBJECT_CAST) reduce 156) ((T_PRINT) reduce 156) ((T_READONLY) reduce 156) ((T_REQUIRE) reduce 156) ((T_REQUIRE_ONCE) reduce 156) ((T_RETURN) reduce 156) ((T_START_HEREDOC) reduce 156) ((T_STATIC) reduce 156) ((T_STRING) reduce 156) ((T_STRING_CAST) reduce 156) ((T_SWITCH) reduce 156) ((T_THROW) reduce 156) ((T_TRAIT) reduce 156) ((T_TRAIT_C) reduce 156) ((T_TRY) reduce 156) ((T_UNSET) reduce 156) ((T_UNSET_CAST) reduce 156) ((T_USE) reduce 156) ((T_VARIABLE) reduce 156) ((T_WHILE) reduce 156) ((T_YIELD) reduce 156) ((T_YIELD_FROM) reduce 156) (("[") reduce 156) (("`") reduce 156) (("{") reduce 156) (("}") reduce 156) (("~") reduce 156)) 28146 ((("!") reduce 154) (("\"") reduce 154) (("$") reduce 154) (("(") reduce 154) (("+") reduce 154) (("-") reduce 154) ((";") reduce 154) (("@") reduce 154) ((T_ABSTRACT) reduce 154) ((T_ARRAY) reduce 154) ((T_ARRAY_CAST) reduce 154) ((T_ATTRIBUTE) reduce 154) ((T_BOOL_CAST) reduce 154) ((T_BREAK) reduce 154) ((T_CLASS) reduce 154) ((T_CLASS_C) reduce 154) ((T_CLONE) reduce 154) ((T_CONST) reduce 154) ((T_CONSTANT_ENCAPSED_STRING) reduce 154) ((T_CONTINUE) reduce 154) ((T_DEC) reduce 154) ((T_DECLARE) reduce 154) ((T_DIR) reduce 154) ((T_DNUMBER) reduce 154) ((T_DO) reduce 154) ((T_DOUBLE_CAST) reduce 154) ((T_ECHO) reduce 154) ((T_EMPTY) reduce 154) ((T_ENUM) reduce 154) ((T_EVAL) reduce 154) ((T_EXIT) reduce 154) ((T_FILE) reduce 154) ((T_FINAL) reduce 154) ((T_FN) reduce 154) ((T_FOR) reduce 154) ((T_FOREACH) reduce 154) ((T_FUNCTION) reduce 154) ((T_FUNC_C) reduce 154) ((T_GLOBAL) reduce 154) ((T_GOTO) reduce 154) ((T_HALT_COMPILER) reduce 154) ((T_IF) reduce 154) ((T_INC) reduce 154) ((T_INCLUDE) reduce 154) ((T_INCLUDE_ONCE) reduce 154) ((T_INLINE_HTML) reduce 154) ((T_INTERFACE) reduce 154) ((T_INT_CAST) reduce 154) ((T_ISSET) reduce 154) ((T_LINE) reduce 154) ((T_LIST) reduce 154) ((T_LNUMBER) reduce 154) ((T_MATCH) reduce 154) ((T_METHOD_C) reduce 154) ((T_NAMESPACE) reduce 154) ((T_NAME_FULLY_QUALIFIED) reduce 154) ((T_NAME_QUALIFIED) reduce 154) ((T_NAME_RELATIVE) reduce 154) ((T_NEW) reduce 154) ((T_NS_C) reduce 154) ((T_OBJECT_CAST) reduce 154) ((T_PRINT) reduce 154) ((T_READONLY) reduce 154) ((T_REQUIRE) reduce 154) ((T_REQUIRE_ONCE) reduce 154) ((T_RETURN) reduce 154) ((T_START_HEREDOC) reduce 154) ((T_STATIC) reduce 154) ((T_STRING) reduce 154) ((T_STRING_CAST) reduce 154) ((T_SWITCH) reduce 154) ((T_THROW) reduce 154) ((T_TRAIT) reduce 154) ((T_TRAIT_C) reduce 154) ((T_TRY) reduce 154) ((T_UNSET) reduce 154) ((T_UNSET_CAST) reduce 154) ((T_USE) reduce 154) ((T_VARIABLE) reduce 154) ((T_WHILE) reduce 154) ((T_YIELD) reduce 154) ((T_YIELD_FROM) reduce 154) (("[") reduce 154) (("`") reduce 154) (("{") reduce 154) (("}") reduce 154) (("~") reduce 154)) 28150 ((("!") reduce 113) (("\"") reduce 113) (("$") reduce 113) (("(") reduce 113) (("+") reduce 113) (("-") reduce 113) ((";") reduce 113) (("@") reduce 113) ((T_ABSTRACT) reduce 113) ((T_ARRAY) reduce 113) ((T_ARRAY_CAST) reduce 113) ((T_ATTRIBUTE) reduce 113) ((T_BOOL_CAST) reduce 113) ((T_BREAK) reduce 113) ((T_CLASS) reduce 113) ((T_CLASS_C) reduce 113) ((T_CLONE) reduce 113) ((T_CONST) reduce 113) ((T_CONSTANT_ENCAPSED_STRING) reduce 113) ((T_CONTINUE) reduce 113) ((T_DEC) reduce 113) ((T_DECLARE) reduce 113) ((T_DIR) reduce 113) ((T_DNUMBER) reduce 113) ((T_DO) reduce 113) ((T_DOUBLE_CAST) reduce 113) ((T_ECHO) reduce 113) ((T_EMPTY) reduce 113) ((T_ENUM) reduce 113) ((T_EVAL) reduce 113) ((T_EXIT) reduce 113) ((T_FILE) reduce 113) ((T_FINAL) reduce 113) ((T_FN) reduce 113) ((T_FOR) reduce 113) ((T_FOREACH) reduce 113) ((T_FUNCTION) reduce 113) ((T_FUNC_C) reduce 113) ((T_GLOBAL) reduce 113) ((T_GOTO) reduce 113) ((T_HALT_COMPILER) reduce 113) ((T_IF) reduce 113) ((T_INC) reduce 113) ((T_INCLUDE) reduce 113) ((T_INCLUDE_ONCE) reduce 113) ((T_INLINE_HTML) reduce 113) ((T_INTERFACE) reduce 113) ((T_INT_CAST) reduce 113) ((T_ISSET) reduce 113) ((T_LINE) reduce 113) ((T_LIST) reduce 113) ((T_LNUMBER) reduce 113) ((T_MATCH) reduce 113) ((T_METHOD_C) reduce 113) ((T_NAMESPACE) reduce 113) ((T_NAME_FULLY_QUALIFIED) reduce 113) ((T_NAME_QUALIFIED) reduce 113) ((T_NAME_RELATIVE) reduce 113) ((T_NEW) reduce 113) ((T_NS_C) reduce 113) ((T_OBJECT_CAST) reduce 113) ((T_PRINT) reduce 113) ((T_READONLY) reduce 113) ((T_REQUIRE) reduce 113) ((T_REQUIRE_ONCE) reduce 113) ((T_RETURN) reduce 113) ((T_START_HEREDOC) reduce 113) ((T_STATIC) reduce 113) ((T_STRING) reduce 113) ((T_STRING_CAST) reduce 113) ((T_SWITCH) reduce 113) ((T_THROW) reduce 113) ((T_TRAIT) reduce 113) ((T_TRAIT_C) reduce 113) ((T_TRY) reduce 113) ((T_UNSET) reduce 113) ((T_UNSET_CAST) reduce 113) ((T_USE) reduce 113) ((T_VARIABLE) reduce 113) ((T_WHILE) reduce 113) ((T_YIELD) reduce 113) ((T_YIELD_FROM) reduce 113) (("[") reduce 113) (("`") reduce 113) (("{") reduce 113) (("}") reduce 113) (("~") reduce 113)) 28151 ((("!") reduce 111) (("\"") reduce 111) (("$") reduce 111) (("(") reduce 111) (("+") reduce 111) (("-") reduce 111) ((";") reduce 111) (("@") reduce 111) ((T_ABSTRACT) reduce 111) ((T_ARRAY) reduce 111) ((T_ARRAY_CAST) reduce 111) ((T_ATTRIBUTE) reduce 111) ((T_BOOL_CAST) reduce 111) ((T_BREAK) reduce 111) ((T_CLASS) reduce 111) ((T_CLASS_C) reduce 111) ((T_CLONE) reduce 111) ((T_CONST) reduce 111) ((T_CONSTANT_ENCAPSED_STRING) reduce 111) ((T_CONTINUE) reduce 111) ((T_DEC) reduce 111) ((T_DECLARE) reduce 111) ((T_DIR) reduce 111) ((T_DNUMBER) reduce 111) ((T_DO) reduce 111) ((T_DOUBLE_CAST) reduce 111) ((T_ECHO) reduce 111) ((T_EMPTY) reduce 111) ((T_ENUM) reduce 111) ((T_EVAL) reduce 111) ((T_EXIT) reduce 111) ((T_FILE) reduce 111) ((T_FINAL) reduce 111) ((T_FN) reduce 111) ((T_FOR) reduce 111) ((T_FOREACH) reduce 111) ((T_FUNCTION) reduce 111) ((T_FUNC_C) reduce 111) ((T_GLOBAL) reduce 111) ((T_GOTO) reduce 111) ((T_HALT_COMPILER) reduce 111) ((T_IF) reduce 111) ((T_INC) reduce 111) ((T_INCLUDE) reduce 111) ((T_INCLUDE_ONCE) reduce 111) ((T_INLINE_HTML) reduce 111) ((T_INTERFACE) reduce 111) ((T_INT_CAST) reduce 111) ((T_ISSET) reduce 111) ((T_LINE) reduce 111) ((T_LIST) reduce 111) ((T_LNUMBER) reduce 111) ((T_MATCH) reduce 111) ((T_METHOD_C) reduce 111) ((T_NAMESPACE) reduce 111) ((T_NAME_FULLY_QUALIFIED) reduce 111) ((T_NAME_QUALIFIED) reduce 111) ((T_NAME_RELATIVE) reduce 111) ((T_NEW) reduce 111) ((T_NS_C) reduce 111) ((T_OBJECT_CAST) reduce 111) ((T_PRINT) reduce 111) ((T_READONLY) reduce 111) ((T_REQUIRE) reduce 111) ((T_REQUIRE_ONCE) reduce 111) ((T_RETURN) reduce 111) ((T_START_HEREDOC) reduce 111) ((T_STATIC) reduce 111) ((T_STRING) reduce 111) ((T_STRING_CAST) reduce 111) ((T_SWITCH) reduce 111) ((T_THROW) reduce 111) ((T_TRAIT) reduce 111) ((T_TRAIT_C) reduce 111) ((T_TRY) reduce 111) ((T_UNSET) reduce 111) ((T_UNSET_CAST) reduce 111) ((T_USE) reduce 111) ((T_VARIABLE) reduce 111) ((T_WHILE) reduce 111) ((T_YIELD) reduce 111) ((T_YIELD_FROM) reduce 111) (("[") reduce 111) (("`") reduce 111) (("{") reduce 111) (("}") reduce 111) (("~") reduce 111)) 28154 ((("!") reduce 112) (("\"") reduce 112) (("$") reduce 112) (("(") reduce 112) (("+") reduce 112) (("-") reduce 112) ((";") reduce 112) (("@") reduce 112) ((T_ABSTRACT) reduce 112) ((T_ARRAY) reduce 112) ((T_ARRAY_CAST) reduce 112) ((T_ATTRIBUTE) reduce 112) ((T_BOOL_CAST) reduce 112) ((T_BREAK) reduce 112) ((T_CLASS) reduce 112) ((T_CLASS_C) reduce 112) ((T_CLONE) reduce 112) ((T_CONST) reduce 112) ((T_CONSTANT_ENCAPSED_STRING) reduce 112) ((T_CONTINUE) reduce 112) ((T_DEC) reduce 112) ((T_DECLARE) reduce 112) ((T_DIR) reduce 112) ((T_DNUMBER) reduce 112) ((T_DO) reduce 112) ((T_DOUBLE_CAST) reduce 112) ((T_ECHO) reduce 112) ((T_EMPTY) reduce 112) ((T_ENUM) reduce 112) ((T_EVAL) reduce 112) ((T_EXIT) reduce 112) ((T_FILE) reduce 112) ((T_FINAL) reduce 112) ((T_FN) reduce 112) ((T_FOR) reduce 112) ((T_FOREACH) reduce 112) ((T_FUNCTION) reduce 112) ((T_FUNC_C) reduce 112) ((T_GLOBAL) reduce 112) ((T_GOTO) reduce 112) ((T_HALT_COMPILER) reduce 112) ((T_IF) reduce 112) ((T_INC) reduce 112) ((T_INCLUDE) reduce 112) ((T_INCLUDE_ONCE) reduce 112) ((T_INLINE_HTML) reduce 112) ((T_INTERFACE) reduce 112) ((T_INT_CAST) reduce 112) ((T_ISSET) reduce 112) ((T_LINE) reduce 112) ((T_LIST) reduce 112) ((T_LNUMBER) reduce 112) ((T_MATCH) reduce 112) ((T_METHOD_C) reduce 112) ((T_NAMESPACE) reduce 112) ((T_NAME_FULLY_QUALIFIED) reduce 112) ((T_NAME_QUALIFIED) reduce 112) ((T_NAME_RELATIVE) reduce 112) ((T_NEW) reduce 112) ((T_NS_C) reduce 112) ((T_OBJECT_CAST) reduce 112) ((T_PRINT) reduce 112) ((T_READONLY) reduce 112) ((T_REQUIRE) reduce 112) ((T_REQUIRE_ONCE) reduce 112) ((T_RETURN) reduce 112) ((T_START_HEREDOC) reduce 112) ((T_STATIC) reduce 112) ((T_STRING) reduce 112) ((T_STRING_CAST) reduce 112) ((T_SWITCH) reduce 112) ((T_THROW) reduce 112) ((T_TRAIT) reduce 112) ((T_TRAIT_C) reduce 112) ((T_TRY) reduce 112) ((T_UNSET) reduce 112) ((T_UNSET_CAST) reduce 112) ((T_USE) reduce 112) ((T_VARIABLE) reduce 112) ((T_WHILE) reduce 112) ((T_YIELD) reduce 112) ((T_YIELD_FROM) reduce 112) (("[") reduce 112) (("`") reduce 112) (("{") reduce 112) (("}") reduce 112) (("~") reduce 112)) 28160 ((("!") reduce 198) (("\"") reduce 198) (("$") reduce 198) (("(") reduce 198) (("+") reduce 198) (("-") reduce 198) ((";") reduce 198) (("@") reduce 198) ((T_ABSTRACT) reduce 198) ((T_ARRAY) reduce 198) ((T_ARRAY_CAST) reduce 198) ((T_ATTRIBUTE) reduce 198) ((T_BOOL_CAST) reduce 198) ((T_BREAK) reduce 198) ((T_CLASS) reduce 198) ((T_CLASS_C) reduce 198) ((T_CLONE) reduce 198) ((T_CONST) reduce 198) ((T_CONSTANT_ENCAPSED_STRING) reduce 198) ((T_CONTINUE) reduce 198) ((T_DEC) reduce 198) ((T_DECLARE) reduce 198) ((T_DIR) reduce 198) ((T_DNUMBER) reduce 198) ((T_DO) reduce 198) ((T_DOUBLE_CAST) reduce 198) ((T_ECHO) reduce 198) ((T_EMPTY) reduce 198) ((T_ENUM) reduce 198) ((T_EVAL) reduce 198) ((T_EXIT) reduce 198) ((T_FILE) reduce 198) ((T_FINAL) reduce 198) ((T_FN) reduce 198) ((T_FOR) reduce 198) ((T_FOREACH) reduce 198) ((T_FUNCTION) reduce 198) ((T_FUNC_C) reduce 198) ((T_GLOBAL) reduce 198) ((T_GOTO) reduce 198) ((T_HALT_COMPILER) reduce 198) ((T_IF) reduce 198) ((T_INC) reduce 198) ((T_INCLUDE) reduce 198) ((T_INCLUDE_ONCE) reduce 198) ((T_INLINE_HTML) reduce 198) ((T_INTERFACE) reduce 198) ((T_INT_CAST) reduce 198) ((T_ISSET) reduce 198) ((T_LINE) reduce 198) ((T_LIST) reduce 198) ((T_LNUMBER) reduce 198) ((T_MATCH) reduce 198) ((T_METHOD_C) reduce 198) ((T_NAMESPACE) reduce 198) ((T_NAME_FULLY_QUALIFIED) reduce 198) ((T_NAME_QUALIFIED) reduce 198) ((T_NAME_RELATIVE) reduce 198) ((T_NEW) reduce 198) ((T_NS_C) reduce 198) ((T_OBJECT_CAST) reduce 198) ((T_PRINT) reduce 198) ((T_READONLY) reduce 198) ((T_REQUIRE) reduce 198) ((T_REQUIRE_ONCE) reduce 198) ((T_RETURN) reduce 198) ((T_START_HEREDOC) reduce 198) ((T_STATIC) reduce 198) ((T_STRING) reduce 198) ((T_STRING_CAST) reduce 198) ((T_SWITCH) reduce 198) ((T_THROW) reduce 198) ((T_TRAIT) reduce 198) ((T_TRAIT_C) reduce 198) ((T_TRY) reduce 198) ((T_UNSET) reduce 198) ((T_UNSET_CAST) reduce 198) ((T_USE) reduce 198) ((T_VARIABLE) reduce 198) ((T_WHILE) reduce 198) ((T_YIELD) reduce 198) ((T_YIELD_FROM) reduce 198) (("[") reduce 198) (("`") reduce 198) (("{") reduce 198) (("}") reduce 198) (("~") reduce 198)) 28164 ((("!") reduce 241) (("\"") reduce 241) (("$") reduce 241) (("(") reduce 241) (("+") reduce 241) (("-") reduce 241) ((";") reduce 241) (("@") reduce 241) ((T_ABSTRACT) reduce 241) ((T_ARRAY) reduce 241) ((T_ARRAY_CAST) reduce 241) ((T_ATTRIBUTE) reduce 241) ((T_BOOL_CAST) reduce 241) ((T_BREAK) reduce 241) ((T_CLASS) reduce 241) ((T_CLASS_C) reduce 241) ((T_CLONE) reduce 241) ((T_CONST) reduce 241) ((T_CONSTANT_ENCAPSED_STRING) reduce 241) ((T_CONTINUE) reduce 241) ((T_DEC) reduce 241) ((T_DECLARE) reduce 241) ((T_DIR) reduce 241) ((T_DNUMBER) reduce 241) ((T_DO) reduce 241) ((T_DOUBLE_CAST) reduce 241) ((T_ECHO) reduce 241) ((T_ELSE) reduce 241) ((T_ELSEIF) reduce 241) ((T_EMPTY) reduce 241) ((T_ENUM) reduce 241) ((T_EVAL) reduce 241) ((T_EXIT) reduce 241) ((T_FILE) reduce 241) ((T_FINAL) reduce 241) ((T_FN) reduce 241) ((T_FOR) reduce 241) ((T_FOREACH) reduce 241) ((T_FUNCTION) reduce 241) ((T_FUNC_C) reduce 241) ((T_GLOBAL) reduce 241) ((T_GOTO) reduce 241) ((T_HALT_COMPILER) reduce 241) ((T_IF) reduce 241) ((T_INC) reduce 241) ((T_INCLUDE) reduce 241) ((T_INCLUDE_ONCE) reduce 241) ((T_INLINE_HTML) reduce 241) ((T_INTERFACE) reduce 241) ((T_INT_CAST) reduce 241) ((T_ISSET) reduce 241) ((T_LINE) reduce 241) ((T_LIST) reduce 241) ((T_LNUMBER) reduce 241) ((T_MATCH) reduce 241) ((T_METHOD_C) reduce 241) ((T_NAMESPACE) reduce 241) ((T_NAME_FULLY_QUALIFIED) reduce 241) ((T_NAME_QUALIFIED) reduce 241) ((T_NAME_RELATIVE) reduce 241) ((T_NEW) reduce 241) ((T_NS_C) reduce 241) ((T_OBJECT_CAST) reduce 241) ((T_PRINT) reduce 241) ((T_READONLY) reduce 241) ((T_REQUIRE) reduce 241) ((T_REQUIRE_ONCE) reduce 241) ((T_RETURN) reduce 241) ((T_START_HEREDOC) reduce 241) ((T_STATIC) reduce 241) ((T_STRING) reduce 241) ((T_STRING_CAST) reduce 241) ((T_SWITCH) reduce 241) ((T_THROW) reduce 241) ((T_TRAIT) reduce 241) ((T_TRAIT_C) reduce 241) ((T_TRY) reduce 241) ((T_UNSET) reduce 241) ((T_UNSET_CAST) reduce 241) ((T_USE) reduce 241) ((T_VARIABLE) reduce 241) ((T_WHILE) reduce 241) ((T_YIELD) reduce 241) ((T_YIELD_FROM) reduce 241) (("[") reduce 241) (("`") reduce 241) (("{") reduce 241) (("}") reduce 241) (("~") reduce 241)) 28167 ((("!") reduce 110) (("\"") reduce 110) (("$") reduce 110) (("(") reduce 110) (("+") reduce 110) (("-") reduce 110) ((";") reduce 110) (("@") reduce 110) ((T_ABSTRACT) reduce 110) ((T_ARRAY) reduce 110) ((T_ARRAY_CAST) reduce 110) ((T_ATTRIBUTE) reduce 110) ((T_BOOL_CAST) reduce 110) ((T_BREAK) reduce 110) ((T_CLASS) reduce 110) ((T_CLASS_C) reduce 110) ((T_CLONE) reduce 110) ((T_CONST) reduce 110) ((T_CONSTANT_ENCAPSED_STRING) reduce 110) ((T_CONTINUE) reduce 110) ((T_DEC) reduce 110) ((T_DECLARE) reduce 110) ((T_DIR) reduce 110) ((T_DNUMBER) reduce 110) ((T_DO) reduce 110) ((T_DOUBLE_CAST) reduce 110) ((T_ECHO) reduce 110) ((T_EMPTY) reduce 110) ((T_ENUM) reduce 110) ((T_EVAL) reduce 110) ((T_EXIT) reduce 110) ((T_FILE) reduce 110) ((T_FINAL) reduce 110) ((T_FN) reduce 110) ((T_FOR) reduce 110) ((T_FOREACH) reduce 110) ((T_FUNCTION) reduce 110) ((T_FUNC_C) reduce 110) ((T_GLOBAL) reduce 110) ((T_GOTO) reduce 110) ((T_HALT_COMPILER) reduce 110) ((T_IF) reduce 110) ((T_INC) reduce 110) ((T_INCLUDE) reduce 110) ((T_INCLUDE_ONCE) reduce 110) ((T_INLINE_HTML) reduce 110) ((T_INTERFACE) reduce 110) ((T_INT_CAST) reduce 110) ((T_ISSET) reduce 110) ((T_LINE) reduce 110) ((T_LIST) reduce 110) ((T_LNUMBER) reduce 110) ((T_MATCH) reduce 110) ((T_METHOD_C) reduce 110) ((T_NAMESPACE) reduce 110) ((T_NAME_FULLY_QUALIFIED) reduce 110) ((T_NAME_QUALIFIED) reduce 110) ((T_NAME_RELATIVE) reduce 110) ((T_NEW) reduce 110) ((T_NS_C) reduce 110) ((T_OBJECT_CAST) reduce 110) ((T_PRINT) reduce 110) ((T_READONLY) reduce 110) ((T_REQUIRE) reduce 110) ((T_REQUIRE_ONCE) reduce 110) ((T_RETURN) reduce 110) ((T_START_HEREDOC) reduce 110) ((T_STATIC) reduce 110) ((T_STRING) reduce 110) ((T_STRING_CAST) reduce 110) ((T_SWITCH) reduce 110) ((T_THROW) reduce 110) ((T_TRAIT) reduce 110) ((T_TRAIT_C) reduce 110) ((T_TRY) reduce 110) ((T_UNSET) reduce 110) ((T_UNSET_CAST) reduce 110) ((T_USE) reduce 110) ((T_VARIABLE) reduce 110) ((T_WHILE) reduce 110) ((T_YIELD) reduce 110) ((T_YIELD_FROM) reduce 110) (("[") reduce 110) (("`") reduce 110) (("{") reduce 110) (("}") reduce 110) (("~") reduce 110)) 28169 ((("!") reduce 166) (("\"") reduce 166) (("$") reduce 166) (("(") reduce 166) (("+") reduce 166) (("-") reduce 166) ((";") reduce 166) (("@") reduce 166) ((T_ABSTRACT) reduce 166) ((T_ARRAY) reduce 166) ((T_ARRAY_CAST) reduce 166) ((T_ATTRIBUTE) reduce 166) ((T_BOOL_CAST) reduce 166) ((T_BREAK) reduce 166) ((T_CLASS) reduce 166) ((T_CLASS_C) reduce 166) ((T_CLONE) reduce 166) ((T_CONST) reduce 166) ((T_CONSTANT_ENCAPSED_STRING) reduce 166) ((T_CONTINUE) reduce 166) ((T_DEC) reduce 166) ((T_DECLARE) reduce 166) ((T_DIR) reduce 166) ((T_DNUMBER) reduce 166) ((T_DO) reduce 166) ((T_DOUBLE_CAST) reduce 166) ((T_ECHO) reduce 166) ((T_EMPTY) reduce 166) ((T_ENUM) reduce 166) ((T_EVAL) reduce 166) ((T_EXIT) reduce 166) ((T_FILE) reduce 166) ((T_FINAL) reduce 166) ((T_FN) reduce 166) ((T_FOR) reduce 166) ((T_FOREACH) reduce 166) ((T_FUNCTION) reduce 166) ((T_FUNC_C) reduce 166) ((T_GLOBAL) reduce 166) ((T_GOTO) reduce 166) ((T_HALT_COMPILER) reduce 166) ((T_IF) reduce 166) ((T_INC) reduce 166) ((T_INCLUDE) reduce 166) ((T_INCLUDE_ONCE) reduce 166) ((T_INLINE_HTML) reduce 166) ((T_INTERFACE) reduce 166) ((T_INT_CAST) reduce 166) ((T_ISSET) reduce 166) ((T_LINE) reduce 166) ((T_LIST) reduce 166) ((T_LNUMBER) reduce 166) ((T_MATCH) reduce 166) ((T_METHOD_C) reduce 166) ((T_NAMESPACE) reduce 166) ((T_NAME_FULLY_QUALIFIED) reduce 166) ((T_NAME_QUALIFIED) reduce 166) ((T_NAME_RELATIVE) reduce 166) ((T_NEW) reduce 166) ((T_NS_C) reduce 166) ((T_OBJECT_CAST) reduce 166) ((T_PRINT) reduce 166) ((T_READONLY) reduce 166) ((T_REQUIRE) reduce 166) ((T_REQUIRE_ONCE) reduce 166) ((T_RETURN) reduce 166) ((T_START_HEREDOC) reduce 166) ((T_STATIC) reduce 166) ((T_STRING) reduce 166) ((T_STRING_CAST) reduce 166) ((T_SWITCH) reduce 166) ((T_THROW) reduce 166) ((T_TRAIT) reduce 166) ((T_TRAIT_C) reduce 166) ((T_TRY) reduce 166) ((T_UNSET) reduce 166) ((T_UNSET_CAST) reduce 166) ((T_USE) reduce 166) ((T_VARIABLE) reduce 166) ((T_WHILE) reduce 166) ((T_YIELD) reduce 166) ((T_YIELD_FROM) reduce 166) (("[") reduce 166) (("`") reduce 166) (("{") reduce 166) (("}") reduce 166) (("~") reduce 166)) 28171 ((("!") reduce 155) (("\"") reduce 155) (("$") reduce 155) (("(") reduce 155) (("+") reduce 155) (("-") reduce 155) ((";") reduce 155) (("@") reduce 155) ((T_ABSTRACT) reduce 155) ((T_ARRAY) reduce 155) ((T_ARRAY_CAST) reduce 155) ((T_ATTRIBUTE) reduce 155) ((T_BOOL_CAST) reduce 155) ((T_BREAK) reduce 155) ((T_CLASS) reduce 155) ((T_CLASS_C) reduce 155) ((T_CLONE) reduce 155) ((T_CONST) reduce 155) ((T_CONSTANT_ENCAPSED_STRING) reduce 155) ((T_CONTINUE) reduce 155) ((T_DEC) reduce 155) ((T_DECLARE) reduce 155) ((T_DIR) reduce 155) ((T_DNUMBER) reduce 155) ((T_DO) reduce 155) ((T_DOUBLE_CAST) reduce 155) ((T_ECHO) reduce 155) ((T_EMPTY) reduce 155) ((T_ENUM) reduce 155) ((T_EVAL) reduce 155) ((T_EXIT) reduce 155) ((T_FILE) reduce 155) ((T_FINAL) reduce 155) ((T_FN) reduce 155) ((T_FOR) reduce 155) ((T_FOREACH) reduce 155) ((T_FUNCTION) reduce 155) ((T_FUNC_C) reduce 155) ((T_GLOBAL) reduce 155) ((T_GOTO) reduce 155) ((T_HALT_COMPILER) reduce 155) ((T_IF) reduce 155) ((T_INC) reduce 155) ((T_INCLUDE) reduce 155) ((T_INCLUDE_ONCE) reduce 155) ((T_INLINE_HTML) reduce 155) ((T_INTERFACE) reduce 155) ((T_INT_CAST) reduce 155) ((T_ISSET) reduce 155) ((T_LINE) reduce 155) ((T_LIST) reduce 155) ((T_LNUMBER) reduce 155) ((T_MATCH) reduce 155) ((T_METHOD_C) reduce 155) ((T_NAMESPACE) reduce 155) ((T_NAME_FULLY_QUALIFIED) reduce 155) ((T_NAME_QUALIFIED) reduce 155) ((T_NAME_RELATIVE) reduce 155) ((T_NEW) reduce 155) ((T_NS_C) reduce 155) ((T_OBJECT_CAST) reduce 155) ((T_PRINT) reduce 155) ((T_READONLY) reduce 155) ((T_REQUIRE) reduce 155) ((T_REQUIRE_ONCE) reduce 155) ((T_RETURN) reduce 155) ((T_START_HEREDOC) reduce 155) ((T_STATIC) reduce 155) ((T_STRING) reduce 155) ((T_STRING_CAST) reduce 155) ((T_SWITCH) reduce 155) ((T_THROW) reduce 155) ((T_TRAIT) reduce 155) ((T_TRAIT_C) reduce 155) ((T_TRY) reduce 155) ((T_UNSET) reduce 155) ((T_UNSET_CAST) reduce 155) ((T_USE) reduce 155) ((T_VARIABLE) reduce 155) ((T_WHILE) reduce 155) ((T_YIELD) reduce 155) ((T_YIELD_FROM) reduce 155) (("[") reduce 155) (("`") reduce 155) (("{") reduce 155) (("}") reduce 155) (("~") reduce 155)) 28181 ((("!") reduce 162) (("\"") reduce 162) (("$") reduce 162) (("(") reduce 162) (("+") reduce 162) (("-") reduce 162) ((";") reduce 162) (("@") reduce 162) ((T_ABSTRACT) reduce 162) ((T_ARRAY) reduce 162) ((T_ARRAY_CAST) reduce 162) ((T_ATTRIBUTE) reduce 162) ((T_BOOL_CAST) reduce 162) ((T_BREAK) reduce 162) ((T_CLASS) reduce 162) ((T_CLASS_C) reduce 162) ((T_CLONE) reduce 162) ((T_CONST) reduce 162) ((T_CONSTANT_ENCAPSED_STRING) reduce 162) ((T_CONTINUE) reduce 162) ((T_DEC) reduce 162) ((T_DECLARE) reduce 162) ((T_DIR) reduce 162) ((T_DNUMBER) reduce 162) ((T_DO) reduce 162) ((T_DOUBLE_CAST) reduce 162) ((T_ECHO) reduce 162) ((T_EMPTY) reduce 162) ((T_ENUM) reduce 162) ((T_EVAL) reduce 162) ((T_EXIT) reduce 162) ((T_FILE) reduce 162) ((T_FINAL) reduce 162) ((T_FN) reduce 162) ((T_FOR) reduce 162) ((T_FOREACH) reduce 162) ((T_FUNCTION) reduce 162) ((T_FUNC_C) reduce 162) ((T_GLOBAL) reduce 162) ((T_GOTO) reduce 162) ((T_HALT_COMPILER) reduce 162) ((T_IF) reduce 162) ((T_INC) reduce 162) ((T_INCLUDE) reduce 162) ((T_INCLUDE_ONCE) reduce 162) ((T_INLINE_HTML) reduce 162) ((T_INTERFACE) reduce 162) ((T_INT_CAST) reduce 162) ((T_ISSET) reduce 162) ((T_LINE) reduce 162) ((T_LIST) reduce 162) ((T_LNUMBER) reduce 162) ((T_MATCH) reduce 162) ((T_METHOD_C) reduce 162) ((T_NAMESPACE) reduce 162) ((T_NAME_FULLY_QUALIFIED) reduce 162) ((T_NAME_QUALIFIED) reduce 162) ((T_NAME_RELATIVE) reduce 162) ((T_NEW) reduce 162) ((T_NS_C) reduce 162) ((T_OBJECT_CAST) reduce 162) ((T_PRINT) reduce 162) ((T_READONLY) reduce 162) ((T_REQUIRE) reduce 162) ((T_REQUIRE_ONCE) reduce 162) ((T_RETURN) reduce 162) ((T_START_HEREDOC) reduce 162) ((T_STATIC) reduce 162) ((T_STRING) reduce 162) ((T_STRING_CAST) reduce 162) ((T_SWITCH) reduce 162) ((T_THROW) reduce 162) ((T_TRAIT) reduce 162) ((T_TRAIT_C) reduce 162) ((T_TRY) reduce 162) ((T_UNSET) reduce 162) ((T_UNSET_CAST) reduce 162) ((T_USE) reduce 162) ((T_VARIABLE) reduce 162) ((T_WHILE) reduce 162) ((T_YIELD) reduce 162) ((T_YIELD_FROM) reduce 162) (("[") reduce 162) (("`") reduce 162) (("{") reduce 162) (("}") reduce 162) (("~") reduce 162)) 28182 ((("!") reduce 217) (("\"") reduce 217) (("$") reduce 217) (("(") reduce 217) (("+") reduce 217) (("-") reduce 217) ((";") reduce 217) (("@") reduce 217) ((T_ABSTRACT) reduce 217) ((T_ARRAY) reduce 217) ((T_ARRAY_CAST) reduce 217) ((T_ATTRIBUTE) reduce 217) ((T_BOOL_CAST) reduce 217) ((T_BREAK) reduce 217) ((T_CLASS) reduce 217) ((T_CLASS_C) reduce 217) ((T_CLONE) reduce 217) ((T_CONST) reduce 217) ((T_CONSTANT_ENCAPSED_STRING) reduce 217) ((T_CONTINUE) reduce 217) ((T_DEC) reduce 217) ((T_DECLARE) reduce 217) ((T_DIR) reduce 217) ((T_DNUMBER) reduce 217) ((T_DO) reduce 217) ((T_DOUBLE_CAST) reduce 217) ((T_ECHO) reduce 217) ((T_EMPTY) reduce 217) ((T_ENUM) reduce 217) ((T_EVAL) reduce 217) ((T_EXIT) reduce 217) ((T_FILE) reduce 217) ((T_FINAL) reduce 217) ((T_FN) reduce 217) ((T_FOR) reduce 217) ((T_FOREACH) reduce 217) ((T_FUNCTION) reduce 217) ((T_FUNC_C) reduce 217) ((T_GLOBAL) reduce 217) ((T_GOTO) reduce 217) ((T_HALT_COMPILER) reduce 217) ((T_IF) reduce 217) ((T_INC) reduce 217) ((T_INCLUDE) reduce 217) ((T_INCLUDE_ONCE) reduce 217) ((T_INLINE_HTML) reduce 217) ((T_INTERFACE) reduce 217) ((T_INT_CAST) reduce 217) ((T_ISSET) reduce 217) ((T_LINE) reduce 217) ((T_LIST) reduce 217) ((T_LNUMBER) reduce 217) ((T_MATCH) reduce 217) ((T_METHOD_C) reduce 217) ((T_NAMESPACE) reduce 217) ((T_NAME_FULLY_QUALIFIED) reduce 217) ((T_NAME_QUALIFIED) reduce 217) ((T_NAME_RELATIVE) reduce 217) ((T_NEW) reduce 217) ((T_NS_C) reduce 217) ((T_OBJECT_CAST) reduce 217) ((T_PRINT) reduce 217) ((T_READONLY) reduce 217) ((T_REQUIRE) reduce 217) ((T_REQUIRE_ONCE) reduce 217) ((T_RETURN) reduce 217) ((T_START_HEREDOC) reduce 217) ((T_STATIC) reduce 217) ((T_STRING) reduce 217) ((T_STRING_CAST) reduce 217) ((T_SWITCH) reduce 217) ((T_THROW) reduce 217) ((T_TRAIT) reduce 217) ((T_TRAIT_C) reduce 217) ((T_TRY) reduce 217) ((T_UNSET) reduce 217) ((T_UNSET_CAST) reduce 217) ((T_USE) reduce 217) ((T_VARIABLE) reduce 217) ((T_WHILE) reduce 217) ((T_YIELD) reduce 217) ((T_YIELD_FROM) reduce 217) (("[") reduce 217) (("`") reduce 217) (("{") reduce 217) (("}") reduce 217) (("~") reduce 217)) 28185 ((("!") reduce 218) (("\"") reduce 218) (("$") reduce 218) (("(") reduce 218) (("+") reduce 218) (("-") reduce 218) ((";") reduce 218) (("@") reduce 218) ((T_ABSTRACT) reduce 218) ((T_ARRAY) reduce 218) ((T_ARRAY_CAST) reduce 218) ((T_ATTRIBUTE) reduce 218) ((T_BOOL_CAST) reduce 218) ((T_BREAK) reduce 218) ((T_CLASS) reduce 218) ((T_CLASS_C) reduce 218) ((T_CLONE) reduce 218) ((T_CONST) reduce 218) ((T_CONSTANT_ENCAPSED_STRING) reduce 218) ((T_CONTINUE) reduce 218) ((T_DEC) reduce 218) ((T_DECLARE) reduce 218) ((T_DIR) reduce 218) ((T_DNUMBER) reduce 218) ((T_DO) reduce 218) ((T_DOUBLE_CAST) reduce 218) ((T_ECHO) reduce 218) ((T_EMPTY) reduce 218) ((T_ENUM) reduce 218) ((T_EVAL) reduce 218) ((T_EXIT) reduce 218) ((T_FILE) reduce 218) ((T_FINAL) reduce 218) ((T_FN) reduce 218) ((T_FOR) reduce 218) ((T_FOREACH) reduce 218) ((T_FUNCTION) reduce 218) ((T_FUNC_C) reduce 218) ((T_GLOBAL) reduce 218) ((T_GOTO) reduce 218) ((T_HALT_COMPILER) reduce 218) ((T_IF) reduce 218) ((T_INC) reduce 218) ((T_INCLUDE) reduce 218) ((T_INCLUDE_ONCE) reduce 218) ((T_INLINE_HTML) reduce 218) ((T_INTERFACE) reduce 218) ((T_INT_CAST) reduce 218) ((T_ISSET) reduce 218) ((T_LINE) reduce 218) ((T_LIST) reduce 218) ((T_LNUMBER) reduce 218) ((T_MATCH) reduce 218) ((T_METHOD_C) reduce 218) ((T_NAMESPACE) reduce 218) ((T_NAME_FULLY_QUALIFIED) reduce 218) ((T_NAME_QUALIFIED) reduce 218) ((T_NAME_RELATIVE) reduce 218) ((T_NEW) reduce 218) ((T_NS_C) reduce 218) ((T_OBJECT_CAST) reduce 218) ((T_PRINT) reduce 218) ((T_READONLY) reduce 218) ((T_REQUIRE) reduce 218) ((T_REQUIRE_ONCE) reduce 218) ((T_RETURN) reduce 218) ((T_START_HEREDOC) reduce 218) ((T_STATIC) reduce 218) ((T_STRING) reduce 218) ((T_STRING_CAST) reduce 218) ((T_SWITCH) reduce 218) ((T_THROW) reduce 218) ((T_TRAIT) reduce 218) ((T_TRAIT_C) reduce 218) ((T_TRY) reduce 218) ((T_UNSET) reduce 218) ((T_UNSET_CAST) reduce 218) ((T_USE) reduce 218) ((T_VARIABLE) reduce 218) ((T_WHILE) reduce 218) ((T_YIELD) reduce 218) ((T_YIELD_FROM) reduce 218) (("[") reduce 218) (("`") reduce 218) (("{") reduce 218) (("}") reduce 218) (("~") reduce 218)) 28186 ((("!") reduce 161) (("\"") reduce 161) (("$") reduce 161) (("(") reduce 161) (("+") reduce 161) (("-") reduce 161) ((";") reduce 161) (("@") reduce 161) ((T_ABSTRACT) reduce 161) ((T_ARRAY) reduce 161) ((T_ARRAY_CAST) reduce 161) ((T_ATTRIBUTE) reduce 161) ((T_BOOL_CAST) reduce 161) ((T_BREAK) reduce 161) ((T_CLASS) reduce 161) ((T_CLASS_C) reduce 161) ((T_CLONE) reduce 161) ((T_CONST) reduce 161) ((T_CONSTANT_ENCAPSED_STRING) reduce 161) ((T_CONTINUE) reduce 161) ((T_DEC) reduce 161) ((T_DECLARE) reduce 161) ((T_DIR) reduce 161) ((T_DNUMBER) reduce 161) ((T_DO) reduce 161) ((T_DOUBLE_CAST) reduce 161) ((T_ECHO) reduce 161) ((T_EMPTY) reduce 161) ((T_ENUM) reduce 161) ((T_EVAL) reduce 161) ((T_EXIT) reduce 161) ((T_FILE) reduce 161) ((T_FINAL) reduce 161) ((T_FN) reduce 161) ((T_FOR) reduce 161) ((T_FOREACH) reduce 161) ((T_FUNCTION) reduce 161) ((T_FUNC_C) reduce 161) ((T_GLOBAL) reduce 161) ((T_GOTO) reduce 161) ((T_HALT_COMPILER) reduce 161) ((T_IF) reduce 161) ((T_INC) reduce 161) ((T_INCLUDE) reduce 161) ((T_INCLUDE_ONCE) reduce 161) ((T_INLINE_HTML) reduce 161) ((T_INTERFACE) reduce 161) ((T_INT_CAST) reduce 161) ((T_ISSET) reduce 161) ((T_LINE) reduce 161) ((T_LIST) reduce 161) ((T_LNUMBER) reduce 161) ((T_MATCH) reduce 161) ((T_METHOD_C) reduce 161) ((T_NAMESPACE) reduce 161) ((T_NAME_FULLY_QUALIFIED) reduce 161) ((T_NAME_QUALIFIED) reduce 161) ((T_NAME_RELATIVE) reduce 161) ((T_NEW) reduce 161) ((T_NS_C) reduce 161) ((T_OBJECT_CAST) reduce 161) ((T_PRINT) reduce 161) ((T_READONLY) reduce 161) ((T_REQUIRE) reduce 161) ((T_REQUIRE_ONCE) reduce 161) ((T_RETURN) reduce 161) ((T_START_HEREDOC) reduce 161) ((T_STATIC) reduce 161) ((T_STRING) reduce 161) ((T_STRING_CAST) reduce 161) ((T_SWITCH) reduce 161) ((T_THROW) reduce 161) ((T_TRAIT) reduce 161) ((T_TRAIT_C) reduce 161) ((T_TRY) reduce 161) ((T_UNSET) reduce 161) ((T_UNSET_CAST) reduce 161) ((T_USE) reduce 161) ((T_VARIABLE) reduce 161) ((T_WHILE) reduce 161) ((T_YIELD) reduce 161) ((T_YIELD_FROM) reduce 161) (("[") reduce 161) (("`") reduce 161) (("{") reduce 161) (("}") reduce 161) (("~") reduce 161)) 28195 ((("!") reduce 150) (("\"") reduce 150) (("$") reduce 150) (("(") reduce 150) (("+") reduce 150) (("-") reduce 150) ((";") reduce 150) (("@") reduce 150) ((T_ABSTRACT) reduce 150) ((T_ARRAY) reduce 150) ((T_ARRAY_CAST) reduce 150) ((T_ATTRIBUTE) reduce 150) ((T_BOOL_CAST) reduce 150) ((T_BREAK) reduce 150) ((T_CLASS) reduce 150) ((T_CLASS_C) reduce 150) ((T_CLONE) reduce 150) ((T_CONST) reduce 150) ((T_CONSTANT_ENCAPSED_STRING) reduce 150) ((T_CONTINUE) reduce 150) ((T_DEC) reduce 150) ((T_DECLARE) reduce 150) ((T_DIR) reduce 150) ((T_DNUMBER) reduce 150) ((T_DO) reduce 150) ((T_DOUBLE_CAST) reduce 150) ((T_ECHO) reduce 150) ((T_EMPTY) reduce 150) ((T_ENUM) reduce 150) ((T_EVAL) reduce 150) ((T_EXIT) reduce 150) ((T_FILE) reduce 150) ((T_FINAL) reduce 150) ((T_FN) reduce 150) ((T_FOR) reduce 150) ((T_FOREACH) reduce 150) ((T_FUNCTION) reduce 150) ((T_FUNC_C) reduce 150) ((T_GLOBAL) reduce 150) ((T_GOTO) reduce 150) ((T_HALT_COMPILER) reduce 150) ((T_IF) reduce 150) ((T_INC) reduce 150) ((T_INCLUDE) reduce 150) ((T_INCLUDE_ONCE) reduce 150) ((T_INLINE_HTML) reduce 150) ((T_INTERFACE) reduce 150) ((T_INT_CAST) reduce 150) ((T_ISSET) reduce 150) ((T_LINE) reduce 150) ((T_LIST) reduce 150) ((T_LNUMBER) reduce 150) ((T_MATCH) reduce 150) ((T_METHOD_C) reduce 150) ((T_NAMESPACE) reduce 150) ((T_NAME_FULLY_QUALIFIED) reduce 150) ((T_NAME_QUALIFIED) reduce 150) ((T_NAME_RELATIVE) reduce 150) ((T_NEW) reduce 150) ((T_NS_C) reduce 150) ((T_OBJECT_CAST) reduce 150) ((T_PRINT) reduce 150) ((T_READONLY) reduce 150) ((T_REQUIRE) reduce 150) ((T_REQUIRE_ONCE) reduce 150) ((T_RETURN) reduce 150) ((T_START_HEREDOC) reduce 150) ((T_STATIC) reduce 150) ((T_STRING) reduce 150) ((T_STRING_CAST) reduce 150) ((T_SWITCH) reduce 150) ((T_THROW) reduce 150) ((T_TRAIT) reduce 150) ((T_TRAIT_C) reduce 150) ((T_TRY) reduce 150) ((T_UNSET) reduce 150) ((T_UNSET_CAST) reduce 150) ((T_USE) reduce 150) ((T_VARIABLE) reduce 150) ((T_WHILE) reduce 150) ((T_YIELD) reduce 150) ((T_YIELD_FROM) reduce 150) (("[") reduce 150) (("`") reduce 150) (("{") reduce 150) (("}") reduce 150) (("~") reduce 150)) 28196 ((("!") reduce 215) (("\"") reduce 215) (("$") reduce 215) (("(") reduce 215) (("+") reduce 215) (("-") reduce 215) ((";") reduce 215) (("@") reduce 215) ((T_ABSTRACT) reduce 215) ((T_ARRAY) reduce 215) ((T_ARRAY_CAST) reduce 215) ((T_ATTRIBUTE) reduce 215) ((T_BOOL_CAST) reduce 215) ((T_BREAK) reduce 215) ((T_CLASS) reduce 215) ((T_CLASS_C) reduce 215) ((T_CLONE) reduce 215) ((T_CONST) reduce 215) ((T_CONSTANT_ENCAPSED_STRING) reduce 215) ((T_CONTINUE) reduce 215) ((T_DEC) reduce 215) ((T_DECLARE) reduce 215) ((T_DIR) reduce 215) ((T_DNUMBER) reduce 215) ((T_DO) reduce 215) ((T_DOUBLE_CAST) reduce 215) ((T_ECHO) reduce 215) ((T_EMPTY) reduce 215) ((T_ENUM) reduce 215) ((T_EVAL) reduce 215) ((T_EXIT) reduce 215) ((T_FILE) reduce 215) ((T_FINAL) reduce 215) ((T_FN) reduce 215) ((T_FOR) reduce 215) ((T_FOREACH) reduce 215) ((T_FUNCTION) reduce 215) ((T_FUNC_C) reduce 215) ((T_GLOBAL) reduce 215) ((T_GOTO) reduce 215) ((T_HALT_COMPILER) reduce 215) ((T_IF) reduce 215) ((T_INC) reduce 215) ((T_INCLUDE) reduce 215) ((T_INCLUDE_ONCE) reduce 215) ((T_INLINE_HTML) reduce 215) ((T_INTERFACE) reduce 215) ((T_INT_CAST) reduce 215) ((T_ISSET) reduce 215) ((T_LINE) reduce 215) ((T_LIST) reduce 215) ((T_LNUMBER) reduce 215) ((T_MATCH) reduce 215) ((T_METHOD_C) reduce 215) ((T_NAMESPACE) reduce 215) ((T_NAME_FULLY_QUALIFIED) reduce 215) ((T_NAME_QUALIFIED) reduce 215) ((T_NAME_RELATIVE) reduce 215) ((T_NEW) reduce 215) ((T_NS_C) reduce 215) ((T_OBJECT_CAST) reduce 215) ((T_PRINT) reduce 215) ((T_READONLY) reduce 215) ((T_REQUIRE) reduce 215) ((T_REQUIRE_ONCE) reduce 215) ((T_RETURN) reduce 215) ((T_START_HEREDOC) reduce 215) ((T_STATIC) reduce 215) ((T_STRING) reduce 215) ((T_STRING_CAST) reduce 215) ((T_SWITCH) reduce 215) ((T_THROW) reduce 215) ((T_TRAIT) reduce 215) ((T_TRAIT_C) reduce 215) ((T_TRY) reduce 215) ((T_UNSET) reduce 215) ((T_UNSET_CAST) reduce 215) ((T_USE) reduce 215) ((T_VARIABLE) reduce 215) ((T_WHILE) reduce 215) ((T_YIELD) reduce 215) ((T_YIELD_FROM) reduce 215) (("[") reduce 215) (("`") reduce 215) (("{") reduce 215) (("}") reduce 215) (("~") reduce 215)) 28199 ((("!") reduce 216) (("\"") reduce 216) (("$") reduce 216) (("(") reduce 216) (("+") reduce 216) (("-") reduce 216) ((";") reduce 216) (("@") reduce 216) ((T_ABSTRACT) reduce 216) ((T_ARRAY) reduce 216) ((T_ARRAY_CAST) reduce 216) ((T_ATTRIBUTE) reduce 216) ((T_BOOL_CAST) reduce 216) ((T_BREAK) reduce 216) ((T_CLASS) reduce 216) ((T_CLASS_C) reduce 216) ((T_CLONE) reduce 216) ((T_CONST) reduce 216) ((T_CONSTANT_ENCAPSED_STRING) reduce 216) ((T_CONTINUE) reduce 216) ((T_DEC) reduce 216) ((T_DECLARE) reduce 216) ((T_DIR) reduce 216) ((T_DNUMBER) reduce 216) ((T_DO) reduce 216) ((T_DOUBLE_CAST) reduce 216) ((T_ECHO) reduce 216) ((T_EMPTY) reduce 216) ((T_ENUM) reduce 216) ((T_EVAL) reduce 216) ((T_EXIT) reduce 216) ((T_FILE) reduce 216) ((T_FINAL) reduce 216) ((T_FN) reduce 216) ((T_FOR) reduce 216) ((T_FOREACH) reduce 216) ((T_FUNCTION) reduce 216) ((T_FUNC_C) reduce 216) ((T_GLOBAL) reduce 216) ((T_GOTO) reduce 216) ((T_HALT_COMPILER) reduce 216) ((T_IF) reduce 216) ((T_INC) reduce 216) ((T_INCLUDE) reduce 216) ((T_INCLUDE_ONCE) reduce 216) ((T_INLINE_HTML) reduce 216) ((T_INTERFACE) reduce 216) ((T_INT_CAST) reduce 216) ((T_ISSET) reduce 216) ((T_LINE) reduce 216) ((T_LIST) reduce 216) ((T_LNUMBER) reduce 216) ((T_MATCH) reduce 216) ((T_METHOD_C) reduce 216) ((T_NAMESPACE) reduce 216) ((T_NAME_FULLY_QUALIFIED) reduce 216) ((T_NAME_QUALIFIED) reduce 216) ((T_NAME_RELATIVE) reduce 216) ((T_NEW) reduce 216) ((T_NS_C) reduce 216) ((T_OBJECT_CAST) reduce 216) ((T_PRINT) reduce 216) ((T_READONLY) reduce 216) ((T_REQUIRE) reduce 216) ((T_REQUIRE_ONCE) reduce 216) ((T_RETURN) reduce 216) ((T_START_HEREDOC) reduce 216) ((T_STATIC) reduce 216) ((T_STRING) reduce 216) ((T_STRING_CAST) reduce 216) ((T_SWITCH) reduce 216) ((T_THROW) reduce 216) ((T_TRAIT) reduce 216) ((T_TRAIT_C) reduce 216) ((T_TRY) reduce 216) ((T_UNSET) reduce 216) ((T_UNSET_CAST) reduce 216) ((T_USE) reduce 216) ((T_VARIABLE) reduce 216) ((T_WHILE) reduce 216) ((T_YIELD) reduce 216) ((T_YIELD_FROM) reduce 216) (("[") reduce 216) (("`") reduce 216) (("{") reduce 216) (("}") reduce 216) (("~") reduce 216)) 28206 ((("!") reduce 199) (("\"") reduce 199) (("$") reduce 199) (("(") reduce 199) (("+") reduce 199) (("-") reduce 199) ((";") reduce 199) (("@") reduce 199) ((T_ABSTRACT) reduce 199) ((T_ARRAY) reduce 199) ((T_ARRAY_CAST) reduce 199) ((T_ATTRIBUTE) reduce 199) ((T_BOOL_CAST) reduce 199) ((T_BREAK) reduce 199) ((T_CLASS) reduce 199) ((T_CLASS_C) reduce 199) ((T_CLONE) reduce 199) ((T_CONST) reduce 199) ((T_CONSTANT_ENCAPSED_STRING) reduce 199) ((T_CONTINUE) reduce 199) ((T_DEC) reduce 199) ((T_DECLARE) reduce 199) ((T_DIR) reduce 199) ((T_DNUMBER) reduce 199) ((T_DO) reduce 199) ((T_DOUBLE_CAST) reduce 199) ((T_ECHO) reduce 199) ((T_EMPTY) reduce 199) ((T_ENUM) reduce 199) ((T_EVAL) reduce 199) ((T_EXIT) reduce 199) ((T_FILE) reduce 199) ((T_FINAL) reduce 199) ((T_FN) reduce 199) ((T_FOR) reduce 199) ((T_FOREACH) reduce 199) ((T_FUNCTION) reduce 199) ((T_FUNC_C) reduce 199) ((T_GLOBAL) reduce 199) ((T_GOTO) reduce 199) ((T_HALT_COMPILER) reduce 199) ((T_IF) reduce 199) ((T_INC) reduce 199) ((T_INCLUDE) reduce 199) ((T_INCLUDE_ONCE) reduce 199) ((T_INLINE_HTML) reduce 199) ((T_INTERFACE) reduce 199) ((T_INT_CAST) reduce 199) ((T_ISSET) reduce 199) ((T_LINE) reduce 199) ((T_LIST) reduce 199) ((T_LNUMBER) reduce 199) ((T_MATCH) reduce 199) ((T_METHOD_C) reduce 199) ((T_NAMESPACE) reduce 199) ((T_NAME_FULLY_QUALIFIED) reduce 199) ((T_NAME_QUALIFIED) reduce 199) ((T_NAME_RELATIVE) reduce 199) ((T_NEW) reduce 199) ((T_NS_C) reduce 199) ((T_OBJECT_CAST) reduce 199) ((T_PRINT) reduce 199) ((T_READONLY) reduce 199) ((T_REQUIRE) reduce 199) ((T_REQUIRE_ONCE) reduce 199) ((T_RETURN) reduce 199) ((T_START_HEREDOC) reduce 199) ((T_STATIC) reduce 199) ((T_STRING) reduce 199) ((T_STRING_CAST) reduce 199) ((T_SWITCH) reduce 199) ((T_THROW) reduce 199) ((T_TRAIT) reduce 199) ((T_TRAIT_C) reduce 199) ((T_TRY) reduce 199) ((T_UNSET) reduce 199) ((T_UNSET_CAST) reduce 199) ((T_USE) reduce 199) ((T_VARIABLE) reduce 199) ((T_WHILE) reduce 199) ((T_YIELD) reduce 199) ((T_YIELD_FROM) reduce 199) (("[") reduce 199) (("`") reduce 199) (("{") reduce 199) (("}") reduce 199) (("~") reduce 199)) 28208 ((("!") reduce 157) (("\"") reduce 157) (("$") reduce 157) (("(") reduce 157) (("+") reduce 157) (("-") reduce 157) ((";") reduce 157) (("@") reduce 157) ((T_ABSTRACT) reduce 157) ((T_ARRAY) reduce 157) ((T_ARRAY_CAST) reduce 157) ((T_ATTRIBUTE) reduce 157) ((T_BOOL_CAST) reduce 157) ((T_BREAK) reduce 157) ((T_CLASS) reduce 157) ((T_CLASS_C) reduce 157) ((T_CLONE) reduce 157) ((T_CONST) reduce 157) ((T_CONSTANT_ENCAPSED_STRING) reduce 157) ((T_CONTINUE) reduce 157) ((T_DEC) reduce 157) ((T_DECLARE) reduce 157) ((T_DIR) reduce 157) ((T_DNUMBER) reduce 157) ((T_DO) reduce 157) ((T_DOUBLE_CAST) reduce 157) ((T_ECHO) reduce 157) ((T_EMPTY) reduce 157) ((T_ENUM) reduce 157) ((T_EVAL) reduce 157) ((T_EXIT) reduce 157) ((T_FILE) reduce 157) ((T_FINAL) reduce 157) ((T_FN) reduce 157) ((T_FOR) reduce 157) ((T_FOREACH) reduce 157) ((T_FUNCTION) reduce 157) ((T_FUNC_C) reduce 157) ((T_GLOBAL) reduce 157) ((T_GOTO) reduce 157) ((T_HALT_COMPILER) reduce 157) ((T_IF) reduce 157) ((T_INC) reduce 157) ((T_INCLUDE) reduce 157) ((T_INCLUDE_ONCE) reduce 157) ((T_INLINE_HTML) reduce 157) ((T_INTERFACE) reduce 157) ((T_INT_CAST) reduce 157) ((T_ISSET) reduce 157) ((T_LINE) reduce 157) ((T_LIST) reduce 157) ((T_LNUMBER) reduce 157) ((T_MATCH) reduce 157) ((T_METHOD_C) reduce 157) ((T_NAMESPACE) reduce 157) ((T_NAME_FULLY_QUALIFIED) reduce 157) ((T_NAME_QUALIFIED) reduce 157) ((T_NAME_RELATIVE) reduce 157) ((T_NEW) reduce 157) ((T_NS_C) reduce 157) ((T_OBJECT_CAST) reduce 157) ((T_PRINT) reduce 157) ((T_READONLY) reduce 157) ((T_REQUIRE) reduce 157) ((T_REQUIRE_ONCE) reduce 157) ((T_RETURN) reduce 157) ((T_START_HEREDOC) reduce 157) ((T_STATIC) reduce 157) ((T_STRING) reduce 157) ((T_STRING_CAST) reduce 157) ((T_SWITCH) reduce 157) ((T_THROW) reduce 157) ((T_TRAIT) reduce 157) ((T_TRAIT_C) reduce 157) ((T_TRY) reduce 157) ((T_UNSET) reduce 157) ((T_UNSET_CAST) reduce 157) ((T_USE) reduce 157) ((T_VARIABLE) reduce 157) ((T_WHILE) reduce 157) ((T_YIELD) reduce 157) ((T_YIELD_FROM) reduce 157) (("[") reduce 157) (("`") reduce 157) (("{") reduce 157) (("}") reduce 157) (("~") reduce 157)) 28214 ((("!") reduce 149) (("\"") reduce 149) (("$") reduce 149) (("(") reduce 149) (("+") reduce 149) (("-") reduce 149) ((";") reduce 149) (("@") reduce 149) ((T_ABSTRACT) reduce 149) ((T_ARRAY) reduce 149) ((T_ARRAY_CAST) reduce 149) ((T_ATTRIBUTE) reduce 149) ((T_BOOL_CAST) reduce 149) ((T_BREAK) reduce 149) ((T_CLASS) reduce 149) ((T_CLASS_C) reduce 149) ((T_CLONE) reduce 149) ((T_CONST) reduce 149) ((T_CONSTANT_ENCAPSED_STRING) reduce 149) ((T_CONTINUE) reduce 149) ((T_DEC) reduce 149) ((T_DECLARE) reduce 149) ((T_DIR) reduce 149) ((T_DNUMBER) reduce 149) ((T_DO) reduce 149) ((T_DOUBLE_CAST) reduce 149) ((T_ECHO) reduce 149) ((T_EMPTY) reduce 149) ((T_ENUM) reduce 149) ((T_EVAL) reduce 149) ((T_EXIT) reduce 149) ((T_FILE) reduce 149) ((T_FINAL) reduce 149) ((T_FN) reduce 149) ((T_FOR) reduce 149) ((T_FOREACH) reduce 149) ((T_FUNCTION) reduce 149) ((T_FUNC_C) reduce 149) ((T_GLOBAL) reduce 149) ((T_GOTO) reduce 149) ((T_HALT_COMPILER) reduce 149) ((T_IF) reduce 149) ((T_INC) reduce 149) ((T_INCLUDE) reduce 149) ((T_INCLUDE_ONCE) reduce 149) ((T_INLINE_HTML) reduce 149) ((T_INTERFACE) reduce 149) ((T_INT_CAST) reduce 149) ((T_ISSET) reduce 149) ((T_LINE) reduce 149) ((T_LIST) reduce 149) ((T_LNUMBER) reduce 149) ((T_MATCH) reduce 149) ((T_METHOD_C) reduce 149) ((T_NAMESPACE) reduce 149) ((T_NAME_FULLY_QUALIFIED) reduce 149) ((T_NAME_QUALIFIED) reduce 149) ((T_NAME_RELATIVE) reduce 149) ((T_NEW) reduce 149) ((T_NS_C) reduce 149) ((T_OBJECT_CAST) reduce 149) ((T_PRINT) reduce 149) ((T_READONLY) reduce 149) ((T_REQUIRE) reduce 149) ((T_REQUIRE_ONCE) reduce 149) ((T_RETURN) reduce 149) ((T_START_HEREDOC) reduce 149) ((T_STATIC) reduce 149) ((T_STRING) reduce 149) ((T_STRING_CAST) reduce 149) ((T_SWITCH) reduce 149) ((T_THROW) reduce 149) ((T_TRAIT) reduce 149) ((T_TRAIT_C) reduce 149) ((T_TRY) reduce 149) ((T_UNSET) reduce 149) ((T_UNSET_CAST) reduce 149) ((T_USE) reduce 149) ((T_VARIABLE) reduce 149) ((T_WHILE) reduce 149) ((T_YIELD) reduce 149) ((T_YIELD_FROM) reduce 149) (("[") reduce 149) (("`") reduce 149) (("{") reduce 149) (("}") reduce 149) (("~") reduce 149)) 28219 ((("!") reduce 163) (("\"") reduce 163) (("$") reduce 163) (("(") reduce 163) (("+") reduce 163) (("-") reduce 163) ((";") reduce 163) (("@") reduce 163) ((T_ABSTRACT) reduce 163) ((T_ARRAY) reduce 163) ((T_ARRAY_CAST) reduce 163) ((T_ATTRIBUTE) reduce 163) ((T_BOOL_CAST) reduce 163) ((T_BREAK) reduce 163) ((T_CLASS) reduce 163) ((T_CLASS_C) reduce 163) ((T_CLONE) reduce 163) ((T_CONST) reduce 163) ((T_CONSTANT_ENCAPSED_STRING) reduce 163) ((T_CONTINUE) reduce 163) ((T_DEC) reduce 163) ((T_DECLARE) reduce 163) ((T_DIR) reduce 163) ((T_DNUMBER) reduce 163) ((T_DO) reduce 163) ((T_DOUBLE_CAST) reduce 163) ((T_ECHO) reduce 163) ((T_EMPTY) reduce 163) ((T_ENUM) reduce 163) ((T_EVAL) reduce 163) ((T_EXIT) reduce 163) ((T_FILE) reduce 163) ((T_FINAL) reduce 163) ((T_FN) reduce 163) ((T_FOR) reduce 163) ((T_FOREACH) reduce 163) ((T_FUNCTION) reduce 163) ((T_FUNC_C) reduce 163) ((T_GLOBAL) reduce 163) ((T_GOTO) reduce 163) ((T_HALT_COMPILER) reduce 163) ((T_IF) reduce 163) ((T_INC) reduce 163) ((T_INCLUDE) reduce 163) ((T_INCLUDE_ONCE) reduce 163) ((T_INLINE_HTML) reduce 163) ((T_INTERFACE) reduce 163) ((T_INT_CAST) reduce 163) ((T_ISSET) reduce 163) ((T_LINE) reduce 163) ((T_LIST) reduce 163) ((T_LNUMBER) reduce 163) ((T_MATCH) reduce 163) ((T_METHOD_C) reduce 163) ((T_NAMESPACE) reduce 163) ((T_NAME_FULLY_QUALIFIED) reduce 163) ((T_NAME_QUALIFIED) reduce 163) ((T_NAME_RELATIVE) reduce 163) ((T_NEW) reduce 163) ((T_NS_C) reduce 163) ((T_OBJECT_CAST) reduce 163) ((T_PRINT) reduce 163) ((T_READONLY) reduce 163) ((T_REQUIRE) reduce 163) ((T_REQUIRE_ONCE) reduce 163) ((T_RETURN) reduce 163) ((T_START_HEREDOC) reduce 163) ((T_STATIC) reduce 163) ((T_STRING) reduce 163) ((T_STRING_CAST) reduce 163) ((T_SWITCH) reduce 163) ((T_THROW) reduce 163) ((T_TRAIT) reduce 163) ((T_TRAIT_C) reduce 163) ((T_TRY) reduce 163) ((T_UNSET) reduce 163) ((T_UNSET_CAST) reduce 163) ((T_USE) reduce 163) ((T_VARIABLE) reduce 163) ((T_WHILE) reduce 163) ((T_YIELD) reduce 163) ((T_YIELD_FROM) reduce 163) (("[") reduce 163) (("`") reduce 163) (("{") reduce 163) (("}") reduce 163) (("~") reduce 163)) 28220 ((("!") reduce 219) (("\"") reduce 219) (("$") reduce 219) (("(") reduce 219) (("+") reduce 219) (("-") reduce 219) ((";") reduce 219) (("@") reduce 219) ((T_ABSTRACT) reduce 219) ((T_ARRAY) reduce 219) ((T_ARRAY_CAST) reduce 219) ((T_ATTRIBUTE) reduce 219) ((T_BOOL_CAST) reduce 219) ((T_BREAK) reduce 219) ((T_CLASS) reduce 219) ((T_CLASS_C) reduce 219) ((T_CLONE) reduce 219) ((T_CONST) reduce 219) ((T_CONSTANT_ENCAPSED_STRING) reduce 219) ((T_CONTINUE) reduce 219) ((T_DEC) reduce 219) ((T_DECLARE) reduce 219) ((T_DIR) reduce 219) ((T_DNUMBER) reduce 219) ((T_DO) reduce 219) ((T_DOUBLE_CAST) reduce 219) ((T_ECHO) reduce 219) ((T_EMPTY) reduce 219) ((T_ENUM) reduce 219) ((T_EVAL) reduce 219) ((T_EXIT) reduce 219) ((T_FILE) reduce 219) ((T_FINAL) reduce 219) ((T_FN) reduce 219) ((T_FOR) reduce 219) ((T_FOREACH) reduce 219) ((T_FUNCTION) reduce 219) ((T_FUNC_C) reduce 219) ((T_GLOBAL) reduce 219) ((T_GOTO) reduce 219) ((T_HALT_COMPILER) reduce 219) ((T_IF) reduce 219) ((T_INC) reduce 219) ((T_INCLUDE) reduce 219) ((T_INCLUDE_ONCE) reduce 219) ((T_INLINE_HTML) reduce 219) ((T_INTERFACE) reduce 219) ((T_INT_CAST) reduce 219) ((T_ISSET) reduce 219) ((T_LINE) reduce 219) ((T_LIST) reduce 219) ((T_LNUMBER) reduce 219) ((T_MATCH) reduce 219) ((T_METHOD_C) reduce 219) ((T_NAMESPACE) reduce 219) ((T_NAME_FULLY_QUALIFIED) reduce 219) ((T_NAME_QUALIFIED) reduce 219) ((T_NAME_RELATIVE) reduce 219) ((T_NEW) reduce 219) ((T_NS_C) reduce 219) ((T_OBJECT_CAST) reduce 219) ((T_PRINT) reduce 219) ((T_READONLY) reduce 219) ((T_REQUIRE) reduce 219) ((T_REQUIRE_ONCE) reduce 219) ((T_RETURN) reduce 219) ((T_START_HEREDOC) reduce 219) ((T_STATIC) reduce 219) ((T_STRING) reduce 219) ((T_STRING_CAST) reduce 219) ((T_SWITCH) reduce 219) ((T_THROW) reduce 219) ((T_TRAIT) reduce 219) ((T_TRAIT_C) reduce 219) ((T_TRY) reduce 219) ((T_UNSET) reduce 219) ((T_UNSET_CAST) reduce 219) ((T_USE) reduce 219) ((T_VARIABLE) reduce 219) ((T_WHILE) reduce 219) ((T_YIELD) reduce 219) ((T_YIELD_FROM) reduce 219) (("[") reduce 219) (("`") reduce 219) (("{") reduce 219) (("}") reduce 219) (("~") reduce 219)) 28223 ((("!") reduce 220) (("\"") reduce 220) (("$") reduce 220) (("(") reduce 220) (("+") reduce 220) (("-") reduce 220) ((";") reduce 220) (("@") reduce 220) ((T_ABSTRACT) reduce 220) ((T_ARRAY) reduce 220) ((T_ARRAY_CAST) reduce 220) ((T_ATTRIBUTE) reduce 220) ((T_BOOL_CAST) reduce 220) ((T_BREAK) reduce 220) ((T_CLASS) reduce 220) ((T_CLASS_C) reduce 220) ((T_CLONE) reduce 220) ((T_CONST) reduce 220) ((T_CONSTANT_ENCAPSED_STRING) reduce 220) ((T_CONTINUE) reduce 220) ((T_DEC) reduce 220) ((T_DECLARE) reduce 220) ((T_DIR) reduce 220) ((T_DNUMBER) reduce 220) ((T_DO) reduce 220) ((T_DOUBLE_CAST) reduce 220) ((T_ECHO) reduce 220) ((T_EMPTY) reduce 220) ((T_ENUM) reduce 220) ((T_EVAL) reduce 220) ((T_EXIT) reduce 220) ((T_FILE) reduce 220) ((T_FINAL) reduce 220) ((T_FN) reduce 220) ((T_FOR) reduce 220) ((T_FOREACH) reduce 220) ((T_FUNCTION) reduce 220) ((T_FUNC_C) reduce 220) ((T_GLOBAL) reduce 220) ((T_GOTO) reduce 220) ((T_HALT_COMPILER) reduce 220) ((T_IF) reduce 220) ((T_INC) reduce 220) ((T_INCLUDE) reduce 220) ((T_INCLUDE_ONCE) reduce 220) ((T_INLINE_HTML) reduce 220) ((T_INTERFACE) reduce 220) ((T_INT_CAST) reduce 220) ((T_ISSET) reduce 220) ((T_LINE) reduce 220) ((T_LIST) reduce 220) ((T_LNUMBER) reduce 220) ((T_MATCH) reduce 220) ((T_METHOD_C) reduce 220) ((T_NAMESPACE) reduce 220) ((T_NAME_FULLY_QUALIFIED) reduce 220) ((T_NAME_QUALIFIED) reduce 220) ((T_NAME_RELATIVE) reduce 220) ((T_NEW) reduce 220) ((T_NS_C) reduce 220) ((T_OBJECT_CAST) reduce 220) ((T_PRINT) reduce 220) ((T_READONLY) reduce 220) ((T_REQUIRE) reduce 220) ((T_REQUIRE_ONCE) reduce 220) ((T_RETURN) reduce 220) ((T_START_HEREDOC) reduce 220) ((T_STATIC) reduce 220) ((T_STRING) reduce 220) ((T_STRING_CAST) reduce 220) ((T_SWITCH) reduce 220) ((T_THROW) reduce 220) ((T_TRAIT) reduce 220) ((T_TRAIT_C) reduce 220) ((T_TRY) reduce 220) ((T_UNSET) reduce 220) ((T_UNSET_CAST) reduce 220) ((T_USE) reduce 220) ((T_VARIABLE) reduce 220) ((T_WHILE) reduce 220) ((T_YIELD) reduce 220) ((T_YIELD_FROM) reduce 220) (("[") reduce 220) (("`") reduce 220) (("{") reduce 220) (("}") reduce 220) (("~") reduce 220)) 28225 ((("!") reduce 153) (("\"") reduce 153) (("$") reduce 153) (("(") reduce 153) (("+") reduce 153) (("-") reduce 153) ((";") reduce 153) (("@") reduce 153) ((T_ABSTRACT) reduce 153) ((T_ARRAY) reduce 153) ((T_ARRAY_CAST) reduce 153) ((T_ATTRIBUTE) reduce 153) ((T_BOOL_CAST) reduce 153) ((T_BREAK) reduce 153) ((T_CLASS) reduce 153) ((T_CLASS_C) reduce 153) ((T_CLONE) reduce 153) ((T_CONST) reduce 153) ((T_CONSTANT_ENCAPSED_STRING) reduce 153) ((T_CONTINUE) reduce 153) ((T_DEC) reduce 153) ((T_DECLARE) reduce 153) ((T_DIR) reduce 153) ((T_DNUMBER) reduce 153) ((T_DO) reduce 153) ((T_DOUBLE_CAST) reduce 153) ((T_ECHO) reduce 153) ((T_EMPTY) reduce 153) ((T_ENUM) reduce 153) ((T_EVAL) reduce 153) ((T_EXIT) reduce 153) ((T_FILE) reduce 153) ((T_FINAL) reduce 153) ((T_FN) reduce 153) ((T_FOR) reduce 153) ((T_FOREACH) reduce 153) ((T_FUNCTION) reduce 153) ((T_FUNC_C) reduce 153) ((T_GLOBAL) reduce 153) ((T_GOTO) reduce 153) ((T_HALT_COMPILER) reduce 153) ((T_IF) reduce 153) ((T_INC) reduce 153) ((T_INCLUDE) reduce 153) ((T_INCLUDE_ONCE) reduce 153) ((T_INLINE_HTML) reduce 153) ((T_INTERFACE) reduce 153) ((T_INT_CAST) reduce 153) ((T_ISSET) reduce 153) ((T_LINE) reduce 153) ((T_LIST) reduce 153) ((T_LNUMBER) reduce 153) ((T_MATCH) reduce 153) ((T_METHOD_C) reduce 153) ((T_NAMESPACE) reduce 153) ((T_NAME_FULLY_QUALIFIED) reduce 153) ((T_NAME_QUALIFIED) reduce 153) ((T_NAME_RELATIVE) reduce 153) ((T_NEW) reduce 153) ((T_NS_C) reduce 153) ((T_OBJECT_CAST) reduce 153) ((T_PRINT) reduce 153) ((T_READONLY) reduce 153) ((T_REQUIRE) reduce 153) ((T_REQUIRE_ONCE) reduce 153) ((T_RETURN) reduce 153) ((T_START_HEREDOC) reduce 153) ((T_STATIC) reduce 153) ((T_STRING) reduce 153) ((T_STRING_CAST) reduce 153) ((T_SWITCH) reduce 153) ((T_THROW) reduce 153) ((T_TRAIT) reduce 153) ((T_TRAIT_C) reduce 153) ((T_TRY) reduce 153) ((T_UNSET) reduce 153) ((T_UNSET_CAST) reduce 153) ((T_USE) reduce 153) ((T_VARIABLE) reduce 153) ((T_WHILE) reduce 153) ((T_YIELD) reduce 153) ((T_YIELD_FROM) reduce 153) (("[") reduce 153) (("`") reduce 153) (("{") reduce 153) (("}") reduce 153) (("~") reduce 153)) 28227 (((",") reduce 138) ((";") reduce 138)) 28230 ((("!") reduce 118) (("\"") reduce 118) (("$") reduce 118) (("(") reduce 118) (("+") reduce 118) (("-") reduce 118) ((";") reduce 118) (("@") reduce 118) ((T_ABSTRACT) reduce 118) ((T_ARRAY) reduce 118) ((T_ARRAY_CAST) reduce 118) ((T_ATTRIBUTE) reduce 118) ((T_BOOL_CAST) reduce 118) ((T_BREAK) reduce 118) ((T_CLASS) reduce 118) ((T_CLASS_C) reduce 118) ((T_CLONE) reduce 118) ((T_CONST) reduce 118) ((T_CONSTANT_ENCAPSED_STRING) reduce 118) ((T_CONTINUE) reduce 118) ((T_DEC) reduce 118) ((T_DECLARE) reduce 118) ((T_DIR) reduce 118) ((T_DNUMBER) reduce 118) ((T_DO) reduce 118) ((T_DOUBLE_CAST) reduce 118) ((T_ECHO) reduce 118) ((T_EMPTY) reduce 118) ((T_ENUM) reduce 118) ((T_EVAL) reduce 118) ((T_EXIT) reduce 118) ((T_FILE) reduce 118) ((T_FINAL) reduce 118) ((T_FN) reduce 118) ((T_FOR) reduce 118) ((T_FOREACH) reduce 118) ((T_FUNCTION) reduce 118) ((T_FUNC_C) reduce 118) ((T_GLOBAL) reduce 118) ((T_GOTO) reduce 118) ((T_HALT_COMPILER) reduce 118) ((T_IF) reduce 118) ((T_INC) reduce 118) ((T_INCLUDE) reduce 118) ((T_INCLUDE_ONCE) reduce 118) ((T_INLINE_HTML) reduce 118) ((T_INTERFACE) reduce 118) ((T_INT_CAST) reduce 118) ((T_ISSET) reduce 118) ((T_LINE) reduce 118) ((T_LIST) reduce 118) ((T_LNUMBER) reduce 118) ((T_MATCH) reduce 118) ((T_METHOD_C) reduce 118) ((T_NAMESPACE) reduce 118) ((T_NAME_FULLY_QUALIFIED) reduce 118) ((T_NAME_QUALIFIED) reduce 118) ((T_NAME_RELATIVE) reduce 118) ((T_NEW) reduce 118) ((T_NS_C) reduce 118) ((T_OBJECT_CAST) reduce 118) ((T_PRINT) reduce 118) ((T_READONLY) reduce 118) ((T_REQUIRE) reduce 118) ((T_REQUIRE_ONCE) reduce 118) ((T_RETURN) reduce 118) ((T_START_HEREDOC) reduce 118) ((T_STATIC) reduce 118) ((T_STRING) reduce 118) ((T_STRING_CAST) reduce 118) ((T_SWITCH) reduce 118) ((T_THROW) reduce 118) ((T_TRAIT) reduce 118) ((T_TRAIT_C) reduce 118) ((T_TRY) reduce 118) ((T_UNSET) reduce 118) ((T_UNSET_CAST) reduce 118) ((T_USE) reduce 118) ((T_VARIABLE) reduce 118) ((T_WHILE) reduce 118) ((T_YIELD) reduce 118) ((T_YIELD_FROM) reduce 118) (("[") reduce 118) (("`") reduce 118) (("{") reduce 118) (("}") reduce 118) (("~") reduce 118)) 28231 (((",") reduce 137) ((";") reduce 137)) 28234 (((",") reduce 355) ((";") reduce 355)) 28241 ((("!") reduce 187) (("\"") reduce 187) (("$") reduce 187) (("(") reduce 187) (("+") reduce 187) (("-") reduce 187) ((";") reduce 187) (("@") reduce 187) ((T_ABSTRACT) reduce 187) ((T_ARRAY) reduce 187) ((T_ARRAY_CAST) reduce 187) ((T_ATTRIBUTE) reduce 187) ((T_BOOL_CAST) reduce 187) ((T_BREAK) reduce 187) ((T_CLASS) reduce 187) ((T_CLASS_C) reduce 187) ((T_CLONE) reduce 187) ((T_CONST) reduce 187) ((T_CONSTANT_ENCAPSED_STRING) reduce 187) ((T_CONTINUE) reduce 187) ((T_DEC) reduce 187) ((T_DECLARE) reduce 187) ((T_DIR) reduce 187) ((T_DNUMBER) reduce 187) ((T_DO) reduce 187) ((T_DOUBLE_CAST) reduce 187) ((T_ECHO) reduce 187) ((T_EMPTY) reduce 187) ((T_ENUM) reduce 187) ((T_EVAL) reduce 187) ((T_EXIT) reduce 187) ((T_FILE) reduce 187) ((T_FINAL) reduce 187) ((T_FN) reduce 187) ((T_FOR) reduce 187) ((T_FOREACH) reduce 187) ((T_FUNCTION) reduce 187) ((T_FUNC_C) reduce 187) ((T_GLOBAL) reduce 187) ((T_GOTO) reduce 187) ((T_HALT_COMPILER) reduce 187) ((T_IF) reduce 187) ((T_INC) reduce 187) ((T_INCLUDE) reduce 187) ((T_INCLUDE_ONCE) reduce 187) ((T_INLINE_HTML) reduce 187) ((T_INTERFACE) reduce 187) ((T_INT_CAST) reduce 187) ((T_ISSET) reduce 187) ((T_LINE) reduce 187) ((T_LIST) reduce 187) ((T_LNUMBER) reduce 187) ((T_MATCH) reduce 187) ((T_METHOD_C) reduce 187) ((T_NAMESPACE) reduce 187) ((T_NAME_FULLY_QUALIFIED) reduce 187) ((T_NAME_QUALIFIED) reduce 187) ((T_NAME_RELATIVE) reduce 187) ((T_NEW) reduce 187) ((T_NS_C) reduce 187) ((T_OBJECT_CAST) reduce 187) ((T_PRINT) reduce 187) ((T_READONLY) reduce 187) ((T_REQUIRE) reduce 187) ((T_REQUIRE_ONCE) reduce 187) ((T_RETURN) reduce 187) ((T_START_HEREDOC) reduce 187) ((T_STATIC) reduce 187) ((T_STRING) reduce 187) ((T_STRING_CAST) reduce 187) ((T_SWITCH) reduce 187) ((T_THROW) reduce 187) ((T_TRAIT) reduce 187) ((T_TRAIT_C) reduce 187) ((T_TRY) reduce 187) ((T_UNSET) reduce 187) ((T_UNSET_CAST) reduce 187) ((T_USE) reduce 187) ((T_VARIABLE) reduce 187) ((T_WHILE) reduce 187) ((T_YIELD) reduce 187) ((T_YIELD_FROM) reduce 187) (("[") reduce 187) (("`") reduce 187) (("{") reduce 187) (("}") reduce 187) (("~") reduce 187)) 28243 ((("!") reduce 152) (("\"") reduce 152) (("$") reduce 152) (("(") reduce 152) (("+") reduce 152) (("-") reduce 152) ((";") reduce 152) (("@") reduce 152) ((T_ABSTRACT) reduce 152) ((T_ARRAY) reduce 152) ((T_ARRAY_CAST) reduce 152) ((T_ATTRIBUTE) reduce 152) ((T_BOOL_CAST) reduce 152) ((T_BREAK) reduce 152) ((T_CLASS) reduce 152) ((T_CLASS_C) reduce 152) ((T_CLONE) reduce 152) ((T_CONST) reduce 152) ((T_CONSTANT_ENCAPSED_STRING) reduce 152) ((T_CONTINUE) reduce 152) ((T_DEC) reduce 152) ((T_DECLARE) reduce 152) ((T_DIR) reduce 152) ((T_DNUMBER) reduce 152) ((T_DO) reduce 152) ((T_DOUBLE_CAST) reduce 152) ((T_ECHO) reduce 152) ((T_EMPTY) reduce 152) ((T_ENUM) reduce 152) ((T_EVAL) reduce 152) ((T_EXIT) reduce 152) ((T_FILE) reduce 152) ((T_FINAL) reduce 152) ((T_FN) reduce 152) ((T_FOR) reduce 152) ((T_FOREACH) reduce 152) ((T_FUNCTION) reduce 152) ((T_FUNC_C) reduce 152) ((T_GLOBAL) reduce 152) ((T_GOTO) reduce 152) ((T_HALT_COMPILER) reduce 152) ((T_IF) reduce 152) ((T_INC) reduce 152) ((T_INCLUDE) reduce 152) ((T_INCLUDE_ONCE) reduce 152) ((T_INLINE_HTML) reduce 152) ((T_INTERFACE) reduce 152) ((T_INT_CAST) reduce 152) ((T_ISSET) reduce 152) ((T_LINE) reduce 152) ((T_LIST) reduce 152) ((T_LNUMBER) reduce 152) ((T_MATCH) reduce 152) ((T_METHOD_C) reduce 152) ((T_NAMESPACE) reduce 152) ((T_NAME_FULLY_QUALIFIED) reduce 152) ((T_NAME_QUALIFIED) reduce 152) ((T_NAME_RELATIVE) reduce 152) ((T_NEW) reduce 152) ((T_NS_C) reduce 152) ((T_OBJECT_CAST) reduce 152) ((T_PRINT) reduce 152) ((T_READONLY) reduce 152) ((T_REQUIRE) reduce 152) ((T_REQUIRE_ONCE) reduce 152) ((T_RETURN) reduce 152) ((T_START_HEREDOC) reduce 152) ((T_STATIC) reduce 152) ((T_STRING) reduce 152) ((T_STRING_CAST) reduce 152) ((T_SWITCH) reduce 152) ((T_THROW) reduce 152) ((T_TRAIT) reduce 152) ((T_TRAIT_C) reduce 152) ((T_TRY) reduce 152) ((T_UNSET) reduce 152) ((T_UNSET_CAST) reduce 152) ((T_USE) reduce 152) ((T_VARIABLE) reduce 152) ((T_WHILE) reduce 152) ((T_YIELD) reduce 152) ((T_YIELD_FROM) reduce 152) (("[") reduce 152) (("`") reduce 152) (("{") reduce 152) (("}") reduce 152) (("~") reduce 152)) 28244 ((("!") reduce 111) (("\"") reduce 111) (("$") reduce 111) (($) reduce 111) (("(") reduce 111) (("+") reduce 111) (("-") reduce 111) ((";") reduce 111) (("@") reduce 111) ((T_ABSTRACT) reduce 111) ((T_ARRAY) reduce 111) ((T_ARRAY_CAST) reduce 111) ((T_ATTRIBUTE) reduce 111) ((T_BOOL_CAST) reduce 111) ((T_BREAK) reduce 111) ((T_CLASS) reduce 111) ((T_CLASS_C) reduce 111) ((T_CLONE) reduce 111) ((T_CONST) reduce 111) ((T_CONSTANT_ENCAPSED_STRING) reduce 111) ((T_CONTINUE) reduce 111) ((T_DEC) reduce 111) ((T_DECLARE) reduce 111) ((T_DIR) reduce 111) ((T_DNUMBER) reduce 111) ((T_DO) reduce 111) ((T_DOUBLE_CAST) reduce 111) ((T_ECHO) reduce 111) ((T_EMPTY) reduce 111) ((T_ENUM) reduce 111) ((T_EVAL) reduce 111) ((T_EXIT) reduce 111) ((T_FILE) reduce 111) ((T_FINAL) reduce 111) ((T_FN) reduce 111) ((T_FOR) reduce 111) ((T_FOREACH) reduce 111) ((T_FUNCTION) reduce 111) ((T_FUNC_C) reduce 111) ((T_GLOBAL) reduce 111) ((T_GOTO) reduce 111) ((T_HALT_COMPILER) reduce 111) ((T_IF) reduce 111) ((T_INC) reduce 111) ((T_INCLUDE) reduce 111) ((T_INCLUDE_ONCE) reduce 111) ((T_INLINE_HTML) reduce 111) ((T_INTERFACE) reduce 111) ((T_INT_CAST) reduce 111) ((T_ISSET) reduce 111) ((T_LINE) reduce 111) ((T_LIST) reduce 111) ((T_LNUMBER) reduce 111) ((T_MATCH) reduce 111) ((T_METHOD_C) reduce 111) ((T_NAMESPACE) reduce 111) ((T_NAME_FULLY_QUALIFIED) reduce 111) ((T_NAME_QUALIFIED) reduce 111) ((T_NAME_RELATIVE) reduce 111) ((T_NEW) reduce 111) ((T_NS_C) reduce 111) ((T_OBJECT_CAST) reduce 111) ((T_PRINT) reduce 111) ((T_READONLY) reduce 111) ((T_REQUIRE) reduce 111) ((T_REQUIRE_ONCE) reduce 111) ((T_RETURN) reduce 111) ((T_START_HEREDOC) reduce 111) ((T_STATIC) reduce 111) ((T_STRING) reduce 111) ((T_STRING_CAST) reduce 111) ((T_SWITCH) reduce 111) ((T_THROW) reduce 111) ((T_TRAIT) reduce 111) ((T_TRAIT_C) reduce 111) ((T_TRY) reduce 111) ((T_UNSET) reduce 111) ((T_UNSET_CAST) reduce 111) ((T_USE) reduce 111) ((T_VARIABLE) reduce 111) ((T_WHILE) reduce 111) ((T_YIELD) reduce 111) ((T_YIELD_FROM) reduce 111) (("[") reduce 111) (("`") reduce 111) (("{") reduce 111) (("~") reduce 111)) 28247 ((("!") reduce 112) (("\"") reduce 112) (("$") reduce 112) (($) reduce 112) (("(") reduce 112) (("+") reduce 112) (("-") reduce 112) ((";") reduce 112) (("@") reduce 112) ((T_ABSTRACT) reduce 112) ((T_ARRAY) reduce 112) ((T_ARRAY_CAST) reduce 112) ((T_ATTRIBUTE) reduce 112) ((T_BOOL_CAST) reduce 112) ((T_BREAK) reduce 112) ((T_CLASS) reduce 112) ((T_CLASS_C) reduce 112) ((T_CLONE) reduce 112) ((T_CONST) reduce 112) ((T_CONSTANT_ENCAPSED_STRING) reduce 112) ((T_CONTINUE) reduce 112) ((T_DEC) reduce 112) ((T_DECLARE) reduce 112) ((T_DIR) reduce 112) ((T_DNUMBER) reduce 112) ((T_DO) reduce 112) ((T_DOUBLE_CAST) reduce 112) ((T_ECHO) reduce 112) ((T_EMPTY) reduce 112) ((T_ENUM) reduce 112) ((T_EVAL) reduce 112) ((T_EXIT) reduce 112) ((T_FILE) reduce 112) ((T_FINAL) reduce 112) ((T_FN) reduce 112) ((T_FOR) reduce 112) ((T_FOREACH) reduce 112) ((T_FUNCTION) reduce 112) ((T_FUNC_C) reduce 112) ((T_GLOBAL) reduce 112) ((T_GOTO) reduce 112) ((T_HALT_COMPILER) reduce 112) ((T_IF) reduce 112) ((T_INC) reduce 112) ((T_INCLUDE) reduce 112) ((T_INCLUDE_ONCE) reduce 112) ((T_INLINE_HTML) reduce 112) ((T_INTERFACE) reduce 112) ((T_INT_CAST) reduce 112) ((T_ISSET) reduce 112) ((T_LINE) reduce 112) ((T_LIST) reduce 112) ((T_LNUMBER) reduce 112) ((T_MATCH) reduce 112) ((T_METHOD_C) reduce 112) ((T_NAMESPACE) reduce 112) ((T_NAME_FULLY_QUALIFIED) reduce 112) ((T_NAME_QUALIFIED) reduce 112) ((T_NAME_RELATIVE) reduce 112) ((T_NEW) reduce 112) ((T_NS_C) reduce 112) ((T_OBJECT_CAST) reduce 112) ((T_PRINT) reduce 112) ((T_READONLY) reduce 112) ((T_REQUIRE) reduce 112) ((T_REQUIRE_ONCE) reduce 112) ((T_RETURN) reduce 112) ((T_START_HEREDOC) reduce 112) ((T_STATIC) reduce 112) ((T_STRING) reduce 112) ((T_STRING_CAST) reduce 112) ((T_SWITCH) reduce 112) ((T_THROW) reduce 112) ((T_TRAIT) reduce 112) ((T_TRAIT_C) reduce 112) ((T_TRY) reduce 112) ((T_UNSET) reduce 112) ((T_UNSET_CAST) reduce 112) ((T_USE) reduce 112) ((T_VARIABLE) reduce 112) ((T_WHILE) reduce 112) ((T_YIELD) reduce 112) ((T_YIELD_FROM) reduce 112) (("[") reduce 112) (("`") reduce 112) (("{") reduce 112) (("~") reduce 112)) 28269 ((("!") reduce 198) (("\"") reduce 198) (("$") reduce 198) (($) reduce 198) (("(") reduce 198) (("+") reduce 198) (("-") reduce 198) ((";") reduce 198) (("@") reduce 198) ((T_ABSTRACT) reduce 198) ((T_ARRAY) reduce 198) ((T_ARRAY_CAST) reduce 198) ((T_ATTRIBUTE) reduce 198) ((T_BOOL_CAST) reduce 198) ((T_BREAK) reduce 198) ((T_CLASS) reduce 198) ((T_CLASS_C) reduce 198) ((T_CLONE) reduce 198) ((T_CONST) reduce 198) ((T_CONSTANT_ENCAPSED_STRING) reduce 198) ((T_CONTINUE) reduce 198) ((T_DEC) reduce 198) ((T_DECLARE) reduce 198) ((T_DIR) reduce 198) ((T_DNUMBER) reduce 198) ((T_DO) reduce 198) ((T_DOUBLE_CAST) reduce 198) ((T_ECHO) reduce 198) ((T_EMPTY) reduce 198) ((T_ENUM) reduce 198) ((T_EVAL) reduce 198) ((T_EXIT) reduce 198) ((T_FILE) reduce 198) ((T_FINAL) reduce 198) ((T_FN) reduce 198) ((T_FOR) reduce 198) ((T_FOREACH) reduce 198) ((T_FUNCTION) reduce 198) ((T_FUNC_C) reduce 198) ((T_GLOBAL) reduce 198) ((T_GOTO) reduce 198) ((T_HALT_COMPILER) reduce 198) ((T_IF) reduce 198) ((T_INC) reduce 198) ((T_INCLUDE) reduce 198) ((T_INCLUDE_ONCE) reduce 198) ((T_INLINE_HTML) reduce 198) ((T_INTERFACE) reduce 198) ((T_INT_CAST) reduce 198) ((T_ISSET) reduce 198) ((T_LINE) reduce 198) ((T_LIST) reduce 198) ((T_LNUMBER) reduce 198) ((T_MATCH) reduce 198) ((T_METHOD_C) reduce 198) ((T_NAMESPACE) reduce 198) ((T_NAME_FULLY_QUALIFIED) reduce 198) ((T_NAME_QUALIFIED) reduce 198) ((T_NAME_RELATIVE) reduce 198) ((T_NEW) reduce 198) ((T_NS_C) reduce 198) ((T_OBJECT_CAST) reduce 198) ((T_PRINT) reduce 198) ((T_READONLY) reduce 198) ((T_REQUIRE) reduce 198) ((T_REQUIRE_ONCE) reduce 198) ((T_RETURN) reduce 198) ((T_START_HEREDOC) reduce 198) ((T_STATIC) reduce 198) ((T_STRING) reduce 198) ((T_STRING_CAST) reduce 198) ((T_SWITCH) reduce 198) ((T_THROW) reduce 198) ((T_TRAIT) reduce 198) ((T_TRAIT_C) reduce 198) ((T_TRY) reduce 198) ((T_UNSET) reduce 198) ((T_UNSET_CAST) reduce 198) ((T_USE) reduce 198) ((T_VARIABLE) reduce 198) ((T_WHILE) reduce 198) ((T_YIELD) reduce 198) ((T_YIELD_FROM) reduce 198) (("[") reduce 198) (("`") reduce 198) (("{") reduce 198) (("~") reduce 198)) 28276 ((("!") reduce 164) (("\"") reduce 164) (("$") reduce 164) (($) reduce 164) (("(") reduce 164) (("+") reduce 164) (("-") reduce 164) ((";") reduce 164) (("@") reduce 164) ((T_ABSTRACT) reduce 164) ((T_ARRAY) reduce 164) ((T_ARRAY_CAST) reduce 164) ((T_ATTRIBUTE) reduce 164) ((T_BOOL_CAST) reduce 164) ((T_BREAK) reduce 164) ((T_CLASS) reduce 164) ((T_CLASS_C) reduce 164) ((T_CLONE) reduce 164) ((T_CONST) reduce 164) ((T_CONSTANT_ENCAPSED_STRING) reduce 164) ((T_CONTINUE) reduce 164) ((T_DEC) reduce 164) ((T_DECLARE) reduce 164) ((T_DIR) reduce 164) ((T_DNUMBER) reduce 164) ((T_DO) reduce 164) ((T_DOUBLE_CAST) reduce 164) ((T_ECHO) reduce 164) ((T_ELSE) reduce 164) ((T_ELSEIF) reduce 164) ((T_EMPTY) reduce 164) ((T_ENUM) reduce 164) ((T_EVAL) reduce 164) ((T_EXIT) reduce 164) ((T_FILE) reduce 164) ((T_FINAL) reduce 164) ((T_FN) reduce 164) ((T_FOR) reduce 164) ((T_FOREACH) reduce 164) ((T_FUNCTION) reduce 164) ((T_FUNC_C) reduce 164) ((T_GLOBAL) reduce 164) ((T_GOTO) reduce 164) ((T_HALT_COMPILER) reduce 164) ((T_IF) reduce 164) ((T_INC) reduce 164) ((T_INCLUDE) reduce 164) ((T_INCLUDE_ONCE) reduce 164) ((T_INLINE_HTML) reduce 164) ((T_INTERFACE) reduce 164) ((T_INT_CAST) reduce 164) ((T_ISSET) reduce 164) ((T_LINE) reduce 164) ((T_LIST) reduce 164) ((T_LNUMBER) reduce 164) ((T_MATCH) reduce 164) ((T_METHOD_C) reduce 164) ((T_NAMESPACE) reduce 164) ((T_NAME_FULLY_QUALIFIED) reduce 164) ((T_NAME_QUALIFIED) reduce 164) ((T_NAME_RELATIVE) reduce 164) ((T_NEW) reduce 164) ((T_NS_C) reduce 164) ((T_OBJECT_CAST) reduce 164) ((T_PRINT) reduce 164) ((T_READONLY) reduce 164) ((T_REQUIRE) reduce 164) ((T_REQUIRE_ONCE) reduce 164) ((T_RETURN) reduce 164) ((T_START_HEREDOC) reduce 164) ((T_STATIC) reduce 164) ((T_STRING) reduce 164) ((T_STRING_CAST) reduce 164) ((T_SWITCH) reduce 164) ((T_THROW) reduce 164) ((T_TRAIT) reduce 164) ((T_TRAIT_C) reduce 164) ((T_TRY) reduce 164) ((T_UNSET) reduce 164) ((T_UNSET_CAST) reduce 164) ((T_USE) reduce 164) ((T_VARIABLE) reduce 164) ((T_WHILE) reduce 164) ((T_YIELD) reduce 164) ((T_YIELD_FROM) reduce 164) (("[") reduce 164) (("`") reduce 164) (("{") reduce 164) (("~") reduce 164)) 28287 ((("!") reduce 158) (("\"") reduce 158) (("$") reduce 158) (($) reduce 158) (("(") reduce 158) (("+") reduce 158) (("-") reduce 158) ((";") reduce 158) (("@") reduce 158) ((T_ABSTRACT) reduce 158) ((T_ARRAY) reduce 158) ((T_ARRAY_CAST) reduce 158) ((T_ATTRIBUTE) reduce 158) ((T_BOOL_CAST) reduce 158) ((T_BREAK) reduce 158) ((T_CLASS) reduce 158) ((T_CLASS_C) reduce 158) ((T_CLONE) reduce 158) ((T_CONST) reduce 158) ((T_CONSTANT_ENCAPSED_STRING) reduce 158) ((T_CONTINUE) reduce 158) ((T_DEC) reduce 158) ((T_DECLARE) reduce 158) ((T_DIR) reduce 158) ((T_DNUMBER) reduce 158) ((T_DO) reduce 158) ((T_DOUBLE_CAST) reduce 158) ((T_ECHO) reduce 158) ((T_ELSE) reduce 158) ((T_ELSEIF) reduce 158) ((T_EMPTY) reduce 158) ((T_ENUM) reduce 158) ((T_EVAL) reduce 158) ((T_EXIT) reduce 158) ((T_FILE) reduce 158) ((T_FINAL) reduce 158) ((T_FN) reduce 158) ((T_FOR) reduce 158) ((T_FOREACH) reduce 158) ((T_FUNCTION) reduce 158) ((T_FUNC_C) reduce 158) ((T_GLOBAL) reduce 158) ((T_GOTO) reduce 158) ((T_HALT_COMPILER) reduce 158) ((T_IF) reduce 158) ((T_INC) reduce 158) ((T_INCLUDE) reduce 158) ((T_INCLUDE_ONCE) reduce 158) ((T_INLINE_HTML) reduce 158) ((T_INTERFACE) reduce 158) ((T_INT_CAST) reduce 158) ((T_ISSET) reduce 158) ((T_LINE) reduce 158) ((T_LIST) reduce 158) ((T_LNUMBER) reduce 158) ((T_MATCH) reduce 158) ((T_METHOD_C) reduce 158) ((T_NAMESPACE) reduce 158) ((T_NAME_FULLY_QUALIFIED) reduce 158) ((T_NAME_QUALIFIED) reduce 158) ((T_NAME_RELATIVE) reduce 158) ((T_NEW) reduce 158) ((T_NS_C) reduce 158) ((T_OBJECT_CAST) reduce 158) ((T_PRINT) reduce 158) ((T_READONLY) reduce 158) ((T_REQUIRE) reduce 158) ((T_REQUIRE_ONCE) reduce 158) ((T_RETURN) reduce 158) ((T_START_HEREDOC) reduce 158) ((T_STATIC) reduce 158) ((T_STRING) reduce 158) ((T_STRING_CAST) reduce 158) ((T_SWITCH) reduce 158) ((T_THROW) reduce 158) ((T_TRAIT) reduce 158) ((T_TRAIT_C) reduce 158) ((T_TRY) reduce 158) ((T_UNSET) reduce 158) ((T_UNSET_CAST) reduce 158) ((T_USE) reduce 158) ((T_VARIABLE) reduce 158) ((T_WHILE) reduce 158) ((T_YIELD) reduce 158) ((T_YIELD_FROM) reduce 158) (("[") reduce 158) (("`") reduce 158) (("{") reduce 158) (("~") reduce 158)) 28295 ((("!") reduce 147) (("\"") reduce 147) (("$") reduce 147) (($) reduce 147) (("(") reduce 147) (("+") reduce 147) (("-") reduce 147) ((";") reduce 147) (("@") reduce 147) ((T_ABSTRACT) reduce 147) ((T_ARRAY) reduce 147) ((T_ARRAY_CAST) reduce 147) ((T_ATTRIBUTE) reduce 147) ((T_BOOL_CAST) reduce 147) ((T_BREAK) reduce 147) ((T_CLASS) reduce 147) ((T_CLASS_C) reduce 147) ((T_CLONE) reduce 147) ((T_CONST) reduce 147) ((T_CONSTANT_ENCAPSED_STRING) reduce 147) ((T_CONTINUE) reduce 147) ((T_DEC) reduce 147) ((T_DECLARE) reduce 147) ((T_DIR) reduce 147) ((T_DNUMBER) reduce 147) ((T_DO) reduce 147) ((T_DOUBLE_CAST) reduce 147) ((T_ECHO) reduce 147) ((T_ELSE) reduce 147) ((T_ELSEIF) reduce 147) ((T_EMPTY) reduce 147) ((T_ENUM) reduce 147) ((T_EVAL) reduce 147) ((T_EXIT) reduce 147) ((T_FILE) reduce 147) ((T_FINAL) reduce 147) ((T_FN) reduce 147) ((T_FOR) reduce 147) ((T_FOREACH) reduce 147) ((T_FUNCTION) reduce 147) ((T_FUNC_C) reduce 147) ((T_GLOBAL) reduce 147) ((T_GOTO) reduce 147) ((T_HALT_COMPILER) reduce 147) ((T_IF) reduce 147) ((T_INC) reduce 147) ((T_INCLUDE) reduce 147) ((T_INCLUDE_ONCE) reduce 147) ((T_INLINE_HTML) reduce 147) ((T_INTERFACE) reduce 147) ((T_INT_CAST) reduce 147) ((T_ISSET) reduce 147) ((T_LINE) reduce 147) ((T_LIST) reduce 147) ((T_LNUMBER) reduce 147) ((T_MATCH) reduce 147) ((T_METHOD_C) reduce 147) ((T_NAMESPACE) reduce 147) ((T_NAME_FULLY_QUALIFIED) reduce 147) ((T_NAME_QUALIFIED) reduce 147) ((T_NAME_RELATIVE) reduce 147) ((T_NEW) reduce 147) ((T_NS_C) reduce 147) ((T_OBJECT_CAST) reduce 147) ((T_PRINT) reduce 147) ((T_READONLY) reduce 147) ((T_REQUIRE) reduce 147) ((T_REQUIRE_ONCE) reduce 147) ((T_RETURN) reduce 147) ((T_START_HEREDOC) reduce 147) ((T_STATIC) reduce 147) ((T_STRING) reduce 147) ((T_STRING_CAST) reduce 147) ((T_SWITCH) reduce 147) ((T_THROW) reduce 147) ((T_TRAIT) reduce 147) ((T_TRAIT_C) reduce 147) ((T_TRY) reduce 147) ((T_UNSET) reduce 147) ((T_UNSET_CAST) reduce 147) ((T_USE) reduce 147) ((T_VARIABLE) reduce 147) ((T_WHILE) reduce 147) ((T_YIELD) reduce 147) ((T_YIELD_FROM) reduce 147) (("[") reduce 147) (("`") reduce 147) (("{") reduce 147) (("~") reduce 147)) 28298 ((("!") reduce 146) (("\"") reduce 146) (("$") reduce 146) (($) reduce 146) (("(") reduce 146) (("+") reduce 146) (("-") reduce 146) ((";") reduce 146) (("@") reduce 146) ((T_ABSTRACT) reduce 146) ((T_ARRAY) reduce 146) ((T_ARRAY_CAST) reduce 146) ((T_ATTRIBUTE) reduce 146) ((T_BOOL_CAST) reduce 146) ((T_BREAK) reduce 146) ((T_CLASS) reduce 146) ((T_CLASS_C) reduce 146) ((T_CLONE) reduce 146) ((T_CONST) reduce 146) ((T_CONSTANT_ENCAPSED_STRING) reduce 146) ((T_CONTINUE) reduce 146) ((T_DEC) reduce 146) ((T_DECLARE) reduce 146) ((T_DIR) reduce 146) ((T_DNUMBER) reduce 146) ((T_DO) reduce 146) ((T_DOUBLE_CAST) reduce 146) ((T_ECHO) reduce 146) ((T_ELSE) reduce 146) ((T_ELSEIF) reduce 146) ((T_EMPTY) reduce 146) ((T_ENUM) reduce 146) ((T_EVAL) reduce 146) ((T_EXIT) reduce 146) ((T_FILE) reduce 146) ((T_FINAL) reduce 146) ((T_FN) reduce 146) ((T_FOR) reduce 146) ((T_FOREACH) reduce 146) ((T_FUNCTION) reduce 146) ((T_FUNC_C) reduce 146) ((T_GLOBAL) reduce 146) ((T_GOTO) reduce 146) ((T_HALT_COMPILER) reduce 146) ((T_IF) reduce 146) ((T_INC) reduce 146) ((T_INCLUDE) reduce 146) ((T_INCLUDE_ONCE) reduce 146) ((T_INLINE_HTML) reduce 146) ((T_INTERFACE) reduce 146) ((T_INT_CAST) reduce 146) ((T_ISSET) reduce 146) ((T_LINE) reduce 146) ((T_LIST) reduce 146) ((T_LNUMBER) reduce 146) ((T_MATCH) reduce 146) ((T_METHOD_C) reduce 146) ((T_NAMESPACE) reduce 146) ((T_NAME_FULLY_QUALIFIED) reduce 146) ((T_NAME_QUALIFIED) reduce 146) ((T_NAME_RELATIVE) reduce 146) ((T_NEW) reduce 146) ((T_NS_C) reduce 146) ((T_OBJECT_CAST) reduce 146) ((T_PRINT) reduce 146) ((T_READONLY) reduce 146) ((T_REQUIRE) reduce 146) ((T_REQUIRE_ONCE) reduce 146) ((T_RETURN) reduce 146) ((T_START_HEREDOC) reduce 146) ((T_STATIC) reduce 146) ((T_STRING) reduce 146) ((T_STRING_CAST) reduce 146) ((T_SWITCH) reduce 146) ((T_THROW) reduce 146) ((T_TRAIT) reduce 146) ((T_TRAIT_C) reduce 146) ((T_TRY) reduce 146) ((T_UNSET) reduce 146) ((T_UNSET_CAST) reduce 146) ((T_USE) reduce 146) ((T_VARIABLE) reduce 146) ((T_WHILE) reduce 146) ((T_YIELD) reduce 146) ((T_YIELD_FROM) reduce 146) (("[") reduce 146) (("`") reduce 146) (("{") reduce 146) (("~") reduce 146)) 28299 ((("!") reduce 243) (("\"") reduce 243) (($) reduce 243) (("$") reduce 243) (("(") reduce 243) (("+") reduce 243) (("-") reduce 243) ((";") reduce 243) (("@") reduce 243) ((T_ABSTRACT) reduce 243) ((T_ARRAY) reduce 243) ((T_ARRAY_CAST) reduce 243) ((T_ATTRIBUTE) reduce 243) ((T_BOOL_CAST) reduce 243) ((T_BREAK) reduce 243) ((T_CLASS) reduce 243) ((T_CLASS_C) reduce 243) ((T_CLONE) reduce 243) ((T_CONST) reduce 243) ((T_CONSTANT_ENCAPSED_STRING) reduce 243) ((T_CONTINUE) reduce 243) ((T_DEC) reduce 243) ((T_DECLARE) reduce 243) ((T_DIR) reduce 243) ((T_DNUMBER) reduce 243) ((T_DO) reduce 243) ((T_DOUBLE_CAST) reduce 243) ((T_ECHO) reduce 243) ((T_ELSE) shift) ((T_ELSEIF) shift) ((T_EMPTY) reduce 243) ((T_ENUM) reduce 243) ((T_EVAL) reduce 243) ((T_EXIT) reduce 243) ((T_FILE) reduce 243) ((T_FINAL) reduce 243) ((T_FN) reduce 243) ((T_FOR) reduce 243) ((T_FOREACH) reduce 243) ((T_FUNCTION) reduce 243) ((T_FUNC_C) reduce 243) ((T_GLOBAL) reduce 243) ((T_GOTO) reduce 243) ((T_HALT_COMPILER) reduce 243) ((T_IF) reduce 243) ((T_INC) reduce 243) ((T_INCLUDE) reduce 243) ((T_INCLUDE_ONCE) reduce 243) ((T_INLINE_HTML) reduce 243) ((T_INTERFACE) reduce 243) ((T_INT_CAST) reduce 243) ((T_ISSET) reduce 243) ((T_LINE) reduce 243) ((T_LIST) reduce 243) ((T_LNUMBER) reduce 243) ((T_MATCH) reduce 243) ((T_METHOD_C) reduce 243) ((T_NAMESPACE) reduce 243) ((T_NAME_FULLY_QUALIFIED) reduce 243) ((T_NAME_QUALIFIED) reduce 243) ((T_NAME_RELATIVE) reduce 243) ((T_NEW) reduce 243) ((T_NS_C) reduce 243) ((T_OBJECT_CAST) reduce 243) ((T_PRINT) reduce 243) ((T_READONLY) reduce 243) ((T_REQUIRE) reduce 243) ((T_REQUIRE_ONCE) reduce 243) ((T_RETURN) reduce 243) ((T_START_HEREDOC) reduce 243) ((T_STATIC) reduce 243) ((T_STRING) reduce 243) ((T_STRING_CAST) reduce 243) ((T_SWITCH) reduce 243) ((T_THROW) reduce 243) ((T_TRAIT) reduce 243) ((T_TRAIT_C) reduce 243) ((T_TRY) reduce 243) ((T_UNSET) reduce 243) ((T_UNSET_CAST) reduce 243) ((T_USE) reduce 243) ((T_VARIABLE) reduce 243) ((T_WHILE) reduce 243) ((T_YIELD) reduce 243) ((T_YIELD_FROM) reduce 243) (("[") reduce 243) (("`") reduce 243) (("{") reduce 243) (("~") reduce 243)) 28300 ((("!") reduce 241) (("\"") reduce 241) (($) reduce 241) (("$") reduce 241) (("(") reduce 241) (("+") reduce 241) (("-") reduce 241) ((";") reduce 241) (("@") reduce 241) ((T_ABSTRACT) reduce 241) ((T_ARRAY) reduce 241) ((T_ARRAY_CAST) reduce 241) ((T_ATTRIBUTE) reduce 241) ((T_BOOL_CAST) reduce 241) ((T_BREAK) reduce 241) ((T_CLASS) reduce 241) ((T_CLASS_C) reduce 241) ((T_CLONE) reduce 241) ((T_CONST) reduce 241) ((T_CONSTANT_ENCAPSED_STRING) reduce 241) ((T_CONTINUE) reduce 241) ((T_DEC) reduce 241) ((T_DECLARE) reduce 241) ((T_DIR) reduce 241) ((T_DNUMBER) reduce 241) ((T_DO) reduce 241) ((T_DOUBLE_CAST) reduce 241) ((T_ECHO) reduce 241) ((T_ELSE) reduce 241) ((T_ELSEIF) reduce 241) ((T_EMPTY) reduce 241) ((T_ENUM) reduce 241) ((T_EVAL) reduce 241) ((T_EXIT) reduce 241) ((T_FILE) reduce 241) ((T_FINAL) reduce 241) ((T_FN) reduce 241) ((T_FOR) reduce 241) ((T_FOREACH) reduce 241) ((T_FUNCTION) reduce 241) ((T_FUNC_C) reduce 241) ((T_GLOBAL) reduce 241) ((T_GOTO) reduce 241) ((T_HALT_COMPILER) reduce 241) ((T_IF) reduce 241) ((T_INC) reduce 241) ((T_INCLUDE) reduce 241) ((T_INCLUDE_ONCE) reduce 241) ((T_INLINE_HTML) reduce 241) ((T_INTERFACE) reduce 241) ((T_INT_CAST) reduce 241) ((T_ISSET) reduce 241) ((T_LINE) reduce 241) ((T_LIST) reduce 241) ((T_LNUMBER) reduce 241) ((T_MATCH) reduce 241) ((T_METHOD_C) reduce 241) ((T_NAMESPACE) reduce 241) ((T_NAME_FULLY_QUALIFIED) reduce 241) ((T_NAME_QUALIFIED) reduce 241) ((T_NAME_RELATIVE) reduce 241) ((T_NEW) reduce 241) ((T_NS_C) reduce 241) ((T_OBJECT_CAST) reduce 241) ((T_PRINT) reduce 241) ((T_READONLY) reduce 241) ((T_REQUIRE) reduce 241) ((T_REQUIRE_ONCE) reduce 241) ((T_RETURN) reduce 241) ((T_START_HEREDOC) reduce 241) ((T_STATIC) reduce 241) ((T_STRING) reduce 241) ((T_STRING_CAST) reduce 241) ((T_SWITCH) reduce 241) ((T_THROW) reduce 241) ((T_TRAIT) reduce 241) ((T_TRAIT_C) reduce 241) ((T_TRY) reduce 241) ((T_UNSET) reduce 241) ((T_UNSET_CAST) reduce 241) ((T_USE) reduce 241) ((T_VARIABLE) reduce 241) ((T_WHILE) reduce 241) ((T_YIELD) reduce 241) ((T_YIELD_FROM) reduce 241) (("[") reduce 241) (("`") reduce 241) (("{") reduce 241) (("~") reduce 241)) 28303 ((("!") reduce 145) (("\"") reduce 145) (("$") reduce 145) (($) reduce 145) (("(") reduce 145) (("+") reduce 145) (("-") reduce 145) ((";") reduce 145) (("@") reduce 145) ((T_ABSTRACT) reduce 145) ((T_ARRAY) reduce 145) ((T_ARRAY_CAST) reduce 145) ((T_ATTRIBUTE) reduce 145) ((T_BOOL_CAST) reduce 145) ((T_BREAK) reduce 145) ((T_CLASS) reduce 145) ((T_CLASS_C) reduce 145) ((T_CLONE) reduce 145) ((T_CONST) reduce 145) ((T_CONSTANT_ENCAPSED_STRING) reduce 145) ((T_CONTINUE) reduce 145) ((T_DEC) reduce 145) ((T_DECLARE) reduce 145) ((T_DIR) reduce 145) ((T_DNUMBER) reduce 145) ((T_DO) reduce 145) ((T_DOUBLE_CAST) reduce 145) ((T_ECHO) reduce 145) ((T_ELSE) reduce 145) ((T_ELSEIF) reduce 145) ((T_EMPTY) reduce 145) ((T_ENUM) reduce 145) ((T_EVAL) reduce 145) ((T_EXIT) reduce 145) ((T_FILE) reduce 145) ((T_FINAL) reduce 145) ((T_FN) reduce 145) ((T_FOR) reduce 145) ((T_FOREACH) reduce 145) ((T_FUNCTION) reduce 145) ((T_FUNC_C) reduce 145) ((T_GLOBAL) reduce 145) ((T_GOTO) reduce 145) ((T_HALT_COMPILER) reduce 145) ((T_IF) reduce 145) ((T_INC) reduce 145) ((T_INCLUDE) reduce 145) ((T_INCLUDE_ONCE) reduce 145) ((T_INLINE_HTML) reduce 145) ((T_INTERFACE) reduce 145) ((T_INT_CAST) reduce 145) ((T_ISSET) reduce 145) ((T_LINE) reduce 145) ((T_LIST) reduce 145) ((T_LNUMBER) reduce 145) ((T_MATCH) reduce 145) ((T_METHOD_C) reduce 145) ((T_NAMESPACE) reduce 145) ((T_NAME_FULLY_QUALIFIED) reduce 145) ((T_NAME_QUALIFIED) reduce 145) ((T_NAME_RELATIVE) reduce 145) ((T_NEW) reduce 145) ((T_NS_C) reduce 145) ((T_OBJECT_CAST) reduce 145) ((T_PRINT) reduce 145) ((T_READONLY) reduce 145) ((T_REQUIRE) reduce 145) ((T_REQUIRE_ONCE) reduce 145) ((T_RETURN) reduce 145) ((T_START_HEREDOC) reduce 145) ((T_STATIC) reduce 145) ((T_STRING) reduce 145) ((T_STRING_CAST) reduce 145) ((T_SWITCH) reduce 145) ((T_THROW) reduce 145) ((T_TRAIT) reduce 145) ((T_TRAIT_C) reduce 145) ((T_TRY) reduce 145) ((T_UNSET) reduce 145) ((T_UNSET_CAST) reduce 145) ((T_USE) reduce 145) ((T_VARIABLE) reduce 145) ((T_WHILE) reduce 145) ((T_YIELD) reduce 145) ((T_YIELD_FROM) reduce 145) (("[") reduce 145) (("`") reduce 145) (("{") reduce 145) (("~") reduce 145)) 28309 ((("!") reduce 242) (("\"") reduce 242) (($) reduce 242) (("$") reduce 242) (("(") reduce 242) (("+") reduce 242) (("-") reduce 242) ((";") reduce 242) (("@") reduce 242) ((T_ABSTRACT) reduce 242) ((T_ARRAY) reduce 242) ((T_ARRAY_CAST) reduce 242) ((T_ATTRIBUTE) reduce 242) ((T_BOOL_CAST) reduce 242) ((T_BREAK) reduce 242) ((T_CLASS) reduce 242) ((T_CLASS_C) reduce 242) ((T_CLONE) reduce 242) ((T_CONST) reduce 242) ((T_CONSTANT_ENCAPSED_STRING) reduce 242) ((T_CONTINUE) reduce 242) ((T_DEC) reduce 242) ((T_DECLARE) reduce 242) ((T_DIR) reduce 242) ((T_DNUMBER) reduce 242) ((T_DO) reduce 242) ((T_DOUBLE_CAST) reduce 242) ((T_ECHO) reduce 242) ((T_ELSE) reduce 242) ((T_ELSEIF) reduce 242) ((T_EMPTY) reduce 242) ((T_ENUM) reduce 242) ((T_EVAL) reduce 242) ((T_EXIT) reduce 242) ((T_FILE) reduce 242) ((T_FINAL) reduce 242) ((T_FN) reduce 242) ((T_FOR) reduce 242) ((T_FOREACH) reduce 242) ((T_FUNCTION) reduce 242) ((T_FUNC_C) reduce 242) ((T_GLOBAL) reduce 242) ((T_GOTO) reduce 242) ((T_HALT_COMPILER) reduce 242) ((T_IF) reduce 242) ((T_INC) reduce 242) ((T_INCLUDE) reduce 242) ((T_INCLUDE_ONCE) reduce 242) ((T_INLINE_HTML) reduce 242) ((T_INTERFACE) reduce 242) ((T_INT_CAST) reduce 242) ((T_ISSET) reduce 242) ((T_LINE) reduce 242) ((T_LIST) reduce 242) ((T_LNUMBER) reduce 242) ((T_MATCH) reduce 242) ((T_METHOD_C) reduce 242) ((T_NAMESPACE) reduce 242) ((T_NAME_FULLY_QUALIFIED) reduce 242) ((T_NAME_QUALIFIED) reduce 242) ((T_NAME_RELATIVE) reduce 242) ((T_NEW) reduce 242) ((T_NS_C) reduce 242) ((T_OBJECT_CAST) reduce 242) ((T_PRINT) reduce 242) ((T_READONLY) reduce 242) ((T_REQUIRE) reduce 242) ((T_REQUIRE_ONCE) reduce 242) ((T_RETURN) reduce 242) ((T_START_HEREDOC) reduce 242) ((T_STATIC) reduce 242) ((T_STRING) reduce 242) ((T_STRING_CAST) reduce 242) ((T_SWITCH) reduce 242) ((T_THROW) reduce 242) ((T_TRAIT) reduce 242) ((T_TRAIT_C) reduce 242) ((T_TRY) reduce 242) ((T_UNSET) reduce 242) ((T_UNSET_CAST) reduce 242) ((T_USE) reduce 242) ((T_VARIABLE) reduce 242) ((T_WHILE) reduce 242) ((T_YIELD) reduce 242) ((T_YIELD_FROM) reduce 242) (("[") reduce 242) (("`") reduce 242) (("{") reduce 242) (("~") reduce 242)) 28310 ((("!") reduce 244) (("\"") reduce 244) (($) reduce 244) (("$") reduce 244) (("(") reduce 244) (("+") reduce 244) (("-") reduce 244) ((";") reduce 244) (("@") reduce 244) ((T_ABSTRACT) reduce 244) ((T_ARRAY) reduce 244) ((T_ARRAY_CAST) reduce 244) ((T_ATTRIBUTE) reduce 244) ((T_BOOL_CAST) reduce 244) ((T_BREAK) reduce 244) ((T_CLASS) reduce 244) ((T_CLASS_C) reduce 244) ((T_CLONE) reduce 244) ((T_CONST) reduce 244) ((T_CONSTANT_ENCAPSED_STRING) reduce 244) ((T_CONTINUE) reduce 244) ((T_DEC) reduce 244) ((T_DECLARE) reduce 244) ((T_DIR) reduce 244) ((T_DNUMBER) reduce 244) ((T_DO) reduce 244) ((T_DOUBLE_CAST) reduce 244) ((T_ECHO) reduce 244) ((T_ELSE) reduce 244) ((T_ELSEIF) reduce 244) ((T_EMPTY) reduce 244) ((T_ENUM) reduce 244) ((T_EVAL) reduce 244) ((T_EXIT) reduce 244) ((T_FILE) reduce 244) ((T_FINAL) reduce 244) ((T_FN) reduce 244) ((T_FOR) reduce 244) ((T_FOREACH) reduce 244) ((T_FUNCTION) reduce 244) ((T_FUNC_C) reduce 244) ((T_GLOBAL) reduce 244) ((T_GOTO) reduce 244) ((T_HALT_COMPILER) reduce 244) ((T_IF) reduce 244) ((T_INC) reduce 244) ((T_INCLUDE) reduce 244) ((T_INCLUDE_ONCE) reduce 244) ((T_INLINE_HTML) reduce 244) ((T_INTERFACE) reduce 244) ((T_INT_CAST) reduce 244) ((T_ISSET) reduce 244) ((T_LINE) reduce 244) ((T_LIST) reduce 244) ((T_LNUMBER) reduce 244) ((T_MATCH) reduce 244) ((T_METHOD_C) reduce 244) ((T_NAMESPACE) reduce 244) ((T_NAME_FULLY_QUALIFIED) reduce 244) ((T_NAME_QUALIFIED) reduce 244) ((T_NAME_RELATIVE) reduce 244) ((T_NEW) reduce 244) ((T_NS_C) reduce 244) ((T_OBJECT_CAST) reduce 244) ((T_PRINT) reduce 244) ((T_READONLY) reduce 244) ((T_REQUIRE) reduce 244) ((T_REQUIRE_ONCE) reduce 244) ((T_RETURN) reduce 244) ((T_START_HEREDOC) reduce 244) ((T_STATIC) reduce 244) ((T_STRING) reduce 244) ((T_STRING_CAST) reduce 244) ((T_SWITCH) reduce 244) ((T_THROW) reduce 244) ((T_TRAIT) reduce 244) ((T_TRAIT_C) reduce 244) ((T_TRY) reduce 244) ((T_UNSET) reduce 244) ((T_UNSET_CAST) reduce 244) ((T_USE) reduce 244) ((T_VARIABLE) reduce 244) ((T_WHILE) reduce 244) ((T_YIELD) reduce 244) ((T_YIELD_FROM) reduce 244) (("[") reduce 244) (("`") reduce 244) (("{") reduce 244) (("~") reduce 244)) 28311 ((("!") reduce 159) (("\"") reduce 159) (($) reduce 159) (("$") reduce 159) (("(") reduce 159) (("+") reduce 159) (("-") reduce 159) ((";") reduce 159) (("@") reduce 159) ((T_ABSTRACT) reduce 159) ((T_ARRAY) reduce 159) ((T_ARRAY_CAST) reduce 159) ((T_ATTRIBUTE) reduce 159) ((T_BOOL_CAST) reduce 159) ((T_BREAK) reduce 159) ((T_CLASS) reduce 159) ((T_CLASS_C) reduce 159) ((T_CLONE) reduce 159) ((T_CONST) reduce 159) ((T_CONSTANT_ENCAPSED_STRING) reduce 159) ((T_CONTINUE) reduce 159) ((T_DEC) reduce 159) ((T_DECLARE) reduce 159) ((T_DIR) reduce 159) ((T_DNUMBER) reduce 159) ((T_DO) reduce 159) ((T_DOUBLE_CAST) reduce 159) ((T_ECHO) reduce 159) ((T_ELSE) reduce 159) ((T_ELSEIF) reduce 159) ((T_EMPTY) reduce 159) ((T_ENUM) reduce 159) ((T_EVAL) reduce 159) ((T_EXIT) reduce 159) ((T_FILE) reduce 159) ((T_FINAL) reduce 159) ((T_FN) reduce 159) ((T_FOR) reduce 159) ((T_FOREACH) reduce 159) ((T_FUNCTION) reduce 159) ((T_FUNC_C) reduce 159) ((T_GLOBAL) reduce 159) ((T_GOTO) reduce 159) ((T_HALT_COMPILER) reduce 159) ((T_IF) reduce 159) ((T_INC) reduce 159) ((T_INCLUDE) reduce 159) ((T_INCLUDE_ONCE) reduce 159) ((T_INLINE_HTML) reduce 159) ((T_INTERFACE) reduce 159) ((T_INT_CAST) reduce 159) ((T_ISSET) reduce 159) ((T_LINE) reduce 159) ((T_LIST) reduce 159) ((T_LNUMBER) reduce 159) ((T_MATCH) reduce 159) ((T_METHOD_C) reduce 159) ((T_NAMESPACE) reduce 159) ((T_NAME_FULLY_QUALIFIED) reduce 159) ((T_NAME_QUALIFIED) reduce 159) ((T_NAME_RELATIVE) reduce 159) ((T_NEW) reduce 159) ((T_NS_C) reduce 159) ((T_OBJECT_CAST) reduce 159) ((T_PRINT) reduce 159) ((T_READONLY) reduce 159) ((T_REQUIRE) reduce 159) ((T_REQUIRE_ONCE) reduce 159) ((T_RETURN) reduce 159) ((T_START_HEREDOC) reduce 159) ((T_STATIC) reduce 159) ((T_STRING) reduce 159) ((T_STRING_CAST) reduce 159) ((T_SWITCH) reduce 159) ((T_THROW) reduce 159) ((T_TRAIT) reduce 159) ((T_TRAIT_C) reduce 159) ((T_TRY) reduce 159) ((T_UNSET) reduce 159) ((T_UNSET_CAST) reduce 159) ((T_USE) reduce 159) ((T_VARIABLE) reduce 159) ((T_WHILE) reduce 159) ((T_YIELD) reduce 159) ((T_YIELD_FROM) reduce 159) (("[") reduce 159) (("`") reduce 159) (("{") reduce 159) (("~") reduce 159)) 28314 ((("!") reduce 247) (("\"") reduce 247) (($) reduce 247) (("$") reduce 247) (("(") reduce 247) (("+") reduce 247) (("-") reduce 247) ((";") reduce 247) (("@") reduce 247) ((T_ABSTRACT) reduce 247) ((T_ARRAY) reduce 247) ((T_ARRAY_CAST) reduce 247) ((T_ATTRIBUTE) reduce 247) ((T_BOOL_CAST) reduce 247) ((T_BREAK) reduce 247) ((T_CLASS) reduce 247) ((T_CLASS_C) reduce 247) ((T_CLONE) reduce 247) ((T_CONST) reduce 247) ((T_CONSTANT_ENCAPSED_STRING) reduce 247) ((T_CONTINUE) reduce 247) ((T_DEC) reduce 247) ((T_DECLARE) reduce 247) ((T_DIR) reduce 247) ((T_DNUMBER) reduce 247) ((T_DO) reduce 247) ((T_DOUBLE_CAST) reduce 247) ((T_ECHO) reduce 247) ((T_ELSE) reduce 247) ((T_ELSEIF) reduce 247) ((T_EMPTY) reduce 247) ((T_ENUM) reduce 247) ((T_EVAL) reduce 247) ((T_EXIT) reduce 247) ((T_FILE) reduce 247) ((T_FINAL) reduce 247) ((T_FN) reduce 247) ((T_FOR) reduce 247) ((T_FOREACH) reduce 247) ((T_FUNCTION) reduce 247) ((T_FUNC_C) reduce 247) ((T_GLOBAL) reduce 247) ((T_GOTO) reduce 247) ((T_HALT_COMPILER) reduce 247) ((T_IF) reduce 247) ((T_INC) reduce 247) ((T_INCLUDE) reduce 247) ((T_INCLUDE_ONCE) reduce 247) ((T_INLINE_HTML) reduce 247) ((T_INTERFACE) reduce 247) ((T_INT_CAST) reduce 247) ((T_ISSET) reduce 247) ((T_LINE) reduce 247) ((T_LIST) reduce 247) ((T_LNUMBER) reduce 247) ((T_MATCH) reduce 247) ((T_METHOD_C) reduce 247) ((T_NAMESPACE) reduce 247) ((T_NAME_FULLY_QUALIFIED) reduce 247) ((T_NAME_QUALIFIED) reduce 247) ((T_NAME_RELATIVE) reduce 247) ((T_NEW) reduce 247) ((T_NS_C) reduce 247) ((T_OBJECT_CAST) reduce 247) ((T_PRINT) reduce 247) ((T_READONLY) reduce 247) ((T_REQUIRE) reduce 247) ((T_REQUIRE_ONCE) reduce 247) ((T_RETURN) reduce 247) ((T_START_HEREDOC) reduce 247) ((T_STATIC) reduce 247) ((T_STRING) reduce 247) ((T_STRING_CAST) reduce 247) ((T_SWITCH) reduce 247) ((T_THROW) reduce 247) ((T_TRAIT) reduce 247) ((T_TRAIT_C) reduce 247) ((T_TRY) reduce 247) ((T_UNSET) reduce 247) ((T_UNSET_CAST) reduce 247) ((T_USE) reduce 247) ((T_VARIABLE) reduce 247) ((T_WHILE) reduce 247) ((T_YIELD) reduce 247) ((T_YIELD_FROM) reduce 247) (("[") reduce 247) (("`") reduce 247) (("{") reduce 247) (("~") reduce 247)) 28318 ((("!") reduce 248) (("\"") reduce 248) (("$") reduce 248) (($) reduce 248) (("(") reduce 248) (("+") reduce 248) (("-") reduce 248) ((";") reduce 248) (("@") reduce 248) ((T_ABSTRACT) reduce 248) ((T_ARRAY) reduce 248) ((T_ARRAY_CAST) reduce 248) ((T_ATTRIBUTE) reduce 248) ((T_BOOL_CAST) reduce 248) ((T_BREAK) reduce 248) ((T_CLASS) reduce 248) ((T_CLASS_C) reduce 248) ((T_CLONE) reduce 248) ((T_CONST) reduce 248) ((T_CONSTANT_ENCAPSED_STRING) reduce 248) ((T_CONTINUE) reduce 248) ((T_DEC) reduce 248) ((T_DECLARE) reduce 248) ((T_DIR) reduce 248) ((T_DNUMBER) reduce 248) ((T_DO) reduce 248) ((T_DOUBLE_CAST) reduce 248) ((T_ECHO) reduce 248) ((T_ELSE) reduce 248) ((T_ELSEIF) reduce 248) ((T_EMPTY) reduce 248) ((T_ENUM) reduce 248) ((T_EVAL) reduce 248) ((T_EXIT) reduce 248) ((T_FILE) reduce 248) ((T_FINAL) reduce 248) ((T_FN) reduce 248) ((T_FOR) reduce 248) ((T_FOREACH) reduce 248) ((T_FUNCTION) reduce 248) ((T_FUNC_C) reduce 248) ((T_GLOBAL) reduce 248) ((T_GOTO) reduce 248) ((T_HALT_COMPILER) reduce 248) ((T_IF) reduce 248) ((T_INC) reduce 248) ((T_INCLUDE) reduce 248) ((T_INCLUDE_ONCE) reduce 248) ((T_INLINE_HTML) reduce 248) ((T_INTERFACE) reduce 248) ((T_INT_CAST) reduce 248) ((T_ISSET) reduce 248) ((T_LINE) reduce 248) ((T_LIST) reduce 248) ((T_LNUMBER) reduce 248) ((T_MATCH) reduce 248) ((T_METHOD_C) reduce 248) ((T_NAMESPACE) reduce 248) ((T_NAME_FULLY_QUALIFIED) reduce 248) ((T_NAME_QUALIFIED) reduce 248) ((T_NAME_RELATIVE) reduce 248) ((T_NEW) reduce 248) ((T_NS_C) reduce 248) ((T_OBJECT_CAST) reduce 248) ((T_PRINT) reduce 248) ((T_READONLY) reduce 248) ((T_REQUIRE) reduce 248) ((T_REQUIRE_ONCE) reduce 248) ((T_RETURN) reduce 248) ((T_START_HEREDOC) reduce 248) ((T_STATIC) reduce 248) ((T_STRING) reduce 248) ((T_STRING_CAST) reduce 248) ((T_SWITCH) reduce 248) ((T_THROW) reduce 248) ((T_TRAIT) reduce 248) ((T_TRAIT_C) reduce 248) ((T_TRY) reduce 248) ((T_UNSET) reduce 248) ((T_UNSET_CAST) reduce 248) ((T_USE) reduce 248) ((T_VARIABLE) reduce 248) ((T_WHILE) reduce 248) ((T_YIELD) reduce 248) ((T_YIELD_FROM) reduce 248) (("[") reduce 248) (("`") reduce 248) (("{") reduce 248) (("~") reduce 248)) 28323 ((("!") reduce 239) (("\"") reduce 239) (($) reduce 239) (("$") reduce 239) (("(") reduce 239) (("+") reduce 239) (("-") reduce 239) ((";") reduce 239) (("@") reduce 239) ((T_ABSTRACT) reduce 239) ((T_ARRAY) reduce 239) ((T_ARRAY_CAST) reduce 239) ((T_ATTRIBUTE) reduce 239) ((T_BOOL_CAST) reduce 239) ((T_BREAK) reduce 239) ((T_CLASS) reduce 239) ((T_CLASS_C) reduce 239) ((T_CLONE) reduce 239) ((T_CONST) reduce 239) ((T_CONSTANT_ENCAPSED_STRING) reduce 239) ((T_CONTINUE) reduce 239) ((T_DEC) reduce 239) ((T_DECLARE) reduce 239) ((T_DIR) reduce 239) ((T_DNUMBER) reduce 239) ((T_DO) reduce 239) ((T_DOUBLE_CAST) reduce 239) ((T_ECHO) reduce 239) ((T_ELSE) reduce 239) ((T_ELSEIF) reduce 239) ((T_EMPTY) reduce 239) ((T_ENUM) reduce 239) ((T_EVAL) reduce 239) ((T_EXIT) reduce 239) ((T_FILE) reduce 239) ((T_FINAL) reduce 239) ((T_FN) reduce 239) ((T_FOR) reduce 239) ((T_FOREACH) reduce 239) ((T_FUNCTION) reduce 239) ((T_FUNC_C) reduce 239) ((T_GLOBAL) reduce 239) ((T_GOTO) reduce 239) ((T_HALT_COMPILER) reduce 239) ((T_IF) reduce 239) ((T_INC) reduce 239) ((T_INCLUDE) reduce 239) ((T_INCLUDE_ONCE) reduce 239) ((T_INLINE_HTML) reduce 239) ((T_INTERFACE) reduce 239) ((T_INT_CAST) reduce 239) ((T_ISSET) reduce 239) ((T_LINE) reduce 239) ((T_LIST) reduce 239) ((T_LNUMBER) reduce 239) ((T_MATCH) reduce 239) ((T_METHOD_C) reduce 239) ((T_NAMESPACE) reduce 239) ((T_NAME_FULLY_QUALIFIED) reduce 239) ((T_NAME_QUALIFIED) reduce 239) ((T_NAME_RELATIVE) reduce 239) ((T_NEW) reduce 239) ((T_NS_C) reduce 239) ((T_OBJECT_CAST) reduce 239) ((T_PRINT) reduce 239) ((T_READONLY) reduce 239) ((T_REQUIRE) reduce 239) ((T_REQUIRE_ONCE) reduce 239) ((T_RETURN) reduce 239) ((T_START_HEREDOC) reduce 239) ((T_STATIC) reduce 239) ((T_STRING) reduce 239) ((T_STRING_CAST) reduce 239) ((T_SWITCH) reduce 239) ((T_THROW) reduce 239) ((T_TRAIT) reduce 239) ((T_TRAIT_C) reduce 239) ((T_TRY) reduce 239) ((T_UNSET) reduce 239) ((T_UNSET_CAST) reduce 239) ((T_USE) reduce 239) ((T_VARIABLE) reduce 239) ((T_WHILE) reduce 239) ((T_YIELD) reduce 239) ((T_YIELD_FROM) reduce 239) (("[") reduce 239) (("`") reduce 239) (("{") reduce 239) (("~") reduce 239)) 28324 ((("!") reduce 148) (("\"") reduce 148) (("$") reduce 148) (($) reduce 148) (("(") reduce 148) (("+") reduce 148) (("-") reduce 148) ((";") reduce 148) (("@") reduce 148) ((T_ABSTRACT) reduce 148) ((T_ARRAY) reduce 148) ((T_ARRAY_CAST) reduce 148) ((T_ATTRIBUTE) reduce 148) ((T_BOOL_CAST) reduce 148) ((T_BREAK) reduce 148) ((T_CLASS) reduce 148) ((T_CLASS_C) reduce 148) ((T_CLONE) reduce 148) ((T_CONST) reduce 148) ((T_CONSTANT_ENCAPSED_STRING) reduce 148) ((T_CONTINUE) reduce 148) ((T_DEC) reduce 148) ((T_DECLARE) reduce 148) ((T_DIR) reduce 148) ((T_DNUMBER) reduce 148) ((T_DO) reduce 148) ((T_DOUBLE_CAST) reduce 148) ((T_ECHO) reduce 148) ((T_ELSE) reduce 148) ((T_ELSEIF) reduce 148) ((T_EMPTY) reduce 148) ((T_ENUM) reduce 148) ((T_EVAL) reduce 148) ((T_EXIT) reduce 148) ((T_FILE) reduce 148) ((T_FINAL) reduce 148) ((T_FN) reduce 148) ((T_FOR) reduce 148) ((T_FOREACH) reduce 148) ((T_FUNCTION) reduce 148) ((T_FUNC_C) reduce 148) ((T_GLOBAL) reduce 148) ((T_GOTO) reduce 148) ((T_HALT_COMPILER) reduce 148) ((T_IF) reduce 148) ((T_INC) reduce 148) ((T_INCLUDE) reduce 148) ((T_INCLUDE_ONCE) reduce 148) ((T_INLINE_HTML) reduce 148) ((T_INTERFACE) reduce 148) ((T_INT_CAST) reduce 148) ((T_ISSET) reduce 148) ((T_LINE) reduce 148) ((T_LIST) reduce 148) ((T_LNUMBER) reduce 148) ((T_MATCH) reduce 148) ((T_METHOD_C) reduce 148) ((T_NAMESPACE) reduce 148) ((T_NAME_FULLY_QUALIFIED) reduce 148) ((T_NAME_QUALIFIED) reduce 148) ((T_NAME_RELATIVE) reduce 148) ((T_NEW) reduce 148) ((T_NS_C) reduce 148) ((T_OBJECT_CAST) reduce 148) ((T_PRINT) reduce 148) ((T_READONLY) reduce 148) ((T_REQUIRE) reduce 148) ((T_REQUIRE_ONCE) reduce 148) ((T_RETURN) reduce 148) ((T_START_HEREDOC) reduce 148) ((T_STATIC) reduce 148) ((T_STRING) reduce 148) ((T_STRING_CAST) reduce 148) ((T_SWITCH) reduce 148) ((T_THROW) reduce 148) ((T_TRAIT) reduce 148) ((T_TRAIT_C) reduce 148) ((T_TRY) reduce 148) ((T_UNSET) reduce 148) ((T_UNSET_CAST) reduce 148) ((T_USE) reduce 148) ((T_VARIABLE) reduce 148) ((T_WHILE) reduce 148) ((T_YIELD) reduce 148) ((T_YIELD_FROM) reduce 148) (("[") reduce 148) (("`") reduce 148) (("{") reduce 148) (("~") reduce 148)) 28327 ((("!") reduce 240) (("\"") reduce 240) (("$") reduce 240) (($) reduce 240) (("(") reduce 240) (("+") reduce 240) (("-") reduce 240) ((";") reduce 240) (("@") reduce 240) ((T_ABSTRACT) reduce 240) ((T_ARRAY) reduce 240) ((T_ARRAY_CAST) reduce 240) ((T_ATTRIBUTE) reduce 240) ((T_BOOL_CAST) reduce 240) ((T_BREAK) reduce 240) ((T_CLASS) reduce 240) ((T_CLASS_C) reduce 240) ((T_CLONE) reduce 240) ((T_CONST) reduce 240) ((T_CONSTANT_ENCAPSED_STRING) reduce 240) ((T_CONTINUE) reduce 240) ((T_DEC) reduce 240) ((T_DECLARE) reduce 240) ((T_DIR) reduce 240) ((T_DNUMBER) reduce 240) ((T_DO) reduce 240) ((T_DOUBLE_CAST) reduce 240) ((T_ECHO) reduce 240) ((T_ELSE) reduce 240) ((T_ELSEIF) reduce 240) ((T_EMPTY) reduce 240) ((T_ENUM) reduce 240) ((T_EVAL) reduce 240) ((T_EXIT) reduce 240) ((T_FILE) reduce 240) ((T_FINAL) reduce 240) ((T_FN) reduce 240) ((T_FOR) reduce 240) ((T_FOREACH) reduce 240) ((T_FUNCTION) reduce 240) ((T_FUNC_C) reduce 240) ((T_GLOBAL) reduce 240) ((T_GOTO) reduce 240) ((T_HALT_COMPILER) reduce 240) ((T_IF) reduce 240) ((T_INC) reduce 240) ((T_INCLUDE) reduce 240) ((T_INCLUDE_ONCE) reduce 240) ((T_INLINE_HTML) reduce 240) ((T_INTERFACE) reduce 240) ((T_INT_CAST) reduce 240) ((T_ISSET) reduce 240) ((T_LINE) reduce 240) ((T_LIST) reduce 240) ((T_LNUMBER) reduce 240) ((T_MATCH) reduce 240) ((T_METHOD_C) reduce 240) ((T_NAMESPACE) reduce 240) ((T_NAME_FULLY_QUALIFIED) reduce 240) ((T_NAME_QUALIFIED) reduce 240) ((T_NAME_RELATIVE) reduce 240) ((T_NEW) reduce 240) ((T_NS_C) reduce 240) ((T_OBJECT_CAST) reduce 240) ((T_PRINT) reduce 240) ((T_READONLY) reduce 240) ((T_REQUIRE) reduce 240) ((T_REQUIRE_ONCE) reduce 240) ((T_RETURN) reduce 240) ((T_START_HEREDOC) reduce 240) ((T_STATIC) reduce 240) ((T_STRING) reduce 240) ((T_STRING_CAST) reduce 240) ((T_SWITCH) reduce 240) ((T_THROW) reduce 240) ((T_TRAIT) reduce 240) ((T_TRAIT_C) reduce 240) ((T_TRY) reduce 240) ((T_UNSET) reduce 240) ((T_UNSET_CAST) reduce 240) ((T_USE) reduce 240) ((T_VARIABLE) reduce 240) ((T_WHILE) reduce 240) ((T_YIELD) reduce 240) ((T_YIELD_FROM) reduce 240) (("[") reduce 240) (("`") reduce 240) (("{") reduce 240) (("~") reduce 240)) 28332 ((("!") reduce 160) (("\"") reduce 160) (($) reduce 160) (("$") reduce 160) (("(") reduce 160) (("+") reduce 160) (("-") reduce 160) ((";") reduce 160) (("@") reduce 160) ((T_ABSTRACT) reduce 160) ((T_ARRAY) reduce 160) ((T_ARRAY_CAST) reduce 160) ((T_ATTRIBUTE) reduce 160) ((T_BOOL_CAST) reduce 160) ((T_BREAK) reduce 160) ((T_CLASS) reduce 160) ((T_CLASS_C) reduce 160) ((T_CLONE) reduce 160) ((T_CONST) reduce 160) ((T_CONSTANT_ENCAPSED_STRING) reduce 160) ((T_CONTINUE) reduce 160) ((T_DEC) reduce 160) ((T_DECLARE) reduce 160) ((T_DIR) reduce 160) ((T_DNUMBER) reduce 160) ((T_DO) reduce 160) ((T_DOUBLE_CAST) reduce 160) ((T_ECHO) reduce 160) ((T_ELSE) reduce 160) ((T_ELSEIF) reduce 160) ((T_EMPTY) reduce 160) ((T_ENUM) reduce 160) ((T_EVAL) reduce 160) ((T_EXIT) reduce 160) ((T_FILE) reduce 160) ((T_FINAL) reduce 160) ((T_FN) reduce 160) ((T_FOR) reduce 160) ((T_FOREACH) reduce 160) ((T_FUNCTION) reduce 160) ((T_FUNC_C) reduce 160) ((T_GLOBAL) reduce 160) ((T_GOTO) reduce 160) ((T_HALT_COMPILER) reduce 160) ((T_IF) reduce 160) ((T_INC) reduce 160) ((T_INCLUDE) reduce 160) ((T_INCLUDE_ONCE) reduce 160) ((T_INLINE_HTML) reduce 160) ((T_INTERFACE) reduce 160) ((T_INT_CAST) reduce 160) ((T_ISSET) reduce 160) ((T_LINE) reduce 160) ((T_LIST) reduce 160) ((T_LNUMBER) reduce 160) ((T_MATCH) reduce 160) ((T_METHOD_C) reduce 160) ((T_NAMESPACE) reduce 160) ((T_NAME_FULLY_QUALIFIED) reduce 160) ((T_NAME_QUALIFIED) reduce 160) ((T_NAME_RELATIVE) reduce 160) ((T_NEW) reduce 160) ((T_NS_C) reduce 160) ((T_OBJECT_CAST) reduce 160) ((T_PRINT) reduce 160) ((T_READONLY) reduce 160) ((T_REQUIRE) reduce 160) ((T_REQUIRE_ONCE) reduce 160) ((T_RETURN) reduce 160) ((T_START_HEREDOC) reduce 160) ((T_STATIC) reduce 160) ((T_STRING) reduce 160) ((T_STRING_CAST) reduce 160) ((T_SWITCH) reduce 160) ((T_THROW) reduce 160) ((T_TRAIT) reduce 160) ((T_TRAIT_C) reduce 160) ((T_TRY) reduce 160) ((T_UNSET) reduce 160) ((T_UNSET_CAST) reduce 160) ((T_USE) reduce 160) ((T_VARIABLE) reduce 160) ((T_WHILE) reduce 160) ((T_YIELD) reduce 160) ((T_YIELD_FROM) reduce 160) (("[") reduce 160) (("`") reduce 160) (("{") reduce 160) (("~") reduce 160)) 28335 ((("!") reduce 168) (("\"") reduce 168) (("$") reduce 168) (($) reduce 168) (("(") reduce 168) (("+") reduce 168) (("-") reduce 168) ((";") reduce 168) (("@") reduce 168) ((T_ABSTRACT) reduce 168) ((T_ARRAY) reduce 168) ((T_ARRAY_CAST) reduce 168) ((T_ATTRIBUTE) reduce 168) ((T_BOOL_CAST) reduce 168) ((T_BREAK) reduce 168) ((T_CATCH) reduce 168) ((T_CLASS) reduce 168) ((T_CLASS_C) reduce 168) ((T_CLONE) reduce 168) ((T_CONST) reduce 168) ((T_CONSTANT_ENCAPSED_STRING) reduce 168) ((T_CONTINUE) reduce 168) ((T_DEC) reduce 168) ((T_DECLARE) reduce 168) ((T_DIR) reduce 168) ((T_DNUMBER) reduce 168) ((T_DO) reduce 168) ((T_DOUBLE_CAST) reduce 168) ((T_ECHO) reduce 168) ((T_ELSE) reduce 168) ((T_ELSEIF) reduce 168) ((T_EMPTY) reduce 168) ((T_ENUM) reduce 168) ((T_EVAL) reduce 168) ((T_EXIT) reduce 168) ((T_FILE) reduce 168) ((T_FINAL) reduce 168) ((T_FINALLY) reduce 168) ((T_FN) reduce 168) ((T_FOR) reduce 168) ((T_FOREACH) reduce 168) ((T_FUNCTION) reduce 168) ((T_FUNC_C) reduce 168) ((T_GLOBAL) reduce 168) ((T_GOTO) reduce 168) ((T_HALT_COMPILER) reduce 168) ((T_IF) reduce 168) ((T_INC) reduce 168) ((T_INCLUDE) reduce 168) ((T_INCLUDE_ONCE) reduce 168) ((T_INLINE_HTML) reduce 168) ((T_INTERFACE) reduce 168) ((T_INT_CAST) reduce 168) ((T_ISSET) reduce 168) ((T_LINE) reduce 168) ((T_LIST) reduce 168) ((T_LNUMBER) reduce 168) ((T_MATCH) reduce 168) ((T_METHOD_C) reduce 168) ((T_NAMESPACE) reduce 168) ((T_NAME_FULLY_QUALIFIED) reduce 168) ((T_NAME_QUALIFIED) reduce 168) ((T_NAME_RELATIVE) reduce 168) ((T_NEW) reduce 168) ((T_NS_C) reduce 168) ((T_OBJECT_CAST) reduce 168) ((T_PRINT) reduce 168) ((T_READONLY) reduce 168) ((T_REQUIRE) reduce 168) ((T_REQUIRE_ONCE) reduce 168) ((T_RETURN) reduce 168) ((T_START_HEREDOC) reduce 168) ((T_STATIC) reduce 168) ((T_STRING) reduce 168) ((T_STRING_CAST) reduce 168) ((T_SWITCH) reduce 168) ((T_THROW) reduce 168) ((T_TRAIT) reduce 168) ((T_TRAIT_C) reduce 168) ((T_TRY) reduce 168) ((T_UNSET) reduce 168) ((T_UNSET_CAST) reduce 168) ((T_USE) reduce 168) ((T_VARIABLE) reduce 168) ((T_WHILE) reduce 168) ((T_YIELD) reduce 168) ((T_YIELD_FROM) reduce 168) (("[") reduce 168) (("`") reduce 168) (("{") reduce 168) (("~") reduce 168)) 28336 ((("!") reduce 174) (("\"") reduce 174) (($) reduce 174) (("$") reduce 174) (("(") reduce 174) (("+") reduce 174) (("-") reduce 174) ((";") reduce 174) (("@") reduce 174) ((T_ABSTRACT) reduce 174) ((T_ARRAY) reduce 174) ((T_ARRAY_CAST) reduce 174) ((T_ATTRIBUTE) reduce 174) ((T_BOOL_CAST) reduce 174) ((T_BREAK) reduce 174) ((T_CATCH) shift) ((T_CLASS) reduce 174) ((T_CLASS_C) reduce 174) ((T_CLONE) reduce 174) ((T_CONST) reduce 174) ((T_CONSTANT_ENCAPSED_STRING) reduce 174) ((T_CONTINUE) reduce 174) ((T_DEC) reduce 174) ((T_DECLARE) reduce 174) ((T_DIR) reduce 174) ((T_DNUMBER) reduce 174) ((T_DO) reduce 174) ((T_DOUBLE_CAST) reduce 174) ((T_ECHO) reduce 174) ((T_ELSE) reduce 174) ((T_ELSEIF) reduce 174) ((T_EMPTY) reduce 174) ((T_ENUM) reduce 174) ((T_EVAL) reduce 174) ((T_EXIT) reduce 174) ((T_FILE) reduce 174) ((T_FINAL) reduce 174) ((T_FINALLY) shift) ((T_FN) reduce 174) ((T_FOR) reduce 174) ((T_FOREACH) reduce 174) ((T_FUNCTION) reduce 174) ((T_FUNC_C) reduce 174) ((T_GLOBAL) reduce 174) ((T_GOTO) reduce 174) ((T_HALT_COMPILER) reduce 174) ((T_IF) reduce 174) ((T_INC) reduce 174) ((T_INCLUDE) reduce 174) ((T_INCLUDE_ONCE) reduce 174) ((T_INLINE_HTML) reduce 174) ((T_INTERFACE) reduce 174) ((T_INT_CAST) reduce 174) ((T_ISSET) reduce 174) ((T_LINE) reduce 174) ((T_LIST) reduce 174) ((T_LNUMBER) reduce 174) ((T_MATCH) reduce 174) ((T_METHOD_C) reduce 174) ((T_NAMESPACE) reduce 174) ((T_NAME_FULLY_QUALIFIED) reduce 174) ((T_NAME_QUALIFIED) reduce 174) ((T_NAME_RELATIVE) reduce 174) ((T_NEW) reduce 174) ((T_NS_C) reduce 174) ((T_OBJECT_CAST) reduce 174) ((T_PRINT) reduce 174) ((T_READONLY) reduce 174) ((T_REQUIRE) reduce 174) ((T_REQUIRE_ONCE) reduce 174) ((T_RETURN) reduce 174) ((T_START_HEREDOC) reduce 174) ((T_STATIC) reduce 174) ((T_STRING) reduce 174) ((T_STRING_CAST) reduce 174) ((T_SWITCH) reduce 174) ((T_THROW) reduce 174) ((T_TRAIT) reduce 174) ((T_TRAIT_C) reduce 174) ((T_TRY) reduce 174) ((T_UNSET) reduce 174) ((T_UNSET_CAST) reduce 174) ((T_USE) reduce 174) ((T_VARIABLE) reduce 174) ((T_WHILE) reduce 174) ((T_YIELD) reduce 174) ((T_YIELD_FROM) reduce 174) (("[") reduce 174) (("`") reduce 174) (("{") reduce 174) (("~") reduce 174)) 28339 ((("!") reduce 165) (("\"") reduce 165) (($) reduce 165) (("$") reduce 165) (("(") reduce 165) (("+") reduce 165) (("-") reduce 165) ((";") reduce 165) (("@") reduce 165) ((T_ABSTRACT) reduce 165) ((T_ARRAY) reduce 165) ((T_ARRAY_CAST) reduce 165) ((T_ATTRIBUTE) reduce 165) ((T_BOOL_CAST) reduce 165) ((T_BREAK) reduce 165) ((T_CLASS) reduce 165) ((T_CLASS_C) reduce 165) ((T_CLONE) reduce 165) ((T_CONST) reduce 165) ((T_CONSTANT_ENCAPSED_STRING) reduce 165) ((T_CONTINUE) reduce 165) ((T_DEC) reduce 165) ((T_DECLARE) reduce 165) ((T_DIR) reduce 165) ((T_DNUMBER) reduce 165) ((T_DO) reduce 165) ((T_DOUBLE_CAST) reduce 165) ((T_ECHO) reduce 165) ((T_ELSE) reduce 165) ((T_ELSEIF) reduce 165) ((T_EMPTY) reduce 165) ((T_ENUM) reduce 165) ((T_EVAL) reduce 165) ((T_EXIT) reduce 165) ((T_FILE) reduce 165) ((T_FINAL) reduce 165) ((T_FN) reduce 165) ((T_FOR) reduce 165) ((T_FOREACH) reduce 165) ((T_FUNCTION) reduce 165) ((T_FUNC_C) reduce 165) ((T_GLOBAL) reduce 165) ((T_GOTO) reduce 165) ((T_HALT_COMPILER) reduce 165) ((T_IF) reduce 165) ((T_INC) reduce 165) ((T_INCLUDE) reduce 165) ((T_INCLUDE_ONCE) reduce 165) ((T_INLINE_HTML) reduce 165) ((T_INTERFACE) reduce 165) ((T_INT_CAST) reduce 165) ((T_ISSET) reduce 165) ((T_LINE) reduce 165) ((T_LIST) reduce 165) ((T_LNUMBER) reduce 165) ((T_MATCH) reduce 165) ((T_METHOD_C) reduce 165) ((T_NAMESPACE) reduce 165) ((T_NAME_FULLY_QUALIFIED) reduce 165) ((T_NAME_QUALIFIED) reduce 165) ((T_NAME_RELATIVE) reduce 165) ((T_NEW) reduce 165) ((T_NS_C) reduce 165) ((T_OBJECT_CAST) reduce 165) ((T_PRINT) reduce 165) ((T_READONLY) reduce 165) ((T_REQUIRE) reduce 165) ((T_REQUIRE_ONCE) reduce 165) ((T_RETURN) reduce 165) ((T_START_HEREDOC) reduce 165) ((T_STATIC) reduce 165) ((T_STRING) reduce 165) ((T_STRING_CAST) reduce 165) ((T_SWITCH) reduce 165) ((T_THROW) reduce 165) ((T_TRAIT) reduce 165) ((T_TRAIT_C) reduce 165) ((T_TRY) reduce 165) ((T_UNSET) reduce 165) ((T_UNSET_CAST) reduce 165) ((T_USE) reduce 165) ((T_VARIABLE) reduce 165) ((T_WHILE) reduce 165) ((T_YIELD) reduce 165) ((T_YIELD_FROM) reduce 165) (("[") reduce 165) (("`") reduce 165) (("{") reduce 165) (("~") reduce 165)) 28342 ((("!") reduce 175) (("\"") reduce 175) (($) reduce 175) (("$") reduce 175) (("(") reduce 175) (("+") reduce 175) (("-") reduce 175) ((";") reduce 175) (("@") reduce 175) ((T_ABSTRACT) reduce 175) ((T_ARRAY) reduce 175) ((T_ARRAY_CAST) reduce 175) ((T_ATTRIBUTE) reduce 175) ((T_BOOL_CAST) reduce 175) ((T_BREAK) reduce 175) ((T_CLASS) reduce 175) ((T_CLASS_C) reduce 175) ((T_CLONE) reduce 175) ((T_CONST) reduce 175) ((T_CONSTANT_ENCAPSED_STRING) reduce 175) ((T_CONTINUE) reduce 175) ((T_DEC) reduce 175) ((T_DECLARE) reduce 175) ((T_DIR) reduce 175) ((T_DNUMBER) reduce 175) ((T_DO) reduce 175) ((T_DOUBLE_CAST) reduce 175) ((T_ECHO) reduce 175) ((T_ELSE) reduce 175) ((T_ELSEIF) reduce 175) ((T_EMPTY) reduce 175) ((T_ENUM) reduce 175) ((T_EVAL) reduce 175) ((T_EXIT) reduce 175) ((T_FILE) reduce 175) ((T_FINAL) reduce 175) ((T_FN) reduce 175) ((T_FOR) reduce 175) ((T_FOREACH) reduce 175) ((T_FUNCTION) reduce 175) ((T_FUNC_C) reduce 175) ((T_GLOBAL) reduce 175) ((T_GOTO) reduce 175) ((T_HALT_COMPILER) reduce 175) ((T_IF) reduce 175) ((T_INC) reduce 175) ((T_INCLUDE) reduce 175) ((T_INCLUDE_ONCE) reduce 175) ((T_INLINE_HTML) reduce 175) ((T_INTERFACE) reduce 175) ((T_INT_CAST) reduce 175) ((T_ISSET) reduce 175) ((T_LINE) reduce 175) ((T_LIST) reduce 175) ((T_LNUMBER) reduce 175) ((T_MATCH) reduce 175) ((T_METHOD_C) reduce 175) ((T_NAMESPACE) reduce 175) ((T_NAME_FULLY_QUALIFIED) reduce 175) ((T_NAME_QUALIFIED) reduce 175) ((T_NAME_RELATIVE) reduce 175) ((T_NEW) reduce 175) ((T_NS_C) reduce 175) ((T_OBJECT_CAST) reduce 175) ((T_PRINT) reduce 175) ((T_READONLY) reduce 175) ((T_REQUIRE) reduce 175) ((T_REQUIRE_ONCE) reduce 175) ((T_RETURN) reduce 175) ((T_START_HEREDOC) reduce 175) ((T_STATIC) reduce 175) ((T_STRING) reduce 175) ((T_STRING_CAST) reduce 175) ((T_SWITCH) reduce 175) ((T_THROW) reduce 175) ((T_TRAIT) reduce 175) ((T_TRAIT_C) reduce 175) ((T_TRY) reduce 175) ((T_UNSET) reduce 175) ((T_UNSET_CAST) reduce 175) ((T_USE) reduce 175) ((T_VARIABLE) reduce 175) ((T_WHILE) reduce 175) ((T_YIELD) reduce 175) ((T_YIELD_FROM) reduce 175) (("[") reduce 175) (("`") reduce 175) (("{") reduce 175) (("~") reduce 175)) 28349 ((("!") reduce 169) (("\"") reduce 169) (($) reduce 169) (("$") reduce 169) (("(") reduce 169) (("+") reduce 169) (("-") reduce 169) ((";") reduce 169) (("@") reduce 169) ((T_ABSTRACT) reduce 169) ((T_ARRAY) reduce 169) ((T_ARRAY_CAST) reduce 169) ((T_ATTRIBUTE) reduce 169) ((T_BOOL_CAST) reduce 169) ((T_BREAK) reduce 169) ((T_CATCH) reduce 169) ((T_CLASS) reduce 169) ((T_CLASS_C) reduce 169) ((T_CLONE) reduce 169) ((T_CONST) reduce 169) ((T_CONSTANT_ENCAPSED_STRING) reduce 169) ((T_CONTINUE) reduce 169) ((T_DEC) reduce 169) ((T_DECLARE) reduce 169) ((T_DIR) reduce 169) ((T_DNUMBER) reduce 169) ((T_DO) reduce 169) ((T_DOUBLE_CAST) reduce 169) ((T_ECHO) reduce 169) ((T_ELSE) reduce 169) ((T_ELSEIF) reduce 169) ((T_EMPTY) reduce 169) ((T_ENUM) reduce 169) ((T_EVAL) reduce 169) ((T_EXIT) reduce 169) ((T_FILE) reduce 169) ((T_FINAL) reduce 169) ((T_FINALLY) reduce 169) ((T_FN) reduce 169) ((T_FOR) reduce 169) ((T_FOREACH) reduce 169) ((T_FUNCTION) reduce 169) ((T_FUNC_C) reduce 169) ((T_GLOBAL) reduce 169) ((T_GOTO) reduce 169) ((T_HALT_COMPILER) reduce 169) ((T_IF) reduce 169) ((T_INC) reduce 169) ((T_INCLUDE) reduce 169) ((T_INCLUDE_ONCE) reduce 169) ((T_INLINE_HTML) reduce 169) ((T_INTERFACE) reduce 169) ((T_INT_CAST) reduce 169) ((T_ISSET) reduce 169) ((T_LINE) reduce 169) ((T_LIST) reduce 169) ((T_LNUMBER) reduce 169) ((T_MATCH) reduce 169) ((T_METHOD_C) reduce 169) ((T_NAMESPACE) reduce 169) ((T_NAME_FULLY_QUALIFIED) reduce 169) ((T_NAME_QUALIFIED) reduce 169) ((T_NAME_RELATIVE) reduce 169) ((T_NEW) reduce 169) ((T_NS_C) reduce 169) ((T_OBJECT_CAST) reduce 169) ((T_PRINT) reduce 169) ((T_READONLY) reduce 169) ((T_REQUIRE) reduce 169) ((T_REQUIRE_ONCE) reduce 169) ((T_RETURN) reduce 169) ((T_START_HEREDOC) reduce 169) ((T_STATIC) reduce 169) ((T_STRING) reduce 169) ((T_STRING_CAST) reduce 169) ((T_SWITCH) reduce 169) ((T_THROW) reduce 169) ((T_TRAIT) reduce 169) ((T_TRAIT_C) reduce 169) ((T_TRY) reduce 169) ((T_UNSET) reduce 169) ((T_UNSET_CAST) reduce 169) ((T_USE) reduce 169) ((T_VARIABLE) reduce 169) ((T_WHILE) reduce 169) ((T_YIELD) reduce 169) ((T_YIELD_FROM) reduce 169) (("[") reduce 169) (("`") reduce 169) (("{") reduce 169) (("~") reduce 169)) 28354 ((("!") reduce 151) (("\"") reduce 151) (("$") reduce 151) (($) reduce 151) (("(") reduce 151) (("+") reduce 151) (("-") reduce 151) ((";") reduce 151) (("@") reduce 151) ((T_ABSTRACT) reduce 151) ((T_ARRAY) reduce 151) ((T_ARRAY_CAST) reduce 151) ((T_ATTRIBUTE) reduce 151) ((T_BOOL_CAST) reduce 151) ((T_BREAK) reduce 151) ((T_CLASS) reduce 151) ((T_CLASS_C) reduce 151) ((T_CLONE) reduce 151) ((T_CONST) reduce 151) ((T_CONSTANT_ENCAPSED_STRING) reduce 151) ((T_CONTINUE) reduce 151) ((T_DEC) reduce 151) ((T_DECLARE) reduce 151) ((T_DIR) reduce 151) ((T_DNUMBER) reduce 151) ((T_DO) reduce 151) ((T_DOUBLE_CAST) reduce 151) ((T_ECHO) reduce 151) ((T_ELSE) reduce 151) ((T_ELSEIF) reduce 151) ((T_EMPTY) reduce 151) ((T_ENUM) reduce 151) ((T_EVAL) reduce 151) ((T_EXIT) reduce 151) ((T_FILE) reduce 151) ((T_FINAL) reduce 151) ((T_FN) reduce 151) ((T_FOR) reduce 151) ((T_FOREACH) reduce 151) ((T_FUNCTION) reduce 151) ((T_FUNC_C) reduce 151) ((T_GLOBAL) reduce 151) ((T_GOTO) reduce 151) ((T_HALT_COMPILER) reduce 151) ((T_IF) reduce 151) ((T_INC) reduce 151) ((T_INCLUDE) reduce 151) ((T_INCLUDE_ONCE) reduce 151) ((T_INLINE_HTML) reduce 151) ((T_INTERFACE) reduce 151) ((T_INT_CAST) reduce 151) ((T_ISSET) reduce 151) ((T_LINE) reduce 151) ((T_LIST) reduce 151) ((T_LNUMBER) reduce 151) ((T_MATCH) reduce 151) ((T_METHOD_C) reduce 151) ((T_NAMESPACE) reduce 151) ((T_NAME_FULLY_QUALIFIED) reduce 151) ((T_NAME_QUALIFIED) reduce 151) ((T_NAME_RELATIVE) reduce 151) ((T_NEW) reduce 151) ((T_NS_C) reduce 151) ((T_OBJECT_CAST) reduce 151) ((T_PRINT) reduce 151) ((T_READONLY) reduce 151) ((T_REQUIRE) reduce 151) ((T_REQUIRE_ONCE) reduce 151) ((T_RETURN) reduce 151) ((T_START_HEREDOC) reduce 151) ((T_STATIC) reduce 151) ((T_STRING) reduce 151) ((T_STRING_CAST) reduce 151) ((T_SWITCH) reduce 151) ((T_THROW) reduce 151) ((T_TRAIT) reduce 151) ((T_TRAIT_C) reduce 151) ((T_TRY) reduce 151) ((T_UNSET) reduce 151) ((T_UNSET_CAST) reduce 151) ((T_USE) reduce 151) ((T_VARIABLE) reduce 151) ((T_WHILE) reduce 151) ((T_YIELD) reduce 151) ((T_YIELD_FROM) reduce 151) (("[") reduce 151) (("`") reduce 151) (("{") reduce 151) (("~") reduce 151)) 28358 ((("!") reduce 221) (("\"") reduce 221) (($) reduce 221) (("$") reduce 221) (("(") reduce 221) (("+") reduce 221) (("-") reduce 221) ((";") reduce 221) (("@") reduce 221) ((T_ABSTRACT) reduce 221) ((T_ARRAY) reduce 221) ((T_ARRAY_CAST) reduce 221) ((T_ATTRIBUTE) reduce 221) ((T_BOOL_CAST) reduce 221) ((T_BREAK) reduce 221) ((T_CLASS) reduce 221) ((T_CLASS_C) reduce 221) ((T_CLONE) reduce 221) ((T_CONST) reduce 221) ((T_CONSTANT_ENCAPSED_STRING) reduce 221) ((T_CONTINUE) reduce 221) ((T_DEC) reduce 221) ((T_DECLARE) reduce 221) ((T_DIR) reduce 221) ((T_DNUMBER) reduce 221) ((T_DO) reduce 221) ((T_DOUBLE_CAST) reduce 221) ((T_ECHO) reduce 221) ((T_ELSE) reduce 221) ((T_ELSEIF) reduce 221) ((T_EMPTY) reduce 221) ((T_ENUM) reduce 221) ((T_EVAL) reduce 221) ((T_EXIT) reduce 221) ((T_FILE) reduce 221) ((T_FINAL) reduce 221) ((T_FN) reduce 221) ((T_FOR) reduce 221) ((T_FOREACH) reduce 221) ((T_FUNCTION) reduce 221) ((T_FUNC_C) reduce 221) ((T_GLOBAL) reduce 221) ((T_GOTO) reduce 221) ((T_HALT_COMPILER) reduce 221) ((T_IF) reduce 221) ((T_INC) reduce 221) ((T_INCLUDE) reduce 221) ((T_INCLUDE_ONCE) reduce 221) ((T_INLINE_HTML) reduce 221) ((T_INTERFACE) reduce 221) ((T_INT_CAST) reduce 221) ((T_ISSET) reduce 221) ((T_LINE) reduce 221) ((T_LIST) reduce 221) ((T_LNUMBER) reduce 221) ((T_MATCH) reduce 221) ((T_METHOD_C) reduce 221) ((T_NAMESPACE) reduce 221) ((T_NAME_FULLY_QUALIFIED) reduce 221) ((T_NAME_QUALIFIED) reduce 221) ((T_NAME_RELATIVE) reduce 221) ((T_NEW) reduce 221) ((T_NS_C) reduce 221) ((T_OBJECT_CAST) reduce 221) ((T_PRINT) reduce 221) ((T_READONLY) reduce 221) ((T_REQUIRE) reduce 221) ((T_REQUIRE_ONCE) reduce 221) ((T_RETURN) reduce 221) ((T_START_HEREDOC) reduce 221) ((T_STATIC) reduce 221) ((T_STRING) reduce 221) ((T_STRING_CAST) reduce 221) ((T_SWITCH) reduce 221) ((T_THROW) reduce 221) ((T_TRAIT) reduce 221) ((T_TRAIT_C) reduce 221) ((T_TRY) reduce 221) ((T_UNSET) reduce 221) ((T_UNSET_CAST) reduce 221) ((T_USE) reduce 221) ((T_VARIABLE) reduce 221) ((T_WHILE) reduce 221) ((T_YIELD) reduce 221) ((T_YIELD_FROM) reduce 221) (("[") reduce 221) (("`") reduce 221) (("{") reduce 221) (("~") reduce 221)) 28360 ((("!") reduce 222) (("\"") reduce 222) (("$") reduce 222) (($) reduce 222) (("(") reduce 222) (("+") reduce 222) (("-") reduce 222) ((";") reduce 222) (("@") reduce 222) ((T_ABSTRACT) reduce 222) ((T_ARRAY) reduce 222) ((T_ARRAY_CAST) reduce 222) ((T_ATTRIBUTE) reduce 222) ((T_BOOL_CAST) reduce 222) ((T_BREAK) reduce 222) ((T_CLASS) reduce 222) ((T_CLASS_C) reduce 222) ((T_CLONE) reduce 222) ((T_CONST) reduce 222) ((T_CONSTANT_ENCAPSED_STRING) reduce 222) ((T_CONTINUE) reduce 222) ((T_DEC) reduce 222) ((T_DECLARE) reduce 222) ((T_DIR) reduce 222) ((T_DNUMBER) reduce 222) ((T_DO) reduce 222) ((T_DOUBLE_CAST) reduce 222) ((T_ECHO) reduce 222) ((T_ELSE) reduce 222) ((T_ELSEIF) reduce 222) ((T_EMPTY) reduce 222) ((T_ENUM) reduce 222) ((T_EVAL) reduce 222) ((T_EXIT) reduce 222) ((T_FILE) reduce 222) ((T_FINAL) reduce 222) ((T_FN) reduce 222) ((T_FOR) reduce 222) ((T_FOREACH) reduce 222) ((T_FUNCTION) reduce 222) ((T_FUNC_C) reduce 222) ((T_GLOBAL) reduce 222) ((T_GOTO) reduce 222) ((T_HALT_COMPILER) reduce 222) ((T_IF) reduce 222) ((T_INC) reduce 222) ((T_INCLUDE) reduce 222) ((T_INCLUDE_ONCE) reduce 222) ((T_INLINE_HTML) reduce 222) ((T_INTERFACE) reduce 222) ((T_INT_CAST) reduce 222) ((T_ISSET) reduce 222) ((T_LINE) reduce 222) ((T_LIST) reduce 222) ((T_LNUMBER) reduce 222) ((T_MATCH) reduce 222) ((T_METHOD_C) reduce 222) ((T_NAMESPACE) reduce 222) ((T_NAME_FULLY_QUALIFIED) reduce 222) ((T_NAME_QUALIFIED) reduce 222) ((T_NAME_RELATIVE) reduce 222) ((T_NEW) reduce 222) ((T_NS_C) reduce 222) ((T_OBJECT_CAST) reduce 222) ((T_PRINT) reduce 222) ((T_READONLY) reduce 222) ((T_REQUIRE) reduce 222) ((T_REQUIRE_ONCE) reduce 222) ((T_RETURN) reduce 222) ((T_START_HEREDOC) reduce 222) ((T_STATIC) reduce 222) ((T_STRING) reduce 222) ((T_STRING_CAST) reduce 222) ((T_SWITCH) reduce 222) ((T_THROW) reduce 222) ((T_TRAIT) reduce 222) ((T_TRAIT_C) reduce 222) ((T_TRY) reduce 222) ((T_UNSET) reduce 222) ((T_UNSET_CAST) reduce 222) ((T_USE) reduce 222) ((T_VARIABLE) reduce 222) ((T_WHILE) reduce 222) ((T_YIELD) reduce 222) ((T_YIELD_FROM) reduce 222) (("[") reduce 222) (("`") reduce 222) (("{") reduce 222) (("~") reduce 222)) 28364 ((("!") reduce 223) (("\"") reduce 223) (("$") reduce 223) (($) reduce 223) (("(") reduce 223) (("+") reduce 223) (("-") reduce 223) ((";") reduce 223) (("@") reduce 223) ((T_ABSTRACT) reduce 223) ((T_ARRAY) reduce 223) ((T_ARRAY_CAST) reduce 223) ((T_ATTRIBUTE) reduce 223) ((T_BOOL_CAST) reduce 223) ((T_BREAK) reduce 223) ((T_CLASS) reduce 223) ((T_CLASS_C) reduce 223) ((T_CLONE) reduce 223) ((T_CONST) reduce 223) ((T_CONSTANT_ENCAPSED_STRING) reduce 223) ((T_CONTINUE) reduce 223) ((T_DEC) reduce 223) ((T_DECLARE) reduce 223) ((T_DIR) reduce 223) ((T_DNUMBER) reduce 223) ((T_DO) reduce 223) ((T_DOUBLE_CAST) reduce 223) ((T_ECHO) reduce 223) ((T_ELSE) reduce 223) ((T_ELSEIF) reduce 223) ((T_EMPTY) reduce 223) ((T_ENUM) reduce 223) ((T_EVAL) reduce 223) ((T_EXIT) reduce 223) ((T_FILE) reduce 223) ((T_FINAL) reduce 223) ((T_FN) reduce 223) ((T_FOR) reduce 223) ((T_FOREACH) reduce 223) ((T_FUNCTION) reduce 223) ((T_FUNC_C) reduce 223) ((T_GLOBAL) reduce 223) ((T_GOTO) reduce 223) ((T_HALT_COMPILER) reduce 223) ((T_IF) reduce 223) ((T_INC) reduce 223) ((T_INCLUDE) reduce 223) ((T_INCLUDE_ONCE) reduce 223) ((T_INLINE_HTML) reduce 223) ((T_INTERFACE) reduce 223) ((T_INT_CAST) reduce 223) ((T_ISSET) reduce 223) ((T_LINE) reduce 223) ((T_LIST) reduce 223) ((T_LNUMBER) reduce 223) ((T_MATCH) reduce 223) ((T_METHOD_C) reduce 223) ((T_NAMESPACE) reduce 223) ((T_NAME_FULLY_QUALIFIED) reduce 223) ((T_NAME_QUALIFIED) reduce 223) ((T_NAME_RELATIVE) reduce 223) ((T_NEW) reduce 223) ((T_NS_C) reduce 223) ((T_OBJECT_CAST) reduce 223) ((T_PRINT) reduce 223) ((T_READONLY) reduce 223) ((T_REQUIRE) reduce 223) ((T_REQUIRE_ONCE) reduce 223) ((T_RETURN) reduce 223) ((T_START_HEREDOC) reduce 223) ((T_STATIC) reduce 223) ((T_STRING) reduce 223) ((T_STRING_CAST) reduce 223) ((T_SWITCH) reduce 223) ((T_THROW) reduce 223) ((T_TRAIT) reduce 223) ((T_TRAIT_C) reduce 223) ((T_TRY) reduce 223) ((T_UNSET) reduce 223) ((T_UNSET_CAST) reduce 223) ((T_USE) reduce 223) ((T_VARIABLE) reduce 223) ((T_WHILE) reduce 223) ((T_YIELD) reduce 223) ((T_YIELD_FROM) reduce 223) (("[") reduce 223) (("`") reduce 223) (("{") reduce 223) (("~") reduce 223)) 28367 ((("!") reduce 224) (("\"") reduce 224) (($) reduce 224) (("$") reduce 224) (("(") reduce 224) (("+") reduce 224) (("-") reduce 224) ((";") reduce 224) (("@") reduce 224) ((T_ABSTRACT) reduce 224) ((T_ARRAY) reduce 224) ((T_ARRAY_CAST) reduce 224) ((T_ATTRIBUTE) reduce 224) ((T_BOOL_CAST) reduce 224) ((T_BREAK) reduce 224) ((T_CLASS) reduce 224) ((T_CLASS_C) reduce 224) ((T_CLONE) reduce 224) ((T_CONST) reduce 224) ((T_CONSTANT_ENCAPSED_STRING) reduce 224) ((T_CONTINUE) reduce 224) ((T_DEC) reduce 224) ((T_DECLARE) reduce 224) ((T_DIR) reduce 224) ((T_DNUMBER) reduce 224) ((T_DO) reduce 224) ((T_DOUBLE_CAST) reduce 224) ((T_ECHO) reduce 224) ((T_ELSE) reduce 224) ((T_ELSEIF) reduce 224) ((T_EMPTY) reduce 224) ((T_ENUM) reduce 224) ((T_EVAL) reduce 224) ((T_EXIT) reduce 224) ((T_FILE) reduce 224) ((T_FINAL) reduce 224) ((T_FN) reduce 224) ((T_FOR) reduce 224) ((T_FOREACH) reduce 224) ((T_FUNCTION) reduce 224) ((T_FUNC_C) reduce 224) ((T_GLOBAL) reduce 224) ((T_GOTO) reduce 224) ((T_HALT_COMPILER) reduce 224) ((T_IF) reduce 224) ((T_INC) reduce 224) ((T_INCLUDE) reduce 224) ((T_INCLUDE_ONCE) reduce 224) ((T_INLINE_HTML) reduce 224) ((T_INTERFACE) reduce 224) ((T_INT_CAST) reduce 224) ((T_ISSET) reduce 224) ((T_LINE) reduce 224) ((T_LIST) reduce 224) ((T_LNUMBER) reduce 224) ((T_MATCH) reduce 224) ((T_METHOD_C) reduce 224) ((T_NAMESPACE) reduce 224) ((T_NAME_FULLY_QUALIFIED) reduce 224) ((T_NAME_QUALIFIED) reduce 224) ((T_NAME_RELATIVE) reduce 224) ((T_NEW) reduce 224) ((T_NS_C) reduce 224) ((T_OBJECT_CAST) reduce 224) ((T_PRINT) reduce 224) ((T_READONLY) reduce 224) ((T_REQUIRE) reduce 224) ((T_REQUIRE_ONCE) reduce 224) ((T_RETURN) reduce 224) ((T_START_HEREDOC) reduce 224) ((T_STATIC) reduce 224) ((T_STRING) reduce 224) ((T_STRING_CAST) reduce 224) ((T_SWITCH) reduce 224) ((T_THROW) reduce 224) ((T_TRAIT) reduce 224) ((T_TRAIT_C) reduce 224) ((T_TRY) reduce 224) ((T_UNSET) reduce 224) ((T_UNSET_CAST) reduce 224) ((T_USE) reduce 224) ((T_VARIABLE) reduce 224) ((T_WHILE) reduce 224) ((T_YIELD) reduce 224) ((T_YIELD_FROM) reduce 224) (("[") reduce 224) (("`") reduce 224) (("{") reduce 224) (("~") reduce 224)) 28368 ((("!") reduce 167) (("\"") reduce 167) (($) reduce 167) (("$") reduce 167) (("(") reduce 167) (("+") reduce 167) (("-") reduce 167) ((";") reduce 167) (("@") reduce 167) ((T_ABSTRACT) reduce 167) ((T_ARRAY) reduce 167) ((T_ARRAY_CAST) reduce 167) ((T_ATTRIBUTE) reduce 167) ((T_BOOL_CAST) reduce 167) ((T_BREAK) reduce 167) ((T_CLASS) reduce 167) ((T_CLASS_C) reduce 167) ((T_CLONE) reduce 167) ((T_CONST) reduce 167) ((T_CONSTANT_ENCAPSED_STRING) reduce 167) ((T_CONTINUE) reduce 167) ((T_DEC) reduce 167) ((T_DECLARE) reduce 167) ((T_DIR) reduce 167) ((T_DNUMBER) reduce 167) ((T_DO) reduce 167) ((T_DOUBLE_CAST) reduce 167) ((T_ECHO) reduce 167) ((T_ELSE) reduce 167) ((T_ELSEIF) reduce 167) ((T_EMPTY) reduce 167) ((T_ENUM) reduce 167) ((T_EVAL) reduce 167) ((T_EXIT) reduce 167) ((T_FILE) reduce 167) ((T_FINAL) reduce 167) ((T_FN) reduce 167) ((T_FOR) reduce 167) ((T_FOREACH) reduce 167) ((T_FUNCTION) reduce 167) ((T_FUNC_C) reduce 167) ((T_GLOBAL) reduce 167) ((T_GOTO) reduce 167) ((T_HALT_COMPILER) reduce 167) ((T_IF) reduce 167) ((T_INC) reduce 167) ((T_INCLUDE) reduce 167) ((T_INCLUDE_ONCE) reduce 167) ((T_INLINE_HTML) reduce 167) ((T_INTERFACE) reduce 167) ((T_INT_CAST) reduce 167) ((T_ISSET) reduce 167) ((T_LINE) reduce 167) ((T_LIST) reduce 167) ((T_LNUMBER) reduce 167) ((T_MATCH) reduce 167) ((T_METHOD_C) reduce 167) ((T_NAMESPACE) reduce 167) ((T_NAME_FULLY_QUALIFIED) reduce 167) ((T_NAME_QUALIFIED) reduce 167) ((T_NAME_RELATIVE) reduce 167) ((T_NEW) reduce 167) ((T_NS_C) reduce 167) ((T_OBJECT_CAST) reduce 167) ((T_PRINT) reduce 167) ((T_READONLY) reduce 167) ((T_REQUIRE) reduce 167) ((T_REQUIRE_ONCE) reduce 167) ((T_RETURN) reduce 167) ((T_START_HEREDOC) reduce 167) ((T_STATIC) reduce 167) ((T_STRING) reduce 167) ((T_STRING_CAST) reduce 167) ((T_SWITCH) reduce 167) ((T_THROW) reduce 167) ((T_TRAIT) reduce 167) ((T_TRAIT_C) reduce 167) ((T_TRY) reduce 167) ((T_UNSET) reduce 167) ((T_UNSET_CAST) reduce 167) ((T_USE) reduce 167) ((T_VARIABLE) reduce 167) ((T_WHILE) reduce 167) ((T_YIELD) reduce 167) ((T_YIELD_FROM) reduce 167) (("[") reduce 167) (("`") reduce 167) (("{") reduce 167) (("~") reduce 167)) 28370 ((("!") reduce 156) (("\"") reduce 156) (("$") reduce 156) (($) reduce 156) (("(") reduce 156) (("+") reduce 156) (("-") reduce 156) ((";") reduce 156) (("@") reduce 156) ((T_ABSTRACT) reduce 156) ((T_ARRAY) reduce 156) ((T_ARRAY_CAST) reduce 156) ((T_ATTRIBUTE) reduce 156) ((T_BOOL_CAST) reduce 156) ((T_BREAK) reduce 156) ((T_CLASS) reduce 156) ((T_CLASS_C) reduce 156) ((T_CLONE) reduce 156) ((T_CONST) reduce 156) ((T_CONSTANT_ENCAPSED_STRING) reduce 156) ((T_CONTINUE) reduce 156) ((T_DEC) reduce 156) ((T_DECLARE) reduce 156) ((T_DIR) reduce 156) ((T_DNUMBER) reduce 156) ((T_DO) reduce 156) ((T_DOUBLE_CAST) reduce 156) ((T_ECHO) reduce 156) ((T_ELSE) reduce 156) ((T_ELSEIF) reduce 156) ((T_EMPTY) reduce 156) ((T_ENUM) reduce 156) ((T_EVAL) reduce 156) ((T_EXIT) reduce 156) ((T_FILE) reduce 156) ((T_FINAL) reduce 156) ((T_FN) reduce 156) ((T_FOR) reduce 156) ((T_FOREACH) reduce 156) ((T_FUNCTION) reduce 156) ((T_FUNC_C) reduce 156) ((T_GLOBAL) reduce 156) ((T_GOTO) reduce 156) ((T_HALT_COMPILER) reduce 156) ((T_IF) reduce 156) ((T_INC) reduce 156) ((T_INCLUDE) reduce 156) ((T_INCLUDE_ONCE) reduce 156) ((T_INLINE_HTML) reduce 156) ((T_INTERFACE) reduce 156) ((T_INT_CAST) reduce 156) ((T_ISSET) reduce 156) ((T_LINE) reduce 156) ((T_LIST) reduce 156) ((T_LNUMBER) reduce 156) ((T_MATCH) reduce 156) ((T_METHOD_C) reduce 156) ((T_NAMESPACE) reduce 156) ((T_NAME_FULLY_QUALIFIED) reduce 156) ((T_NAME_QUALIFIED) reduce 156) ((T_NAME_RELATIVE) reduce 156) ((T_NEW) reduce 156) ((T_NS_C) reduce 156) ((T_OBJECT_CAST) reduce 156) ((T_PRINT) reduce 156) ((T_READONLY) reduce 156) ((T_REQUIRE) reduce 156) ((T_REQUIRE_ONCE) reduce 156) ((T_RETURN) reduce 156) ((T_START_HEREDOC) reduce 156) ((T_STATIC) reduce 156) ((T_STRING) reduce 156) ((T_STRING_CAST) reduce 156) ((T_SWITCH) reduce 156) ((T_THROW) reduce 156) ((T_TRAIT) reduce 156) ((T_TRAIT_C) reduce 156) ((T_TRY) reduce 156) ((T_UNSET) reduce 156) ((T_UNSET_CAST) reduce 156) ((T_USE) reduce 156) ((T_VARIABLE) reduce 156) ((T_WHILE) reduce 156) ((T_YIELD) reduce 156) ((T_YIELD_FROM) reduce 156) (("[") reduce 156) (("`") reduce 156) (("{") reduce 156) (("~") reduce 156)) 28372 ((("!") reduce 154) (("\"") reduce 154) (("$") reduce 154) (($) reduce 154) (("(") reduce 154) (("+") reduce 154) (("-") reduce 154) ((";") reduce 154) (("@") reduce 154) ((T_ABSTRACT) reduce 154) ((T_ARRAY) reduce 154) ((T_ARRAY_CAST) reduce 154) ((T_ATTRIBUTE) reduce 154) ((T_BOOL_CAST) reduce 154) ((T_BREAK) reduce 154) ((T_CLASS) reduce 154) ((T_CLASS_C) reduce 154) ((T_CLONE) reduce 154) ((T_CONST) reduce 154) ((T_CONSTANT_ENCAPSED_STRING) reduce 154) ((T_CONTINUE) reduce 154) ((T_DEC) reduce 154) ((T_DECLARE) reduce 154) ((T_DIR) reduce 154) ((T_DNUMBER) reduce 154) ((T_DO) reduce 154) ((T_DOUBLE_CAST) reduce 154) ((T_ECHO) reduce 154) ((T_ELSE) reduce 154) ((T_ELSEIF) reduce 154) ((T_EMPTY) reduce 154) ((T_ENUM) reduce 154) ((T_EVAL) reduce 154) ((T_EXIT) reduce 154) ((T_FILE) reduce 154) ((T_FINAL) reduce 154) ((T_FN) reduce 154) ((T_FOR) reduce 154) ((T_FOREACH) reduce 154) ((T_FUNCTION) reduce 154) ((T_FUNC_C) reduce 154) ((T_GLOBAL) reduce 154) ((T_GOTO) reduce 154) ((T_HALT_COMPILER) reduce 154) ((T_IF) reduce 154) ((T_INC) reduce 154) ((T_INCLUDE) reduce 154) ((T_INCLUDE_ONCE) reduce 154) ((T_INLINE_HTML) reduce 154) ((T_INTERFACE) reduce 154) ((T_INT_CAST) reduce 154) ((T_ISSET) reduce 154) ((T_LINE) reduce 154) ((T_LIST) reduce 154) ((T_LNUMBER) reduce 154) ((T_MATCH) reduce 154) ((T_METHOD_C) reduce 154) ((T_NAMESPACE) reduce 154) ((T_NAME_FULLY_QUALIFIED) reduce 154) ((T_NAME_QUALIFIED) reduce 154) ((T_NAME_RELATIVE) reduce 154) ((T_NEW) reduce 154) ((T_NS_C) reduce 154) ((T_OBJECT_CAST) reduce 154) ((T_PRINT) reduce 154) ((T_READONLY) reduce 154) ((T_REQUIRE) reduce 154) ((T_REQUIRE_ONCE) reduce 154) ((T_RETURN) reduce 154) ((T_START_HEREDOC) reduce 154) ((T_STATIC) reduce 154) ((T_STRING) reduce 154) ((T_STRING_CAST) reduce 154) ((T_SWITCH) reduce 154) ((T_THROW) reduce 154) ((T_TRAIT) reduce 154) ((T_TRAIT_C) reduce 154) ((T_TRY) reduce 154) ((T_UNSET) reduce 154) ((T_UNSET_CAST) reduce 154) ((T_USE) reduce 154) ((T_VARIABLE) reduce 154) ((T_WHILE) reduce 154) ((T_YIELD) reduce 154) ((T_YIELD_FROM) reduce 154) (("[") reduce 154) (("`") reduce 154) (("{") reduce 154) (("~") reduce 154)) 28376 ((("!") reduce 241) (("\"") reduce 241) (("$") reduce 241) (($) reduce 241) (("(") reduce 241) (("+") reduce 241) (("-") reduce 241) ((";") reduce 241) (("@") reduce 241) ((T_ABSTRACT) reduce 241) ((T_ARRAY) reduce 241) ((T_ARRAY_CAST) reduce 241) ((T_ATTRIBUTE) reduce 241) ((T_BOOL_CAST) reduce 241) ((T_BREAK) reduce 241) ((T_CLASS) reduce 241) ((T_CLASS_C) reduce 241) ((T_CLONE) reduce 241) ((T_CONST) reduce 241) ((T_CONSTANT_ENCAPSED_STRING) reduce 241) ((T_CONTINUE) reduce 241) ((T_DEC) reduce 241) ((T_DECLARE) reduce 241) ((T_DIR) reduce 241) ((T_DNUMBER) reduce 241) ((T_DO) reduce 241) ((T_DOUBLE_CAST) reduce 241) ((T_ECHO) reduce 241) ((T_ELSE) reduce 241) ((T_ELSEIF) reduce 241) ((T_EMPTY) reduce 241) ((T_ENUM) reduce 241) ((T_EVAL) reduce 241) ((T_EXIT) reduce 241) ((T_FILE) reduce 241) ((T_FINAL) reduce 241) ((T_FN) reduce 241) ((T_FOR) reduce 241) ((T_FOREACH) reduce 241) ((T_FUNCTION) reduce 241) ((T_FUNC_C) reduce 241) ((T_GLOBAL) reduce 241) ((T_GOTO) reduce 241) ((T_HALT_COMPILER) reduce 241) ((T_IF) reduce 241) ((T_INC) reduce 241) ((T_INCLUDE) reduce 241) ((T_INCLUDE_ONCE) reduce 241) ((T_INLINE_HTML) reduce 241) ((T_INTERFACE) reduce 241) ((T_INT_CAST) reduce 241) ((T_ISSET) reduce 241) ((T_LINE) reduce 241) ((T_LIST) reduce 241) ((T_LNUMBER) reduce 241) ((T_MATCH) reduce 241) ((T_METHOD_C) reduce 241) ((T_NAMESPACE) reduce 241) ((T_NAME_FULLY_QUALIFIED) reduce 241) ((T_NAME_QUALIFIED) reduce 241) ((T_NAME_RELATIVE) reduce 241) ((T_NEW) reduce 241) ((T_NS_C) reduce 241) ((T_OBJECT_CAST) reduce 241) ((T_PRINT) reduce 241) ((T_READONLY) reduce 241) ((T_REQUIRE) reduce 241) ((T_REQUIRE_ONCE) reduce 241) ((T_RETURN) reduce 241) ((T_START_HEREDOC) reduce 241) ((T_STATIC) reduce 241) ((T_STRING) reduce 241) ((T_STRING_CAST) reduce 241) ((T_SWITCH) reduce 241) ((T_THROW) reduce 241) ((T_TRAIT) reduce 241) ((T_TRAIT_C) reduce 241) ((T_TRY) reduce 241) ((T_UNSET) reduce 241) ((T_UNSET_CAST) reduce 241) ((T_USE) reduce 241) ((T_VARIABLE) reduce 241) ((T_WHILE) reduce 241) ((T_YIELD) reduce 241) ((T_YIELD_FROM) reduce 241) (("[") reduce 241) (("`") reduce 241) (("{") reduce 241) (("~") reduce 241)) 28378 ((("!") reduce 166) (("\"") reduce 166) (("$") reduce 166) (($) reduce 166) (("(") reduce 166) (("+") reduce 166) (("-") reduce 166) ((";") reduce 166) (("@") reduce 166) ((T_ABSTRACT) reduce 166) ((T_ARRAY) reduce 166) ((T_ARRAY_CAST) reduce 166) ((T_ATTRIBUTE) reduce 166) ((T_BOOL_CAST) reduce 166) ((T_BREAK) reduce 166) ((T_CLASS) reduce 166) ((T_CLASS_C) reduce 166) ((T_CLONE) reduce 166) ((T_CONST) reduce 166) ((T_CONSTANT_ENCAPSED_STRING) reduce 166) ((T_CONTINUE) reduce 166) ((T_DEC) reduce 166) ((T_DECLARE) reduce 166) ((T_DIR) reduce 166) ((T_DNUMBER) reduce 166) ((T_DO) reduce 166) ((T_DOUBLE_CAST) reduce 166) ((T_ECHO) reduce 166) ((T_ELSE) reduce 166) ((T_ELSEIF) reduce 166) ((T_EMPTY) reduce 166) ((T_ENUM) reduce 166) ((T_EVAL) reduce 166) ((T_EXIT) reduce 166) ((T_FILE) reduce 166) ((T_FINAL) reduce 166) ((T_FN) reduce 166) ((T_FOR) reduce 166) ((T_FOREACH) reduce 166) ((T_FUNCTION) reduce 166) ((T_FUNC_C) reduce 166) ((T_GLOBAL) reduce 166) ((T_GOTO) reduce 166) ((T_HALT_COMPILER) reduce 166) ((T_IF) reduce 166) ((T_INC) reduce 166) ((T_INCLUDE) reduce 166) ((T_INCLUDE_ONCE) reduce 166) ((T_INLINE_HTML) reduce 166) ((T_INTERFACE) reduce 166) ((T_INT_CAST) reduce 166) ((T_ISSET) reduce 166) ((T_LINE) reduce 166) ((T_LIST) reduce 166) ((T_LNUMBER) reduce 166) ((T_MATCH) reduce 166) ((T_METHOD_C) reduce 166) ((T_NAMESPACE) reduce 166) ((T_NAME_FULLY_QUALIFIED) reduce 166) ((T_NAME_QUALIFIED) reduce 166) ((T_NAME_RELATIVE) reduce 166) ((T_NEW) reduce 166) ((T_NS_C) reduce 166) ((T_OBJECT_CAST) reduce 166) ((T_PRINT) reduce 166) ((T_READONLY) reduce 166) ((T_REQUIRE) reduce 166) ((T_REQUIRE_ONCE) reduce 166) ((T_RETURN) reduce 166) ((T_START_HEREDOC) reduce 166) ((T_STATIC) reduce 166) ((T_STRING) reduce 166) ((T_STRING_CAST) reduce 166) ((T_SWITCH) reduce 166) ((T_THROW) reduce 166) ((T_TRAIT) reduce 166) ((T_TRAIT_C) reduce 166) ((T_TRY) reduce 166) ((T_UNSET) reduce 166) ((T_UNSET_CAST) reduce 166) ((T_USE) reduce 166) ((T_VARIABLE) reduce 166) ((T_WHILE) reduce 166) ((T_YIELD) reduce 166) ((T_YIELD_FROM) reduce 166) (("[") reduce 166) (("`") reduce 166) (("{") reduce 166) (("~") reduce 166)) 28380 ((("!") reduce 155) (("\"") reduce 155) (("$") reduce 155) (($) reduce 155) (("(") reduce 155) (("+") reduce 155) (("-") reduce 155) ((";") reduce 155) (("@") reduce 155) ((T_ABSTRACT) reduce 155) ((T_ARRAY) reduce 155) ((T_ARRAY_CAST) reduce 155) ((T_ATTRIBUTE) reduce 155) ((T_BOOL_CAST) reduce 155) ((T_BREAK) reduce 155) ((T_CLASS) reduce 155) ((T_CLASS_C) reduce 155) ((T_CLONE) reduce 155) ((T_CONST) reduce 155) ((T_CONSTANT_ENCAPSED_STRING) reduce 155) ((T_CONTINUE) reduce 155) ((T_DEC) reduce 155) ((T_DECLARE) reduce 155) ((T_DIR) reduce 155) ((T_DNUMBER) reduce 155) ((T_DO) reduce 155) ((T_DOUBLE_CAST) reduce 155) ((T_ECHO) reduce 155) ((T_ELSE) reduce 155) ((T_ELSEIF) reduce 155) ((T_EMPTY) reduce 155) ((T_ENUM) reduce 155) ((T_EVAL) reduce 155) ((T_EXIT) reduce 155) ((T_FILE) reduce 155) ((T_FINAL) reduce 155) ((T_FN) reduce 155) ((T_FOR) reduce 155) ((T_FOREACH) reduce 155) ((T_FUNCTION) reduce 155) ((T_FUNC_C) reduce 155) ((T_GLOBAL) reduce 155) ((T_GOTO) reduce 155) ((T_HALT_COMPILER) reduce 155) ((T_IF) reduce 155) ((T_INC) reduce 155) ((T_INCLUDE) reduce 155) ((T_INCLUDE_ONCE) reduce 155) ((T_INLINE_HTML) reduce 155) ((T_INTERFACE) reduce 155) ((T_INT_CAST) reduce 155) ((T_ISSET) reduce 155) ((T_LINE) reduce 155) ((T_LIST) reduce 155) ((T_LNUMBER) reduce 155) ((T_MATCH) reduce 155) ((T_METHOD_C) reduce 155) ((T_NAMESPACE) reduce 155) ((T_NAME_FULLY_QUALIFIED) reduce 155) ((T_NAME_QUALIFIED) reduce 155) ((T_NAME_RELATIVE) reduce 155) ((T_NEW) reduce 155) ((T_NS_C) reduce 155) ((T_OBJECT_CAST) reduce 155) ((T_PRINT) reduce 155) ((T_READONLY) reduce 155) ((T_REQUIRE) reduce 155) ((T_REQUIRE_ONCE) reduce 155) ((T_RETURN) reduce 155) ((T_START_HEREDOC) reduce 155) ((T_STATIC) reduce 155) ((T_STRING) reduce 155) ((T_STRING_CAST) reduce 155) ((T_SWITCH) reduce 155) ((T_THROW) reduce 155) ((T_TRAIT) reduce 155) ((T_TRAIT_C) reduce 155) ((T_TRY) reduce 155) ((T_UNSET) reduce 155) ((T_UNSET_CAST) reduce 155) ((T_USE) reduce 155) ((T_VARIABLE) reduce 155) ((T_WHILE) reduce 155) ((T_YIELD) reduce 155) ((T_YIELD_FROM) reduce 155) (("[") reduce 155) (("`") reduce 155) (("{") reduce 155) (("~") reduce 155)) 28390 ((("!") reduce 162) (("\"") reduce 162) (("$") reduce 162) (($) reduce 162) (("(") reduce 162) (("+") reduce 162) (("-") reduce 162) ((";") reduce 162) (("@") reduce 162) ((T_ABSTRACT) reduce 162) ((T_ARRAY) reduce 162) ((T_ARRAY_CAST) reduce 162) ((T_ATTRIBUTE) reduce 162) ((T_BOOL_CAST) reduce 162) ((T_BREAK) reduce 162) ((T_CLASS) reduce 162) ((T_CLASS_C) reduce 162) ((T_CLONE) reduce 162) ((T_CONST) reduce 162) ((T_CONSTANT_ENCAPSED_STRING) reduce 162) ((T_CONTINUE) reduce 162) ((T_DEC) reduce 162) ((T_DECLARE) reduce 162) ((T_DIR) reduce 162) ((T_DNUMBER) reduce 162) ((T_DO) reduce 162) ((T_DOUBLE_CAST) reduce 162) ((T_ECHO) reduce 162) ((T_ELSE) reduce 162) ((T_ELSEIF) reduce 162) ((T_EMPTY) reduce 162) ((T_ENUM) reduce 162) ((T_EVAL) reduce 162) ((T_EXIT) reduce 162) ((T_FILE) reduce 162) ((T_FINAL) reduce 162) ((T_FN) reduce 162) ((T_FOR) reduce 162) ((T_FOREACH) reduce 162) ((T_FUNCTION) reduce 162) ((T_FUNC_C) reduce 162) ((T_GLOBAL) reduce 162) ((T_GOTO) reduce 162) ((T_HALT_COMPILER) reduce 162) ((T_IF) reduce 162) ((T_INC) reduce 162) ((T_INCLUDE) reduce 162) ((T_INCLUDE_ONCE) reduce 162) ((T_INLINE_HTML) reduce 162) ((T_INTERFACE) reduce 162) ((T_INT_CAST) reduce 162) ((T_ISSET) reduce 162) ((T_LINE) reduce 162) ((T_LIST) reduce 162) ((T_LNUMBER) reduce 162) ((T_MATCH) reduce 162) ((T_METHOD_C) reduce 162) ((T_NAMESPACE) reduce 162) ((T_NAME_FULLY_QUALIFIED) reduce 162) ((T_NAME_QUALIFIED) reduce 162) ((T_NAME_RELATIVE) reduce 162) ((T_NEW) reduce 162) ((T_NS_C) reduce 162) ((T_OBJECT_CAST) reduce 162) ((T_PRINT) reduce 162) ((T_READONLY) reduce 162) ((T_REQUIRE) reduce 162) ((T_REQUIRE_ONCE) reduce 162) ((T_RETURN) reduce 162) ((T_START_HEREDOC) reduce 162) ((T_STATIC) reduce 162) ((T_STRING) reduce 162) ((T_STRING_CAST) reduce 162) ((T_SWITCH) reduce 162) ((T_THROW) reduce 162) ((T_TRAIT) reduce 162) ((T_TRAIT_C) reduce 162) ((T_TRY) reduce 162) ((T_UNSET) reduce 162) ((T_UNSET_CAST) reduce 162) ((T_USE) reduce 162) ((T_VARIABLE) reduce 162) ((T_WHILE) reduce 162) ((T_YIELD) reduce 162) ((T_YIELD_FROM) reduce 162) (("[") reduce 162) (("`") reduce 162) (("{") reduce 162) (("~") reduce 162)) 28391 ((("!") reduce 217) (("\"") reduce 217) (($) reduce 217) (("$") reduce 217) (("(") reduce 217) (("+") reduce 217) (("-") reduce 217) ((";") reduce 217) (("@") reduce 217) ((T_ABSTRACT) reduce 217) ((T_ARRAY) reduce 217) ((T_ARRAY_CAST) reduce 217) ((T_ATTRIBUTE) reduce 217) ((T_BOOL_CAST) reduce 217) ((T_BREAK) reduce 217) ((T_CLASS) reduce 217) ((T_CLASS_C) reduce 217) ((T_CLONE) reduce 217) ((T_CONST) reduce 217) ((T_CONSTANT_ENCAPSED_STRING) reduce 217) ((T_CONTINUE) reduce 217) ((T_DEC) reduce 217) ((T_DECLARE) reduce 217) ((T_DIR) reduce 217) ((T_DNUMBER) reduce 217) ((T_DO) reduce 217) ((T_DOUBLE_CAST) reduce 217) ((T_ECHO) reduce 217) ((T_ELSE) reduce 217) ((T_ELSEIF) reduce 217) ((T_EMPTY) reduce 217) ((T_ENUM) reduce 217) ((T_EVAL) reduce 217) ((T_EXIT) reduce 217) ((T_FILE) reduce 217) ((T_FINAL) reduce 217) ((T_FN) reduce 217) ((T_FOR) reduce 217) ((T_FOREACH) reduce 217) ((T_FUNCTION) reduce 217) ((T_FUNC_C) reduce 217) ((T_GLOBAL) reduce 217) ((T_GOTO) reduce 217) ((T_HALT_COMPILER) reduce 217) ((T_IF) reduce 217) ((T_INC) reduce 217) ((T_INCLUDE) reduce 217) ((T_INCLUDE_ONCE) reduce 217) ((T_INLINE_HTML) reduce 217) ((T_INTERFACE) reduce 217) ((T_INT_CAST) reduce 217) ((T_ISSET) reduce 217) ((T_LINE) reduce 217) ((T_LIST) reduce 217) ((T_LNUMBER) reduce 217) ((T_MATCH) reduce 217) ((T_METHOD_C) reduce 217) ((T_NAMESPACE) reduce 217) ((T_NAME_FULLY_QUALIFIED) reduce 217) ((T_NAME_QUALIFIED) reduce 217) ((T_NAME_RELATIVE) reduce 217) ((T_NEW) reduce 217) ((T_NS_C) reduce 217) ((T_OBJECT_CAST) reduce 217) ((T_PRINT) reduce 217) ((T_READONLY) reduce 217) ((T_REQUIRE) reduce 217) ((T_REQUIRE_ONCE) reduce 217) ((T_RETURN) reduce 217) ((T_START_HEREDOC) reduce 217) ((T_STATIC) reduce 217) ((T_STRING) reduce 217) ((T_STRING_CAST) reduce 217) ((T_SWITCH) reduce 217) ((T_THROW) reduce 217) ((T_TRAIT) reduce 217) ((T_TRAIT_C) reduce 217) ((T_TRY) reduce 217) ((T_UNSET) reduce 217) ((T_UNSET_CAST) reduce 217) ((T_USE) reduce 217) ((T_VARIABLE) reduce 217) ((T_WHILE) reduce 217) ((T_YIELD) reduce 217) ((T_YIELD_FROM) reduce 217) (("[") reduce 217) (("`") reduce 217) (("{") reduce 217) (("~") reduce 217)) 28394 ((("!") reduce 218) (("\"") reduce 218) (("$") reduce 218) (($) reduce 218) (("(") reduce 218) (("+") reduce 218) (("-") reduce 218) ((";") reduce 218) (("@") reduce 218) ((T_ABSTRACT) reduce 218) ((T_ARRAY) reduce 218) ((T_ARRAY_CAST) reduce 218) ((T_ATTRIBUTE) reduce 218) ((T_BOOL_CAST) reduce 218) ((T_BREAK) reduce 218) ((T_CLASS) reduce 218) ((T_CLASS_C) reduce 218) ((T_CLONE) reduce 218) ((T_CONST) reduce 218) ((T_CONSTANT_ENCAPSED_STRING) reduce 218) ((T_CONTINUE) reduce 218) ((T_DEC) reduce 218) ((T_DECLARE) reduce 218) ((T_DIR) reduce 218) ((T_DNUMBER) reduce 218) ((T_DO) reduce 218) ((T_DOUBLE_CAST) reduce 218) ((T_ECHO) reduce 218) ((T_ELSE) reduce 218) ((T_ELSEIF) reduce 218) ((T_EMPTY) reduce 218) ((T_ENUM) reduce 218) ((T_EVAL) reduce 218) ((T_EXIT) reduce 218) ((T_FILE) reduce 218) ((T_FINAL) reduce 218) ((T_FN) reduce 218) ((T_FOR) reduce 218) ((T_FOREACH) reduce 218) ((T_FUNCTION) reduce 218) ((T_FUNC_C) reduce 218) ((T_GLOBAL) reduce 218) ((T_GOTO) reduce 218) ((T_HALT_COMPILER) reduce 218) ((T_IF) reduce 218) ((T_INC) reduce 218) ((T_INCLUDE) reduce 218) ((T_INCLUDE_ONCE) reduce 218) ((T_INLINE_HTML) reduce 218) ((T_INTERFACE) reduce 218) ((T_INT_CAST) reduce 218) ((T_ISSET) reduce 218) ((T_LINE) reduce 218) ((T_LIST) reduce 218) ((T_LNUMBER) reduce 218) ((T_MATCH) reduce 218) ((T_METHOD_C) reduce 218) ((T_NAMESPACE) reduce 218) ((T_NAME_FULLY_QUALIFIED) reduce 218) ((T_NAME_QUALIFIED) reduce 218) ((T_NAME_RELATIVE) reduce 218) ((T_NEW) reduce 218) ((T_NS_C) reduce 218) ((T_OBJECT_CAST) reduce 218) ((T_PRINT) reduce 218) ((T_READONLY) reduce 218) ((T_REQUIRE) reduce 218) ((T_REQUIRE_ONCE) reduce 218) ((T_RETURN) reduce 218) ((T_START_HEREDOC) reduce 218) ((T_STATIC) reduce 218) ((T_STRING) reduce 218) ((T_STRING_CAST) reduce 218) ((T_SWITCH) reduce 218) ((T_THROW) reduce 218) ((T_TRAIT) reduce 218) ((T_TRAIT_C) reduce 218) ((T_TRY) reduce 218) ((T_UNSET) reduce 218) ((T_UNSET_CAST) reduce 218) ((T_USE) reduce 218) ((T_VARIABLE) reduce 218) ((T_WHILE) reduce 218) ((T_YIELD) reduce 218) ((T_YIELD_FROM) reduce 218) (("[") reduce 218) (("`") reduce 218) (("{") reduce 218) (("~") reduce 218)) 28395 ((("!") reduce 161) (("\"") reduce 161) (("$") reduce 161) (($) reduce 161) (("(") reduce 161) (("+") reduce 161) (("-") reduce 161) ((";") reduce 161) (("@") reduce 161) ((T_ABSTRACT) reduce 161) ((T_ARRAY) reduce 161) ((T_ARRAY_CAST) reduce 161) ((T_ATTRIBUTE) reduce 161) ((T_BOOL_CAST) reduce 161) ((T_BREAK) reduce 161) ((T_CLASS) reduce 161) ((T_CLASS_C) reduce 161) ((T_CLONE) reduce 161) ((T_CONST) reduce 161) ((T_CONSTANT_ENCAPSED_STRING) reduce 161) ((T_CONTINUE) reduce 161) ((T_DEC) reduce 161) ((T_DECLARE) reduce 161) ((T_DIR) reduce 161) ((T_DNUMBER) reduce 161) ((T_DO) reduce 161) ((T_DOUBLE_CAST) reduce 161) ((T_ECHO) reduce 161) ((T_ELSE) reduce 161) ((T_ELSEIF) reduce 161) ((T_EMPTY) reduce 161) ((T_ENUM) reduce 161) ((T_EVAL) reduce 161) ((T_EXIT) reduce 161) ((T_FILE) reduce 161) ((T_FINAL) reduce 161) ((T_FN) reduce 161) ((T_FOR) reduce 161) ((T_FOREACH) reduce 161) ((T_FUNCTION) reduce 161) ((T_FUNC_C) reduce 161) ((T_GLOBAL) reduce 161) ((T_GOTO) reduce 161) ((T_HALT_COMPILER) reduce 161) ((T_IF) reduce 161) ((T_INC) reduce 161) ((T_INCLUDE) reduce 161) ((T_INCLUDE_ONCE) reduce 161) ((T_INLINE_HTML) reduce 161) ((T_INTERFACE) reduce 161) ((T_INT_CAST) reduce 161) ((T_ISSET) reduce 161) ((T_LINE) reduce 161) ((T_LIST) reduce 161) ((T_LNUMBER) reduce 161) ((T_MATCH) reduce 161) ((T_METHOD_C) reduce 161) ((T_NAMESPACE) reduce 161) ((T_NAME_FULLY_QUALIFIED) reduce 161) ((T_NAME_QUALIFIED) reduce 161) ((T_NAME_RELATIVE) reduce 161) ((T_NEW) reduce 161) ((T_NS_C) reduce 161) ((T_OBJECT_CAST) reduce 161) ((T_PRINT) reduce 161) ((T_READONLY) reduce 161) ((T_REQUIRE) reduce 161) ((T_REQUIRE_ONCE) reduce 161) ((T_RETURN) reduce 161) ((T_START_HEREDOC) reduce 161) ((T_STATIC) reduce 161) ((T_STRING) reduce 161) ((T_STRING_CAST) reduce 161) ((T_SWITCH) reduce 161) ((T_THROW) reduce 161) ((T_TRAIT) reduce 161) ((T_TRAIT_C) reduce 161) ((T_TRY) reduce 161) ((T_UNSET) reduce 161) ((T_UNSET_CAST) reduce 161) ((T_USE) reduce 161) ((T_VARIABLE) reduce 161) ((T_WHILE) reduce 161) ((T_YIELD) reduce 161) ((T_YIELD_FROM) reduce 161) (("[") reduce 161) (("`") reduce 161) (("{") reduce 161) (("~") reduce 161)) 28404 ((("!") reduce 150) (("\"") reduce 150) (("$") reduce 150) (($) reduce 150) (("(") reduce 150) (("+") reduce 150) (("-") reduce 150) ((";") reduce 150) (("@") reduce 150) ((T_ABSTRACT) reduce 150) ((T_ARRAY) reduce 150) ((T_ARRAY_CAST) reduce 150) ((T_ATTRIBUTE) reduce 150) ((T_BOOL_CAST) reduce 150) ((T_BREAK) reduce 150) ((T_CLASS) reduce 150) ((T_CLASS_C) reduce 150) ((T_CLONE) reduce 150) ((T_CONST) reduce 150) ((T_CONSTANT_ENCAPSED_STRING) reduce 150) ((T_CONTINUE) reduce 150) ((T_DEC) reduce 150) ((T_DECLARE) reduce 150) ((T_DIR) reduce 150) ((T_DNUMBER) reduce 150) ((T_DO) reduce 150) ((T_DOUBLE_CAST) reduce 150) ((T_ECHO) reduce 150) ((T_ELSE) reduce 150) ((T_ELSEIF) reduce 150) ((T_EMPTY) reduce 150) ((T_ENUM) reduce 150) ((T_EVAL) reduce 150) ((T_EXIT) reduce 150) ((T_FILE) reduce 150) ((T_FINAL) reduce 150) ((T_FN) reduce 150) ((T_FOR) reduce 150) ((T_FOREACH) reduce 150) ((T_FUNCTION) reduce 150) ((T_FUNC_C) reduce 150) ((T_GLOBAL) reduce 150) ((T_GOTO) reduce 150) ((T_HALT_COMPILER) reduce 150) ((T_IF) reduce 150) ((T_INC) reduce 150) ((T_INCLUDE) reduce 150) ((T_INCLUDE_ONCE) reduce 150) ((T_INLINE_HTML) reduce 150) ((T_INTERFACE) reduce 150) ((T_INT_CAST) reduce 150) ((T_ISSET) reduce 150) ((T_LINE) reduce 150) ((T_LIST) reduce 150) ((T_LNUMBER) reduce 150) ((T_MATCH) reduce 150) ((T_METHOD_C) reduce 150) ((T_NAMESPACE) reduce 150) ((T_NAME_FULLY_QUALIFIED) reduce 150) ((T_NAME_QUALIFIED) reduce 150) ((T_NAME_RELATIVE) reduce 150) ((T_NEW) reduce 150) ((T_NS_C) reduce 150) ((T_OBJECT_CAST) reduce 150) ((T_PRINT) reduce 150) ((T_READONLY) reduce 150) ((T_REQUIRE) reduce 150) ((T_REQUIRE_ONCE) reduce 150) ((T_RETURN) reduce 150) ((T_START_HEREDOC) reduce 150) ((T_STATIC) reduce 150) ((T_STRING) reduce 150) ((T_STRING_CAST) reduce 150) ((T_SWITCH) reduce 150) ((T_THROW) reduce 150) ((T_TRAIT) reduce 150) ((T_TRAIT_C) reduce 150) ((T_TRY) reduce 150) ((T_UNSET) reduce 150) ((T_UNSET_CAST) reduce 150) ((T_USE) reduce 150) ((T_VARIABLE) reduce 150) ((T_WHILE) reduce 150) ((T_YIELD) reduce 150) ((T_YIELD_FROM) reduce 150) (("[") reduce 150) (("`") reduce 150) (("{") reduce 150) (("~") reduce 150)) 28405 ((("!") reduce 215) (("\"") reduce 215) (($) reduce 215) (("$") reduce 215) (("(") reduce 215) (("+") reduce 215) (("-") reduce 215) ((";") reduce 215) (("@") reduce 215) ((T_ABSTRACT) reduce 215) ((T_ARRAY) reduce 215) ((T_ARRAY_CAST) reduce 215) ((T_ATTRIBUTE) reduce 215) ((T_BOOL_CAST) reduce 215) ((T_BREAK) reduce 215) ((T_CLASS) reduce 215) ((T_CLASS_C) reduce 215) ((T_CLONE) reduce 215) ((T_CONST) reduce 215) ((T_CONSTANT_ENCAPSED_STRING) reduce 215) ((T_CONTINUE) reduce 215) ((T_DEC) reduce 215) ((T_DECLARE) reduce 215) ((T_DIR) reduce 215) ((T_DNUMBER) reduce 215) ((T_DO) reduce 215) ((T_DOUBLE_CAST) reduce 215) ((T_ECHO) reduce 215) ((T_ELSE) reduce 215) ((T_ELSEIF) reduce 215) ((T_EMPTY) reduce 215) ((T_ENUM) reduce 215) ((T_EVAL) reduce 215) ((T_EXIT) reduce 215) ((T_FILE) reduce 215) ((T_FINAL) reduce 215) ((T_FN) reduce 215) ((T_FOR) reduce 215) ((T_FOREACH) reduce 215) ((T_FUNCTION) reduce 215) ((T_FUNC_C) reduce 215) ((T_GLOBAL) reduce 215) ((T_GOTO) reduce 215) ((T_HALT_COMPILER) reduce 215) ((T_IF) reduce 215) ((T_INC) reduce 215) ((T_INCLUDE) reduce 215) ((T_INCLUDE_ONCE) reduce 215) ((T_INLINE_HTML) reduce 215) ((T_INTERFACE) reduce 215) ((T_INT_CAST) reduce 215) ((T_ISSET) reduce 215) ((T_LINE) reduce 215) ((T_LIST) reduce 215) ((T_LNUMBER) reduce 215) ((T_MATCH) reduce 215) ((T_METHOD_C) reduce 215) ((T_NAMESPACE) reduce 215) ((T_NAME_FULLY_QUALIFIED) reduce 215) ((T_NAME_QUALIFIED) reduce 215) ((T_NAME_RELATIVE) reduce 215) ((T_NEW) reduce 215) ((T_NS_C) reduce 215) ((T_OBJECT_CAST) reduce 215) ((T_PRINT) reduce 215) ((T_READONLY) reduce 215) ((T_REQUIRE) reduce 215) ((T_REQUIRE_ONCE) reduce 215) ((T_RETURN) reduce 215) ((T_START_HEREDOC) reduce 215) ((T_STATIC) reduce 215) ((T_STRING) reduce 215) ((T_STRING_CAST) reduce 215) ((T_SWITCH) reduce 215) ((T_THROW) reduce 215) ((T_TRAIT) reduce 215) ((T_TRAIT_C) reduce 215) ((T_TRY) reduce 215) ((T_UNSET) reduce 215) ((T_UNSET_CAST) reduce 215) ((T_USE) reduce 215) ((T_VARIABLE) reduce 215) ((T_WHILE) reduce 215) ((T_YIELD) reduce 215) ((T_YIELD_FROM) reduce 215) (("[") reduce 215) (("`") reduce 215) (("{") reduce 215) (("~") reduce 215)) 28408 ((("!") reduce 216) (("\"") reduce 216) (("$") reduce 216) (($) reduce 216) (("(") reduce 216) (("+") reduce 216) (("-") reduce 216) ((";") reduce 216) (("@") reduce 216) ((T_ABSTRACT) reduce 216) ((T_ARRAY) reduce 216) ((T_ARRAY_CAST) reduce 216) ((T_ATTRIBUTE) reduce 216) ((T_BOOL_CAST) reduce 216) ((T_BREAK) reduce 216) ((T_CLASS) reduce 216) ((T_CLASS_C) reduce 216) ((T_CLONE) reduce 216) ((T_CONST) reduce 216) ((T_CONSTANT_ENCAPSED_STRING) reduce 216) ((T_CONTINUE) reduce 216) ((T_DEC) reduce 216) ((T_DECLARE) reduce 216) ((T_DIR) reduce 216) ((T_DNUMBER) reduce 216) ((T_DO) reduce 216) ((T_DOUBLE_CAST) reduce 216) ((T_ECHO) reduce 216) ((T_ELSE) reduce 216) ((T_ELSEIF) reduce 216) ((T_EMPTY) reduce 216) ((T_ENUM) reduce 216) ((T_EVAL) reduce 216) ((T_EXIT) reduce 216) ((T_FILE) reduce 216) ((T_FINAL) reduce 216) ((T_FN) reduce 216) ((T_FOR) reduce 216) ((T_FOREACH) reduce 216) ((T_FUNCTION) reduce 216) ((T_FUNC_C) reduce 216) ((T_GLOBAL) reduce 216) ((T_GOTO) reduce 216) ((T_HALT_COMPILER) reduce 216) ((T_IF) reduce 216) ((T_INC) reduce 216) ((T_INCLUDE) reduce 216) ((T_INCLUDE_ONCE) reduce 216) ((T_INLINE_HTML) reduce 216) ((T_INTERFACE) reduce 216) ((T_INT_CAST) reduce 216) ((T_ISSET) reduce 216) ((T_LINE) reduce 216) ((T_LIST) reduce 216) ((T_LNUMBER) reduce 216) ((T_MATCH) reduce 216) ((T_METHOD_C) reduce 216) ((T_NAMESPACE) reduce 216) ((T_NAME_FULLY_QUALIFIED) reduce 216) ((T_NAME_QUALIFIED) reduce 216) ((T_NAME_RELATIVE) reduce 216) ((T_NEW) reduce 216) ((T_NS_C) reduce 216) ((T_OBJECT_CAST) reduce 216) ((T_PRINT) reduce 216) ((T_READONLY) reduce 216) ((T_REQUIRE) reduce 216) ((T_REQUIRE_ONCE) reduce 216) ((T_RETURN) reduce 216) ((T_START_HEREDOC) reduce 216) ((T_STATIC) reduce 216) ((T_STRING) reduce 216) ((T_STRING_CAST) reduce 216) ((T_SWITCH) reduce 216) ((T_THROW) reduce 216) ((T_TRAIT) reduce 216) ((T_TRAIT_C) reduce 216) ((T_TRY) reduce 216) ((T_UNSET) reduce 216) ((T_UNSET_CAST) reduce 216) ((T_USE) reduce 216) ((T_VARIABLE) reduce 216) ((T_WHILE) reduce 216) ((T_YIELD) reduce 216) ((T_YIELD_FROM) reduce 216) (("[") reduce 216) (("`") reduce 216) (("{") reduce 216) (("~") reduce 216)) 28410 ((("!") reduce 157) (("\"") reduce 157) (("$") reduce 157) (($) reduce 157) (("(") reduce 157) (("+") reduce 157) (("-") reduce 157) ((";") reduce 157) (("@") reduce 157) ((T_ABSTRACT) reduce 157) ((T_ARRAY) reduce 157) ((T_ARRAY_CAST) reduce 157) ((T_ATTRIBUTE) reduce 157) ((T_BOOL_CAST) reduce 157) ((T_BREAK) reduce 157) ((T_CLASS) reduce 157) ((T_CLASS_C) reduce 157) ((T_CLONE) reduce 157) ((T_CONST) reduce 157) ((T_CONSTANT_ENCAPSED_STRING) reduce 157) ((T_CONTINUE) reduce 157) ((T_DEC) reduce 157) ((T_DECLARE) reduce 157) ((T_DIR) reduce 157) ((T_DNUMBER) reduce 157) ((T_DO) reduce 157) ((T_DOUBLE_CAST) reduce 157) ((T_ECHO) reduce 157) ((T_ELSE) reduce 157) ((T_ELSEIF) reduce 157) ((T_EMPTY) reduce 157) ((T_ENUM) reduce 157) ((T_EVAL) reduce 157) ((T_EXIT) reduce 157) ((T_FILE) reduce 157) ((T_FINAL) reduce 157) ((T_FN) reduce 157) ((T_FOR) reduce 157) ((T_FOREACH) reduce 157) ((T_FUNCTION) reduce 157) ((T_FUNC_C) reduce 157) ((T_GLOBAL) reduce 157) ((T_GOTO) reduce 157) ((T_HALT_COMPILER) reduce 157) ((T_IF) reduce 157) ((T_INC) reduce 157) ((T_INCLUDE) reduce 157) ((T_INCLUDE_ONCE) reduce 157) ((T_INLINE_HTML) reduce 157) ((T_INTERFACE) reduce 157) ((T_INT_CAST) reduce 157) ((T_ISSET) reduce 157) ((T_LINE) reduce 157) ((T_LIST) reduce 157) ((T_LNUMBER) reduce 157) ((T_MATCH) reduce 157) ((T_METHOD_C) reduce 157) ((T_NAMESPACE) reduce 157) ((T_NAME_FULLY_QUALIFIED) reduce 157) ((T_NAME_QUALIFIED) reduce 157) ((T_NAME_RELATIVE) reduce 157) ((T_NEW) reduce 157) ((T_NS_C) reduce 157) ((T_OBJECT_CAST) reduce 157) ((T_PRINT) reduce 157) ((T_READONLY) reduce 157) ((T_REQUIRE) reduce 157) ((T_REQUIRE_ONCE) reduce 157) ((T_RETURN) reduce 157) ((T_START_HEREDOC) reduce 157) ((T_STATIC) reduce 157) ((T_STRING) reduce 157) ((T_STRING_CAST) reduce 157) ((T_SWITCH) reduce 157) ((T_THROW) reduce 157) ((T_TRAIT) reduce 157) ((T_TRAIT_C) reduce 157) ((T_TRY) reduce 157) ((T_UNSET) reduce 157) ((T_UNSET_CAST) reduce 157) ((T_USE) reduce 157) ((T_VARIABLE) reduce 157) ((T_WHILE) reduce 157) ((T_YIELD) reduce 157) ((T_YIELD_FROM) reduce 157) (("[") reduce 157) (("`") reduce 157) (("{") reduce 157) (("~") reduce 157)) 28416 ((("!") reduce 149) (("\"") reduce 149) (("$") reduce 149) (($) reduce 149) (("(") reduce 149) (("+") reduce 149) (("-") reduce 149) ((";") reduce 149) (("@") reduce 149) ((T_ABSTRACT) reduce 149) ((T_ARRAY) reduce 149) ((T_ARRAY_CAST) reduce 149) ((T_ATTRIBUTE) reduce 149) ((T_BOOL_CAST) reduce 149) ((T_BREAK) reduce 149) ((T_CLASS) reduce 149) ((T_CLASS_C) reduce 149) ((T_CLONE) reduce 149) ((T_CONST) reduce 149) ((T_CONSTANT_ENCAPSED_STRING) reduce 149) ((T_CONTINUE) reduce 149) ((T_DEC) reduce 149) ((T_DECLARE) reduce 149) ((T_DIR) reduce 149) ((T_DNUMBER) reduce 149) ((T_DO) reduce 149) ((T_DOUBLE_CAST) reduce 149) ((T_ECHO) reduce 149) ((T_ELSE) reduce 149) ((T_ELSEIF) reduce 149) ((T_EMPTY) reduce 149) ((T_ENUM) reduce 149) ((T_EVAL) reduce 149) ((T_EXIT) reduce 149) ((T_FILE) reduce 149) ((T_FINAL) reduce 149) ((T_FN) reduce 149) ((T_FOR) reduce 149) ((T_FOREACH) reduce 149) ((T_FUNCTION) reduce 149) ((T_FUNC_C) reduce 149) ((T_GLOBAL) reduce 149) ((T_GOTO) reduce 149) ((T_HALT_COMPILER) reduce 149) ((T_IF) reduce 149) ((T_INC) reduce 149) ((T_INCLUDE) reduce 149) ((T_INCLUDE_ONCE) reduce 149) ((T_INLINE_HTML) reduce 149) ((T_INTERFACE) reduce 149) ((T_INT_CAST) reduce 149) ((T_ISSET) reduce 149) ((T_LINE) reduce 149) ((T_LIST) reduce 149) ((T_LNUMBER) reduce 149) ((T_MATCH) reduce 149) ((T_METHOD_C) reduce 149) ((T_NAMESPACE) reduce 149) ((T_NAME_FULLY_QUALIFIED) reduce 149) ((T_NAME_QUALIFIED) reduce 149) ((T_NAME_RELATIVE) reduce 149) ((T_NEW) reduce 149) ((T_NS_C) reduce 149) ((T_OBJECT_CAST) reduce 149) ((T_PRINT) reduce 149) ((T_READONLY) reduce 149) ((T_REQUIRE) reduce 149) ((T_REQUIRE_ONCE) reduce 149) ((T_RETURN) reduce 149) ((T_START_HEREDOC) reduce 149) ((T_STATIC) reduce 149) ((T_STRING) reduce 149) ((T_STRING_CAST) reduce 149) ((T_SWITCH) reduce 149) ((T_THROW) reduce 149) ((T_TRAIT) reduce 149) ((T_TRAIT_C) reduce 149) ((T_TRY) reduce 149) ((T_UNSET) reduce 149) ((T_UNSET_CAST) reduce 149) ((T_USE) reduce 149) ((T_VARIABLE) reduce 149) ((T_WHILE) reduce 149) ((T_YIELD) reduce 149) ((T_YIELD_FROM) reduce 149) (("[") reduce 149) (("`") reduce 149) (("{") reduce 149) (("~") reduce 149)) 28421 ((("!") reduce 163) (("\"") reduce 163) (("$") reduce 163) (($) reduce 163) (("(") reduce 163) (("+") reduce 163) (("-") reduce 163) ((";") reduce 163) (("@") reduce 163) ((T_ABSTRACT) reduce 163) ((T_ARRAY) reduce 163) ((T_ARRAY_CAST) reduce 163) ((T_ATTRIBUTE) reduce 163) ((T_BOOL_CAST) reduce 163) ((T_BREAK) reduce 163) ((T_CLASS) reduce 163) ((T_CLASS_C) reduce 163) ((T_CLONE) reduce 163) ((T_CONST) reduce 163) ((T_CONSTANT_ENCAPSED_STRING) reduce 163) ((T_CONTINUE) reduce 163) ((T_DEC) reduce 163) ((T_DECLARE) reduce 163) ((T_DIR) reduce 163) ((T_DNUMBER) reduce 163) ((T_DO) reduce 163) ((T_DOUBLE_CAST) reduce 163) ((T_ECHO) reduce 163) ((T_ELSE) reduce 163) ((T_ELSEIF) reduce 163) ((T_EMPTY) reduce 163) ((T_ENUM) reduce 163) ((T_EVAL) reduce 163) ((T_EXIT) reduce 163) ((T_FILE) reduce 163) ((T_FINAL) reduce 163) ((T_FN) reduce 163) ((T_FOR) reduce 163) ((T_FOREACH) reduce 163) ((T_FUNCTION) reduce 163) ((T_FUNC_C) reduce 163) ((T_GLOBAL) reduce 163) ((T_GOTO) reduce 163) ((T_HALT_COMPILER) reduce 163) ((T_IF) reduce 163) ((T_INC) reduce 163) ((T_INCLUDE) reduce 163) ((T_INCLUDE_ONCE) reduce 163) ((T_INLINE_HTML) reduce 163) ((T_INTERFACE) reduce 163) ((T_INT_CAST) reduce 163) ((T_ISSET) reduce 163) ((T_LINE) reduce 163) ((T_LIST) reduce 163) ((T_LNUMBER) reduce 163) ((T_MATCH) reduce 163) ((T_METHOD_C) reduce 163) ((T_NAMESPACE) reduce 163) ((T_NAME_FULLY_QUALIFIED) reduce 163) ((T_NAME_QUALIFIED) reduce 163) ((T_NAME_RELATIVE) reduce 163) ((T_NEW) reduce 163) ((T_NS_C) reduce 163) ((T_OBJECT_CAST) reduce 163) ((T_PRINT) reduce 163) ((T_READONLY) reduce 163) ((T_REQUIRE) reduce 163) ((T_REQUIRE_ONCE) reduce 163) ((T_RETURN) reduce 163) ((T_START_HEREDOC) reduce 163) ((T_STATIC) reduce 163) ((T_STRING) reduce 163) ((T_STRING_CAST) reduce 163) ((T_SWITCH) reduce 163) ((T_THROW) reduce 163) ((T_TRAIT) reduce 163) ((T_TRAIT_C) reduce 163) ((T_TRY) reduce 163) ((T_UNSET) reduce 163) ((T_UNSET_CAST) reduce 163) ((T_USE) reduce 163) ((T_VARIABLE) reduce 163) ((T_WHILE) reduce 163) ((T_YIELD) reduce 163) ((T_YIELD_FROM) reduce 163) (("[") reduce 163) (("`") reduce 163) (("{") reduce 163) (("~") reduce 163)) 28422 ((("!") reduce 219) (("\"") reduce 219) (($) reduce 219) (("$") reduce 219) (("(") reduce 219) (("+") reduce 219) (("-") reduce 219) ((";") reduce 219) (("@") reduce 219) ((T_ABSTRACT) reduce 219) ((T_ARRAY) reduce 219) ((T_ARRAY_CAST) reduce 219) ((T_ATTRIBUTE) reduce 219) ((T_BOOL_CAST) reduce 219) ((T_BREAK) reduce 219) ((T_CLASS) reduce 219) ((T_CLASS_C) reduce 219) ((T_CLONE) reduce 219) ((T_CONST) reduce 219) ((T_CONSTANT_ENCAPSED_STRING) reduce 219) ((T_CONTINUE) reduce 219) ((T_DEC) reduce 219) ((T_DECLARE) reduce 219) ((T_DIR) reduce 219) ((T_DNUMBER) reduce 219) ((T_DO) reduce 219) ((T_DOUBLE_CAST) reduce 219) ((T_ECHO) reduce 219) ((T_ELSE) reduce 219) ((T_ELSEIF) reduce 219) ((T_EMPTY) reduce 219) ((T_ENUM) reduce 219) ((T_EVAL) reduce 219) ((T_EXIT) reduce 219) ((T_FILE) reduce 219) ((T_FINAL) reduce 219) ((T_FN) reduce 219) ((T_FOR) reduce 219) ((T_FOREACH) reduce 219) ((T_FUNCTION) reduce 219) ((T_FUNC_C) reduce 219) ((T_GLOBAL) reduce 219) ((T_GOTO) reduce 219) ((T_HALT_COMPILER) reduce 219) ((T_IF) reduce 219) ((T_INC) reduce 219) ((T_INCLUDE) reduce 219) ((T_INCLUDE_ONCE) reduce 219) ((T_INLINE_HTML) reduce 219) ((T_INTERFACE) reduce 219) ((T_INT_CAST) reduce 219) ((T_ISSET) reduce 219) ((T_LINE) reduce 219) ((T_LIST) reduce 219) ((T_LNUMBER) reduce 219) ((T_MATCH) reduce 219) ((T_METHOD_C) reduce 219) ((T_NAMESPACE) reduce 219) ((T_NAME_FULLY_QUALIFIED) reduce 219) ((T_NAME_QUALIFIED) reduce 219) ((T_NAME_RELATIVE) reduce 219) ((T_NEW) reduce 219) ((T_NS_C) reduce 219) ((T_OBJECT_CAST) reduce 219) ((T_PRINT) reduce 219) ((T_READONLY) reduce 219) ((T_REQUIRE) reduce 219) ((T_REQUIRE_ONCE) reduce 219) ((T_RETURN) reduce 219) ((T_START_HEREDOC) reduce 219) ((T_STATIC) reduce 219) ((T_STRING) reduce 219) ((T_STRING_CAST) reduce 219) ((T_SWITCH) reduce 219) ((T_THROW) reduce 219) ((T_TRAIT) reduce 219) ((T_TRAIT_C) reduce 219) ((T_TRY) reduce 219) ((T_UNSET) reduce 219) ((T_UNSET_CAST) reduce 219) ((T_USE) reduce 219) ((T_VARIABLE) reduce 219) ((T_WHILE) reduce 219) ((T_YIELD) reduce 219) ((T_YIELD_FROM) reduce 219) (("[") reduce 219) (("`") reduce 219) (("{") reduce 219) (("~") reduce 219)) 28425 ((("!") reduce 220) (("\"") reduce 220) (("$") reduce 220) (($) reduce 220) (("(") reduce 220) (("+") reduce 220) (("-") reduce 220) ((";") reduce 220) (("@") reduce 220) ((T_ABSTRACT) reduce 220) ((T_ARRAY) reduce 220) ((T_ARRAY_CAST) reduce 220) ((T_ATTRIBUTE) reduce 220) ((T_BOOL_CAST) reduce 220) ((T_BREAK) reduce 220) ((T_CLASS) reduce 220) ((T_CLASS_C) reduce 220) ((T_CLONE) reduce 220) ((T_CONST) reduce 220) ((T_CONSTANT_ENCAPSED_STRING) reduce 220) ((T_CONTINUE) reduce 220) ((T_DEC) reduce 220) ((T_DECLARE) reduce 220) ((T_DIR) reduce 220) ((T_DNUMBER) reduce 220) ((T_DO) reduce 220) ((T_DOUBLE_CAST) reduce 220) ((T_ECHO) reduce 220) ((T_ELSE) reduce 220) ((T_ELSEIF) reduce 220) ((T_EMPTY) reduce 220) ((T_ENUM) reduce 220) ((T_EVAL) reduce 220) ((T_EXIT) reduce 220) ((T_FILE) reduce 220) ((T_FINAL) reduce 220) ((T_FN) reduce 220) ((T_FOR) reduce 220) ((T_FOREACH) reduce 220) ((T_FUNCTION) reduce 220) ((T_FUNC_C) reduce 220) ((T_GLOBAL) reduce 220) ((T_GOTO) reduce 220) ((T_HALT_COMPILER) reduce 220) ((T_IF) reduce 220) ((T_INC) reduce 220) ((T_INCLUDE) reduce 220) ((T_INCLUDE_ONCE) reduce 220) ((T_INLINE_HTML) reduce 220) ((T_INTERFACE) reduce 220) ((T_INT_CAST) reduce 220) ((T_ISSET) reduce 220) ((T_LINE) reduce 220) ((T_LIST) reduce 220) ((T_LNUMBER) reduce 220) ((T_MATCH) reduce 220) ((T_METHOD_C) reduce 220) ((T_NAMESPACE) reduce 220) ((T_NAME_FULLY_QUALIFIED) reduce 220) ((T_NAME_QUALIFIED) reduce 220) ((T_NAME_RELATIVE) reduce 220) ((T_NEW) reduce 220) ((T_NS_C) reduce 220) ((T_OBJECT_CAST) reduce 220) ((T_PRINT) reduce 220) ((T_READONLY) reduce 220) ((T_REQUIRE) reduce 220) ((T_REQUIRE_ONCE) reduce 220) ((T_RETURN) reduce 220) ((T_START_HEREDOC) reduce 220) ((T_STATIC) reduce 220) ((T_STRING) reduce 220) ((T_STRING_CAST) reduce 220) ((T_SWITCH) reduce 220) ((T_THROW) reduce 220) ((T_TRAIT) reduce 220) ((T_TRAIT_C) reduce 220) ((T_TRY) reduce 220) ((T_UNSET) reduce 220) ((T_UNSET_CAST) reduce 220) ((T_USE) reduce 220) ((T_VARIABLE) reduce 220) ((T_WHILE) reduce 220) ((T_YIELD) reduce 220) ((T_YIELD_FROM) reduce 220) (("[") reduce 220) (("`") reduce 220) (("{") reduce 220) (("~") reduce 220)) 28427 ((("!") reduce 153) (("\"") reduce 153) (("$") reduce 153) (($) reduce 153) (("(") reduce 153) (("+") reduce 153) (("-") reduce 153) ((";") reduce 153) (("@") reduce 153) ((T_ABSTRACT) reduce 153) ((T_ARRAY) reduce 153) ((T_ARRAY_CAST) reduce 153) ((T_ATTRIBUTE) reduce 153) ((T_BOOL_CAST) reduce 153) ((T_BREAK) reduce 153) ((T_CLASS) reduce 153) ((T_CLASS_C) reduce 153) ((T_CLONE) reduce 153) ((T_CONST) reduce 153) ((T_CONSTANT_ENCAPSED_STRING) reduce 153) ((T_CONTINUE) reduce 153) ((T_DEC) reduce 153) ((T_DECLARE) reduce 153) ((T_DIR) reduce 153) ((T_DNUMBER) reduce 153) ((T_DO) reduce 153) ((T_DOUBLE_CAST) reduce 153) ((T_ECHO) reduce 153) ((T_ELSE) reduce 153) ((T_ELSEIF) reduce 153) ((T_EMPTY) reduce 153) ((T_ENUM) reduce 153) ((T_EVAL) reduce 153) ((T_EXIT) reduce 153) ((T_FILE) reduce 153) ((T_FINAL) reduce 153) ((T_FN) reduce 153) ((T_FOR) reduce 153) ((T_FOREACH) reduce 153) ((T_FUNCTION) reduce 153) ((T_FUNC_C) reduce 153) ((T_GLOBAL) reduce 153) ((T_GOTO) reduce 153) ((T_HALT_COMPILER) reduce 153) ((T_IF) reduce 153) ((T_INC) reduce 153) ((T_INCLUDE) reduce 153) ((T_INCLUDE_ONCE) reduce 153) ((T_INLINE_HTML) reduce 153) ((T_INTERFACE) reduce 153) ((T_INT_CAST) reduce 153) ((T_ISSET) reduce 153) ((T_LINE) reduce 153) ((T_LIST) reduce 153) ((T_LNUMBER) reduce 153) ((T_MATCH) reduce 153) ((T_METHOD_C) reduce 153) ((T_NAMESPACE) reduce 153) ((T_NAME_FULLY_QUALIFIED) reduce 153) ((T_NAME_QUALIFIED) reduce 153) ((T_NAME_RELATIVE) reduce 153) ((T_NEW) reduce 153) ((T_NS_C) reduce 153) ((T_OBJECT_CAST) reduce 153) ((T_PRINT) reduce 153) ((T_READONLY) reduce 153) ((T_REQUIRE) reduce 153) ((T_REQUIRE_ONCE) reduce 153) ((T_RETURN) reduce 153) ((T_START_HEREDOC) reduce 153) ((T_STATIC) reduce 153) ((T_STRING) reduce 153) ((T_STRING_CAST) reduce 153) ((T_SWITCH) reduce 153) ((T_THROW) reduce 153) ((T_TRAIT) reduce 153) ((T_TRAIT_C) reduce 153) ((T_TRY) reduce 153) ((T_UNSET) reduce 153) ((T_UNSET_CAST) reduce 153) ((T_USE) reduce 153) ((T_VARIABLE) reduce 153) ((T_WHILE) reduce 153) ((T_YIELD) reduce 153) ((T_YIELD_FROM) reduce 153) (("[") reduce 153) (("`") reduce 153) (("{") reduce 153) (("~") reduce 153)) 28429 ((("!") reduce 152) (("\"") reduce 152) (("$") reduce 152) (($) reduce 152) (("(") reduce 152) (("+") reduce 152) (("-") reduce 152) ((";") reduce 152) (("@") reduce 152) ((T_ABSTRACT) reduce 152) ((T_ARRAY) reduce 152) ((T_ARRAY_CAST) reduce 152) ((T_ATTRIBUTE) reduce 152) ((T_BOOL_CAST) reduce 152) ((T_BREAK) reduce 152) ((T_CLASS) reduce 152) ((T_CLASS_C) reduce 152) ((T_CLONE) reduce 152) ((T_CONST) reduce 152) ((T_CONSTANT_ENCAPSED_STRING) reduce 152) ((T_CONTINUE) reduce 152) ((T_DEC) reduce 152) ((T_DECLARE) reduce 152) ((T_DIR) reduce 152) ((T_DNUMBER) reduce 152) ((T_DO) reduce 152) ((T_DOUBLE_CAST) reduce 152) ((T_ECHO) reduce 152) ((T_ELSE) reduce 152) ((T_ELSEIF) reduce 152) ((T_EMPTY) reduce 152) ((T_ENUM) reduce 152) ((T_EVAL) reduce 152) ((T_EXIT) reduce 152) ((T_FILE) reduce 152) ((T_FINAL) reduce 152) ((T_FN) reduce 152) ((T_FOR) reduce 152) ((T_FOREACH) reduce 152) ((T_FUNCTION) reduce 152) ((T_FUNC_C) reduce 152) ((T_GLOBAL) reduce 152) ((T_GOTO) reduce 152) ((T_HALT_COMPILER) reduce 152) ((T_IF) reduce 152) ((T_INC) reduce 152) ((T_INCLUDE) reduce 152) ((T_INCLUDE_ONCE) reduce 152) ((T_INLINE_HTML) reduce 152) ((T_INTERFACE) reduce 152) ((T_INT_CAST) reduce 152) ((T_ISSET) reduce 152) ((T_LINE) reduce 152) ((T_LIST) reduce 152) ((T_LNUMBER) reduce 152) ((T_MATCH) reduce 152) ((T_METHOD_C) reduce 152) ((T_NAMESPACE) reduce 152) ((T_NAME_FULLY_QUALIFIED) reduce 152) ((T_NAME_QUALIFIED) reduce 152) ((T_NAME_RELATIVE) reduce 152) ((T_NEW) reduce 152) ((T_NS_C) reduce 152) ((T_OBJECT_CAST) reduce 152) ((T_PRINT) reduce 152) ((T_READONLY) reduce 152) ((T_REQUIRE) reduce 152) ((T_REQUIRE_ONCE) reduce 152) ((T_RETURN) reduce 152) ((T_START_HEREDOC) reduce 152) ((T_STATIC) reduce 152) ((T_STRING) reduce 152) ((T_STRING_CAST) reduce 152) ((T_SWITCH) reduce 152) ((T_THROW) reduce 152) ((T_TRAIT) reduce 152) ((T_TRAIT_C) reduce 152) ((T_TRY) reduce 152) ((T_UNSET) reduce 152) ((T_UNSET_CAST) reduce 152) ((T_USE) reduce 152) ((T_VARIABLE) reduce 152) ((T_WHILE) reduce 152) ((T_YIELD) reduce 152) ((T_YIELD_FROM) reduce 152) (("[") reduce 152) (("`") reduce 152) (("{") reduce 152) (("~") reduce 152)) 28432 ((("!") reduce 110) (("\"") reduce 110) (($) reduce 110) (("$") reduce 110) (("(") reduce 110) (("+") reduce 110) (("-") reduce 110) ((";") reduce 110) (("@") reduce 110) ((T_ABSTRACT) reduce 110) ((T_ARRAY) reduce 110) ((T_ARRAY_CAST) reduce 110) ((T_ATTRIBUTE) reduce 110) ((T_BOOL_CAST) reduce 110) ((T_BREAK) reduce 110) ((T_CLASS) reduce 110) ((T_CLASS_C) reduce 110) ((T_CLONE) reduce 110) ((T_CONST) reduce 110) ((T_CONSTANT_ENCAPSED_STRING) reduce 110) ((T_CONTINUE) reduce 110) ((T_DEC) reduce 110) ((T_DECLARE) reduce 110) ((T_DIR) reduce 110) ((T_DNUMBER) reduce 110) ((T_DO) reduce 110) ((T_DOUBLE_CAST) reduce 110) ((T_ECHO) reduce 110) ((T_EMPTY) reduce 110) ((T_ENUM) reduce 110) ((T_EVAL) reduce 110) ((T_EXIT) reduce 110) ((T_FILE) reduce 110) ((T_FINAL) reduce 110) ((T_FN) reduce 110) ((T_FOR) reduce 110) ((T_FOREACH) reduce 110) ((T_FUNCTION) reduce 110) ((T_FUNC_C) reduce 110) ((T_GLOBAL) reduce 110) ((T_GOTO) reduce 110) ((T_HALT_COMPILER) reduce 110) ((T_IF) reduce 110) ((T_INC) reduce 110) ((T_INCLUDE) reduce 110) ((T_INCLUDE_ONCE) reduce 110) ((T_INLINE_HTML) reduce 110) ((T_INTERFACE) reduce 110) ((T_INT_CAST) reduce 110) ((T_ISSET) reduce 110) ((T_LINE) reduce 110) ((T_LIST) reduce 110) ((T_LNUMBER) reduce 110) ((T_MATCH) reduce 110) ((T_METHOD_C) reduce 110) ((T_NAMESPACE) reduce 110) ((T_NAME_FULLY_QUALIFIED) reduce 110) ((T_NAME_QUALIFIED) reduce 110) ((T_NAME_RELATIVE) reduce 110) ((T_NEW) reduce 110) ((T_NS_C) reduce 110) ((T_OBJECT_CAST) reduce 110) ((T_PRINT) reduce 110) ((T_READONLY) reduce 110) ((T_REQUIRE) reduce 110) ((T_REQUIRE_ONCE) reduce 110) ((T_RETURN) reduce 110) ((T_START_HEREDOC) reduce 110) ((T_STATIC) reduce 110) ((T_STRING) reduce 110) ((T_STRING_CAST) reduce 110) ((T_SWITCH) reduce 110) ((T_THROW) reduce 110) ((T_TRAIT) reduce 110) ((T_TRAIT_C) reduce 110) ((T_TRY) reduce 110) ((T_UNSET) reduce 110) ((T_UNSET_CAST) reduce 110) ((T_USE) reduce 110) ((T_VARIABLE) reduce 110) ((T_WHILE) reduce 110) ((T_YIELD) reduce 110) ((T_YIELD_FROM) reduce 110) (("[") reduce 110) (("`") reduce 110) (("{") reduce 110) (("~") reduce 110)) 28434 ((("!") reduce 166) (("\"") reduce 166) (($) reduce 166) (("$") reduce 166) (("(") reduce 166) (("+") reduce 166) (("-") reduce 166) ((";") reduce 166) (("@") reduce 166) ((T_ABSTRACT) reduce 166) ((T_ARRAY) reduce 166) ((T_ARRAY_CAST) reduce 166) ((T_ATTRIBUTE) reduce 166) ((T_BOOL_CAST) reduce 166) ((T_BREAK) reduce 166) ((T_CLASS) reduce 166) ((T_CLASS_C) reduce 166) ((T_CLONE) reduce 166) ((T_CONST) reduce 166) ((T_CONSTANT_ENCAPSED_STRING) reduce 166) ((T_CONTINUE) reduce 166) ((T_DEC) reduce 166) ((T_DECLARE) reduce 166) ((T_DIR) reduce 166) ((T_DNUMBER) reduce 166) ((T_DO) reduce 166) ((T_DOUBLE_CAST) reduce 166) ((T_ECHO) reduce 166) ((T_EMPTY) reduce 166) ((T_ENUM) reduce 166) ((T_EVAL) reduce 166) ((T_EXIT) reduce 166) ((T_FILE) reduce 166) ((T_FINAL) reduce 166) ((T_FN) reduce 166) ((T_FOR) reduce 166) ((T_FOREACH) reduce 166) ((T_FUNCTION) reduce 166) ((T_FUNC_C) reduce 166) ((T_GLOBAL) reduce 166) ((T_GOTO) reduce 166) ((T_HALT_COMPILER) reduce 166) ((T_IF) reduce 166) ((T_INC) reduce 166) ((T_INCLUDE) reduce 166) ((T_INCLUDE_ONCE) reduce 166) ((T_INLINE_HTML) reduce 166) ((T_INTERFACE) reduce 166) ((T_INT_CAST) reduce 166) ((T_ISSET) reduce 166) ((T_LINE) reduce 166) ((T_LIST) reduce 166) ((T_LNUMBER) reduce 166) ((T_MATCH) reduce 166) ((T_METHOD_C) reduce 166) ((T_NAMESPACE) reduce 166) ((T_NAME_FULLY_QUALIFIED) reduce 166) ((T_NAME_QUALIFIED) reduce 166) ((T_NAME_RELATIVE) reduce 166) ((T_NEW) reduce 166) ((T_NS_C) reduce 166) ((T_OBJECT_CAST) reduce 166) ((T_PRINT) reduce 166) ((T_READONLY) reduce 166) ((T_REQUIRE) reduce 166) ((T_REQUIRE_ONCE) reduce 166) ((T_RETURN) reduce 166) ((T_START_HEREDOC) reduce 166) ((T_STATIC) reduce 166) ((T_STRING) reduce 166) ((T_STRING_CAST) reduce 166) ((T_SWITCH) reduce 166) ((T_THROW) reduce 166) ((T_TRAIT) reduce 166) ((T_TRAIT_C) reduce 166) ((T_TRY) reduce 166) ((T_UNSET) reduce 166) ((T_UNSET_CAST) reduce 166) ((T_USE) reduce 166) ((T_VARIABLE) reduce 166) ((T_WHILE) reduce 166) ((T_YIELD) reduce 166) ((T_YIELD_FROM) reduce 166) (("[") reduce 166) (("`") reduce 166) (("{") reduce 166) (("~") reduce 166)) 28436 ((("!") reduce 155) (("\"") reduce 155) (($) reduce 155) (("$") reduce 155) (("(") reduce 155) (("+") reduce 155) (("-") reduce 155) ((";") reduce 155) (("@") reduce 155) ((T_ABSTRACT) reduce 155) ((T_ARRAY) reduce 155) ((T_ARRAY_CAST) reduce 155) ((T_ATTRIBUTE) reduce 155) ((T_BOOL_CAST) reduce 155) ((T_BREAK) reduce 155) ((T_CLASS) reduce 155) ((T_CLASS_C) reduce 155) ((T_CLONE) reduce 155) ((T_CONST) reduce 155) ((T_CONSTANT_ENCAPSED_STRING) reduce 155) ((T_CONTINUE) reduce 155) ((T_DEC) reduce 155) ((T_DECLARE) reduce 155) ((T_DIR) reduce 155) ((T_DNUMBER) reduce 155) ((T_DO) reduce 155) ((T_DOUBLE_CAST) reduce 155) ((T_ECHO) reduce 155) ((T_EMPTY) reduce 155) ((T_ENUM) reduce 155) ((T_EVAL) reduce 155) ((T_EXIT) reduce 155) ((T_FILE) reduce 155) ((T_FINAL) reduce 155) ((T_FN) reduce 155) ((T_FOR) reduce 155) ((T_FOREACH) reduce 155) ((T_FUNCTION) reduce 155) ((T_FUNC_C) reduce 155) ((T_GLOBAL) reduce 155) ((T_GOTO) reduce 155) ((T_HALT_COMPILER) reduce 155) ((T_IF) reduce 155) ((T_INC) reduce 155) ((T_INCLUDE) reduce 155) ((T_INCLUDE_ONCE) reduce 155) ((T_INLINE_HTML) reduce 155) ((T_INTERFACE) reduce 155) ((T_INT_CAST) reduce 155) ((T_ISSET) reduce 155) ((T_LINE) reduce 155) ((T_LIST) reduce 155) ((T_LNUMBER) reduce 155) ((T_MATCH) reduce 155) ((T_METHOD_C) reduce 155) ((T_NAMESPACE) reduce 155) ((T_NAME_FULLY_QUALIFIED) reduce 155) ((T_NAME_QUALIFIED) reduce 155) ((T_NAME_RELATIVE) reduce 155) ((T_NEW) reduce 155) ((T_NS_C) reduce 155) ((T_OBJECT_CAST) reduce 155) ((T_PRINT) reduce 155) ((T_READONLY) reduce 155) ((T_REQUIRE) reduce 155) ((T_REQUIRE_ONCE) reduce 155) ((T_RETURN) reduce 155) ((T_START_HEREDOC) reduce 155) ((T_STATIC) reduce 155) ((T_STRING) reduce 155) ((T_STRING_CAST) reduce 155) ((T_SWITCH) reduce 155) ((T_THROW) reduce 155) ((T_TRAIT) reduce 155) ((T_TRAIT_C) reduce 155) ((T_TRY) reduce 155) ((T_UNSET) reduce 155) ((T_UNSET_CAST) reduce 155) ((T_USE) reduce 155) ((T_VARIABLE) reduce 155) ((T_WHILE) reduce 155) ((T_YIELD) reduce 155) ((T_YIELD_FROM) reduce 155) (("[") reduce 155) (("`") reduce 155) (("{") reduce 155) (("~") reduce 155)) 28446 ((("!") reduce 162) (("\"") reduce 162) (($) reduce 162) (("$") reduce 162) (("(") reduce 162) (("+") reduce 162) (("-") reduce 162) ((";") reduce 162) (("@") reduce 162) ((T_ABSTRACT) reduce 162) ((T_ARRAY) reduce 162) ((T_ARRAY_CAST) reduce 162) ((T_ATTRIBUTE) reduce 162) ((T_BOOL_CAST) reduce 162) ((T_BREAK) reduce 162) ((T_CLASS) reduce 162) ((T_CLASS_C) reduce 162) ((T_CLONE) reduce 162) ((T_CONST) reduce 162) ((T_CONSTANT_ENCAPSED_STRING) reduce 162) ((T_CONTINUE) reduce 162) ((T_DEC) reduce 162) ((T_DECLARE) reduce 162) ((T_DIR) reduce 162) ((T_DNUMBER) reduce 162) ((T_DO) reduce 162) ((T_DOUBLE_CAST) reduce 162) ((T_ECHO) reduce 162) ((T_EMPTY) reduce 162) ((T_ENUM) reduce 162) ((T_EVAL) reduce 162) ((T_EXIT) reduce 162) ((T_FILE) reduce 162) ((T_FINAL) reduce 162) ((T_FN) reduce 162) ((T_FOR) reduce 162) ((T_FOREACH) reduce 162) ((T_FUNCTION) reduce 162) ((T_FUNC_C) reduce 162) ((T_GLOBAL) reduce 162) ((T_GOTO) reduce 162) ((T_HALT_COMPILER) reduce 162) ((T_IF) reduce 162) ((T_INC) reduce 162) ((T_INCLUDE) reduce 162) ((T_INCLUDE_ONCE) reduce 162) ((T_INLINE_HTML) reduce 162) ((T_INTERFACE) reduce 162) ((T_INT_CAST) reduce 162) ((T_ISSET) reduce 162) ((T_LINE) reduce 162) ((T_LIST) reduce 162) ((T_LNUMBER) reduce 162) ((T_MATCH) reduce 162) ((T_METHOD_C) reduce 162) ((T_NAMESPACE) reduce 162) ((T_NAME_FULLY_QUALIFIED) reduce 162) ((T_NAME_QUALIFIED) reduce 162) ((T_NAME_RELATIVE) reduce 162) ((T_NEW) reduce 162) ((T_NS_C) reduce 162) ((T_OBJECT_CAST) reduce 162) ((T_PRINT) reduce 162) ((T_READONLY) reduce 162) ((T_REQUIRE) reduce 162) ((T_REQUIRE_ONCE) reduce 162) ((T_RETURN) reduce 162) ((T_START_HEREDOC) reduce 162) ((T_STATIC) reduce 162) ((T_STRING) reduce 162) ((T_STRING_CAST) reduce 162) ((T_SWITCH) reduce 162) ((T_THROW) reduce 162) ((T_TRAIT) reduce 162) ((T_TRAIT_C) reduce 162) ((T_TRY) reduce 162) ((T_UNSET) reduce 162) ((T_UNSET_CAST) reduce 162) ((T_USE) reduce 162) ((T_VARIABLE) reduce 162) ((T_WHILE) reduce 162) ((T_YIELD) reduce 162) ((T_YIELD_FROM) reduce 162) (("[") reduce 162) (("`") reduce 162) (("{") reduce 162) (("~") reduce 162)) 28447 ((("!") reduce 217) (("\"") reduce 217) (("$") reduce 217) (($) reduce 217) (("(") reduce 217) (("+") reduce 217) (("-") reduce 217) ((";") reduce 217) (("@") reduce 217) ((T_ABSTRACT) reduce 217) ((T_ARRAY) reduce 217) ((T_ARRAY_CAST) reduce 217) ((T_ATTRIBUTE) reduce 217) ((T_BOOL_CAST) reduce 217) ((T_BREAK) reduce 217) ((T_CLASS) reduce 217) ((T_CLASS_C) reduce 217) ((T_CLONE) reduce 217) ((T_CONST) reduce 217) ((T_CONSTANT_ENCAPSED_STRING) reduce 217) ((T_CONTINUE) reduce 217) ((T_DEC) reduce 217) ((T_DECLARE) reduce 217) ((T_DIR) reduce 217) ((T_DNUMBER) reduce 217) ((T_DO) reduce 217) ((T_DOUBLE_CAST) reduce 217) ((T_ECHO) reduce 217) ((T_EMPTY) reduce 217) ((T_ENUM) reduce 217) ((T_EVAL) reduce 217) ((T_EXIT) reduce 217) ((T_FILE) reduce 217) ((T_FINAL) reduce 217) ((T_FN) reduce 217) ((T_FOR) reduce 217) ((T_FOREACH) reduce 217) ((T_FUNCTION) reduce 217) ((T_FUNC_C) reduce 217) ((T_GLOBAL) reduce 217) ((T_GOTO) reduce 217) ((T_HALT_COMPILER) reduce 217) ((T_IF) reduce 217) ((T_INC) reduce 217) ((T_INCLUDE) reduce 217) ((T_INCLUDE_ONCE) reduce 217) ((T_INLINE_HTML) reduce 217) ((T_INTERFACE) reduce 217) ((T_INT_CAST) reduce 217) ((T_ISSET) reduce 217) ((T_LINE) reduce 217) ((T_LIST) reduce 217) ((T_LNUMBER) reduce 217) ((T_MATCH) reduce 217) ((T_METHOD_C) reduce 217) ((T_NAMESPACE) reduce 217) ((T_NAME_FULLY_QUALIFIED) reduce 217) ((T_NAME_QUALIFIED) reduce 217) ((T_NAME_RELATIVE) reduce 217) ((T_NEW) reduce 217) ((T_NS_C) reduce 217) ((T_OBJECT_CAST) reduce 217) ((T_PRINT) reduce 217) ((T_READONLY) reduce 217) ((T_REQUIRE) reduce 217) ((T_REQUIRE_ONCE) reduce 217) ((T_RETURN) reduce 217) ((T_START_HEREDOC) reduce 217) ((T_STATIC) reduce 217) ((T_STRING) reduce 217) ((T_STRING_CAST) reduce 217) ((T_SWITCH) reduce 217) ((T_THROW) reduce 217) ((T_TRAIT) reduce 217) ((T_TRAIT_C) reduce 217) ((T_TRY) reduce 217) ((T_UNSET) reduce 217) ((T_UNSET_CAST) reduce 217) ((T_USE) reduce 217) ((T_VARIABLE) reduce 217) ((T_WHILE) reduce 217) ((T_YIELD) reduce 217) ((T_YIELD_FROM) reduce 217) (("[") reduce 217) (("`") reduce 217) (("{") reduce 217) (("~") reduce 217)) 28450 ((("!") reduce 218) (("\"") reduce 218) (($) reduce 218) (("$") reduce 218) (("(") reduce 218) (("+") reduce 218) (("-") reduce 218) ((";") reduce 218) (("@") reduce 218) ((T_ABSTRACT) reduce 218) ((T_ARRAY) reduce 218) ((T_ARRAY_CAST) reduce 218) ((T_ATTRIBUTE) reduce 218) ((T_BOOL_CAST) reduce 218) ((T_BREAK) reduce 218) ((T_CLASS) reduce 218) ((T_CLASS_C) reduce 218) ((T_CLONE) reduce 218) ((T_CONST) reduce 218) ((T_CONSTANT_ENCAPSED_STRING) reduce 218) ((T_CONTINUE) reduce 218) ((T_DEC) reduce 218) ((T_DECLARE) reduce 218) ((T_DIR) reduce 218) ((T_DNUMBER) reduce 218) ((T_DO) reduce 218) ((T_DOUBLE_CAST) reduce 218) ((T_ECHO) reduce 218) ((T_EMPTY) reduce 218) ((T_ENUM) reduce 218) ((T_EVAL) reduce 218) ((T_EXIT) reduce 218) ((T_FILE) reduce 218) ((T_FINAL) reduce 218) ((T_FN) reduce 218) ((T_FOR) reduce 218) ((T_FOREACH) reduce 218) ((T_FUNCTION) reduce 218) ((T_FUNC_C) reduce 218) ((T_GLOBAL) reduce 218) ((T_GOTO) reduce 218) ((T_HALT_COMPILER) reduce 218) ((T_IF) reduce 218) ((T_INC) reduce 218) ((T_INCLUDE) reduce 218) ((T_INCLUDE_ONCE) reduce 218) ((T_INLINE_HTML) reduce 218) ((T_INTERFACE) reduce 218) ((T_INT_CAST) reduce 218) ((T_ISSET) reduce 218) ((T_LINE) reduce 218) ((T_LIST) reduce 218) ((T_LNUMBER) reduce 218) ((T_MATCH) reduce 218) ((T_METHOD_C) reduce 218) ((T_NAMESPACE) reduce 218) ((T_NAME_FULLY_QUALIFIED) reduce 218) ((T_NAME_QUALIFIED) reduce 218) ((T_NAME_RELATIVE) reduce 218) ((T_NEW) reduce 218) ((T_NS_C) reduce 218) ((T_OBJECT_CAST) reduce 218) ((T_PRINT) reduce 218) ((T_READONLY) reduce 218) ((T_REQUIRE) reduce 218) ((T_REQUIRE_ONCE) reduce 218) ((T_RETURN) reduce 218) ((T_START_HEREDOC) reduce 218) ((T_STATIC) reduce 218) ((T_STRING) reduce 218) ((T_STRING_CAST) reduce 218) ((T_SWITCH) reduce 218) ((T_THROW) reduce 218) ((T_TRAIT) reduce 218) ((T_TRAIT_C) reduce 218) ((T_TRY) reduce 218) ((T_UNSET) reduce 218) ((T_UNSET_CAST) reduce 218) ((T_USE) reduce 218) ((T_VARIABLE) reduce 218) ((T_WHILE) reduce 218) ((T_YIELD) reduce 218) ((T_YIELD_FROM) reduce 218) (("[") reduce 218) (("`") reduce 218) (("{") reduce 218) (("~") reduce 218)) 28451 ((("!") reduce 161) (("\"") reduce 161) (($) reduce 161) (("$") reduce 161) (("(") reduce 161) (("+") reduce 161) (("-") reduce 161) ((";") reduce 161) (("@") reduce 161) ((T_ABSTRACT) reduce 161) ((T_ARRAY) reduce 161) ((T_ARRAY_CAST) reduce 161) ((T_ATTRIBUTE) reduce 161) ((T_BOOL_CAST) reduce 161) ((T_BREAK) reduce 161) ((T_CLASS) reduce 161) ((T_CLASS_C) reduce 161) ((T_CLONE) reduce 161) ((T_CONST) reduce 161) ((T_CONSTANT_ENCAPSED_STRING) reduce 161) ((T_CONTINUE) reduce 161) ((T_DEC) reduce 161) ((T_DECLARE) reduce 161) ((T_DIR) reduce 161) ((T_DNUMBER) reduce 161) ((T_DO) reduce 161) ((T_DOUBLE_CAST) reduce 161) ((T_ECHO) reduce 161) ((T_EMPTY) reduce 161) ((T_ENUM) reduce 161) ((T_EVAL) reduce 161) ((T_EXIT) reduce 161) ((T_FILE) reduce 161) ((T_FINAL) reduce 161) ((T_FN) reduce 161) ((T_FOR) reduce 161) ((T_FOREACH) reduce 161) ((T_FUNCTION) reduce 161) ((T_FUNC_C) reduce 161) ((T_GLOBAL) reduce 161) ((T_GOTO) reduce 161) ((T_HALT_COMPILER) reduce 161) ((T_IF) reduce 161) ((T_INC) reduce 161) ((T_INCLUDE) reduce 161) ((T_INCLUDE_ONCE) reduce 161) ((T_INLINE_HTML) reduce 161) ((T_INTERFACE) reduce 161) ((T_INT_CAST) reduce 161) ((T_ISSET) reduce 161) ((T_LINE) reduce 161) ((T_LIST) reduce 161) ((T_LNUMBER) reduce 161) ((T_MATCH) reduce 161) ((T_METHOD_C) reduce 161) ((T_NAMESPACE) reduce 161) ((T_NAME_FULLY_QUALIFIED) reduce 161) ((T_NAME_QUALIFIED) reduce 161) ((T_NAME_RELATIVE) reduce 161) ((T_NEW) reduce 161) ((T_NS_C) reduce 161) ((T_OBJECT_CAST) reduce 161) ((T_PRINT) reduce 161) ((T_READONLY) reduce 161) ((T_REQUIRE) reduce 161) ((T_REQUIRE_ONCE) reduce 161) ((T_RETURN) reduce 161) ((T_START_HEREDOC) reduce 161) ((T_STATIC) reduce 161) ((T_STRING) reduce 161) ((T_STRING_CAST) reduce 161) ((T_SWITCH) reduce 161) ((T_THROW) reduce 161) ((T_TRAIT) reduce 161) ((T_TRAIT_C) reduce 161) ((T_TRY) reduce 161) ((T_UNSET) reduce 161) ((T_UNSET_CAST) reduce 161) ((T_USE) reduce 161) ((T_VARIABLE) reduce 161) ((T_WHILE) reduce 161) ((T_YIELD) reduce 161) ((T_YIELD_FROM) reduce 161) (("[") reduce 161) (("`") reduce 161) (("{") reduce 161) (("~") reduce 161)) 28460 ((("!") reduce 150) (("\"") reduce 150) (($) reduce 150) (("$") reduce 150) (("(") reduce 150) (("+") reduce 150) (("-") reduce 150) ((";") reduce 150) (("@") reduce 150) ((T_ABSTRACT) reduce 150) ((T_ARRAY) reduce 150) ((T_ARRAY_CAST) reduce 150) ((T_ATTRIBUTE) reduce 150) ((T_BOOL_CAST) reduce 150) ((T_BREAK) reduce 150) ((T_CLASS) reduce 150) ((T_CLASS_C) reduce 150) ((T_CLONE) reduce 150) ((T_CONST) reduce 150) ((T_CONSTANT_ENCAPSED_STRING) reduce 150) ((T_CONTINUE) reduce 150) ((T_DEC) reduce 150) ((T_DECLARE) reduce 150) ((T_DIR) reduce 150) ((T_DNUMBER) reduce 150) ((T_DO) reduce 150) ((T_DOUBLE_CAST) reduce 150) ((T_ECHO) reduce 150) ((T_EMPTY) reduce 150) ((T_ENUM) reduce 150) ((T_EVAL) reduce 150) ((T_EXIT) reduce 150) ((T_FILE) reduce 150) ((T_FINAL) reduce 150) ((T_FN) reduce 150) ((T_FOR) reduce 150) ((T_FOREACH) reduce 150) ((T_FUNCTION) reduce 150) ((T_FUNC_C) reduce 150) ((T_GLOBAL) reduce 150) ((T_GOTO) reduce 150) ((T_HALT_COMPILER) reduce 150) ((T_IF) reduce 150) ((T_INC) reduce 150) ((T_INCLUDE) reduce 150) ((T_INCLUDE_ONCE) reduce 150) ((T_INLINE_HTML) reduce 150) ((T_INTERFACE) reduce 150) ((T_INT_CAST) reduce 150) ((T_ISSET) reduce 150) ((T_LINE) reduce 150) ((T_LIST) reduce 150) ((T_LNUMBER) reduce 150) ((T_MATCH) reduce 150) ((T_METHOD_C) reduce 150) ((T_NAMESPACE) reduce 150) ((T_NAME_FULLY_QUALIFIED) reduce 150) ((T_NAME_QUALIFIED) reduce 150) ((T_NAME_RELATIVE) reduce 150) ((T_NEW) reduce 150) ((T_NS_C) reduce 150) ((T_OBJECT_CAST) reduce 150) ((T_PRINT) reduce 150) ((T_READONLY) reduce 150) ((T_REQUIRE) reduce 150) ((T_REQUIRE_ONCE) reduce 150) ((T_RETURN) reduce 150) ((T_START_HEREDOC) reduce 150) ((T_STATIC) reduce 150) ((T_STRING) reduce 150) ((T_STRING_CAST) reduce 150) ((T_SWITCH) reduce 150) ((T_THROW) reduce 150) ((T_TRAIT) reduce 150) ((T_TRAIT_C) reduce 150) ((T_TRY) reduce 150) ((T_UNSET) reduce 150) ((T_UNSET_CAST) reduce 150) ((T_USE) reduce 150) ((T_VARIABLE) reduce 150) ((T_WHILE) reduce 150) ((T_YIELD) reduce 150) ((T_YIELD_FROM) reduce 150) (("[") reduce 150) (("`") reduce 150) (("{") reduce 150) (("~") reduce 150)) 28461 ((("!") reduce 215) (("\"") reduce 215) (("$") reduce 215) (($) reduce 215) (("(") reduce 215) (("+") reduce 215) (("-") reduce 215) ((";") reduce 215) (("@") reduce 215) ((T_ABSTRACT) reduce 215) ((T_ARRAY) reduce 215) ((T_ARRAY_CAST) reduce 215) ((T_ATTRIBUTE) reduce 215) ((T_BOOL_CAST) reduce 215) ((T_BREAK) reduce 215) ((T_CLASS) reduce 215) ((T_CLASS_C) reduce 215) ((T_CLONE) reduce 215) ((T_CONST) reduce 215) ((T_CONSTANT_ENCAPSED_STRING) reduce 215) ((T_CONTINUE) reduce 215) ((T_DEC) reduce 215) ((T_DECLARE) reduce 215) ((T_DIR) reduce 215) ((T_DNUMBER) reduce 215) ((T_DO) reduce 215) ((T_DOUBLE_CAST) reduce 215) ((T_ECHO) reduce 215) ((T_EMPTY) reduce 215) ((T_ENUM) reduce 215) ((T_EVAL) reduce 215) ((T_EXIT) reduce 215) ((T_FILE) reduce 215) ((T_FINAL) reduce 215) ((T_FN) reduce 215) ((T_FOR) reduce 215) ((T_FOREACH) reduce 215) ((T_FUNCTION) reduce 215) ((T_FUNC_C) reduce 215) ((T_GLOBAL) reduce 215) ((T_GOTO) reduce 215) ((T_HALT_COMPILER) reduce 215) ((T_IF) reduce 215) ((T_INC) reduce 215) ((T_INCLUDE) reduce 215) ((T_INCLUDE_ONCE) reduce 215) ((T_INLINE_HTML) reduce 215) ((T_INTERFACE) reduce 215) ((T_INT_CAST) reduce 215) ((T_ISSET) reduce 215) ((T_LINE) reduce 215) ((T_LIST) reduce 215) ((T_LNUMBER) reduce 215) ((T_MATCH) reduce 215) ((T_METHOD_C) reduce 215) ((T_NAMESPACE) reduce 215) ((T_NAME_FULLY_QUALIFIED) reduce 215) ((T_NAME_QUALIFIED) reduce 215) ((T_NAME_RELATIVE) reduce 215) ((T_NEW) reduce 215) ((T_NS_C) reduce 215) ((T_OBJECT_CAST) reduce 215) ((T_PRINT) reduce 215) ((T_READONLY) reduce 215) ((T_REQUIRE) reduce 215) ((T_REQUIRE_ONCE) reduce 215) ((T_RETURN) reduce 215) ((T_START_HEREDOC) reduce 215) ((T_STATIC) reduce 215) ((T_STRING) reduce 215) ((T_STRING_CAST) reduce 215) ((T_SWITCH) reduce 215) ((T_THROW) reduce 215) ((T_TRAIT) reduce 215) ((T_TRAIT_C) reduce 215) ((T_TRY) reduce 215) ((T_UNSET) reduce 215) ((T_UNSET_CAST) reduce 215) ((T_USE) reduce 215) ((T_VARIABLE) reduce 215) ((T_WHILE) reduce 215) ((T_YIELD) reduce 215) ((T_YIELD_FROM) reduce 215) (("[") reduce 215) (("`") reduce 215) (("{") reduce 215) (("~") reduce 215)) 28464 ((("!") reduce 216) (("\"") reduce 216) (($) reduce 216) (("$") reduce 216) (("(") reduce 216) (("+") reduce 216) (("-") reduce 216) ((";") reduce 216) (("@") reduce 216) ((T_ABSTRACT) reduce 216) ((T_ARRAY) reduce 216) ((T_ARRAY_CAST) reduce 216) ((T_ATTRIBUTE) reduce 216) ((T_BOOL_CAST) reduce 216) ((T_BREAK) reduce 216) ((T_CLASS) reduce 216) ((T_CLASS_C) reduce 216) ((T_CLONE) reduce 216) ((T_CONST) reduce 216) ((T_CONSTANT_ENCAPSED_STRING) reduce 216) ((T_CONTINUE) reduce 216) ((T_DEC) reduce 216) ((T_DECLARE) reduce 216) ((T_DIR) reduce 216) ((T_DNUMBER) reduce 216) ((T_DO) reduce 216) ((T_DOUBLE_CAST) reduce 216) ((T_ECHO) reduce 216) ((T_EMPTY) reduce 216) ((T_ENUM) reduce 216) ((T_EVAL) reduce 216) ((T_EXIT) reduce 216) ((T_FILE) reduce 216) ((T_FINAL) reduce 216) ((T_FN) reduce 216) ((T_FOR) reduce 216) ((T_FOREACH) reduce 216) ((T_FUNCTION) reduce 216) ((T_FUNC_C) reduce 216) ((T_GLOBAL) reduce 216) ((T_GOTO) reduce 216) ((T_HALT_COMPILER) reduce 216) ((T_IF) reduce 216) ((T_INC) reduce 216) ((T_INCLUDE) reduce 216) ((T_INCLUDE_ONCE) reduce 216) ((T_INLINE_HTML) reduce 216) ((T_INTERFACE) reduce 216) ((T_INT_CAST) reduce 216) ((T_ISSET) reduce 216) ((T_LINE) reduce 216) ((T_LIST) reduce 216) ((T_LNUMBER) reduce 216) ((T_MATCH) reduce 216) ((T_METHOD_C) reduce 216) ((T_NAMESPACE) reduce 216) ((T_NAME_FULLY_QUALIFIED) reduce 216) ((T_NAME_QUALIFIED) reduce 216) ((T_NAME_RELATIVE) reduce 216) ((T_NEW) reduce 216) ((T_NS_C) reduce 216) ((T_OBJECT_CAST) reduce 216) ((T_PRINT) reduce 216) ((T_READONLY) reduce 216) ((T_REQUIRE) reduce 216) ((T_REQUIRE_ONCE) reduce 216) ((T_RETURN) reduce 216) ((T_START_HEREDOC) reduce 216) ((T_STATIC) reduce 216) ((T_STRING) reduce 216) ((T_STRING_CAST) reduce 216) ((T_SWITCH) reduce 216) ((T_THROW) reduce 216) ((T_TRAIT) reduce 216) ((T_TRAIT_C) reduce 216) ((T_TRY) reduce 216) ((T_UNSET) reduce 216) ((T_UNSET_CAST) reduce 216) ((T_USE) reduce 216) ((T_VARIABLE) reduce 216) ((T_WHILE) reduce 216) ((T_YIELD) reduce 216) ((T_YIELD_FROM) reduce 216) (("[") reduce 216) (("`") reduce 216) (("{") reduce 216) (("~") reduce 216)) 28478 ((("!") reduce 199) (("\"") reduce 199) (($) reduce 199) (("$") reduce 199) (("(") reduce 199) (("+") reduce 199) (("-") reduce 199) ((";") reduce 199) (("@") reduce 199) ((T_ABSTRACT) reduce 199) ((T_ARRAY) reduce 199) ((T_ARRAY_CAST) reduce 199) ((T_ATTRIBUTE) reduce 199) ((T_BOOL_CAST) reduce 199) ((T_BREAK) reduce 199) ((T_CLASS) reduce 199) ((T_CLASS_C) reduce 199) ((T_CLONE) reduce 199) ((T_CONST) reduce 199) ((T_CONSTANT_ENCAPSED_STRING) reduce 199) ((T_CONTINUE) reduce 199) ((T_DEC) reduce 199) ((T_DECLARE) reduce 199) ((T_DIR) reduce 199) ((T_DNUMBER) reduce 199) ((T_DO) reduce 199) ((T_DOUBLE_CAST) reduce 199) ((T_ECHO) reduce 199) ((T_EMPTY) reduce 199) ((T_ENUM) reduce 199) ((T_EVAL) reduce 199) ((T_EXIT) reduce 199) ((T_FILE) reduce 199) ((T_FINAL) reduce 199) ((T_FN) reduce 199) ((T_FOR) reduce 199) ((T_FOREACH) reduce 199) ((T_FUNCTION) reduce 199) ((T_FUNC_C) reduce 199) ((T_GLOBAL) reduce 199) ((T_GOTO) reduce 199) ((T_HALT_COMPILER) reduce 199) ((T_IF) reduce 199) ((T_INC) reduce 199) ((T_INCLUDE) reduce 199) ((T_INCLUDE_ONCE) reduce 199) ((T_INLINE_HTML) reduce 199) ((T_INTERFACE) reduce 199) ((T_INT_CAST) reduce 199) ((T_ISSET) reduce 199) ((T_LINE) reduce 199) ((T_LIST) reduce 199) ((T_LNUMBER) reduce 199) ((T_MATCH) reduce 199) ((T_METHOD_C) reduce 199) ((T_NAMESPACE) reduce 199) ((T_NAME_FULLY_QUALIFIED) reduce 199) ((T_NAME_QUALIFIED) reduce 199) ((T_NAME_RELATIVE) reduce 199) ((T_NEW) reduce 199) ((T_NS_C) reduce 199) ((T_OBJECT_CAST) reduce 199) ((T_PRINT) reduce 199) ((T_READONLY) reduce 199) ((T_REQUIRE) reduce 199) ((T_REQUIRE_ONCE) reduce 199) ((T_RETURN) reduce 199) ((T_START_HEREDOC) reduce 199) ((T_STATIC) reduce 199) ((T_STRING) reduce 199) ((T_STRING_CAST) reduce 199) ((T_SWITCH) reduce 199) ((T_THROW) reduce 199) ((T_TRAIT) reduce 199) ((T_TRAIT_C) reduce 199) ((T_TRY) reduce 199) ((T_UNSET) reduce 199) ((T_UNSET_CAST) reduce 199) ((T_USE) reduce 199) ((T_VARIABLE) reduce 199) ((T_WHILE) reduce 199) ((T_YIELD) reduce 199) ((T_YIELD_FROM) reduce 199) (("[") reduce 199) (("`") reduce 199) (("{") reduce 199) (("~") reduce 199)) 28483 ((("!") reduce 157) (("\"") reduce 157) (($) reduce 157) (("$") reduce 157) (("(") reduce 157) (("+") reduce 157) (("-") reduce 157) ((";") reduce 157) (("@") reduce 157) ((T_ABSTRACT) reduce 157) ((T_ARRAY) reduce 157) ((T_ARRAY_CAST) reduce 157) ((T_ATTRIBUTE) reduce 157) ((T_BOOL_CAST) reduce 157) ((T_BREAK) reduce 157) ((T_CLASS) reduce 157) ((T_CLASS_C) reduce 157) ((T_CLONE) reduce 157) ((T_CONST) reduce 157) ((T_CONSTANT_ENCAPSED_STRING) reduce 157) ((T_CONTINUE) reduce 157) ((T_DEC) reduce 157) ((T_DECLARE) reduce 157) ((T_DIR) reduce 157) ((T_DNUMBER) reduce 157) ((T_DO) reduce 157) ((T_DOUBLE_CAST) reduce 157) ((T_ECHO) reduce 157) ((T_EMPTY) reduce 157) ((T_ENUM) reduce 157) ((T_EVAL) reduce 157) ((T_EXIT) reduce 157) ((T_FILE) reduce 157) ((T_FINAL) reduce 157) ((T_FN) reduce 157) ((T_FOR) reduce 157) ((T_FOREACH) reduce 157) ((T_FUNCTION) reduce 157) ((T_FUNC_C) reduce 157) ((T_GLOBAL) reduce 157) ((T_GOTO) reduce 157) ((T_HALT_COMPILER) reduce 157) ((T_IF) reduce 157) ((T_INC) reduce 157) ((T_INCLUDE) reduce 157) ((T_INCLUDE_ONCE) reduce 157) ((T_INLINE_HTML) reduce 157) ((T_INTERFACE) reduce 157) ((T_INT_CAST) reduce 157) ((T_ISSET) reduce 157) ((T_LINE) reduce 157) ((T_LIST) reduce 157) ((T_LNUMBER) reduce 157) ((T_MATCH) reduce 157) ((T_METHOD_C) reduce 157) ((T_NAMESPACE) reduce 157) ((T_NAME_FULLY_QUALIFIED) reduce 157) ((T_NAME_QUALIFIED) reduce 157) ((T_NAME_RELATIVE) reduce 157) ((T_NEW) reduce 157) ((T_NS_C) reduce 157) ((T_OBJECT_CAST) reduce 157) ((T_PRINT) reduce 157) ((T_READONLY) reduce 157) ((T_REQUIRE) reduce 157) ((T_REQUIRE_ONCE) reduce 157) ((T_RETURN) reduce 157) ((T_START_HEREDOC) reduce 157) ((T_STATIC) reduce 157) ((T_STRING) reduce 157) ((T_STRING_CAST) reduce 157) ((T_SWITCH) reduce 157) ((T_THROW) reduce 157) ((T_TRAIT) reduce 157) ((T_TRAIT_C) reduce 157) ((T_TRY) reduce 157) ((T_UNSET) reduce 157) ((T_UNSET_CAST) reduce 157) ((T_USE) reduce 157) ((T_VARIABLE) reduce 157) ((T_WHILE) reduce 157) ((T_YIELD) reduce 157) ((T_YIELD_FROM) reduce 157) (("[") reduce 157) (("`") reduce 157) (("{") reduce 157) (("~") reduce 157)) 28490 ((("!") reduce 149) (("\"") reduce 149) (($) reduce 149) (("$") reduce 149) (("(") reduce 149) (("+") reduce 149) (("-") reduce 149) ((";") reduce 149) (("@") reduce 149) ((T_ABSTRACT) reduce 149) ((T_ARRAY) reduce 149) ((T_ARRAY_CAST) reduce 149) ((T_ATTRIBUTE) reduce 149) ((T_BOOL_CAST) reduce 149) ((T_BREAK) reduce 149) ((T_CLASS) reduce 149) ((T_CLASS_C) reduce 149) ((T_CLONE) reduce 149) ((T_CONST) reduce 149) ((T_CONSTANT_ENCAPSED_STRING) reduce 149) ((T_CONTINUE) reduce 149) ((T_DEC) reduce 149) ((T_DECLARE) reduce 149) ((T_DIR) reduce 149) ((T_DNUMBER) reduce 149) ((T_DO) reduce 149) ((T_DOUBLE_CAST) reduce 149) ((T_ECHO) reduce 149) ((T_EMPTY) reduce 149) ((T_ENUM) reduce 149) ((T_EVAL) reduce 149) ((T_EXIT) reduce 149) ((T_FILE) reduce 149) ((T_FINAL) reduce 149) ((T_FN) reduce 149) ((T_FOR) reduce 149) ((T_FOREACH) reduce 149) ((T_FUNCTION) reduce 149) ((T_FUNC_C) reduce 149) ((T_GLOBAL) reduce 149) ((T_GOTO) reduce 149) ((T_HALT_COMPILER) reduce 149) ((T_IF) reduce 149) ((T_INC) reduce 149) ((T_INCLUDE) reduce 149) ((T_INCLUDE_ONCE) reduce 149) ((T_INLINE_HTML) reduce 149) ((T_INTERFACE) reduce 149) ((T_INT_CAST) reduce 149) ((T_ISSET) reduce 149) ((T_LINE) reduce 149) ((T_LIST) reduce 149) ((T_LNUMBER) reduce 149) ((T_MATCH) reduce 149) ((T_METHOD_C) reduce 149) ((T_NAMESPACE) reduce 149) ((T_NAME_FULLY_QUALIFIED) reduce 149) ((T_NAME_QUALIFIED) reduce 149) ((T_NAME_RELATIVE) reduce 149) ((T_NEW) reduce 149) ((T_NS_C) reduce 149) ((T_OBJECT_CAST) reduce 149) ((T_PRINT) reduce 149) ((T_READONLY) reduce 149) ((T_REQUIRE) reduce 149) ((T_REQUIRE_ONCE) reduce 149) ((T_RETURN) reduce 149) ((T_START_HEREDOC) reduce 149) ((T_STATIC) reduce 149) ((T_STRING) reduce 149) ((T_STRING_CAST) reduce 149) ((T_SWITCH) reduce 149) ((T_THROW) reduce 149) ((T_TRAIT) reduce 149) ((T_TRAIT_C) reduce 149) ((T_TRY) reduce 149) ((T_UNSET) reduce 149) ((T_UNSET_CAST) reduce 149) ((T_USE) reduce 149) ((T_VARIABLE) reduce 149) ((T_WHILE) reduce 149) ((T_YIELD) reduce 149) ((T_YIELD_FROM) reduce 149) (("[") reduce 149) (("`") reduce 149) (("{") reduce 149) (("~") reduce 149)) 28495 ((("!") reduce 163) (("\"") reduce 163) (($) reduce 163) (("$") reduce 163) (("(") reduce 163) (("+") reduce 163) (("-") reduce 163) ((";") reduce 163) (("@") reduce 163) ((T_ABSTRACT) reduce 163) ((T_ARRAY) reduce 163) ((T_ARRAY_CAST) reduce 163) ((T_ATTRIBUTE) reduce 163) ((T_BOOL_CAST) reduce 163) ((T_BREAK) reduce 163) ((T_CLASS) reduce 163) ((T_CLASS_C) reduce 163) ((T_CLONE) reduce 163) ((T_CONST) reduce 163) ((T_CONSTANT_ENCAPSED_STRING) reduce 163) ((T_CONTINUE) reduce 163) ((T_DEC) reduce 163) ((T_DECLARE) reduce 163) ((T_DIR) reduce 163) ((T_DNUMBER) reduce 163) ((T_DO) reduce 163) ((T_DOUBLE_CAST) reduce 163) ((T_ECHO) reduce 163) ((T_EMPTY) reduce 163) ((T_ENUM) reduce 163) ((T_EVAL) reduce 163) ((T_EXIT) reduce 163) ((T_FILE) reduce 163) ((T_FINAL) reduce 163) ((T_FN) reduce 163) ((T_FOR) reduce 163) ((T_FOREACH) reduce 163) ((T_FUNCTION) reduce 163) ((T_FUNC_C) reduce 163) ((T_GLOBAL) reduce 163) ((T_GOTO) reduce 163) ((T_HALT_COMPILER) reduce 163) ((T_IF) reduce 163) ((T_INC) reduce 163) ((T_INCLUDE) reduce 163) ((T_INCLUDE_ONCE) reduce 163) ((T_INLINE_HTML) reduce 163) ((T_INTERFACE) reduce 163) ((T_INT_CAST) reduce 163) ((T_ISSET) reduce 163) ((T_LINE) reduce 163) ((T_LIST) reduce 163) ((T_LNUMBER) reduce 163) ((T_MATCH) reduce 163) ((T_METHOD_C) reduce 163) ((T_NAMESPACE) reduce 163) ((T_NAME_FULLY_QUALIFIED) reduce 163) ((T_NAME_QUALIFIED) reduce 163) ((T_NAME_RELATIVE) reduce 163) ((T_NEW) reduce 163) ((T_NS_C) reduce 163) ((T_OBJECT_CAST) reduce 163) ((T_PRINT) reduce 163) ((T_READONLY) reduce 163) ((T_REQUIRE) reduce 163) ((T_REQUIRE_ONCE) reduce 163) ((T_RETURN) reduce 163) ((T_START_HEREDOC) reduce 163) ((T_STATIC) reduce 163) ((T_STRING) reduce 163) ((T_STRING_CAST) reduce 163) ((T_SWITCH) reduce 163) ((T_THROW) reduce 163) ((T_TRAIT) reduce 163) ((T_TRAIT_C) reduce 163) ((T_TRY) reduce 163) ((T_UNSET) reduce 163) ((T_UNSET_CAST) reduce 163) ((T_USE) reduce 163) ((T_VARIABLE) reduce 163) ((T_WHILE) reduce 163) ((T_YIELD) reduce 163) ((T_YIELD_FROM) reduce 163) (("[") reduce 163) (("`") reduce 163) (("{") reduce 163) (("~") reduce 163)) 28496 ((("!") reduce 219) (("\"") reduce 219) (("$") reduce 219) (($) reduce 219) (("(") reduce 219) (("+") reduce 219) (("-") reduce 219) ((";") reduce 219) (("@") reduce 219) ((T_ABSTRACT) reduce 219) ((T_ARRAY) reduce 219) ((T_ARRAY_CAST) reduce 219) ((T_ATTRIBUTE) reduce 219) ((T_BOOL_CAST) reduce 219) ((T_BREAK) reduce 219) ((T_CLASS) reduce 219) ((T_CLASS_C) reduce 219) ((T_CLONE) reduce 219) ((T_CONST) reduce 219) ((T_CONSTANT_ENCAPSED_STRING) reduce 219) ((T_CONTINUE) reduce 219) ((T_DEC) reduce 219) ((T_DECLARE) reduce 219) ((T_DIR) reduce 219) ((T_DNUMBER) reduce 219) ((T_DO) reduce 219) ((T_DOUBLE_CAST) reduce 219) ((T_ECHO) reduce 219) ((T_EMPTY) reduce 219) ((T_ENUM) reduce 219) ((T_EVAL) reduce 219) ((T_EXIT) reduce 219) ((T_FILE) reduce 219) ((T_FINAL) reduce 219) ((T_FN) reduce 219) ((T_FOR) reduce 219) ((T_FOREACH) reduce 219) ((T_FUNCTION) reduce 219) ((T_FUNC_C) reduce 219) ((T_GLOBAL) reduce 219) ((T_GOTO) reduce 219) ((T_HALT_COMPILER) reduce 219) ((T_IF) reduce 219) ((T_INC) reduce 219) ((T_INCLUDE) reduce 219) ((T_INCLUDE_ONCE) reduce 219) ((T_INLINE_HTML) reduce 219) ((T_INTERFACE) reduce 219) ((T_INT_CAST) reduce 219) ((T_ISSET) reduce 219) ((T_LINE) reduce 219) ((T_LIST) reduce 219) ((T_LNUMBER) reduce 219) ((T_MATCH) reduce 219) ((T_METHOD_C) reduce 219) ((T_NAMESPACE) reduce 219) ((T_NAME_FULLY_QUALIFIED) reduce 219) ((T_NAME_QUALIFIED) reduce 219) ((T_NAME_RELATIVE) reduce 219) ((T_NEW) reduce 219) ((T_NS_C) reduce 219) ((T_OBJECT_CAST) reduce 219) ((T_PRINT) reduce 219) ((T_READONLY) reduce 219) ((T_REQUIRE) reduce 219) ((T_REQUIRE_ONCE) reduce 219) ((T_RETURN) reduce 219) ((T_START_HEREDOC) reduce 219) ((T_STATIC) reduce 219) ((T_STRING) reduce 219) ((T_STRING_CAST) reduce 219) ((T_SWITCH) reduce 219) ((T_THROW) reduce 219) ((T_TRAIT) reduce 219) ((T_TRAIT_C) reduce 219) ((T_TRY) reduce 219) ((T_UNSET) reduce 219) ((T_UNSET_CAST) reduce 219) ((T_USE) reduce 219) ((T_VARIABLE) reduce 219) ((T_WHILE) reduce 219) ((T_YIELD) reduce 219) ((T_YIELD_FROM) reduce 219) (("[") reduce 219) (("`") reduce 219) (("{") reduce 219) (("~") reduce 219)) 28499 ((("!") reduce 220) (("\"") reduce 220) (($) reduce 220) (("$") reduce 220) (("(") reduce 220) (("+") reduce 220) (("-") reduce 220) ((";") reduce 220) (("@") reduce 220) ((T_ABSTRACT) reduce 220) ((T_ARRAY) reduce 220) ((T_ARRAY_CAST) reduce 220) ((T_ATTRIBUTE) reduce 220) ((T_BOOL_CAST) reduce 220) ((T_BREAK) reduce 220) ((T_CLASS) reduce 220) ((T_CLASS_C) reduce 220) ((T_CLONE) reduce 220) ((T_CONST) reduce 220) ((T_CONSTANT_ENCAPSED_STRING) reduce 220) ((T_CONTINUE) reduce 220) ((T_DEC) reduce 220) ((T_DECLARE) reduce 220) ((T_DIR) reduce 220) ((T_DNUMBER) reduce 220) ((T_DO) reduce 220) ((T_DOUBLE_CAST) reduce 220) ((T_ECHO) reduce 220) ((T_EMPTY) reduce 220) ((T_ENUM) reduce 220) ((T_EVAL) reduce 220) ((T_EXIT) reduce 220) ((T_FILE) reduce 220) ((T_FINAL) reduce 220) ((T_FN) reduce 220) ((T_FOR) reduce 220) ((T_FOREACH) reduce 220) ((T_FUNCTION) reduce 220) ((T_FUNC_C) reduce 220) ((T_GLOBAL) reduce 220) ((T_GOTO) reduce 220) ((T_HALT_COMPILER) reduce 220) ((T_IF) reduce 220) ((T_INC) reduce 220) ((T_INCLUDE) reduce 220) ((T_INCLUDE_ONCE) reduce 220) ((T_INLINE_HTML) reduce 220) ((T_INTERFACE) reduce 220) ((T_INT_CAST) reduce 220) ((T_ISSET) reduce 220) ((T_LINE) reduce 220) ((T_LIST) reduce 220) ((T_LNUMBER) reduce 220) ((T_MATCH) reduce 220) ((T_METHOD_C) reduce 220) ((T_NAMESPACE) reduce 220) ((T_NAME_FULLY_QUALIFIED) reduce 220) ((T_NAME_QUALIFIED) reduce 220) ((T_NAME_RELATIVE) reduce 220) ((T_NEW) reduce 220) ((T_NS_C) reduce 220) ((T_OBJECT_CAST) reduce 220) ((T_PRINT) reduce 220) ((T_READONLY) reduce 220) ((T_REQUIRE) reduce 220) ((T_REQUIRE_ONCE) reduce 220) ((T_RETURN) reduce 220) ((T_START_HEREDOC) reduce 220) ((T_STATIC) reduce 220) ((T_STRING) reduce 220) ((T_STRING_CAST) reduce 220) ((T_SWITCH) reduce 220) ((T_THROW) reduce 220) ((T_TRAIT) reduce 220) ((T_TRAIT_C) reduce 220) ((T_TRY) reduce 220) ((T_UNSET) reduce 220) ((T_UNSET_CAST) reduce 220) ((T_USE) reduce 220) ((T_VARIABLE) reduce 220) ((T_WHILE) reduce 220) ((T_YIELD) reduce 220) ((T_YIELD_FROM) reduce 220) (("[") reduce 220) (("`") reduce 220) (("{") reduce 220) (("~") reduce 220)) 28502 ((("!") reduce 153) (("\"") reduce 153) (($) reduce 153) (("$") reduce 153) (("(") reduce 153) (("+") reduce 153) (("-") reduce 153) ((";") reduce 153) (("@") reduce 153) ((T_ABSTRACT) reduce 153) ((T_ARRAY) reduce 153) ((T_ARRAY_CAST) reduce 153) ((T_ATTRIBUTE) reduce 153) ((T_BOOL_CAST) reduce 153) ((T_BREAK) reduce 153) ((T_CLASS) reduce 153) ((T_CLASS_C) reduce 153) ((T_CLONE) reduce 153) ((T_CONST) reduce 153) ((T_CONSTANT_ENCAPSED_STRING) reduce 153) ((T_CONTINUE) reduce 153) ((T_DEC) reduce 153) ((T_DECLARE) reduce 153) ((T_DIR) reduce 153) ((T_DNUMBER) reduce 153) ((T_DO) reduce 153) ((T_DOUBLE_CAST) reduce 153) ((T_ECHO) reduce 153) ((T_EMPTY) reduce 153) ((T_ENUM) reduce 153) ((T_EVAL) reduce 153) ((T_EXIT) reduce 153) ((T_FILE) reduce 153) ((T_FINAL) reduce 153) ((T_FN) reduce 153) ((T_FOR) reduce 153) ((T_FOREACH) reduce 153) ((T_FUNCTION) reduce 153) ((T_FUNC_C) reduce 153) ((T_GLOBAL) reduce 153) ((T_GOTO) reduce 153) ((T_HALT_COMPILER) reduce 153) ((T_IF) reduce 153) ((T_INC) reduce 153) ((T_INCLUDE) reduce 153) ((T_INCLUDE_ONCE) reduce 153) ((T_INLINE_HTML) reduce 153) ((T_INTERFACE) reduce 153) ((T_INT_CAST) reduce 153) ((T_ISSET) reduce 153) ((T_LINE) reduce 153) ((T_LIST) reduce 153) ((T_LNUMBER) reduce 153) ((T_MATCH) reduce 153) ((T_METHOD_C) reduce 153) ((T_NAMESPACE) reduce 153) ((T_NAME_FULLY_QUALIFIED) reduce 153) ((T_NAME_QUALIFIED) reduce 153) ((T_NAME_RELATIVE) reduce 153) ((T_NEW) reduce 153) ((T_NS_C) reduce 153) ((T_OBJECT_CAST) reduce 153) ((T_PRINT) reduce 153) ((T_READONLY) reduce 153) ((T_REQUIRE) reduce 153) ((T_REQUIRE_ONCE) reduce 153) ((T_RETURN) reduce 153) ((T_START_HEREDOC) reduce 153) ((T_STATIC) reduce 153) ((T_STRING) reduce 153) ((T_STRING_CAST) reduce 153) ((T_SWITCH) reduce 153) ((T_THROW) reduce 153) ((T_TRAIT) reduce 153) ((T_TRAIT_C) reduce 153) ((T_TRY) reduce 153) ((T_UNSET) reduce 153) ((T_UNSET_CAST) reduce 153) ((T_USE) reduce 153) ((T_VARIABLE) reduce 153) ((T_WHILE) reduce 153) ((T_YIELD) reduce 153) ((T_YIELD_FROM) reduce 153) (("[") reduce 153) (("`") reduce 153) (("{") reduce 153) (("~") reduce 153)) 28504 ((("!") reduce 118) (("\"") reduce 118) (("$") reduce 118) (($) reduce 118) (("(") reduce 118) (("+") reduce 118) (("-") reduce 118) ((";") reduce 118) (("@") reduce 118) ((T_ABSTRACT) reduce 118) ((T_ARRAY) reduce 118) ((T_ARRAY_CAST) reduce 118) ((T_ATTRIBUTE) reduce 118) ((T_BOOL_CAST) reduce 118) ((T_BREAK) reduce 118) ((T_CLASS) reduce 118) ((T_CLASS_C) reduce 118) ((T_CLONE) reduce 118) ((T_CONST) reduce 118) ((T_CONSTANT_ENCAPSED_STRING) reduce 118) ((T_CONTINUE) reduce 118) ((T_DEC) reduce 118) ((T_DECLARE) reduce 118) ((T_DIR) reduce 118) ((T_DNUMBER) reduce 118) ((T_DO) reduce 118) ((T_DOUBLE_CAST) reduce 118) ((T_ECHO) reduce 118) ((T_EMPTY) reduce 118) ((T_ENUM) reduce 118) ((T_EVAL) reduce 118) ((T_EXIT) reduce 118) ((T_FILE) reduce 118) ((T_FINAL) reduce 118) ((T_FN) reduce 118) ((T_FOR) reduce 118) ((T_FOREACH) reduce 118) ((T_FUNCTION) reduce 118) ((T_FUNC_C) reduce 118) ((T_GLOBAL) reduce 118) ((T_GOTO) reduce 118) ((T_HALT_COMPILER) reduce 118) ((T_IF) reduce 118) ((T_INC) reduce 118) ((T_INCLUDE) reduce 118) ((T_INCLUDE_ONCE) reduce 118) ((T_INLINE_HTML) reduce 118) ((T_INTERFACE) reduce 118) ((T_INT_CAST) reduce 118) ((T_ISSET) reduce 118) ((T_LINE) reduce 118) ((T_LIST) reduce 118) ((T_LNUMBER) reduce 118) ((T_MATCH) reduce 118) ((T_METHOD_C) reduce 118) ((T_NAMESPACE) reduce 118) ((T_NAME_FULLY_QUALIFIED) reduce 118) ((T_NAME_QUALIFIED) reduce 118) ((T_NAME_RELATIVE) reduce 118) ((T_NEW) reduce 118) ((T_NS_C) reduce 118) ((T_OBJECT_CAST) reduce 118) ((T_PRINT) reduce 118) ((T_READONLY) reduce 118) ((T_REQUIRE) reduce 118) ((T_REQUIRE_ONCE) reduce 118) ((T_RETURN) reduce 118) ((T_START_HEREDOC) reduce 118) ((T_STATIC) reduce 118) ((T_STRING) reduce 118) ((T_STRING_CAST) reduce 118) ((T_SWITCH) reduce 118) ((T_THROW) reduce 118) ((T_TRAIT) reduce 118) ((T_TRAIT_C) reduce 118) ((T_TRY) reduce 118) ((T_UNSET) reduce 118) ((T_UNSET_CAST) reduce 118) ((T_USE) reduce 118) ((T_VARIABLE) reduce 118) ((T_WHILE) reduce 118) ((T_YIELD) reduce 118) ((T_YIELD_FROM) reduce 118) (("[") reduce 118) (("`") reduce 118) (("{") reduce 118) (("~") reduce 118)) 28512 ((("!") reduce 187) (("\"") reduce 187) (($) reduce 187) (("$") reduce 187) (("(") reduce 187) (("+") reduce 187) (("-") reduce 187) ((";") reduce 187) (("@") reduce 187) ((T_ABSTRACT) reduce 187) ((T_ARRAY) reduce 187) ((T_ARRAY_CAST) reduce 187) ((T_ATTRIBUTE) reduce 187) ((T_BOOL_CAST) reduce 187) ((T_BREAK) reduce 187) ((T_CLASS) reduce 187) ((T_CLASS_C) reduce 187) ((T_CLONE) reduce 187) ((T_CONST) reduce 187) ((T_CONSTANT_ENCAPSED_STRING) reduce 187) ((T_CONTINUE) reduce 187) ((T_DEC) reduce 187) ((T_DECLARE) reduce 187) ((T_DIR) reduce 187) ((T_DNUMBER) reduce 187) ((T_DO) reduce 187) ((T_DOUBLE_CAST) reduce 187) ((T_ECHO) reduce 187) ((T_EMPTY) reduce 187) ((T_ENUM) reduce 187) ((T_EVAL) reduce 187) ((T_EXIT) reduce 187) ((T_FILE) reduce 187) ((T_FINAL) reduce 187) ((T_FN) reduce 187) ((T_FOR) reduce 187) ((T_FOREACH) reduce 187) ((T_FUNCTION) reduce 187) ((T_FUNC_C) reduce 187) ((T_GLOBAL) reduce 187) ((T_GOTO) reduce 187) ((T_HALT_COMPILER) reduce 187) ((T_IF) reduce 187) ((T_INC) reduce 187) ((T_INCLUDE) reduce 187) ((T_INCLUDE_ONCE) reduce 187) ((T_INLINE_HTML) reduce 187) ((T_INTERFACE) reduce 187) ((T_INT_CAST) reduce 187) ((T_ISSET) reduce 187) ((T_LINE) reduce 187) ((T_LIST) reduce 187) ((T_LNUMBER) reduce 187) ((T_MATCH) reduce 187) ((T_METHOD_C) reduce 187) ((T_NAMESPACE) reduce 187) ((T_NAME_FULLY_QUALIFIED) reduce 187) ((T_NAME_QUALIFIED) reduce 187) ((T_NAME_RELATIVE) reduce 187) ((T_NEW) reduce 187) ((T_NS_C) reduce 187) ((T_OBJECT_CAST) reduce 187) ((T_PRINT) reduce 187) ((T_READONLY) reduce 187) ((T_REQUIRE) reduce 187) ((T_REQUIRE_ONCE) reduce 187) ((T_RETURN) reduce 187) ((T_START_HEREDOC) reduce 187) ((T_STATIC) reduce 187) ((T_STRING) reduce 187) ((T_STRING_CAST) reduce 187) ((T_SWITCH) reduce 187) ((T_THROW) reduce 187) ((T_TRAIT) reduce 187) ((T_TRAIT_C) reduce 187) ((T_TRY) reduce 187) ((T_UNSET) reduce 187) ((T_UNSET_CAST) reduce 187) ((T_USE) reduce 187) ((T_VARIABLE) reduce 187) ((T_WHILE) reduce 187) ((T_YIELD) reduce 187) ((T_YIELD_FROM) reduce 187) (("[") reduce 187) (("`") reduce 187) (("{") reduce 187) (("~") reduce 187)) 28514 ((("!") reduce 152) (("\"") reduce 152) (($) reduce 152) (("$") reduce 152) (("(") reduce 152) (("+") reduce 152) (("-") reduce 152) ((";") reduce 152) (("@") reduce 152) ((T_ABSTRACT) reduce 152) ((T_ARRAY) reduce 152) ((T_ARRAY_CAST) reduce 152) ((T_ATTRIBUTE) reduce 152) ((T_BOOL_CAST) reduce 152) ((T_BREAK) reduce 152) ((T_CLASS) reduce 152) ((T_CLASS_C) reduce 152) ((T_CLONE) reduce 152) ((T_CONST) reduce 152) ((T_CONSTANT_ENCAPSED_STRING) reduce 152) ((T_CONTINUE) reduce 152) ((T_DEC) reduce 152) ((T_DECLARE) reduce 152) ((T_DIR) reduce 152) ((T_DNUMBER) reduce 152) ((T_DO) reduce 152) ((T_DOUBLE_CAST) reduce 152) ((T_ECHO) reduce 152) ((T_EMPTY) reduce 152) ((T_ENUM) reduce 152) ((T_EVAL) reduce 152) ((T_EXIT) reduce 152) ((T_FILE) reduce 152) ((T_FINAL) reduce 152) ((T_FN) reduce 152) ((T_FOR) reduce 152) ((T_FOREACH) reduce 152) ((T_FUNCTION) reduce 152) ((T_FUNC_C) reduce 152) ((T_GLOBAL) reduce 152) ((T_GOTO) reduce 152) ((T_HALT_COMPILER) reduce 152) ((T_IF) reduce 152) ((T_INC) reduce 152) ((T_INCLUDE) reduce 152) ((T_INCLUDE_ONCE) reduce 152) ((T_INLINE_HTML) reduce 152) ((T_INTERFACE) reduce 152) ((T_INT_CAST) reduce 152) ((T_ISSET) reduce 152) ((T_LINE) reduce 152) ((T_LIST) reduce 152) ((T_LNUMBER) reduce 152) ((T_MATCH) reduce 152) ((T_METHOD_C) reduce 152) ((T_NAMESPACE) reduce 152) ((T_NAME_FULLY_QUALIFIED) reduce 152) ((T_NAME_QUALIFIED) reduce 152) ((T_NAME_RELATIVE) reduce 152) ((T_NEW) reduce 152) ((T_NS_C) reduce 152) ((T_OBJECT_CAST) reduce 152) ((T_PRINT) reduce 152) ((T_READONLY) reduce 152) ((T_REQUIRE) reduce 152) ((T_REQUIRE_ONCE) reduce 152) ((T_RETURN) reduce 152) ((T_START_HEREDOC) reduce 152) ((T_STATIC) reduce 152) ((T_STRING) reduce 152) ((T_STRING_CAST) reduce 152) ((T_SWITCH) reduce 152) ((T_THROW) reduce 152) ((T_TRAIT) reduce 152) ((T_TRAIT_C) reduce 152) ((T_TRY) reduce 152) ((T_UNSET) reduce 152) ((T_UNSET_CAST) reduce 152) ((T_USE) reduce 152) ((T_VARIABLE) reduce 152) ((T_WHILE) reduce 152) ((T_YIELD) reduce 152) ((T_YIELD_FROM) reduce 152) (("[") reduce 152) (("`") reduce 152) (("{") reduce 152) (("~") reduce 152)) 28518 (((T_ABSTRACT) reduce 99) ((T_ATTRIBUTE) reduce 99) ((T_CLASS) reduce 99) ((T_ENUM) reduce 99) ((T_FINAL) reduce 99) ((T_FN) reduce 99) ((T_FUNCTION) reduce 99) ((T_INTERFACE) reduce 99) ((T_READONLY) reduce 99) ((T_STATIC) reduce 99) ((T_TRAIT) reduce 99))))
  "The generated distinct action-tables.")

(defvar
  phps-mode-parser--goto-tables
  #s(hash-table size 42072 test equal rehash-size 1.5 rehash-threshold 0.8125 data (0 0 1 1 2 2 3 3 4 4 5 5 6 6 7 7 8 8 9 9 10 8 11 10 12 11 13 12 14 13 15 14 16 15 17 8 18 16 19 17 20 8 21 18 22 19 23 20 24 8 25 8 26 21 27 22 28 23 29 24 30 25 31 26 32 27 33 8 34 8 35 8 36 28 37 29 38 8 39 8 40 30 41 31 42 32 43 33 44 34 45 35 46 36 47 8 48 37 49 38 50 39 51 8 52 40 53 8 54 41 55 8 56 42 57 8 58 8 59 8 60 43 61 8 62 44 63 45 64 46 65 47 66 48 67 49 68 50 69 51 70 52 71 53 72 54 73 55 74 56 75 8 76 57 77 58 78 59 79 60 80 8 81 61 82 62 83 63 84 64 85 65 86 8 87 66 88 67 89 8 90 8 91 68 92 69 93 8 94 8 95 8 96 8 97 70 98 71 99 8 100 8 101 8 102 72 103 73 104 8 105 74 106 8 107 8 108 8 109 75 110 8 111 8 112 8 113 8 114 76 115 8 116 8 117 8 118 8 119 8 120 8 121 8 122 77 123 78 124 79 125 80 126 81 127 8 128 46 129 82 130 8 131 8 132 83 133 84 134 85 135 8 136 8 137 8 138 86 139 87 140 88 141 8 142 89 143 8 144 8 145 8 146 8 147 8 148 8 149 8 150 8 151 90 152 8 153 91 154 92 155 93 156 8 157 94 158 95 159 96 160 97 161 98 162 99 163 100 164 101 165 102 166 8 167 103 168 104 169 105 170 106 171 107 172 108 173 109 174 110 175 111 176 112 177 113 178 114 179 115 180 8 181 116 182 117 183 118 184 119 185 120 186 121 187 122 188 123 189 124 190 8 191 125 192 8 193 126 194 8 195 127 196 8 197 128 198 129 199 8 200 8 201 130 202 8 203 8 204 8 205 8 206 131 207 132 208 8 209 133 210 8 211 134 212 135 213 136 214 137 215 138 216 139 217 140 218 141 219 142 220 143 221 144 222 145 223 146 224 8 225 147 226 8 227 148 228 8 229 8 230 149 231 150 232 151 233 152 234 8 235 8 236 153 237 154 238 155 239 156 240 157 241 8 242 158 243 8 244 159 245 8 246 8 247 8 248 8 249 160 250 8 251 161 252 162 253 163 254 164 255 165 256 166 257 167 258 8 259 168 260 169 261 8 262 170 263 8 264 171 265 172 266 173 267 174 268 175 269 176 270 177 271 8 272 8 273 178 274 8 275 8 276 179 277 180 278 181 279 8 280 8 281 8 282 8 283 182 284 8 285 8 286 8 287 8 288 183 289 184 290 185 291 186 292 187 293 188 294 189 295 190 296 191 297 192 298 193 299 194 300 195 301 196 302 197 303 198 304 199 305 200 306 201 307 202 308 203 309 204 310 205 311 206 312 207 313 208 314 209 315 210 316 211 317 212 318 213 319 214 320 215 321 216 322 186 323 186 324 186 325 186 326 186 327 186 328 186 329 186 330 186 331 186 332 186 333 186 334 186 335 186 336 186 337 217 338 218 339 8 340 8 341 8 342 8 343 8 344 8 345 219 346 8 347 8 348 220 349 8 350 221 351 222 352 223 353 224 354 225 355 226 356 227 357 228 358 229 359 230 360 231 361 232 362 233 363 234 364 235 365 8 366 236 367 8 368 237 369 8 370 8 371 238 372 239 373 240 374 241 375 8 376 8 377 242 378 243 379 244 380 245 381 246 382 8 383 247 384 8 385 248 386 8 387 8 388 8 389 8 390 249 391 8 392 250 393 251 394 252 395 253 396 254 397 255 398 256 399 8 400 257 401 258 402 8 403 259 404 8 405 260 406 261 407 262 408 263 409 264 410 265 411 266 412 8 413 8 414 267 415 8 416 8 417 268 418 269 419 270 420 8 421 8 422 8 423 8 424 271 425 8 426 8 427 8 428 8 429 272 430 273 431 274 432 275 433 276 434 277 435 278 436 279 437 280 438 281 439 282 440 283 441 284 442 285 443 286 444 287 445 288 446 289 447 290 448 291 449 292 450 293 451 294 452 295 453 296 454 297 455 298 456 299 457 300 458 301 459 302 460 303 461 304 462 305 463 275 464 275 465 275 466 275 467 275 468 275 469 275 470 275 471 275 472 275 473 275 474 275 475 275 476 275 477 275 478 306 479 307 480 8 481 8 482 8 483 8 484 8 485 8 486 308 487 8 488 8 489 309 490 8 491 310 492 311 493 312 494 313 495 314 496 315 497 8 498 316 499 317 500 318 501 319 502 320 503 321 504 322 505 323 506 324 507 325 508 8 509 326 510 8 511 327 512 8 513 8 514 328 515 329 516 330 517 331 518 8 519 8 520 332 521 333 522 334 523 335 524 336 525 8 526 337 527 8 528 338 529 8 530 8 531 8 532 8 533 339 534 8 535 340 536 341 537 342 538 343 539 344 540 345 541 346 542 8 543 347 544 348 545 8 546 349 547 8 548 350 549 351 550 352 551 353 552 354 553 355 554 356 555 8 556 8 557 357 558 8 559 8 560 358 561 359 562 360 563 8 564 8 565 8 566 8 567 361 568 8 569 362 570 8 571 8 572 8 573 363 574 364 575 365 576 358 577 366 578 367 579 368 580 369 581 370 582 371 583 372 584 373 585 374 586 375 587 376 588 377 589 378 590 379 591 380 592 381 593 382 594 383 595 384 596 385 597 386 598 387 599 388 600 389 601 390 602 391 603 392 604 393 605 394 606 395 607 358 608 358 609 358 610 358 611 358 612 358 613 358 614 358 615 358 616 358 617 358 618 358 619 358 620 358 621 358 622 396 623 397 624 8 625 8 626 8 627 8 628 8 629 8 630 398 631 8 632 8 633 399 634 8 635 400 636 401 637 402 638 403 639 404 640 405 641 8 642 406 643 8 644 8 645 8 646 8 647 8 648 407 649 408 650 8 651 8 652 409 653 8 654 410 655 8 656 8 657 411 658 412 659 8 660 358 661 358 662 358 663 358 664 358 665 413 666 414 667 415 668 416 669 417 670 418 671 419 672 420 673 421 674 422 675 423 676 8 677 424 678 8 679 425 680 8 681 8 682 426 683 427 684 428 685 429 686 8 687 8 688 430 689 431 690 432 691 433 692 434 693 8 694 435 695 8 696 436 697 8 698 8 699 8 700 8 701 437 702 8 703 438 704 439 705 440 706 441 707 442 708 443 709 444 710 8 711 445 712 446 713 8 714 447 715 8 716 448 717 449 718 450 719 451 720 452 721 453 722 454 723 8 724 8 725 455 726 8 727 8 728 456 729 457 730 458 731 8 732 8 733 8 734 8 735 459 736 8 737 8 738 8 739 8 740 460 741 461 742 462 743 463 744 464 745 465 746 466 747 467 748 468 749 469 750 470 751 471 752 472 753 473 754 474 755 475 756 476 757 477 758 478 759 479 760 480 761 481 762 482 763 483 764 484 765 485 766 486 767 487 768 488 769 489 770 490 771 491 772 492 773 493 774 463 775 463 776 463 777 463 778 463 779 463 780 463 781 463 782 463 783 463 784 463 785 463 786 463 787 463 788 463 789 494 790 495 791 8 792 8 793 8 794 8 795 8 796 8 797 496 798 8 799 8 800 497 801 8 802 498 803 499 804 500 805 501 806 502 807 503 808 8 809 504 810 8 811 8 812 8 813 8 814 8 815 505 816 506 817 8 818 8 819 507 820 8 821 508 822 8 823 8 824 509 825 510 826 8 827 463 828 463 829 463 830 463 831 463 832 511 833 512 834 513 835 463 836 463 837 463 838 463 839 463 840 463 841 463 842 463 843 463 844 463 845 514 846 8 847 8 848 8 849 8 850 8 851 8 852 8 853 8 854 8 855 8 856 8 857 8 858 8 859 8 860 8 861 8 862 8 863 8 864 8 865 8 866 8 867 8 868 8 869 8 870 8 871 8 872 8 873 8 874 8 875 8 876 8 877 8 878 8 879 8 880 8 881 8 882 8 883 8 884 8 885 8 886 8 887 8 888 8 889 8 890 8 891 8 892 8 893 8 894 8 895 8 896 8 897 8 898 8 899 8 900 8 901 8 902 8 903 8 904 8 905 8 906 8 907 8 908 8 909 8 910 8 911 8 912 8 913 8 914 8 915 8 916 8 917 8 918 8 919 8 920 8 921 8 922 8 923 8 924 8 925 515 926 8 927 8 928 8 929 516 930 517 931 8 932 518 933 8 934 519 935 520 936 521 937 522 938 8 939 523 940 524 941 525 942 8 943 526 944 527 945 8 946 528 947 8 948 8 949 8 950 8 951 8 952 8 953 529 954 8 955 8 956 8 957 530 958 8 959 8 960 8 961 8 962 8 963 531 964 8 965 532 966 8 967 8 968 533 969 8 970 8 971 8 972 8 973 8 974 8 975 8 976 534 977 535 978 8 979 8 980 8 981 8 982 8 983 8 984 8 985 8 986 8 987 8 988 8 989 8 990 8 991 536 992 537 993 538 994 8 995 8 996 8 997 539 998 540 999 8 1000 541 1001 8 1002 8 1003 8 1004 8 1005 542 1006 8 1007 8 1008 8 1009 8 1010 8 1011 543 1012 8 1013 544 1014 545 1015 8 1016 8 1017 8 1018 546 1019 547 1020 548 1021 8 1022 549 1023 550 1024 8 1025 551 1026 8 1027 552 1028 8 1029 8 1030 8 1031 8 1032 553 1033 8 1034 8 1035 8 1036 8 1037 554 1038 555 1039 556 1040 557 1041 8 1042 558 1043 559 1044 560 1045 8 1046 8 1047 561 1048 8 1049 8 1050 562 1051 563 1052 564 1053 8 1054 565 1055 8 1056 8 1057 8 1058 566 1059 8 1060 567 1061 8 1062 8 1063 8 1064 8 1065 8 1066 568 1067 569 1068 570 1069 526 1070 8 1071 529 1072 8 1073 533 1074 534 1075 535 1076 8 1077 8 1078 537 1079 538 1080 540 1081 8 1082 541 1083 542 1084 8 1085 543 1086 8 1087 545 1088 546 1089 547 1090 548 1091 550 1092 8 1093 552 1094 8 1095 554 1096 562 1097 571 1098 572 1099 573 1100 574 1101 575 1102 576 1103 577 1104 578 1105 579 1106 580 1107 581 1108 582 1109 583 1110 584 1111 585 1112 586 1113 587 1114 588 1115 589 1116 590 1117 591 1118 592 1119 593 1120 594 1121 595 1122 596 1123 597 1124 598 1125 599 1126 600 1127 562 1128 562 1129 562 1130 562 1131 562 1132 562 1133 562 1134 562 1135 562 1136 562 1137 562 1138 562 1139 562 1140 562 1141 562 1142 601 1143 602 1144 8 1145 8 1146 8 1147 8 1148 8 1149 8 1150 603 1151 8 1152 8 1153 604 1154 8 1155 605 1156 606 1157 607 1158 608 1159 609 1160 610 1161 8 1162 611 1163 8 1164 8 1165 8 1166 8 1167 8 1168 612 1169 613 1170 8 1171 8 1172 614 1173 8 1174 615 1175 8 1176 8 1177 616 1178 617 1179 8 1180 562 1181 562 1182 562 1183 562 1184 562 1185 618 1186 619 1187 620 1188 562 1189 562 1190 562 1191 562 1192 562 1193 562 1194 562 1195 562 1196 562 1197 562 1198 621 1199 622 1200 623 1201 624 1202 625 1203 626 1204 627 1205 628 1206 629 1207 630 1208 8 1209 631 1210 8 1211 632 1212 8 1213 8 1214 633 1215 634 1216 635 1217 636 1218 8 1219 8 1220 637 1221 638 1222 639 1223 640 1224 641 1225 8 1226 642 1227 8 1228 643 1229 8 1230 8 1231 8 1232 8 1233 644 1234 8 1235 645 1236 646 1237 647 1238 648 1239 649 1240 650 1241 651 1242 8 1243 652 1244 653 1245 8 1246 654 1247 8 1248 655 1249 656 1250 657 1251 658 1252 659 1253 660 1254 661 1255 8 1256 8 1257 662 1258 8 1259 8 1260 663 1261 664 1262 665 1263 8 1264 8 1265 8 1266 8 1267 666 1268 8 1269 8 1270 8 1271 8 1272 667 1273 668 1274 669 1275 670 1276 671 1277 672 1278 673 1279 674 1280 675 1281 676 1282 677 1283 678 1284 679 1285 680 1286 681 1287 682 1288 683 1289 684 1290 685 1291 686 1292 687 1293 688 1294 689 1295 690 1296 691 1297 692 1298 693 1299 694 1300 695 1301 696 1302 697 1303 698 1304 699 1305 700 1306 670 1307 670 1308 670 1309 670 1310 670 1311 670 1312 670 1313 670 1314 670 1315 670 1316 670 1317 670 1318 670 1319 670 1320 670 1321 701 1322 702 1323 8 1324 8 1325 8 1326 8 1327 8 1328 8 1329 703 1330 8 1331 8 1332 704 1333 8 1334 705 1335 706 1336 707 1337 708 1338 709 1339 710 1340 8 1341 711 1342 8 1343 8 1344 8 1345 8 1346 8 1347 712 1348 713 1349 8 1350 8 1351 714 1352 8 1353 715 1354 8 1355 8 1356 716 1357 717 1358 8 1359 670 1360 670 1361 670 1362 670 1363 670 1364 718 1365 719 1366 720 1367 670 1368 670 1369 670 1370 670 1371 670 1372 670 1373 670 1374 670 1375 670 1376 670 1377 721 1378 8 1379 8 1380 8 1381 8 1382 8 1383 8 1384 8 1385 8 1386 8 1387 8 1388 8 1389 8 1390 8 1391 8 1392 8 1393 8 1394 8 1395 8 1396 8 1397 8 1398 8 1399 8 1400 8 1401 8 1402 8 1403 8 1404 8 1405 8 1406 8 1407 8 1408 8 1409 8 1410 8 1411 8 1412 8 1413 8 1414 8 1415 8 1416 8 1417 8 1418 8 1419 8 1420 8 1421 8 1422 8 1423 8 1424 8 1425 8 1426 8 1427 8 1428 8 1429 8 1430 8 1431 8 1432 8 1433 8 1434 8 1435 8 1436 8 1437 8 1438 8 1439 8 1440 8 1441 8 1442 8 1443 8 1444 8 1445 8 1446 8 1447 8 1448 8 1449 8 1450 8 1451 8 1452 8 1453 8 1454 8 1455 8 1456 8 1457 722 1458 8 1459 8 1460 8 1461 723 1462 724 1463 8 1464 725 1465 8 1466 8 1467 726 1468 727 1469 728 1470 729 1471 8 1472 730 1473 8 1474 562 1475 8 1476 731 1477 732 1478 733 1479 734 1480 8 1481 735 1482 8 1483 736 1484 737 1485 738 1486 739 1487 740 1488 741 1489 742 1490 743 1491 744 1492 670 1493 670 1494 670 1495 670 1496 670 1497 670 1498 670 1499 670 1500 670 1501 670 1502 670 1503 670 1504 670 1505 8 1506 8 1507 745 1508 670 1509 746 1510 747 1511 748 1512 749 1513 8 1514 8 1515 8 1516 8 1517 8 1518 8 1519 8 1520 8 1521 8 1522 8 1523 8 1524 750 1525 8 1526 8 1527 8 1528 8 1529 751 1530 752 1531 753 1532 8 1533 8 1534 754 1535 8 1536 8 1537 8 1538 755 1539 8 1540 8 1541 8 1542 756 1543 757 1544 8 1545 8 1546 8 1547 8 1548 8 1549 8 1550 8 1551 8 1552 8 1553 8 1554 8 1555 8 1556 8 1557 8 1558 8 1559 8 1560 8 1561 8 1562 8 1563 8 1564 8 1565 8 1566 8 1567 8 1568 8 1569 8 1570 8 1571 8 1572 8 1573 8 1574 8 1575 8 1576 8 1577 8 1578 8 1579 8 1580 8 1581 8 1582 8 1583 8 1584 8 1585 8 1586 8 1587 8 1588 8 1589 8 1590 8 1591 8 1592 8 1593 8 1594 8 1595 8 1596 8 1597 8 1598 8 1599 8 1600 8 1601 8 1602 8 1603 8 1604 8 1605 8 1606 8 1607 8 1608 8 1609 8 1610 8 1611 8 1612 8 1613 8 1614 8 1615 8 1616 8 1617 8 1618 8 1619 8 1620 8 1621 8 1622 8 1623 758 1624 8 1625 8 1626 8 1627 759 1628 760 1629 8 1630 761 1631 8 1632 8 1633 762 1634 763 1635 764 1636 8 1637 8 1638 8 1639 765 1640 8 1641 766 1642 8 1643 767 1644 768 1645 8 1646 8 1647 8 1648 769 1649 770 1650 771 1651 772 1652 773 1653 8 1654 774 1655 8 1656 8 1657 775 1658 8 1659 776 1660 777 1661 8 1662 8 1663 778 1664 8 1665 779 1666 780 1667 781 1668 782 1669 783 1670 784 1671 785 1672 786 1673 787 1674 788 1675 8 1676 789 1677 8 1678 790 1679 8 1680 8 1681 791 1682 792 1683 793 1684 794 1685 795 1686 8 1687 8 1688 796 1689 797 1690 798 1691 799 1692 800 1693 8 1694 801 1695 8 1696 802 1697 8 1698 8 1699 8 1700 8 1701 803 1702 8 1703 804 1704 805 1705 806 1706 807 1707 808 1708 809 1709 810 1710 8 1711 811 1712 812 1713 8 1714 813 1715 8 1716 814 1717 815 1718 816 1719 817 1720 818 1721 819 1722 8 1723 820 1724 821 1725 822 1726 8 1727 8 1728 823 1729 8 1730 8 1731 824 1732 825 1733 826 1734 8 1735 8 1736 8 1737 8 1738 827 1739 8 1740 828 1741 8 1742 8 1743 8 1744 8 1745 829 1746 830 1747 831 1748 832 1749 833 1750 834 1751 835 1752 836 1753 837 1754 838 1755 839 1756 840 1757 841 1758 842 1759 843 1760 844 1761 845 1762 846 1763 847 1764 848 1765 849 1766 850 1767 851 1768 852 1769 853 1770 854 1771 855 1772 856 1773 857 1774 858 1775 859 1776 860 1777 861 1778 862 1779 863 1780 833 1781 833 1782 833 1783 833 1784 833 1785 833 1786 833 1787 833 1788 833 1789 833 1790 833 1791 833 1792 833 1793 833 1794 833 1795 864 1796 865 1797 8 1798 8 1799 8 1800 8 1801 8 1802 8 1803 866 1804 8 1805 8 1806 867 1807 8 1808 868 1809 869 1810 870 1811 871 1812 872 1813 873 1814 8 1815 874 1816 8 1817 8 1818 8 1819 8 1820 8 1821 875 1822 876 1823 8 1824 8 1825 877 1826 8 1827 878 1828 8 1829 8 1830 879 1831 880 1832 8 1833 833 1834 833 1835 833 1836 833 1837 833 1838 881 1839 882 1840 883 1841 833 1842 833 1843 833 1844 833 1845 833 1846 833 1847 833 1848 833 1849 833 1850 833 1851 884 1852 885 1853 886 1854 887 1855 888 1856 889 1857 890 1858 891 1859 892 1860 893 1861 894 1862 8 1863 895 1864 8 1865 896 1866 8 1867 8 1868 897 1869 898 1870 899 1871 900 1872 901 1873 8 1874 8 1875 902 1876 903 1877 904 1878 905 1879 906 1880 8 1881 907 1882 8 1883 908 1884 8 1885 8 1886 8 1887 8 1888 909 1889 8 1890 910 1891 911 1892 912 1893 913 1894 914 1895 915 1896 916 1897 8 1898 917 1899 918 1900 8 1901 919 1902 8 1903 920 1904 921 1905 922 1906 923 1907 924 1908 925 1909 8 1910 926 1911 927 1912 928 1913 8 1914 8 1915 929 1916 8 1917 8 1918 930 1919 931 1920 932 1921 8 1922 8 1923 8 1924 8 1925 933 1926 8 1927 934 1928 8 1929 8 1930 8 1931 8 1932 935 1933 936 1934 937 1935 938 1936 939 1937 940 1938 941 1939 942 1940 943 1941 944 1942 945 1943 946 1944 947 1945 948 1946 949 1947 950 1948 951 1949 952 1950 953 1951 954 1952 955 1953 956 1954 957 1955 958 1956 959 1957 960 1958 961 1959 962 1960 963 1961 964 1962 965 1963 966 1964 967 1965 968 1966 969 1967 939 1968 939 1969 939 1970 939 1971 939 1972 939 1973 939 1974 939 1975 939 1976 939 1977 939 1978 939 1979 939 1980 939 1981 939 1982 970 1983 971 1984 8 1985 8 1986 8 1987 8 1988 8 1989 8 1990 972 1991 8 1992 8 1993 973 1994 8 1995 974 1996 975 1997 976 1998 977 1999 978 2000 979 2001 8 2002 980 2003 8 2004 8 2005 8 2006 8 2007 8 2008 981 2009 982 2010 8 2011 8 2012 983 2013 8 2014 984 2015 8 2016 8 2017 985 2018 986 2019 8 2020 939 2021 939 2022 939 2023 939 2024 939 2025 987 2026 988 2027 989 2028 939 2029 939 2030 939 2031 939 2032 939 2033 939 2034 939 2035 939 2036 939 2037 939 2038 990 2039 991 2040 992 2041 993 2042 939 2043 994 2044 8 2045 8 2046 8 2047 8 2048 8 2049 8 2050 8 2051 8 2052 8 2053 8 2054 8 2055 8 2056 8 2057 8 2058 8 2059 8 2060 8 2061 8 2062 8 2063 8 2064 8 2065 8 2066 8 2067 8 2068 8 2069 8 2070 8 2071 8 2072 8 2073 8 2074 8 2075 8 2076 8 2077 8 2078 8 2079 8 2080 8 2081 8 2082 8 2083 8 2084 8 2085 8 2086 8 2087 8 2088 8 2089 8 2090 8 2091 8 2092 8 2093 8 2094 8 2095 8 2096 8 2097 8 2098 8 2099 8 2100 8 2101 8 2102 8 2103 8 2104 8 2105 8 2106 8 2107 8 2108 8 2109 8 2110 8 2111 8 2112 8 2113 8 2114 8 2115 8 2116 8 2117 8 2118 8 2119 8 2120 8 2121 8 2122 8 2123 995 2124 8 2125 8 2126 8 2127 996 2128 997 2129 8 2130 998 2131 8 2132 8 2133 999 2134 1000 2135 1001 2136 8 2137 8 2138 1002 2139 1003 2140 1004 2141 1005 2142 8 2143 1006 2144 8 2145 1007 2146 1008 2147 1009 2148 1010 2149 1011 2150 1012 2151 1013 2152 1014 2153 1015 2154 939 2155 939 2156 939 2157 939 2158 939 2159 939 2160 939 2161 939 2162 939 2163 939 2164 939 2165 939 2166 939 2167 1016 2168 939 2169 1017 2170 1018 2171 8 2172 1019 2173 1020 2174 8 2175 1021 2176 8 2177 1022 2178 8 2179 8 2180 8 2181 1023 2182 1024 2183 1025 2184 8 2185 1026 2186 8 2187 8 2188 1027 2189 1028 2190 1029 2191 8 2192 8 2193 8 2194 1030 2195 1031 2196 8 2197 8 2198 8 2199 1032 2200 1033 2201 1034 2202 1035 2203 1036 2204 8 2205 1037 2206 8 2207 8 2208 1038 2209 8 2210 1039 2211 1040 2212 8 2213 8 2214 1041 2215 8 2216 8 2217 8 2218 1042 2219 1043 2220 8 2221 1044 2222 8 2223 8 2224 1045 2225 1046 2226 1047 2227 1048 2228 1049 2229 1050 2230 1051 2231 1052 2232 1053 2233 1054 2234 1055 2235 8 2236 1056 2237 1057 2238 1058 2239 1059 2240 1060 2241 1061 2242 1062 2243 1063 2244 1064 2245 1065 2246 1066 2247 8 2248 1067 2249 1068 2250 8 2251 8 2252 8 2253 8 2254 8 2255 8 2256 8 2257 1069 2258 8 2259 1070 2260 8 2261 8 2262 1071 2263 1072 2264 1073 2265 1074 2266 8 2267 8 2268 8 2269 8 2270 8 2271 8 2272 8 2273 8 2274 8 2275 8 2276 8 2277 8 2278 8 2279 8 2280 8 2281 8 2282 8 2283 8 2284 1075 2285 8 2286 1076 2287 8 2288 1077 2289 8 2290 8 2291 8 2292 8 2293 8 2294 8 2295 8 2296 8 2297 8 2298 8 2299 8 2300 1078 2301 8 2302 1079 2303 8 2304 1080 2305 8 2306 8 2307 8 2308 8 2309 8 2310 8 2311 8 2312 8 2313 8 2314 8 2315 1081 2316 8 2317 8 2318 8 2319 8 2320 8 2321 8 2322 8 2323 8 2324 8 2325 8 2326 8 2327 1082 2328 8 2329 1083 2330 1084 2331 1085 2332 1086 2333 1087 2334 1088 2335 1089 2336 1090 2337 1091 2338 1092 2339 1093 2340 8 2341 1094 2342 8 2343 1095 2344 8 2345 8 2346 1096 2347 1097 2348 1098 2349 1099 2350 8 2351 8 2352 1100 2353 1101 2354 1102 2355 1103 2356 1104 2357 8 2358 1105 2359 8 2360 1106 2361 8 2362 8 2363 8 2364 8 2365 1107 2366 8 2367 1108 2368 1109 2369 1110 2370 1111 2371 1112 2372 1113 2373 1114 2374 8 2375 1115 2376 1116 2377 8 2378 1117 2379 8 2380 1118 2381 1119 2382 1120 2383 1121 2384 1122 2385 1123 2386 1124 2387 1125 2388 8 2389 8 2390 1126 2391 8 2392 8 2393 1127 2394 1128 2395 1129 2396 8 2397 8 2398 8 2399 8 2400 1130 2401 8 2402 8 2403 8 2404 8 2405 1131 2406 1132 2407 1133 2408 1134 2409 1127 2410 1135 2411 1136 2412 1137 2413 1138 2414 1139 2415 1140 2416 1141 2417 1142 2418 1143 2419 1144 2420 1145 2421 1146 2422 1147 2423 1148 2424 1149 2425 1150 2426 1151 2427 1152 2428 1153 2429 1154 2430 1155 2431 1156 2432 1157 2433 1158 2434 1159 2435 1160 2436 1161 2437 1162 2438 1163 2439 1164 2440 1127 2441 1127 2442 1127 2443 1127 2444 1127 2445 1127 2446 1127 2447 1127 2448 1127 2449 1127 2450 1127 2451 1127 2452 1127 2453 1127 2454 1127 2455 1165 2456 1166 2457 8 2458 8 2459 8 2460 8 2461 8 2462 8 2463 1167 2464 8 2465 8 2466 1168 2467 8 2468 1169 2469 1170 2470 1171 2471 1172 2472 1173 2473 1174 2474 8 2475 1175 2476 8 2477 8 2478 8 2479 8 2480 8 2481 1176 2482 1177 2483 8 2484 8 2485 1178 2486 8 2487 1179 2488 8 2489 8 2490 1180 2491 1181 2492 8 2493 1127 2494 1127 2495 1127 2496 1127 2497 1127 2498 1182 2499 1183 2500 1184 2501 1127 2502 1127 2503 1127 2504 1127 2505 1127 2506 1127 2507 1127 2508 1127 2509 1127 2510 1127 2511 1185 2512 1186 2513 1187 2514 1188 2515 1127 2516 1189 2517 8 2518 8 2519 8 2520 8 2521 8 2522 8 2523 8 2524 8 2525 8 2526 8 2527 8 2528 8 2529 8 2530 8 2531 8 2532 8 2533 8 2534 8 2535 8 2536 8 2537 8 2538 8 2539 8 2540 8 2541 8 2542 8 2543 8 2544 8 2545 8 2546 8 2547 8 2548 8 2549 8 2550 8 2551 8 2552 8 2553 8 2554 8 2555 8 2556 8 2557 8 2558 8 2559 8 2560 8 2561 8 2562 8 2563 8 2564 8 2565 8 2566 8 2567 8 2568 8 2569 8 2570 8 2571 8 2572 8 2573 8 2574 8 2575 8 2576 8 2577 8 2578 8 2579 8 2580 8 2581 8 2582 8 2583 8 2584 8 2585 8 2586 8 2587 8 2588 8 2589 8 2590 8 2591 8 2592 8 2593 8 2594 8 2595 8 2596 1190 2597 8 2598 8 2599 8 2600 1191 2601 1192 2602 8 2603 1193 2604 8 2605 8 2606 1194 2607 1195 2608 1196 2609 8 2610 8 2611 1197 2612 1198 2613 1199 2614 1200 2615 8 2616 1201 2617 8 2618 1202 2619 1203 2620 1204 2621 1205 2622 1206 2623 1207 2624 1208 2625 1209 2626 1210 2627 1127 2628 1127 2629 1127 2630 1127 2631 1127 2632 1127 2633 1127 2634 1127 2635 1127 2636 1127 2637 1127 2638 1127 2639 1127 2640 1211 2641 1127 2642 1212 2643 1213 2644 8 2645 1214 2646 1215 2647 8 2648 1216 2649 8 2650 1217 2651 8 2652 8 2653 8 2654 1218 2655 1219 2656 1220 2657 8 2658 1221 2659 8 2660 8 2661 1222 2662 1223 2663 1224 2664 8 2665 8 2666 8 2667 1225 2668 1226 2669 8 2670 8 2671 8 2672 1227 2673 1228 2674 1229 2675 1230 2676 1231 2677 8 2678 1232 2679 8 2680 8 2681 1233 2682 8 2683 1234 2684 1235 2685 8 2686 8 2687 1236 2688 8 2689 8 2690 8 2691 1237 2692 1238 2693 8 2694 8 2695 1239 2696 1240 2697 1241 2698 1242 2699 1243 2700 1244 2701 1245 2702 1246 2703 1247 2704 1248 2705 1249 2706 8 2707 1250 2708 1251 2709 1252 2710 1253 2711 1254 2712 1255 2713 1256 2714 1257 2715 1258 2716 1259 2717 8 2718 1260 2719 8 2720 1261 2721 8 2722 1262 2723 1263 2724 8 2725 8 2726 8 2727 1264 2728 8 2729 8 2730 8 2731 1265 2732 1266 2733 1267 2734 1268 2735 1269 2736 8 2737 1270 2738 8 2739 8 2740 1271 2741 8 2742 1272 2743 1273 2744 8 2745 8 2746 1274 2747 8 2748 1275 2749 1276 2750 8 2751 1277 2752 1278 2753 8 2754 1279 2755 8 2756 1280 2757 8 2758 8 2759 8 2760 1281 2761 1282 2762 1283 2763 8 2764 1284 2765 8 2766 8 2767 1285 2768 1286 2769 1287 2770 8 2771 8 2772 8 2773 1288 2774 1289 2775 8 2776 8 2777 8 2778 1290 2779 1291 2780 1292 2781 1293 2782 1294 2783 8 2784 1295 2785 8 2786 8 2787 1296 2788 8 2789 1297 2790 1298 2791 8 2792 8 2793 1299 2794 8 2795 8 2796 8 2797 1300 2798 1301 2799 8 2800 1302 2801 1303 2802 1304 2803 1305 2804 1306 2805 1307 2806 8 2807 8 2808 8 2809 8 2810 1308 2811 1309 2812 1310 2813 1311 2814 8 2815 8 2816 8 2817 1312 2818 8 2819 8 2820 8 2821 8 2822 8 2823 1313 2824 1314 2825 8 2826 1315 2827 8 2828 1316 2829 1317 2830 8 2831 1318 2832 1319 2833 8 2834 1320 2835 1321 2836 8 2837 1322 2838 8 2839 1323 2840 8 2841 8 2842 1324 2843 1325 2844 1326 2845 1327 2846 8 2847 1328 2848 8 2849 8 2850 1329 2851 1330 2852 1331 2853 8 2854 8 2855 8 2856 8 2857 1332 2858 1333 2859 8 2860 8 2861 8 2862 1334 2863 1335 2864 1336 2865 1337 2866 1338 2867 8 2868 1339 2869 8 2870 8 2871 1340 2872 8 2873 1341 2874 1342 2875 8 2876 8 2877 1343 2878 8 2879 8 2880 8 2881 1344 2882 1345 2883 8 2884 1346 2885 1347 2886 1348 2887 1127 2888 1127 2889 1349 2890 1350 2891 1127 2892 1127 2893 1127 2894 1127 2895 8 2896 1351 2897 1352 2898 1353 2899 8 2900 1354 2901 1355 2902 8 2903 8 2904 8 2905 8 2906 1356 2907 1357 2908 1358 2909 1359 2910 8 2911 8 2912 8 2913 8 2914 8 2915 1360 2916 1361 2917 8 2918 1362 2919 8 2920 1363 2921 1364 2922 8 2923 1365 2924 8 2925 1127 2926 1127 2927 8 2928 1127 2929 1127 2930 1366 2931 1367 2932 1368 2933 8 2934 8 2935 8 2936 8 2937 8 2938 8 2939 8 2940 8 2941 1369 2942 1370 2943 8 2944 1371 2945 8 2946 1372 2947 1373 2948 8 2949 1374 2950 8 2951 1375 2952 1376 2953 1377 2954 1378 2955 1379 2956 1380 2957 8 2958 1381 2959 8 2960 8 2961 8 2962 8 2963 8 2964 1382 2965 1383 2966 8 2967 8 2968 1384 2969 8 2970 8 2971 8 2972 1385 2973 1386 2974 1387 2975 8 2976 8 2977 1388 2978 8 2979 8 2980 8 2981 1389 2982 1390 2983 8 2984 1391 2985 1392 2986 1393 2987 1394 2988 1395 2989 1396 2990 1397 2991 1398 2992 8 2993 1399 2994 1400 2995 8 2996 8 2997 8 2998 8 2999 8 3000 8 3001 1401 3002 8 3003 8 3004 8 3005 1402 3006 1403 3007 8 3008 8 3009 8 3010 1404 3011 1405 3012 1406 3013 8 3014 1407 3015 1408 3016 8 3017 8 3018 8 3019 8 3020 8 3021 8 3022 1409 3023 8 3024 1410 3025 8 3026 1411 3027 1412 3028 1413 3029 1414 3030 1415 3031 8 3032 8 3033 8 3034 8 3035 8 3036 8 3037 8 3038 8 3039 8 3040 1416 3041 1417 3042 1418 3043 8 3044 8 3045 1419 3046 8 3047 1420 3048 8 3049 1421 3050 8 3051 8 3052 8 3053 8 3054 8 3055 8 3056 8 3057 8 3058 1422 3059 8 3060 1423 3061 1424 3062 8 3063 8 3064 1425 3065 8 3066 1426 3067 1427 3068 1428 3069 1429 3070 1430 3071 1431 3072 1432 3073 1433 3074 1434 3075 1435 3076 8 3077 1436 3078 8 3079 1437 3080 8 3081 8 3082 1438 3083 1439 3084 1440 3085 1441 3086 8 3087 8 3088 1442 3089 1443 3090 1444 3091 1445 3092 1446 3093 8 3094 1447 3095 8 3096 1448 3097 8 3098 8 3099 8 3100 8 3101 1449 3102 8 3103 1450 3104 1451 3105 1452 3106 1453 3107 1454 3108 1455 3109 1456 3110 8 3111 1457 3112 1458 3113 8 3114 1459 3115 8 3116 1460 3117 1461 3118 1462 3119 1463 3120 1464 3121 1465 3122 1466 3123 8 3124 8 3125 1467 3126 8 3127 8 3128 1468 3129 1469 3130 1470 3131 8 3132 8 3133 8 3134 8 3135 1471 3136 8 3137 8 3138 8 3139 8 3140 1472 3141 1473 3142 1474 3143 1475 3144 1476 3145 1477 3146 1478 3147 1479 3148 1480 3149 1481 3150 1482 3151 1483 3152 1484 3153 1485 3154 1486 3155 1487 3156 1488 3157 1489 3158 1490 3159 1491 3160 1492 3161 1493 3162 1494 3163 1495 3164 1496 3165 1497 3166 1498 3167 1499 3168 1500 3169 1501 3170 1502 3171 1503 3172 1504 3173 1505 3174 1475 3175 1475 3176 1475 3177 1475 3178 1475 3179 1475 3180 1475 3181 1475 3182 1475 3183 1475 3184 1475 3185 1475 3186 1475 3187 1475 3188 1475 3189 1506 3190 1507 3191 8 3192 8 3193 8 3194 8 3195 8 3196 8 3197 1508 3198 8 3199 8 3200 1509 3201 8 3202 1510 3203 1511 3204 1512 3205 1513 3206 1514 3207 1515 3208 8 3209 1516 3210 8 3211 8 3212 8 3213 8 3214 8 3215 1517 3216 1518 3217 8 3218 8 3219 1519 3220 8 3221 1520 3222 8 3223 8 3224 1521 3225 1522 3226 8 3227 1475 3228 1475 3229 1475 3230 1475 3231 1475 3232 1523 3233 1524 3234 1525 3235 1475 3236 1475 3237 1475 3238 1475 3239 1475 3240 1475 3241 1475 3242 1475 3243 1475 3244 1475 3245 1526 3246 8 3247 8 3248 8 3249 8 3250 8 3251 8 3252 8 3253 8 3254 8 3255 8 3256 8 3257 8 3258 8 3259 8 3260 8 3261 8 3262 8 3263 8 3264 8 3265 8 3266 8 3267 8 3268 8 3269 8 3270 8 3271 8 3272 8 3273 8 3274 8 3275 8 3276 8 3277 8 3278 8 3279 8 3280 8 3281 8 3282 8 3283 8 3284 8 3285 8 3286 8 3287 8 3288 8 3289 8 3290 8 3291 8 3292 8 3293 8 3294 8 3295 8 3296 8 3297 8 3298 8 3299 8 3300 8 3301 8 3302 8 3303 8 3304 8 3305 8 3306 8 3307 8 3308 8 3309 8 3310 8 3311 8 3312 8 3313 8 3314 8 3315 8 3316 8 3317 8 3318 8 3319 8 3320 8 3321 8 3322 8 3323 8 3324 8 3325 1527 3326 8 3327 8 3328 8 3329 1528 3330 1529 3331 8 3332 1530 3333 8 3334 8 3335 1531 3336 1532 3337 1533 3338 8 3339 8 3340 1534 3341 1535 3342 1536 3343 1537 3344 8 3345 1538 3346 8 3347 1539 3348 1540 3349 1541 3350 1542 3351 1543 3352 1544 3353 1545 3354 1546 3355 1547 3356 1475 3357 1475 3358 1475 3359 1475 3360 1475 3361 1475 3362 1475 3363 1475 3364 1475 3365 1475 3366 1475 3367 1475 3368 1475 3369 1548 3370 1475 3371 1549 3372 1550 3373 8 3374 1551 3375 1552 3376 8 3377 1553 3378 8 3379 1554 3380 8 3381 8 3382 8 3383 1555 3384 1556 3385 1557 3386 8 3387 1558 3388 8 3389 8 3390 1559 3391 1560 3392 1561 3393 8 3394 8 3395 8 3396 1562 3397 1563 3398 8 3399 8 3400 8 3401 1564 3402 1565 3403 1566 3404 1567 3405 1568 3406 8 3407 1569 3408 8 3409 8 3410 1570 3411 8 3412 1571 3413 1572 3414 8 3415 8 3416 1573 3417 8 3418 8 3419 8 3420 1574 3421 1575 3422 8 3423 8 3424 1576 3425 1577 3426 1578 3427 1579 3428 1580 3429 1581 3430 1582 3431 1583 3432 1584 3433 1585 3434 1586 3435 8 3436 1587 3437 1588 3438 1589 3439 1590 3440 1591 3441 1592 3442 1593 3443 1594 3444 1595 3445 1596 3446 8 3447 8 3448 1597 3449 8 3450 1598 3451 8 3452 1599 3453 1600 3454 8 3455 8 3456 8 3457 1601 3458 8 3459 8 3460 1602 3461 1603 3462 1604 3463 1605 3464 1606 3465 8 3466 1607 3467 8 3468 8 3469 1608 3470 8 3471 1609 3472 1610 3473 8 3474 8 3475 1611 3476 8 3477 1612 3478 8 3479 1613 3480 1614 3481 1615 3482 1475 3483 1475 3484 1616 3485 1617 3486 1618 3487 1619 3488 1620 3489 1621 3490 1622 3491 1623 3492 1624 3493 1625 3494 8 3495 1626 3496 8 3497 1627 3498 8 3499 8 3500 1628 3501 1629 3502 1630 3503 1631 3504 8 3505 8 3506 1632 3507 1633 3508 1634 3509 1635 3510 1636 3511 8 3512 1637 3513 8 3514 1638 3515 8 3516 8 3517 8 3518 8 3519 1639 3520 8 3521 1640 3522 1641 3523 1642 3524 1643 3525 1644 3526 1645 3527 1646 3528 8 3529 1647 3530 1648 3531 8 3532 1649 3533 8 3534 1650 3535 1651 3536 1652 3537 1653 3538 1654 3539 1655 3540 1656 3541 8 3542 8 3543 1657 3544 8 3545 8 3546 1658 3547 1659 3548 1660 3549 8 3550 8 3551 8 3552 8 3553 1661 3554 8 3555 8 3556 8 3557 8 3558 1662 3559 1663 3560 1664 3561 1665 3562 1666 3563 1667 3564 1668 3565 1669 3566 1670 3567 1671 3568 1672 3569 1673 3570 1674 3571 1675 3572 1676 3573 1677 3574 1678 3575 1679 3576 1680 3577 1681 3578 1682 3579 1683 3580 1684 3581 1685 3582 1686 3583 1687 3584 1688 3585 1689 3586 1690 3587 1691 3588 1692 3589 1693 3590 1694 3591 1695 3592 1665 3593 1665 3594 1665 3595 1665 3596 1665 3597 1665 3598 1665 3599 1665 3600 1665 3601 1665 3602 1665 3603 1665 3604 1665 3605 1665 3606 1665 3607 1696 3608 1697 3609 8 3610 8 3611 8 3612 8 3613 8 3614 8 3615 1698 3616 8 3617 8 3618 1699 3619 8 3620 1700 3621 1701 3622 1702 3623 1703 3624 1704 3625 1705 3626 8 3627 1706 3628 8 3629 8 3630 8 3631 8 3632 8 3633 1707 3634 1708 3635 8 3636 8 3637 1709 3638 8 3639 1710 3640 8 3641 8 3642 1711 3643 1712 3644 8 3645 1665 3646 1665 3647 1665 3648 1665 3649 1665 3650 1713 3651 1714 3652 1715 3653 1665 3654 1665 3655 1665 3656 1665 3657 1665 3658 1665 3659 1665 3660 1665 3661 1665 3662 1665 3663 1716 3664 8 3665 8 3666 8 3667 8 3668 8 3669 8 3670 8 3671 8 3672 8 3673 8 3674 8 3675 8 3676 8 3677 8 3678 8 3679 8 3680 8 3681 8 3682 8 3683 8 3684 8 3685 8 3686 8 3687 8 3688 8 3689 8 3690 8 3691 8 3692 8 3693 8 3694 8 3695 8 3696 8 3697 8 3698 8 3699 8 3700 8 3701 8 3702 8 3703 8 3704 8 3705 8 3706 8 3707 8 3708 8 3709 8 3710 8 3711 8 3712 8 3713 8 3714 8 3715 8 3716 8 3717 8 3718 8 3719 8 3720 8 3721 8 3722 8 3723 8 3724 8 3725 8 3726 8 3727 8 3728 8 3729 8 3730 8 3731 8 3732 8 3733 8 3734 8 3735 8 3736 8 3737 8 3738 8 3739 8 3740 8 3741 8 3742 8 3743 1717 3744 8 3745 8 3746 8 3747 1718 3748 1719 3749 8 3750 1720 3751 8 3752 8 3753 1721 3754 1722 3755 1723 3756 8 3757 8 3758 1724 3759 1725 3760 1726 3761 1727 3762 8 3763 1728 3764 8 3765 1729 3766 1730 3767 1731 3768 1732 3769 1733 3770 1734 3771 1735 3772 1736 3773 1737 3774 1665 3775 1665 3776 1665 3777 1665 3778 1665 3779 1665 3780 1665 3781 1665 3782 1665 3783 1665 3784 1665 3785 1665 3786 1665 3787 1738 3788 1665 3789 1739 3790 1740 3791 8 3792 1741 3793 1742 3794 8 3795 1743 3796 8 3797 1744 3798 8 3799 8 3800 8 3801 1745 3802 1746 3803 1747 3804 8 3805 1748 3806 8 3807 8 3808 1749 3809 1750 3810 1751 3811 8 3812 8 3813 8 3814 1752 3815 1753 3816 8 3817 8 3818 8 3819 1754 3820 1755 3821 1756 3822 1757 3823 1758 3824 8 3825 1759 3826 8 3827 8 3828 1760 3829 8 3830 1761 3831 1762 3832 8 3833 8 3834 1763 3835 8 3836 8 3837 8 3838 1764 3839 1765 3840 8 3841 8 3842 1766 3843 1767 3844 1768 3845 1769 3846 1770 3847 1771 3848 1772 3849 1773 3850 1774 3851 1775 3852 1776 3853 8 3854 1777 3855 1778 3856 1779 3857 1780 3858 1781 3859 1782 3860 1783 3861 1784 3862 1785 3863 1786 3864 8 3865 1787 3866 1475 3867 1788 3868 8 3869 1789 3870 8 3871 1790 3872 1791 3873 8 3874 8 3875 8 3876 1792 3877 8 3878 8 3879 1793 3880 1794 3881 1795 3882 1796 3883 1797 3884 8 3885 1798 3886 8 3887 8 3888 1799 3889 8 3890 1800 3891 1801 3892 8 3893 8 3894 1802 3895 8 3896 1803 3897 8 3898 1804 3899 1805 3900 1806 3901 1665 3902 1665 3903 1807 3904 1808 3905 1665 3906 1665 3907 1665 3908 1665 3909 8 3910 1809 3911 8 3912 1810 3913 8 3914 8 3915 1665 3916 1665 3917 8 3918 1665 3919 1665 3920 1811 3921 8 3922 8 3923 8 3924 8 3925 8 3926 8 3927 1812 3928 1813 3929 1814 3930 1815 3931 8 3932 1816 3933 8 3934 1817 3935 1818 3936 1819 3937 1820 3938 1821 3939 1822 3940 8 3941 1823 3942 8 3943 8 3944 8 3945 8 3946 1824 3947 8 3948 8 3949 8 3950 1825 3951 1826 3952 1827 3953 8 3954 8 3955 1828 3956 8 3957 8 3958 1829 3959 1830 3960 1831 3961 1832 3962 1833 3963 1834 3964 1835 3965 8 3966 1836 3967 8 3968 1837 3969 1838 3970 1839 3971 1840 3972 1841 3973 1842 3974 1843 3975 1844 3976 1845 3977 1846 3978 1847 3979 1848 3980 1849 3981 1850 3982 8 3983 1851 3984 8 3985 1852 3986 1853 3987 8 3988 8 3989 1854 3990 1855 3991 1856 3992 1857 3993 8 3994 8 3995 1858 3996 1859 3997 1860 3998 1861 3999 1862 4000 8 4001 1863 4002 8 4003 1864 4004 8 4005 8 4006 8 4007 8 4008 1865 4009 8 4010 1866 4011 1867 4012 1868 4013 1869 4014 1870 4015 1871 4016 1872 4017 8 4018 1873 4019 1874 4020 8 4021 1875 4022 8 4023 1876 4024 1877 4025 1878 4026 1879 4027 1880 4028 1881 4029 1882 4030 8 4031 8 4032 1883 4033 8 4034 8 4035 1884 4036 1885 4037 1886 4038 8 4039 8 4040 8 4041 8 4042 8 4043 1887 4044 1888 4045 1889 4046 8 4047 1890 4048 8 4049 8 4050 8 4051 1891 4052 1892 4053 1893 4054 1884 4055 1894 4056 1895 4057 1896 4058 1897 4059 1898 4060 1899 4061 1900 4062 1901 4063 1902 4064 1903 4065 1904 4066 1905 4067 1906 4068 1907 4069 1908 4070 1909 4071 1910 4072 1911 4073 1912 4074 1913 4075 1914 4076 1915 4077 1916 4078 1917 4079 1918 4080 1919 4081 1920 4082 1921 4083 1922 4084 1923 4085 1884 4086 1884 4087 1884 4088 1884 4089 1884 4090 1884 4091 1884 4092 1884 4093 1884 4094 1884 4095 1884 4096 1884 4097 1884 4098 1884 4099 1884 4100 1924 4101 1925 4102 8 4103 8 4104 8 4105 8 4106 8 4107 8 4108 1926 4109 8 4110 8 4111 1927 4112 8 4113 1928 4114 1929 4115 1930 4116 1931 4117 1932 4118 1933 4119 8 4120 1934 4121 8 4122 8 4123 8 4124 8 4125 8 4126 1935 4127 1936 4128 8 4129 8 4130 1937 4131 8 4132 1938 4133 8 4134 8 4135 1939 4136 1940 4137 8 4138 1884 4139 1884 4140 1884 4141 1884 4142 1884 4143 1941 4144 1942 4145 1943 4146 1884 4147 1884 4148 1884 4149 1884 4150 1884 4151 1884 4152 1884 4153 1884 4154 1884 4155 1884 4156 1944 4157 8 4158 8 4159 8 4160 8 4161 8 4162 8 4163 8 4164 8 4165 8 4166 8 4167 8 4168 8 4169 8 4170 8 4171 8 4172 8 4173 8 4174 8 4175 8 4176 8 4177 8 4178 8 4179 8 4180 8 4181 8 4182 8 4183 8 4184 8 4185 8 4186 8 4187 8 4188 8 4189 8 4190 8 4191 8 4192 8 4193 8 4194 8 4195 8 4196 8 4197 8 4198 8 4199 8 4200 8 4201 8 4202 8 4203 8 4204 8 4205 8 4206 8 4207 8 4208 8 4209 8 4210 8 4211 8 4212 8 4213 8 4214 8 4215 8 4216 8 4217 8 4218 8 4219 8 4220 8 4221 8 4222 8 4223 8 4224 8 4225 8 4226 8 4227 8 4228 8 4229 8 4230 8 4231 8 4232 8 4233 8 4234 8 4235 8 4236 1945 4237 8 4238 8 4239 8 4240 1946 4241 1947 4242 8 4243 1948 4244 8 4245 8 4246 1949 4247 1950 4248 1951 4249 8 4250 8 4251 1952 4252 1953 4253 1954 4254 1955 4255 8 4256 1956 4257 8 4258 1957 4259 1958 4260 1959 4261 1960 4262 1961 4263 1962 4264 1963 4265 1964 4266 1965 4267 1884 4268 1884 4269 1884 4270 1884 4271 1884 4272 1884 4273 1884 4274 1884 4275 1884 4276 1884 4277 1884 4278 1884 4279 1884 4280 1966 4281 1884 4282 1967 4283 1968 4284 8 4285 1969 4286 1970 4287 8 4288 1971 4289 8 4290 1972 4291 8 4292 8 4293 8 4294 1973 4295 1974 4296 1975 4297 8 4298 1976 4299 8 4300 8 4301 1977 4302 1978 4303 1979 4304 8 4305 8 4306 8 4307 1980 4308 1981 4309 8 4310 8 4311 8 4312 1982 4313 1983 4314 1984 4315 1985 4316 1986 4317 8 4318 1987 4319 8 4320 8 4321 1988 4322 8 4323 1989 4324 1990 4325 8 4326 8 4327 1991 4328 8 4329 8 4330 8 4331 1992 4332 1993 4333 8 4334 1994 4335 8 4336 8 4337 8 4338 8 4339 1995 4340 1996 4341 1997 4342 1998 4343 1999 4344 2000 4345 2001 4346 2002 4347 2003 4348 2004 4349 2005 4350 2006 4351 2007 4352 8 4353 2008 4354 8 4355 2009 4356 8 4357 8 4358 2010 4359 2011 4360 2012 4361 2013 4362 8 4363 8 4364 2014 4365 2015 4366 2016 4367 2017 4368 2018 4369 8 4370 2019 4371 8 4372 2020 4373 8 4374 8 4375 8 4376 8 4377 2021 4378 8 4379 2022 4380 2023 4381 2024 4382 2025 4383 2026 4384 2027 4385 2028 4386 8 4387 2029 4388 2030 4389 8 4390 2031 4391 8 4392 2032 4393 2033 4394 2034 4395 2035 4396 2036 4397 2037 4398 2038 4399 8 4400 8 4401 2039 4402 8 4403 8 4404 2040 4405 2041 4406 2042 4407 8 4408 8 4409 8 4410 8 4411 2043 4412 8 4413 8 4414 8 4415 8 4416 2044 4417 2045 4418 2046 4419 2040 4420 2047 4421 2048 4422 2049 4423 2050 4424 2051 4425 2052 4426 2053 4427 2054 4428 2055 4429 2056 4430 2057 4431 2058 4432 2059 4433 2060 4434 2061 4435 2062 4436 2063 4437 2064 4438 2065 4439 2066 4440 2067 4441 2068 4442 2069 4443 2070 4444 2071 4445 2072 4446 2073 4447 2074 4448 2075 4449 2076 4450 2040 4451 2040 4452 2040 4453 2040 4454 2040 4455 2040 4456 2040 4457 2040 4458 2040 4459 2040 4460 2040 4461 2040 4462 2040 4463 2040 4464 2040 4465 2077 4466 2078 4467 8 4468 8 4469 8 4470 8 4471 8 4472 8 4473 2079 4474 8 4475 8 4476 2080 4477 8 4478 2081 4479 2082 4480 2083 4481 2084 4482 2085 4483 2086 4484 8 4485 2087 4486 8 4487 8 4488 8 4489 8 4490 8 4491 2088 4492 2089 4493 8 4494 8 4495 2090 4496 8 4497 2091 4498 8 4499 8 4500 2092 4501 2093 4502 8 4503 2040 4504 2040 4505 2040 4506 2040 4507 2040 4508 2094 4509 2095 4510 2096 4511 2040 4512 2040 4513 2040 4514 2040 4515 2040 4516 2040 4517 2040 4518 2040 4519 2040 4520 2040 4521 2097 4522 8 4523 8 4524 8 4525 8 4526 8 4527 8 4528 8 4529 8 4530 8 4531 8 4532 8 4533 8 4534 8 4535 8 4536 8 4537 8 4538 8 4539 8 4540 8 4541 8 4542 8 4543 8 4544 8 4545 8 4546 8 4547 8 4548 8 4549 8 4550 8 4551 8 4552 8 4553 8 4554 8 4555 8 4556 8 4557 8 4558 8 4559 8 4560 8 4561 8 4562 8 4563 8 4564 8 4565 8 4566 8 4567 8 4568 8 4569 8 4570 8 4571 8 4572 8 4573 8 4574 8 4575 8 4576 8 4577 8 4578 8 4579 8 4580 8 4581 8 4582 8 4583 8 4584 8 4585 8 4586 8 4587 8 4588 8 4589 8 4590 8 4591 8 4592 8 4593 8 4594 8 4595 8 4596 8 4597 8 4598 8 4599 8 4600 8 4601 2098 4602 8 4603 8 4604 8 4605 2099 4606 2100 4607 8 4608 2101 4609 8 4610 8 4611 2102 4612 2103 4613 2104 4614 8 4615 8 4616 2105 4617 2106 4618 2107 4619 2108 4620 8 4621 2109 4622 8 4623 2110 4624 2111 4625 2112 4626 2113 4627 2114 4628 2115 4629 2116 4630 2117 4631 2118 4632 2040 4633 2040 4634 2040 4635 2040 4636 2040 4637 2040 4638 2040 4639 2040 4640 2040 4641 2040 4642 2040 4643 2040 4644 2040 4645 2119 4646 2040 4647 2120 4648 2121 4649 8 4650 2122 4651 2123 4652 8 4653 2124 4654 8 4655 2125 4656 8 4657 8 4658 8 4659 2126 4660 2127 4661 2128 4662 8 4663 2129 4664 8 4665 8 4666 2130 4667 2131 4668 2132 4669 8 4670 8 4671 8 4672 2133 4673 2134 4674 8 4675 8 4676 8 4677 2135 4678 2136 4679 2137 4680 2138 4681 2139 4682 8 4683 2140 4684 8 4685 8 4686 2141 4687 8 4688 2142 4689 2143 4690 8 4691 8 4692 2144 4693 8 4694 8 4695 8 4696 2145 4697 2146 4698 8 4699 8 4700 2147 4701 2148 4702 2149 4703 2150 4704 2151 4705 2152 4706 2153 4707 2154 4708 2155 4709 2156 4710 2157 4711 8 4712 2158 4713 2159 4714 2160 4715 2161 4716 2162 4717 2163 4718 2164 4719 2165 4720 2166 4721 2167 4722 8 4723 2168 4724 8 4725 2169 4726 8 4727 2170 4728 2171 4729 8 4730 8 4731 8 4732 2172 4733 8 4734 8 4735 2173 4736 2174 4737 2175 4738 2176 4739 2177 4740 8 4741 2178 4742 8 4743 8 4744 2179 4745 8 4746 2180 4747 2181 4748 8 4749 8 4750 2182 4751 8 4752 2183 4753 8 4754 2184 4755 2185 4756 2186 4757 2040 4758 2040 4759 2187 4760 2188 4761 2189 4762 2190 4763 2191 4764 2192 4765 2193 4766 2194 4767 2195 4768 2196 4769 8 4770 2197 4771 8 4772 2198 4773 8 4774 8 4775 2199 4776 2200 4777 2201 4778 2202 4779 8 4780 8 4781 2203 4782 2204 4783 2205 4784 2206 4785 2207 4786 8 4787 2208 4788 8 4789 2209 4790 8 4791 8 4792 8 4793 8 4794 2210 4795 8 4796 2211 4797 2212 4798 2213 4799 2214 4800 2215 4801 2216 4802 2217 4803 8 4804 2218 4805 2219 4806 8 4807 2220 4808 8 4809 2221 4810 2222 4811 2223 4812 2224 4813 2225 4814 2226 4815 2227 4816 8 4817 8 4818 2228 4819 8 4820 8 4821 2229 4822 2230 4823 2231 4824 8 4825 8 4826 8 4827 8 4828 2232 4829 8 4830 8 4831 8 4832 8 4833 2233 4834 2234 4835 2235 4836 2236 4837 2237 4838 2238 4839 2239 4840 2240 4841 2241 4842 2242 4843 2243 4844 2244 4845 2245 4846 2246 4847 2247 4848 2248 4849 2249 4850 2250 4851 2251 4852 2252 4853 2253 4854 2254 4855 2255 4856 2256 4857 2257 4858 2258 4859 2259 4860 2260 4861 2261 4862 2262 4863 2263 4864 2264 4865 2265 4866 2266 4867 2236 4868 2236 4869 2236 4870 2236 4871 2236 4872 2236 4873 2236 4874 2236 4875 2236 4876 2236 4877 2236 4878 2236 4879 2236 4880 2236 4881 2236 4882 2267 4883 2268 4884 8 4885 8 4886 8 4887 8 4888 8 4889 8 4890 2269 4891 8 4892 8 4893 2270 4894 8 4895 2271 4896 2272 4897 2273 4898 2274 4899 2275 4900 2276 4901 8 4902 2277 4903 8 4904 8 4905 8 4906 8 4907 8 4908 2278 4909 2279 4910 8 4911 8 4912 2280 4913 8 4914 2281 4915 8 4916 8 4917 2282 4918 2283 4919 8 4920 2236 4921 2236 4922 2236 4923 2236 4924 2236 4925 2284 4926 2285 4927 2286 4928 2236 4929 2236 4930 2236 4931 2236 4932 2236 4933 2236 4934 2236 4935 2236 4936 2236 4937 2236 4938 2287 4939 8 4940 8 4941 8 4942 8 4943 8 4944 8 4945 8 4946 8 4947 8 4948 8 4949 8 4950 8 4951 8 4952 8 4953 8 4954 8 4955 8 4956 8 4957 8 4958 8 4959 8 4960 8 4961 8 4962 8 4963 8 4964 8 4965 8 4966 8 4967 8 4968 8 4969 8 4970 8 4971 8 4972 8 4973 8 4974 8 4975 8 4976 8 4977 8 4978 8 4979 8 4980 8 4981 8 4982 8 4983 8 4984 8 4985 8 4986 8 4987 8 4988 8 4989 8 4990 8 4991 8 4992 8 4993 8 4994 8 4995 8 4996 8 4997 8 4998 8 4999 8 5000 8 5001 8 5002 8 5003 8 5004 8 5005 8 5006 8 5007 8 5008 8 5009 8 5010 8 5011 8 5012 8 5013 8 5014 8 5015 8 5016 8 5017 8 5018 2288 5019 8 5020 8 5021 8 5022 2289 5023 2290 5024 8 5025 2291 5026 8 5027 8 5028 2292 5029 2293 5030 2294 5031 8 5032 8 5033 2295 5034 2296 5035 2297 5036 2298 5037 8 5038 2299 5039 8 5040 2300 5041 2301 5042 2302 5043 2303 5044 2304 5045 2305 5046 2306 5047 2307 5048 2308 5049 2236 5050 2236 5051 2236 5052 2236 5053 2236 5054 2236 5055 2236 5056 2236 5057 2236 5058 2236 5059 2236 5060 2236 5061 2236 5062 2309 5063 2236 5064 2310 5065 2311 5066 8 5067 2312 5068 2313 5069 8 5070 2314 5071 8 5072 2315 5073 8 5074 8 5075 8 5076 2316 5077 2317 5078 2318 5079 8 5080 2319 5081 8 5082 8 5083 2320 5084 2321 5085 2322 5086 8 5087 8 5088 8 5089 2323 5090 2324 5091 8 5092 8 5093 8 5094 2325 5095 2326 5096 2327 5097 2328 5098 2329 5099 8 5100 2330 5101 8 5102 8 5103 2331 5104 8 5105 2332 5106 2333 5107 8 5108 8 5109 2334 5110 8 5111 8 5112 8 5113 2335 5114 2336 5115 8 5116 8 5117 2337 5118 2338 5119 2339 5120 2340 5121 2341 5122 2342 5123 2343 5124 2344 5125 2345 5126 2346 5127 2347 5128 8 5129 2348 5130 2349 5131 2350 5132 2351 5133 2352 5134 2353 5135 2354 5136 2355 5137 2356 5138 2357 5139 8 5140 2358 5141 2040 5142 2359 5143 8 5144 2360 5145 8 5146 2361 5147 2362 5148 8 5149 8 5150 8 5151 2363 5152 8 5153 8 5154 2364 5155 2365 5156 2366 5157 2367 5158 2368 5159 8 5160 2369 5161 8 5162 8 5163 2370 5164 8 5165 2371 5166 2372 5167 8 5168 8 5169 2373 5170 8 5171 2374 5172 8 5173 2375 5174 2376 5175 2377 5176 2236 5177 2236 5178 2378 5179 2379 5180 2236 5181 2236 5182 2236 5183 2236 5184 8 5185 2380 5186 8 5187 2381 5188 8 5189 8 5190 2236 5191 2236 5192 8 5193 2236 5194 2236 5195 2382 5196 8 5197 8 5198 8 5199 8 5200 8 5201 8 5202 2383 5203 2384 5204 2385 5205 2386 5206 8 5207 2387 5208 8 5209 2388 5210 2389 5211 2390 5212 2391 5213 2392 5214 2393 5215 8 5216 2394 5217 8 5218 8 5219 8 5220 8 5221 2395 5222 8 5223 8 5224 8 5225 2396 5226 2397 5227 2398 5228 8 5229 8 5230 2399 5231 8 5232 8 5233 2400 5234 2401 5235 2402 5236 2403 5237 2404 5238 2405 5239 2406 5240 8 5241 2407 5242 8 5243 2408 5244 2409 5245 2410 5246 2411 5247 2412 5248 8 5249 2413 5250 2414 5251 2415 5252 2416 5253 2236 5254 2417 5255 562 5256 8 5257 2418 5258 2419 5259 2420 5260 8 5261 8 5262 2236 5263 2236 5264 2236 5265 8 5266 2421 5267 8 5268 186 5269 2422 5270 8 5271 2423 5272 2424 5273 8 5274 2425 5275 2426 5276 8 5277 2236 5278 8 5279 2236 5280 2236 5281 2236 5282 2427 5283 2428 5284 8 5285 2236 5286 2236 5287 2236 5288 2429 5289 8 5290 8 5291 2430 5292 2431 5293 8 5294 2432 5295 2433 5296 2434 5297 2435 5298 2436 5299 8 5300 8 5301 8 5302 8 5303 2437 5304 2438 5305 2439 5306 2440 5307 8 5308 8 5309 8 5310 8 5311 2441 5312 2442 5313 8 5314 2443 5315 8 5316 2444 5317 2445 5318 8 5319 2446 5320 8 5321 2236 5322 2040 5323 2040 5324 2040 5325 8 5326 2447 5327 8 5328 2448 5329 8 5330 8 5331 2040 5332 2040 5333 8 5334 2040 5335 2040 5336 2449 5337 8 5338 8 5339 8 5340 8 5341 8 5342 8 5343 2450 5344 2451 5345 2452 5346 2453 5347 8 5348 2454 5349 8 5350 2455 5351 2456 5352 2457 5353 2458 5354 2459 5355 2460 5356 8 5357 2461 5358 8 5359 8 5360 8 5361 8 5362 2462 5363 8 5364 8 5365 8 5366 2463 5367 2464 5368 2465 5369 8 5370 8 5371 2466 5372 8 5373 8 5374 2467 5375 2468 5376 2469 5377 2470 5378 2471 5379 2472 5380 2473 5381 8 5382 2474 5383 8 5384 2475 5385 2476 5386 2477 5387 2478 5388 2479 5389 8 5390 2480 5391 2481 5392 2482 5393 2483 5394 2040 5395 2484 5396 2485 5397 2486 5398 8 5399 2040 5400 2040 5401 2040 5402 8 5403 2487 5404 8 5405 2488 5406 8 5407 2489 5408 2490 5409 8 5410 2491 5411 2492 5412 8 5413 2040 5414 8 5415 2040 5416 2040 5417 2040 5418 2493 5419 2494 5420 8 5421 2040 5422 2040 5423 2040 5424 2495 5425 8 5426 8 5427 2496 5428 2497 5429 8 5430 2498 5431 8 5432 2040 5433 1884 5434 2499 5435 2500 5436 2501 5437 2502 5438 2503 5439 2504 5440 2505 5441 2506 5442 2507 5443 2508 5444 2509 5445 8 5446 2510 5447 2511 5448 2512 5449 2513 5450 2514 5451 2515 5452 2516 5453 2517 5454 2518 5455 2519 5456 8 5457 2520 5458 8 5459 2521 5460 8 5461 2522 5462 2523 5463 8 5464 8 5465 8 5466 2524 5467 8 5468 8 5469 2525 5470 2526 5471 2527 5472 2528 5473 2529 5474 8 5475 2530 5476 8 5477 8 5478 2531 5479 8 5480 2532 5481 2533 5482 8 5483 8 5484 2534 5485 8 5486 2535 5487 8 5488 2536 5489 2537 5490 2538 5491 1884 5492 1884 5493 2539 5494 2540 5495 1884 5496 1884 5497 1884 5498 1884 5499 8 5500 2541 5501 8 5502 2542 5503 8 5504 8 5505 1884 5506 1884 5507 8 5508 1884 5509 1884 5510 2543 5511 8 5512 8 5513 8 5514 8 5515 8 5516 8 5517 2544 5518 2545 5519 2546 5520 2547 5521 8 5522 2548 5523 8 5524 2549 5525 2550 5526 2551 5527 2552 5528 2553 5529 2554 5530 8 5531 2555 5532 8 5533 8 5534 8 5535 8 5536 2556 5537 8 5538 8 5539 8 5540 2557 5541 2558 5542 2559 5543 8 5544 8 5545 2560 5546 8 5547 8 5548 2561 5549 2562 5550 2563 5551 2564 5552 2565 5553 2566 5554 2567 5555 8 5556 2568 5557 8 5558 2569 5559 2570 5560 2571 5561 2572 5562 2573 5563 8 5564 2574 5565 2575 5566 2576 5567 2577 5568 1884 5569 2578 5570 2579 5571 2580 5572 8 5573 1884 5574 1884 5575 1884 5576 8 5577 2581 5578 8 5579 2582 5580 8 5581 2583 5582 2584 5583 8 5584 2585 5585 2586 5586 8 5587 1884 5588 8 5589 2587 5590 2588 5591 2040 5592 8 5593 1884 5594 1884 5595 1884 5596 2589 5597 2590 5598 8 5599 1884 5600 1884 5601 1884 5602 2591 5603 8 5604 8 5605 2592 5606 2593 5607 8 5608 2594 5609 8 5610 1884 5611 2595 5612 2596 5613 2597 5614 2598 5615 1665 5616 2599 5617 2600 5618 2601 5619 8 5620 1665 5621 1665 5622 1665 5623 8 5624 2602 5625 8 5626 2603 5627 8 5628 2604 5629 2605 5630 8 5631 2606 5632 2607 5633 8 5634 1665 5635 8 5636 1665 5637 1665 5638 1665 5639 2608 5640 2609 5641 8 5642 1665 5643 1665 5644 1665 5645 2610 5646 8 5647 8 5648 2611 5649 2612 5650 8 5651 2613 5652 8 5653 1665 5654 1475 5655 1475 5656 1475 5657 8 5658 2614 5659 8 5660 2615 5661 8 5662 8 5663 1475 5664 1475 5665 8 5666 1475 5667 1475 5668 2616 5669 8 5670 8 5671 8 5672 8 5673 8 5674 8 5675 2617 5676 2618 5677 2619 5678 2620 5679 8 5680 2621 5681 8 5682 2622 5683 2623 5684 2624 5685 2625 5686 2626 5687 2627 5688 8 5689 2628 5690 8 5691 8 5692 8 5693 8 5694 2629 5695 8 5696 8 5697 8 5698 2630 5699 2631 5700 2632 5701 8 5702 8 5703 2633 5704 8 5705 8 5706 2634 5707 2635 5708 2636 5709 2637 5710 2638 5711 2639 5712 2640 5713 8 5714 2641 5715 8 5716 2642 5717 2643 5718 2644 5719 2645 5720 2646 5721 8 5722 2647 5723 2648 5724 2649 5725 2650 5726 1475 5727 2651 5728 2652 5729 2653 5730 8 5731 1475 5732 1475 5733 1475 5734 8 5735 2654 5736 8 5737 2655 5738 8 5739 2656 5740 2657 5741 8 5742 2658 5743 2659 5744 8 5745 1475 5746 8 5747 1475 5748 1475 5749 1475 5750 2660 5751 2661 5752 8 5753 1475 5754 1475 5755 1475 5756 2662 5757 8 5758 8 5759 2663 5760 2664 5761 8 5762 2665 5763 8 5764 1475 5765 2666 5766 8 5767 8 5768 8 5769 8 5770 8 5771 8 5772 8 5773 8 5774 8 5775 2667 5776 8 5777 8 5778 8 5779 2668 5780 8 5781 8 5782 8 5783 2669 5784 8 5785 8 5786 8 5787 8 5788 8 5789 8 5790 8 5791 8 5792 8 5793 8 5794 8 5795 8 5796 8 5797 8 5798 8 5799 8 5800 8 5801 8 5802 8 5803 8 5804 8 5805 8 5806 8 5807 8 5808 8 5809 8 5810 8 5811 8 5812 8 5813 8 5814 8 5815 8 5816 8 5817 8 5818 8 5819 8 5820 8 5821 8 5822 8 5823 8 5824 8 5825 8 5826 8 5827 8 5828 8 5829 8 5830 8 5831 8 5832 8 5833 8 5834 8 5835 8 5836 8 5837 8 5838 8 5839 8 5840 8 5841 8 5842 8 5843 8 5844 8 5845 8 5846 8 5847 8 5848 8 5849 8 5850 8 5851 8 5852 8 5853 8 5854 8 5855 8 5856 8 5857 8 5858 8 5859 8 5860 8 5861 8 5862 2670 5863 8 5864 8 5865 2671 5866 2672 5867 2673 5868 2674 5869 2675 5870 2676 5871 2677 5872 8 5873 2678 5874 2679 5875 2680 5876 8 5877 8 5878 2681 5879 8 5880 8 5881 8 5882 8 5883 8 5884 8 5885 8 5886 2682 5887 8 5888 2683 5889 8 5890 8 5891 2684 5892 2685 5893 2686 5894 2687 5895 8 5896 8 5897 8 5898 8 5899 8 5900 8 5901 8 5902 8 5903 8 5904 8 5905 8 5906 2688 5907 8 5908 2689 5909 8 5910 2690 5911 8 5912 8 5913 8 5914 8 5915 8 5916 8 5917 8 5918 8 5919 8 5920 8 5921 2691 5922 8 5923 8 5924 8 5925 8 5926 8 5927 8 5928 8 5929 8 5930 8 5931 8 5932 8 5933 2692 5934 2693 5935 8 5936 8 5937 8 5938 8 5939 8 5940 8 5941 8 5942 8 5943 8 5944 8 5945 8 5946 8 5947 8 5948 8 5949 8 5950 8 5951 8 5952 8 5953 8 5954 8 5955 8 5956 8 5957 8 5958 8 5959 8 5960 8 5961 8 5962 8 5963 8 5964 8 5965 8 5966 8 5967 8 5968 8 5969 8 5970 8 5971 8 5972 8 5973 8 5974 8 5975 8 5976 8 5977 8 5978 8 5979 8 5980 8 5981 8 5982 8 5983 8 5984 8 5985 8 5986 8 5987 8 5988 8 5989 8 5990 8 5991 8 5992 8 5993 8 5994 8 5995 8 5996 8 5997 8 5998 8 5999 8 6000 8 6001 8 6002 8 6003 8 6004 8 6005 2694 6006 8 6007 8 6008 8 6009 8 6010 8 6011 8 6012 8 6013 8 6014 8 6015 8 6016 8 6017 2695 6018 2696 6019 8 6020 8 6021 2697 6022 2698 6023 2699 6024 8 6025 2700 6026 2701 6027 2702 6028 2703 6029 8 6030 8 6031 8 6032 8 6033 8 6034 8 6035 8 6036 8 6037 8 6038 8 6039 8 6040 2704 6041 8 6042 2705 6043 8 6044 8 6045 8 6046 8 6047 2694 6048 2706 6049 2707 6050 8 6051 8 6052 2708 6053 2709 6054 8 6055 2710 6056 8 6057 8 6058 8 6059 8 6060 8 6061 8 6062 8 6063 8 6064 8 6065 8 6066 2711 6067 2712 6068 8 6069 2713 6070 8 6071 8 6072 8 6073 8 6074 8 6075 8 6076 8 6077 8 6078 8 6079 8 6080 8 6081 8 6082 8 6083 8 6084 8 6085 8 6086 8 6087 8 6088 8 6089 8 6090 2714 6091 8 6092 2715 6093 8 6094 8 6095 2716 6096 8 6097 8 6098 8 6099 8 6100 8 6101 8 6102 8 6103 8 6104 8 6105 8 6106 8 6107 8 6108 8 6109 8 6110 8 6111 8 6112 8 6113 8 6114 8 6115 8 6116 8 6117 8 6118 8 6119 8 6120 8 6121 8 6122 8 6123 8 6124 8 6125 8 6126 8 6127 8 6128 8 6129 8 6130 8 6131 8 6132 8 6133 8 6134 8 6135 8 6136 8 6137 8 6138 8 6139 8 6140 8 6141 8 6142 8 6143 8 6144 8 6145 8 6146 8 6147 8 6148 8 6149 8 6150 8 6151 8 6152 8 6153 8 6154 8 6155 8 6156 8 6157 8 6158 8 6159 8 6160 8 6161 8 6162 8 6163 8 6164 8 6165 8 6166 8 6167 8 6168 8 6169 8 6170 8 6171 8 6172 8 6173 8 6174 8 6175 8 6176 8 6177 2717 6178 2718 6179 8 6180 8 6181 8 6182 8 6183 8 6184 2719 6185 2720 6186 2721 6187 2722 6188 8 6189 8 6190 2723 6191 8 6192 8 6193 8 6194 8 6195 8 6196 8 6197 8 6198 8 6199 8 6200 8 6201 8 6202 8 6203 8 6204 8 6205 8 6206 8 6207 8 6208 8 6209 8 6210 8 6211 8 6212 8 6213 8 6214 8 6215 8 6216 8 6217 8 6218 8 6219 8 6220 8 6221 8 6222 8 6223 8 6224 8 6225 8 6226 8 6227 8 6228 8 6229 8 6230 8 6231 8 6232 8 6233 8 6234 8 6235 8 6236 8 6237 8 6238 8 6239 8 6240 8 6241 8 6242 8 6243 8 6244 8 6245 8 6246 8 6247 8 6248 8 6249 8 6250 8 6251 8 6252 8 6253 8 6254 8 6255 8 6256 8 6257 8 6258 8 6259 8 6260 8 6261 8 6262 8 6263 8 6264 8 6265 8 6266 8 6267 8 6268 8 6269 2724 6270 8 6271 8 6272 8 6273 8 6274 8 6275 8 6276 8 6277 8 6278 8 6279 8 6280 8 6281 8 6282 8 6283 8 6284 8 6285 2725 6286 8 6287 8 6288 8 6289 8 6290 8 6291 8 6292 8 6293 8 6294 8 6295 8 6296 8 6297 8 6298 8 6299 8 6300 8 6301 8 6302 8 6303 8 6304 8 6305 8 6306 8 6307 8 6308 8 6309 8 6310 8 6311 8 6312 8 6313 8 6314 8 6315 8 6316 8 6317 8 6318 8 6319 8 6320 8 6321 8 6322 8 6323 8 6324 8 6325 8 6326 8 6327 8 6328 8 6329 8 6330 8 6331 8 6332 8 6333 8 6334 8 6335 8 6336 8 6337 8 6338 8 6339 8 6340 8 6341 8 6342 8 6343 8 6344 8 6345 8 6346 8 6347 8 6348 8 6349 8 6350 8 6351 8 6352 8 6353 8 6354 8 6355 8 6356 8 6357 8 6358 8 6359 8 6360 8 6361 8 6362 8 6363 8 6364 8 6365 8 6366 8 6367 2726 6368 8 6369 8 6370 8 6371 8 6372 8 6373 8 6374 2727 6375 8 6376 2728 6377 8 6378 8 6379 2729 6380 8 6381 8 6382 8 6383 8 6384 8 6385 8 6386 8 6387 8 6388 8 6389 8 6390 8 6391 8 6392 8 6393 8 6394 8 6395 8 6396 8 6397 8 6398 8 6399 8 6400 8 6401 8 6402 8 6403 8 6404 8 6405 8 6406 8 6407 8 6408 8 6409 8 6410 8 6411 8 6412 8 6413 8 6414 8 6415 8 6416 8 6417 8 6418 8 6419 8 6420 8 6421 8 6422 8 6423 8 6424 8 6425 8 6426 8 6427 8 6428 8 6429 8 6430 8 6431 8 6432 8 6433 8 6434 8 6435 8 6436 8 6437 8 6438 8 6439 8 6440 8 6441 8 6442 8 6443 8 6444 8 6445 8 6446 8 6447 8 6448 8 6449 8 6450 8 6451 8 6452 8 6453 8 6454 8 6455 8 6456 8 6457 8 6458 2730 6459 8 6460 8 6461 2731 6462 2732 6463 8 6464 84 6465 2733 6466 2734 6467 2735 6468 2736 6469 2737 6470 2738 6471 2739 6472 2740 6473 2741 6474 2742 6475 2743 6476 2744 6477 2745 6478 2746 6479 2747 6480 2748 6481 2749 6482 2750 6483 2751 6484 2752 6485 2753 6486 2754 6487 2755 6488 2756 6489 2757 6490 2758 6491 2759 6492 2760 6493 2761 6494 2762 6495 84 6496 84 6497 84 6498 84 6499 84 6500 84 6501 84 6502 84 6503 84 6504 84 6505 84 6506 84 6507 84 6508 84 6509 84 6510 2763 6511 2764 6512 8 6513 8 6514 8 6515 8 6516 8 6517 8 6518 2765 6519 8 6520 8 6521 2766 6522 8 6523 2767 6524 2768 6525 2769 6526 2770 6527 2771 6528 2772 6529 8 6530 2773 6531 8 6532 8 6533 8 6534 8 6535 8 6536 2774 6537 2775 6538 8 6539 8 6540 2776 6541 8 6542 2777 6543 8 6544 8 6545 2778 6546 2779 6547 8 6548 84 6549 84 6550 84 6551 84 6552 84 6553 2780 6554 2781 6555 2782 6556 84 6557 84 6558 84 6559 84 6560 84 6561 84 6562 84 6563 84 6564 84 6565 84 6566 8 6567 8 6568 8 6569 8 6570 8 6571 8 6572 2783 6573 2784 6574 8 6575 2785 6576 8 6577 8 6578 2786 6579 2787 6580 2788 6581 8 6582 8 6583 2789 6584 2790 6585 8 6586 8 6587 8 6588 8 6589 8 6590 8 6591 8 6592 8 6593 2791 6594 8 6595 2792 6596 8 6597 8 6598 8 6599 8 6600 8 6601 8 6602 8 6603 8 6604 8 6605 2793 6606 2794 6607 2795 6608 8 6609 8 6610 8 6611 2796 6612 2797 6613 8 6614 2798 6615 8 6616 8 6617 2799 6618 2800 6619 8 6620 2801 6621 2802 6622 2803 6623 2804 6624 2805 6625 8 6626 2806 6627 2807 6628 1187 6629 2808 6630 2809 6631 2810 6632 8 6633 1127 6634 1127 6635 1127 6636 8 6637 2811 6638 8 6639 2812 6640 8 6641 2813 6642 2814 6643 8 6644 2815 6645 2816 6646 8 6647 1127 6648 8 6649 1127 6650 1127 6651 1127 6652 2817 6653 2818 6654 8 6655 1127 6656 1127 6657 1127 6658 2819 6659 8 6660 8 6661 2820 6662 2821 6663 8 6664 2822 6665 8 6666 1127 6667 2823 6668 8 6669 2824 6670 8 6671 2825 6672 2826 6673 8 6674 8 6675 8 6676 2827 6677 8 6678 8 6679 2828 6680 2829 6681 833 6682 2830 6683 2831 6684 2832 6685 2833 6686 2834 6687 8 6688 2835 6689 8 6690 8 6691 2836 6692 8 6693 2837 6694 2838 6695 8 6696 8 6697 2839 6698 8 6699 8 6700 2840 6701 8 6702 2841 6703 2842 6704 2843 6705 939 6706 939 6707 2844 6708 2845 6709 939 6710 939 6711 939 6712 939 6713 8 6714 2846 6715 8 6716 2847 6717 8 6718 8 6719 939 6720 939 6721 8 6722 939 6723 939 6724 2848 6725 8 6726 8 6727 8 6728 8 6729 8 6730 8 6731 2849 6732 2850 6733 2851 6734 2852 6735 8 6736 2853 6737 8 6738 2854 6739 2855 6740 2856 6741 2857 6742 2858 6743 2859 6744 8 6745 2860 6746 8 6747 8 6748 8 6749 8 6750 2861 6751 8 6752 8 6753 8 6754 2862 6755 2863 6756 2864 6757 8 6758 8 6759 2865 6760 8 6761 8 6762 2866 6763 2867 6764 2868 6765 2869 6766 2870 6767 2871 6768 2872 6769 8 6770 2873 6771 8 6772 2874 6773 2875 6774 2876 6775 2877 6776 2878 6777 8 6778 2879 6779 2880 6780 992 6781 2881 6782 2882 6783 2883 6784 8 6785 939 6786 939 6787 939 6788 8 6789 2884 6790 8 6791 2885 6792 8 6793 2886 6794 2887 6795 8 6796 2888 6797 2889 6798 8 6799 1127 6800 939 6801 8 6802 939 6803 939 6804 939 6805 2890 6806 2891 6807 8 6808 939 6809 939 6810 939 6811 2892 6812 8 6813 8 6814 2893 6815 2894 6816 8 6817 2895 6818 8 6819 939 6820 2896 6821 8 6822 8 6823 8 6824 8 6825 8 6826 8 6827 8 6828 8 6829 8 6830 8 6831 8 6832 8 6833 8 6834 8 6835 8 6836 8 6837 8 6838 8 6839 8 6840 8 6841 8 6842 8 6843 8 6844 8 6845 8 6846 8 6847 8 6848 8 6849 8 6850 8 6851 8 6852 8 6853 8 6854 8 6855 8 6856 8 6857 8 6858 8 6859 8 6860 8 6861 8 6862 8 6863 8 6864 8 6865 8 6866 8 6867 8 6868 8 6869 8 6870 8 6871 8 6872 8 6873 8 6874 8 6875 8 6876 8 6877 8 6878 8 6879 8 6880 8 6881 8 6882 8 6883 8 6884 8 6885 8 6886 8 6887 8 6888 8 6889 8 6890 8 6891 8 6892 8 6893 8 6894 8 6895 8 6896 8 6897 8 6898 8 6899 8 6900 2897 6901 8 6902 8 6903 8 6904 2898 6905 2899 6906 8 6907 2900 6908 8 6909 8 6910 2901 6911 2902 6912 2903 6913 8 6914 8 6915 2904 6916 2905 6917 2906 6918 2907 6919 8 6920 2908 6921 8 6922 2909 6923 2910 6924 2911 6925 2912 6926 2913 6927 2914 6928 2915 6929 2916 6930 2917 6931 833 6932 833 6933 833 6934 833 6935 833 6936 833 6937 833 6938 833 6939 833 6940 833 6941 833 6942 833 6943 833 6944 2918 6945 833 6946 2919 6947 2920 6948 8 6949 2921 6950 2922 6951 8 6952 2923 6953 8 6954 2924 6955 8 6956 8 6957 8 6958 2925 6959 2926 6960 2927 6961 8 6962 2928 6963 8 6964 8 6965 2929 6966 2930 6967 2931 6968 8 6969 8 6970 8 6971 2932 6972 2933 6973 8 6974 8 6975 8 6976 2934 6977 2935 6978 2936 6979 2937 6980 2938 6981 8 6982 2939 6983 8 6984 8 6985 2940 6986 8 6987 2941 6988 2942 6989 8 6990 8 6991 2943 6992 8 6993 8 6994 8 6995 2944 6996 2945 6997 8 6998 2946 6999 8 7000 8 7001 2947 7002 2948 7003 2949 7004 2950 7005 2951 7006 2952 7007 2953 7008 2954 7009 2955 7010 2956 7011 2957 7012 8 7013 2958 7014 2959 7015 2960 7016 2961 7017 2962 7018 2963 7019 2964 7020 2965 7021 2966 7022 2967 7023 2968 7024 2969 7025 2970 7026 2971 7027 2972 7028 2973 7029 2974 7030 2975 7031 2976 7032 8 7033 2977 7034 8 7035 2978 7036 8 7037 8 7038 2979 7039 2980 7040 2981 7041 2982 7042 8 7043 8 7044 2983 7045 2984 7046 2985 7047 2986 7048 2987 7049 8 7050 2988 7051 8 7052 2989 7053 8 7054 8 7055 8 7056 8 7057 2990 7058 8 7059 2991 7060 2992 7061 2993 7062 2994 7063 2995 7064 2996 7065 2997 7066 8 7067 2998 7068 2999 7069 8 7070 3000 7071 8 7072 3001 7073 3002 7074 3003 7075 3004 7076 3005 7077 3006 7078 3007 7079 8 7080 8 7081 3008 7082 8 7083 8 7084 3009 7085 3010 7086 3011 7087 8 7088 8 7089 8 7090 8 7091 3012 7092 8 7093 8 7094 8 7095 8 7096 3013 7097 3014 7098 3015 7099 3016 7100 3017 7101 3018 7102 3019 7103 3020 7104 3021 7105 3022 7106 3023 7107 3024 7108 3025 7109 3026 7110 3027 7111 3028 7112 3029 7113 3030 7114 3031 7115 3032 7116 3033 7117 3034 7118 3035 7119 3036 7120 3037 7121 3038 7122 3039 7123 3040 7124 3041 7125 3042 7126 3043 7127 3044 7128 3045 7129 3046 7130 3016 7131 3016 7132 3016 7133 3016 7134 3016 7135 3016 7136 3016 7137 3016 7138 3016 7139 3016 7140 3016 7141 3016 7142 3016 7143 3016 7144 3016 7145 3047 7146 3048 7147 8 7148 8 7149 8 7150 8 7151 8 7152 8 7153 3049 7154 8 7155 8 7156 3050 7157 8 7158 3051 7159 3052 7160 3053 7161 3054 7162 3055 7163 3056 7164 8 7165 3057 7166 8 7167 8 7168 8 7169 8 7170 8 7171 3058 7172 3059 7173 8 7174 8 7175 3060 7176 8 7177 3061 7178 8 7179 8 7180 3062 7181 3063 7182 8 7183 3016 7184 3016 7185 3016 7186 3016 7187 3016 7188 3064 7189 3065 7190 3066 7191 3016 7192 3016 7193 3016 7194 3016 7195 3016 7196 3016 7197 3016 7198 3016 7199 3016 7200 3016 7201 3067 7202 8 7203 8 7204 8 7205 8 7206 8 7207 8 7208 8 7209 8 7210 8 7211 8 7212 8 7213 8 7214 8 7215 8 7216 8 7217 8 7218 8 7219 8 7220 8 7221 8 7222 8 7223 8 7224 8 7225 8 7226 8 7227 8 7228 8 7229 8 7230 8 7231 8 7232 8 7233 8 7234 8 7235 8 7236 8 7237 8 7238 8 7239 8 7240 8 7241 8 7242 8 7243 8 7244 8 7245 8 7246 8 7247 8 7248 8 7249 8 7250 8 7251 8 7252 8 7253 8 7254 8 7255 8 7256 8 7257 8 7258 8 7259 8 7260 8 7261 8 7262 8 7263 8 7264 8 7265 8 7266 8 7267 8 7268 8 7269 8 7270 8 7271 8 7272 8 7273 8 7274 8 7275 8 7276 8 7277 8 7278 8 7279 8 7280 8 7281 3068 7282 8 7283 8 7284 8 7285 3069 7286 3070 7287 8 7288 3071 7289 8 7290 8 7291 3072 7292 3073 7293 3074 7294 8 7295 8 7296 3075 7297 3076 7298 3077 7299 3078 7300 8 7301 3079 7302 8 7303 3080 7304 3081 7305 3082 7306 3083 7307 3084 7308 3085 7309 3086 7310 3087 7311 3088 7312 3016 7313 3016 7314 3016 7315 3016 7316 3016 7317 3016 7318 3016 7319 3016 7320 3016 7321 3016 7322 3016 7323 3016 7324 3016 7325 3089 7326 3016 7327 3090 7328 3091 7329 8 7330 3092 7331 3093 7332 8 7333 3094 7334 8 7335 3095 7336 8 7337 8 7338 8 7339 3096 7340 3097 7341 3098 7342 8 7343 3099 7344 8 7345 8 7346 3100 7347 3101 7348 3102 7349 8 7350 8 7351 8 7352 3103 7353 3104 7354 8 7355 8 7356 8 7357 3105 7358 3106 7359 3107 7360 3108 7361 3109 7362 8 7363 3110 7364 8 7365 8 7366 3111 7367 8 7368 3112 7369 3113 7370 8 7371 8 7372 3114 7373 8 7374 8 7375 8 7376 3115 7377 3116 7378 8 7379 8 7380 3117 7381 3118 7382 3119 7383 3120 7384 3121 7385 3122 7386 3123 7387 3124 7388 3125 7389 3126 7390 3127 7391 8 7392 3128 7393 3129 7394 3130 7395 3131 7396 3132 7397 3133 7398 3134 7399 3135 7400 3136 7401 3137 7402 8 7403 8 7404 3138 7405 8 7406 3139 7407 8 7408 3140 7409 3141 7410 8 7411 8 7412 8 7413 3142 7414 8 7415 8 7416 3143 7417 3144 7418 3145 7419 3146 7420 3147 7421 8 7422 3148 7423 8 7424 8 7425 3149 7426 8 7427 3150 7428 3151 7429 8 7430 8 7431 3152 7432 8 7433 3153 7434 8 7435 3154 7436 3155 7437 3156 7438 3016 7439 3016 7440 3157 7441 3158 7442 3016 7443 3016 7444 3016 7445 3016 7446 8 7447 3159 7448 8 7449 3160 7450 8 7451 8 7452 3016 7453 3016 7454 8 7455 3016 7456 3016 7457 3161 7458 8 7459 8 7460 8 7461 8 7462 8 7463 8 7464 3162 7465 3163 7466 3164 7467 3165 7468 8 7469 3166 7470 8 7471 3167 7472 3168 7473 3169 7474 3170 7475 3171 7476 3172 7477 8 7478 3173 7479 8 7480 8 7481 8 7482 8 7483 3174 7484 8 7485 8 7486 8 7487 3175 7488 3176 7489 3177 7490 8 7491 8 7492 3178 7493 8 7494 8 7495 3179 7496 3180 7497 3181 7498 3182 7499 3183 7500 3184 7501 3185 7502 8 7503 3186 7504 8 7505 3187 7506 3188 7507 3189 7508 3190 7509 3191 7510 8 7511 3192 7512 3193 7513 3194 7514 3195 7515 3016 7516 3196 7517 3197 7518 3198 7519 8 7520 3016 7521 3016 7522 3016 7523 8 7524 3199 7525 8 7526 3200 7527 8 7528 3201 7529 3202 7530 8 7531 3203 7532 3204 7533 8 7534 3016 7535 8 7536 3016 7537 3016 7538 3016 7539 3205 7540 3206 7541 8 7542 3016 7543 3016 7544 3016 7545 3207 7546 8 7547 8 7548 3208 7549 3209 7550 8 7551 3210 7552 8 7553 3016 7554 3211 7555 3212 7556 3213 7557 3214 7558 3215 7559 3216 7560 3217 7561 3218 7562 3219 7563 3220 7564 3221 7565 8 7566 3222 7567 8 7568 3223 7569 8 7570 8 7571 3224 7572 3225 7573 3226 7574 3227 7575 8 7576 8 7577 3228 7578 3229 7579 3230 7580 3231 7581 3232 7582 8 7583 3233 7584 8 7585 3234 7586 8 7587 8 7588 8 7589 8 7590 3235 7591 8 7592 3236 7593 3237 7594 3238 7595 3239 7596 3240 7597 3241 7598 3242 7599 8 7600 3243 7601 3244 7602 8 7603 3245 7604 8 7605 3246 7606 3247 7607 3248 7608 3249 7609 3250 7610 3251 7611 3252 7612 3253 7613 8 7614 8 7615 3254 7616 8 7617 8 7618 3255 7619 3256 7620 3257 7621 8 7622 8 7623 8 7624 8 7625 3258 7626 8 7627 8 7628 8 7629 8 7630 3259 7631 3260 7632 3261 7633 3262 7634 3255 7635 3263 7636 3264 7637 3265 7638 3266 7639 3267 7640 3268 7641 3269 7642 3270 7643 3271 7644 3272 7645 3273 7646 3274 7647 3275 7648 3276 7649 3277 7650 3278 7651 3279 7652 3280 7653 3281 7654 3282 7655 3283 7656 3284 7657 3285 7658 3286 7659 3287 7660 3288 7661 3289 7662 3290 7663 3291 7664 3292 7665 3255 7666 3255 7667 3255 7668 3255 7669 3255 7670 3255 7671 3255 7672 3255 7673 3255 7674 3255 7675 3255 7676 3255 7677 3255 7678 3255 7679 3255 7680 3293 7681 3294 7682 8 7683 8 7684 8 7685 8 7686 8 7687 8 7688 3295 7689 8 7690 8 7691 3296 7692 8 7693 3297 7694 3298 7695 3299 7696 3300 7697 3301 7698 3302 7699 8 7700 3303 7701 8 7702 8 7703 8 7704 8 7705 8 7706 3304 7707 3305 7708 8 7709 8 7710 3306 7711 8 7712 3307 7713 8 7714 8 7715 3308 7716 3309 7717 8 7718 3255 7719 3255 7720 3255 7721 3255 7722 3255 7723 3310 7724 3311 7725 3312 7726 3255 7727 3255 7728 3255 7729 3255 7730 3255 7731 3255 7732 3255 7733 3255 7734 3255 7735 3255 7736 3313 7737 3314 7738 3315 7739 3316 7740 3255 7741 3317 7742 8 7743 8 7744 8 7745 8 7746 8 7747 8 7748 8 7749 8 7750 8 7751 8 7752 8 7753 8 7754 8 7755 8 7756 8 7757 8 7758 8 7759 8 7760 8 7761 8 7762 8 7763 8 7764 8 7765 8 7766 8 7767 8 7768 8 7769 8 7770 8 7771 8 7772 8 7773 8 7774 8 7775 8 7776 8 7777 8 7778 8 7779 8 7780 8 7781 8 7782 8 7783 8 7784 8 7785 8 7786 8 7787 8 7788 8 7789 8 7790 8 7791 8 7792 8 7793 8 7794 8 7795 8 7796 8 7797 8 7798 8 7799 8 7800 8 7801 8 7802 8 7803 8 7804 8 7805 8 7806 8 7807 8 7808 8 7809 8 7810 8 7811 8 7812 8 7813 8 7814 8 7815 8 7816 8 7817 8 7818 8 7819 8 7820 8 7821 3318 7822 8 7823 8 7824 8 7825 3319 7826 3320 7827 8 7828 3321 7829 8 7830 8 7831 3322 7832 3323 7833 3324 7834 8 7835 8 7836 3325 7837 3326 7838 3327 7839 3328 7840 8 7841 3329 7842 8 7843 3330 7844 3331 7845 3332 7846 3333 7847 3334 7848 3335 7849 3336 7850 3337 7851 3338 7852 3255 7853 3255 7854 3255 7855 3255 7856 3255 7857 3255 7858 3255 7859 3255 7860 3255 7861 3255 7862 3255 7863 3255 7864 3255 7865 3339 7866 3255 7867 3340 7868 3341 7869 8 7870 3342 7871 3343 7872 8 7873 3344 7874 8 7875 3345 7876 8 7877 8 7878 8 7879 3346 7880 3347 7881 3348 7882 8 7883 3349 7884 8 7885 8 7886 3350 7887 3351 7888 3352 7889 8 7890 8 7891 8 7892 3353 7893 3354 7894 8 7895 8 7896 8 7897 3355 7898 3356 7899 3357 7900 3358 7901 3359 7902 8 7903 3360 7904 8 7905 8 7906 3361 7907 8 7908 3362 7909 3363 7910 8 7911 8 7912 3364 7913 8 7914 8 7915 8 7916 3365 7917 3366 7918 8 7919 8 7920 3367 7921 3368 7922 3369 7923 3370 7924 3371 7925 3372 7926 3373 7927 3374 7928 3375 7929 3376 7930 3377 7931 8 7932 3378 7933 3379 7934 3380 7935 3381 7936 3382 7937 3383 7938 3384 7939 3385 7940 3386 7941 3387 7942 3388 7943 3389 7944 3390 7945 3391 7946 3392 7947 3393 7948 3394 7949 3395 7950 3396 7951 8 7952 3397 7953 8 7954 3398 7955 8 7956 8 7957 3399 7958 3400 7959 3401 7960 3402 7961 8 7962 8 7963 3403 7964 3404 7965 3405 7966 3406 7967 3407 7968 8 7969 3408 7970 8 7971 3409 7972 8 7973 8 7974 8 7975 8 7976 3410 7977 8 7978 3411 7979 3412 7980 3413 7981 3414 7982 3415 7983 3416 7984 3417 7985 8 7986 3418 7987 3419 7988 8 7989 3420 7990 8 7991 3421 7992 3422 7993 3423 7994 3424 7995 3425 7996 3426 7997 3427 7998 8 7999 8 8000 3428 8001 8 8002 8 8003 3429 8004 3430 8005 3431 8006 8 8007 8 8008 8 8009 8 8010 3432 8011 8 8012 8 8013 8 8014 8 8015 3433 8016 3434 8017 3435 8018 3436 8019 3437 8020 3438 8021 3439 8022 3440 8023 3441 8024 3442 8025 3443 8026 3444 8027 3445 8028 3446 8029 3447 8030 3448 8031 3449 8032 3450 8033 3451 8034 3452 8035 3453 8036 3454 8037 3455 8038 3456 8039 3457 8040 3458 8041 3459 8042 3460 8043 3461 8044 3462 8045 3463 8046 3464 8047 3465 8048 3466 8049 3436 8050 3436 8051 3436 8052 3436 8053 3436 8054 3436 8055 3436 8056 3436 8057 3436 8058 3436 8059 3436 8060 3436 8061 3436 8062 3436 8063 3436 8064 3467 8065 3468 8066 8 8067 8 8068 8 8069 8 8070 8 8071 8 8072 3469 8073 8 8074 8 8075 3470 8076 8 8077 3471 8078 3472 8079 3473 8080 3474 8081 3475 8082 3476 8083 8 8084 3477 8085 8 8086 8 8087 8 8088 8 8089 8 8090 3478 8091 3479 8092 8 8093 8 8094 3480 8095 8 8096 3481 8097 8 8098 8 8099 3482 8100 3483 8101 8 8102 3436 8103 3436 8104 3436 8105 3436 8106 3436 8107 3484 8108 3485 8109 3486 8110 3436 8111 3436 8112 3436 8113 3436 8114 3436 8115 3436 8116 3436 8117 3436 8118 3436 8119 3436 8120 3487 8121 8 8122 8 8123 8 8124 8 8125 8 8126 8 8127 8 8128 8 8129 8 8130 8 8131 8 8132 8 8133 8 8134 8 8135 8 8136 8 8137 8 8138 8 8139 8 8140 8 8141 8 8142 8 8143 8 8144 8 8145 8 8146 8 8147 8 8148 8 8149 8 8150 8 8151 8 8152 8 8153 8 8154 8 8155 8 8156 8 8157 8 8158 8 8159 8 8160 8 8161 8 8162 8 8163 8 8164 8 8165 8 8166 8 8167 8 8168 8 8169 8 8170 8 8171 8 8172 8 8173 8 8174 8 8175 8 8176 8 8177 8 8178 8 8179 8 8180 8 8181 8 8182 8 8183 8 8184 8 8185 8 8186 8 8187 8 8188 8 8189 8 8190 8 8191 8 8192 8 8193 8 8194 8 8195 8 8196 8 8197 8 8198 8 8199 8 8200 3488 8201 8 8202 8 8203 8 8204 3489 8205 3490 8206 8 8207 3491 8208 8 8209 8 8210 3492 8211 3493 8212 3494 8213 8 8214 8 8215 3495 8216 3496 8217 3497 8218 3498 8219 8 8220 3499 8221 8 8222 3500 8223 3501 8224 3502 8225 3503 8226 3504 8227 3505 8228 3506 8229 3507 8230 3508 8231 3436 8232 3436 8233 3436 8234 3436 8235 3436 8236 3436 8237 3436 8238 3436 8239 3436 8240 3436 8241 3436 8242 3436 8243 3436 8244 3509 8245 3436 8246 3510 8247 3511 8248 8 8249 3512 8250 3513 8251 8 8252 3514 8253 8 8254 3515 8255 8 8256 8 8257 8 8258 3516 8259 3517 8260 3518 8261 8 8262 3519 8263 8 8264 8 8265 3520 8266 3521 8267 3522 8268 8 8269 8 8270 8 8271 3523 8272 3524 8273 8 8274 8 8275 8 8276 3525 8277 3526 8278 3527 8279 3528 8280 3529 8281 8 8282 3530 8283 8 8284 8 8285 3531 8286 8 8287 3532 8288 3533 8289 8 8290 8 8291 3534 8292 8 8293 8 8294 8 8295 3535 8296 3536 8297 8 8298 8 8299 3537 8300 3538 8301 3539 8302 3540 8303 3541 8304 3542 8305 3543 8306 3544 8307 3545 8308 3546 8309 3547 8310 8 8311 3548 8312 3549 8313 3550 8314 3551 8315 3552 8316 3553 8317 3554 8318 3555 8319 3556 8320 3557 8321 8 8322 8 8323 3558 8324 8 8325 3559 8326 8 8327 3560 8328 3561 8329 8 8330 8 8331 8 8332 3562 8333 8 8334 8 8335 3563 8336 3564 8337 3565 8338 3566 8339 3567 8340 8 8341 3568 8342 8 8343 8 8344 3569 8345 8 8346 3570 8347 3571 8348 8 8349 8 8350 3572 8351 8 8352 3573 8353 8 8354 3574 8355 3575 8356 3576 8357 3436 8358 3436 8359 3577 8360 3578 8361 3436 8362 3436 8363 3436 8364 3436 8365 8 8366 3579 8367 8 8368 3580 8369 8 8370 8 8371 3436 8372 3436 8373 8 8374 3436 8375 3436 8376 3581 8377 8 8378 8 8379 8 8380 8 8381 8 8382 8 8383 3582 8384 3583 8385 3584 8386 3585 8387 8 8388 3586 8389 8 8390 3587 8391 3588 8392 3589 8393 3590 8394 3591 8395 3592 8396 8 8397 3593 8398 8 8399 8 8400 8 8401 8 8402 3594 8403 8 8404 8 8405 8 8406 3595 8407 3596 8408 3597 8409 8 8410 8 8411 3598 8412 8 8413 8 8414 3599 8415 3600 8416 3601 8417 3602 8418 3603 8419 3604 8420 3605 8421 8 8422 3606 8423 8 8424 3607 8425 3608 8426 3609 8427 3610 8428 3611 8429 8 8430 3612 8431 3613 8432 3614 8433 3615 8434 3436 8435 3616 8436 3617 8437 3618 8438 8 8439 3436 8440 3436 8441 3436 8442 8 8443 3619 8444 8 8445 3620 8446 8 8447 3621 8448 3622 8449 8 8450 3623 8451 3624 8452 8 8453 3436 8454 8 8455 3436 8456 3436 8457 3436 8458 3625 8459 3626 8460 8 8461 3436 8462 3436 8463 3436 8464 3627 8465 8 8466 8 8467 3628 8468 3629 8469 8 8470 3630 8471 8 8472 3436 8473 3631 8474 8 8475 3632 8476 8 8477 3633 8478 3634 8479 8 8480 8 8481 8 8482 3635 8483 8 8484 8 8485 3636 8486 3637 8487 3638 8488 3639 8489 3640 8490 8 8491 3641 8492 8 8493 8 8494 3642 8495 8 8496 3643 8497 3644 8498 8 8499 8 8500 3645 8501 8 8502 3646 8503 3647 8504 8 8505 3648 8506 3649 8507 8 8508 3650 8509 8 8510 3651 8511 8 8512 8 8513 8 8514 3652 8515 3653 8516 3654 8517 8 8518 3655 8519 8 8520 8 8521 3656 8522 3657 8523 3658 8524 8 8525 8 8526 8 8527 3659 8528 3660 8529 8 8530 8 8531 8 8532 3661 8533 3662 8534 3663 8535 3664 8536 3665 8537 8 8538 3666 8539 8 8540 8 8541 3667 8542 8 8543 3668 8544 3669 8545 8 8546 8 8547 3670 8548 8 8549 8 8550 8 8551 3671 8552 3672 8553 8 8554 3673 8555 8 8556 3674 8557 3675 8558 3676 8559 3255 8560 3255 8561 3677 8562 3678 8563 3255 8564 3255 8565 3255 8566 3255 8567 8 8568 3679 8569 8 8570 3680 8571 8 8572 8 8573 3255 8574 3255 8575 8 8576 3255 8577 3255 8578 8 8579 3681 8580 3682 8581 3683 8582 3684 8583 8 8584 8 8585 8 8586 3685 8587 3686 8588 3687 8589 8 8590 8 8591 8 8592 3688 8593 3689 8594 3690 8595 3691 8596 3692 8597 3693 8598 3694 8599 8 8600 3695 8601 3696 8602 3697 8603 3698 8604 3699 8605 8 8606 3700 8607 3701 8608 3315 8609 3702 8610 3703 8611 3704 8612 8 8613 3255 8614 3255 8615 3255 8616 8 8617 3705 8618 8 8619 3706 8620 8 8621 3707 8622 3708 8623 8 8624 3709 8625 3710 8626 8 8627 3255 8628 8 8629 3255 8630 3255 8631 3255 8632 3711 8633 3712 8634 8 8635 3255 8636 3255 8637 3255 8638 3713 8639 8 8640 8 8641 3714 8642 3715 8643 8 8644 3716 8645 8 8646 3255 8647 3717 8648 8 8649 3718 8650 8 8651 3719 8652 3720 8653 8 8654 8 8655 8 8656 3721 8657 8 8658 8 8659 8 8660 3722 8661 3723 8662 3724 8663 3725 8664 3726 8665 8 8666 3727 8667 8 8668 8 8669 3728 8670 8 8671 3729 8672 3730 8673 8 8674 8 8675 3731 8676 8 8677 8 8678 3732 8679 8 8680 3733 8681 3734 8682 3735 8683 833 8684 833 8685 3736 8686 3737 8687 833 8688 833 8689 833 8690 833 8691 8 8692 3738 8693 8 8694 3739 8695 8 8696 8 8697 833 8698 833 8699 8 8700 833 8701 833 8702 8 8703 3740 8704 3741 8705 3742 8706 3743 8707 8 8708 8 8709 8 8710 3744 8711 3745 8712 3746 8713 8 8714 8 8715 8 8716 3747 8717 3748 8718 3749 8719 3750 8720 3751 8721 3752 8722 3753 8723 8 8724 3754 8725 3755 8726 3756 8727 3757 8728 3758 8729 8 8730 3759 8731 3760 8732 2828 8733 3761 8734 3762 8735 3763 8736 8 8737 833 8738 833 8739 833 8740 8 8741 3764 8742 8 8743 3765 8744 8 8745 3766 8746 3767 8747 8 8748 3768 8749 3769 8750 8 8751 3255 8752 833 8753 8 8754 833 8755 833 8756 833 8757 3770 8758 3771 8759 8 8760 833 8761 833 8762 833 8763 3772 8764 8 8765 8 8766 3773 8767 3774 8768 8 8769 3775 8770 8 8771 833 8772 8 8773 3776 8774 3777 8775 8 8776 3778 8777 8 8778 8 8779 3779 8780 3780 8781 8 8782 3781 8783 8 8784 8 8785 3782 8786 3783 8787 3784 8788 3785 8789 3786 8790 3787 8791 3788 8792 3789 8793 3790 8794 3791 8795 3792 8796 8 8797 3793 8798 3794 8799 3795 8800 3796 8801 3797 8802 3798 8803 3799 8804 3800 8805 3801 8806 3802 8807 8 8808 3803 8809 562 8810 3804 8811 8 8812 3805 8813 8 8814 3806 8815 3807 8816 8 8817 8 8818 8 8819 3808 8820 8 8821 8 8822 3809 8823 3810 8824 3811 8825 3812 8826 3813 8827 8 8828 3814 8829 8 8830 8 8831 3815 8832 8 8833 3816 8834 3817 8835 8 8836 8 8837 3818 8838 8 8839 3819 8840 8 8841 3820 8842 3821 8843 3822 8844 670 8845 670 8846 3823 8847 3824 8848 670 8849 670 8850 670 8851 670 8852 8 8853 3825 8854 8 8855 3826 8856 8 8857 8 8858 670 8859 670 8860 8 8861 670 8862 670 8863 8 8864 3827 8865 3828 8866 3829 8867 3830 8868 8 8869 8 8870 8 8871 3831 8872 3832 8873 3833 8874 8 8875 8 8876 8 8877 3834 8878 3835 8879 3836 8880 3837 8881 3838 8882 3839 8883 3840 8884 8 8885 3841 8886 3842 8887 3843 8888 3844 8889 3845 8890 8 8891 3846 8892 3847 8893 3848 8894 3849 8895 670 8896 3850 8897 3851 8898 3852 8899 8 8900 670 8901 670 8902 670 8903 8 8904 3853 8905 8 8906 3854 8907 8 8908 3855 8909 3856 8910 8 8911 3857 8912 3858 8913 8 8914 670 8915 8 8916 670 8917 670 8918 670 8919 3859 8920 3860 8921 8 8922 670 8923 670 8924 670 8925 3861 8926 8 8927 8 8928 3862 8929 3863 8930 8 8931 3864 8932 8 8933 670 8934 562 8935 8 8936 562 8937 562 8938 3865 8939 8 8940 8 8941 3866 8942 3867 8943 3868 8944 8 8945 8 8946 562 8947 8 8948 3869 8949 3870 8950 3871 8951 3872 8952 8 8953 8 8954 8 8955 3873 8956 3874 8957 3875 8958 8 8959 8 8960 8 8961 3876 8962 3877 8963 3878 8964 3879 8965 3880 8966 3881 8967 3882 8968 8 8969 3883 8970 3884 8971 3885 8972 3886 8973 3887 8974 8 8975 3888 8976 3889 8977 3890 8978 3891 8979 562 8980 3892 8981 3893 8982 3894 8983 8 8984 562 8985 562 8986 3895 8987 8 8988 3896 8989 8 8990 3897 8991 3898 8992 8 8993 3899 8994 3900 8995 8 8996 562 8997 3901 8998 3902 8999 8 9000 3903 9001 8 9002 8 9003 8 9004 8 9005 8 9006 8 9007 8 9008 8 9009 8 9010 8 9011 8 9012 8 9013 8 9014 8 9015 8 9016 8 9017 8 9018 8 9019 8 9020 8 9021 8 9022 8 9023 8 9024 8 9025 8 9026 8 9027 8 9028 8 9029 8 9030 8 9031 8 9032 8 9033 8 9034 8 9035 8 9036 8 9037 8 9038 8 9039 8 9040 8 9041 8 9042 8 9043 8 9044 8 9045 8 9046 8 9047 8 9048 8 9049 8 9050 8 9051 8 9052 8 9053 8 9054 8 9055 8 9056 8 9057 8 9058 8 9059 8 9060 8 9061 8 9062 8 9063 8 9064 8 9065 8 9066 8 9067 8 9068 8 9069 8 9070 8 9071 8 9072 8 9073 8 9074 8 9075 8 9076 8 9077 8 9078 8 9079 8 9080 3904 9081 8 9082 8 9083 8 9084 3905 9085 3906 9086 8 9087 8 9088 3907 9089 3908 9090 3909 9091 3910 9092 8 9093 3911 9094 8 9095 3912 9096 3913 9097 3914 9098 3915 9099 3916 9100 3917 9101 3918 9102 3919 9103 3920 9104 562 9105 562 9106 562 9107 562 9108 562 9109 562 9110 562 9111 562 9112 562 9113 562 9114 562 9115 562 9116 562 9117 3921 9118 562 9119 3922 9120 3923 9121 3924 9122 8 9123 3925 9124 8 9125 3926 9126 8 9127 8 9128 8 9129 3927 9130 3928 9131 3929 9132 8 9133 3930 9134 8 9135 8 9136 3931 9137 3932 9138 3933 9139 8 9140 8 9141 8 9142 3934 9143 3935 9144 8 9145 8 9146 8 9147 3936 9148 3937 9149 3938 9150 3939 9151 3940 9152 8 9153 3941 9154 8 9155 3942 9156 8 9157 3943 9158 8 9159 8 9160 3944 9161 8 9162 8 9163 3945 9164 562 9165 3946 9166 3947 9167 3948 9168 3949 9169 3950 9170 3951 9171 3952 9172 3953 9173 3954 9174 3955 9175 3956 9176 8 9177 3957 9178 3958 9179 3959 9180 3960 9181 3961 9182 3962 9183 3963 9184 3964 9185 3965 9186 3966 9187 8 9188 3967 9189 8 9190 3968 9191 8 9192 3969 9193 3970 9194 8 9195 8 9196 8 9197 3971 9198 8 9199 8 9200 3972 9201 3973 9202 3974 9203 3975 9204 3976 9205 8 9206 3977 9207 8 9208 8 9209 3978 9210 8 9211 3979 9212 3980 9213 8 9214 8 9215 3981 9216 8 9217 3982 9218 8 9219 3983 9220 3984 9221 3985 9222 562 9223 562 9224 562 9225 562 9226 3986 9227 8 9228 3987 9229 8 9230 8 9231 562 9232 562 9233 8 9234 8 9235 562 9236 8 9237 562 9238 562 9239 562 9240 562 9241 562 9242 3988 9243 8 9244 8 9245 3989 9246 3990 9247 8 9248 3991 9249 8 9250 562 9251 3992 9252 3993 9253 3994 9254 3995 9255 8 9256 3996 9257 8 9258 3997 9259 3998 9260 3999 9261 4000 9262 4001 9263 4002 9264 4003 9265 4004 9266 4005 9267 463 9268 463 9269 463 9270 463 9271 463 9272 463 9273 463 9274 463 9275 463 9276 463 9277 463 9278 463 9279 463 9280 4006 9281 463 9282 4007 9283 4008 9284 8 9285 4009 9286 4010 9287 8 9288 4011 9289 8 9290 4012 9291 8 9292 8 9293 8 9294 4013 9295 4014 9296 4015 9297 8 9298 4016 9299 8 9300 8 9301 4017 9302 4018 9303 4019 9304 8 9305 8 9306 8 9307 4020 9308 4021 9309 8 9310 8 9311 8 9312 4022 9313 4023 9314 4024 9315 4025 9316 4026 9317 8 9318 4027 9319 8 9320 8 9321 4028 9322 8 9323 4029 9324 4030 9325 8 9326 8 9327 4031 9328 8 9329 8 9330 8 9331 4032 9332 4033 9333 8 9334 8 9335 4034 9336 4035 9337 4036 9338 4037 9339 4038 9340 4039 9341 4040 9342 4041 9343 4042 9344 4043 9345 4044 9346 8 9347 4045 9348 4046 9349 4047 9350 4048 9351 4049 9352 4050 9353 4051 9354 4052 9355 4053 9356 4054 9357 4055 9358 4056 9359 4057 9360 4058 9361 4059 9362 4060 9363 4061 9364 4062 9365 4063 9366 8 9367 4064 9368 8 9369 4065 9370 8 9371 8 9372 4066 9373 4067 9374 4068 9375 4069 9376 8 9377 8 9378 4070 9379 4071 9380 4072 9381 4073 9382 4074 9383 8 9384 4075 9385 8 9386 4076 9387 8 9388 8 9389 8 9390 8 9391 4077 9392 8 9393 4078 9394 4079 9395 4080 9396 4081 9397 4082 9398 4083 9399 4084 9400 8 9401 4085 9402 4086 9403 8 9404 4087 9405 8 9406 4088 9407 4089 9408 4090 9409 4091 9410 4092 9411 4093 9412 4094 9413 8 9414 8 9415 4095 9416 8 9417 8 9418 4096 9419 4097 9420 4098 9421 8 9422 8 9423 8 9424 8 9425 4099 9426 8 9427 8 9428 8 9429 8 9430 4100 9431 4101 9432 4102 9433 4103 9434 4104 9435 4105 9436 4106 9437 4107 9438 4108 9439 4109 9440 4110 9441 4111 9442 4112 9443 4113 9444 4114 9445 4115 9446 4116 9447 4117 9448 4118 9449 4119 9450 4120 9451 4121 9452 4122 9453 4123 9454 4124 9455 4125 9456 4126 9457 4127 9458 4128 9459 4129 9460 4130 9461 4131 9462 4132 9463 4133 9464 4103 9465 4103 9466 4103 9467 4103 9468 4103 9469 4103 9470 4103 9471 4103 9472 4103 9473 4103 9474 4103 9475 4103 9476 4103 9477 4103 9478 4103 9479 4134 9480 4135 9481 8 9482 8 9483 8 9484 8 9485 8 9486 8 9487 4136 9488 8 9489 8 9490 4137 9491 8 9492 4138 9493 4139 9494 4140 9495 4141 9496 4142 9497 4143 9498 8 9499 4144 9500 8 9501 8 9502 8 9503 8 9504 8 9505 4145 9506 4146 9507 8 9508 8 9509 4147 9510 8 9511 4148 9512 8 9513 8 9514 4149 9515 4150 9516 8 9517 4103 9518 4103 9519 4103 9520 4103 9521 4103 9522 4151 9523 4152 9524 4153 9525 4103 9526 4103 9527 4103 9528 4103 9529 4103 9530 4103 9531 4103 9532 4103 9533 4103 9534 4103 9535 4154 9536 8 9537 8 9538 8 9539 8 9540 8 9541 8 9542 8 9543 8 9544 8 9545 8 9546 8 9547 8 9548 8 9549 8 9550 8 9551 8 9552 8 9553 8 9554 8 9555 8 9556 8 9557 8 9558 8 9559 8 9560 8 9561 8 9562 8 9563 8 9564 8 9565 8 9566 8 9567 8 9568 8 9569 8 9570 8 9571 8 9572 8 9573 8 9574 8 9575 8 9576 8 9577 8 9578 8 9579 8 9580 8 9581 8 9582 8 9583 8 9584 8 9585 8 9586 8 9587 8 9588 8 9589 8 9590 8 9591 8 9592 8 9593 8 9594 8 9595 8 9596 8 9597 8 9598 8 9599 8 9600 8 9601 8 9602 8 9603 8 9604 8 9605 8 9606 8 9607 8 9608 8 9609 8 9610 8 9611 8 9612 8 9613 8 9614 8 9615 4155 9616 8 9617 8 9618 8 9619 4156 9620 4157 9621 8 9622 4158 9623 8 9624 8 9625 4159 9626 4160 9627 4161 9628 8 9629 8 9630 4162 9631 4163 9632 4164 9633 4165 9634 8 9635 4166 9636 8 9637 4167 9638 4168 9639 4169 9640 4170 9641 4171 9642 4172 9643 4173 9644 4174 9645 4175 9646 4103 9647 4103 9648 4103 9649 4103 9650 4103 9651 4103 9652 4103 9653 4103 9654 4103 9655 4103 9656 4103 9657 4103 9658 4103 9659 4176 9660 4103 9661 4177 9662 4178 9663 8 9664 4179 9665 4180 9666 8 9667 4181 9668 8 9669 4182 9670 8 9671 8 9672 8 9673 4183 9674 4184 9675 4185 9676 8 9677 4186 9678 8 9679 8 9680 4187 9681 4188 9682 4189 9683 8 9684 8 9685 8 9686 4190 9687 4191 9688 8 9689 8 9690 8 9691 4192 9692 4193 9693 4194 9694 4195 9695 4196 9696 8 9697 4197 9698 8 9699 8 9700 4198 9701 8 9702 4199 9703 4200 9704 8 9705 8 9706 4201 9707 8 9708 8 9709 8 9710 4202 9711 4203 9712 8 9713 8 9714 4204 9715 4205 9716 4206 9717 4207 9718 4208 9719 4209 9720 4210 9721 4211 9722 4212 9723 4213 9724 4214 9725 8 9726 4215 9727 4216 9728 4217 9729 4218 9730 4219 9731 4220 9732 4221 9733 4222 9734 4223 9735 4224 9736 8 9737 8 9738 4225 9739 8 9740 4226 9741 8 9742 4227 9743 4228 9744 8 9745 8 9746 8 9747 4229 9748 8 9749 8 9750 4230 9751 4231 9752 4232 9753 4233 9754 4234 9755 8 9756 4235 9757 8 9758 8 9759 4236 9760 8 9761 4237 9762 4238 9763 8 9764 8 9765 4239 9766 8 9767 4240 9768 8 9769 4241 9770 4242 9771 4243 9772 4103 9773 4103 9774 4244 9775 4245 9776 4246 9777 4247 9778 4248 9779 4249 9780 4250 9781 4251 9782 4252 9783 4253 9784 8 9785 4254 9786 8 9787 4255 9788 8 9789 8 9790 4256 9791 4257 9792 4258 9793 4259 9794 8 9795 8 9796 4260 9797 4261 9798 4262 9799 4263 9800 4264 9801 8 9802 4265 9803 8 9804 4266 9805 8 9806 8 9807 8 9808 8 9809 4267 9810 8 9811 4268 9812 4269 9813 4270 9814 4271 9815 4272 9816 4273 9817 4274 9818 8 9819 4275 9820 4276 9821 8 9822 4277 9823 8 9824 4278 9825 4279 9826 4280 9827 4281 9828 4282 9829 4283 9830 4284 9831 8 9832 8 9833 4285 9834 8 9835 8 9836 4286 9837 4287 9838 4288 9839 8 9840 8 9841 8 9842 8 9843 4289 9844 8 9845 8 9846 8 9847 8 9848 4290 9849 4291 9850 4292 9851 4293 9852 4294 9853 4295 9854 4296 9855 4297 9856 4298 9857 4299 9858 4300 9859 4301 9860 4302 9861 4303 9862 4304 9863 4305 9864 4306 9865 4307 9866 4308 9867 4309 9868 4310 9869 4311 9870 4312 9871 4313 9872 4314 9873 4315 9874 4316 9875 4317 9876 4318 9877 4319 9878 4320 9879 4321 9880 4322 9881 4323 9882 4293 9883 4293 9884 4293 9885 4293 9886 4293 9887 4293 9888 4293 9889 4293 9890 4293 9891 4293 9892 4293 9893 4293 9894 4293 9895 4293 9896 4293 9897 4324 9898 4325 9899 8 9900 8 9901 8 9902 8 9903 8 9904 8 9905 4326 9906 8 9907 8 9908 4327 9909 8 9910 4328 9911 4329 9912 4330 9913 4331 9914 4332 9915 4333 9916 8 9917 4334 9918 8 9919 8 9920 8 9921 8 9922 8 9923 4335 9924 4336 9925 8 9926 8 9927 4337 9928 8 9929 4338 9930 8 9931 8 9932 4339 9933 4340 9934 8 9935 4293 9936 4293 9937 4293 9938 4293 9939 4293 9940 4341 9941 4342 9942 4343 9943 4293 9944 4293 9945 4293 9946 4293 9947 4293 9948 4293 9949 4293 9950 4293 9951 4293 9952 4293 9953 4344 9954 8 9955 8 9956 8 9957 8 9958 8 9959 8 9960 8 9961 8 9962 8 9963 8 9964 8 9965 8 9966 8 9967 8 9968 8 9969 8 9970 8 9971 8 9972 8 9973 8 9974 8 9975 8 9976 8 9977 8 9978 8 9979 8 9980 8 9981 8 9982 8 9983 8 9984 8 9985 8 9986 8 9987 8 9988 8 9989 8 9990 8 9991 8 9992 8 9993 8 9994 8 9995 8 9996 8 9997 8 9998 8 9999 8 10000 8 10001 8 10002 8 10003 8 10004 8 10005 8 10006 8 10007 8 10008 8 10009 8 10010 8 10011 8 10012 8 10013 8 10014 8 10015 8 10016 8 10017 8 10018 8 10019 8 10020 8 10021 8 10022 8 10023 8 10024 8 10025 8 10026 8 10027 8 10028 8 10029 8 10030 8 10031 8 10032 8 10033 4345 10034 8 10035 8 10036 8 10037 4346 10038 4347 10039 8 10040 4348 10041 8 10042 8 10043 4349 10044 4350 10045 4351 10046 8 10047 8 10048 4352 10049 4353 10050 4354 10051 4355 10052 8 10053 4356 10054 8 10055 4357 10056 4358 10057 4359 10058 4360 10059 4361 10060 4362 10061 4363 10062 4364 10063 4365 10064 4293 10065 4293 10066 4293 10067 4293 10068 4293 10069 4293 10070 4293 10071 4293 10072 4293 10073 4293 10074 4293 10075 4293 10076 4293 10077 4366 10078 4293 10079 4367 10080 4368 10081 8 10082 4369 10083 4370 10084 8 10085 4371 10086 8 10087 4372 10088 8 10089 8 10090 8 10091 4373 10092 4374 10093 4375 10094 8 10095 4376 10096 8 10097 8 10098 4377 10099 4378 10100 4379 10101 8 10102 8 10103 8 10104 4380 10105 4381 10106 8 10107 8 10108 8 10109 4382 10110 4383 10111 4384 10112 4385 10113 4386 10114 8 10115 4387 10116 8 10117 8 10118 4388 10119 8 10120 4389 10121 4390 10122 8 10123 8 10124 4391 10125 8 10126 8 10127 8 10128 4392 10129 4393 10130 8 10131 8 10132 4394 10133 4395 10134 4396 10135 4397 10136 4398 10137 4399 10138 4400 10139 4401 10140 4402 10141 4403 10142 4404 10143 8 10144 4405 10145 4406 10146 4407 10147 4408 10148 4409 10149 4410 10150 4411 10151 4412 10152 4413 10153 4414 10154 8 10155 4415 10156 4103 10157 4416 10158 8 10159 4417 10160 8 10161 4418 10162 4419 10163 8 10164 8 10165 8 10166 4420 10167 8 10168 8 10169 4421 10170 4422 10171 4423 10172 4424 10173 4425 10174 8 10175 4426 10176 8 10177 8 10178 4427 10179 8 10180 4428 10181 4429 10182 8 10183 8 10184 4430 10185 8 10186 4431 10187 8 10188 4432 10189 4433 10190 4434 10191 4293 10192 4293 10193 4435 10194 4436 10195 4293 10196 4293 10197 4293 10198 4293 10199 8 10200 4437 10201 8 10202 4438 10203 8 10204 8 10205 4293 10206 4293 10207 8 10208 4293 10209 4293 10210 4439 10211 8 10212 8 10213 8 10214 8 10215 8 10216 8 10217 4440 10218 4441 10219 4442 10220 4443 10221 8 10222 4444 10223 8 10224 4445 10225 4446 10226 4447 10227 4448 10228 4449 10229 4450 10230 8 10231 4451 10232 8 10233 8 10234 8 10235 8 10236 4452 10237 8 10238 8 10239 8 10240 4453 10241 4454 10242 4455 10243 8 10244 8 10245 4456 10246 8 10247 8 10248 4457 10249 4458 10250 4459 10251 4460 10252 4461 10253 4462 10254 4463 10255 8 10256 4464 10257 8 10258 4465 10259 4466 10260 4467 10261 4468 10262 4469 10263 8 10264 4470 10265 4471 10266 4472 10267 4473 10268 4293 10269 4474 10270 4475 10271 4476 10272 8 10273 4293 10274 4293 10275 4293 10276 8 10277 4477 10278 8 10279 4478 10280 8 10281 4479 10282 4480 10283 8 10284 4481 10285 4482 10286 8 10287 4293 10288 8 10289 4293 10290 4293 10291 4293 10292 4483 10293 4484 10294 8 10295 4293 10296 4293 10297 4293 10298 4485 10299 8 10300 8 10301 4486 10302 4487 10303 8 10304 4488 10305 8 10306 4293 10307 4103 10308 4103 10309 4103 10310 8 10311 4489 10312 8 10313 4490 10314 8 10315 8 10316 4103 10317 4103 10318 8 10319 4103 10320 4103 10321 4491 10322 8 10323 8 10324 8 10325 8 10326 8 10327 8 10328 4492 10329 4493 10330 4494 10331 4495 10332 8 10333 4496 10334 8 10335 4497 10336 4498 10337 4499 10338 4500 10339 4501 10340 4502 10341 8 10342 4503 10343 8 10344 8 10345 8 10346 8 10347 4504 10348 8 10349 8 10350 8 10351 4505 10352 4506 10353 4507 10354 8 10355 8 10356 4508 10357 8 10358 8 10359 4509 10360 4510 10361 4511 10362 4512 10363 4513 10364 4514 10365 4515 10366 8 10367 4516 10368 8 10369 4517 10370 4518 10371 4519 10372 4520 10373 4521 10374 8 10375 4522 10376 4523 10377 4524 10378 4525 10379 4103 10380 4526 10381 4527 10382 4528 10383 8 10384 4103 10385 4103 10386 4103 10387 8 10388 4529 10389 8 10390 4530 10391 8 10392 4531 10393 4532 10394 8 10395 4533 10396 4534 10397 8 10398 4103 10399 8 10400 4103 10401 4103 10402 4103 10403 4535 10404 4536 10405 8 10406 4103 10407 4103 10408 4103 10409 4537 10410 8 10411 8 10412 4538 10413 4539 10414 8 10415 4540 10416 8 10417 4103 10418 4541 10419 358 10420 4542 10421 8 10422 4543 10423 8 10424 4544 10425 4545 10426 8 10427 8 10428 8 10429 4546 10430 8 10431 8 10432 4547 10433 4548 10434 4549 10435 4550 10436 4551 10437 8 10438 4552 10439 8 10440 8 10441 4553 10442 8 10443 4554 10444 4555 10445 8 10446 8 10447 4556 10448 8 10449 4557 10450 8 10451 4558 10452 4559 10453 4560 10454 463 10455 463 10456 4561 10457 4562 10458 4563 10459 4564 10460 4565 10461 4566 10462 4567 10463 4568 10464 4569 10465 4570 10466 8 10467 4571 10468 8 10469 4572 10470 8 10471 8 10472 4573 10473 4574 10474 4575 10475 4576 10476 8 10477 8 10478 4577 10479 4578 10480 4579 10481 4580 10482 4581 10483 8 10484 4582 10485 8 10486 4583 10487 8 10488 8 10489 8 10490 8 10491 4584 10492 8 10493 4585 10494 4586 10495 4587 10496 4588 10497 4589 10498 4590 10499 4591 10500 8 10501 4592 10502 4593 10503 8 10504 4594 10505 8 10506 4595 10507 4596 10508 4597 10509 4598 10510 4599 10511 4600 10512 4601 10513 8 10514 8 10515 4602 10516 8 10517 8 10518 4603 10519 4604 10520 4605 10521 8 10522 8 10523 8 10524 8 10525 4606 10526 8 10527 8 10528 8 10529 8 10530 4607 10531 4608 10532 4609 10533 4610 10534 4611 10535 4612 10536 4613 10537 4614 10538 4615 10539 4616 10540 4617 10541 4618 10542 4619 10543 4620 10544 4621 10545 4622 10546 4623 10547 4624 10548 4625 10549 4626 10550 4627 10551 4628 10552 4629 10553 4630 10554 4631 10555 4632 10556 4633 10557 4634 10558 4635 10559 4636 10560 4637 10561 4638 10562 4639 10563 4640 10564 4610 10565 4610 10566 4610 10567 4610 10568 4610 10569 4610 10570 4610 10571 4610 10572 4610 10573 4610 10574 4610 10575 4610 10576 4610 10577 4610 10578 4610 10579 4641 10580 4642 10581 8 10582 8 10583 8 10584 8 10585 8 10586 8 10587 4643 10588 8 10589 8 10590 4644 10591 8 10592 4645 10593 4646 10594 4647 10595 4648 10596 4649 10597 4650 10598 8 10599 4651 10600 8 10601 8 10602 8 10603 8 10604 8 10605 4652 10606 4653 10607 8 10608 8 10609 4654 10610 8 10611 4655 10612 8 10613 8 10614 4656 10615 4657 10616 8 10617 4610 10618 4610 10619 4610 10620 4610 10621 4610 10622 4658 10623 4659 10624 4660 10625 4610 10626 4610 10627 4610 10628 4610 10629 4610 10630 4610 10631 4610 10632 4610 10633 4610 10634 4610 10635 4661 10636 8 10637 8 10638 8 10639 8 10640 8 10641 8 10642 8 10643 8 10644 8 10645 8 10646 8 10647 8 10648 8 10649 8 10650 8 10651 8 10652 8 10653 8 10654 8 10655 8 10656 8 10657 8 10658 8 10659 8 10660 8 10661 8 10662 8 10663 8 10664 8 10665 8 10666 8 10667 8 10668 8 10669 8 10670 8 10671 8 10672 8 10673 8 10674 8 10675 8 10676 8 10677 8 10678 8 10679 8 10680 8 10681 8 10682 8 10683 8 10684 8 10685 8 10686 8 10687 8 10688 8 10689 8 10690 8 10691 8 10692 8 10693 8 10694 8 10695 8 10696 8 10697 8 10698 8 10699 8 10700 8 10701 8 10702 8 10703 8 10704 8 10705 8 10706 8 10707 8 10708 8 10709 8 10710 8 10711 8 10712 8 10713 8 10714 8 10715 4662 10716 8 10717 8 10718 8 10719 4663 10720 4664 10721 8 10722 4665 10723 8 10724 8 10725 4666 10726 4667 10727 4668 10728 8 10729 8 10730 4669 10731 4670 10732 4671 10733 4672 10734 8 10735 4673 10736 8 10737 4674 10738 4675 10739 4676 10740 4677 10741 4678 10742 4679 10743 4680 10744 4681 10745 4682 10746 4610 10747 4610 10748 4610 10749 4610 10750 4610 10751 4610 10752 4610 10753 4610 10754 4610 10755 4610 10756 4610 10757 4610 10758 4610 10759 4683 10760 4610 10761 4684 10762 4685 10763 8 10764 4686 10765 4687 10766 8 10767 4688 10768 8 10769 4689 10770 8 10771 8 10772 8 10773 4690 10774 4691 10775 4692 10776 8 10777 4693 10778 8 10779 8 10780 4694 10781 4695 10782 4696 10783 8 10784 8 10785 8 10786 4697 10787 4698 10788 8 10789 8 10790 8 10791 4699 10792 4700 10793 4701 10794 4702 10795 4703 10796 8 10797 4704 10798 8 10799 8 10800 4705 10801 8 10802 4706 10803 4707 10804 8 10805 8 10806 4708 10807 8 10808 8 10809 8 10810 4709 10811 4710 10812 8 10813 8 10814 4711 10815 4712 10816 4713 10817 4714 10818 4715 10819 4716 10820 4717 10821 4718 10822 4719 10823 4720 10824 4721 10825 8 10826 4722 10827 4723 10828 4724 10829 4725 10830 4726 10831 4727 10832 4728 10833 4729 10834 4730 10835 4731 10836 8 10837 4732 10838 463 10839 4733 10840 8 10841 4734 10842 8 10843 4735 10844 4736 10845 8 10846 8 10847 8 10848 4737 10849 8 10850 8 10851 4738 10852 4739 10853 4740 10854 4741 10855 4742 10856 8 10857 4743 10858 8 10859 8 10860 4744 10861 8 10862 4745 10863 4746 10864 8 10865 8 10866 4747 10867 8 10868 4748 10869 8 10870 4749 10871 4750 10872 4751 10873 4610 10874 4610 10875 4752 10876 4753 10877 4610 10878 4610 10879 4610 10880 4610 10881 8 10882 4754 10883 8 10884 4755 10885 8 10886 8 10887 4610 10888 4610 10889 8 10890 4610 10891 4610 10892 8 10893 4756 10894 4757 10895 4758 10896 4759 10897 8 10898 8 10899 8 10900 4760 10901 4761 10902 4762 10903 8 10904 8 10905 8 10906 4763 10907 4764 10908 4765 10909 4766 10910 4767 10911 4768 10912 4769 10913 8 10914 4770 10915 4771 10916 4772 10917 4773 10918 4774 10919 8 10920 4775 10921 4776 10922 4777 10923 4778 10924 4610 10925 4779 10926 4780 10927 4781 10928 8 10929 4610 10930 4610 10931 4610 10932 8 10933 4782 10934 8 10935 4783 10936 8 10937 4784 10938 4785 10939 8 10940 4786 10941 4787 10942 8 10943 4610 10944 8 10945 4610 10946 4610 10947 4610 10948 4788 10949 4789 10950 8 10951 4610 10952 4610 10953 4610 10954 4790 10955 8 10956 8 10957 4791 10958 4792 10959 8 10960 4793 10961 8 10962 4610 10963 463 10964 463 10965 463 10966 8 10967 4794 10968 8 10969 4795 10970 8 10971 8 10972 463 10973 463 10974 8 10975 463 10976 463 10977 8 10978 4796 10979 4797 10980 4798 10981 4799 10982 8 10983 8 10984 8 10985 4800 10986 4801 10987 4802 10988 8 10989 8 10990 8 10991 4803 10992 4804 10993 4805 10994 4806 10995 4807 10996 4808 10997 4809 10998 8 10999 4810 11000 4811 11001 4812 11002 4813 11003 4814 11004 8 11005 4815 11006 4816 11007 4817 11008 4818 11009 463 11010 4819 11011 4820 11012 4821 11013 8 11014 463 11015 463 11016 463 11017 8 11018 4822 11019 8 11020 4823 11021 8 11022 4824 11023 4825 11024 8 11025 4826 11026 4827 11027 8 11028 463 11029 8 11030 463 11031 463 11032 463 11033 4828 11034 4829 11035 8 11036 463 11037 358 11038 463 11039 463 11040 4830 11041 8 11042 8 11043 4831 11044 4832 11045 8 11046 4833 11047 8 11048 463 11049 358 11050 358 11051 358 11052 358 11053 358 11054 358 11055 358 11056 358 11057 4834 11058 8 11059 8 11060 8 11061 8 11062 8 11063 8 11064 8 11065 8 11066 8 11067 8 11068 8 11069 8 11070 8 11071 8 11072 8 11073 8 11074 8 11075 8 11076 8 11077 8 11078 8 11079 8 11080 8 11081 8 11082 8 11083 8 11084 8 11085 8 11086 8 11087 8 11088 8 11089 8 11090 8 11091 8 11092 8 11093 8 11094 8 11095 8 11096 8 11097 8 11098 8 11099 8 11100 8 11101 8 11102 8 11103 8 11104 8 11105 8 11106 8 11107 8 11108 8 11109 8 11110 8 11111 8 11112 8 11113 8 11114 8 11115 8 11116 8 11117 8 11118 8 11119 8 11120 8 11121 8 11122 8 11123 8 11124 8 11125 8 11126 8 11127 8 11128 8 11129 8 11130 8 11131 8 11132 8 11133 8 11134 8 11135 8 11136 8 11137 4835 11138 8 11139 8 11140 8 11141 4836 11142 4837 11143 8 11144 4838 11145 8 11146 8 11147 4839 11148 4840 11149 4841 11150 8 11151 8 11152 4842 11153 4843 11154 4844 11155 4845 11156 8 11157 4846 11158 8 11159 4847 11160 4848 11161 4849 11162 4850 11163 4851 11164 4852 11165 4853 11166 4854 11167 4855 11168 358 11169 358 11170 358 11171 358 11172 358 11173 358 11174 358 11175 358 11176 358 11177 358 11178 358 11179 358 11180 358 11181 4856 11182 358 11183 4857 11184 4858 11185 8 11186 4859 11187 4860 11188 8 11189 4861 11190 8 11191 4862 11192 8 11193 8 11194 8 11195 4863 11196 4864 11197 4865 11198 8 11199 4866 11200 8 11201 8 11202 4867 11203 4868 11204 4869 11205 8 11206 8 11207 8 11208 4870 11209 4871 11210 8 11211 8 11212 8 11213 4872 11214 4873 11215 4874 11216 4875 11217 4876 11218 8 11219 4877 11220 8 11221 8 11222 4878 11223 8 11224 4879 11225 4880 11226 8 11227 8 11228 4881 11229 8 11230 8 11231 8 11232 4882 11233 4883 11234 8 11235 8 11236 8 11237 4884 11238 4885 11239 4886 11240 4887 11241 4888 11242 4889 11243 4890 11244 4891 11245 4892 11246 4893 11247 4894 11248 8 11249 4895 11250 4896 11251 4897 11252 4898 11253 4899 11254 4900 11255 4901 11256 4902 11257 4903 11258 4904 11259 4905 11260 4906 11261 4907 11262 4908 11263 4909 11264 4910 11265 4911 11266 4912 11267 4913 11268 8 11269 4914 11270 8 11271 4915 11272 8 11273 8 11274 4916 11275 4917 11276 4918 11277 4919 11278 8 11279 8 11280 4920 11281 4921 11282 4922 11283 4923 11284 4924 11285 8 11286 4925 11287 8 11288 4926 11289 8 11290 8 11291 8 11292 8 11293 4927 11294 8 11295 4928 11296 4929 11297 4930 11298 4931 11299 4932 11300 4933 11301 4934 11302 8 11303 4935 11304 4936 11305 8 11306 4937 11307 8 11308 4938 11309 4939 11310 4940 11311 4941 11312 4942 11313 4943 11314 4944 11315 8 11316 8 11317 4945 11318 8 11319 8 11320 4946 11321 4947 11322 4948 11323 8 11324 8 11325 8 11326 8 11327 4949 11328 8 11329 8 11330 8 11331 8 11332 4950 11333 4951 11334 4952 11335 4953 11336 4954 11337 4955 11338 4956 11339 4957 11340 4958 11341 4959 11342 4960 11343 4961 11344 4962 11345 4963 11346 4964 11347 4965 11348 4966 11349 4967 11350 4968 11351 4969 11352 4970 11353 4971 11354 4972 11355 4973 11356 4974 11357 4975 11358 4976 11359 4977 11360 4978 11361 4979 11362 4980 11363 4981 11364 4982 11365 4983 11366 4953 11367 4953 11368 4953 11369 4953 11370 4953 11371 4953 11372 4953 11373 4953 11374 4953 11375 4953 11376 4953 11377 4953 11378 4953 11379 4953 11380 4953 11381 4984 11382 4985 11383 8 11384 8 11385 8 11386 8 11387 8 11388 8 11389 4986 11390 8 11391 8 11392 4987 11393 8 11394 4988 11395 4989 11396 4990 11397 4991 11398 4992 11399 4993 11400 8 11401 4994 11402 8 11403 8 11404 8 11405 8 11406 8 11407 4995 11408 4996 11409 8 11410 8 11411 4997 11412 8 11413 4998 11414 8 11415 8 11416 4999 11417 5000 11418 8 11419 4953 11420 4953 11421 4953 11422 4953 11423 4953 11424 5001 11425 5002 11426 5003 11427 4953 11428 4953 11429 4953 11430 4953 11431 4953 11432 4953 11433 4953 11434 4953 11435 4953 11436 4953 11437 5004 11438 8 11439 8 11440 8 11441 8 11442 8 11443 8 11444 8 11445 8 11446 8 11447 8 11448 8 11449 8 11450 8 11451 8 11452 8 11453 8 11454 8 11455 8 11456 8 11457 8 11458 8 11459 8 11460 8 11461 8 11462 8 11463 8 11464 8 11465 8 11466 8 11467 8 11468 8 11469 8 11470 8 11471 8 11472 8 11473 8 11474 8 11475 8 11476 8 11477 8 11478 8 11479 8 11480 8 11481 8 11482 8 11483 8 11484 8 11485 8 11486 8 11487 8 11488 8 11489 8 11490 8 11491 8 11492 8 11493 8 11494 8 11495 8 11496 8 11497 8 11498 8 11499 8 11500 8 11501 8 11502 8 11503 8 11504 8 11505 8 11506 8 11507 8 11508 8 11509 8 11510 8 11511 8 11512 8 11513 8 11514 8 11515 8 11516 8 11517 5005 11518 8 11519 8 11520 8 11521 5006 11522 5007 11523 8 11524 5008 11525 8 11526 8 11527 5009 11528 5010 11529 5011 11530 8 11531 8 11532 5012 11533 5013 11534 5014 11535 5015 11536 8 11537 5016 11538 8 11539 5017 11540 5018 11541 5019 11542 5020 11543 5021 11544 5022 11545 5023 11546 5024 11547 5025 11548 4953 11549 4953 11550 4953 11551 4953 11552 4953 11553 4953 11554 4953 11555 4953 11556 4953 11557 4953 11558 4953 11559 4953 11560 4953 11561 5026 11562 4953 11563 5027 11564 5028 11565 8 11566 5029 11567 5030 11568 8 11569 5031 11570 8 11571 5032 11572 8 11573 8 11574 8 11575 5033 11576 5034 11577 5035 11578 8 11579 5036 11580 8 11581 8 11582 5037 11583 5038 11584 5039 11585 8 11586 8 11587 8 11588 5040 11589 5041 11590 8 11591 8 11592 8 11593 5042 11594 5043 11595 5044 11596 5045 11597 5046 11598 8 11599 5047 11600 8 11601 8 11602 5048 11603 8 11604 5049 11605 5050 11606 8 11607 8 11608 5051 11609 8 11610 8 11611 8 11612 5052 11613 5053 11614 8 11615 8 11616 5054 11617 5055 11618 5056 11619 5057 11620 5058 11621 5059 11622 5060 11623 5061 11624 5062 11625 5063 11626 5064 11627 8 11628 5065 11629 5066 11630 5067 11631 5068 11632 5069 11633 5070 11634 5071 11635 5072 11636 5073 11637 5074 11638 8 11639 8 11640 5075 11641 8 11642 5076 11643 8 11644 5077 11645 5078 11646 8 11647 8 11648 8 11649 5079 11650 8 11651 8 11652 5080 11653 5081 11654 5082 11655 5083 11656 5084 11657 8 11658 5085 11659 8 11660 8 11661 5086 11662 8 11663 5087 11664 5088 11665 8 11666 8 11667 5089 11668 8 11669 5090 11670 8 11671 5091 11672 5092 11673 5093 11674 4953 11675 4953 11676 5094 11677 5095 11678 5096 11679 5097 11680 5098 11681 5099 11682 5100 11683 5101 11684 5102 11685 5103 11686 8 11687 5104 11688 8 11689 5105 11690 8 11691 8 11692 5106 11693 5107 11694 5108 11695 5109 11696 8 11697 8 11698 5110 11699 5111 11700 5112 11701 5113 11702 5114 11703 8 11704 5115 11705 8 11706 5116 11707 8 11708 8 11709 8 11710 8 11711 5117 11712 8 11713 5118 11714 5119 11715 5120 11716 5121 11717 5122 11718 5123 11719 5124 11720 8 11721 5125 11722 5126 11723 8 11724 5127 11725 8 11726 5128 11727 5129 11728 5130 11729 5131 11730 5132 11731 5133 11732 5134 11733 8 11734 8 11735 5135 11736 8 11737 8 11738 5136 11739 5137 11740 5138 11741 8 11742 8 11743 8 11744 8 11745 5139 11746 8 11747 8 11748 8 11749 8 11750 5140 11751 5141 11752 5142 11753 5143 11754 5144 11755 5145 11756 5146 11757 5147 11758 5148 11759 5149 11760 5150 11761 5151 11762 5152 11763 5153 11764 5154 11765 5155 11766 5156 11767 5157 11768 5158 11769 5159 11770 5160 11771 5161 11772 5162 11773 5163 11774 5164 11775 5165 11776 5166 11777 5167 11778 5168 11779 5169 11780 5170 11781 5171 11782 5172 11783 5173 11784 5143 11785 5143 11786 5143 11787 5143 11788 5143 11789 5143 11790 5143 11791 5143 11792 5143 11793 5143 11794 5143 11795 5143 11796 5143 11797 5143 11798 5143 11799 5174 11800 5175 11801 8 11802 8 11803 8 11804 8 11805 8 11806 8 11807 5176 11808 8 11809 8 11810 5177 11811 8 11812 5178 11813 5179 11814 5180 11815 5181 11816 5182 11817 5183 11818 8 11819 5184 11820 8 11821 8 11822 8 11823 8 11824 8 11825 5185 11826 5186 11827 8 11828 8 11829 5187 11830 8 11831 5188 11832 8 11833 8 11834 5189 11835 5190 11836 8 11837 5143 11838 5143 11839 5143 11840 5143 11841 5143 11842 5191 11843 5192 11844 5193 11845 5143 11846 5143 11847 5143 11848 5143 11849 5143 11850 5143 11851 5143 11852 5143 11853 5143 11854 5143 11855 5194 11856 8 11857 8 11858 8 11859 8 11860 8 11861 8 11862 8 11863 8 11864 8 11865 8 11866 8 11867 8 11868 8 11869 8 11870 8 11871 8 11872 8 11873 8 11874 8 11875 8 11876 8 11877 8 11878 8 11879 8 11880 8 11881 8 11882 8 11883 8 11884 8 11885 8 11886 8 11887 8 11888 8 11889 8 11890 8 11891 8 11892 8 11893 8 11894 8 11895 8 11896 8 11897 8 11898 8 11899 8 11900 8 11901 8 11902 8 11903 8 11904 8 11905 8 11906 8 11907 8 11908 8 11909 8 11910 8 11911 8 11912 8 11913 8 11914 8 11915 8 11916 8 11917 8 11918 8 11919 8 11920 8 11921 8 11922 8 11923 8 11924 8 11925 8 11926 8 11927 8 11928 8 11929 8 11930 8 11931 8 11932 8 11933 8 11934 8 11935 5195 11936 8 11937 8 11938 8 11939 5196 11940 5197 11941 8 11942 5198 11943 8 11944 8 11945 5199 11946 5200 11947 5201 11948 8 11949 8 11950 5202 11951 5203 11952 5204 11953 5205 11954 8 11955 5206 11956 8 11957 5207 11958 5208 11959 5209 11960 5210 11961 5211 11962 5212 11963 5213 11964 5214 11965 5215 11966 5143 11967 5143 11968 5143 11969 5143 11970 5143 11971 5143 11972 5143 11973 5143 11974 5143 11975 5143 11976 5143 11977 5143 11978 5143 11979 5216 11980 5143 11981 5217 11982 5218 11983 8 11984 5219 11985 5220 11986 8 11987 5221 11988 8 11989 5222 11990 8 11991 8 11992 8 11993 5223 11994 5224 11995 5225 11996 8 11997 5226 11998 8 11999 8 12000 5227 12001 5228 12002 5229 12003 8 12004 8 12005 8 12006 5230 12007 5231 12008 8 12009 8 12010 8 12011 5232 12012 5233 12013 5234 12014 5235 12015 5236 12016 8 12017 5237 12018 8 12019 8 12020 5238 12021 8 12022 5239 12023 5240 12024 8 12025 8 12026 5241 12027 8 12028 8 12029 8 12030 5242 12031 5243 12032 8 12033 8 12034 5244 12035 5245 12036 5246 12037 5247 12038 5248 12039 5249 12040 5250 12041 5251 12042 5252 12043 5253 12044 5254 12045 8 12046 5255 12047 5256 12048 5257 12049 5258 12050 5259 12051 5260 12052 5261 12053 5262 12054 5263 12055 5264 12056 8 12057 5265 12058 4953 12059 5266 12060 8 12061 5267 12062 8 12063 5268 12064 5269 12065 8 12066 8 12067 8 12068 5270 12069 8 12070 8 12071 5271 12072 5272 12073 5273 12074 5274 12075 5275 12076 8 12077 5276 12078 8 12079 8 12080 5277 12081 8 12082 5278 12083 5279 12084 8 12085 8 12086 5280 12087 8 12088 5281 12089 8 12090 5282 12091 5283 12092 5284 12093 5143 12094 5143 12095 5285 12096 5286 12097 5143 12098 5143 12099 5143 12100 5143 12101 8 12102 5287 12103 8 12104 5288 12105 8 12106 8 12107 5143 12108 5143 12109 8 12110 5143 12111 5143 12112 5289 12113 8 12114 8 12115 8 12116 8 12117 8 12118 8 12119 5290 12120 5291 12121 5292 12122 5293 12123 8 12124 5294 12125 8 12126 5295 12127 5296 12128 5297 12129 5298 12130 5299 12131 5300 12132 8 12133 5301 12134 8 12135 8 12136 8 12137 8 12138 5302 12139 8 12140 8 12141 8 12142 5303 12143 5304 12144 5305 12145 8 12146 8 12147 5306 12148 8 12149 8 12150 5307 12151 5308 12152 5309 12153 5310 12154 5311 12155 5312 12156 5313 12157 8 12158 5314 12159 8 12160 5315 12161 5316 12162 5317 12163 5318 12164 5319 12165 8 12166 5320 12167 5321 12168 5322 12169 5323 12170 5143 12171 5324 12172 5325 12173 5326 12174 8 12175 5143 12176 5143 12177 5143 12178 8 12179 5327 12180 8 12181 5328 12182 8 12183 5329 12184 5330 12185 8 12186 5331 12187 5332 12188 8 12189 5143 12190 8 12191 5143 12192 5143 12193 5143 12194 5333 12195 5334 12196 8 12197 5143 12198 5143 12199 5143 12200 5335 12201 8 12202 8 12203 5336 12204 5337 12205 8 12206 5338 12207 8 12208 5143 12209 4953 12210 4953 12211 4953 12212 8 12213 5339 12214 8 12215 5340 12216 8 12217 8 12218 4953 12219 4953 12220 8 12221 4953 12222 4953 12223 5341 12224 8 12225 8 12226 8 12227 8 12228 8 12229 8 12230 5342 12231 5343 12232 5344 12233 5345 12234 8 12235 5346 12236 8 12237 5347 12238 5348 12239 5349 12240 5350 12241 5351 12242 5352 12243 8 12244 5353 12245 8 12246 8 12247 8 12248 8 12249 5354 12250 8 12251 8 12252 8 12253 5355 12254 5356 12255 5357 12256 8 12257 8 12258 5358 12259 8 12260 8 12261 5359 12262 5360 12263 5361 12264 5362 12265 5363 12266 5364 12267 5365 12268 8 12269 5366 12270 8 12271 5367 12272 5368 12273 5369 12274 5370 12275 5371 12276 8 12277 5372 12278 5373 12279 5374 12280 5375 12281 4953 12282 5376 12283 5377 12284 5378 12285 8 12286 4953 12287 4953 12288 4953 12289 8 12290 5379 12291 8 12292 5380 12293 8 12294 5381 12295 5382 12296 8 12297 5383 12298 5384 12299 8 12300 4953 12301 8 12302 4953 12303 4953 12304 4953 12305 5385 12306 5386 12307 8 12308 4953 12309 4953 12310 4953 12311 5387 12312 8 12313 8 12314 5388 12315 5389 12316 8 12317 5390 12318 8 12319 4953 12320 5391 12321 8 12322 5392 12323 8 12324 5393 12325 5394 12326 8 12327 8 12328 8 12329 5395 12330 8 12331 8 12332 5396 12333 5397 12334 5398 12335 5399 12336 5400 12337 8 12338 5401 12339 8 12340 8 12341 5402 12342 8 12343 5403 12344 5404 12345 8 12346 8 12347 5405 12348 8 12349 5406 12350 8 12351 5407 12352 5408 12353 5409 12354 358 12355 358 12356 5410 12357 5411 12358 5412 12359 5413 12360 5414 12361 5415 12362 5416 12363 5417 12364 5418 12365 5419 12366 8 12367 5420 12368 8 12369 5421 12370 8 12371 8 12372 5422 12373 5423 12374 5424 12375 5425 12376 8 12377 8 12378 5426 12379 5427 12380 5428 12381 5429 12382 5430 12383 8 12384 5431 12385 8 12386 5432 12387 8 12388 8 12389 8 12390 8 12391 5433 12392 8 12393 5434 12394 5435 12395 5436 12396 5437 12397 5438 12398 5439 12399 5440 12400 8 12401 5441 12402 5442 12403 8 12404 5443 12405 8 12406 5444 12407 5445 12408 5446 12409 5447 12410 5448 12411 5449 12412 5450 12413 8 12414 8 12415 5451 12416 8 12417 8 12418 5452 12419 5453 12420 5454 12421 8 12422 8 12423 8 12424 8 12425 5455 12426 8 12427 8 12428 8 12429 8 12430 5456 12431 5457 12432 5458 12433 5459 12434 5460 12435 5461 12436 5462 12437 5463 12438 5464 12439 5465 12440 5466 12441 5467 12442 5468 12443 5469 12444 5470 12445 5471 12446 5472 12447 5473 12448 5474 12449 5475 12450 5476 12451 5477 12452 5478 12453 5479 12454 5480 12455 5481 12456 5482 12457 5483 12458 5484 12459 5485 12460 5486 12461 5487 12462 5488 12463 5489 12464 5459 12465 5459 12466 5459 12467 5459 12468 5459 12469 5459 12470 5459 12471 5459 12472 5459 12473 5459 12474 5459 12475 5459 12476 5459 12477 5459 12478 5459 12479 5490 12480 5491 12481 8 12482 8 12483 8 12484 8 12485 8 12486 8 12487 5492 12488 8 12489 8 12490 5493 12491 8 12492 5494 12493 5495 12494 5496 12495 5497 12496 5498 12497 5499 12498 8 12499 5500 12500 8 12501 8 12502 8 12503 8 12504 8 12505 5501 12506 5502 12507 8 12508 8 12509 5503 12510 8 12511 5504 12512 8 12513 8 12514 5505 12515 5506 12516 8 12517 5459 12518 5459 12519 5459 12520 5459 12521 5459 12522 5507 12523 5508 12524 5509 12525 5459 12526 5459 12527 5459 12528 5459 12529 5459 12530 5459 12531 5459 12532 5459 12533 5459 12534 5459 12535 5510 12536 8 12537 8 12538 8 12539 8 12540 8 12541 8 12542 8 12543 8 12544 8 12545 8 12546 8 12547 8 12548 8 12549 8 12550 8 12551 8 12552 8 12553 8 12554 8 12555 8 12556 8 12557 8 12558 8 12559 8 12560 8 12561 8 12562 8 12563 8 12564 8 12565 8 12566 8 12567 8 12568 8 12569 8 12570 8 12571 8 12572 8 12573 8 12574 8 12575 8 12576 8 12577 8 12578 8 12579 8 12580 8 12581 8 12582 8 12583 8 12584 8 12585 8 12586 8 12587 8 12588 8 12589 8 12590 8 12591 8 12592 8 12593 8 12594 8 12595 8 12596 8 12597 8 12598 8 12599 8 12600 8 12601 8 12602 8 12603 8 12604 8 12605 8 12606 8 12607 8 12608 8 12609 8 12610 8 12611 8 12612 8 12613 8 12614 8 12615 5511 12616 8 12617 8 12618 8 12619 5512 12620 5513 12621 8 12622 5514 12623 8 12624 8 12625 5515 12626 5516 12627 5517 12628 8 12629 8 12630 5518 12631 5519 12632 5520 12633 5521 12634 8 12635 5522 12636 8 12637 5523 12638 5524 12639 5525 12640 5526 12641 5527 12642 5528 12643 5529 12644 5530 12645 5531 12646 5459 12647 5459 12648 5459 12649 5459 12650 5459 12651 5459 12652 5459 12653 5459 12654 5459 12655 5459 12656 5459 12657 5459 12658 5459 12659 5532 12660 5459 12661 5533 12662 5534 12663 8 12664 5535 12665 5536 12666 8 12667 5537 12668 8 12669 5538 12670 8 12671 8 12672 8 12673 5539 12674 5540 12675 5541 12676 8 12677 5542 12678 8 12679 8 12680 5543 12681 5544 12682 5545 12683 8 12684 8 12685 8 12686 5546 12687 5547 12688 8 12689 8 12690 8 12691 5548 12692 5549 12693 5550 12694 5551 12695 5552 12696 8 12697 5553 12698 8 12699 8 12700 5554 12701 8 12702 5555 12703 5556 12704 8 12705 8 12706 5557 12707 8 12708 8 12709 8 12710 5558 12711 5559 12712 8 12713 8 12714 5560 12715 5561 12716 5562 12717 5563 12718 5564 12719 5565 12720 5566 12721 5567 12722 5568 12723 5569 12724 5570 12725 8 12726 5571 12727 5572 12728 5573 12729 5574 12730 5575 12731 5576 12732 5577 12733 5578 12734 5579 12735 5580 12736 8 12737 5581 12738 358 12739 5582 12740 8 12741 5583 12742 8 12743 5584 12744 5585 12745 8 12746 8 12747 8 12748 5586 12749 8 12750 8 12751 5587 12752 5588 12753 5589 12754 5590 12755 5591 12756 8 12757 5592 12758 8 12759 8 12760 5593 12761 8 12762 5594 12763 5595 12764 8 12765 8 12766 5596 12767 8 12768 5597 12769 8 12770 5598 12771 5599 12772 5600 12773 5459 12774 5459 12775 5601 12776 5602 12777 5459 12778 5459 12779 5459 12780 5459 12781 8 12782 5603 12783 8 12784 5604 12785 8 12786 8 12787 5459 12788 5459 12789 8 12790 5459 12791 5459 12792 8 12793 5605 12794 5606 12795 5607 12796 5608 12797 8 12798 8 12799 8 12800 5609 12801 5610 12802 5611 12803 8 12804 8 12805 8 12806 5612 12807 5613 12808 5614 12809 5615 12810 5616 12811 5617 12812 5618 12813 8 12814 5619 12815 5620 12816 5621 12817 5622 12818 5623 12819 8 12820 5624 12821 5625 12822 5626 12823 5627 12824 5459 12825 5628 12826 5629 12827 5630 12828 8 12829 5459 12830 5459 12831 5459 12832 8 12833 5631 12834 8 12835 5632 12836 8 12837 5633 12838 5634 12839 8 12840 5635 12841 5636 12842 8 12843 5459 12844 8 12845 5459 12846 5459 12847 5459 12848 5637 12849 5638 12850 8 12851 5459 12852 5459 12853 5459 12854 5639 12855 8 12856 8 12857 5640 12858 5641 12859 8 12860 5642 12861 8 12862 5459 12863 358 12864 358 12865 358 12866 8 12867 5643 12868 8 12869 5644 12870 8 12871 8 12872 358 12873 358 12874 8 12875 358 12876 358 12877 8 12878 5645 12879 5646 12880 5647 12881 5648 12882 8 12883 8 12884 8 12885 5649 12886 5650 12887 5651 12888 8 12889 8 12890 8 12891 5652 12892 5653 12893 5654 12894 5655 12895 5656 12896 5657 12897 5658 12898 8 12899 5659 12900 5660 12901 5661 12902 5662 12903 5663 12904 8 12905 5664 12906 5665 12907 5666 12908 5667 12909 358 12910 5668 12911 5669 12912 5670 12913 8 12914 358 12915 358 12916 358 12917 8 12918 5671 12919 8 12920 5672 12921 8 12922 5673 12923 5674 12924 8 12925 5675 12926 5676 12927 8 12928 358 12929 8 12930 358 12931 358 12932 358 12933 5677 12934 5678 12935 8 12936 358 12937 358 12938 358 12939 5679 12940 8 12941 8 12942 5680 12943 5681 12944 8 12945 5682 12946 8 12947 358 12948 8 12949 8 12950 8 12951 8 12952 5683 12953 5684 12954 8 12955 8 12956 5685 12957 8 12958 5686 12959 8 12960 8 12961 5687 12962 5688 12963 8 12964 275 12965 275 12966 275 12967 275 12968 275 12969 5689 12970 5690 12971 5691 12972 275 12973 275 12974 275 12975 275 12976 275 12977 275 12978 275 12979 275 12980 275 12981 275 12982 5692 12983 8 12984 8 12985 8 12986 8 12987 8 12988 8 12989 8 12990 8 12991 8 12992 8 12993 8 12994 8 12995 8 12996 8 12997 8 12998 8 12999 8 13000 8 13001 8 13002 8 13003 8 13004 8 13005 8 13006 8 13007 8 13008 8 13009 8 13010 8 13011 8 13012 8 13013 8 13014 8 13015 8 13016 8 13017 8 13018 8 13019 8 13020 8 13021 8 13022 8 13023 8 13024 8 13025 8 13026 8 13027 8 13028 8 13029 8 13030 8 13031 8 13032 8 13033 8 13034 8 13035 8 13036 8 13037 8 13038 8 13039 8 13040 8 13041 8 13042 8 13043 8 13044 8 13045 8 13046 8 13047 8 13048 8 13049 8 13050 8 13051 8 13052 8 13053 8 13054 8 13055 8 13056 8 13057 8 13058 8 13059 8 13060 8 13061 8 13062 5693 13063 8 13064 8 13065 8 13066 5694 13067 5695 13068 8 13069 5696 13070 8 13071 8 13072 5697 13073 5698 13074 5699 13075 8 13076 8 13077 5700 13078 5701 13079 5702 13080 5703 13081 8 13082 5704 13083 8 13084 5705 13085 5706 13086 5707 13087 5708 13088 5709 13089 5710 13090 5711 13091 5712 13092 5713 13093 275 13094 275 13095 275 13096 275 13097 275 13098 275 13099 275 13100 275 13101 275 13102 275 13103 275 13104 275 13105 275 13106 5714 13107 275 13108 5715 13109 5716 13110 8 13111 5717 13112 5718 13113 8 13114 5719 13115 8 13116 5720 13117 8 13118 8 13119 8 13120 5721 13121 5722 13122 5723 13123 8 13124 5724 13125 8 13126 8 13127 5725 13128 5726 13129 5727 13130 8 13131 8 13132 8 13133 5728 13134 5729 13135 8 13136 8 13137 8 13138 5730 13139 5731 13140 5732 13141 5733 13142 5734 13143 8 13144 5735 13145 8 13146 8 13147 5736 13148 8 13149 5737 13150 5738 13151 8 13152 8 13153 5739 13154 8 13155 8 13156 8 13157 5740 13158 5741 13159 8 13160 8 13161 5742 13162 5743 13163 5744 13164 5745 13165 5746 13166 5747 13167 5748 13168 5749 13169 5750 13170 5751 13171 5752 13172 8 13173 5753 13174 5754 13175 5755 13176 5756 13177 5757 13178 5758 13179 5759 13180 5760 13181 5761 13182 5762 13183 5763 13184 5764 13185 5765 13186 5766 13187 5767 13188 5768 13189 5769 13190 5770 13191 5771 13192 8 13193 5772 13194 8 13195 5773 13196 8 13197 8 13198 5774 13199 5775 13200 5776 13201 5777 13202 8 13203 8 13204 5778 13205 5779 13206 5780 13207 5781 13208 5782 13209 8 13210 5783 13211 8 13212 5784 13213 8 13214 8 13215 8 13216 8 13217 5785 13218 8 13219 5786 13220 5787 13221 5788 13222 5789 13223 5790 13224 5791 13225 5792 13226 8 13227 5793 13228 5794 13229 8 13230 5795 13231 8 13232 5796 13233 5797 13234 5798 13235 5799 13236 5800 13237 5801 13238 5802 13239 8 13240 8 13241 5803 13242 8 13243 8 13244 5804 13245 5805 13246 5806 13247 8 13248 8 13249 8 13250 8 13251 5807 13252 8 13253 8 13254 8 13255 8 13256 5808 13257 5809 13258 5810 13259 5811 13260 5812 13261 5813 13262 5814 13263 5815 13264 5816 13265 5817 13266 5818 13267 5819 13268 5820 13269 5821 13270 5822 13271 5823 13272 5824 13273 5825 13274 5826 13275 5827 13276 5828 13277 5829 13278 5830 13279 5831 13280 5832 13281 5833 13282 5834 13283 5835 13284 5836 13285 5837 13286 5838 13287 5839 13288 5840 13289 5841 13290 5811 13291 5811 13292 5811 13293 5811 13294 5811 13295 5811 13296 5811 13297 5811 13298 5811 13299 5811 13300 5811 13301 5811 13302 5811 13303 5811 13304 5811 13305 5842 13306 5843 13307 8 13308 8 13309 8 13310 8 13311 8 13312 8 13313 5844 13314 8 13315 8 13316 5845 13317 8 13318 5846 13319 5847 13320 5848 13321 5849 13322 5850 13323 5851 13324 8 13325 5852 13326 8 13327 8 13328 8 13329 8 13330 8 13331 5853 13332 5854 13333 8 13334 8 13335 5855 13336 8 13337 5856 13338 8 13339 8 13340 5857 13341 5858 13342 8 13343 5811 13344 5811 13345 5811 13346 5811 13347 5811 13348 5859 13349 5860 13350 5861 13351 5811 13352 5811 13353 5811 13354 5811 13355 5811 13356 5811 13357 5811 13358 5811 13359 5811 13360 5811 13361 5862 13362 8 13363 8 13364 8 13365 8 13366 8 13367 8 13368 8 13369 8 13370 8 13371 8 13372 8 13373 8 13374 8 13375 8 13376 8 13377 8 13378 8 13379 8 13380 8 13381 8 13382 8 13383 8 13384 8 13385 8 13386 8 13387 8 13388 8 13389 8 13390 8 13391 8 13392 8 13393 8 13394 8 13395 8 13396 8 13397 8 13398 8 13399 8 13400 8 13401 8 13402 8 13403 8 13404 8 13405 8 13406 8 13407 8 13408 8 13409 8 13410 8 13411 8 13412 8 13413 8 13414 8 13415 8 13416 8 13417 8 13418 8 13419 8 13420 8 13421 8 13422 8 13423 8 13424 8 13425 8 13426 8 13427 8 13428 8 13429 8 13430 8 13431 8 13432 8 13433 8 13434 8 13435 8 13436 8 13437 8 13438 8 13439 8 13440 8 13441 5863 13442 8 13443 8 13444 8 13445 5864 13446 5865 13447 8 13448 5866 13449 8 13450 8 13451 5867 13452 5868 13453 5869 13454 8 13455 8 13456 5870 13457 5871 13458 5872 13459 5873 13460 8 13461 5874 13462 8 13463 5875 13464 5876 13465 5877 13466 5878 13467 5879 13468 5880 13469 5881 13470 5882 13471 5883 13472 5811 13473 5811 13474 5811 13475 5811 13476 5811 13477 5811 13478 5811 13479 5811 13480 5811 13481 5811 13482 5811 13483 5811 13484 5811 13485 5884 13486 5811 13487 5885 13488 5886 13489 8 13490 5887 13491 5888 13492 8 13493 5889 13494 8 13495 5890 13496 8 13497 8 13498 8 13499 5891 13500 5892 13501 5893 13502 8 13503 5894 13504 8 13505 8 13506 5895 13507 5896 13508 5897 13509 8 13510 8 13511 8 13512 5898 13513 5899 13514 8 13515 8 13516 8 13517 5900 13518 5901 13519 5902 13520 5903 13521 5904 13522 8 13523 5905 13524 8 13525 8 13526 5906 13527 8 13528 5907 13529 5908 13530 8 13531 8 13532 5909 13533 8 13534 8 13535 8 13536 5910 13537 5911 13538 8 13539 8 13540 5912 13541 5913 13542 5914 13543 5915 13544 5916 13545 5917 13546 5918 13547 5919 13548 5920 13549 5921 13550 5922 13551 8 13552 5923 13553 5924 13554 5925 13555 5926 13556 5927 13557 5928 13558 5929 13559 5930 13560 5931 13561 5932 13562 8 13563 8 13564 5933 13565 8 13566 5934 13567 8 13568 5935 13569 5936 13570 8 13571 8 13572 8 13573 5937 13574 8 13575 8 13576 5938 13577 5939 13578 5940 13579 5941 13580 5942 13581 8 13582 5943 13583 8 13584 8 13585 5944 13586 8 13587 5945 13588 5946 13589 8 13590 8 13591 5947 13592 8 13593 5948 13594 8 13595 5949 13596 5950 13597 5951 13598 5811 13599 5811 13600 5952 13601 5953 13602 5954 13603 5955 13604 5956 13605 5957 13606 5958 13607 5959 13608 5960 13609 5961 13610 8 13611 5962 13612 8 13613 5963 13614 8 13615 8 13616 5964 13617 5965 13618 5966 13619 5967 13620 8 13621 8 13622 5968 13623 5969 13624 5970 13625 5971 13626 5972 13627 8 13628 5973 13629 8 13630 5974 13631 8 13632 8 13633 8 13634 8 13635 5975 13636 8 13637 5976 13638 5977 13639 5978 13640 5979 13641 5980 13642 5981 13643 5982 13644 8 13645 5983 13646 5984 13647 8 13648 5985 13649 8 13650 5986 13651 5987 13652 5988 13653 5989 13654 5990 13655 5991 13656 5992 13657 8 13658 8 13659 5993 13660 8 13661 8 13662 5994 13663 5995 13664 5996 13665 8 13666 8 13667 8 13668 8 13669 5997 13670 8 13671 8 13672 8 13673 8 13674 5998 13675 5999 13676 6000 13677 6001 13678 6002 13679 6003 13680 6004 13681 6005 13682 6006 13683 6007 13684 6008 13685 6009 13686 6010 13687 6011 13688 6012 13689 6013 13690 6014 13691 6015 13692 6016 13693 6017 13694 6018 13695 6019 13696 6020 13697 6021 13698 6022 13699 6023 13700 6024 13701 6025 13702 6026 13703 6027 13704 6028 13705 6029 13706 6030 13707 6031 13708 6001 13709 6001 13710 6001 13711 6001 13712 6001 13713 6001 13714 6001 13715 6001 13716 6001 13717 6001 13718 6001 13719 6001 13720 6001 13721 6001 13722 6001 13723 6032 13724 6033 13725 8 13726 8 13727 8 13728 8 13729 8 13730 8 13731 6034 13732 8 13733 8 13734 6035 13735 8 13736 6036 13737 6037 13738 6038 13739 6039 13740 6040 13741 6041 13742 8 13743 6042 13744 8 13745 8 13746 8 13747 8 13748 8 13749 6043 13750 6044 13751 8 13752 8 13753 6045 13754 8 13755 6046 13756 8 13757 8 13758 6047 13759 6048 13760 8 13761 6001 13762 6001 13763 6001 13764 6001 13765 6001 13766 6049 13767 6050 13768 6051 13769 6001 13770 6001 13771 6001 13772 6001 13773 6001 13774 6001 13775 6001 13776 6001 13777 6001 13778 6001 13779 6052 13780 8 13781 8 13782 8 13783 8 13784 8 13785 8 13786 8 13787 8 13788 8 13789 8 13790 8 13791 8 13792 8 13793 8 13794 8 13795 8 13796 8 13797 8 13798 8 13799 8 13800 8 13801 8 13802 8 13803 8 13804 8 13805 8 13806 8 13807 8 13808 8 13809 8 13810 8 13811 8 13812 8 13813 8 13814 8 13815 8 13816 8 13817 8 13818 8 13819 8 13820 8 13821 8 13822 8 13823 8 13824 8 13825 8 13826 8 13827 8 13828 8 13829 8 13830 8 13831 8 13832 8 13833 8 13834 8 13835 8 13836 8 13837 8 13838 8 13839 8 13840 8 13841 8 13842 8 13843 8 13844 8 13845 8 13846 8 13847 8 13848 8 13849 8 13850 8 13851 8 13852 8 13853 8 13854 8 13855 8 13856 8 13857 8 13858 8 13859 6053 13860 8 13861 8 13862 8 13863 6054 13864 6055 13865 8 13866 6056 13867 8 13868 8 13869 6057 13870 6058 13871 6059 13872 8 13873 8 13874 6060 13875 6061 13876 6062 13877 6063 13878 8 13879 6064 13880 8 13881 6065 13882 6066 13883 6067 13884 6068 13885 6069 13886 6070 13887 6071 13888 6072 13889 6073 13890 6001 13891 6001 13892 6001 13893 6001 13894 6001 13895 6001 13896 6001 13897 6001 13898 6001 13899 6001 13900 6001 13901 6001 13902 6001 13903 6074 13904 6001 13905 6075 13906 6076 13907 8 13908 6077 13909 6078 13910 8 13911 6079 13912 8 13913 6080 13914 8 13915 8 13916 8 13917 6081 13918 6082 13919 6083 13920 8 13921 6084 13922 8 13923 8 13924 6085 13925 6086 13926 6087 13927 8 13928 8 13929 8 13930 6088 13931 6089 13932 8 13933 8 13934 8 13935 6090 13936 6091 13937 6092 13938 6093 13939 6094 13940 8 13941 6095 13942 8 13943 8 13944 6096 13945 8 13946 6097 13947 6098 13948 8 13949 8 13950 6099 13951 8 13952 8 13953 8 13954 6100 13955 6101 13956 8 13957 8 13958 6102 13959 6103 13960 6104 13961 6105 13962 6106 13963 6107 13964 6108 13965 6109 13966 6110 13967 6111 13968 6112 13969 8 13970 6113 13971 6114 13972 6115 13973 6116 13974 6117 13975 6118 13976 6119 13977 6120 13978 6121 13979 6122 13980 8 13981 6123 13982 5811 13983 6124 13984 8 13985 6125 13986 8 13987 6126 13988 6127 13989 8 13990 8 13991 8 13992 6128 13993 8 13994 8 13995 6129 13996 6130 13997 6131 13998 6132 13999 6133 14000 8 14001 6134 14002 8 14003 8 14004 6135 14005 8 14006 6136 14007 6137 14008 8 14009 8 14010 6138 14011 8 14012 6139 14013 8 14014 6140 14015 6141 14016 6142 14017 6001 14018 6001 14019 6143 14020 6144 14021 6001 14022 6001 14023 6001 14024 6001 14025 8 14026 6145 14027 8 14028 6146 14029 8 14030 8 14031 6001 14032 6001 14033 8 14034 6001 14035 6001 14036 6147 14037 8 14038 8 14039 8 14040 8 14041 8 14042 8 14043 6148 14044 6149 14045 6150 14046 6151 14047 8 14048 6152 14049 8 14050 6153 14051 6154 14052 6155 14053 6156 14054 6157 14055 6158 14056 8 14057 6159 14058 8 14059 8 14060 8 14061 8 14062 6160 14063 8 14064 8 14065 8 14066 6161 14067 6162 14068 6163 14069 8 14070 8 14071 6164 14072 8 14073 8 14074 6165 14075 6166 14076 6167 14077 6168 14078 6169 14079 6170 14080 6171 14081 8 14082 6172 14083 8 14084 6173 14085 6174 14086 6175 14087 6176 14088 6177 14089 8 14090 6178 14091 6179 14092 6180 14093 6181 14094 6001 14095 6182 14096 6183 14097 6184 14098 8 14099 6001 14100 6001 14101 6001 14102 8 14103 6185 14104 8 14105 6186 14106 8 14107 6187 14108 6188 14109 8 14110 6189 14111 6190 14112 8 14113 6001 14114 8 14115 6001 14116 6001 14117 6001 14118 6191 14119 6192 14120 8 14121 6001 14122 6001 14123 6001 14124 6193 14125 8 14126 8 14127 6194 14128 6195 14129 8 14130 6196 14131 8 14132 6001 14133 5811 14134 5811 14135 5811 14136 8 14137 6197 14138 8 14139 6198 14140 8 14141 8 14142 5811 14143 5811 14144 8 14145 5811 14146 5811 14147 6199 14148 8 14149 8 14150 8 14151 8 14152 8 14153 8 14154 6200 14155 6201 14156 6202 14157 6203 14158 8 14159 6204 14160 8 14161 6205 14162 6206 14163 6207 14164 6208 14165 6209 14166 6210 14167 8 14168 6211 14169 8 14170 8 14171 8 14172 8 14173 6212 14174 8 14175 8 14176 8 14177 6213 14178 6214 14179 6215 14180 8 14181 8 14182 6216 14183 8 14184 8 14185 6217 14186 6218 14187 6219 14188 6220 14189 6221 14190 6222 14191 6223 14192 8 14193 6224 14194 8 14195 6225 14196 6226 14197 6227 14198 6228 14199 6229 14200 8 14201 6230 14202 6231 14203 6232 14204 6233 14205 5811 14206 6234 14207 6235 14208 6236 14209 8 14210 5811 14211 5811 14212 5811 14213 8 14214 6237 14215 8 14216 6238 14217 8 14218 6239 14219 6240 14220 8 14221 6241 14222 6242 14223 8 14224 5811 14225 8 14226 5811 14227 5811 14228 5811 14229 6243 14230 6244 14231 8 14232 5811 14233 5811 14234 5811 14235 6245 14236 8 14237 8 14238 6246 14239 6247 14240 8 14241 6248 14242 8 14243 5811 14244 8 14245 6249 14246 8 14247 6250 14248 8 14249 6251 14250 6252 14251 8 14252 8 14253 8 14254 6253 14255 8 14256 8 14257 6254 14258 6255 14259 6256 14260 6257 14261 6258 14262 8 14263 6259 14264 8 14265 8 14266 6260 14267 8 14268 6261 14269 6262 14270 8 14271 8 14272 6263 14273 8 14274 6264 14275 8 14276 6265 14277 6266 14278 6267 14279 275 14280 275 14281 6268 14282 6269 14283 6270 14284 6271 14285 6272 14286 6273 14287 6274 14288 6275 14289 6276 14290 6277 14291 8 14292 6278 14293 8 14294 6279 14295 8 14296 8 14297 6280 14298 6281 14299 6282 14300 6283 14301 8 14302 8 14303 6284 14304 6285 14305 6286 14306 6287 14307 6288 14308 8 14309 6289 14310 8 14311 6290 14312 8 14313 8 14314 8 14315 8 14316 6291 14317 8 14318 6292 14319 6293 14320 6294 14321 6295 14322 6296 14323 6297 14324 6298 14325 8 14326 6299 14327 6300 14328 8 14329 6301 14330 8 14331 6302 14332 6303 14333 6304 14334 6305 14335 6306 14336 6307 14337 6308 14338 8 14339 8 14340 6309 14341 8 14342 8 14343 6310 14344 6311 14345 6312 14346 8 14347 8 14348 8 14349 8 14350 6313 14351 8 14352 8 14353 8 14354 8 14355 6314 14356 6315 14357 6316 14358 6317 14359 6318 14360 6319 14361 6320 14362 6321 14363 6322 14364 6323 14365 6324 14366 6325 14367 6326 14368 6327 14369 6328 14370 6329 14371 6330 14372 6331 14373 6332 14374 6333 14375 6334 14376 6335 14377 6336 14378 6337 14379 6338 14380 6339 14381 6340 14382 6341 14383 6342 14384 6343 14385 6344 14386 6345 14387 6346 14388 6347 14389 6317 14390 6317 14391 6317 14392 6317 14393 6317 14394 6317 14395 6317 14396 6317 14397 6317 14398 6317 14399 6317 14400 6317 14401 6317 14402 6317 14403 6317 14404 6348 14405 6349 14406 8 14407 8 14408 8 14409 8 14410 8 14411 8 14412 6350 14413 8 14414 8 14415 6351 14416 8 14417 6352 14418 6353 14419 6354 14420 6355 14421 6356 14422 6357 14423 8 14424 6358 14425 8 14426 8 14427 8 14428 8 14429 8 14430 6359 14431 6360 14432 8 14433 8 14434 6361 14435 8 14436 6362 14437 8 14438 8 14439 6363 14440 6364 14441 8 14442 6317 14443 6317 14444 6317 14445 6317 14446 6317 14447 6365 14448 6366 14449 6367 14450 6317 14451 6317 14452 6317 14453 6317 14454 6317 14455 6317 14456 6317 14457 6317 14458 6317 14459 6317 14460 6368 14461 8 14462 8 14463 8 14464 8 14465 8 14466 8 14467 8 14468 8 14469 8 14470 8 14471 8 14472 8 14473 8 14474 8 14475 8 14476 8 14477 8 14478 8 14479 8 14480 8 14481 8 14482 8 14483 8 14484 8 14485 8 14486 8 14487 8 14488 8 14489 8 14490 8 14491 8 14492 8 14493 8 14494 8 14495 8 14496 8 14497 8 14498 8 14499 8 14500 8 14501 8 14502 8 14503 8 14504 8 14505 8 14506 8 14507 8 14508 8 14509 8 14510 8 14511 8 14512 8 14513 8 14514 8 14515 8 14516 8 14517 8 14518 8 14519 8 14520 8 14521 8 14522 8 14523 8 14524 8 14525 8 14526 8 14527 8 14528 8 14529 8 14530 8 14531 8 14532 8 14533 8 14534 8 14535 8 14536 8 14537 8 14538 8 14539 8 14540 6369 14541 8 14542 8 14543 8 14544 6370 14545 6371 14546 8 14547 6372 14548 8 14549 8 14550 6373 14551 6374 14552 6375 14553 8 14554 8 14555 6376 14556 6377 14557 6378 14558 6379 14559 8 14560 6380 14561 8 14562 6381 14563 6382 14564 6383 14565 6384 14566 6385 14567 6386 14568 6387 14569 6388 14570 6389 14571 6317 14572 6317 14573 6317 14574 6317 14575 6317 14576 6317 14577 6317 14578 6317 14579 6317 14580 6317 14581 6317 14582 6317 14583 6317 14584 6390 14585 6317 14586 6391 14587 6392 14588 8 14589 6393 14590 6394 14591 8 14592 6395 14593 8 14594 6396 14595 8 14596 8 14597 8 14598 6397 14599 6398 14600 6399 14601 8 14602 6400 14603 8 14604 8 14605 6401 14606 6402 14607 6403 14608 8 14609 8 14610 8 14611 6404 14612 6405 14613 8 14614 8 14615 8 14616 6406 14617 6407 14618 6408 14619 6409 14620 6410 14621 8 14622 6411 14623 8 14624 8 14625 6412 14626 8 14627 6413 14628 6414 14629 8 14630 8 14631 6415 14632 8 14633 8 14634 8 14635 6416 14636 6417 14637 8 14638 8 14639 6418 14640 6419 14641 6420 14642 6421 14643 6422 14644 6423 14645 6424 14646 6425 14647 6426 14648 6427 14649 6428 14650 8 14651 6429 14652 6430 14653 6431 14654 6432 14655 6433 14656 6434 14657 6435 14658 6436 14659 6437 14660 6438 14661 8 14662 6439 14663 275 14664 6440 14665 8 14666 6441 14667 8 14668 6442 14669 6443 14670 8 14671 8 14672 8 14673 6444 14674 8 14675 8 14676 6445 14677 6446 14678 6447 14679 6448 14680 6449 14681 8 14682 6450 14683 8 14684 8 14685 6451 14686 8 14687 6452 14688 6453 14689 8 14690 8 14691 6454 14692 8 14693 6455 14694 8 14695 6456 14696 6457 14697 6458 14698 6317 14699 6317 14700 6459 14701 6460 14702 6317 14703 6317 14704 6317 14705 6317 14706 8 14707 6461 14708 8 14709 6462 14710 8 14711 8 14712 6317 14713 6317 14714 8 14715 6317 14716 6317 14717 8 14718 6463 14719 6464 14720 6465 14721 6466 14722 8 14723 8 14724 8 14725 6467 14726 6468 14727 6469 14728 8 14729 8 14730 8 14731 6470 14732 6471 14733 6472 14734 6473 14735 6474 14736 6475 14737 6476 14738 8 14739 6477 14740 6478 14741 6479 14742 6480 14743 6481 14744 8 14745 6482 14746 6483 14747 6484 14748 6485 14749 6317 14750 6486 14751 6487 14752 6488 14753 8 14754 6317 14755 6317 14756 6317 14757 8 14758 6489 14759 8 14760 6490 14761 8 14762 6491 14763 6492 14764 8 14765 6493 14766 6494 14767 8 14768 6317 14769 8 14770 6317 14771 6317 14772 6317 14773 6495 14774 6496 14775 8 14776 6317 14777 6317 14778 6317 14779 6497 14780 8 14781 8 14782 6498 14783 6499 14784 8 14785 6500 14786 8 14787 6317 14788 275 14789 275 14790 275 14791 8 14792 6501 14793 8 14794 6502 14795 8 14796 8 14797 275 14798 275 14799 8 14800 275 14801 275 14802 8 14803 6503 14804 6504 14805 6505 14806 6506 14807 8 14808 8 14809 8 14810 6507 14811 6508 14812 6509 14813 8 14814 8 14815 8 14816 6510 14817 6511 14818 6512 14819 6513 14820 6514 14821 6515 14822 6516 14823 8 14824 6517 14825 6518 14826 6519 14827 6520 14828 6521 14829 8 14830 6522 14831 6523 14832 6524 14833 6525 14834 275 14835 6526 14836 6527 14837 6528 14838 8 14839 275 14840 275 14841 275 14842 8 14843 6529 14844 8 14845 6530 14846 8 14847 6531 14848 6532 14849 8 14850 6533 14851 6534 14852 8 14853 275 14854 8 14855 275 14856 275 14857 275 14858 6535 14859 6536 14860 8 14861 275 14862 275 14863 275 14864 6537 14865 8 14866 8 14867 6538 14868 6539 14869 8 14870 6540 14871 8 14872 275 14873 6541 14874 8 14875 8 14876 8 14877 8 14878 8 14879 6542 14880 6543 14881 8 14882 8 14883 6544 14884 8 14885 6545 14886 8 14887 8 14888 6546 14889 6547 14890 8 14891 186 14892 186 14893 186 14894 186 14895 186 14896 6548 14897 6549 14898 6550 14899 186 14900 186 14901 186 14902 186 14903 186 14904 186 14905 186 14906 186 14907 186 14908 186 14909 6551 14910 8 14911 8 14912 8 14913 8 14914 8 14915 8 14916 8 14917 8 14918 8 14919 8 14920 8 14921 8 14922 8 14923 8 14924 8 14925 8 14926 8 14927 8 14928 8 14929 8 14930 8 14931 8 14932 8 14933 8 14934 8 14935 8 14936 8 14937 8 14938 8 14939 8 14940 8 14941 8 14942 8 14943 8 14944 8 14945 8 14946 8 14947 8 14948 8 14949 8 14950 8 14951 8 14952 8 14953 8 14954 8 14955 8 14956 8 14957 8 14958 8 14959 8 14960 8 14961 8 14962 8 14963 8 14964 8 14965 8 14966 8 14967 8 14968 8 14969 8 14970 8 14971 8 14972 8 14973 8 14974 8 14975 8 14976 8 14977 8 14978 8 14979 8 14980 8 14981 8 14982 8 14983 8 14984 8 14985 8 14986 8 14987 8 14988 8 14989 6552 14990 8 14991 8 14992 8 14993 6553 14994 6554 14995 8 14996 6555 14997 8 14998 8 14999 6556 15000 6557 15001 6558 15002 8 15003 8 15004 6559 15005 6560 15006 6561 15007 6562 15008 8 15009 6563 15010 8 15011 6564 15012 6565 15013 6566 15014 6567 15015 6568 15016 6569 15017 6570 15018 6571 15019 6572 15020 186 15021 186 15022 186 15023 186 15024 186 15025 186 15026 186 15027 186 15028 186 15029 186 15030 186 15031 186 15032 186 15033 6573 15034 186 15035 6574 15036 6575 15037 8 15038 6576 15039 6577 15040 8 15041 6578 15042 8 15043 6579 15044 8 15045 8 15046 8 15047 6580 15048 6581 15049 6582 15050 8 15051 6583 15052 8 15053 8 15054 6584 15055 6585 15056 6586 15057 8 15058 8 15059 8 15060 6587 15061 6588 15062 8 15063 8 15064 8 15065 6589 15066 6590 15067 6591 15068 6592 15069 6593 15070 8 15071 6594 15072 8 15073 8 15074 6595 15075 8 15076 6596 15077 6597 15078 8 15079 8 15080 6598 15081 8 15082 8 15083 8 15084 6599 15085 6600 15086 8 15087 8 15088 6601 15089 6602 15090 6603 15091 6604 15092 6605 15093 6606 15094 6607 15095 6608 15096 6609 15097 6610 15098 6611 15099 8 15100 6612 15101 6613 15102 6614 15103 6615 15104 6616 15105 6617 15106 6618 15107 6619 15108 6620 15109 6621 15110 6622 15111 6623 15112 6624 15113 6625 15114 6626 15115 6627 15116 6628 15117 6629 15118 6630 15119 8 15120 6631 15121 8 15122 6632 15123 8 15124 8 15125 6633 15126 6634 15127 6635 15128 6636 15129 8 15130 8 15131 6637 15132 6638 15133 6639 15134 6640 15135 6641 15136 8 15137 6642 15138 8 15139 6643 15140 8 15141 8 15142 8 15143 8 15144 6644 15145 8 15146 6645 15147 6646 15148 6647 15149 6648 15150 6649 15151 6650 15152 6651 15153 8 15154 6652 15155 6653 15156 8 15157 6654 15158 8 15159 6655 15160 6656 15161 6657 15162 6658 15163 6659 15164 6660 15165 6661 15166 8 15167 8 15168 6662 15169 8 15170 8 15171 6663 15172 6664 15173 6665 15174 8 15175 8 15176 8 15177 8 15178 6666 15179 8 15180 8 15181 8 15182 8 15183 6667 15184 6668 15185 6669 15186 6670 15187 6671 15188 6672 15189 6673 15190 6674 15191 6675 15192 6676 15193 6677 15194 6678 15195 6679 15196 6680 15197 6681 15198 6682 15199 6683 15200 6684 15201 6685 15202 6686 15203 6687 15204 6688 15205 6689 15206 6690 15207 6691 15208 6692 15209 6693 15210 6694 15211 6695 15212 6696 15213 6697 15214 6698 15215 6699 15216 6700 15217 6670 15218 6670 15219 6670 15220 6670 15221 6670 15222 6670 15223 6670 15224 6670 15225 6670 15226 6670 15227 6670 15228 6670 15229 6670 15230 6670 15231 6670 15232 6701 15233 6702 15234 8 15235 8 15236 8 15237 8 15238 8 15239 8 15240 6703 15241 8 15242 8 15243 6704 15244 8 15245 6705 15246 6706 15247 6707 15248 6708 15249 6709 15250 6710 15251 8 15252 6711 15253 8 15254 8 15255 8 15256 8 15257 8 15258 6712 15259 6713 15260 8 15261 8 15262 6714 15263 8 15264 6715 15265 8 15266 8 15267 6716 15268 6717 15269 8 15270 6670 15271 6670 15272 6670 15273 6670 15274 6670 15275 6718 15276 6719 15277 6720 15278 6670 15279 6670 15280 6670 15281 6670 15282 6670 15283 6670 15284 6670 15285 6670 15286 6670 15287 6670 15288 6721 15289 8 15290 8 15291 8 15292 8 15293 8 15294 8 15295 8 15296 8 15297 8 15298 8 15299 8 15300 8 15301 8 15302 8 15303 8 15304 8 15305 8 15306 8 15307 8 15308 8 15309 8 15310 8 15311 8 15312 8 15313 8 15314 8 15315 8 15316 8 15317 8 15318 8 15319 8 15320 8 15321 8 15322 8 15323 8 15324 8 15325 8 15326 8 15327 8 15328 8 15329 8 15330 8 15331 8 15332 8 15333 8 15334 8 15335 8 15336 8 15337 8 15338 8 15339 8 15340 8 15341 8 15342 8 15343 8 15344 8 15345 8 15346 8 15347 8 15348 8 15349 8 15350 8 15351 8 15352 8 15353 8 15354 8 15355 8 15356 8 15357 8 15358 8 15359 8 15360 8 15361 8 15362 8 15363 8 15364 8 15365 8 15366 8 15367 8 15368 6722 15369 8 15370 8 15371 8 15372 6723 15373 6724 15374 8 15375 6725 15376 8 15377 8 15378 6726 15379 6727 15380 6728 15381 8 15382 8 15383 6729 15384 6730 15385 6731 15386 6732 15387 8 15388 6733 15389 8 15390 6734 15391 6735 15392 6736 15393 6737 15394 6738 15395 6739 15396 6740 15397 6741 15398 6742 15399 6670 15400 6670 15401 6670 15402 6670 15403 6670 15404 6670 15405 6670 15406 6670 15407 6670 15408 6670 15409 6670 15410 6670 15411 6670 15412 6743 15413 6670 15414 6744 15415 6745 15416 8 15417 6746 15418 6747 15419 8 15420 6748 15421 8 15422 6749 15423 8 15424 8 15425 8 15426 6750 15427 6751 15428 6752 15429 8 15430 6753 15431 8 15432 8 15433 6754 15434 6755 15435 6756 15436 8 15437 8 15438 8 15439 6757 15440 6758 15441 8 15442 8 15443 8 15444 6759 15445 6760 15446 6761 15447 6762 15448 6763 15449 8 15450 6764 15451 8 15452 8 15453 6765 15454 8 15455 6766 15456 6767 15457 8 15458 8 15459 6768 15460 8 15461 8 15462 8 15463 6769 15464 6770 15465 8 15466 8 15467 6771 15468 6772 15469 6773 15470 6774 15471 6775 15472 6776 15473 6777 15474 6778 15475 6779 15476 6780 15477 6781 15478 8 15479 6782 15480 6783 15481 6784 15482 6785 15483 6786 15484 6787 15485 6788 15486 6789 15487 6790 15488 6791 15489 8 15490 8 15491 6792 15492 8 15493 6793 15494 8 15495 6794 15496 6795 15497 8 15498 8 15499 8 15500 6796 15501 8 15502 8 15503 6797 15504 6798 15505 6799 15506 6800 15507 6801 15508 8 15509 6802 15510 8 15511 8 15512 6803 15513 8 15514 6804 15515 6805 15516 8 15517 8 15518 6806 15519 8 15520 6807 15521 8 15522 6808 15523 6809 15524 6810 15525 6670 15526 6670 15527 6811 15528 6812 15529 6813 15530 6814 15531 6815 15532 6816 15533 6817 15534 6818 15535 6819 15536 6820 15537 8 15538 6821 15539 8 15540 6822 15541 8 15542 8 15543 6823 15544 6824 15545 6825 15546 6826 15547 8 15548 8 15549 6827 15550 6828 15551 6829 15552 6830 15553 6831 15554 8 15555 6832 15556 8 15557 6833 15558 8 15559 8 15560 8 15561 8 15562 6834 15563 8 15564 6835 15565 6836 15566 6837 15567 6838 15568 6839 15569 6840 15570 6841 15571 8 15572 6842 15573 6843 15574 8 15575 6844 15576 8 15577 6845 15578 6846 15579 6847 15580 6848 15581 6849 15582 6850 15583 6851 15584 8 15585 8 15586 6852 15587 8 15588 8 15589 6853 15590 6854 15591 6855 15592 8 15593 8 15594 8 15595 8 15596 6856 15597 8 15598 8 15599 8 15600 8 15601 6857 15602 6858 15603 6859 15604 6860 15605 6861 15606 6862 15607 6863 15608 6864 15609 6865 15610 6866 15611 6867 15612 6868 15613 6869 15614 6870 15615 6871 15616 6872 15617 6873 15618 6874 15619 6875 15620 6876 15621 6877 15622 6878 15623 6879 15624 6880 15625 6881 15626 6882 15627 6883 15628 6884 15629 6885 15630 6886 15631 6887 15632 6888 15633 6889 15634 6890 15635 6860 15636 6860 15637 6860 15638 6860 15639 6860 15640 6860 15641 6860 15642 6860 15643 6860 15644 6860 15645 6860 15646 6860 15647 6860 15648 6860 15649 6860 15650 6891 15651 6892 15652 8 15653 8 15654 8 15655 8 15656 8 15657 8 15658 6893 15659 8 15660 8 15661 6894 15662 8 15663 6895 15664 6896 15665 6897 15666 6898 15667 6899 15668 6900 15669 8 15670 6901 15671 8 15672 8 15673 8 15674 8 15675 8 15676 6902 15677 6903 15678 8 15679 8 15680 6904 15681 8 15682 6905 15683 8 15684 8 15685 6906 15686 6907 15687 8 15688 6860 15689 6860 15690 6860 15691 6860 15692 6860 15693 6908 15694 6909 15695 6910 15696 6860 15697 6860 15698 6860 15699 6860 15700 6860 15701 6860 15702 6860 15703 6860 15704 6860 15705 6860 15706 6911 15707 8 15708 8 15709 8 15710 8 15711 8 15712 8 15713 8 15714 8 15715 8 15716 8 15717 8 15718 8 15719 8 15720 8 15721 8 15722 8 15723 8 15724 8 15725 8 15726 8 15727 8 15728 8 15729 8 15730 8 15731 8 15732 8 15733 8 15734 8 15735 8 15736 8 15737 8 15738 8 15739 8 15740 8 15741 8 15742 8 15743 8 15744 8 15745 8 15746 8 15747 8 15748 8 15749 8 15750 8 15751 8 15752 8 15753 8 15754 8 15755 8 15756 8 15757 8 15758 8 15759 8 15760 8 15761 8 15762 8 15763 8 15764 8 15765 8 15766 8 15767 8 15768 8 15769 8 15770 8 15771 8 15772 8 15773 8 15774 8 15775 8 15776 8 15777 8 15778 8 15779 8 15780 8 15781 8 15782 8 15783 8 15784 8 15785 8 15786 6912 15787 8 15788 8 15789 8 15790 6913 15791 6914 15792 8 15793 6915 15794 8 15795 8 15796 6916 15797 6917 15798 6918 15799 8 15800 8 15801 6919 15802 6920 15803 6921 15804 6922 15805 8 15806 6923 15807 8 15808 6924 15809 6925 15810 6926 15811 6927 15812 6928 15813 6929 15814 6930 15815 6931 15816 6932 15817 6860 15818 6860 15819 6860 15820 6860 15821 6860 15822 6860 15823 6860 15824 6860 15825 6860 15826 6860 15827 6860 15828 6860 15829 6860 15830 6933 15831 6860 15832 6934 15833 6935 15834 8 15835 6936 15836 6937 15837 8 15838 6938 15839 8 15840 6939 15841 8 15842 8 15843 8 15844 6940 15845 6941 15846 6942 15847 8 15848 6943 15849 8 15850 8 15851 6944 15852 6945 15853 6946 15854 8 15855 8 15856 8 15857 6947 15858 6948 15859 8 15860 8 15861 8 15862 6949 15863 6950 15864 6951 15865 6952 15866 6953 15867 8 15868 6954 15869 8 15870 8 15871 6955 15872 8 15873 6956 15874 6957 15875 8 15876 8 15877 6958 15878 8 15879 8 15880 8 15881 6959 15882 6960 15883 8 15884 8 15885 6961 15886 6962 15887 6963 15888 6964 15889 6965 15890 6966 15891 6967 15892 6968 15893 6969 15894 6970 15895 6971 15896 8 15897 6972 15898 6973 15899 6974 15900 6975 15901 6976 15902 6977 15903 6978 15904 6979 15905 6980 15906 6981 15907 8 15908 6982 15909 6670 15910 6983 15911 8 15912 6984 15913 8 15914 6985 15915 6986 15916 8 15917 8 15918 8 15919 6987 15920 8 15921 8 15922 6988 15923 6989 15924 6990 15925 6991 15926 6992 15927 8 15928 6993 15929 8 15930 8 15931 6994 15932 8 15933 6995 15934 6996 15935 8 15936 8 15937 6997 15938 8 15939 6998 15940 8 15941 6999 15942 7000 15943 7001 15944 6860 15945 6860 15946 7002 15947 7003 15948 6860 15949 6860 15950 6860 15951 6860 15952 8 15953 7004 15954 8 15955 7005 15956 8 15957 8 15958 6860 15959 6860 15960 8 15961 6860 15962 6860 15963 7006 15964 8 15965 8 15966 8 15967 8 15968 8 15969 8 15970 7007 15971 7008 15972 7009 15973 7010 15974 8 15975 7011 15976 8 15977 7012 15978 7013 15979 7014 15980 7015 15981 7016 15982 7017 15983 8 15984 7018 15985 8 15986 8 15987 8 15988 8 15989 7019 15990 8 15991 8 15992 8 15993 7020 15994 7021 15995 7022 15996 8 15997 8 15998 7023 15999 8 16000 8 16001 7024 16002 7025 16003 7026 16004 7027 16005 7028 16006 7029 16007 7030 16008 8 16009 7031 16010 8 16011 7032 16012 7033 16013 7034 16014 7035 16015 7036 16016 8 16017 7037 16018 7038 16019 7039 16020 7040 16021 6860 16022 7041 16023 7042 16024 7043 16025 8 16026 6860 16027 6860 16028 6860 16029 8 16030 7044 16031 8 16032 7045 16033 8 16034 7046 16035 7047 16036 8 16037 7048 16038 7049 16039 8 16040 6860 16041 8 16042 6860 16043 6860 16044 6860 16045 7050 16046 7051 16047 8 16048 6860 16049 6860 16050 6860 16051 7052 16052 8 16053 8 16054 7053 16055 7054 16056 8 16057 7055 16058 8 16059 6860 16060 6670 16061 6670 16062 6670 16063 8 16064 7056 16065 8 16066 7057 16067 8 16068 8 16069 6670 16070 6670 16071 8 16072 6670 16073 6670 16074 7058 16075 8 16076 8 16077 8 16078 8 16079 8 16080 8 16081 7059 16082 7060 16083 7061 16084 7062 16085 8 16086 7063 16087 8 16088 7064 16089 7065 16090 7066 16091 7067 16092 7068 16093 7069 16094 8 16095 7070 16096 8 16097 8 16098 8 16099 8 16100 7071 16101 8 16102 8 16103 8 16104 7072 16105 7073 16106 7074 16107 8 16108 8 16109 7075 16110 8 16111 8 16112 7076 16113 7077 16114 7078 16115 7079 16116 7080 16117 7081 16118 7082 16119 8 16120 7083 16121 8 16122 7084 16123 7085 16124 7086 16125 7087 16126 7088 16127 8 16128 7089 16129 7090 16130 7091 16131 7092 16132 6670 16133 7093 16134 7094 16135 7095 16136 8 16137 6670 16138 6670 16139 6670 16140 8 16141 7096 16142 8 16143 7097 16144 8 16145 7098 16146 7099 16147 8 16148 7100 16149 7101 16150 8 16151 6670 16152 8 16153 6670 16154 6670 16155 6670 16156 7102 16157 7103 16158 8 16159 6670 16160 6670 16161 6670 16162 7104 16163 8 16164 8 16165 7105 16166 7106 16167 8 16168 7107 16169 8 16170 6670 16171 7108 16172 8 16173 7109 16174 7110 16175 7111 16176 7112 16177 7113 16178 7114 16179 7115 16180 7116 16181 7117 16182 8 16183 7118 16184 7119 16185 7120 16186 7121 16187 7122 16188 7123 16189 7124 16190 8 16191 7125 16192 7126 16193 8 16194 7127 16195 8 16196 7128 16197 7129 16198 8 16199 7130 16200 8 16201 8 16202 7131 16203 7132 16204 7133 16205 8 16206 7134 16207 7135 16208 7136 16209 7137 16210 7138 16211 8 16212 7139 16213 7140 16214 7141 16215 7142 16216 7143 16217 7144 16218 7145 16219 7146 16220 7147 16221 7148 16222 7149 16223 7150 16224 7151 16225 8 16226 7152 16227 7153 16228 7154 16229 7155 16230 7156 16231 7157 16232 7158 16233 7159 16234 7160 16235 8 16236 7161 16237 8 16238 7162 16239 8 16240 7163 16241 8 16242 7164 16243 7165 16244 8 16245 8 16246 7166 16247 8 16248 8 16249 8 16250 8 16251 7167 16252 7168 16253 8 16254 7169 16255 7170 16256 7171 16257 7172 16258 7173 16259 8 16260 8 16261 8 16262 8 16263 8 16264 7174 16265 8 16266 8 16267 7175 16268 7176 16269 7177 16270 7178 16271 7179 16272 7180 16273 7181 16274 7182 16275 7183 16276 7184 16277 8 16278 8 16279 7185 16280 8 16281 7186 16282 7187 16283 7188 16284 7189 16285 7190 16286 7191 16287 8 16288 7192 16289 8 16290 8 16291 8 16292 8 16293 7193 16294 7194 16295 8 16296 7195 16297 7196 16298 8 16299 7197 16300 7198 16301 7199 16302 7200 16303 7201 16304 7202 16305 7203 16306 7204 16307 7205 16308 7206 16309 7207 16310 7208 16311 7209 16312 8 16313 7210 16314 7211 16315 7212 16316 7213 16317 7214 16318 7215 16319 7216 16320 7217 16321 7218 16322 8 16323 7219 16324 8 16325 7220 16326 8 16327 7221 16328 8 16329 7222 16330 7223 16331 8 16332 8 16333 7224 16334 8 16335 8 16336 8 16337 8 16338 7225 16339 7226 16340 8 16341 7227 16342 8 16343 7228 16344 7229 16345 7230 16346 7231 16347 7232 16348 7233 16349 7234 16350 7235 16351 7236 16352 7237 16353 7238 16354 8 16355 8 16356 7239 16357 7240 16358 7241 16359 7242 16360 7243 16361 7244 16362 7245 16363 8 16364 8 16365 7246 16366 7247 16367 8 16368 7248 16369 7249 16370 7250 16371 8 16372 7251 16373 7252 16374 7253 16375 7254 16376 8 16377 8 16378 7255 16379 8 16380 7256 16381 7257 16382 7258 16383 7259 16384 7260 16385 7261 16386 7262 16387 7263 16388 7264 16389 7265 16390 7266 16391 7267 16392 7268 16393 7269 16394 8 16395 7270 16396 7271 16397 7272 16398 7273 16399 7274 16400 7275 16401 7276 16402 7277 16403 7278 16404 8 16405 7279 16406 8 16407 7280 16408 8 16409 7281 16410 8 16411 7282 16412 7283 16413 8 16414 8 16415 7284 16416 8 16417 8 16418 8 16419 8 16420 7285 16421 7286 16422 8 16423 7287 16424 7288 16425 7289 16426 7290 16427 7291 16428 8 16429 7292 16430 7293 16431 7294 16432 7295 16433 7296 16434 7297 16435 7298 16436 7299 16437 7300 16438 8 16439 7301 16440 7302 16441 7303 16442 7304 16443 7305 16444 7306 16445 7307 16446 8 16447 7308 16448 7309 16449 8 16450 7310 16451 8 16452 7311 16453 7312 16454 8 16455 7313 16456 8 16457 8 16458 7314 16459 7315 16460 8 16461 7316 16462 7317 16463 7318 16464 8 16465 7319 16466 7320 16467 7321 16468 7322 16469 8 16470 8 16471 7323 16472 7324 16473 8 16474 7325 16475 7326 16476 7327 16477 8 16478 7328 16479 7329 16480 8 16481 7330 16482 8 16483 7331 16484 8 16485 8 16486 8 16487 7332 16488 8 16489 7333 16490 7334 16491 7335 16492 8 16493 7336 16494 8 16495 8 16496 7337 16497 7338 16498 7339 16499 8 16500 8 16501 7340 16502 7341 16503 7342 16504 8 16505 8 16506 8 16507 7343 16508 7344 16509 8 16510 8 16511 8 16512 7345 16513 7346 16514 7347 16515 7348 16516 7349 16517 8 16518 7350 16519 8 16520 8 16521 7351 16522 8 16523 7352 16524 7353 16525 8 16526 8 16527 7354 16528 8 16529 8 16530 8 16531 7355 16532 7356 16533 8 16534 7357 16535 7358 16536 7359 16537 7360 16538 7361 16539 7362 16540 8 16541 7363 16542 7364 16543 8 16544 7365 16545 8 16546 8 16547 8 16548 8 16549 8 16550 7366 16551 8 16552 8 16553 8 16554 7367 16555 7368 16556 8 16557 7369 16558 7370 16559 7371 16560 8 16561 7372 16562 7373 16563 7374 16564 7375 16565 8 16566 7376 16567 7377 16568 7378 16569 7379 16570 7380 16571 8 16572 8 16573 8 16574 7381 16575 7382 16576 8 16577 7383 16578 7384 16579 7385 16580 7386 16581 7387 16582 7388 16583 7389 16584 7390 16585 7391 16586 7392 16587 7393 16588 7394 16589 7395 16590 8 16591 7396 16592 7397 16593 7398 16594 7399 16595 7400 16596 7401 16597 7402 16598 7403 16599 7404 16600 8 16601 7405 16602 8 16603 7406 16604 8 16605 7407 16606 8 16607 7408 16608 7409 16609 8 16610 8 16611 7410 16612 8 16613 8 16614 8 16615 8 16616 7411 16617 7412 16618 8 16619 7413 16620 7414 16621 7415 16622 7416 16623 7417 16624 8 16625 7418 16626 7419 16627 7420 16628 7421 16629 7422 16630 7423 16631 7424 16632 7425 16633 7426 16634 8 16635 7427 16636 7428 16637 7429 16638 7430 16639 7431 16640 7432 16641 7433 16642 8 16643 7434 16644 7435 16645 8 16646 7436 16647 8 16648 7437 16649 7438 16650 8 16651 7439 16652 8 16653 8 16654 7440 16655 7441 16656 8 16657 7442 16658 7443 16659 7444 16660 8 16661 7445 16662 7446 16663 7447 16664 7448 16665 8 16666 8 16667 7449 16668 7450 16669 8 16670 7451 16671 7452 16672 7453 16673 7454 16674 8 16675 7455 16676 7456 16677 7457 16678 7458 16679 7459 16680 7460 16681 8 16682 7461 16683 7462 16684 8 16685 7463 16686 7464 16687 7465 16688 7466 16689 7467 16690 7468 16691 8 16692 7469 16693 7470 16694 7471 16695 7472 16696 8 16697 7473 16698 7474 16699 7475 16700 8 16701 7476 16702 8 16703 7477 16704 7478 16705 7479 16706 7480 16707 7481 16708 8 16709 8 16710 8 16711 7482 16712 7483 16713 8 16714 7484 16715 7485 16716 7486 16717 7487 16718 7488 16719 7489 16720 7490 16721 7491 16722 7492 16723 7493 16724 7494 16725 7495 16726 7496 16727 8 16728 7497 16729 7498 16730 7499 16731 7500 16732 7501 16733 7502 16734 7503 16735 7504 16736 7505 16737 8 16738 7506 16739 8 16740 7507 16741 8 16742 7508 16743 8 16744 7509 16745 7510 16746 8 16747 8 16748 7511 16749 8 16750 8 16751 8 16752 8 16753 7512 16754 7513 16755 8 16756 7514 16757 7515 16758 7516 16759 7517 16760 7518 16761 8 16762 7519 16763 7520 16764 7521 16765 7522 16766 7523 16767 7524 16768 7525 16769 7526 16770 7527 16771 8 16772 7528 16773 7529 16774 7530 16775 7531 16776 7532 16777 7533 16778 7534 16779 8 16780 7535 16781 7536 16782 8 16783 7537 16784 8 16785 7538 16786 7539 16787 8 16788 7540 16789 8 16790 8 16791 7541 16792 7542 16793 8 16794 7543 16795 7544 16796 7545 16797 8 16798 7546 16799 7547 16800 7548 16801 7549 16802 8 16803 8 16804 7550 16805 7551 16806 8 16807 7552 16808 7553 16809 7554 16810 7555 16811 8 16812 7556 16813 7557 16814 7558 16815 7559 16816 7560 16817 7561 16818 8 16819 7562 16820 7563 16821 8 16822 7564 16823 7565 16824 7566 16825 7567 16826 7568 16827 7569 16828 8 16829 7570 16830 7571 16831 7572 16832 7573 16833 8 16834 7574 16835 7575 16836 7576 16837 8 16838 7577 16839 8 16840 7578 16841 7579 16842 7580 16843 8 16844 7581 16845 7582 16846 8 16847 8 16848 7583 16849 8 16850 8 16851 7584 16852 7585 16853 8 16854 8 16855 7586 16856 7587 16857 7588 16858 7589 16859 7590 16860 7591 16861 7592 16862 7593 16863 7594 16864 7595 16865 7596 16866 8 16867 7597 16868 8 16869 7598 16870 8 16871 8 16872 7599 16873 7600 16874 7601 16875 7602 16876 8 16877 8 16878 7603 16879 7604 16880 7605 16881 7606 16882 7607 16883 8 16884 7608 16885 8 16886 7609 16887 8 16888 8 16889 8 16890 8 16891 7610 16892 8 16893 7611 16894 7612 16895 7613 16896 7614 16897 7615 16898 7616 16899 7617 16900 8 16901 7618 16902 7619 16903 8 16904 7620 16905 8 16906 7621 16907 7622 16908 7623 16909 7624 16910 7625 16911 7626 16912 7627 16913 8 16914 8 16915 7628 16916 8 16917 8 16918 7629 16919 7630 16920 7631 16921 8 16922 8 16923 8 16924 8 16925 7632 16926 8 16927 8 16928 8 16929 8 16930 7633 16931 7634 16932 7635 16933 7629 16934 7636 16935 7637 16936 7638 16937 7639 16938 7640 16939 7641 16940 7642 16941 7643 16942 7644 16943 7645 16944 7646 16945 7647 16946 7648 16947 7649 16948 7650 16949 7651 16950 7652 16951 7653 16952 7654 16953 7655 16954 7656 16955 7657 16956 7658 16957 7659 16958 7660 16959 7661 16960 7662 16961 7663 16962 7664 16963 7665 16964 7629 16965 7629 16966 7629 16967 7629 16968 7629 16969 7629 16970 7629 16971 7629 16972 7629 16973 7629 16974 7629 16975 7629 16976 7629 16977 7629 16978 7629 16979 7666 16980 7667 16981 8 16982 8 16983 8 16984 8 16985 8 16986 8 16987 7668 16988 8 16989 8 16990 7669 16991 8 16992 7670 16993 7671 16994 7672 16995 7673 16996 7674 16997 7675 16998 8 16999 7676 17000 8 17001 8 17002 8 17003 8 17004 8 17005 7677 17006 7678 17007 8 17008 8 17009 7679 17010 8 17011 7680 17012 8 17013 8 17014 7681 17015 7682 17016 8 17017 7629 17018 7629 17019 7629 17020 7629 17021 7629 17022 7683 17023 7684 17024 7685 17025 7629 17026 7629 17027 7629 17028 7629 17029 7629 17030 7629 17031 7629 17032 7629 17033 7629 17034 7629 17035 7686 17036 8 17037 8 17038 8 17039 8 17040 8 17041 8 17042 8 17043 8 17044 8 17045 8 17046 8 17047 8 17048 8 17049 8 17050 8 17051 8 17052 8 17053 8 17054 8 17055 8 17056 8 17057 8 17058 8 17059 8 17060 8 17061 8 17062 8 17063 8 17064 8 17065 8 17066 8 17067 8 17068 8 17069 8 17070 8 17071 8 17072 8 17073 8 17074 8 17075 8 17076 8 17077 8 17078 8 17079 8 17080 8 17081 8 17082 8 17083 8 17084 8 17085 8 17086 8 17087 8 17088 8 17089 8 17090 8 17091 8 17092 8 17093 8 17094 8 17095 8 17096 8 17097 8 17098 8 17099 8 17100 8 17101 8 17102 8 17103 8 17104 8 17105 8 17106 8 17107 8 17108 8 17109 8 17110 8 17111 8 17112 8 17113 8 17114 8 17115 7687 17116 8 17117 8 17118 8 17119 7688 17120 7689 17121 8 17122 7690 17123 8 17124 8 17125 7691 17126 7692 17127 7693 17128 8 17129 8 17130 7694 17131 7695 17132 7696 17133 7697 17134 8 17135 7698 17136 8 17137 7699 17138 7700 17139 7701 17140 7702 17141 7703 17142 7704 17143 7705 17144 7706 17145 7707 17146 7629 17147 7629 17148 7629 17149 7629 17150 7629 17151 7629 17152 7629 17153 7629 17154 7629 17155 7629 17156 7629 17157 7629 17158 7629 17159 7708 17160 7629 17161 7709 17162 7710 17163 8 17164 7711 17165 7712 17166 8 17167 7713 17168 8 17169 7714 17170 8 17171 8 17172 8 17173 7715 17174 7716 17175 7717 17176 8 17177 7718 17178 8 17179 8 17180 7719 17181 7720 17182 7721 17183 8 17184 8 17185 8 17186 7722 17187 7723 17188 8 17189 8 17190 8 17191 7724 17192 7725 17193 7726 17194 7727 17195 7728 17196 8 17197 7729 17198 8 17199 8 17200 7730 17201 8 17202 7731 17203 7732 17204 8 17205 8 17206 7733 17207 8 17208 8 17209 8 17210 7734 17211 7735 17212 8 17213 8 17214 7736 17215 7737 17216 7738 17217 7739 17218 7740 17219 7741 17220 7742 17221 7743 17222 7744 17223 7745 17224 7746 17225 8 17226 7747 17227 7748 17228 7749 17229 7750 17230 7751 17231 7752 17232 7753 17233 7754 17234 7755 17235 7756 17236 8 17237 7757 17238 8 17239 7758 17240 8 17241 7759 17242 7760 17243 8 17244 8 17245 8 17246 7761 17247 8 17248 8 17249 7762 17250 7763 17251 7764 17252 7765 17253 7766 17254 8 17255 7767 17256 8 17257 8 17258 7768 17259 8 17260 7769 17261 7770 17262 8 17263 8 17264 7771 17265 8 17266 7772 17267 8 17268 7773 17269 7774 17270 7775 17271 7629 17272 7629 17273 7776 17274 7777 17275 7778 17276 7779 17277 7780 17278 7781 17279 7782 17280 7783 17281 7784 17282 7785 17283 8 17284 7786 17285 8 17286 7787 17287 8 17288 8 17289 7788 17290 7789 17291 7790 17292 7791 17293 8 17294 8 17295 7792 17296 7793 17297 7794 17298 7795 17299 7796 17300 8 17301 7797 17302 8 17303 7798 17304 8 17305 8 17306 8 17307 8 17308 7799 17309 8 17310 7800 17311 7801 17312 7802 17313 7803 17314 7804 17315 7805 17316 7806 17317 8 17318 7807 17319 7808 17320 8 17321 7809 17322 8 17323 7810 17324 7811 17325 7812 17326 7813 17327 7814 17328 7815 17329 7816 17330 8 17331 8 17332 7817 17333 8 17334 8 17335 7818 17336 7819 17337 7820 17338 8 17339 8 17340 8 17341 8 17342 7821 17343 8 17344 8 17345 8 17346 8 17347 7822 17348 7823 17349 7824 17350 7825 17351 7826 17352 7827 17353 7828 17354 7829 17355 7830 17356 7831 17357 7832 17358 7833 17359 7834 17360 7835 17361 7836 17362 7837 17363 7838 17364 7839 17365 7840 17366 7841 17367 7842 17368 7843 17369 7844 17370 7845 17371 7846 17372 7847 17373 7848 17374 7849 17375 7850 17376 7851 17377 7852 17378 7853 17379 7854 17380 7855 17381 7825 17382 7825 17383 7825 17384 7825 17385 7825 17386 7825 17387 7825 17388 7825 17389 7825 17390 7825 17391 7825 17392 7825 17393 7825 17394 7825 17395 7825 17396 7856 17397 7857 17398 8 17399 8 17400 8 17401 8 17402 8 17403 8 17404 7858 17405 8 17406 8 17407 7859 17408 8 17409 7860 17410 7861 17411 7862 17412 7863 17413 7864 17414 7865 17415 8 17416 7866 17417 8 17418 8 17419 8 17420 8 17421 8 17422 7867 17423 7868 17424 8 17425 8 17426 7869 17427 8 17428 7870 17429 8 17430 8 17431 7871 17432 7872 17433 8 17434 7825 17435 7825 17436 7825 17437 7825 17438 7825 17439 7873 17440 7874 17441 7875 17442 7825 17443 7825 17444 7825 17445 7825 17446 7825 17447 7825 17448 7825 17449 7825 17450 7825 17451 7825 17452 7876 17453 8 17454 8 17455 8 17456 8 17457 8 17458 8 17459 8 17460 8 17461 8 17462 8 17463 8 17464 8 17465 8 17466 8 17467 8 17468 8 17469 8 17470 8 17471 8 17472 8 17473 8 17474 8 17475 8 17476 8 17477 8 17478 8 17479 8 17480 8 17481 8 17482 8 17483 8 17484 8 17485 8 17486 8 17487 8 17488 8 17489 8 17490 8 17491 8 17492 8 17493 8 17494 8 17495 8 17496 8 17497 8 17498 8 17499 8 17500 8 17501 8 17502 8 17503 8 17504 8 17505 8 17506 8 17507 8 17508 8 17509 8 17510 8 17511 8 17512 8 17513 8 17514 8 17515 8 17516 8 17517 8 17518 8 17519 8 17520 8 17521 8 17522 8 17523 8 17524 8 17525 8 17526 8 17527 8 17528 8 17529 8 17530 8 17531 8 17532 7877 17533 8 17534 8 17535 8 17536 7878 17537 7879 17538 8 17539 7880 17540 8 17541 8 17542 7881 17543 7882 17544 7883 17545 8 17546 8 17547 7884 17548 7885 17549 7886 17550 7887 17551 8 17552 7888 17553 8 17554 7889 17555 7890 17556 7891 17557 7892 17558 7893 17559 7894 17560 7895 17561 7896 17562 7897 17563 7825 17564 7825 17565 7825 17566 7825 17567 7825 17568 7825 17569 7825 17570 7825 17571 7825 17572 7825 17573 7825 17574 7825 17575 7825 17576 7898 17577 7825 17578 7899 17579 7900 17580 8 17581 7901 17582 7902 17583 8 17584 7903 17585 8 17586 7904 17587 8 17588 8 17589 8 17590 7905 17591 7906 17592 7907 17593 8 17594 7908 17595 8 17596 8 17597 7909 17598 7910 17599 7911 17600 8 17601 8 17602 8 17603 7912 17604 7913 17605 8 17606 8 17607 8 17608 7914 17609 7915 17610 7916 17611 7917 17612 7918 17613 8 17614 7919 17615 8 17616 8 17617 7920 17618 8 17619 7921 17620 7922 17621 8 17622 8 17623 7923 17624 8 17625 8 17626 8 17627 7924 17628 7925 17629 8 17630 8 17631 7926 17632 7927 17633 7928 17634 7929 17635 7930 17636 7931 17637 7932 17638 7933 17639 7934 17640 7935 17641 7936 17642 8 17643 7937 17644 7938 17645 7939 17646 7940 17647 7941 17648 7942 17649 7943 17650 7944 17651 7945 17652 7946 17653 8 17654 7947 17655 7629 17656 7948 17657 8 17658 7949 17659 8 17660 7950 17661 7951 17662 8 17663 8 17664 8 17665 7952 17666 8 17667 8 17668 7953 17669 7954 17670 7955 17671 7956 17672 7957 17673 8 17674 7958 17675 8 17676 8 17677 7959 17678 8 17679 7960 17680 7961 17681 8 17682 8 17683 7962 17684 8 17685 7963 17686 8 17687 7964 17688 7965 17689 7966 17690 7825 17691 7825 17692 7967 17693 7968 17694 7825 17695 7825 17696 7825 17697 7825 17698 8 17699 7969 17700 8 17701 7970 17702 8 17703 8 17704 7825 17705 7825 17706 8 17707 7825 17708 7825 17709 8 17710 7971 17711 7972 17712 7973 17713 7974 17714 8 17715 8 17716 8 17717 7975 17718 7976 17719 7977 17720 8 17721 8 17722 8 17723 7978 17724 7979 17725 7980 17726 7981 17727 7982 17728 7983 17729 7984 17730 8 17731 7985 17732 7986 17733 7987 17734 7988 17735 7989 17736 8 17737 7990 17738 7991 17739 7992 17740 7993 17741 7825 17742 7994 17743 7995 17744 7996 17745 8 17746 7825 17747 7825 17748 7825 17749 8 17750 7997 17751 8 17752 7998 17753 8 17754 7999 17755 8000 17756 8 17757 8001 17758 8002 17759 8 17760 7825 17761 8 17762 7825 17763 7825 17764 7825 17765 8003 17766 8004 17767 8 17768 7825 17769 7825 17770 7825 17771 8005 17772 8 17773 8 17774 8006 17775 8007 17776 8 17777 8008 17778 8 17779 7825 17780 7629 17781 7629 17782 7629 17783 8 17784 8009 17785 8 17786 8010 17787 8 17788 8 17789 7629 17790 7629 17791 8 17792 7629 17793 7629 17794 8 17795 8011 17796 8012 17797 8013 17798 8014 17799 8 17800 8 17801 8 17802 8015 17803 8016 17804 8017 17805 8 17806 8 17807 8 17808 8018 17809 8019 17810 8020 17811 8021 17812 8022 17813 8023 17814 8024 17815 8 17816 8025 17817 8026 17818 8027 17819 8028 17820 8029 17821 8 17822 8030 17823 8031 17824 8032 17825 8033 17826 7629 17827 8034 17828 8035 17829 8036 17830 8 17831 7629 17832 7629 17833 7629 17834 8 17835 8037 17836 8 17837 8038 17838 8 17839 8039 17840 8040 17841 8 17842 8041 17843 8042 17844 8 17845 7629 17846 8 17847 7629 17848 7629 17849 7629 17850 8043 17851 8044 17852 8 17853 7629 17854 7629 17855 7629 17856 8045 17857 8 17858 8 17859 8046 17860 8047 17861 8 17862 8048 17863 8 17864 7629 17865 84 17866 8049 17867 8 17868 8050 17869 8 17870 8051 17871 8 17872 8 17873 8052 17874 8 17875 8053 17876 8 17877 8 17878 8 17879 8054 17880 8055 17881 8 17882 8056 17883 8057 17884 8058 17885 8059 17886 8060 17887 8061 17888 8062 17889 8063 17890 8064 17891 8065 17892 8066 17893 8 17894 8067 17895 8 17896 8068 17897 8 17898 8 17899 8069 17900 8070 17901 8071 17902 8072 17903 8 17904 8 17905 8073 17906 8074 17907 8075 17908 8076 17909 8077 17910 8 17911 8078 17912 8 17913 8079 17914 8 17915 8 17916 8 17917 8 17918 8080 17919 8 17920 8081 17921 8082 17922 8083 17923 8084 17924 8085 17925 8086 17926 8087 17927 8 17928 8088 17929 8089 17930 8 17931 8090 17932 8 17933 8091 17934 8092 17935 8093 17936 8094 17937 8095 17938 8096 17939 8097 17940 8 17941 8 17942 8098 17943 8 17944 8 17945 8099 17946 8100 17947 8101 17948 8 17949 8 17950 8 17951 8 17952 8102 17953 8 17954 8 17955 8 17956 8 17957 8103 17958 8104 17959 8105 17960 8106 17961 8107 17962 8108 17963 8109 17964 8110 17965 8111 17966 8112 17967 8113 17968 8114 17969 8115 17970 8116 17971 8117 17972 8118 17973 8119 17974 8120 17975 8121 17976 8122 17977 8123 17978 8124 17979 8125 17980 8126 17981 8127 17982 8128 17983 8129 17984 8130 17985 8131 17986 8132 17987 8133 17988 8134 17989 8135 17990 8136 17991 8106 17992 8106 17993 8106 17994 8106 17995 8106 17996 8106 17997 8106 17998 8106 17999 8106 18000 8106 18001 8106 18002 8106 18003 8106 18004 8106 18005 8106 18006 8137 18007 8138 18008 8 18009 8 18010 8 18011 8 18012 8 18013 8 18014 8139 18015 8 18016 8 18017 8140 18018 8 18019 8141 18020 8142 18021 8143 18022 8144 18023 8145 18024 8146 18025 8 18026 8147 18027 8 18028 8 18029 8 18030 8 18031 8 18032 8148 18033 8149 18034 8 18035 8 18036 8150 18037 8 18038 8151 18039 8 18040 8 18041 8152 18042 8153 18043 8 18044 8106 18045 8106 18046 8106 18047 8106 18048 8106 18049 8154 18050 8155 18051 8156 18052 8106 18053 8106 18054 8106 18055 8106 18056 8106 18057 8106 18058 8106 18059 8106 18060 8106 18061 8106 18062 8157 18063 8 18064 8 18065 8 18066 8 18067 8 18068 8 18069 8 18070 8 18071 8 18072 8 18073 8 18074 8 18075 8 18076 8 18077 8 18078 8 18079 8 18080 8 18081 8 18082 8 18083 8 18084 8 18085 8 18086 8 18087 8 18088 8 18089 8 18090 8 18091 8 18092 8 18093 8 18094 8 18095 8 18096 8 18097 8 18098 8 18099 8 18100 8 18101 8 18102 8 18103 8 18104 8 18105 8 18106 8 18107 8 18108 8 18109 8 18110 8 18111 8 18112 8 18113 8 18114 8 18115 8 18116 8 18117 8 18118 8 18119 8 18120 8 18121 8 18122 8 18123 8 18124 8 18125 8 18126 8 18127 8 18128 8 18129 8 18130 8 18131 8 18132 8 18133 8 18134 8 18135 8 18136 8 18137 8 18138 8 18139 8 18140 8 18141 8 18142 8158 18143 8 18144 8 18145 8 18146 8159 18147 8160 18148 8 18149 8161 18150 8 18151 8 18152 8162 18153 8163 18154 8164 18155 8 18156 8 18157 8165 18158 8166 18159 8167 18160 8168 18161 8 18162 8169 18163 8 18164 8170 18165 8171 18166 8172 18167 8173 18168 8174 18169 8175 18170 8176 18171 8177 18172 8178 18173 8106 18174 8106 18175 8106 18176 8106 18177 8106 18178 8106 18179 8106 18180 8106 18181 8106 18182 8106 18183 8106 18184 8106 18185 8106 18186 8179 18187 8106 18188 8180 18189 8181 18190 8 18191 8182 18192 8183 18193 8 18194 8184 18195 8 18196 8185 18197 8 18198 8 18199 8 18200 8186 18201 8187 18202 8188 18203 8 18204 8189 18205 8 18206 8 18207 8190 18208 8191 18209 8192 18210 8 18211 8 18212 8 18213 8193 18214 8194 18215 8 18216 8 18217 8 18218 8195 18219 8196 18220 8197 18221 8198 18222 8199 18223 8 18224 8200 18225 8 18226 8 18227 8201 18228 8 18229 8202 18230 8203 18231 8 18232 8 18233 8204 18234 8 18235 8 18236 8 18237 8205 18238 8206 18239 8 18240 8 18241 8207 18242 8208 18243 8209 18244 8210 18245 8211 18246 8212 18247 8213 18248 8214 18249 8215 18250 8216 18251 8217 18252 8 18253 8218 18254 8219 18255 8220 18256 8221 18257 8222 18258 8223 18259 8224 18260 8225 18261 8226 18262 8227 18263 8228 18264 8229 18265 8230 18266 8231 18267 8232 18268 8233 18269 8234 18270 8235 18271 8236 18272 8 18273 8237 18274 8 18275 8238 18276 8 18277 8 18278 8239 18279 8240 18280 8241 18281 8242 18282 8 18283 8 18284 8243 18285 8244 18286 8245 18287 8246 18288 8247 18289 8 18290 8248 18291 8 18292 8249 18293 8 18294 8 18295 8 18296 8 18297 8250 18298 8 18299 8251 18300 8252 18301 8253 18302 8254 18303 8255 18304 8256 18305 8257 18306 8 18307 8258 18308 8259 18309 8 18310 8260 18311 8 18312 8261 18313 8262 18314 8263 18315 8264 18316 8265 18317 8266 18318 8267 18319 8 18320 8 18321 8268 18322 8 18323 8 18324 8269 18325 8270 18326 8271 18327 8 18328 8 18329 8 18330 8 18331 8272 18332 8 18333 8 18334 8 18335 8 18336 8273 18337 8274 18338 8275 18339 8276 18340 8277 18341 8278 18342 8279 18343 8280 18344 8281 18345 8282 18346 8283 18347 8284 18348 8285 18349 8286 18350 8287 18351 8288 18352 8289 18353 8290 18354 8291 18355 8292 18356 8293 18357 8294 18358 8295 18359 8296 18360 8297 18361 8298 18362 8299 18363 8300 18364 8301 18365 8302 18366 8303 18367 8304 18368 8305 18369 8306 18370 8276 18371 8276 18372 8276 18373 8276 18374 8276 18375 8276 18376 8276 18377 8276 18378 8276 18379 8276 18380 8276 18381 8276 18382 8276 18383 8276 18384 8276 18385 8307 18386 8308 18387 8 18388 8 18389 8 18390 8 18391 8 18392 8 18393 8309 18394 8 18395 8 18396 8310 18397 8 18398 8311 18399 8312 18400 8313 18401 8314 18402 8315 18403 8316 18404 8 18405 8317 18406 8 18407 8 18408 8 18409 8 18410 8 18411 8318 18412 8319 18413 8 18414 8 18415 8320 18416 8 18417 8321 18418 8 18419 8 18420 8322 18421 8323 18422 8 18423 8276 18424 8276 18425 8276 18426 8276 18427 8276 18428 8324 18429 8325 18430 8326 18431 8276 18432 8276 18433 8276 18434 8276 18435 8276 18436 8276 18437 8276 18438 8276 18439 8276 18440 8276 18441 8327 18442 8 18443 8 18444 8 18445 8 18446 8 18447 8 18448 8 18449 8 18450 8 18451 8 18452 8 18453 8 18454 8 18455 8 18456 8 18457 8 18458 8 18459 8 18460 8 18461 8 18462 8 18463 8 18464 8 18465 8 18466 8 18467 8 18468 8 18469 8 18470 8 18471 8 18472 8 18473 8 18474 8 18475 8 18476 8 18477 8 18478 8 18479 8 18480 8 18481 8 18482 8 18483 8 18484 8 18485 8 18486 8 18487 8 18488 8 18489 8 18490 8 18491 8 18492 8 18493 8 18494 8 18495 8 18496 8 18497 8 18498 8 18499 8 18500 8 18501 8 18502 8 18503 8 18504 8 18505 8 18506 8 18507 8 18508 8 18509 8 18510 8 18511 8 18512 8 18513 8 18514 8 18515 8 18516 8 18517 8 18518 8 18519 8 18520 8 18521 8328 18522 8 18523 8 18524 8 18525 8329 18526 8330 18527 8 18528 8331 18529 8 18530 8 18531 8332 18532 8333 18533 8334 18534 8 18535 8 18536 8335 18537 8336 18538 8337 18539 8338 18540 8 18541 8339 18542 8 18543 8340 18544 8341 18545 8342 18546 8343 18547 8344 18548 8345 18549 8346 18550 8347 18551 8348 18552 8276 18553 8276 18554 8276 18555 8276 18556 8276 18557 8276 18558 8276 18559 8276 18560 8276 18561 8276 18562 8276 18563 8276 18564 8276 18565 8349 18566 8276 18567 8350 18568 8351 18569 8 18570 8352 18571 8353 18572 8 18573 8354 18574 8 18575 8355 18576 8 18577 8 18578 8 18579 8356 18580 8357 18581 8358 18582 8 18583 8359 18584 8 18585 8 18586 8360 18587 8361 18588 8362 18589 8 18590 8 18591 8 18592 8363 18593 8364 18594 8 18595 8 18596 8 18597 8365 18598 8366 18599 8367 18600 8368 18601 8369 18602 8 18603 8370 18604 8 18605 8 18606 8371 18607 8 18608 8372 18609 8373 18610 8 18611 8 18612 8374 18613 8 18614 8 18615 8 18616 8375 18617 8376 18618 8 18619 8 18620 8377 18621 8378 18622 8379 18623 8380 18624 8381 18625 8382 18626 8383 18627 8384 18628 8385 18629 8386 18630 8387 18631 8 18632 8388 18633 8389 18634 8390 18635 8391 18636 8392 18637 8393 18638 8394 18639 8395 18640 8396 18641 8397 18642 8 18643 8 18644 8398 18645 8 18646 8399 18647 8 18648 8400 18649 8401 18650 8 18651 8 18652 8 18653 8402 18654 8 18655 8 18656 8403 18657 8404 18658 8405 18659 8406 18660 8407 18661 8 18662 8408 18663 8 18664 8 18665 8409 18666 8 18667 8410 18668 8411 18669 8 18670 8 18671 8412 18672 8 18673 8413 18674 8 18675 8414 18676 8415 18677 8416 18678 8276 18679 8276 18680 8417 18681 8418 18682 8419 18683 8420 18684 8421 18685 8422 18686 8423 18687 8424 18688 8425 18689 8426 18690 8 18691 8427 18692 8 18693 8428 18694 8 18695 8 18696 8429 18697 8430 18698 8431 18699 8432 18700 8 18701 8 18702 8433 18703 8434 18704 8435 18705 8436 18706 8437 18707 8 18708 8438 18709 8 18710 8439 18711 8 18712 8 18713 8 18714 8 18715 8440 18716 8 18717 8441 18718 8442 18719 8443 18720 8444 18721 8445 18722 8446 18723 8447 18724 8 18725 8448 18726 8449 18727 8 18728 8450 18729 8 18730 8451 18731 8452 18732 8453 18733 8454 18734 8455 18735 8456 18736 8457 18737 8 18738 8 18739 8458 18740 8 18741 8 18742 8459 18743 8460 18744 8461 18745 8 18746 8 18747 8 18748 8 18749 8462 18750 8 18751 8 18752 8 18753 8 18754 8463 18755 8464 18756 8465 18757 8466 18758 8467 18759 8468 18760 8469 18761 8470 18762 8471 18763 8472 18764 8473 18765 8474 18766 8475 18767 8476 18768 8477 18769 8478 18770 8479 18771 8480 18772 8481 18773 8482 18774 8483 18775 8484 18776 8485 18777 8486 18778 8487 18779 8488 18780 8489 18781 8490 18782 8491 18783 8492 18784 8493 18785 8494 18786 8495 18787 8496 18788 8466 18789 8466 18790 8466 18791 8466 18792 8466 18793 8466 18794 8466 18795 8466 18796 8466 18797 8466 18798 8466 18799 8466 18800 8466 18801 8466 18802 8466 18803 8497 18804 8498 18805 8 18806 8 18807 8 18808 8 18809 8 18810 8 18811 8499 18812 8 18813 8 18814 8500 18815 8 18816 8501 18817 8502 18818 8503 18819 8504 18820 8505 18821 8506 18822 8 18823 8507 18824 8 18825 8 18826 8 18827 8 18828 8 18829 8508 18830 8509 18831 8 18832 8 18833 8510 18834 8 18835 8511 18836 8 18837 8 18838 8512 18839 8513 18840 8 18841 8466 18842 8466 18843 8466 18844 8466 18845 8466 18846 8514 18847 8515 18848 8516 18849 8466 18850 8466 18851 8466 18852 8466 18853 8466 18854 8466 18855 8466 18856 8466 18857 8466 18858 8466 18859 8517 18860 8 18861 8 18862 8 18863 8 18864 8 18865 8 18866 8 18867 8 18868 8 18869 8 18870 8 18871 8 18872 8 18873 8 18874 8 18875 8 18876 8 18877 8 18878 8 18879 8 18880 8 18881 8 18882 8 18883 8 18884 8 18885 8 18886 8 18887 8 18888 8 18889 8 18890 8 18891 8 18892 8 18893 8 18894 8 18895 8 18896 8 18897 8 18898 8 18899 8 18900 8 18901 8 18902 8 18903 8 18904 8 18905 8 18906 8 18907 8 18908 8 18909 8 18910 8 18911 8 18912 8 18913 8 18914 8 18915 8 18916 8 18917 8 18918 8 18919 8 18920 8 18921 8 18922 8 18923 8 18924 8 18925 8 18926 8 18927 8 18928 8 18929 8 18930 8 18931 8 18932 8 18933 8 18934 8 18935 8 18936 8 18937 8 18938 8 18939 8518 18940 8 18941 8 18942 8 18943 8519 18944 8520 18945 8 18946 8521 18947 8 18948 8 18949 8522 18950 8523 18951 8524 18952 8 18953 8 18954 8525 18955 8526 18956 8527 18957 8528 18958 8 18959 8529 18960 8 18961 8530 18962 8531 18963 8532 18964 8533 18965 8534 18966 8535 18967 8536 18968 8537 18969 8538 18970 8466 18971 8466 18972 8466 18973 8466 18974 8466 18975 8466 18976 8466 18977 8466 18978 8466 18979 8466 18980 8466 18981 8466 18982 8466 18983 8539 18984 8466 18985 8540 18986 8541 18987 8 18988 8542 18989 8543 18990 8 18991 8544 18992 8 18993 8545 18994 8 18995 8 18996 8 18997 8546 18998 8547 18999 8548 19000 8 19001 8549 19002 8 19003 8 19004 8550 19005 8551 19006 8552 19007 8 19008 8 19009 8 19010 8553 19011 8554 19012 8 19013 8 19014 8 19015 8555 19016 8556 19017 8557 19018 8558 19019 8559 19020 8 19021 8560 19022 8 19023 8 19024 8561 19025 8 19026 8562 19027 8563 19028 8 19029 8 19030 8564 19031 8 19032 8 19033 8 19034 8565 19035 8566 19036 8 19037 8 19038 8567 19039 8568 19040 8569 19041 8570 19042 8571 19043 8572 19044 8573 19045 8574 19046 8575 19047 8576 19048 8577 19049 8 19050 8578 19051 8579 19052 8580 19053 8581 19054 8582 19055 8583 19056 8584 19057 8585 19058 8586 19059 8587 19060 8 19061 8588 19062 8276 19063 8589 19064 8 19065 8590 19066 8 19067 8591 19068 8592 19069 8 19070 8 19071 8 19072 8593 19073 8 19074 8 19075 8594 19076 8595 19077 8596 19078 8597 19079 8598 19080 8 19081 8599 19082 8 19083 8 19084 8600 19085 8 19086 8601 19087 8602 19088 8 19089 8 19090 8603 19091 8 19092 8604 19093 8 19094 8605 19095 8606 19096 8607 19097 8466 19098 8466 19099 8608 19100 8609 19101 8466 19102 8466 19103 8466 19104 8466 19105 8 19106 8610 19107 8 19108 8611 19109 8 19110 8 19111 8466 19112 8466 19113 8 19114 8466 19115 8466 19116 8612 19117 8 19118 8 19119 8 19120 8 19121 8 19122 8 19123 8613 19124 8614 19125 8615 19126 8616 19127 8 19128 8617 19129 8 19130 8618 19131 8619 19132 8620 19133 8621 19134 8622 19135 8623 19136 8 19137 8624 19138 8 19139 8 19140 8 19141 8 19142 8625 19143 8 19144 8 19145 8 19146 8626 19147 8627 19148 8628 19149 8 19150 8 19151 8629 19152 8 19153 8 19154 8630 19155 8631 19156 8632 19157 8633 19158 8634 19159 8635 19160 8636 19161 8 19162 8637 19163 8 19164 8638 19165 8639 19166 8640 19167 8641 19168 8642 19169 8 19170 8643 19171 8644 19172 8645 19173 8646 19174 8466 19175 8647 19176 8648 19177 8649 19178 8 19179 8466 19180 8466 19181 8466 19182 8 19183 8650 19184 8 19185 8651 19186 8 19187 8652 19188 8653 19189 8 19190 8654 19191 8655 19192 8 19193 8466 19194 8 19195 8466 19196 8466 19197 8466 19198 8656 19199 8657 19200 8 19201 8466 19202 8466 19203 8466 19204 8658 19205 8 19206 8 19207 8659 19208 8660 19209 8 19210 8661 19211 8 19212 8466 19213 8276 19214 8276 19215 8276 19216 8 19217 8662 19218 8 19219 8663 19220 8 19221 8 19222 8276 19223 8276 19224 8 19225 8276 19226 8276 19227 8664 19228 8 19229 8 19230 8 19231 8 19232 8 19233 8 19234 8665 19235 8666 19236 8667 19237 8668 19238 8 19239 8669 19240 8 19241 8670 19242 8671 19243 8672 19244 8673 19245 8674 19246 8675 19247 8 19248 8676 19249 8 19250 8 19251 8 19252 8 19253 8677 19254 8 19255 8 19256 8 19257 8678 19258 8679 19259 8680 19260 8 19261 8 19262 8681 19263 8 19264 8 19265 8682 19266 8683 19267 8684 19268 8685 19269 8686 19270 8687 19271 8688 19272 8 19273 8689 19274 8 19275 8690 19276 8691 19277 8692 19278 8693 19279 8694 19280 8 19281 8695 19282 8696 19283 8697 19284 8698 19285 8276 19286 8699 19287 8700 19288 8701 19289 8 19290 8276 19291 8276 19292 8276 19293 8 19294 8702 19295 8 19296 8703 19297 8 19298 8704 19299 8705 19300 8 19301 8706 19302 8707 19303 8 19304 8276 19305 8 19306 8276 19307 8276 19308 8276 19309 8708 19310 8709 19311 8 19312 8276 19313 8276 19314 8276 19315 8710 19316 8 19317 8 19318 8711 19319 8712 19320 8 19321 8713 19322 8 19323 8276 19324 8714 19325 8715 19326 8716 19327 8717 19328 8 19329 8718 19330 8719 19331 8720 19332 8721 19333 8 19334 8722 19335 8723 19336 8 19337 8724 19338 8 19339 8 19340 8 19341 8725 19342 8726 19343 8727 19344 8 19345 8728 19346 8 19347 8 19348 8729 19349 8730 19350 8731 19351 8 19352 8 19353 8 19354 8732 19355 8733 19356 8734 19357 8735 19358 8736 19359 8 19360 8737 19361 8738 19362 8739 19363 8740 19364 8 19365 8741 19366 8742 19367 8 19368 8743 19369 8 19370 8 19371 8 19372 8744 19373 8745 19374 8746 19375 8 19376 8747 19377 8 19378 8 19379 8748 19380 8749 19381 8750 19382 8 19383 8 19384 8 19385 8751 19386 8752 19387 8 19388 8 19389 8753 19390 8 19391 8754 19392 8755 19393 8756 19394 8757 19395 8758 19396 8759 19397 8760 19398 8761 19399 8762 19400 8763 19401 8764 19402 8765 19403 8766 19404 8767 19405 8 19406 8768 19407 8769 19408 8770 19409 8771 19410 8772 19411 8773 19412 8774 19413 8775 19414 8776 19415 8 19416 8777 19417 8 19418 8778 19419 8 19420 8779 19421 8 19422 8780 19423 8781 19424 8 19425 8 19426 8782 19427 8 19428 8 19429 8 19430 8 19431 8783 19432 8784 19433 8 19434 8785 19435 8786 19436 8787 19437 8788 19438 8789 19439 8 19440 8790 19441 8791 19442 8792 19443 8793 19444 8794 19445 8795 19446 8796 19447 8797 19448 8798 19449 8 19450 8799 19451 8800 19452 8801 19453 8802 19454 8803 19455 8804 19456 8805 19457 8 19458 8806 19459 8807 19460 8 19461 8808 19462 8 19463 8809 19464 8810 19465 8 19466 8811 19467 8 19468 8 19469 8812 19470 8813 19471 8 19472 8814 19473 8815 19474 8816 19475 8 19476 8817 19477 8818 19478 8819 19479 8820 19480 8 19481 8 19482 8821 19483 8822 19484 8 19485 8823 19486 8824 19487 8825 19488 8826 19489 8 19490 8827 19491 8828 19492 8829 19493 8830 19494 8831 19495 8832 19496 8 19497 8833 19498 8834 19499 8 19500 8835 19501 8836 19502 8837 19503 8838 19504 8839 19505 8840 19506 8 19507 8841 19508 8842 19509 8843 19510 8844 19511 8 19512 8845 19513 8846 19514 8847 19515 8 19516 8848 19517 8 19518 8849 19519 8850 19520 8851 19521 8 19522 8852 19523 8853 19524 8 19525 8 19526 8854 19527 8 19528 8855 19529 8 19530 8856 19531 8 19532 8857 19533 8 19534 8858 19535 8859 19536 8860 19537 8861 19538 8862 19539 8863 19540 8864 19541 8865 19542 8866 19543 8 19544 8 19545 8867 19546 8868 19547 8 19548 8 19549 8869 19550 7629 19551 8870 19552 8871 19553 8872 19554 7629 19555 8873 19556 8874 19557 8875 19558 1127 19559 8876 19560 8877 19561 8878 19562 1127 19563 8879 19564 8880 19565 8 19566 8 19567 8881 19568 8 19569 8882 19570 8883 19571 8884 19572 8885 19573 8886 19574 8887 19575 8888 19576 8889 19577 8890 19578 8891 19579 8892 19580 8893 19581 8894 19582 8895 19583 8 19584 8896 19585 8897 19586 8898 19587 8899 19588 8900 19589 8901 19590 8902 19591 8903 19592 8904 19593 8 19594 8905 19595 8 19596 8906 19597 8 19598 8907 19599 8 19600 8908 19601 8909 19602 8 19603 8 19604 8910 19605 8 19606 8 19607 8 19608 8 19609 8911 19610 8912 19611 8 19612 8913 19613 8914 19614 8915 19615 8916 19616 8917 19617 8 19618 8918 19619 8919 19620 8920 19621 8921 19622 8922 19623 8923 19624 8924 19625 8925 19626 8926 19627 8 19628 8927 19629 8928 19630 8929 19631 8930 19632 8931 19633 8932 19634 8933 19635 8 19636 8934 19637 8935 19638 8 19639 8936 19640 8 19641 8937 19642 8938 19643 8 19644 8939 19645 8 19646 8 19647 8940 19648 8941 19649 8 19650 8942 19651 8943 19652 8944 19653 8 19654 8945 19655 8946 19656 8947 19657 8948 19658 8 19659 8 19660 8949 19661 8950 19662 8 19663 8951 19664 8952 19665 8953 19666 8954 19667 8 19668 8955 19669 8956 19670 8957 19671 8958 19672 8959 19673 8960 19674 8 19675 8961 19676 8962 19677 8 19678 8963 19679 8964 19680 8965 19681 8966 19682 8967 19683 8968 19684 8 19685 8969 19686 8970 19687 8971 19688 8972 19689 8 19690 8973 19691 8974 19692 8975 19693 8 19694 8976 19695 8 19696 8977 19697 8978 19698 8979 19699 8 19700 8980 19701 8981 19702 8 19703 8 19704 8982 19705 8 19706 8983 19707 8 19708 8984 19709 8 19710 8985 19711 8 19712 8986 19713 8987 19714 8988 19715 8989 19716 8990 19717 8991 19718 8992 19719 8993 19720 8994 19721 8 19722 8 19723 8995 19724 8996 19725 8 19726 8 19727 8997 19728 8998 19729 8999 19730 9000 19731 9001 19732 9002 19733 9003 19734 9004 19735 8 19736 8 19737 9005 19738 9006 19739 8 19740 8 19741 9007 19742 7629 19743 9008 19744 8 19745 8 19746 8 19747 9009 19748 9010 19749 9011 19750 9012 19751 9013 19752 9014 19753 9015 19754 9016 19755 9017 19756 9018 19757 8 19758 9019 19759 9020 19760 9021 19761 9022 19762 9023 19763 9024 19764 9025 19765 8 19766 9026 19767 9027 19768 8 19769 9028 19770 9029 19771 9030 19772 9031 19773 8 19774 9032 19775 9033 19776 9034 19777 9035 19778 8 19779 9036 19780 9037 19781 9038 19782 9039 19783 9040 19784 8 19785 9041 19786 9042 19787 9043 19788 9044 19789 9045 19790 9046 19791 9047 19792 9048 19793 9049 19794 8 19795 9050 19796 9051 19797 9052 19798 9053 19799 9054 19800 9055 19801 9056 19802 8 19803 9057 19804 9058 19805 8 19806 9059 19807 8 19808 9060 19809 9061 19810 8 19811 9062 19812 8 19813 8 19814 9063 19815 9064 19816 8 19817 9065 19818 9066 19819 9067 19820 8 19821 9068 19822 9069 19823 9070 19824 9071 19825 8 19826 8 19827 9072 19828 9073 19829 8 19830 9074 19831 9075 19832 9076 19833 9077 19834 8 19835 9078 19836 9079 19837 9080 19838 9081 19839 9082 19840 9083 19841 8 19842 9084 19843 9085 19844 8 19845 9086 19846 9087 19847 9088 19848 9089 19849 9090 19850 9091 19851 8 19852 9092 19853 9093 19854 9094 19855 9095 19856 8 19857 9096 19858 9097 19859 9098 19860 8 19861 9099 19862 8 19863 9100 19864 9101 19865 9102 19866 8 19867 9103 19868 9104 19869 8 19870 8 19871 9105 19872 8 19873 9106 19874 8 19875 9107 19876 8 19877 9108 19878 8 19879 9109 19880 9110 19881 9111 19882 9112 19883 9113 19884 9114 19885 9115 19886 9116 19887 9117 19888 8 19889 8 19890 9118 19891 9119 19892 8 19893 8 19894 9120 19895 9121 19896 9122 19897 9123 19898 9124 19899 9125 19900 9126 19901 9127 19902 8 19903 8 19904 9128 19905 9129 19906 8 19907 9130 19908 8 19909 9131 19910 9132 19911 9133 19912 9134 19913 9135 19914 8 19915 9136 19916 9137 19917 8 19918 9138 19919 9139 19920 9140 19921 8 19922 9141 19923 8 19924 8 19925 9142 19926 8 19927 9143 19928 9144 19929 9145 19930 9146 19931 9147 19932 9148 19933 9149 19934 9150 19935 9151 19936 9152 19937 9153 19938 9154 19939 9155 19940 9156 19941 8 19942 9157 19943 9158 19944 9159 19945 9160 19946 9161 19947 9162 19948 9163 19949 9164 19950 9165 19951 8 19952 9166 19953 8 19954 9167 19955 8 19956 9168 19957 8 19958 9169 19959 9170 19960 8 19961 8 19962 9171 19963 8 19964 8 19965 8 19966 8 19967 9172 19968 9173 19969 8 19970 9174 19971 9175 19972 9176 19973 9177 19974 9178 19975 8 19976 9179 19977 9180 19978 9181 19979 9182 19980 9183 19981 9184 19982 9185 19983 9186 19984 9187 19985 8 19986 9188 19987 9189 19988 9190 19989 9191 19990 9192 19991 9193 19992 9194 19993 8 19994 9195 19995 9196 19996 8 19997 9197 19998 8 19999 9198 20000 9199 20001 8 20002 9200 20003 8 20004 8 20005 9201 20006 9202 20007 8 20008 9203 20009 9204 20010 9205 20011 8 20012 9206 20013 9207 20014 9208 20015 9209 20016 8 20017 8 20018 9210 20019 9211 20020 8 20021 9212 20022 9213 20023 9214 20024 9215 20025 8 20026 9216 20027 9217 20028 9218 20029 9219 20030 9220 20031 9221 20032 8 20033 9222 20034 9223 20035 8 20036 9224 20037 9225 20038 9226 20039 9227 20040 9228 20041 9229 20042 8 20043 9230 20044 9231 20045 9232 20046 9233 20047 8 20048 9234 20049 9235 20050 9236 20051 8 20052 9237 20053 8 20054 9238 20055 9239 20056 9240 20057 8 20058 9241 20059 9242 20060 8 20061 8 20062 9243 20063 8 20064 9244 20065 8 20066 9245 20067 8 20068 9246 20069 8 20070 9247 20071 9248 20072 9249 20073 9250 20074 9251 20075 9252 20076 9253 20077 9254 20078 9255 20079 8 20080 8 20081 9256 20082 9257 20083 8 20084 8 20085 9258 20086 9259 20087 9260 20088 9261 20089 9262 20090 9263 20091 9264 20092 9265 20093 8 20094 8 20095 9266 20096 9267 20097 8 20098 9268 20099 8 20100 9269 20101 9270 20102 9271 20103 9272 20104 9273 20105 8 20106 9274 20107 9275 20108 9276 20109 9277 20110 8 20111 8 20112 9278 20113 9279 20114 8 20115 9280 20116 8 20117 9281 20118 8 20119 8 20120 9282 20121 9283 20122 9284 20123 9285 20124 9286 20125 9287 20126 9288 20127 9289 20128 9290 20129 9291 20130 9292 20131 8 20132 8 20133 9293 20134 9294 20135 9295 20136 9296 20137 9297 20138 9298 20139 9299 20140 8 20141 8 20142 9300 20143 9301 20144 8 20145 9302 20146 9303 20147 9304 20148 8 20149 9305 20150 9306 20151 9307 20152 9308 20153 8 20154 8 20155 9309 20156 9310 20157 8 20158 9311 20159 9312 20160 9313 20161 9314 20162 8 20163 9315 20164 9316 20165 9317 20166 9318 20167 9319 20168 9320 20169 8 20170 9321 20171 9322 20172 8 20173 9323 20174 9324 20175 9325 20176 9326 20177 9327 20178 9328 20179 8 20180 9329 20181 9330 20182 9331 20183 9332 20184 8 20185 9333 20186 9334 20187 9335 20188 9336 20189 8 20190 9337 20191 9338 20192 9339 20193 8 20194 9340 20195 8 20196 9341 20197 9342 20198 9343 20199 8 20200 9344 20201 9345 20202 8 20203 8 20204 9346 20205 8 20206 9347 20207 8 20208 9348 20209 9349 20210 9350 20211 9351 20212 9352 20213 9353 20214 8 20215 2791 20216 9354 20217 9355 20218 9356 20219 9357 20220 8 20221 7138 20222 9358 20223 9359 20224 8 20225 9360 20226 8 20227 9361 20228 8 20229 9362 20230 9363 20231 9364 20232 9365 20233 9366 20234 9367 20235 9368 20236 9369 20237 9370 20238 8 20239 8 20240 9371 20241 9372 20242 8 20243 8 20244 9373 20245 9374 20246 9375 20247 9376 20248 9377 20249 9378 20250 9379 20251 9380 20252 8 20253 8 20254 9381 20255 9382 20256 8 20257 9383 20258 9384 20259 9385 20260 9386 20261 9387 20262 9388 20263 9389 20264 8 20265 9390 20266 8 20267 8 20268 8 20269 8 20270 8 20271 8 20272 8 20273 9391 20274 8 20275 9392 20276 8 20277 8 20278 9393 20279 9394 20280 9395 20281 9396 20282 8 20283 8 20284 8 20285 8 20286 8 20287 8 20288 8 20289 8 20290 8 20291 8 20292 8 20293 9397 20294 8 20295 9398 20296 8 20297 9399 20298 8 20299 8 20300 8 20301 8 20302 8 20303 8 20304 8 20305 8 20306 8 20307 8 20308 9400 20309 8 20310 8 20311 8 20312 8 20313 8 20314 8 20315 8 20316 8 20317 9401 20318 8 20319 9402 20320 9403 20321 9404 20322 9405 20323 9406 20324 8 20325 9407 20326 9408 20327 9409 20328 9410 20329 8 20330 8 20331 9411 20332 9412 20333 8 20334 9413 20335 8 20336 9414 20337 9415 20338 9416 20339 9417 20340 9418 20341 9419 20342 8 20343 9420 20344 8 20345 9421 20346 9422 20347 8 20348 9423 20349 8 20350 9424 20351 8 20352 8 20353 8 20354 9425 20355 9426 20356 8 20357 9427 20358 9428 20359 9429 20360 8 20361 9430 20362 9431 20363 9432 20364 9433 20365 8 20366 8 20367 9434 20368 9435 20369 8 20370 9436 20371 9437 20372 9438 20373 9439 20374 8 20375 9440 20376 9441 20377 9442 20378 9443 20379 9444 20380 9445 20381 8 20382 9446 20383 9447 20384 8 20385 9448 20386 9449 20387 9450 20388 9451 20389 9452 20390 9453 20391 8 20392 9454 20393 9455 20394 9456 20395 9457 20396 8 20397 9458 20398 9459 20399 9460 20400 8 20401 9461 20402 8 20403 9462 20404 9463 20405 9464 20406 8 20407 9465 20408 9466 20409 8 20410 8 20411 9467 20412 8 20413 9468 20414 8 20415 9469 20416 9470 20417 9471 20418 8 20419 9472 20420 8 20421 9473 20422 8 20423 9474 20424 9475 20425 9476 20426 9477 20427 9478 20428 9479 20429 9480 20430 9481 20431 9482 20432 8 20433 8 20434 9483 20435 9484 20436 8 20437 8 20438 9485 20439 9486 20440 9487 20441 9488 20442 9489 20443 9490 20444 9491 20445 9492 20446 8 20447 8 20448 9493 20449 9494 20450 8 20451 9495 20452 8 20453 9496 20454 9497 20455 9498 20456 9499 20457 9500 20458 8 20459 9501 20460 9502 20461 9503 20462 9504 20463 8 20464 8 20465 9505 20466 9506 20467 8 20468 9507 20469 8 20470 9508 20471 8 20472 9509 20473 9510 20474 9511 20475 9512 20476 8 20477 8 20478 9513 20479 9514 20480 8 20481 9515 20482 8 20483 9516 20484 8 20485 8 20486 9517 20487 9518 20488 9519 20489 9520 20490 9521 20491 9522 20492 9523 20493 9524 20494 9525 20495 9526 20496 9527 20497 8 20498 8 20499 9528 20500 9529 20501 9530 20502 9531 20503 9532 20504 9533 20505 9534 20506 8 20507 8 20508 9535 20509 9536 20510 8 20511 9537 20512 9538 20513 9539 20514 8 20515 9540 20516 9541 20517 9542 20518 9543 20519 8 20520 8 20521 9544 20522 9545 20523 8 20524 9546 20525 9547 20526 9548 20527 9549 20528 8 20529 9550 20530 9551 20531 9552 20532 9553 20533 9554 20534 9555 20535 8 20536 9556 20537 9557 20538 8 20539 9558 20540 9559 20541 9560 20542 9561 20543 9562 20544 9563 20545 8 20546 9564 20547 9565 20548 9566 20549 9567 20550 8 20551 9568 20552 9569 20553 9570 20554 9571 20555 8 20556 9572 20557 9573 20558 9574 20559 8 20560 9575 20561 8 20562 9576 20563 9577 20564 9578 20565 8 20566 9579 20567 9580 20568 8 20569 8 20570 9581 20571 8 20572 9582 20573 8 20574 9583 20575 9584 20576 9585 20577 9586 20578 9587 20579 8 20580 9588 20581 9589 20582 9590 20583 8 20584 9591 20585 9592 20586 8 20587 9593 20588 8 20589 9594 20590 8 20591 9595 20592 9596 20593 9597 20594 9598 20595 9599 20596 9600 20597 9601 20598 9602 20599 9603 20600 8 20601 8 20602 9604 20603 9605 20604 8 20605 8 20606 9606 20607 9607 20608 9608 20609 9609 20610 9610 20611 9611 20612 9612 20613 9613 20614 8 20615 8 20616 9614 20617 9615 20618 8 20619 9616 20620 9617 20621 9618 20622 9619 20623 9620 20624 9621 20625 8 20626 8 20627 9622 20628 8 20629 9623 20630 9624 20631 9625 20632 9626 20633 9627 20634 8 20635 9628 20636 9629 20637 9630 20638 9631 20639 8 20640 8 20641 9632 20642 9633 20643 8 20644 9634 20645 8 20646 9635 20647 9636 20648 9637 20649 9638 20650 9639 20651 9640 20652 8 20653 9641 20654 8 20655 9642 20656 8 20657 9643 20658 9644 20659 9645 20660 9646 20661 9647 20662 8 20663 9648 20664 9649 20665 9650 20666 9651 20667 8 20668 8 20669 9652 20670 9653 20671 8 20672 9654 20673 8 20674 9655 20675 8 20676 8 20677 9656 20678 9657 20679 9658 20680 9659 20681 9660 20682 9661 20683 9662 20684 9663 20685 9664 20686 9665 20687 9666 20688 8 20689 8 20690 9667 20691 9668 20692 9669 20693 9670 20694 9671 20695 9672 20696 9673 20697 8 20698 8 20699 9674 20700 9675 20701 8 20702 9676 20703 9677 20704 9678 20705 8 20706 9679 20707 9680 20708 9681 20709 9682 20710 8 20711 8 20712 9683 20713 9684 20714 8 20715 9685 20716 9686 20717 9687 20718 9688 20719 8 20720 9689 20721 9690 20722 9691 20723 9692 20724 9693 20725 9694 20726 8 20727 9695 20728 9696 20729 8 20730 9697 20731 9698 20732 9699 20733 9700 20734 9701 20735 9702 20736 8 20737 9703 20738 9704 20739 9705 20740 9706 20741 8 20742 9707 20743 9708 20744 9709 20745 9710 20746 8 20747 9711 20748 9712 20749 9713 20750 8 20751 9714 20752 8 20753 9715 20754 9716 20755 9717 20756 8 20757 9718 20758 9719 20759 8 20760 8 20761 9720 20762 8 20763 9721 20764 8 20765 9722 20766 9723 20767 9724 20768 9725 20769 9726 20770 8 20771 9727 20772 9728 20773 9729 20774 8 20775 9730 20776 9731 20777 8 20778 9732 20779 8 20780 9733 20781 8 20782 9734 20783 9735 20784 9736 20785 9737 20786 9738 20787 9739 20788 9740 20789 9741 20790 9742 20791 8 20792 8 20793 9743 20794 9744 20795 8 20796 8 20797 9745 20798 9746 20799 9747 20800 9748 20801 9749 20802 9750 20803 9751 20804 9752 20805 8 20806 8 20807 9753 20808 9754 20809 8 20810 9755 20811 9756 20812 9757 20813 9758 20814 9759 20815 9760 20816 8 20817 8 20818 9761 20819 8 20820 9762 20821 9763 20822 9764 20823 9765 20824 9766 20825 8 20826 9767 20827 9768 20828 9769 20829 9770 20830 8 20831 8 20832 9771 20833 9772 20834 8 20835 9773 20836 8 20837 9774 20838 9775 20839 9776 20840 9777 20841 9778 20842 9779 20843 8 20844 9780 20845 8 20846 9781 20847 9782 20848 8 20849 8 20850 8 20851 9783 20852 9784 20853 9785 20854 9786 20855 9787 20856 8 20857 9788 20858 8 20859 8 20860 9789 20861 8 20862 9790 20863 9791 20864 8 20865 8 20866 9792 20867 8 20868 8 20869 9793 20870 8 20871 8 20872 9794 20873 9795 20874 8 20875 8 20876 9796 20877 9797 20878 8 20879 8 20880 9798 20881 9799 20882 8 20883 8 20884 8 20885 9800 20886 9801 20887 9802 20888 9803 20889 9804 20890 8 20891 9805 20892 8 20893 8 20894 9806 20895 8 20896 9807 20897 9808 20898 8 20899 8 20900 9809 20901 8 20902 8 20903 9810 20904 8 20905 8 20906 9811 20907 9812 20908 8 20909 8 20910 9813 20911 9814 20912 8 20913 9815 20914 8 20915 9816 20916 8 20917 9817 20918 9818 20919 8 20920 8 20921 8 20922 9819 20923 8 20924 8 20925 9820 20926 9821 20927 9822 20928 9823 20929 9824 20930 8 20931 9825 20932 8 20933 8 20934 9826 20935 8 20936 9827 20937 9828 20938 8 20939 8 20940 9829 20941 8 20942 9830 20943 8 20944 9831 20945 9832 20946 9833 20947 8106 20948 8106 20949 9834 20950 9835 20951 9836 20952 9837 20953 9838 20954 9839 20955 9840 20956 9841 20957 9842 20958 9843 20959 8 20960 9844 20961 8 20962 9845 20963 8 20964 8 20965 9846 20966 9847 20967 9848 20968 9849 20969 8 20970 8 20971 9850 20972 9851 20973 9852 20974 9853 20975 9854 20976 8 20977 9855 20978 8 20979 9856 20980 8 20981 8 20982 8 20983 8 20984 9857 20985 8 20986 9858 20987 9859 20988 9860 20989 9861 20990 9862 20991 9863 20992 9864 20993 8 20994 9865 20995 9866 20996 8 20997 9867 20998 8 20999 9868 21000 9869 21001 9870 21002 9871 21003 9872 21004 9873 21005 9874 21006 8 21007 8 21008 9875 21009 8 21010 8 21011 9876 21012 9877 21013 9878 21014 8 21015 8 21016 8 21017 8 21018 9879 21019 8 21020 8 21021 8 21022 8 21023 9880 21024 9881 21025 9882 21026 9883 21027 9884 21028 9885 21029 9886 21030 9887 21031 9888 21032 9889 21033 9890 21034 9891 21035 9892 21036 9893 21037 9894 21038 9895 21039 9896 21040 9897 21041 9898 21042 9899 21043 9900 21044 9901 21045 9902 21046 9903 21047 9904 21048 9905 21049 9906 21050 9907 21051 9908 21052 9909 21053 9910 21054 9911 21055 9912 21056 9913 21057 9883 21058 9883 21059 9883 21060 9883 21061 9883 21062 9883 21063 9883 21064 9883 21065 9883 21066 9883 21067 9883 21068 9883 21069 9883 21070 9883 21071 9883 21072 9914 21073 9915 21074 8 21075 8 21076 8 21077 8 21078 8 21079 8 21080 9916 21081 8 21082 8 21083 9917 21084 8 21085 9918 21086 9919 21087 9920 21088 9921 21089 9922 21090 9923 21091 8 21092 9924 21093 8 21094 8 21095 8 21096 8 21097 8 21098 9925 21099 9926 21100 8 21101 8 21102 9927 21103 8 21104 9928 21105 8 21106 8 21107 9929 21108 9930 21109 8 21110 9883 21111 9883 21112 9883 21113 9883 21114 9883 21115 9931 21116 9932 21117 9933 21118 9883 21119 9883 21120 9883 21121 9883 21122 9883 21123 9883 21124 9883 21125 9883 21126 9883 21127 9883 21128 9934 21129 8 21130 8 21131 8 21132 8 21133 8 21134 8 21135 8 21136 8 21137 8 21138 8 21139 8 21140 8 21141 8 21142 8 21143 8 21144 8 21145 8 21146 8 21147 8 21148 8 21149 8 21150 8 21151 8 21152 8 21153 8 21154 8 21155 8 21156 8 21157 8 21158 8 21159 8 21160 8 21161 8 21162 8 21163 8 21164 8 21165 8 21166 8 21167 8 21168 8 21169 8 21170 8 21171 8 21172 8 21173 8 21174 8 21175 8 21176 8 21177 8 21178 8 21179 8 21180 8 21181 8 21182 8 21183 8 21184 8 21185 8 21186 8 21187 8 21188 8 21189 8 21190 8 21191 8 21192 8 21193 8 21194 8 21195 8 21196 8 21197 8 21198 8 21199 8 21200 8 21201 8 21202 8 21203 8 21204 8 21205 8 21206 8 21207 8 21208 9935 21209 8 21210 8 21211 8 21212 9936 21213 9937 21214 8 21215 9938 21216 8 21217 8 21218 9939 21219 9940 21220 9941 21221 8 21222 8 21223 9942 21224 9943 21225 9944 21226 9945 21227 8 21228 9946 21229 8 21230 9947 21231 9948 21232 9949 21233 9950 21234 9951 21235 9952 21236 9953 21237 9954 21238 9955 21239 9883 21240 9883 21241 9883 21242 9883 21243 9883 21244 9883 21245 9883 21246 9883 21247 9883 21248 9883 21249 9883 21250 9883 21251 9883 21252 9956 21253 9883 21254 9957 21255 9958 21256 8 21257 9959 21258 9960 21259 8 21260 9961 21261 8 21262 9962 21263 8 21264 8 21265 8 21266 9963 21267 9964 21268 9965 21269 8 21270 9966 21271 8 21272 8 21273 9967 21274 9968 21275 9969 21276 8 21277 8 21278 8 21279 9970 21280 9971 21281 8 21282 8 21283 8 21284 9972 21285 9973 21286 9974 21287 9975 21288 9976 21289 8 21290 9977 21291 8 21292 8 21293 9978 21294 8 21295 9979 21296 9980 21297 8 21298 8 21299 9981 21300 8 21301 8 21302 8 21303 9982 21304 9983 21305 8 21306 8 21307 9984 21308 9985 21309 9986 21310 9987 21311 9988 21312 9989 21313 9990 21314 9991 21315 9992 21316 9993 21317 9994 21318 8 21319 9995 21320 9996 21321 9997 21322 9998 21323 9999 21324 10000 21325 10001 21326 10002 21327 10003 21328 10004 21329 8 21330 10005 21331 8106 21332 10006 21333 8 21334 10007 21335 8 21336 10008 21337 10009 21338 8 21339 8 21340 8 21341 10010 21342 8 21343 8 21344 10011 21345 10012 21346 10013 21347 10014 21348 10015 21349 8 21350 10016 21351 8 21352 8 21353 10017 21354 8 21355 10018 21356 10019 21357 8 21358 8 21359 10020 21360 8 21361 10021 21362 8 21363 10022 21364 10023 21365 10024 21366 9883 21367 9883 21368 10025 21369 10026 21370 9883 21371 9883 21372 9883 21373 9883 21374 8 21375 10027 21376 8 21377 10028 21378 8 21379 8 21380 9883 21381 9883 21382 8 21383 9883 21384 9883 21385 8 21386 10029 21387 10030 21388 10031 21389 10032 21390 8 21391 8 21392 8 21393 10033 21394 10034 21395 10035 21396 8 21397 8 21398 8 21399 10036 21400 10037 21401 10038 21402 10039 21403 10040 21404 10041 21405 10042 21406 8 21407 10043 21408 10044 21409 10045 21410 10046 21411 10047 21412 8 21413 10048 21414 10049 21415 10050 21416 10051 21417 9883 21418 10052 21419 10053 21420 10054 21421 8 21422 9883 21423 9883 21424 9883 21425 8 21426 10055 21427 8 21428 10056 21429 8 21430 10057 21431 10058 21432 8 21433 10059 21434 10060 21435 8 21436 9883 21437 8 21438 9883 21439 9883 21440 9883 21441 10061 21442 10062 21443 8 21444 9883 21445 9883 21446 9883 21447 10063 21448 8 21449 8 21450 10064 21451 10065 21452 8 21453 10066 21454 8 21455 9883 21456 8106 21457 8106 21458 8106 21459 8 21460 10067 21461 8 21462 10068 21463 8 21464 8 21465 8106 21466 8106 21467 8 21468 8106 21469 8106 21470 8 21471 10069 21472 10070 21473 10071 21474 10072 21475 8 21476 8 21477 8 21478 10073 21479 10074 21480 10075 21481 8 21482 8 21483 8 21484 10076 21485 10077 21486 10078 21487 10079 21488 10080 21489 10081 21490 10082 21491 8 21492 10083 21493 10084 21494 10085 21495 10086 21496 10087 21497 8 21498 10088 21499 10089 21500 10090 21501 10091 21502 8106 21503 10092 21504 10093 21505 10094 21506 8 21507 8106 21508 8106 21509 8106 21510 8 21511 10095 21512 8 21513 10096 21514 8 21515 10097 21516 10098 21517 8 21518 10099 21519 10100 21520 8 21521 8106 21522 8 21523 8106 21524 8106 21525 8106 21526 10101 21527 10102 21528 8 21529 8106 21530 8106 21531 8106 21532 10103 21533 8 21534 8 21535 10104 21536 10105 21537 8 21538 10106 21539 8 21540 8106 21541 10107 21542 10108 21543 10109 21544 10110 21545 10111 21546 10112 21547 10113 21548 10114 21549 8 21550 8 21551 10115 21552 10116 21553 8 21554 10117 21555 8 21556 10118 21557 10119 21558 10120 21559 10121 21560 10122 21561 8 21562 10123 21563 10124 21564 10125 21565 10126 21566 8 21567 8 21568 10127 21569 10128 21570 8 21571 10129 21572 8 21573 10130 21574 8 21575 8 21576 10131 21577 10132 21578 10133 21579 10134 21580 10135 21581 10136 21582 10137 21583 10138 21584 10139 21585 10140 21586 10141 21587 8 21588 8 21589 10142 21590 10143 21591 10144 21592 10145 21593 10146 21594 10147 21595 10148 21596 8 21597 8 21598 10149 21599 10150 21600 8 21601 10151 21602 10152 21603 10153 21604 8 21605 10154 21606 10155 21607 10156 21608 10157 21609 8 21610 8 21611 10158 21612 10159 21613 8 21614 10160 21615 10161 21616 10162 21617 10163 21618 8 21619 10164 21620 10165 21621 10166 21622 10167 21623 10168 21624 10169 21625 8 21626 10170 21627 10171 21628 8 21629 10172 21630 10173 21631 10174 21632 10175 21633 10176 21634 10177 21635 8 21636 10178 21637 10179 21638 10180 21639 10181 21640 8 21641 10182 21642 10183 21643 10184 21644 10185 21645 8 21646 10186 21647 10187 21648 10188 21649 8 21650 10189 21651 8 21652 10190 21653 10191 21654 10192 21655 8 21656 10193 21657 10194 21658 8 21659 8 21660 10195 21661 8 21662 10196 21663 8 21664 10197 21665 10198 21666 10199 21667 10200 21668 10201 21669 8 21670 10202 21671 10203 21672 10204 21673 8 21674 10205 21675 10206 21676 8 21677 10207 21678 8 21679 10208 21680 8 21681 10209 21682 10210 21683 10211 21684 10212 21685 10213 21686 10214 21687 10215 21688 10216 21689 10217 21690 8 21691 8 21692 10218 21693 10219 21694 8 21695 8 21696 10220 21697 10221 21698 10222 21699 10223 21700 10224 21701 10225 21702 10226 21703 10227 21704 8 21705 8 21706 10228 21707 10229 21708 8 21709 10230 21710 10231 21711 10232 21712 10233 21713 10234 21714 10235 21715 8 21716 10236 21717 8 21718 10237 21719 10238 21720 10239 21721 10240 21722 10241 21723 8 21724 10242 21725 10243 21726 10244 21727 10245 21728 8 21729 8 21730 10246 21731 10247 21732 8 21733 10248 21734 8 21735 10249 21736 10250 21737 10251 21738 10252 21739 10253 21740 10254 21741 8 21742 10255 21743 8 21744 10256 21745 10257 21746 10258 21747 10259 21748 10260 21749 10261 21750 10262 21751 10263 21752 10264 21753 10265 21754 8 21755 10266 21756 8 21757 10267 21758 8 21759 8 21760 10268 21761 10269 21762 10270 21763 10271 21764 8 21765 8 21766 10272 21767 10273 21768 10274 21769 10275 21770 10276 21771 8 21772 10277 21773 8 21774 10278 21775 8 21776 8 21777 8 21778 8 21779 10279 21780 8 21781 10280 21782 10281 21783 10282 21784 10283 21785 10284 21786 10285 21787 10286 21788 8 21789 10287 21790 10288 21791 8 21792 10289 21793 8 21794 10290 21795 10291 21796 10292 21797 10293 21798 10294 21799 10295 21800 10296 21801 8 21802 8 21803 10297 21804 8 21805 8 21806 10298 21807 10299 21808 10300 21809 8 21810 8 21811 8 21812 8 21813 10301 21814 8 21815 8 21816 8 21817 8 21818 10302 21819 10303 21820 10304 21821 10305 21822 10306 21823 10307 21824 10308 21825 10309 21826 10310 21827 10311 21828 10312 21829 10313 21830 10314 21831 10315 21832 10316 21833 10317 21834 10318 21835 10319 21836 10320 21837 10321 21838 10322 21839 10323 21840 10324 21841 10325 21842 10326 21843 10327 21844 10328 21845 10329 21846 10330 21847 10331 21848 10332 21849 10333 21850 10334 21851 10335 21852 10305 21853 10305 21854 10305 21855 10305 21856 10305 21857 10305 21858 10305 21859 10305 21860 10305 21861 10305 21862 10305 21863 10305 21864 10305 21865 10305 21866 10305 21867 10336 21868 10337 21869 8 21870 8 21871 8 21872 8 21873 8 21874 8 21875 10338 21876 8 21877 8 21878 10339 21879 8 21880 10340 21881 10341 21882 10342 21883 10343 21884 10344 21885 10345 21886 8 21887 10346 21888 8 21889 8 21890 8 21891 8 21892 8 21893 10347 21894 10348 21895 8 21896 8 21897 10349 21898 8 21899 10350 21900 8 21901 8 21902 10351 21903 10352 21904 8 21905 10305 21906 10305 21907 10305 21908 10305 21909 10305 21910 10353 21911 10354 21912 10355 21913 10305 21914 10305 21915 10305 21916 10305 21917 10305 21918 10305 21919 10305 21920 10305 21921 10305 21922 10305 21923 10356 21924 8 21925 8 21926 8 21927 8 21928 8 21929 8 21930 8 21931 8 21932 8 21933 8 21934 8 21935 8 21936 8 21937 8 21938 8 21939 8 21940 8 21941 8 21942 8 21943 8 21944 8 21945 8 21946 8 21947 8 21948 8 21949 8 21950 8 21951 8 21952 8 21953 8 21954 8 21955 8 21956 8 21957 8 21958 8 21959 8 21960 8 21961 8 21962 8 21963 8 21964 8 21965 8 21966 8 21967 8 21968 8 21969 8 21970 8 21971 8 21972 8 21973 8 21974 8 21975 8 21976 8 21977 8 21978 8 21979 8 21980 8 21981 8 21982 8 21983 8 21984 8 21985 8 21986 8 21987 8 21988 8 21989 8 21990 8 21991 8 21992 8 21993 8 21994 8 21995 8 21996 8 21997 8 21998 8 21999 8 22000 8 22001 8 22002 8 22003 10357 22004 8 22005 8 22006 8 22007 10358 22008 10359 22009 8 22010 10360 22011 8 22012 8 22013 10361 22014 10362 22015 10363 22016 8 22017 8 22018 10364 22019 10365 22020 10366 22021 10367 22022 8 22023 10368 22024 8 22025 10369 22026 10370 22027 10371 22028 10372 22029 10373 22030 10374 22031 10375 22032 10376 22033 10377 22034 10305 22035 10305 22036 10305 22037 10305 22038 10305 22039 10305 22040 10305 22041 10305 22042 10305 22043 10305 22044 10305 22045 10305 22046 10305 22047 10378 22048 10305 22049 10379 22050 10380 22051 8 22052 10381 22053 10382 22054 8 22055 10383 22056 8 22057 10384 22058 8 22059 8 22060 8 22061 10385 22062 10386 22063 10387 22064 8 22065 10388 22066 8 22067 8 22068 10389 22069 10390 22070 10391 22071 8 22072 8 22073 8 22074 10392 22075 10393 22076 8 22077 8 22078 8 22079 10394 22080 10395 22081 10396 22082 10397 22083 10398 22084 8 22085 10399 22086 8 22087 8 22088 10400 22089 8 22090 10401 22091 10402 22092 8 22093 8 22094 10403 22095 8 22096 8 22097 8 22098 10404 22099 10405 22100 8 22101 8 22102 10406 22103 10407 22104 10408 22105 10409 22106 10410 22107 10411 22108 10412 22109 10413 22110 10414 22111 10415 22112 10416 22113 8 22114 10417 22115 10418 22116 10419 22117 10420 22118 10421 22119 10422 22120 10423 22121 10424 22122 10425 22123 10426 22124 10427 22125 10428 22126 10429 22127 10430 22128 10431 22129 10432 22130 10433 22131 10434 22132 10435 22133 8 22134 10436 22135 8 22136 10437 22137 8 22138 8 22139 10438 22140 10439 22141 10440 22142 10441 22143 8 22144 8 22145 10442 22146 10443 22147 10444 22148 10445 22149 10446 22150 8 22151 10447 22152 8 22153 10448 22154 8 22155 8 22156 8 22157 8 22158 10449 22159 8 22160 10450 22161 10451 22162 10452 22163 10453 22164 10454 22165 10455 22166 10456 22167 8 22168 10457 22169 10458 22170 8 22171 10459 22172 8 22173 10460 22174 10461 22175 10462 22176 10463 22177 10464 22178 10465 22179 10466 22180 8 22181 8 22182 10467 22183 8 22184 8 22185 10468 22186 10469 22187 10470 22188 8 22189 8 22190 8 22191 8 22192 10471 22193 8 22194 8 22195 8 22196 8 22197 10472 22198 10473 22199 10474 22200 10475 22201 10476 22202 10477 22203 10478 22204 10479 22205 10480 22206 10481 22207 10482 22208 10483 22209 10484 22210 10485 22211 10486 22212 10487 22213 10488 22214 10489 22215 10490 22216 10491 22217 10492 22218 10493 22219 10494 22220 10495 22221 10496 22222 10497 22223 10498 22224 10499 22225 10500 22226 10501 22227 10502 22228 10503 22229 10504 22230 10505 22231 10475 22232 10475 22233 10475 22234 10475 22235 10475 22236 10475 22237 10475 22238 10475 22239 10475 22240 10475 22241 10475 22242 10475 22243 10475 22244 10475 22245 10475 22246 10506 22247 10507 22248 8 22249 8 22250 8 22251 8 22252 8 22253 8 22254 10508 22255 8 22256 8 22257 10509 22258 8 22259 10510 22260 10511 22261 10512 22262 10513 22263 10514 22264 10515 22265 8 22266 10516 22267 8 22268 8 22269 8 22270 8 22271 8 22272 10517 22273 10518 22274 8 22275 8 22276 10519 22277 8 22278 10520 22279 8 22280 8 22281 10521 22282 10522 22283 8 22284 10475 22285 10475 22286 10475 22287 10475 22288 10475 22289 10523 22290 10524 22291 10525 22292 10475 22293 10475 22294 10475 22295 10475 22296 10475 22297 10475 22298 10475 22299 10475 22300 10475 22301 10475 22302 10526 22303 8 22304 8 22305 8 22306 8 22307 8 22308 8 22309 8 22310 8 22311 8 22312 8 22313 8 22314 8 22315 8 22316 8 22317 8 22318 8 22319 8 22320 8 22321 8 22322 8 22323 8 22324 8 22325 8 22326 8 22327 8 22328 8 22329 8 22330 8 22331 8 22332 8 22333 8 22334 8 22335 8 22336 8 22337 8 22338 8 22339 8 22340 8 22341 8 22342 8 22343 8 22344 8 22345 8 22346 8 22347 8 22348 8 22349 8 22350 8 22351 8 22352 8 22353 8 22354 8 22355 8 22356 8 22357 8 22358 8 22359 8 22360 8 22361 8 22362 8 22363 8 22364 8 22365 8 22366 8 22367 8 22368 8 22369 8 22370 8 22371 8 22372 8 22373 8 22374 8 22375 8 22376 8 22377 8 22378 8 22379 8 22380 8 22381 8 22382 10527 22383 8 22384 8 22385 8 22386 10528 22387 10529 22388 8 22389 10530 22390 8 22391 8 22392 10531 22393 10532 22394 10533 22395 8 22396 8 22397 10534 22398 10535 22399 10536 22400 10537 22401 8 22402 10538 22403 8 22404 10539 22405 10540 22406 10541 22407 10542 22408 10543 22409 10544 22410 10545 22411 10546 22412 10547 22413 10475 22414 10475 22415 10475 22416 10475 22417 10475 22418 10475 22419 10475 22420 10475 22421 10475 22422 10475 22423 10475 22424 10475 22425 10475 22426 10548 22427 10475 22428 10549 22429 10550 22430 8 22431 10551 22432 10552 22433 8 22434 10553 22435 8 22436 10554 22437 8 22438 8 22439 8 22440 10555 22441 10556 22442 10557 22443 8 22444 10558 22445 8 22446 8 22447 10559 22448 10560 22449 10561 22450 8 22451 8 22452 8 22453 10562 22454 10563 22455 8 22456 8 22457 8 22458 10564 22459 10565 22460 10566 22461 10567 22462 10568 22463 8 22464 10569 22465 8 22466 8 22467 10570 22468 8 22469 10571 22470 10572 22471 8 22472 8 22473 10573 22474 8 22475 8 22476 8 22477 10574 22478 10575 22479 8 22480 8 22481 10576 22482 10577 22483 10578 22484 10579 22485 10580 22486 10581 22487 10582 22488 10583 22489 10584 22490 10585 22491 10586 22492 8 22493 10587 22494 10588 22495 10589 22496 10590 22497 10591 22498 10592 22499 10593 22500 10594 22501 10595 22502 10596 22503 8 22504 8 22505 10597 22506 8 22507 10598 22508 8 22509 10599 22510 10600 22511 8 22512 8 22513 8 22514 10601 22515 8 22516 8 22517 10602 22518 10603 22519 10604 22520 10605 22521 10606 22522 8 22523 10607 22524 8 22525 8 22526 10608 22527 8 22528 10609 22529 10610 22530 8 22531 8 22532 10611 22533 8 22534 10612 22535 8 22536 10613 22537 10614 22538 10615 22539 10475 22540 10475 22541 10616 22542 10617 22543 10618 22544 10619 22545 10620 22546 10621 22547 10622 22548 10623 22549 10624 22550 10625 22551 8 22552 10626 22553 8 22554 10627 22555 8 22556 8 22557 10628 22558 10629 22559 10630 22560 10631 22561 8 22562 8 22563 10632 22564 10633 22565 10634 22566 10635 22567 10636 22568 8 22569 10637 22570 8 22571 10638 22572 8 22573 8 22574 8 22575 8 22576 10639 22577 8 22578 10640 22579 10641 22580 10642 22581 10643 22582 10644 22583 10645 22584 10646 22585 8 22586 10647 22587 10648 22588 8 22589 10649 22590 8 22591 10650 22592 10651 22593 10652 22594 10653 22595 10654 22596 10655 22597 10656 22598 8 22599 8 22600 10657 22601 8 22602 8 22603 10658 22604 10659 22605 10660 22606 8 22607 8 22608 8 22609 8 22610 10661 22611 8 22612 8 22613 8 22614 8 22615 10662 22616 10663 22617 10664 22618 10665 22619 10666 22620 10667 22621 10668 22622 10669 22623 10670 22624 10671 22625 10672 22626 10673 22627 10674 22628 10675 22629 10676 22630 10677 22631 10678 22632 10679 22633 10680 22634 10681 22635 10682 22636 10683 22637 10684 22638 10685 22639 10686 22640 10687 22641 10688 22642 10689 22643 10690 22644 10691 22645 10692 22646 10693 22647 10694 22648 10695 22649 10665 22650 10665 22651 10665 22652 10665 22653 10665 22654 10665 22655 10665 22656 10665 22657 10665 22658 10665 22659 10665 22660 10665 22661 10665 22662 10665 22663 10665 22664 10696 22665 10697 22666 8 22667 8 22668 8 22669 8 22670 8 22671 8 22672 10698 22673 8 22674 8 22675 10699 22676 8 22677 10700 22678 10701 22679 10702 22680 10703 22681 10704 22682 10705 22683 8 22684 10706 22685 8 22686 8 22687 8 22688 8 22689 8 22690 10707 22691 10708 22692 8 22693 8 22694 10709 22695 8 22696 10710 22697 8 22698 8 22699 10711 22700 10712 22701 8 22702 10665 22703 10665 22704 10665 22705 10665 22706 10665 22707 10713 22708 10714 22709 10715 22710 10665 22711 10665 22712 10665 22713 10665 22714 10665 22715 10665 22716 10665 22717 10665 22718 10665 22719 10665 22720 10716 22721 8 22722 8 22723 8 22724 8 22725 8 22726 8 22727 8 22728 8 22729 8 22730 8 22731 8 22732 8 22733 8 22734 8 22735 8 22736 8 22737 8 22738 8 22739 8 22740 8 22741 8 22742 8 22743 8 22744 8 22745 8 22746 8 22747 8 22748 8 22749 8 22750 8 22751 8 22752 8 22753 8 22754 8 22755 8 22756 8 22757 8 22758 8 22759 8 22760 8 22761 8 22762 8 22763 8 22764 8 22765 8 22766 8 22767 8 22768 8 22769 8 22770 8 22771 8 22772 8 22773 8 22774 8 22775 8 22776 8 22777 8 22778 8 22779 8 22780 8 22781 8 22782 8 22783 8 22784 8 22785 8 22786 8 22787 8 22788 8 22789 8 22790 8 22791 8 22792 8 22793 8 22794 8 22795 8 22796 8 22797 8 22798 8 22799 8 22800 10717 22801 8 22802 8 22803 8 22804 10718 22805 10719 22806 8 22807 10720 22808 8 22809 8 22810 10721 22811 10722 22812 10723 22813 8 22814 8 22815 10724 22816 10725 22817 10726 22818 10727 22819 8 22820 10728 22821 8 22822 10729 22823 10730 22824 10731 22825 10732 22826 10733 22827 10734 22828 10735 22829 10736 22830 10737 22831 10665 22832 10665 22833 10665 22834 10665 22835 10665 22836 10665 22837 10665 22838 10665 22839 10665 22840 10665 22841 10665 22842 10665 22843 10665 22844 10738 22845 10665 22846 10739 22847 10740 22848 8 22849 10741 22850 10742 22851 8 22852 10743 22853 8 22854 10744 22855 8 22856 8 22857 8 22858 10745 22859 10746 22860 10747 22861 8 22862 10748 22863 8 22864 8 22865 10749 22866 10750 22867 10751 22868 8 22869 8 22870 8 22871 10752 22872 10753 22873 8 22874 8 22875 8 22876 10754 22877 10755 22878 10756 22879 10757 22880 10758 22881 8 22882 10759 22883 8 22884 8 22885 10760 22886 8 22887 10761 22888 10762 22889 8 22890 8 22891 10763 22892 8 22893 8 22894 8 22895 10764 22896 10765 22897 8 22898 8 22899 10766 22900 10767 22901 10768 22902 10769 22903 10770 22904 10771 22905 10772 22906 10773 22907 10774 22908 10775 22909 10776 22910 8 22911 10777 22912 10778 22913 10779 22914 10780 22915 10781 22916 10782 22917 10783 22918 10784 22919 10785 22920 10786 22921 8 22922 10787 22923 10475 22924 10788 22925 8 22926 10789 22927 8 22928 10790 22929 10791 22930 8 22931 8 22932 8 22933 10792 22934 8 22935 8 22936 10793 22937 10794 22938 10795 22939 10796 22940 10797 22941 8 22942 10798 22943 8 22944 8 22945 10799 22946 8 22947 10800 22948 10801 22949 8 22950 8 22951 10802 22952 8 22953 10803 22954 8 22955 10804 22956 10805 22957 10806 22958 10665 22959 10665 22960 10807 22961 10808 22962 10665 22963 10665 22964 10665 22965 10665 22966 8 22967 10809 22968 8 22969 10810 22970 8 22971 8 22972 10665 22973 10665 22974 8 22975 10665 22976 10665 22977 10811 22978 8 22979 8 22980 8 22981 8 22982 8 22983 8 22984 10812 22985 10813 22986 10814 22987 10815 22988 8 22989 10816 22990 8 22991 10817 22992 10818 22993 10819 22994 10820 22995 10821 22996 10822 22997 8 22998 10823 22999 8 23000 8 23001 8 23002 8 23003 10824 23004 8 23005 8 23006 8 23007 10825 23008 10826 23009 10827 23010 8 23011 8 23012 10828 23013 8 23014 8 23015 10829 23016 10830 23017 10831 23018 10832 23019 10833 23020 10834 23021 10835 23022 8 23023 10836 23024 8 23025 10837 23026 10838 23027 10839 23028 10840 23029 10841 23030 8 23031 10842 23032 10843 23033 10844 23034 10845 23035 10665 23036 10846 23037 10847 23038 10848 23039 8 23040 10665 23041 10665 23042 10665 23043 8 23044 10849 23045 8 23046 10850 23047 8 23048 10851 23049 10852 23050 8 23051 10853 23052 10854 23053 8 23054 10665 23055 8 23056 10665 23057 10665 23058 10665 23059 10855 23060 10856 23061 8 23062 10665 23063 10665 23064 10665 23065 10857 23066 8 23067 8 23068 10858 23069 10859 23070 8 23071 10860 23072 8 23073 10665 23074 10475 23075 10475 23076 10475 23077 8 23078 10861 23079 8 23080 10862 23081 8 23082 8 23083 10475 23084 10475 23085 8 23086 10475 23087 10475 23088 10863 23089 8 23090 8 23091 8 23092 8 23093 8 23094 8 23095 10864 23096 10865 23097 10866 23098 10867 23099 8 23100 10868 23101 8 23102 10869 23103 10870 23104 10871 23105 10872 23106 10873 23107 10874 23108 8 23109 10875 23110 8 23111 8 23112 8 23113 8 23114 10876 23115 8 23116 8 23117 8 23118 10877 23119 10878 23120 10879 23121 8 23122 8 23123 10880 23124 8 23125 8 23126 10881 23127 10882 23128 10883 23129 10884 23130 10885 23131 10886 23132 10887 23133 8 23134 10888 23135 8 23136 10889 23137 10890 23138 10891 23139 10892 23140 10893 23141 8 23142 10894 23143 10895 23144 10896 23145 10897 23146 10475 23147 10898 23148 10899 23149 10900 23150 8 23151 10475 23152 10475 23153 10475 23154 8 23155 10901 23156 8 23157 10902 23158 8 23159 10903 23160 10904 23161 8 23162 10905 23163 10906 23164 8 23165 10475 23166 8 23167 10475 23168 10475 23169 10475 23170 10907 23171 10908 23172 8 23173 10475 23174 10475 23175 10475 23176 10909 23177 8 23178 8 23179 10910 23180 10911 23181 8 23182 10912 23183 8 23184 10475 23185 10913 23186 7483 23187 10914 23188 8 23189 10915 23190 8 23191 10916 23192 10917 23193 8 23194 8 23195 8 23196 10918 23197 8 23198 8 23199 10919 23200 10920 23201 10921 23202 10922 23203 10923 23204 8 23205 10924 23206 8 23207 8 23208 10925 23209 8 23210 10926 23211 10927 23212 8 23213 8 23214 10928 23215 8 23216 10929 23217 8 23218 10930 23219 10931 23220 10932 23221 10305 23222 10305 23223 10933 23224 10934 23225 10935 23226 10936 23227 10937 23228 10938 23229 10939 23230 10940 23231 10941 23232 10942 23233 8 23234 10943 23235 8 23236 10944 23237 8 23238 8 23239 10945 23240 10946 23241 10947 23242 10948 23243 8 23244 8 23245 10949 23246 10950 23247 10951 23248 10952 23249 10953 23250 8 23251 10954 23252 8 23253 10955 23254 8 23255 8 23256 8 23257 8 23258 10956 23259 8 23260 10957 23261 10958 23262 10959 23263 10960 23264 10961 23265 10962 23266 10963 23267 8 23268 10964 23269 10965 23270 8 23271 10966 23272 8 23273 10967 23274 10968 23275 10969 23276 10970 23277 10971 23278 10972 23279 10973 23280 8 23281 8 23282 10974 23283 8 23284 8 23285 10975 23286 10976 23287 10977 23288 8 23289 8 23290 8 23291 8 23292 10978 23293 8 23294 8 23295 8 23296 8 23297 10979 23298 10980 23299 10981 23300 10982 23301 10983 23302 10984 23303 10985 23304 10986 23305 10987 23306 10988 23307 10989 23308 10990 23309 10991 23310 10992 23311 10993 23312 10994 23313 10995 23314 10996 23315 10997 23316 10998 23317 10999 23318 11000 23319 11001 23320 11002 23321 11003 23322 11004 23323 11005 23324 11006 23325 11007 23326 11008 23327 11009 23328 11010 23329 11011 23330 11012 23331 10982 23332 10982 23333 10982 23334 10982 23335 10982 23336 10982 23337 10982 23338 10982 23339 10982 23340 10982 23341 10982 23342 10982 23343 10982 23344 10982 23345 10982 23346 11013 23347 11014 23348 8 23349 8 23350 8 23351 8 23352 8 23353 8 23354 11015 23355 8 23356 8 23357 11016 23358 8 23359 11017 23360 11018 23361 11019 23362 11020 23363 11021 23364 11022 23365 8 23366 11023 23367 8 23368 8 23369 8 23370 8 23371 8 23372 11024 23373 11025 23374 8 23375 8 23376 11026 23377 8 23378 11027 23379 8 23380 8 23381 11028 23382 11029 23383 8 23384 10982 23385 10982 23386 10982 23387 10982 23388 10982 23389 11030 23390 11031 23391 11032 23392 10982 23393 10982 23394 10982 23395 10982 23396 10982 23397 10982 23398 10982 23399 10982 23400 10982 23401 10982 23402 11033 23403 8 23404 8 23405 8 23406 8 23407 8 23408 8 23409 8 23410 8 23411 8 23412 8 23413 8 23414 8 23415 8 23416 8 23417 8 23418 8 23419 8 23420 8 23421 8 23422 8 23423 8 23424 8 23425 8 23426 8 23427 8 23428 8 23429 8 23430 8 23431 8 23432 8 23433 8 23434 8 23435 8 23436 8 23437 8 23438 8 23439 8 23440 8 23441 8 23442 8 23443 8 23444 8 23445 8 23446 8 23447 8 23448 8 23449 8 23450 8 23451 8 23452 8 23453 8 23454 8 23455 8 23456 8 23457 8 23458 8 23459 8 23460 8 23461 8 23462 8 23463 8 23464 8 23465 8 23466 8 23467 8 23468 8 23469 8 23470 8 23471 8 23472 8 23473 8 23474 8 23475 8 23476 8 23477 8 23478 8 23479 8 23480 8 23481 8 23482 11034 23483 8 23484 8 23485 8 23486 11035 23487 11036 23488 8 23489 11037 23490 8 23491 8 23492 11038 23493 11039 23494 11040 23495 8 23496 8 23497 11041 23498 11042 23499 11043 23500 11044 23501 8 23502 11045 23503 8 23504 11046 23505 11047 23506 11048 23507 11049 23508 11050 23509 11051 23510 11052 23511 11053 23512 11054 23513 10982 23514 10982 23515 10982 23516 10982 23517 10982 23518 10982 23519 10982 23520 10982 23521 10982 23522 10982 23523 10982 23524 10982 23525 10982 23526 11055 23527 10982 23528 11056 23529 11057 23530 8 23531 11058 23532 11059 23533 8 23534 11060 23535 8 23536 11061 23537 8 23538 8 23539 8 23540 11062 23541 11063 23542 11064 23543 8 23544 11065 23545 8 23546 8 23547 11066 23548 11067 23549 11068 23550 8 23551 8 23552 8 23553 11069 23554 11070 23555 8 23556 8 23557 8 23558 11071 23559 11072 23560 11073 23561 11074 23562 11075 23563 8 23564 11076 23565 8 23566 8 23567 11077 23568 8 23569 11078 23570 11079 23571 8 23572 8 23573 11080 23574 8 23575 8 23576 8 23577 11081 23578 11082 23579 8 23580 8 23581 11083 23582 11084 23583 11085 23584 11086 23585 11087 23586 11088 23587 11089 23588 11090 23589 11091 23590 11092 23591 11093 23592 8 23593 11094 23594 11095 23595 11096 23596 11097 23597 11098 23598 11099 23599 11100 23600 11101 23601 11102 23602 11103 23603 8 23604 11104 23605 10305 23606 11105 23607 8 23608 11106 23609 8 23610 11107 23611 11108 23612 8 23613 8 23614 8 23615 11109 23616 8 23617 8 23618 11110 23619 11111 23620 11112 23621 11113 23622 11114 23623 8 23624 11115 23625 8 23626 8 23627 11116 23628 8 23629 11117 23630 11118 23631 8 23632 8 23633 11119 23634 8 23635 11120 23636 8 23637 11121 23638 11122 23639 11123 23640 10982 23641 10982 23642 11124 23643 11125 23644 10982 23645 10982 23646 10982 23647 10982 23648 8 23649 11126 23650 8 23651 11127 23652 8 23653 8 23654 10982 23655 10982 23656 8 23657 10982 23658 10982 23659 8 23660 11128 23661 11129 23662 11130 23663 11131 23664 8 23665 8 23666 8 23667 11132 23668 11133 23669 11134 23670 8 23671 8 23672 8 23673 11135 23674 11136 23675 11137 23676 11138 23677 11139 23678 11140 23679 11141 23680 8 23681 11142 23682 11143 23683 11144 23684 11145 23685 11146 23686 8 23687 11147 23688 11148 23689 11149 23690 11150 23691 10982 23692 11151 23693 11152 23694 11153 23695 8 23696 10982 23697 10982 23698 10982 23699 8 23700 11154 23701 8 23702 11155 23703 8 23704 11156 23705 11157 23706 8 23707 11158 23708 11159 23709 8 23710 10982 23711 8 23712 10982 23713 10982 23714 10982 23715 11160 23716 11161 23717 8 23718 10982 23719 10982 23720 10982 23721 11162 23722 8 23723 8 23724 11163 23725 11164 23726 8 23727 11165 23728 8 23729 10982 23730 10305 23731 10305 23732 10305 23733 8 23734 11166 23735 8 23736 11167 23737 8 23738 8 23739 10305 23740 10305 23741 8 23742 10305 23743 10305 23744 8 23745 11168 23746 11169 23747 11170 23748 11171 23749 8 23750 8 23751 8 23752 11172 23753 11173 23754 11174 23755 8 23756 8 23757 8 23758 11175 23759 11176 23760 11177 23761 11178 23762 11179 23763 11180 23764 11181 23765 8 23766 11182 23767 11183 23768 11184 23769 11185 23770 11186 23771 8 23772 11187 23773 11188 23774 11189 23775 11190 23776 10305 23777 11191 23778 11192 23779 11193 23780 8 23781 10305 23782 10305 23783 10305 23784 8 23785 11194 23786 8 23787 11195 23788 8 23789 11196 23790 11197 23791 8 23792 11198 23793 11199 23794 8 23795 10305 23796 8 23797 10305 23798 10305 23799 10305 23800 11200 23801 11201 23802 8 23803 10305 23804 10305 23805 10305 23806 11202 23807 8 23808 8 23809 11203 23810 11204 23811 8 23812 11205 23813 8 23814 10305 23815 11206 23816 11207 23817 8 23818 8 23819 11208 23820 8 23821 11209 23822 8 23823 11210 23824 8 23825 11211 23826 8 23827 11212 23828 11213 23829 11214 23830 11215 23831 11216 23832 11217 23833 11218 23834 11219 23835 11220 23836 8 23837 8 23838 11221 23839 11222 23840 8 23841 8 23842 11223 23843 11224 23844 11225 23845 11226 23846 11227 23847 11228 23848 11229 23849 11230 23850 8 23851 8 23852 11231 23853 11232 23854 8 23855 11233 23856 8 23857 11234 23858 11235 23859 11236 23860 11237 23861 11238 23862 8 23863 11239 23864 11240 23865 11241 23866 11242 23867 8 23868 8 23869 11243 23870 11244 23871 8 23872 11245 23873 8 23874 11246 23875 8 23876 8 23877 11247 23878 11248 23879 11249 23880 11250 23881 11251 23882 11252 23883 11253 23884 11254 23885 11255 23886 11256 23887 11257 23888 8 23889 8 23890 11258 23891 11259 23892 11260 23893 11261 23894 11262 23895 11263 23896 11264 23897 8 23898 8 23899 11265 23900 11266 23901 8 23902 11267 23903 11268 23904 11269 23905 8 23906 11270 23907 11271 23908 11272 23909 11273 23910 8 23911 8 23912 11274 23913 11275 23914 8 23915 11276 23916 11277 23917 11278 23918 11279 23919 8 23920 11280 23921 11281 23922 11282 23923 11283 23924 11284 23925 11285 23926 8 23927 11286 23928 11287 23929 8 23930 11288 23931 11289 23932 11290 23933 11291 23934 11292 23935 11293 23936 8 23937 11294 23938 11295 23939 11296 23940 11297 23941 8 23942 11298 23943 11299 23944 11300 23945 11301 23946 8 23947 11302 23948 11303 23949 11304 23950 8 23951 11305 23952 8 23953 11306 23954 11307 23955 11308 23956 8 23957 11309 23958 11310 23959 8 23960 8 23961 11311 23962 8 23963 11312 23964 8 23965 11313 23966 11314 23967 11315 23968 11316 23969 11317 23970 8 23971 11318 23972 11319 23973 11320 23974 8 23975 11321 23976 11322 23977 8 23978 11323 23979 8 23980 11324 23981 8 23982 11325 23983 11326 23984 11327 23985 11328 23986 11329 23987 11330 23988 11331 23989 11332 23990 11333 23991 8 23992 8 23993 11334 23994 11335 23995 8 23996 8 23997 11336 23998 11337 23999 11338 24000 11339 24001 11340 24002 11341 24003 11342 24004 11343 24005 8 24006 8 24007 11344 24008 11345 24009 8 24010 11346 24011 11347 24012 11348 24013 11349 24014 11350 24015 11351 24016 8 24017 11352 24018 8 24019 11353 24020 11354 24021 11355 24022 11356 24023 11357 24024 8 24025 11358 24026 11359 24027 11360 24028 11361 24029 8 24030 8 24031 11362 24032 11363 24033 8 24034 11364 24035 8 24036 11365 24037 11366 24038 11367 24039 11368 24040 11369 24041 11370 24042 8 24043 11371 24044 8 24045 11372 24046 11373 24047 7382 24048 11374 24049 8 24050 11375 24051 11376 24052 11377 24053 8 24054 11378 24055 11379 24056 8 24057 8 24058 11380 24059 8 24060 11381 24061 8 24062 11382 24063 8 24064 11383 24065 8 24066 11384 24067 11385 24068 11386 24069 11387 24070 11388 24071 11389 24072 11390 24073 11391 24074 11392 24075 8 24076 8 24077 11393 24078 11394 24079 8 24080 8 24081 11395 24082 11396 24083 11397 24084 11398 24085 11399 24086 11400 24087 11401 24088 11402 24089 8 24090 8 24091 11403 24092 11404 24093 8 24094 11405 24095 8 24096 11406 24097 11407 24098 11408 24099 11409 24100 11410 24101 8 24102 11411 24103 11412 24104 11413 24105 11414 24106 8 24107 8 24108 11415 24109 11416 24110 8 24111 11417 24112 8 24113 11418 24114 8 24115 8 24116 11419 24117 11420 24118 11421 24119 11422 24120 11423 24121 11424 24122 11425 24123 11426 24124 11427 24125 11428 24126 11429 24127 8 24128 8 24129 11430 24130 11431 24131 11432 24132 11433 24133 11434 24134 11435 24135 11436 24136 8 24137 8 24138 11437 24139 11438 24140 8 24141 11439 24142 11440 24143 11441 24144 8 24145 11442 24146 11443 24147 11444 24148 11445 24149 8 24150 8 24151 11446 24152 11447 24153 8 24154 11448 24155 11449 24156 11450 24157 11451 24158 8 24159 11452 24160 11453 24161 11454 24162 11455 24163 11456 24164 11457 24165 8 24166 11458 24167 11459 24168 8 24169 11460 24170 11461 24171 11462 24172 11463 24173 11464 24174 11465 24175 8 24176 11466 24177 11467 24178 11468 24179 11469 24180 8 24181 11470 24182 11471 24183 11472 24184 11473 24185 8 24186 11474 24187 11475 24188 11476 24189 8 24190 11477 24191 8 24192 11478 24193 11479 24194 11480 24195 8 24196 11481 24197 11482 24198 8 24199 8 24200 11483 24201 8 24202 11484 24203 8 24204 11485 24205 11486 24206 11487 24207 11488 24208 11489 24209 8 24210 11490 24211 11491 24212 11492 24213 8 24214 11493 24215 11494 24216 8 24217 11495 24218 8 24219 11496 24220 8 24221 11497 24222 11498 24223 11499 24224 11500 24225 11501 24226 11502 24227 11503 24228 11504 24229 11505 24230 8 24231 8 24232 11506 24233 11507 24234 8 24235 8 24236 11508 24237 11509 24238 11510 24239 11511 24240 11512 24241 11513 24242 11514 24243 11515 24244 8 24245 8 24246 11516 24247 11517 24248 8 24249 11518 24250 11519 24251 11520 24252 11521 24253 11522 24254 11523 24255 8 24256 8 24257 11524 24258 8 24259 11525 24260 11526 24261 11527 24262 11528 24263 11529 24264 8 24265 11530 24266 11531 24267 11532 24268 11533 24269 8 24270 8 24271 11534 24272 11535 24273 8 24274 11536 24275 8 24276 11537 24277 11538 24278 11539 24279 11540 24280 11541 24281 11542 24282 8 24283 11543 24284 8 24285 11544 24286 11545 24287 11546 24288 11547 24289 8 24290 11548 24291 11549 24292 11550 24293 11551 24294 11552 24295 11553 24296 8 24297 11554 24298 11555 24299 8 24300 11556 24301 11557 24302 11558 24303 11559 24304 11560 24305 11561 24306 8 24307 11562 24308 11563 24309 11564 24310 11565 24311 8 24312 11566 24313 11567 24314 11568 24315 11569 24316 8 24317 11570 24318 11571 24319 11572 24320 8 24321 11573 24322 8 24323 11574 24324 11575 24325 11576 24326 8 24327 11577 24328 11578 24329 8 24330 8 24331 11579 24332 8 24333 11580 24334 8 24335 11581 24336 11582 24337 11583 24338 11584 24339 11585 24340 8 24341 11586 24342 11587 24343 8 24344 11588 24345 8 24346 11589 24347 8 24348 11590 24349 11591 24350 11592 24351 11593 24352 11594 24353 11595 24354 11596 24355 11597 24356 11598 24357 8 24358 8 24359 11599 24360 11600 24361 8 24362 8 24363 11601 24364 11602 24365 11603 24366 11604 24367 11605 24368 11606 24369 11607 24370 11608 24371 8 24372 8 24373 11609 24374 11610 24375 8 24376 11611 24377 11612 24378 11613 24379 11614 24380 11615 24381 11616 24382 8 24383 8 24384 11617 24385 8 24386 11618 24387 11619 24388 11620 24389 11621 24390 11622 24391 8 24392 11623 24393 11624 24394 11625 24395 11626 24396 8 24397 8 24398 11627 24399 11628 24400 8 24401 11629 24402 8 24403 11630 24404 11631 24405 11632 24406 11633 24407 11634 24408 11635 24409 8 24410 11636 24411 8 24412 11637 24413 11638 24414 11639 24415 11640 24416 8 24417 8 24418 11641 24419 11642 24420 8 24421 11643 24422 11644 24423 11645 24424 11646 24425 8 24426 11647 24427 11648 24428 11649 24429 11650 24430 11651 24431 11652 24432 8 24433 11653 24434 11654 24435 8 24436 11655 24437 11656 24438 11657 24439 11658 24440 11659 24441 11660 24442 8 24443 11661 24444 11662 24445 11663 24446 11664 24447 8 24448 11665 24449 11666 24450 11667 24451 11668 24452 8 24453 11669 24454 11670 24455 11671 24456 8 24457 11672 24458 8 24459 11673 24460 11674 24461 11675 24462 8 24463 11676 24464 11677 24465 8 24466 8 24467 11678 24468 8 24469 11679 24470 8 24471 11680 24472 11681 24473 11682 24474 11683 24475 11684 24476 8 24477 11685 24478 11686 24479 11687 24480 8 24481 11688 24482 11689 24483 8 24484 11690 24485 8 24486 11691 24487 8 24488 11692 24489 11693 24490 11694 24491 11695 24492 11696 24493 11697 24494 11698 24495 11699 24496 11700 24497 8 24498 8 24499 11701 24500 11702 24501 8 24502 8 24503 11703 24504 11704 24505 11705 24506 11706 24507 11707 24508 11708 24509 11709 24510 11710 24511 8 24512 8 24513 11711 24514 11712 24515 8 24516 11713 24517 11714 24518 11715 24519 11716 24520 11717 24521 11718 24522 8 24523 11719 24524 8 24525 11720 24526 11721 24527 11722 24528 11723 24529 11724 24530 8 24531 11725 24532 11726 24533 11727 24534 11728 24535 8 24536 8 24537 11729 24538 11730 24539 8 24540 11731 24541 8 24542 11732 24543 11733 24544 11734 24545 11735 24546 11736 24547 11737 24548 8 24549 11738 24550 8 24551 11739 24552 11740 24553 11741 24554 8 24555 11742 24556 11743 24557 11744 24558 11745 24559 8 24560 8 24561 11746 24562 11747 24563 8 24564 11748 24565 11749 24566 11750 24567 11751 24568 8 24569 11752 24570 11753 24571 11754 24572 11755 24573 11756 24574 11757 24575 8 24576 11758 24577 11759 24578 8 24579 11760 24580 11761 24581 11762 24582 11763 24583 11764 24584 11765 24585 8 24586 11766 24587 11767 24588 11768 24589 11769 24590 8 24591 11770 24592 11771 24593 11772 24594 8 24595 11773 24596 8 24597 11774 24598 11775 24599 11776 24600 8 24601 11777 24602 11778 24603 8 24604 8 24605 11779 24606 8 24607 11780 24608 8 24609 11781 24610 8 24611 11782 24612 8 24613 11783 24614 11784 24615 11785 24616 11786 24617 11787 24618 11788 24619 11789 24620 11790 24621 11791 24622 8 24623 8 24624 11792 24625 11793 24626 8 24627 8 24628 11794 24629 11795 24630 11796 24631 11797 24632 11798 24633 11799 24634 11800 24635 11801 24636 8 24637 8 24638 11802 24639 11803 24640 8 24641 11804 24642 8 24643 11805 24644 11806 24645 11807 24646 11808 24647 11809 24648 8 24649 11810 24650 11811 24651 11812 24652 11813 24653 8 24654 8 24655 11814 24656 11815 24657 8 24658 11816 24659 8 24660 11817 24661 8 24662 11818 24663 8 24664 11819 24665 8 24666 11820 24667 11821 24668 8 24669 8 24670 8 24671 11822 24672 8 24673 8 24674 11823 24675 11824 24676 11825 24677 11826 24678 11827 24679 8 24680 11828 24681 8 24682 8 24683 11829 24684 8 24685 11830 24686 11831 24687 8 24688 8 24689 11832 24690 8 24691 11833 24692 8 24693 11834 24694 11835 24695 11836 24696 186 24697 186 24698 11837 24699 11838 24700 11839 24701 11840 24702 11841 24703 11842 24704 11843 24705 11844 24706 11845 24707 11846 24708 8 24709 11847 24710 8 24711 11848 24712 8 24713 8 24714 11849 24715 11850 24716 11851 24717 11852 24718 8 24719 8 24720 11853 24721 11854 24722 11855 24723 11856 24724 11857 24725 8 24726 11858 24727 8 24728 11859 24729 8 24730 8 24731 8 24732 8 24733 11860 24734 8 24735 11861 24736 11862 24737 11863 24738 11864 24739 11865 24740 11866 24741 11867 24742 8 24743 11868 24744 11869 24745 8 24746 11870 24747 8 24748 11871 24749 11872 24750 11873 24751 11874 24752 11875 24753 11876 24754 11877 24755 8 24756 8 24757 11878 24758 8 24759 8 24760 11879 24761 11880 24762 11881 24763 8 24764 8 24765 8 24766 8 24767 11882 24768 8 24769 8 24770 8 24771 8 24772 11883 24773 11884 24774 11885 24775 11886 24776 11887 24777 11888 24778 11889 24779 11890 24780 11891 24781 11892 24782 11893 24783 11894 24784 11895 24785 11896 24786 11897 24787 11898 24788 11899 24789 11900 24790 11901 24791 11902 24792 11903 24793 11904 24794 11905 24795 11906 24796 11907 24797 11908 24798 11909 24799 11910 24800 11911 24801 11912 24802 11913 24803 11914 24804 11915 24805 11916 24806 11886 24807 11886 24808 11886 24809 11886 24810 11886 24811 11886 24812 11886 24813 11886 24814 11886 24815 11886 24816 11886 24817 11886 24818 11886 24819 11886 24820 11886 24821 11917 24822 11918 24823 8 24824 8 24825 8 24826 8 24827 8 24828 8 24829 11919 24830 8 24831 8 24832 11920 24833 8 24834 11921 24835 11922 24836 11923 24837 11924 24838 11925 24839 11926 24840 8 24841 11927 24842 8 24843 8 24844 8 24845 8 24846 8 24847 11928 24848 11929 24849 8 24850 8 24851 11930 24852 8 24853 11931 24854 8 24855 8 24856 11932 24857 11933 24858 8 24859 11886 24860 11886 24861 11886 24862 11886 24863 11886 24864 11934 24865 11935 24866 11936 24867 11886 24868 11886 24869 11886 24870 11886 24871 11886 24872 11886 24873 11886 24874 11886 24875 11886 24876 11886 24877 11937 24878 8 24879 8 24880 8 24881 8 24882 8 24883 8 24884 8 24885 8 24886 8 24887 8 24888 8 24889 8 24890 8 24891 8 24892 8 24893 8 24894 8 24895 8 24896 8 24897 8 24898 8 24899 8 24900 8 24901 8 24902 8 24903 8 24904 8 24905 8 24906 8 24907 8 24908 8 24909 8 24910 8 24911 8 24912 8 24913 8 24914 8 24915 8 24916 8 24917 8 24918 8 24919 8 24920 8 24921 8 24922 8 24923 8 24924 8 24925 8 24926 8 24927 8 24928 8 24929 8 24930 8 24931 8 24932 8 24933 8 24934 8 24935 8 24936 8 24937 8 24938 8 24939 8 24940 8 24941 8 24942 8 24943 8 24944 8 24945 8 24946 8 24947 8 24948 8 24949 8 24950 8 24951 8 24952 8 24953 8 24954 8 24955 8 24956 8 24957 11938 24958 8 24959 8 24960 8 24961 11939 24962 11940 24963 8 24964 11941 24965 8 24966 8 24967 11942 24968 11943 24969 11944 24970 8 24971 8 24972 11945 24973 11946 24974 11947 24975 11948 24976 8 24977 11949 24978 8 24979 11950 24980 11951 24981 11952 24982 11953 24983 11954 24984 11955 24985 11956 24986 11957 24987 11958 24988 11886 24989 11886 24990 11886 24991 11886 24992 11886 24993 11886 24994 11886 24995 11886 24996 11886 24997 11886 24998 11886 24999 11886 25000 11886 25001 11959 25002 11886 25003 11960 25004 11961 25005 8 25006 11962 25007 11963 25008 8 25009 11964 25010 8 25011 11965 25012 8 25013 8 25014 8 25015 11966 25016 11967 25017 11968 25018 8 25019 11969 25020 8 25021 8 25022 11970 25023 11971 25024 11972 25025 8 25026 8 25027 8 25028 11973 25029 11974 25030 8 25031 8 25032 8 25033 11975 25034 11976 25035 11977 25036 11978 25037 11979 25038 8 25039 11980 25040 8 25041 8 25042 11981 25043 8 25044 11982 25045 11983 25046 8 25047 8 25048 11984 25049 8 25050 8 25051 8 25052 11985 25053 11986 25054 8 25055 8 25056 11987 25057 11988 25058 11989 25059 11990 25060 11991 25061 11992 25062 11993 25063 11994 25064 11995 25065 11996 25066 11997 25067 8 25068 11998 25069 11999 25070 12000 25071 12001 25072 12002 25073 12003 25074 12004 25075 12005 25076 12006 25077 12007 25078 8 25079 12008 25080 186 25081 12009 25082 8 25083 12010 25084 8 25085 12011 25086 12012 25087 8 25088 8 25089 8 25090 12013 25091 8 25092 8 25093 12014 25094 12015 25095 12016 25096 12017 25097 12018 25098 8 25099 12019 25100 8 25101 8 25102 12020 25103 8 25104 12021 25105 12022 25106 8 25107 8 25108 12023 25109 8 25110 12024 25111 8 25112 12025 25113 12026 25114 12027 25115 11886 25116 11886 25117 12028 25118 12029 25119 11886 25120 11886 25121 11886 25122 11886 25123 8 25124 12030 25125 8 25126 12031 25127 8 25128 8 25129 11886 25130 11886 25131 8 25132 11886 25133 11886 25134 8 25135 12032 25136 12033 25137 12034 25138 12035 25139 8 25140 8 25141 8 25142 12036 25143 12037 25144 12038 25145 8 25146 8 25147 8 25148 12039 25149 12040 25150 12041 25151 12042 25152 12043 25153 12044 25154 12045 25155 8 25156 12046 25157 12047 25158 12048 25159 12049 25160 12050 25161 8 25162 12051 25163 12052 25164 12053 25165 12054 25166 11886 25167 12055 25168 12056 25169 12057 25170 8 25171 11886 25172 11886 25173 11886 25174 8 25175 12058 25176 8 25177 12059 25178 8 25179 12060 25180 12061 25181 8 25182 12062 25183 12063 25184 8 25185 11886 25186 8 25187 11886 25188 11886 25189 11886 25190 12064 25191 12065 25192 8 25193 11886 25194 11886 25195 11886 25196 12066 25197 8 25198 8 25199 12067 25200 12068 25201 8 25202 12069 25203 8 25204 11886 25205 186 25206 186 25207 186 25208 8 25209 12070 25210 8 25211 12071 25212 8 25213 8 25214 186 25215 186 25216 8 25217 186 25218 186 25219 8 25220 12072 25221 12073 25222 12074 25223 12075 25224 8 25225 8 25226 8 25227 12076 25228 12077 25229 12078 25230 8 25231 8 25232 8 25233 12079 25234 12080 25235 12081 25236 12082 25237 12083 25238 12084 25239 12085 25240 8 25241 12086 25242 12087 25243 12088 25244 12089 25245 12090 25246 8 25247 12091 25248 12092 25249 12093 25250 12094 25251 186 25252 12095 25253 12096 25254 12097 25255 8 25256 186 25257 186 25258 186 25259 8 25260 12098 25261 8 25262 12099 25263 8 25264 12100 25265 12101 25266 8 25267 12102 25268 12103 25269 8 25270 186 25271 8 25272 186 25273 186 25274 186 25275 12104 25276 12105 25277 8 25278 186 25279 186 25280 186 25281 12106 25282 8 25283 8 25284 12107 25285 12108 25286 8 25287 12109 25288 8 25289 186 25290 8 25291 12110 25292 12111 25293 12112 25294 12113 25295 12114 25296 12115 25297 12116 25298 12117 25299 12118 25300 12119 25301 12120 25302 8 25303 8 25304 12121 25305 12122 25306 12123 25307 12124 25308 12125 25309 12126 25310 12127 25311 8 25312 8 25313 12128 25314 12129 25315 8 25316 12130 25317 12131 25318 12132 25319 8 25320 12133 25321 12134 25322 12135 25323 12136 25324 8 25325 8 25326 12137 25327 12138 25328 8 25329 12139 25330 12140 25331 12141 25332 12142 25333 8 25334 12143 25335 12144 25336 12145 25337 12146 25338 12147 25339 12148 25340 8 25341 12149 25342 12150 25343 8 25344 12151 25345 12152 25346 12153 25347 12154 25348 12155 25349 12156 25350 8 25351 12157 25352 12158 25353 12159 25354 12160 25355 8 25356 12161 25357 12162 25358 12163 25359 12164 25360 8 25361 12165 25362 12166 25363 12167 25364 8 25365 12168 25366 8 25367 12169 25368 12170 25369 12171 25370 8 25371 12172 25372 12173 25373 8 25374 8 25375 12174 25376 8 25377 12175 25378 8 25379 12176 25380 12177 25381 12178 25382 12179 25383 12180 25384 8 25385 12181 25386 12182 25387 12183 25388 8 25389 12184 25390 12185 25391 8 25392 12186 25393 8 25394 12187 25395 8 25396 12188 25397 12189 25398 12190 25399 12191 25400 12192 25401 12193 25402 12194 25403 12195 25404 12196 25405 8 25406 8 25407 12197 25408 12198 25409 8 25410 8 25411 12199 25412 12200 25413 12201 25414 12202 25415 12203 25416 12204 25417 12205 25418 12206 25419 8 25420 8 25421 12207 25422 12208 25423 8 25424 12209 25425 12210 25426 12211 25427 12212 25428 12213 25429 12214 25430 8 25431 12215 25432 8 25433 12216 25434 12217 25435 12218 25436 12219 25437 12220 25438 8 25439 12221 25440 12222 25441 12223 25442 12224 25443 8 25444 8 25445 12225 25446 12226 25447 8 25448 12227 25449 8 25450 12228 25451 12229 25452 12230 25453 12231 25454 12232 25455 12233 25456 8 25457 12234 25458 8 25459 12235 25460 8 25461 8 25462 8 25463 8 25464 8 25465 8 25466 8 25467 12236 25468 8 25469 12237 25470 8 25471 8 25472 12238 25473 12239 25474 12240 25475 12241 25476 8 25477 8 25478 8 25479 8 25480 8 25481 8 25482 8 25483 8 25484 8 25485 8 25486 8 25487 12242 25488 8 25489 12243 25490 8 25491 12244 25492 8 25493 8 25494 8 25495 8 25496 8 25497 8 25498 8 25499 8 25500 8 25501 8 25502 12245 25503 8 25504 8 25505 8 25506 8 25507 8 25508 8 25509 8 25510 8 25511 8 25512 8 25513 8 25514 12246 25515 8 25516 8 25517 8 25518 12247 25519 8 25520 12248 25521 12249 25522 12250 25523 8 25524 8 25525 8 25526 12251 25527 8 25528 8 25529 8 25530 8 25531 8 25532 8 25533 12252 25534 8 25535 12253 25536 8 25537 12254 25538 12255 25539 12256 25540 12257 25541 12258 25542 8 25543 8 25544 8 25545 8 25546 8 25547 8 25548 8 25549 8 25550 8 25551 12259 25552 8 25553 12260 25554 8 25555 12261 25556 8 25557 8 25558 8 25559 8 25560 8 25561 8 25562 8 25563 8 25564 8 25565 12262 25566 8 25567 12263 25568 12264 25569 12265 25570 12266 25571 562 25572 12267 25573 8 25574 8 25575 8 25576 8 25577 8 25578 8 25579 8 25580 8 25581 8 25582 12268 25583 8 25584 8 25585 8 25586 8 25587 8 25588 12269 25589 12270 25590 8 25591 12271 25592 8 25593 8 25594 12272 25595 12273 25596 12274 25597 8 25598 8 25599 12275 25600 12276 25601 8 25602 12277 25603 8 25604 12278 25605 8 25606 8 25607 8 25608 8 25609 8 25610 8 25611 8 25612 8 25613 8 25614 8 25615 8 25616 8 25617 8 25618 8 25619 8 25620 8 25621 8 25622 8 25623 8 25624 8 25625 8 25626 8 25627 8 25628 8 25629 8 25630 8 25631 8 25632 8 25633 8 25634 8 25635 8 25636 8 25637 8 25638 8 25639 8 25640 8 25641 8 25642 8 25643 8 25644 8 25645 8 25646 8 25647 8 25648 8 25649 8 25650 8 25651 8 25652 8 25653 8 25654 8 25655 8 25656 8 25657 8 25658 8 25659 8 25660 8 25661 8 25662 8 25663 8 25664 8 25665 8 25666 8 25667 8 25668 8 25669 8 25670 8 25671 8 25672 8 25673 8 25674 8 25675 8 25676 8 25677 8 25678 8 25679 8 25680 8 25681 8 25682 8 25683 8 25684 12279 25685 8 25686 8 25687 8 25688 12280 25689 12281 25690 8 25691 8 25692 12282 25693 12283 25694 12284 25695 12285 25696 8 25697 12286 25698 8 25699 12287 25700 12288 25701 12289 25702 12290 25703 12291 25704 12292 25705 12293 25706 12294 25707 12295 25708 84 25709 84 25710 84 25711 84 25712 84 25713 84 25714 84 25715 84 25716 84 25717 84 25718 84 25719 84 25720 84 25721 12296 25722 84 25723 12297 25724 12298 25725 8 25726 12299 25727 12300 25728 8 25729 12301 25730 8 25731 12302 25732 8 25733 8 25734 8 25735 12303 25736 12304 25737 12305 25738 8 25739 12306 25740 8 25741 8 25742 12307 25743 12308 25744 12309 25745 8 25746 8 25747 8 25748 12310 25749 12311 25750 8 25751 8 25752 8 25753 12312 25754 12313 25755 12314 25756 12315 25757 12316 25758 8 25759 12317 25760 8 25761 8 25762 12318 25763 8 25764 12319 25765 12320 25766 8 25767 8 25768 12321 25769 8 25770 8 25771 8 25772 12322 25773 12323 25774 8 25775 8 25776 12324 25777 12325 25778 12326 25779 12327 25780 12328 25781 8 25782 12329 25783 12330 25784 12331 25785 12332 25786 12333 25787 12334 25788 12335 25789 12336 25790 12337 25791 8 25792 12338 25793 12339 25794 12340 25795 12341 25796 12342 25797 12343 25798 12344 25799 8 25800 12345 25801 12346 25802 8 25803 12347 25804 8 25805 12348 25806 12349 25807 8 25808 12350 25809 8 25810 8 25811 12351 25812 12352 25813 8 25814 12353 25815 12354 25816 12355 25817 8 25818 12356 25819 12357 25820 12358 25821 12359 25822 8 25823 8 25824 12360 25825 12361 25826 8 25827 12362 25828 12363 25829 12364 25830 12365 25831 8 25832 12366 25833 12367 25834 12368 25835 12369 25836 12370 25837 12371 25838 8 25839 12372 25840 12373 25841 8 25842 12374 25843 12375 25844 12376 25845 12377 25846 12378 25847 12379 25848 8 25849 12380 25850 12381 25851 12382 25852 12383 25853 8 25854 12384 25855 12385 25856 12386 25857 8 25858 12387 25859 8 25860 12388 25861 12389 25862 12390 25863 8 25864 12391 25865 12392 25866 8 25867 8 25868 12393 25869 8 25870 12394 25871 8 25872 12395 25873 8 25874 12396 25875 8 25876 12397 25877 12398 25878 12399 25879 12400 25880 12401 25881 12402 25882 12403 25883 12404 25884 12405 25885 8 25886 8 25887 12406 25888 12407 25889 8 25890 8 25891 12408 25892 12409 25893 12410 25894 12411 25895 12412 25896 12413 25897 12414 25898 12415 25899 8 25900 8 25901 12416 25902 12417 25903 8 25904 12418 25905 8 25906 12419 25907 12420 25908 12421 25909 12422 25910 12423 25911 8 25912 12424 25913 12425 25914 12426 25915 12427 25916 8 25917 8 25918 12428 25919 12429 25920 8 25921 12430 25922 8 25923 12431 25924 8 25925 8 25926 12432 25927 12433 25928 12434 25929 12435 25930 12436 25931 12437 25932 12438 25933 12439 25934 12440 25935 12441 25936 12442 25937 8 25938 12443 25939 12444 25940 12445 25941 12446 25942 12447 25943 12448 25944 12449 25945 12450 25946 12451 25947 12452 25948 12453 25949 12454 25950 12455 25951 12456 25952 12457 25953 12458 25954 12459 25955 12460 25956 12461 25957 8 25958 12462 25959 8 25960 12463 25961 8 25962 8 25963 12464 25964 12465 25965 12466 25966 12467 25967 8 25968 8 25969 12468 25970 12469 25971 12470 25972 12471 25973 12472 25974 8 25975 12473 25976 8 25977 12474 25978 8 25979 8 25980 8 25981 8 25982 12475 25983 8 25984 12476 25985 12477 25986 12478 25987 12479 25988 12480 25989 12481 25990 12482 25991 8 25992 12483 25993 12484 25994 8 25995 12485 25996 8 25997 12486 25998 12487 25999 12488 26000 12489 26001 12490 26002 12491 26003 12492 26004 8 26005 8 26006 12493 26007 8 26008 8 26009 12494 26010 12495 26011 12496 26012 8 26013 8 26014 8 26015 8 26016 12497 26017 8 26018 8 26019 8 26020 8 26021 12498 26022 12499 26023 12500 26024 12501 26025 12502 26026 12503 26027 12504 26028 12505 26029 12506 26030 12507 26031 12508 26032 12509 26033 12510 26034 12511 26035 12512 26036 12513 26037 12514 26038 12515 26039 12516 26040 12517 26041 12518 26042 12519 26043 12520 26044 12521 26045 12522 26046 12523 26047 12524 26048 12525 26049 12526 26050 12527 26051 12528 26052 12529 26053 12530 26054 12531 26055 12501 26056 12501 26057 12501 26058 12501 26059 12501 26060 12501 26061 12501 26062 12501 26063 12501 26064 12501 26065 12501 26066 12501 26067 12501 26068 12501 26069 12501 26070 12532 26071 12533 26072 8 26073 8 26074 8 26075 8 26076 8 26077 8 26078 12534 26079 8 26080 8 26081 12535 26082 8 26083 12536 26084 12537 26085 12538 26086 12539 26087 12540 26088 12541 26089 8 26090 12542 26091 8 26092 8 26093 8 26094 8 26095 8 26096 12543 26097 12544 26098 8 26099 8 26100 12545 26101 8 26102 12546 26103 8 26104 8 26105 12547 26106 12548 26107 8 26108 12501 26109 12501 26110 12501 26111 12501 26112 12501 26113 12549 26114 12550 26115 12551 26116 12501 26117 12501 26118 12501 26119 12501 26120 12501 26121 12501 26122 12501 26123 12501 26124 12501 26125 12501 26126 12552 26127 8 26128 8 26129 8 26130 8 26131 8 26132 8 26133 8 26134 8 26135 8 26136 8 26137 8 26138 8 26139 8 26140 8 26141 8 26142 8 26143 8 26144 8 26145 8 26146 8 26147 8 26148 8 26149 8 26150 8 26151 8 26152 8 26153 8 26154 8 26155 8 26156 8 26157 8 26158 8 26159 8 26160 8 26161 8 26162 8 26163 8 26164 8 26165 8 26166 8 26167 8 26168 8 26169 8 26170 8 26171 8 26172 8 26173 8 26174 8 26175 8 26176 8 26177 8 26178 8 26179 8 26180 8 26181 8 26182 8 26183 8 26184 8 26185 8 26186 8 26187 8 26188 8 26189 8 26190 8 26191 8 26192 8 26193 8 26194 8 26195 8 26196 8 26197 8 26198 8 26199 8 26200 8 26201 8 26202 8 26203 8 26204 8 26205 8 26206 12553 26207 8 26208 8 26209 8 26210 12554 26211 12555 26212 8 26213 12556 26214 8 26215 8 26216 12557 26217 12558 26218 12559 26219 8 26220 8 26221 12560 26222 12561 26223 12562 26224 12563 26225 8 26226 12564 26227 8 26228 12565 26229 12566 26230 12567 26231 12568 26232 12569 26233 12570 26234 12571 26235 12572 26236 12573 26237 12501 26238 12501 26239 12501 26240 12501 26241 12501 26242 12501 26243 12501 26244 12501 26245 12501 26246 12501 26247 12501 26248 12501 26249 12501 26250 12574 26251 12501 26252 12575 26253 12576 26254 8 26255 12577 26256 12578 26257 8 26258 12579 26259 8 26260 12580 26261 8 26262 8 26263 8 26264 12581 26265 12582 26266 12583 26267 8 26268 12584 26269 8 26270 8 26271 12585 26272 12586 26273 12587 26274 8 26275 8 26276 8 26277 12588 26278 12589 26279 8 26280 8 26281 8 26282 12590 26283 12591 26284 12592 26285 12593 26286 12594 26287 8 26288 12595 26289 8 26290 8 26291 12596 26292 8 26293 12597 26294 12598 26295 8 26296 8 26297 12599 26298 8 26299 8 26300 8 26301 12600 26302 12601 26303 8 26304 8 26305 12602 26306 12603 26307 12604 26308 12605 26309 12606 26310 12607 26311 12608 26312 12609 26313 12610 26314 12611 26315 12612 26316 8 26317 12613 26318 12614 26319 12615 26320 12616 26321 12617 26322 12618 26323 12619 26324 12620 26325 12621 26326 12622 26327 8 26328 8 26329 12623 26330 8 26331 12624 26332 8 26333 12625 26334 12626 26335 8 26336 8 26337 8 26338 12627 26339 8 26340 8 26341 12628 26342 12629 26343 12630 26344 12631 26345 12632 26346 8 26347 12633 26348 8 26349 8 26350 12634 26351 8 26352 12635 26353 12636 26354 8 26355 8 26356 12637 26357 8 26358 12638 26359 8 26360 12639 26361 12640 26362 12641 26363 12501 26364 12501 26365 12642 26366 12643 26367 12644 26368 12645 26369 12646 26370 12647 26371 12648 26372 12649 26373 12650 26374 12651 26375 8 26376 12652 26377 8 26378 12653 26379 8 26380 8 26381 12654 26382 12655 26383 12656 26384 12657 26385 8 26386 8 26387 12658 26388 12659 26389 12660 26390 12661 26391 12662 26392 8 26393 12663 26394 8 26395 12664 26396 8 26397 8 26398 8 26399 8 26400 12665 26401 8 26402 12666 26403 12667 26404 12668 26405 12669 26406 12670 26407 12671 26408 12672 26409 8 26410 12673 26411 12674 26412 8 26413 12675 26414 8 26415 12676 26416 12677 26417 12678 26418 12679 26419 12680 26420 12681 26421 12682 26422 8 26423 8 26424 12683 26425 8 26426 8 26427 12684 26428 12685 26429 12686 26430 8 26431 8 26432 8 26433 8 26434 12687 26435 8 26436 8 26437 8 26438 8 26439 12688 26440 12689 26441 12690 26442 12691 26443 12692 26444 12693 26445 12694 26446 12695 26447 12696 26448 12697 26449 12698 26450 12699 26451 12700 26452 12701 26453 12702 26454 12703 26455 12704 26456 12705 26457 12706 26458 12707 26459 12708 26460 12709 26461 12710 26462 12711 26463 12712 26464 12713 26465 12714 26466 12715 26467 12716 26468 12717 26469 12718 26470 12719 26471 12720 26472 12721 26473 12691 26474 12691 26475 12691 26476 12691 26477 12691 26478 12691 26479 12691 26480 12691 26481 12691 26482 12691 26483 12691 26484 12691 26485 12691 26486 12691 26487 12691 26488 12722 26489 12723 26490 8 26491 8 26492 8 26493 8 26494 8 26495 8 26496 12724 26497 8 26498 8 26499 12725 26500 8 26501 12726 26502 12727 26503 12728 26504 12729 26505 12730 26506 12731 26507 8 26508 12732 26509 8 26510 8 26511 8 26512 8 26513 8 26514 12733 26515 12734 26516 8 26517 8 26518 12735 26519 8 26520 12736 26521 8 26522 8 26523 12737 26524 12738 26525 8 26526 12691 26527 12691 26528 12691 26529 12691 26530 12691 26531 12739 26532 12740 26533 12741 26534 12691 26535 12691 26536 12691 26537 12691 26538 12691 26539 12691 26540 12691 26541 12691 26542 12691 26543 12691 26544 12742 26545 8 26546 8 26547 8 26548 8 26549 8 26550 8 26551 8 26552 8 26553 8 26554 8 26555 8 26556 8 26557 8 26558 8 26559 8 26560 8 26561 8 26562 8 26563 8 26564 8 26565 8 26566 8 26567 8 26568 8 26569 8 26570 8 26571 8 26572 8 26573 8 26574 8 26575 8 26576 8 26577 8 26578 8 26579 8 26580 8 26581 8 26582 8 26583 8 26584 8 26585 8 26586 8 26587 8 26588 8 26589 8 26590 8 26591 8 26592 8 26593 8 26594 8 26595 8 26596 8 26597 8 26598 8 26599 8 26600 8 26601 8 26602 8 26603 8 26604 8 26605 8 26606 8 26607 8 26608 8 26609 8 26610 8 26611 8 26612 8 26613 8 26614 8 26615 8 26616 8 26617 8 26618 8 26619 8 26620 8 26621 8 26622 8 26623 8 26624 12743 26625 8 26626 8 26627 8 26628 12744 26629 12745 26630 8 26631 12746 26632 8 26633 8 26634 12747 26635 12748 26636 12749 26637 8 26638 8 26639 12750 26640 12751 26641 12752 26642 12753 26643 8 26644 12754 26645 8 26646 12755 26647 12756 26648 12757 26649 12758 26650 12759 26651 12760 26652 12761 26653 12762 26654 12763 26655 12691 26656 12691 26657 12691 26658 12691 26659 12691 26660 12691 26661 12691 26662 12691 26663 12691 26664 12691 26665 12691 26666 12691 26667 12691 26668 12764 26669 12691 26670 12765 26671 12766 26672 8 26673 12767 26674 12768 26675 8 26676 12769 26677 8 26678 12770 26679 8 26680 8 26681 8 26682 12771 26683 12772 26684 12773 26685 8 26686 12774 26687 8 26688 8 26689 12775 26690 12776 26691 12777 26692 8 26693 8 26694 8 26695 12778 26696 12779 26697 8 26698 8 26699 8 26700 12780 26701 12781 26702 12782 26703 12783 26704 12784 26705 8 26706 12785 26707 8 26708 8 26709 12786 26710 8 26711 12787 26712 12788 26713 8 26714 8 26715 12789 26716 8 26717 8 26718 8 26719 12790 26720 12791 26721 8 26722 8 26723 12792 26724 12793 26725 12794 26726 12795 26727 12796 26728 12797 26729 12798 26730 12799 26731 12800 26732 12801 26733 12802 26734 8 26735 12803 26736 12804 26737 12805 26738 12806 26739 12807 26740 12808 26741 12809 26742 12810 26743 12811 26744 12812 26745 8 26746 12813 26747 12501 26748 12814 26749 8 26750 12815 26751 8 26752 12816 26753 12817 26754 8 26755 8 26756 8 26757 12818 26758 8 26759 8 26760 12819 26761 12820 26762 12821 26763 12822 26764 12823 26765 8 26766 12824 26767 8 26768 8 26769 12825 26770 8 26771 12826 26772 12827 26773 8 26774 8 26775 12828 26776 8 26777 12829 26778 8 26779 12830 26780 12831 26781 12832 26782 12691 26783 12691 26784 12833 26785 12834 26786 12691 26787 12691 26788 12691 26789 12691 26790 8 26791 12835 26792 8 26793 12836 26794 8 26795 8 26796 12691 26797 12691 26798 8 26799 12691 26800 12691 26801 12837 26802 8 26803 8 26804 8 26805 8 26806 8 26807 8 26808 12838 26809 12839 26810 12840 26811 12841 26812 8 26813 12842 26814 8 26815 12843 26816 12844 26817 12845 26818 12846 26819 12847 26820 12848 26821 8 26822 12849 26823 8 26824 8 26825 8 26826 8 26827 12850 26828 8 26829 8 26830 8 26831 12851 26832 12852 26833 12853 26834 8 26835 8 26836 12854 26837 8 26838 8 26839 12855 26840 12856 26841 12857 26842 12858 26843 12859 26844 12860 26845 12861 26846 8 26847 12862 26848 8 26849 12863 26850 12864 26851 12865 26852 12866 26853 12867 26854 8 26855 12868 26856 12869 26857 12870 26858 12871 26859 12691 26860 12872 26861 12873 26862 12874 26863 8 26864 12691 26865 12691 26866 12691 26867 8 26868 12875 26869 8 26870 12876 26871 8 26872 12877 26873 12878 26874 8 26875 12879 26876 12880 26877 8 26878 12691 26879 8 26880 12691 26881 12691 26882 12691 26883 12881 26884 12882 26885 8 26886 12691 26887 12691 26888 12691 26889 12883 26890 8 26891 8 26892 12884 26893 12885 26894 8 26895 12886 26896 8 26897 12691 26898 12501 26899 12501 26900 12501 26901 8 26902 12887 26903 8 26904 12888 26905 8 26906 8 26907 12501 26908 12501 26909 8 26910 12501 26911 12501 26912 12889 26913 8 26914 8 26915 8 26916 8 26917 8 26918 8 26919 12890 26920 12891 26921 12892 26922 12893 26923 8 26924 12894 26925 8 26926 12895 26927 12896 26928 12897 26929 12898 26930 12899 26931 12900 26932 8 26933 12901 26934 8 26935 8 26936 8 26937 8 26938 12902 26939 8 26940 8 26941 8 26942 12903 26943 12904 26944 12905 26945 8 26946 8 26947 12906 26948 8 26949 8 26950 12907 26951 12908 26952 12909 26953 12910 26954 12911 26955 12912 26956 12913 26957 8 26958 12914 26959 8 26960 12915 26961 12916 26962 12917 26963 12918 26964 12919 26965 8 26966 12920 26967 12921 26968 12922 26969 12923 26970 12501 26971 12924 26972 12925 26973 12926 26974 8 26975 12501 26976 12501 26977 12501 26978 8 26979 12927 26980 8 26981 12928 26982 8 26983 12929 26984 12930 26985 8 26986 12931 26987 12932 26988 8 26989 12501 26990 8 26991 12501 26992 12501 26993 12501 26994 12933 26995 12934 26996 8 26997 12501 26998 12501 26999 12501 27000 12935 27001 8 27002 8 27003 12936 27004 12937 27005 8 27006 12938 27007 8 27008 12501 27009 8 27010 12939 27011 8 27012 12940 27013 8 27014 12941 27015 12942 27016 8 27017 8 27018 12943 27019 12944 27020 12945 27021 12946 27022 12947 27023 12948 27024 12949 27025 8 27026 8 27027 12950 27028 12951 27029 12952 27030 12953 27031 8 27032 8 27033 12954 27034 8 27035 12955 27036 8 27037 8 27038 8 27039 12956 27040 12957 27041 12958 27042 12959 27043 12960 27044 12961 27045 12962 27046 12963 27047 12964 27048 12965 27049 12966 27050 8 27051 12967 27052 12968 27053 12969 27054 12970 27055 12971 27056 12972 27057 12973 27058 8 27059 12974 27060 12975 27061 12976 27062 12977 27063 8 27064 12978 27065 12979 27066 12980 27067 12981 27068 12982 27069 8 27070 12983 27071 12984 27072 12985 27073 12986 27074 12987 27075 12988 27076 8 27077 12989 27078 12990 27079 12991 27080 12992 27081 12993 27082 12994 27083 8 27084 12995 27085 12996 27086 12997 27087 12998 27088 12999 27089 8 27090 13000 27091 8 27092 8 27093 13001 27094 8 27095 13002 27096 13003 27097 8 27098 8 27099 13004 27100 8 27101 13005 27102 13006 27103 8 27104 13007 27105 13008 27106 13009 27107 8 27108 13010 27109 8 27110 13011 27111 13012 27112 13013 27113 84 27114 84 27115 13014 27116 13015 27117 13016 27118 13017 27119 13018 27120 13019 27121 13020 27122 13021 27123 13022 27124 13023 27125 8 27126 13024 27127 8 27128 13025 27129 8 27130 8 27131 13026 27132 13027 27133 13028 27134 13029 27135 8 27136 8 27137 13030 27138 13031 27139 13032 27140 13033 27141 13034 27142 8 27143 13035 27144 8 27145 13036 27146 8 27147 8 27148 8 27149 8 27150 13037 27151 8 27152 13038 27153 13039 27154 13040 27155 13041 27156 13042 27157 13043 27158 13044 27159 8 27160 13045 27161 13046 27162 8 27163 13047 27164 8 27165 13048 27166 13049 27167 13050 27168 13051 27169 13052 27170 13053 27171 13054 27172 8 27173 8 27174 13055 27175 8 27176 8 27177 13056 27178 13057 27179 13058 27180 8 27181 8 27182 8 27183 8 27184 13059 27185 8 27186 8 27187 8 27188 8 27189 13060 27190 13061 27191 13062 27192 13063 27193 13064 27194 13065 27195 13066 27196 13067 27197 13068 27198 13069 27199 13070 27200 13071 27201 13072 27202 13073 27203 13074 27204 13075 27205 13076 27206 13077 27207 13078 27208 13079 27209 13080 27210 13081 27211 13082 27212 13083 27213 13084 27214 13085 27215 13086 27216 13087 27217 13088 27218 13089 27219 13090 27220 13091 27221 13092 27222 13093 27223 13063 27224 13063 27225 13063 27226 13063 27227 13063 27228 13063 27229 13063 27230 13063 27231 13063 27232 13063 27233 13063 27234 13063 27235 13063 27236 13063 27237 13063 27238 13094 27239 13095 27240 8 27241 8 27242 8 27243 8 27244 8 27245 8 27246 13096 27247 8 27248 8 27249 13097 27250 8 27251 13098 27252 13099 27253 13100 27254 13101 27255 13102 27256 13103 27257 8 27258 13104 27259 8 27260 8 27261 8 27262 8 27263 8 27264 13105 27265 13106 27266 8 27267 8 27268 13107 27269 8 27270 13108 27271 8 27272 8 27273 13109 27274 13110 27275 8 27276 13063 27277 13063 27278 13063 27279 13063 27280 13063 27281 13111 27282 13112 27283 13113 27284 13063 27285 13063 27286 13063 27287 13063 27288 13063 27289 13063 27290 13063 27291 13063 27292 13063 27293 13063 27294 13114 27295 8 27296 8 27297 8 27298 8 27299 8 27300 8 27301 8 27302 8 27303 8 27304 8 27305 8 27306 8 27307 8 27308 8 27309 8 27310 8 27311 8 27312 8 27313 8 27314 8 27315 8 27316 8 27317 8 27318 8 27319 8 27320 8 27321 8 27322 8 27323 8 27324 8 27325 8 27326 8 27327 8 27328 8 27329 8 27330 8 27331 8 27332 8 27333 8 27334 8 27335 8 27336 8 27337 8 27338 8 27339 8 27340 8 27341 8 27342 8 27343 8 27344 8 27345 8 27346 8 27347 8 27348 8 27349 8 27350 8 27351 8 27352 8 27353 8 27354 8 27355 8 27356 8 27357 8 27358 8 27359 8 27360 8 27361 8 27362 8 27363 8 27364 8 27365 8 27366 8 27367 8 27368 8 27369 8 27370 8 27371 8 27372 8 27373 8 27374 13115 27375 8 27376 8 27377 8 27378 13116 27379 13117 27380 8 27381 13118 27382 8 27383 8 27384 13119 27385 13120 27386 13121 27387 8 27388 8 27389 13122 27390 13123 27391 13124 27392 13125 27393 8 27394 13126 27395 8 27396 13127 27397 13128 27398 13129 27399 13130 27400 13131 27401 13132 27402 13133 27403 13134 27404 13135 27405 13063 27406 13063 27407 13063 27408 13063 27409 13063 27410 13063 27411 13063 27412 13063 27413 13063 27414 13063 27415 13063 27416 13063 27417 13063 27418 13136 27419 13063 27420 13137 27421 13138 27422 8 27423 13139 27424 13140 27425 8 27426 13141 27427 8 27428 13142 27429 8 27430 8 27431 8 27432 13143 27433 13144 27434 13145 27435 8 27436 13146 27437 8 27438 8 27439 13147 27440 13148 27441 13149 27442 8 27443 8 27444 8 27445 13150 27446 13151 27447 8 27448 8 27449 8 27450 13152 27451 13153 27452 13154 27453 13155 27454 13156 27455 8 27456 13157 27457 8 27458 8 27459 13158 27460 8 27461 13159 27462 13160 27463 8 27464 8 27465 13161 27466 8 27467 8 27468 8 27469 13162 27470 13163 27471 8 27472 8 27473 13164 27474 13165 27475 13166 27476 13167 27477 13168 27478 13169 27479 13170 27480 13171 27481 13172 27482 13173 27483 13174 27484 8 27485 13175 27486 13176 27487 13177 27488 13178 27489 13179 27490 13180 27491 13181 27492 13182 27493 13183 27494 13184 27495 8 27496 13185 27497 84 27498 13186 27499 8 27500 13187 27501 8 27502 13188 27503 13189 27504 8 27505 8 27506 8 27507 13190 27508 8 27509 8 27510 13191 27511 13192 27512 13193 27513 13194 27514 13195 27515 8 27516 13196 27517 8 27518 8 27519 13197 27520 8 27521 13198 27522 13199 27523 8 27524 8 27525 13200 27526 8 27527 13201 27528 8 27529 13202 27530 13203 27531 13204 27532 13063 27533 13063 27534 13205 27535 13206 27536 13063 27537 13063 27538 13063 27539 13063 27540 8 27541 13207 27542 8 27543 13208 27544 8 27545 8 27546 13063 27547 13063 27548 8 27549 13063 27550 13063 27551 8 27552 13209 27553 13210 27554 13211 27555 13212 27556 8 27557 8 27558 8 27559 13213 27560 13214 27561 13215 27562 8 27563 8 27564 8 27565 13216 27566 13217 27567 13218 27568 13219 27569 13220 27570 13221 27571 13222 27572 8 27573 13223 27574 13224 27575 13225 27576 13226 27577 13227 27578 8 27579 13228 27580 13229 27581 13230 27582 13231 27583 13063 27584 13232 27585 13233 27586 13234 27587 8 27588 13063 27589 13063 27590 13063 27591 8 27592 13235 27593 8 27594 13236 27595 8 27596 13237 27597 13238 27598 8 27599 13239 27600 13240 27601 8 27602 13063 27603 8 27604 13063 27605 13063 27606 13063 27607 13241 27608 13242 27609 8 27610 13063 27611 13063 27612 13063 27613 13243 27614 8 27615 8 27616 13244 27617 13245 27618 8 27619 13246 27620 8 27621 13063 27622 13247 27623 13248 27624 13249 27625 13250 27626 8 27627 8 27628 13251 27629 13252 27630 8 27631 8 27632 8 27633 8 27634 8 27635 8 27636 13253 27637 13254 27638 8 27639 8 27640 13255 27641 13256 27642 13257 27643 13258 27644 13259 27645 13260 27646 8 27647 8 27648 8 27649 8 27650 13261 27651 8 27652 8 27653 13262 27654 8 27655 13263 27656 13264 27657 8 27658 8 27659 13265 27660 8 27661 13266 27662 13267 27663 13268 27664 8 27665 8 27666 13269 27667 8 27668 8 27669 8 27670 8 27671 13270 27672 13271 27673 8 27674 8 27675 8 27676 13272 27677 8 27678 13273 27679 8 27680 13274 27681 13275 27682 8 27683 8 27684 84 27685 13276 27686 13277 27687 13278 27688 13279 27689 8 27690 13280 27691 13281 27692 13282 27693 13283 27694 13284 27695 13285 27696 8 27697 13286 27698 13287 27699 8 27700 13288 27701 13289 27702 13290 27703 13291 27704 13292 27705 13293 27706 8 27707 13294 27708 13295 27709 13296 27710 13297 27711 8 27712 84 27713 13298 27714 13299 27715 13300 27716 13301 27717 8 27718 13302 27719 13303 27720 13304 27721 8 27722 13305 27723 8 27724 13306 27725 13307 27726 13308 27727 8 27728 13309 27729 13310 27730 8 27731 84 27732 8 27733 13311 27734 8 27735 13312 27736 8 27737 13313 27738 8 27739 8 27740 13314 27741 8 27742 84 27743 84 27744 84 27745 84 27746 8 27747 13315 27748 13316 27749 13317 27750 13318 27751 8 27752 8 27753 8 27754 13319 27755 13320 27756 13321 27757 8 27758 8 27759 8 27760 13322 27761 13323 27762 13324 27763 13325 27764 13326 27765 13327 27766 13328 27767 8 27768 8 27769 8 27770 8 27771 8 27772 8 27773 8 27774 8 27775 8 27776 8 27777 8 27778 8 27779 8 27780 8 27781 8 27782 8 27783 8 27784 8 27785 8 27786 8 27787 8 27788 8 27789 8 27790 8 27791 8 27792 8 27793 8 27794 8 27795 8 27796 8 27797 8 27798 8 27799 8 27800 8 27801 8 27802 8 27803 8 27804 8 27805 8 27806 8 27807 8 27808 8 27809 8 27810 8 27811 8 27812 8 27813 8 27814 8 27815 8 27816 8 27817 8 27818 8 27819 8 27820 8 27821 8 27822 8 27823 8 27824 8 27825 8 27826 8 27827 8 27828 8 27829 8 27830 8 27831 8 27832 8 27833 8 27834 8 27835 8 27836 8 27837 8 27838 8 27839 8 27840 8 27841 8 27842 8 27843 8 27844 8 27845 8 27846 8 27847 8 27848 13329 27849 8 27850 8 27851 13330 27852 13331 27853 8 27854 13332 27855 13333 27856 13334 27857 13335 27858 13336 27859 13337 27860 13338 27861 13339 27862 13340 27863 13341 27864 13342 27865 13343 27866 13344 27867 13345 27868 8 27869 13346 27870 13347 27871 13348 27872 13349 27873 13350 27874 13351 27875 13352 27876 13353 27877 13354 27878 13355 27879 13356 27880 8 27881 13357 27882 8 27883 13358 27884 8 27885 13359 27886 8 27887 13360 27888 13361 27889 8 27890 8 27891 13362 27892 8 27893 8 27894 8 27895 8 27896 13363 27897 8 27898 13364 27899 8 27900 13365 27901 13366 27902 13367 27903 13368 27904 13369 27905 8 27906 13370 27907 13371 27908 13372 27909 13373 27910 13374 27911 13375 27912 13376 27913 13377 27914 13378 27915 8 27916 13379 27917 13380 27918 13381 27919 13382 27920 13383 27921 13384 27922 13385 27923 8 27924 13386 27925 13387 27926 8 27927 13388 27928 8 27929 13389 27930 13390 27931 8 27932 13391 27933 8 27934 8 27935 13392 27936 13393 27937 8 27938 13394 27939 13395 27940 13396 27941 8 27942 13397 27943 13398 27944 13399 27945 13400 27946 8 27947 8 27948 13401 27949 13402 27950 8 27951 13403 27952 13404 27953 13405 27954 13406 27955 8 27956 13407 27957 13408 27958 13409 27959 13410 27960 13411 27961 13412 27962 8 27963 13413 27964 13414 27965 8 27966 13415 27967 13416 27968 13417 27969 13418 27970 13419 27971 13420 27972 8 27973 13421 27974 13422 27975 13423 27976 13424 27977 8 27978 13425 27979 13426 27980 13427 27981 8 27982 13428 27983 8 27984 13429 27985 13430 27986 13431 27987 8 27988 13432 27989 13433 27990 8 27991 8 27992 13434 27993 8 27994 13435 27995 8 27996 13436 27997 8 27998 13437 27999 8 28000 13438 28001 13439 28002 13440 28003 13441 28004 13442 28005 13443 28006 13444 28007 13445 28008 13446 28009 8 28010 8 28011 13447 28012 13448 28013 8 28014 8 28015 13449 28016 13450 28017 13451 28018 13452 28019 13453 28020 13454 28021 13455 28022 13456 28023 8 28024 8 28025 13457 28026 13458 28027 8 28028 13459 28029 8 28030 13460 28031 13461 28032 13462 28033 13463 28034 13464 28035 8 28036 13465 28037 13466 28038 13467 28039 13468 28040 8 28041 8 28042 13469 28043 13470 28044 8 28045 13471 28046 8 28047 13472 28048 8 28049 8 28050 13473 28051 13474 28052 13475 28053 13476 28054 13477 28055 13478 28056 13479 28057 13480 28058 13481 28059 13482 28060 13483 28061 8 28062 8 28063 13484 28064 13485 28065 13486 28066 13487 28067 13488 28068 13489 28069 13490 28070 8 28071 8 28072 13491 28073 13492 28074 8 28075 13493 28076 13494 28077 13495 28078 8 28079 13496 28080 13497 28081 13498 28082 13499 28083 8 28084 8 28085 13500 28086 13501 28087 8 28088 13502 28089 13503 28090 13504 28091 13505 28092 13506 28093 8 28094 8 28095 8 28096 8 28097 13507 28098 13508 28099 13509 28100 13510 28101 8 28102 13511 28103 13512 28104 13513 28105 13514 28106 13515 28107 13516 28108 8 28109 13517 28110 13518 28111 8 28112 13519 28113 13520 28114 13521 28115 13522 28116 13523 28117 13524 28118 8 28119 13525 28120 13526 28121 13527 28122 13528 28123 8 28124 13529 28125 13530 28126 13531 28127 13532 28128 8 28129 13533 28130 13534 28131 13535 28132 8 28133 13536 28134 8 28135 13537 28136 13538 28137 13539 28138 8 28139 13540 28140 13541 28141 8 28142 8 28143 13542 28144 8 28145 13543 28146 8 28147 13544 28148 13545 28149 13546 28150 8 28151 8 28152 13547 28153 13548 28154 8 28155 13549 28156 13550 28157 13551 28158 13552 28159 13553 28160 8 28161 13554 28162 13555 28163 13556 28164 8 28165 13557 28166 13558 28167 8 28168 13559 28169 8 28170 13560 28171 8 28172 13561 28173 13562 28174 13563 28175 13564 28176 13565 28177 13566 28178 13567 28179 13568 28180 13569 28181 8 28182 8 28183 13570 28184 13571 28185 8 28186 8 28187 13572 28188 13573 28189 13574 28190 13575 28191 13576 28192 13577 28193 13578 28194 13579 28195 8 28196 8 28197 13580 28198 13581 28199 8 28200 13582 28201 13583 28202 13584 28203 13585 28204 13586 28205 13587 28206 8 28207 13588 28208 8 28209 13589 28210 13590 28211 13591 28212 13592 28213 13593 28214 8 28215 13594 28216 13595 28217 13596 28218 13597 28219 8 28220 8 28221 13598 28222 13599 28223 8 28224 13600 28225 8 28226 13601 28227 8 28228 13602 28229 13603 28230 8 28231 8 28232 13604 28233 13605 28234 8 28235 13606 28236 13607 28237 13608 28238 13609 28239 13610 28240 13611 28241 8 28242 13612 28243 8 28244 8 28245 13613 28246 13614 28247 8 28248 13615 28249 13616 28250 13617 28251 13618 28252 13619 28253 8 28254 13620 28255 13621 28256 13622 28257 13623 28258 84 28259 13624 28260 13625 28261 13626 28262 8 28263 84 28264 13627 28265 13628 28266 13629 28267 13630 28268 13631 28269 8 28270 84 28271 84 28272 8 28273 13632 28274 13633 28275 13634 28276 8 28277 13635 28278 13636 28279 13637 28280 13638 28281 13639 28282 13640 28283 13641 28284 13642 28285 13643 28286 13644 28287 8 28288 13645 28289 13646 28290 13647 28291 13648 28292 13649 28293 13650 28294 13651 28295 8 28296 13652 28297 13653 28298 8 28299 13654 28300 8 28301 13655 28302 13656 28303 8 28304 13657 28305 13658 28306 13659 28307 13660 28308 13661 28309 8 28310 8 28311 8 28312 13662 28313 13663 28314 8 28315 13664 28316 13665 28317 13666 28318 8 28319 13667 28320 13668 28321 13669 28322 13670 28323 8 28324 8 28325 13671 28326 13672 28327 8 28328 13673 28329 13674 28330 13675 28331 13676 28332 8 28333 13677 28334 13678 28335 13679 28336 13680 28337 13681 28338 13682 28339 8 28340 13683 28341 13684 28342 8 28343 13685 28344 13686 28345 13687 28346 13688 28347 13689 28348 13690 28349 8 28350 13691 28351 13692 28352 13693 28353 13694 28354 8 28355 13695 28356 13696 28357 13697 28358 8 28359 13698 28360 8 28361 13699 28362 13700 28363 13701 28364 8 28365 13702 28366 13703 28367 8 28368 8 28369 13704 28370 8 28371 13705 28372 8 28373 13706 28374 13707 28375 13708 28376 8 28377 13709 28378 8 28379 13710 28380 8 28381 13711 28382 13712 28383 13713 28384 13714 28385 13715 28386 13716 28387 13717 28388 13718 28389 13719 28390 8 28391 8 28392 13720 28393 13721 28394 8 28395 8 28396 13722 28397 13723 28398 13724 28399 13725 28400 13726 28401 13727 28402 13728 28403 13729 28404 8 28405 8 28406 13730 28407 13731 28408 8 28409 13732 28410 8 28411 13733 28412 13734 28413 13735 28414 13736 28415 13737 28416 8 28417 13738 28418 13739 28419 13740 28420 13741 28421 8 28422 8 28423 13742 28424 13743 28425 8 28426 13744 28427 8 28428 13745 28429 8 28430 13746 28431 13747 28432 8 28433 13748 28434 8 28435 13749 28436 8 28437 13750 28438 13751 28439 13752 28440 13753 28441 13754 28442 13755 28443 13756 28444 13757 28445 13758 28446 8 28447 8 28448 13759 28449 13760 28450 8 28451 8 28452 13761 28453 13762 28454 13763 28455 13764 28456 13765 28457 13766 28458 13767 28459 13768 28460 8 28461 8 28462 13769 28463 13770 28464 8 28465 13771 28466 8 28467 13772 28468 8 28469 13773 28470 13774 28471 8 28472 13775 28473 13776 28474 13777 28475 13778 28476 13779 28477 13780 28478 8 28479 13781 28480 13782 28481 8 28482 13783 28483 8 28484 84 28485 13784 28486 13785 28487 13786 28488 13787 28489 13788 28490 8 28491 13789 28492 13790 28493 13791 28494 13792 28495 8 28496 8 28497 13793 28498 13794 28499 8 28500 8 28501 13795 28502 8 28503 13796 28504 8 28505 84 28506 13797 28507 13798 28508 13799 28509 13800 28510 13801 28511 13802 28512 8 28513 13803 28514 8 28515 84 28516 13804 28517 13805 28518 8 28519 84 28520 13806 28521 13807 28522 8 28523 84 28524 84 28525 84 28526 13808 28527 8 28528 8 28529 13809 28530 13810 28531 8 28532 13811 28533 8 28534 84))
  "The generated goto-tables.")

(defvar
  phps-mode-parser--distinct-goto-tables
  #s(hash-table size 18699 test equal rehash-size 1.5 rehash-threshold 0.8125 data (0 ((top_statement_list 1)) 1 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 8) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 15) (T_CLASS 16) (T_CLASS_C 17) (T_CLONE 18) (T_CONST 19) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 21) (T_DEC 22) (T_DECLARE 23) (T_DIR 24) (T_DNUMBER 25) (T_DO 26) (T_DOUBLE_CAST 27) (T_ECHO 28) (T_EMPTY 29) (T_ENUM 30) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 36) (T_FOREACH 37) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 40) (T_GOTO 41) (T_HALT_COMPILER 42) (T_IF 43) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 47) (T_INTERFACE 48) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAMESPACE 56) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 67) (T_START_HEREDOC 68) (T_STATIC 69) (T_STRING 70) (T_STRING_CAST 71) (T_SWITCH 72) (T_THROW 73) (T_TRAIT 74) (T_TRAIT_C 75) (T_TRY 76) (T_UNSET 77) (T_UNSET_CAST 78) (T_USE 79) (T_VARIABLE 80) (T_WHILE 81) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 86) (alt_if_stmt_without_else 87) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 90) (attributes 91) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 95) (class_modifier 96) (class_modifiers 97) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 101) (expr 102) (fn 103) (fully_dereferenceable 104) #'105 (function_call 106) (function_declaration_statement 107) (if_stmt 108) (if_stmt_without_else 109) (inline_function 110) (interface_declaration_statement 111) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 118) (static_member 119) (top_statement 120) (trait_declaration_statement 121) (variable 122) (variable_class_name 123) ("{" 124) ("~" 125)) 2 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 28534) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 3 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 28532) (encaps_var 5299)) 4 (("$" 4) (T_VARIABLE 80) (simple_variable 28528) ("{" 28529)) 5 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 28526) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 28525) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 7 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 28524) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 8 nil 9 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 28523) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 10 (("(" 28520)) 11 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 28519) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 12 ((T_NAME_FULLY_QUALIFIED 6566) (T_NAME_QUALIFIED 6567) (T_NAME_RELATIVE 6568) (T_STATIC 6569) (T_STRING 6570) (attribute_decl 6571) (attribute_group 28516) (class_name 6573) (name 6574)) 13 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 28515) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 14 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 28513) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 15 ((T_STRING 28506)) 16 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 28505) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 17 ((T_STRING 28226) (const_decl 28227) (const_list 28503)) 18 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 28501) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 19 (("\"" 1509) ("$" 25723) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 25724) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 25725) ("[" 1529) (array_object_dereferenceable 25726) (callable_expr 25727) (callable_variable 25728) (class_constant 1533) (class_name 25729) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 25730) (name 25731) (simple_variable 25732) (static_member 25733) (variable 28500) (variable_class_name 25735)) 20 (("(" 28491)) 21 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19746) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19747) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19748) (T_DEC 22) (T_DECLARE 19749) (T_DIR 24) (T_DNUMBER 25) (T_DO 19750) (T_DOUBLE_CAST 27) (T_ECHO 19751) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19752) (T_FOREACH 19753) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19754) (T_GOTO 19755) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19757) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19758) (T_START_HEREDOC 68) (T_STATIC 19759) (T_STRING 19760) (T_STRING_CAST 71) (T_SWITCH 19761) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19762) (T_UNSET 19763) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19764) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19765) (alt_if_stmt_without_else 19766) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19767) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19768) (if_stmt_without_else 19769) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 28485) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19771) ("~" 125)) 22 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 28484) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 23 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (echo_expr 19740) (echo_expr_list 28482) (expr 19742) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 24 (("(" 28479)) 25 ((T_STRING 28472)) 26 (("(" 28469)) 27 (("(" 28465) (exit_expr 28466)) 28 (("(" 28452)) 29 (("(" 28437)) 30 (("$" 17870) (T_VARIABLE 17871) (global_var 17872) (global_var_list 28435) (simple_variable 17874)) 31 ((T_STRING 28433)) 32 (("(" 28430)) 33 (("(" 28273)) 34 (("\"" 1509) ("$" 25723) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 25724) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 25725) ("[" 1529) (array_object_dereferenceable 25726) (callable_expr 25727) (callable_variable 25728) (class_constant 1533) (class_name 25729) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 25730) (name 25731) (simple_variable 25732) (static_member 25733) (variable 28272) (variable_class_name 25735)) 35 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 28271) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 36 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 28270) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 37 ((T_STRING 28264)) 38 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 28263) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 39 (("(" 28259)) 40 (("(" 28254)) 41 (("(" 28248)) 42 ((T_ABSTRACT 27768) (T_ARRAY 27769) (T_AS 27770) (T_BREAK 27771) (T_CALLABLE 27772) (T_CASE 27773) (T_CATCH 27774) (T_CLASS 27775) (T_CLASS_C 27776) (T_CLONE 27777) (T_CONST 27778) (T_CONTINUE 27779) (T_DECLARE 27780) (T_DEFAULT 27781) (T_DIR 27782) (T_DO 27783) (T_ECHO 27784) (T_ELSE 27785) (T_ELSEIF 27786) (T_EMPTY 27787) (T_ENDDECLARE 27788) (T_ENDFOR 27789) (T_ENDFOREACH 27790) (T_ENDIF 27791) (T_ENDSWITCH 27792) (T_ENDWHILE 27793) (T_ENUM 27794) (T_EVAL 27795) (T_EXIT 27796) (T_EXTENDS 27797) (T_FILE 27798) (T_FINAL 27799) (T_FINALLY 27800) (T_FN 27801) (T_FOR 27802) (T_FOREACH 27803) (T_FUNCTION 27804) (T_FUNC_C 27805) (T_GLOBAL 27806) (T_GOTO 27807) (T_IF 27808) (T_IMPLEMENTS 27809) (T_INCLUDE 27810) (T_INCLUDE_ONCE 27811) (T_INSTANCEOF 27812) (T_INSTEADOF 27813) (T_INTERFACE 27814) (T_ISSET 27815) (T_LINE 27816) (T_LIST 27817) (T_LOGICAL_AND 27818) (T_LOGICAL_OR 27819) (T_LOGICAL_XOR 27820) (T_MATCH 27821) (T_METHOD_C 27822) (T_NAMESPACE 27823) (T_NAME_QUALIFIED 27824) (T_NEW 27825) (T_NS_C 27826) (T_PRINT 27827) (T_PRIVATE 27828) (T_PROTECTED 27829) (T_PUBLIC 27830) (T_READONLY 27831) (T_REQUIRE 27832) (T_REQUIRE_ONCE 27833) (T_RETURN 27834) (T_STATIC 27835) (T_STRING 27836) (T_SWITCH 27837) (T_THROW 27838) (T_TRAIT 27839) (T_TRAIT_C 27840) (T_TRY 27841) (T_UNSET 27842) (T_USE 27843) (T_VAR 27844) (T_WHILE 27845) (T_YIELD 27846) (identifier 27847) (namespace_declaration_name 27848) (reserved_non_modifiers 27849) (semi_reserved 27850) ("{" 27851)) 43 (("$" 26252) ("(" 26912) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 26913) (T_NAME_QUALIFIED 26914) (T_NAME_RELATIVE 26915) (T_READONLY 2936) (T_STATIC 26916) (T_STRING 26917) (T_VARIABLE 26254) (anonymous_class 27746) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 27747) (attribute 2943) (attributes 27748) (class_modifier 2945) (class_name 26921) (class_name_reference 27749) (name 26923) (new_variable 26924) (simple_variable 26925)) 44 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 27745) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 45 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 27744) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 46 (("(" 25591) (argument_list 25592)) 47 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 27743) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 48 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 27742) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 49 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 27740) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 50 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 27735) (T_END_HEREDOC 27736) (T_VARIABLE 2900) (encaps_list 27737) (encaps_var 2902)) 51 ((T_FN 35) (T_FUNCTION 127) (T_VARIABLE 16848) (fn 103) #'134 (inline_function 16849) (static_var 16850) (static_var_list 27733)) 52 ((":" 27732)) 53 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 27731) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 54 (("(" 27713)) 55 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 27712) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 56 ((T_STRING 27707)) 57 (("{" 27690)) 58 (("(" 27685)) 59 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 27684) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 60 ((T_CONST 27631) (T_FUNCTION 27632) (T_NAME_FULLY_QUALIFIED 27633) (T_NAME_QUALIFIED 27634) (T_STRING 27635) (legacy_namespace_name 27636) (mixed_group_use_declaration 27637) (namespace_name 27638) (use_declaration 27639) (use_declarations 27640) (use_type 27641)) 61 (("(" 27622)) 62 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27177) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 63 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 27114) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 64 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 27110) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 65 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 27108) (encaps_list 2805) (encaps_var 2806)) 66 ((T_ELSE 27101) (T_ELSEIF 16203) (T_ENDIF 27102)) 67 ((T_NULLSAFE_OBJECT_OPERATOR 27084) (T_OBJECT_OPERATOR 27085) ("[" 27086) ("{" 27087)) 68 ((T_ABSTRACT 10) (T_ATTRIBUTE 13) (T_CLASS 27027) (T_ENUM 27028) (T_FINAL 34) (T_FN 35) (T_FUNCTION 38) (T_INTERFACE 27029) (T_READONLY 2936) (T_STATIC 16288) (T_TRAIT 27030) (attribute 16289) (attributed_statement 27031) (class_declaration_statement 27032) (class_modifier 96) (class_modifiers 27033) (enum_declaration_statement 27034) (fn 103) #'27035 (function_declaration_statement 27036) (inline_function 16291) (interface_declaration_statement 27037) (trait_declaration_statement 27038)) 69 (("(" 25591) (argument_list 27026)) 70 ((T_ABSTRACT 10) (T_CLASS 27018) (T_FINAL 34) (T_READONLY 2936) (class_modifier 16280)) 71 ((T_PAAMAYIM_NEKUDOTAYIM 27010)) 72 (("%" 6465) ("*" 6466) ("+" 6467) ("-" 6468) ("." 6469) ("/" 6470) (";" 27009) ("<" 6471) (">" 6472) ("?" 6473) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 6474) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 6475) (T_BOOLEAN_AND 6476) (T_BOOLEAN_OR 6477) (T_COALESCE 6478) (T_INSTANCEOF 6479) (T_IS_EQUAL 6480) (T_IS_GREATER_OR_EQUAL 6481) (T_IS_IDENTICAL 6482) (T_IS_NOT_EQUAL 6483) (T_IS_NOT_IDENTICAL 6484) (T_IS_SMALLER_OR_EQUAL 6485) (T_LOGICAL_AND 6486) (T_LOGICAL_OR 6487) (T_LOGICAL_XOR 6488) (T_POW 6489) (T_SL 6490) (T_SPACESHIP 6491) (T_SR 6492) ("^" 6493) ("|" 6494)) 73 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 25938)) 74 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 16261) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 16262) (ampersand 16263) (returns_ref 25926)) 75 ((T_ELSE 25776) (T_ELSEIF 25777)) 76 (("(" 25591) (argument_list 25775)) 77 (("=" 25692) (T_AND_EQUAL 25693) (T_COALESCE_EQUAL 25694) (T_CONCAT_EQUAL 25695) (T_DEC 25696) (T_DIV_EQUAL 25697) (T_INC 25698) (T_MINUS_EQUAL 25699) (T_MOD_EQUAL 25700) (T_MUL_EQUAL 25701) (T_OR_EQUAL 25702) (T_PLUS_EQUAL 25703) (T_POW_EQUAL 25704) (T_SL_EQUAL 25705) (T_SR_EQUAL 25706) (T_XOR_EQUAL 25707)) 78 ((T_PAAMAYIM_NEKUDOTAYIM 25604)) 79 ((inner_statement_list 25602)) 80 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 133) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 81 ((T_NAME_FULLY_QUALIFIED 6566) (T_NAME_QUALIFIED 6567) (T_NAME_RELATIVE 6568) (T_STATIC 6569) (T_STRING 6570) (attribute_decl 6571) (attribute_group 25599) (class_name 6573) (name 6574)) 82 ((T_FN 35) (T_FUNCTION 127) (fn 103) #'134 (inline_function 16849)) 83 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 16288) (attribute 2728) (fn 103) #'134 (inline_function 16291)) 84 (("%" 6465) ("*" 6466) ("+" 6467) ("-" 6468) ("." 6469) ("/" 6470) ("<" 6471) (">" 6472) ("?" 6473) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 6474) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 6475) (T_BOOLEAN_AND 6476) (T_BOOLEAN_OR 6477) (T_COALESCE 6478) (T_INSTANCEOF 6479) (T_IS_EQUAL 6480) (T_IS_GREATER_OR_EQUAL 6481) (T_IS_IDENTICAL 6482) (T_IS_NOT_EQUAL 6483) (T_IS_NOT_IDENTICAL 6484) (T_IS_SMALLER_OR_EQUAL 6485) (T_LOGICAL_AND 6486) (T_LOGICAL_OR 6487) (T_LOGICAL_XOR 6488) (T_POW 6489) (T_SL 6490) (T_SPACESHIP 6491) (T_SR 6492) ("^" 6493) ("|" 6494)) 85 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 138)) 86 ((backup_doc_comment 139)) 87 (("(" 140)) 88 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 157)) 89 ((T_NAME_FULLY_QUALIFIED 6566) (T_NAME_QUALIFIED 6567) (T_NAME_RELATIVE 6568) (T_STATIC 6569) (T_STRING 6570) (attribute_decl 6571) (attribute_group 25588) (class_name 6573) (name 6574)) 90 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 25586) (member_modifier 152) (non_empty_member_modifiers 153) (optional_cpp_modifiers 155) (parameter 25587)) 91 ((T_ABSTRACT 141) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (member_modifier 25585)) 92 (("," 25582) (possible_comma 25583)) 93 (("(" 3014) ("?" 25526) (T_ARRAY 25527) (T_CALLABLE 25528) (T_NAME_FULLY_QUALIFIED 25529) (T_NAME_QUALIFIED 25530) (T_NAME_RELATIVE 25531) (T_STRING 25532) (intersection_type_without_static 25533) (name 25534) (optional_type_without_static 25535) (type_expr_without_static 25536) (type_without_static 25537) (union_type_without_static 25538) (union_type_without_static_element 25539)) 94 ((")" 158)) 95 ((T_USE 159) (lexical_vars 160)) 96 (("(" 25514)) 97 ((":" 161) (return_type 162)) 98 (("(" 2248) ("?" 25459) (T_ARRAY 25460) (T_CALLABLE 25461) (T_NAME_FULLY_QUALIFIED 25462) (T_NAME_QUALIFIED 25463) (T_NAME_RELATIVE 25464) (T_STATIC 25465) (T_STRING 25466) (intersection_type 25467) (name 25468) (type 25469) (type_expr 25470) (type_without_static 25471) (union_type 25472) (union_type_element 25473)) 99 ((backup_fn_flags 163)) 100 (("{" 164)) 101 ((inner_statement_list 165)) 102 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 207) ("~" 125)) 103 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 25457) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 104 ((T_STRING 25450)) 105 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 25448) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 106 (("(" 25439)) 107 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19746) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19747) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19748) (T_DEC 22) (T_DECLARE 19749) (T_DIR 24) (T_DNUMBER 25) (T_DO 19750) (T_DOUBLE_CAST 27) (T_ECHO 19751) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19752) (T_FOREACH 19753) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19754) (T_GOTO 19755) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19757) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19758) (T_START_HEREDOC 68) (T_STATIC 19759) (T_STRING 19760) (T_STRING_CAST 71) (T_SWITCH 19761) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19762) (T_UNSET 19763) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19764) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19765) (alt_if_stmt_without_else 19766) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19767) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19768) (if_stmt_without_else 19769) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 25433) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19771) ("~" 125)) 108 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (echo_expr 19740) (echo_expr_list 25431) (expr 19742) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 109 ((T_STRING 25424)) 110 (("(" 25411)) 111 (("(" 25396)) 112 (("$" 17870) (T_VARIABLE 17871) (global_var 17872) (global_var_list 25394) (simple_variable 17874)) 113 ((T_STRING 25392)) 114 (("(" 25389)) 115 (("(" 25385)) 116 ((T_STRING 25379)) 117 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 25377) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 118 ((T_FN 35) (T_FUNCTION 127) (T_VARIABLE 16848) (fn 103) #'134 (inline_function 16849) (static_var 16850) (static_var_list 25375)) 119 ((":" 25374)) 120 (("(" 25356)) 121 ((T_STRING 25351)) 122 (("{" 25334)) 123 (("(" 25329)) 124 (("(" 25320)) 125 ((T_ELSE 25313) (T_ELSEIF 16203) (T_ENDIF 25314)) 126 ((T_ABSTRACT 10) (T_ATTRIBUTE 13) (T_CLASS 168) (T_ENUM 173) (T_FINAL 34) (T_FN 35) (T_FUNCTION 38) (T_INTERFACE 181) (T_READONLY 2936) (T_STATIC 16288) (T_TRAIT 186) (attribute 16289) (attributed_statement 25312) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (enum_declaration_statement 196) (fn 103) #'198 (function_declaration_statement 199) (inline_function 16291) (interface_declaration_statement 203) (trait_declaration_statement 205)) 127 ((T_ABSTRACT 10) (T_CLASS 25304) (T_FINAL 34) (T_READONLY 2936) (class_modifier 16280)) 128 (("%" 6465) ("*" 6466) ("+" 6467) ("-" 6468) ("." 6469) ("/" 6470) (";" 25303) ("<" 6471) (">" 6472) ("?" 6473) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 6474) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 6475) (T_BOOLEAN_AND 6476) (T_BOOLEAN_OR 6477) (T_COALESCE 6478) (T_INSTANCEOF 6479) (T_IS_EQUAL 6480) (T_IS_GREATER_OR_EQUAL 6481) (T_IS_IDENTICAL 6482) (T_IS_NOT_EQUAL 6483) (T_IS_NOT_IDENTICAL 6484) (T_IS_SMALLER_OR_EQUAL 6485) (T_LOGICAL_AND 6486) (T_LOGICAL_OR 6487) (T_LOGICAL_XOR 6488) (T_POW 6489) (T_SL 6490) (T_SPACESHIP 6491) (T_SR 6492) ("^" 6493) ("|" 6494)) 129 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 16261) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 16262) (ampersand 16263) (returns_ref 25291)) 130 ((T_ELSE 211) (T_ELSEIF 212)) 131 ((inner_statement_list 209)) 132 ((backup_fn_flags 208)) 133 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 210) ("~" 125)) 134 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 197) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 25290) (static_member 119) (variable 122) (variable_class_name 123) ("{" 206) ("~" 125)) 135 (("(" 213)) 136 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 276) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 137 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25289) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 138 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 25287) (encaps_var 5299)) 139 (("$" 216) (T_VARIABLE 263) (simple_variable 25283) ("{" 25284)) 140 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25281) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 141 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25280) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 142 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25279) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 143 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25278) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 144 (("(" 25275)) 145 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25274) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 146 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25273) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 147 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25272) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 148 (("\"" 1509) ("$" 15035) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 15036) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 15037) ("[" 1529) (array_object_dereferenceable 15038) (callable_expr 15039) (callable_variable 15040) (class_constant 1533) (class_name 15041) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 15042) (name 15043) (simple_variable 15044) (static_member 15045) (variable 25271) (variable_class_name 15047)) 149 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25270) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 150 (("(" 25267)) 151 (("(" 25264)) 152 (("(" 25260) (exit_expr 25261)) 153 (("\"" 1509) ("$" 15035) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 15036) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 15037) ("[" 1529) (array_object_dereferenceable 15038) (callable_expr 15039) (callable_variable 15040) (class_constant 1533) (class_name 15041) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 15042) (name 15043) (simple_variable 15044) (static_member 15045) (variable 25259) (variable_class_name 15047)) 154 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25258) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 155 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25257) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 156 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25256) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 157 (("(" 25252)) 158 (("(" 25247)) 159 (("(" 25241)) 160 (("$" 15414) ("(" 16074) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 16075) (T_NAME_QUALIFIED 16076) (T_NAME_RELATIVE 16077) (T_READONLY 2936) (T_STATIC 16078) (T_STRING 16079) (T_VARIABLE 15416) (anonymous_class 25219) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 25220) (attribute 2943) (attributes 25221) (class_modifier 2945) (class_name 16083) (class_name_reference 25222) (name 16085) (new_variable 16086) (simple_variable 16087)) 161 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25218) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 162 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25217) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 163 (("(" 14996) (argument_list 25216)) 164 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25215) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 165 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25214) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 166 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 25209) (T_END_HEREDOC 25210) (T_VARIABLE 2900) (encaps_list 25211) (encaps_var 2902)) 167 ((T_FN 35) (T_FUNCTION 127) (fn 277) #'278 (inline_function 25208)) 168 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25207) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 169 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25206) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 170 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25205) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 171 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24760) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 172 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 24697) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 173 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 24693) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 174 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 24691) (encaps_list 2805) (encaps_var 2806)) 175 ((T_NULLSAFE_OBJECT_OPERATOR 24674) (T_OBJECT_OPERATOR 24675) ("[" 24676) ("{" 24677)) 176 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 24671) (attribute 2728) (fn 277) #'278 (inline_function 24672)) 177 (("(" 14996) (argument_list 24670)) 178 ((T_PAAMAYIM_NEKUDOTAYIM 24662)) 179 (("%" 292) (")" 16171) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 180 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 15100)) 181 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 15088)) 182 (("(" 14996) (argument_list 15087)) 183 (("=" 15004) (T_AND_EQUAL 15005) (T_COALESCE_EQUAL 15006) (T_CONCAT_EQUAL 15007) (T_DEC 15008) (T_DIV_EQUAL 15009) (T_INC 15010) (T_MINUS_EQUAL 15011) (T_MOD_EQUAL 15012) (T_MUL_EQUAL 15013) (T_OR_EQUAL 15014) (T_PLUS_EQUAL 15015) (T_POW_EQUAL 15016) (T_SL_EQUAL 15017) (T_SR_EQUAL 15018) (T_XOR_EQUAL 15019)) 184 ((T_PAAMAYIM_NEKUDOTAYIM 14909)) 185 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 291) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 186 (("%" 292) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 187 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14908) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 188 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14907) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 189 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14906) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 190 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14905) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 191 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14904) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 192 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14903) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 193 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14902) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 194 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14901) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 195 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 14896) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 14897) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 196 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14895) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 197 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14894) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 198 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14893) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 199 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14892) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 200 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14891) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 201 (("$" 337) ("(" 338) (T_NAME_FULLY_QUALIFIED 339) (T_NAME_QUALIFIED 340) (T_NAME_RELATIVE 341) (T_STATIC 342) (T_STRING 343) (T_VARIABLE 344) (class_name 345) (class_name_reference 346) (name 347) (new_variable 348) (simple_variable 349)) 202 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 336) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 203 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 335) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 204 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 334) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 205 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 333) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 206 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 332) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 207 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 331) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 208 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 330) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 209 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 329) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 210 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 328) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 211 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 327) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 212 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 326) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 213 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 325) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 214 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 324) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 215 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 323) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 216 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 322) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 217 (("$" 337) (T_VARIABLE 344) (simple_variable 14887) ("{" 14888)) 218 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14885) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 219 ((T_PAAMAYIM_NEKUDOTAYIM 14883)) 220 ((T_NULLSAFE_OBJECT_OPERATOR 350) (T_OBJECT_OPERATOR 351) (T_PAAMAYIM_NEKUDOTAYIM 352) ("[" 353) ("{" 354)) 221 (("$" 337) (T_STRING 14876) (T_VARIABLE 344) (property_name 14882) (simple_variable 14878) ("{" 14879)) 222 (("$" 337) (T_STRING 14876) (T_VARIABLE 344) (property_name 14877) (simple_variable 14878) ("{" 14879)) 223 (("$" 337) (T_VARIABLE 344) (simple_variable 14875)) 224 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 14873) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 225 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 417) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 226 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14872) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 227 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 14870) (encaps_var 5299)) 228 (("$" 357) (T_VARIABLE 404) (simple_variable 14866) ("{" 14867)) 229 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14864) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 230 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14863) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 231 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14862) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 232 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14861) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 233 (("(" 14858)) 234 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14857) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 235 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14856) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 236 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14855) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 237 (("\"" 1509) ("$" 13108) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 13109) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 13110) ("[" 1529) (array_object_dereferenceable 13111) (callable_expr 13112) (callable_variable 13113) (class_constant 1533) (class_name 13114) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 13115) (name 13116) (simple_variable 13117) (static_member 13118) (variable 14854) (variable_class_name 13120)) 238 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14853) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 239 (("(" 14850)) 240 (("(" 14847)) 241 (("(" 14843) (exit_expr 14844)) 242 (("\"" 1509) ("$" 13108) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 13109) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 13110) ("[" 1529) (array_object_dereferenceable 13111) (callable_expr 13112) (callable_variable 13113) (class_constant 1533) (class_name 13114) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 13115) (name 13116) (simple_variable 13117) (static_member 13118) (variable 14842) (variable_class_name 13120)) 243 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14841) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 244 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14840) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 245 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14839) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 246 (("(" 14835)) 247 (("(" 14830)) 248 (("(" 14824)) 249 (("$" 13487) ("(" 14147) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 14148) (T_NAME_QUALIFIED 14149) (T_NAME_RELATIVE 14150) (T_READONLY 2936) (T_STATIC 14151) (T_STRING 14152) (T_VARIABLE 13489) (anonymous_class 14802) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 14803) (attribute 2943) (attributes 14804) (class_modifier 2945) (class_name 14156) (class_name_reference 14805) (name 14158) (new_variable 14159) (simple_variable 14160)) 250 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14801) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 251 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14800) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 252 (("(" 13069) (argument_list 14799)) 253 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14798) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 254 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14797) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 255 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 14792) (T_END_HEREDOC 14793) (T_VARIABLE 2900) (encaps_list 14794) (encaps_var 2902)) 256 ((T_FN 35) (T_FUNCTION 127) (fn 418) #'419 (inline_function 14791)) 257 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14790) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 258 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14789) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 259 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14788) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 260 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14343) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 261 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14280) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 262 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 14276) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 263 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 14274) (encaps_list 2805) (encaps_var 2806)) 264 ((T_NULLSAFE_OBJECT_OPERATOR 14257) (T_OBJECT_OPERATOR 14258) ("[" 14259) ("{" 14260)) 265 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 14254) (attribute 2728) (fn 418) #'419 (inline_function 14255)) 266 (("(" 13069) (argument_list 14253)) 267 ((T_PAAMAYIM_NEKUDOTAYIM 14245)) 268 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 14244)) 269 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 13173)) 270 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 13161)) 271 (("(" 13069) (argument_list 13160)) 272 (("=" 13077) (T_AND_EQUAL 13078) (T_COALESCE_EQUAL 13079) (T_CONCAT_EQUAL 13080) (T_DEC 13081) (T_DIV_EQUAL 13082) (T_INC 13083) (T_MINUS_EQUAL 13084) (T_MOD_EQUAL 13085) (T_MUL_EQUAL 13086) (T_OR_EQUAL 13087) (T_PLUS_EQUAL 13088) (T_POW_EQUAL 13089) (T_SL_EQUAL 13090) (T_SR_EQUAL 13091) (T_XOR_EQUAL 13092)) 273 ((T_PAAMAYIM_NEKUDOTAYIM 12982)) 274 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 432) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 275 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462)) 276 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12981) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 277 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12980) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 278 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12979) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 279 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12978) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 280 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12977) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 281 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12976) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 282 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12975) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 283 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12974) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 284 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 12969) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 12970) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 285 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12968) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 286 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12967) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 287 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12966) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 288 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12965) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 289 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12964) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 290 (("$" 478) ("(" 479) (T_NAME_FULLY_QUALIFIED 480) (T_NAME_QUALIFIED 481) (T_NAME_RELATIVE 482) (T_STATIC 483) (T_STRING 484) (T_VARIABLE 485) (class_name 486) (class_name_reference 487) (name 488) (new_variable 489) (simple_variable 490)) 291 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 477) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 292 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 476) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 293 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 475) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 294 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 474) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 295 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 473) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 296 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 472) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 297 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 471) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 298 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 470) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 299 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 469) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 300 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 468) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 301 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 467) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 302 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 466) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 303 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 465) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 304 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 464) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 305 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 463) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 306 (("$" 478) (T_VARIABLE 485) (simple_variable 12960) ("{" 12961)) 307 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 12958) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 308 ((T_PAAMAYIM_NEKUDOTAYIM 12956)) 309 ((T_NULLSAFE_OBJECT_OPERATOR 491) (T_OBJECT_OPERATOR 492) (T_PAAMAYIM_NEKUDOTAYIM 493) ("[" 494) ("{" 495)) 310 (("$" 478) (T_STRING 12949) (T_VARIABLE 485) (property_name 12955) (simple_variable 12951) ("{" 12952)) 311 (("$" 478) (T_STRING 12949) (T_VARIABLE 485) (property_name 12950) (simple_variable 12951) ("{" 12952)) 312 (("$" 478) (T_VARIABLE 485) (simple_variable 12948)) 313 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 569) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 314 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 496) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 315 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 497)) 316 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 12947) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 317 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 12945) (encaps_var 5299)) 318 (("$" 500) (T_VARIABLE 547) (simple_variable 12941) ("{" 12942)) 319 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 12939) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 320 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 12938) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 321 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 12937) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 322 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 12936) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 323 (("(" 12933)) 324 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 12932) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 325 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 12931) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 326 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 12930) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 327 (("\"" 1509) ("$" 11183) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 11184) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 11185) ("[" 1529) (array_object_dereferenceable 11186) (callable_expr 11187) (callable_variable 11188) (class_constant 1533) (class_name 11189) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 11190) (name 11191) (simple_variable 11192) (static_member 11193) (variable 12929) (variable_class_name 11195)) 328 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 12928) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 329 (("(" 12925)) 330 (("(" 12922)) 331 (("(" 12918) (exit_expr 12919)) 332 (("\"" 1509) ("$" 11183) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 11184) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 11185) ("[" 1529) (array_object_dereferenceable 11186) (callable_expr 11187) (callable_variable 11188) (class_constant 1533) (class_name 11189) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 11190) (name 11191) (simple_variable 11192) (static_member 11193) (variable 12917) (variable_class_name 11195)) 333 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 12916) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 334 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 12915) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 335 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 12914) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 336 (("(" 12910)) 337 (("(" 12905)) 338 (("(" 12899)) 339 (("$" 11563) ("(" 12223) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 12224) (T_NAME_QUALIFIED 12225) (T_NAME_RELATIVE 12226) (T_READONLY 2936) (T_STATIC 12227) (T_STRING 12228) (T_VARIABLE 11565) (anonymous_class 12877) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 12878) (attribute 2943) (attributes 12879) (class_modifier 2945) (class_name 12232) (class_name_reference 12880) (name 12234) (new_variable 12235) (simple_variable 12236)) 340 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 12876) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 341 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 12875) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 342 (("(" 11144) (argument_list 12874)) 343 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 12873) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 344 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 12872) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 345 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 12867) (T_END_HEREDOC 12868) (T_VARIABLE 2900) (encaps_list 12869) (encaps_var 2902)) 346 ((T_FN 35) (T_FUNCTION 127) (fn 561) #'562 (inline_function 12866)) 347 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 12865) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 348 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 12864) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 349 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 12863) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 350 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12418) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 351 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 12355) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 352 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 12351) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 353 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 12349) (encaps_list 2805) (encaps_var 2806)) 354 ((T_NULLSAFE_OBJECT_OPERATOR 12332) (T_OBJECT_OPERATOR 12333) ("[" 12334) ("{" 12335)) 355 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 12329) (attribute 2728) (fn 561) #'562 (inline_function 12330)) 356 (("(" 11144) (argument_list 12328)) 357 ((T_PAAMAYIM_NEKUDOTAYIM 12320)) 358 (("%" 577) ("*" 578) ("+" 579) ("-" 580) ("." 581) ("/" 582) ("<" 583) (">" 584) ("?" 585) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 586) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 587) (T_BOOLEAN_AND 588) (T_BOOLEAN_OR 589) (T_COALESCE 590) (T_INSTANCEOF 591) (T_IS_EQUAL 592) (T_IS_GREATER_OR_EQUAL 593) (T_IS_IDENTICAL 594) (T_IS_NOT_EQUAL 595) (T_IS_NOT_IDENTICAL 596) (T_IS_SMALLER_OR_EQUAL 597) (T_LOGICAL_AND 598) (T_LOGICAL_OR 599) (T_LOGICAL_XOR 600) (T_POW 601) (T_SL 602) (T_SPACESHIP 603) (T_SR 604) ("^" 605) ("|" 606)) 359 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 11249)) 360 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 11237)) 361 (("(" 11144) (argument_list 11236)) 362 (("]" 11235)) 363 (("=" 11152) (T_AND_EQUAL 11153) (T_COALESCE_EQUAL 11154) (T_CONCAT_EQUAL 11155) (T_DEC 11156) (T_DIV_EQUAL 11157) (T_INC 11158) (T_MINUS_EQUAL 11159) (T_MOD_EQUAL 11160) (T_MUL_EQUAL 11161) (T_OR_EQUAL 11162) (T_PLUS_EQUAL 11163) (T_POW_EQUAL 11164) (T_SL_EQUAL 11165) (T_SR_EQUAL 11166) (T_XOR_EQUAL 11167)) 364 ((T_PAAMAYIM_NEKUDOTAYIM 11057)) 365 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 576) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 366 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 11056) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 367 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 11055) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 368 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 11054) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 369 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 11053) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 370 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 11052) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 371 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 11051) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 372 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 11050) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 373 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 11049) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 374 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 671) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 728) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 375 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 664) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 376 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 663) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 377 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 662) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 378 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 661) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 379 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 660) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 380 (("$" 622) ("(" 623) (T_NAME_FULLY_QUALIFIED 624) (T_NAME_QUALIFIED 625) (T_NAME_RELATIVE 626) (T_STATIC 627) (T_STRING 628) (T_VARIABLE 629) (class_name 630) (class_name_reference 631) (name 632) (new_variable 633) (simple_variable 634)) 381 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 621) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 382 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 620) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 383 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 619) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 384 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 618) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 385 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 617) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 386 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 616) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 387 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 615) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 388 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 614) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 389 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 613) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 390 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 612) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 391 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 611) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 392 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 610) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 393 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 609) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 394 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 608) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 395 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 607) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 396 (("$" 622) (T_VARIABLE 629) (simple_variable 656) ("{" 657)) 397 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 654) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 398 ((T_PAAMAYIM_NEKUDOTAYIM 652)) 399 ((T_NULLSAFE_OBJECT_OPERATOR 635) (T_OBJECT_OPERATOR 636) (T_PAAMAYIM_NEKUDOTAYIM 637) ("[" 638) ("{" 639)) 400 (("$" 622) (T_STRING 645) (T_VARIABLE 629) (property_name 651) (simple_variable 647) ("{" 648)) 401 (("$" 622) (T_STRING 645) (T_VARIABLE 629) (property_name 646) (simple_variable 647) ("{" 648)) 402 (("$" 622) (T_VARIABLE 629) (simple_variable 644)) 403 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 642) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 404 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 640) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 405 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 641)) 406 (("]" 643)) 407 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 649) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 408 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 650)) 409 (("$" 622) (T_VARIABLE 629) (simple_variable 653)) 410 (("%" 292) (")" 655) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 411 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 658) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 412 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 659)) 413 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 11048) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 414 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 11046) (encaps_var 5299)) 415 (("$" 667) (T_VARIABLE 715) (simple_variable 11042) ("{" 11043)) 416 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 11040) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 417 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 11039) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 418 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 11038) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 419 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 11037) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 420 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 11036) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 421 (("(" 11033)) 422 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 11032) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 423 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 11031) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 424 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 11030) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 425 (("\"" 1509) ("$" 9282) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 9283) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 9284) ("[" 1529) (array_object_dereferenceable 9285) (callable_expr 9286) (callable_variable 9287) (class_constant 1533) (class_name 9288) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 9289) (name 9290) (simple_variable 9291) (static_member 9292) (variable 11029) (variable_class_name 9294)) 426 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 11028) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 427 (("(" 11025)) 428 (("(" 11022)) 429 (("(" 11018) (exit_expr 11019)) 430 (("\"" 1509) ("$" 9282) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 9283) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 9284) ("[" 1529) (array_object_dereferenceable 9285) (callable_expr 9286) (callable_variable 9287) (class_constant 1533) (class_name 9288) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 9289) (name 9290) (simple_variable 9291) (static_member 9292) (variable 11017) (variable_class_name 9294)) 431 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 11016) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 432 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 11015) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 433 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 11014) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 434 (("(" 11010)) 435 (("(" 11005)) 436 (("(" 10999)) 437 (("$" 9661) ("(" 10321) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 10322) (T_NAME_QUALIFIED 10323) (T_NAME_RELATIVE 10324) (T_READONLY 2936) (T_STATIC 10325) (T_STRING 10326) (T_VARIABLE 9663) (anonymous_class 10977) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 10978) (attribute 2943) (attributes 10979) (class_modifier 2945) (class_name 10330) (class_name_reference 10980) (name 10332) (new_variable 10333) (simple_variable 10334)) 438 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 10976) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 439 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 10975) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 440 (("(" 932) (argument_list 10974)) 441 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 10973) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 442 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 10972) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 443 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 10967) (T_END_HEREDOC 10968) (T_VARIABLE 2900) (encaps_list 10969) (encaps_var 2902)) 444 ((T_FN 35) (T_FUNCTION 127) (fn 729) #'730 (inline_function 10966)) 445 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 10965) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 446 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 10964) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 447 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 10963) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 448 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10518) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 449 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 10455) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 450 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 10451) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 451 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 10449) (encaps_list 2805) (encaps_var 2806)) 452 ((T_NULLSAFE_OBJECT_OPERATOR 10432) (T_OBJECT_OPERATOR 10433) ("[" 10434) ("{" 10435)) 453 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 10429) (attribute 2728) (fn 729) #'730 (inline_function 10430)) 454 (("(" 932) (argument_list 10428)) 455 ((T_PAAMAYIM_NEKUDOTAYIM 10420)) 456 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 10418) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 457 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 9347)) 458 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 9335)) 459 (("(" 932) (argument_list 9334)) 460 (("=" 9251) (T_AND_EQUAL 9252) (T_COALESCE_EQUAL 9253) (T_CONCAT_EQUAL 9254) (T_DEC 9255) (T_DIV_EQUAL 9256) (T_INC 9257) (T_MINUS_EQUAL 9258) (T_MOD_EQUAL 9259) (T_MUL_EQUAL 9260) (T_OR_EQUAL 9261) (T_PLUS_EQUAL 9262) (T_POW_EQUAL 9263) (T_SL_EQUAL 9264) (T_SR_EQUAL 9265) (T_XOR_EQUAL 9266)) 461 ((T_PAAMAYIM_NEKUDOTAYIM 845)) 462 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 743) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 463 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 464 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 844) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 465 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 843) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 466 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 842) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 467 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 841) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 468 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 840) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 469 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 839) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 470 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 838) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 471 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 837) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 472 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 832) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 833) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 473 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 831) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 474 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 830) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 475 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 829) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 476 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 828) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 477 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 827) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 478 (("$" 789) ("(" 790) (T_NAME_FULLY_QUALIFIED 791) (T_NAME_QUALIFIED 792) (T_NAME_RELATIVE 793) (T_STATIC 794) (T_STRING 795) (T_VARIABLE 796) (class_name 797) (class_name_reference 798) (name 799) (new_variable 800) (simple_variable 801)) 479 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 788) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 480 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 787) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 481 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 786) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 482 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 785) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 483 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 784) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 484 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 783) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 485 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 782) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 486 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 781) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 487 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 780) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 488 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 779) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 489 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 778) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 490 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 777) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 491 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 776) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 492 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 775) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 493 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 774) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 494 (("$" 789) (T_VARIABLE 796) (simple_variable 823) ("{" 824)) 495 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 821) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 496 ((T_PAAMAYIM_NEKUDOTAYIM 819)) 497 ((T_NULLSAFE_OBJECT_OPERATOR 802) (T_OBJECT_OPERATOR 803) (T_PAAMAYIM_NEKUDOTAYIM 804) ("[" 805) ("{" 806)) 498 (("$" 789) (T_STRING 812) (T_VARIABLE 796) (property_name 818) (simple_variable 814) ("{" 815)) 499 (("$" 789) (T_STRING 812) (T_VARIABLE 796) (property_name 813) (simple_variable 814) ("{" 815)) 500 (("$" 789) (T_VARIABLE 796) (simple_variable 811)) 501 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 809) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 502 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 807) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 503 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 808)) 504 (("]" 810)) 505 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 816) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 506 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 817)) 507 (("$" 789) (T_VARIABLE 796) (simple_variable 820)) 508 (("%" 292) (")" 822) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 509 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 825) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 510 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 826)) 511 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 836) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 512 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 834) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 513 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 835) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 514 (("$" 667) (T_ABSTRACT 846) (T_ARRAY 847) (T_AS 848) (T_BREAK 849) (T_CALLABLE 850) (T_CASE 851) (T_CATCH 852) (T_CLASS 853) (T_CLASS_C 854) (T_CLONE 855) (T_CONST 856) (T_CONTINUE 857) (T_DECLARE 858) (T_DEFAULT 859) (T_DIR 860) (T_DO 861) (T_ECHO 862) (T_ELSE 863) (T_ELSEIF 864) (T_EMPTY 865) (T_ENDDECLARE 866) (T_ENDFOR 867) (T_ENDFOREACH 868) (T_ENDIF 869) (T_ENDSWITCH 870) (T_ENDWHILE 871) (T_ENUM 872) (T_EVAL 873) (T_EXIT 874) (T_EXTENDS 875) (T_FILE 876) (T_FINAL 877) (T_FINALLY 878) (T_FN 879) (T_FOR 880) (T_FOREACH 881) (T_FUNCTION 882) (T_FUNC_C 883) (T_GLOBAL 884) (T_GOTO 885) (T_IF 886) (T_IMPLEMENTS 887) (T_INCLUDE 888) (T_INCLUDE_ONCE 889) (T_INSTANCEOF 890) (T_INSTEADOF 891) (T_INTERFACE 892) (T_ISSET 893) (T_LINE 894) (T_LIST 895) (T_LOGICAL_AND 896) (T_LOGICAL_OR 897) (T_LOGICAL_XOR 898) (T_MATCH 899) (T_METHOD_C 900) (T_NAMESPACE 901) (T_NEW 902) (T_NS_C 903) (T_PRINT 904) (T_PRIVATE 905) (T_PROTECTED 906) (T_PUBLIC 907) (T_READONLY 908) (T_REQUIRE 909) (T_REQUIRE_ONCE 910) (T_RETURN 911) (T_STATIC 912) (T_STRING 913) (T_SWITCH 914) (T_THROW 915) (T_TRAIT 916) (T_TRAIT_C 917) (T_TRY 918) (T_UNSET 919) (T_USE 920) (T_VAR 921) (T_VARIABLE 715) (T_WHILE 922) (T_YIELD 923) (identifier 924) (member_name 925) (reserved_non_modifiers 926) (semi_reserved 927) (simple_variable 928) ("{" 929)) 515 (("(" 932) (argument_list 933)) 516 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 930) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 517 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 931)) 518 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 938) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 965) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 1060) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 519 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 9250) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 520 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 9248) (encaps_var 5299)) 521 (("$" 936) (T_VARIABLE 1035) (simple_variable 9244) ("{" 9245)) 522 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 9242) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 523 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 9241) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 524 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 9240) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 525 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 9239) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 526 (("(" 8997)) 527 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 9238) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 528 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 9237) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 529 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 8996) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 530 (("\"" 1509) ("$" 2930) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 9119) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 2939) ("[" 1529) (array_object_dereferenceable 9120) (callable_expr 9121) (callable_variable 9122) (class_constant 1533) (class_name 9123) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 9124) (name 9125) (simple_variable 9126) (static_member 9127) (variable 9236) (variable_class_name 9129)) 531 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 9235) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 532 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 9234) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 533 (("(" 8993)) 534 (("(" 8990)) 535 (("(" 8986) (exit_expr 8987)) 536 (("\"" 1509) ("$" 2930) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 9119) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 2939) ("[" 1529) (array_object_dereferenceable 9120) (callable_expr 9121) (callable_variable 9122) (class_constant 1533) (class_name 9123) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 9124) (name 9125) (simple_variable 9126) (static_member 9127) (variable 9233) (variable_class_name 9129)) 537 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 8985) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 538 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 8984) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 539 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 9232) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 540 (("(" 8980)) 541 (("(" 8975)) 542 (("(" 8969)) 543 (("$" 2930) ("(" 2931) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 2933) (T_NAME_QUALIFIED 2934) (T_NAME_RELATIVE 2935) (T_READONLY 2936) (T_STATIC 2937) (T_STRING 2938) (T_VARIABLE 2939) (anonymous_class 8947) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 8948) (attribute 2943) (attributes 8949) (class_modifier 2945) (class_name 2946) (class_name_reference 8950) (name 2948) (new_variable 2949) (simple_variable 2950)) 544 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 9231) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 545 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 8946) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 546 (("(" 8938) (argument_list 8939)) 547 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 8937) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 548 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 8936) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 549 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 9226) (T_END_HEREDOC 9227) (T_VARIABLE 2900) (encaps_list 9228) (encaps_var 2902)) 550 ((T_FN 35) (T_FUNCTION 127) (fn 1051) #'1052 (inline_function 8935)) 551 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 9225) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 552 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 8934) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 553 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 9224) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 554 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1260) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 555 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 9223) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 556 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 9219) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 557 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 9217) (encaps_list 2805) (encaps_var 2806)) 558 ((T_NULLSAFE_OBJECT_OPERATOR 9200) (T_OBJECT_OPERATOR 9201) ("[" 9202) ("{" 9203)) 559 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 9197) (attribute 2728) (fn 1051) #'1052 (inline_function 9198)) 560 (("(" 8938) (argument_list 9196)) 561 ((T_PAAMAYIM_NEKUDOTAYIM 9188)) 562 (("%" 1097) ("*" 1098) ("+" 1099) ("-" 1100) ("." 1101) ("/" 1102) ("<" 1103) (">" 1104) ("?" 1105) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1106) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1107) (T_BOOLEAN_AND 1108) (T_BOOLEAN_OR 1109) (T_COALESCE 1110) (T_INSTANCEOF 1111) (T_IS_EQUAL 1112) (T_IS_GREATER_OR_EQUAL 1113) (T_IS_IDENTICAL 1114) (T_IS_NOT_EQUAL 1115) (T_IS_NOT_IDENTICAL 1116) (T_IS_SMALLER_OR_EQUAL 1117) (T_LOGICAL_AND 1118) (T_LOGICAL_OR 1119) (T_LOGICAL_XOR 1120) (T_POW 1121) (T_SL 1122) (T_SPACESHIP 1123) (T_SR 1124) ("^" 1125) ("|" 1126)) 563 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 9177)) 564 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 9165)) 565 ((":" 9163)) 566 (("(" 8938) (argument_list 9162)) 567 (("," 1469) (possible_comma 9160)) 568 (("=" 9088) (T_AND_EQUAL 9089) (T_COALESCE_EQUAL 9090) (T_CONCAT_EQUAL 9091) (T_DEC 9092) (T_DIV_EQUAL 9093) (T_INC 9094) (T_MINUS_EQUAL 9095) (T_MOD_EQUAL 9096) (T_MUL_EQUAL 9097) (T_OR_EQUAL 9098) (T_PLUS_EQUAL 9099) (T_POW_EQUAL 9100) (T_SL_EQUAL 9101) (T_SR_EQUAL 9102) (T_XOR_EQUAL 9103)) 569 ((T_PAAMAYIM_NEKUDOTAYIM 9000)) 570 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1096) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 571 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1197) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 572 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1196) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 573 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1195) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 574 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1194) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 575 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1193) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 576 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1192) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 577 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1191) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 578 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1190) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 579 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 1185) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 1186) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 580 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1184) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 581 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1183) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 582 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1182) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 583 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1181) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 584 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1180) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 585 (("$" 1142) ("(" 1143) (T_NAME_FULLY_QUALIFIED 1144) (T_NAME_QUALIFIED 1145) (T_NAME_RELATIVE 1146) (T_STATIC 1147) (T_STRING 1148) (T_VARIABLE 1149) (class_name 1150) (class_name_reference 1151) (name 1152) (new_variable 1153) (simple_variable 1154)) 586 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1141) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 587 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1140) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 588 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1139) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 589 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1138) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 590 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1137) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 591 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1136) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 592 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1135) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 593 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1134) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 594 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1133) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 595 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1132) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 596 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1131) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 597 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1130) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 598 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1129) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 599 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1128) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 600 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1127) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 601 (("$" 1142) (T_VARIABLE 1149) (simple_variable 1176) ("{" 1177)) 602 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 1174) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 603 ((T_PAAMAYIM_NEKUDOTAYIM 1172)) 604 ((T_NULLSAFE_OBJECT_OPERATOR 1155) (T_OBJECT_OPERATOR 1156) (T_PAAMAYIM_NEKUDOTAYIM 1157) ("[" 1158) ("{" 1159)) 605 (("$" 1142) (T_STRING 1165) (T_VARIABLE 1149) (property_name 1171) (simple_variable 1167) ("{" 1168)) 606 (("$" 1142) (T_STRING 1165) (T_VARIABLE 1149) (property_name 1166) (simple_variable 1167) ("{" 1168)) 607 (("$" 1142) (T_VARIABLE 1149) (simple_variable 1164)) 608 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 1162) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 609 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 1160) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 610 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 1161)) 611 (("]" 1163)) 612 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 1169) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 613 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 1170)) 614 (("$" 1142) (T_VARIABLE 1149) (simple_variable 1173)) 615 (("%" 292) (")" 1175) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 616 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 1178) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 617 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 1179)) 618 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1189) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 619 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 1187) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 620 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1188) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 621 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 8933) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 622 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 8931) (encaps_var 5299)) 623 (("$" 1200) (T_VARIABLE 1247) (simple_variable 8927) ("{" 8928)) 624 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 8925) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 625 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 8924) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 626 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 8923) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 627 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 8922) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 628 (("(" 8919)) 629 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 8918) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 630 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 8917) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 631 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 8916) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 632 (("\"" 1509) ("$" 1510) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 1524) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 1528) ("[" 1529) (array_object_dereferenceable 1530) (callable_expr 1531) (callable_variable 1532) (class_constant 1533) (class_name 1534) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 1537) (name 1538) (simple_variable 1539) (static_member 1540) (variable 8915) (variable_class_name 1542)) 633 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 8914) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 634 (("(" 8911)) 635 (("(" 8908)) 636 (("(" 8904) (exit_expr 8905)) 637 (("\"" 1509) ("$" 1510) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 1524) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 1528) ("[" 1529) (array_object_dereferenceable 1530) (callable_expr 1531) (callable_variable 1532) (class_constant 1533) (class_name 1534) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 1537) (name 1538) (simple_variable 1539) (static_member 1540) (variable 8903) (variable_class_name 1542)) 638 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 8902) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 639 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 8901) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 640 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 8900) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 641 (("(" 8896)) 642 (("(" 8891)) 643 (("(" 8885)) 644 (("$" 1510) ("(" 6724) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 6725) (T_NAME_QUALIFIED 6726) (T_NAME_RELATIVE 6727) (T_READONLY 2936) (T_STATIC 6728) (T_STRING 6729) (T_VARIABLE 1528) (anonymous_class 8863) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 8864) (attribute 2943) (attributes 8865) (class_modifier 2945) (class_name 6733) (class_name_reference 8866) (name 6735) (new_variable 6736) (simple_variable 6737)) 645 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 8862) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 646 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 8861) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 647 (("(" 1464) (argument_list 8860)) 648 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 8859) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 649 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 8858) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 650 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 8853) (T_END_HEREDOC 8854) (T_VARIABLE 2900) (encaps_list 8855) (encaps_var 2902)) 651 ((T_FN 35) (T_FUNCTION 127) (fn 1261) #'1262 (inline_function 8852)) 652 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 8851) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 653 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 8850) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 654 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 8849) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 655 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 8846) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 656 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 8845) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 657 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 8841) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 658 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 8839) (encaps_list 2805) (encaps_var 2806)) 659 ((T_NULLSAFE_OBJECT_OPERATOR 8822) (T_OBJECT_OPERATOR 8823) ("[" 8824) ("{" 8825)) 660 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 8819) (attribute 2728) (fn 1261) #'1262 (inline_function 8820)) 661 (("(" 1464) (argument_list 8818)) 662 ((T_PAAMAYIM_NEKUDOTAYIM 8810)) 663 (("%" 1276) ("*" 1277) ("+" 1278) ("-" 1279) ("." 1280) ("/" 1281) ("<" 1282) (">" 1283) ("?" 1284) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1285) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1286) (T_BOOLEAN_AND 1287) (T_BOOLEAN_OR 1288) (T_COALESCE 1289) (T_DOUBLE_ARROW 8808) (T_INSTANCEOF 1290) (T_IS_EQUAL 1291) (T_IS_GREATER_OR_EQUAL 1292) (T_IS_IDENTICAL 1293) (T_IS_NOT_EQUAL 1294) (T_IS_NOT_IDENTICAL 1295) (T_IS_SMALLER_OR_EQUAL 1296) (T_LOGICAL_AND 1297) (T_LOGICAL_OR 1298) (T_LOGICAL_XOR 1299) (T_POW 1300) (T_SL 1301) (T_SPACESHIP 1302) (T_SR 1303) ("^" 1304) ("|" 1305)) 664 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 8797)) 665 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 8785)) 666 (("(" 1464) (argument_list 8784)) 667 (("=" 1476) (T_AND_EQUAL 1477) (T_COALESCE_EQUAL 1478) (T_CONCAT_EQUAL 1479) (T_DEC 1480) (T_DIV_EQUAL 1481) (T_INC 1482) (T_MINUS_EQUAL 1483) (T_MOD_EQUAL 1484) (T_MUL_EQUAL 1485) (T_OR_EQUAL 1486) (T_PLUS_EQUAL 1487) (T_POW_EQUAL 1488) (T_SL_EQUAL 1489) (T_SR_EQUAL 1490) (T_XOR_EQUAL 1491)) 668 ((T_PAAMAYIM_NEKUDOTAYIM 1377)) 669 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1275) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 670 (("%" 1276) ("*" 1277) ("+" 1278) ("-" 1279) ("." 1280) ("/" 1281) ("<" 1282) (">" 1283) ("?" 1284) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1285) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1286) (T_BOOLEAN_AND 1287) (T_BOOLEAN_OR 1288) (T_COALESCE 1289) (T_INSTANCEOF 1290) (T_IS_EQUAL 1291) (T_IS_GREATER_OR_EQUAL 1292) (T_IS_IDENTICAL 1293) (T_IS_NOT_EQUAL 1294) (T_IS_NOT_IDENTICAL 1295) (T_IS_SMALLER_OR_EQUAL 1296) (T_LOGICAL_AND 1297) (T_LOGICAL_OR 1298) (T_LOGICAL_XOR 1299) (T_POW 1300) (T_SL 1301) (T_SPACESHIP 1302) (T_SR 1303) ("^" 1304) ("|" 1305)) 671 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1376) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 672 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1375) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 673 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1374) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 674 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1373) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 675 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1372) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 676 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1371) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 677 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1370) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 678 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1369) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 679 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 1364) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 1365) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 680 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1363) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 681 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1362) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 682 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1361) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 683 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1360) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 684 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1359) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 685 (("$" 1321) ("(" 1322) (T_NAME_FULLY_QUALIFIED 1323) (T_NAME_QUALIFIED 1324) (T_NAME_RELATIVE 1325) (T_STATIC 1326) (T_STRING 1327) (T_VARIABLE 1328) (class_name 1329) (class_name_reference 1330) (name 1331) (new_variable 1332) (simple_variable 1333)) 686 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1320) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 687 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1319) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 688 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1318) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 689 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1317) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 690 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1316) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 691 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1315) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 692 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1314) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 693 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1313) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 694 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1312) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 695 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1311) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 696 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1310) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 697 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1309) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 698 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1308) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 699 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1307) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 700 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1306) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 701 (("$" 1321) (T_VARIABLE 1328) (simple_variable 1355) ("{" 1356)) 702 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 1353) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 703 ((T_PAAMAYIM_NEKUDOTAYIM 1351)) 704 ((T_NULLSAFE_OBJECT_OPERATOR 1334) (T_OBJECT_OPERATOR 1335) (T_PAAMAYIM_NEKUDOTAYIM 1336) ("[" 1337) ("{" 1338)) 705 (("$" 1321) (T_STRING 1344) (T_VARIABLE 1328) (property_name 1350) (simple_variable 1346) ("{" 1347)) 706 (("$" 1321) (T_STRING 1344) (T_VARIABLE 1328) (property_name 1345) (simple_variable 1346) ("{" 1347)) 707 (("$" 1321) (T_VARIABLE 1328) (simple_variable 1343)) 708 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 1341) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 709 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 1339) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 710 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 1340)) 711 (("]" 1342)) 712 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 1348) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 713 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 1349)) 714 (("$" 1321) (T_VARIABLE 1328) (simple_variable 1352)) 715 (("%" 292) (")" 1354) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 716 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 1357) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 717 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 1358)) 718 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1368) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 719 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 1366) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 720 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1367) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 721 (("$" 1200) (T_ABSTRACT 1378) (T_ARRAY 1379) (T_AS 1380) (T_BREAK 1381) (T_CALLABLE 1382) (T_CASE 1383) (T_CATCH 1384) (T_CLASS 1385) (T_CLASS_C 1386) (T_CLONE 1387) (T_CONST 1388) (T_CONTINUE 1389) (T_DECLARE 1390) (T_DEFAULT 1391) (T_DIR 1392) (T_DO 1393) (T_ECHO 1394) (T_ELSE 1395) (T_ELSEIF 1396) (T_EMPTY 1397) (T_ENDDECLARE 1398) (T_ENDFOR 1399) (T_ENDFOREACH 1400) (T_ENDIF 1401) (T_ENDSWITCH 1402) (T_ENDWHILE 1403) (T_ENUM 1404) (T_EVAL 1405) (T_EXIT 1406) (T_EXTENDS 1407) (T_FILE 1408) (T_FINAL 1409) (T_FINALLY 1410) (T_FN 1411) (T_FOR 1412) (T_FOREACH 1413) (T_FUNCTION 1414) (T_FUNC_C 1415) (T_GLOBAL 1416) (T_GOTO 1417) (T_IF 1418) (T_IMPLEMENTS 1419) (T_INCLUDE 1420) (T_INCLUDE_ONCE 1421) (T_INSTANCEOF 1422) (T_INSTEADOF 1423) (T_INTERFACE 1424) (T_ISSET 1425) (T_LINE 1426) (T_LIST 1427) (T_LOGICAL_AND 1428) (T_LOGICAL_OR 1429) (T_LOGICAL_XOR 1430) (T_MATCH 1431) (T_METHOD_C 1432) (T_NAMESPACE 1433) (T_NEW 1434) (T_NS_C 1435) (T_PRINT 1436) (T_PRIVATE 1437) (T_PROTECTED 1438) (T_PUBLIC 1439) (T_READONLY 1440) (T_REQUIRE 1441) (T_REQUIRE_ONCE 1442) (T_RETURN 1443) (T_STATIC 1444) (T_STRING 1445) (T_SWITCH 1446) (T_THROW 1447) (T_TRAIT 1448) (T_TRAIT_C 1449) (T_TRY 1450) (T_UNSET 1451) (T_USE 1452) (T_VAR 1453) (T_VARIABLE 1247) (T_WHILE 1454) (T_YIELD 1455) (identifier 1456) (member_name 1457) (reserved_non_modifiers 1458) (semi_reserved 1459) (simple_variable 1460) ("{" 1461)) 722 (("(" 1464) (argument_list 1465)) 723 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 1462) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 724 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 1463)) 725 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 1466) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 1467) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 1468) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 726 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 1475) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 727 (("," 1469) (possible_comma 1470)) 728 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 1472) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1473) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 729 ((")" 1471)) 730 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 731 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (ampersand 1507) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1508) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 732 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1504) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 733 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1503) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 734 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1502) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 735 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1501) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 736 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1500) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 737 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1499) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 738 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1498) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 739 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1497) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 740 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1496) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 741 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1495) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 742 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1494) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 743 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1493) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 744 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 1492) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 745 (("\"" 1509) ("$" 1510) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 1524) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 1528) ("[" 1529) (array_object_dereferenceable 1530) (callable_expr 1531) (callable_variable 1532) (class_constant 1533) (class_name 1534) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 1537) (name 1538) (simple_variable 1539) (static_member 1540) (variable 1541) (variable_class_name 1542)) 746 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 8782) (encaps_var 5299)) 747 (("$" 1510) (T_VARIABLE 1528) (simple_variable 8778) ("{" 8779)) 748 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 8776) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 749 (("(" 8773)) 750 (("(" 1630) (argument_list 8772)) 751 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 1723) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 752 ((T_NULLSAFE_OBJECT_OPERATOR 1648) (T_OBJECT_OPERATOR 1649) ("[" 1650) ("{" 1651)) 753 (("(" 1630) (argument_list 1647)) 754 ((T_PAAMAYIM_NEKUDOTAYIM 1639)) 755 (("(" 1630) (argument_list 1638)) 756 ((T_PAAMAYIM_NEKUDOTAYIM 1543)) 757 (("$" 1510) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 1528) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 1623) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 1626) ("{" 1627)) 758 (("(" 1630) (argument_list 1631)) 759 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 1628) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 760 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 1629)) 761 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 1632) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 1633) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 1634) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 762 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 1637) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 763 (("," 1469) (possible_comma 1635)) 764 ((")" 1636)) 765 (("$" 1510) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 1528) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 1641) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 1642) ("{" 1643)) 766 (("(" 1630) (argument_list 1646)) 767 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 1644) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 768 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 1645)) 769 (("$" 1510) (T_STRING 1656) (T_VARIABLE 1528) (property_name 1663) (simple_variable 1658) ("{" 1659)) 770 (("$" 1510) (T_STRING 1656) (T_VARIABLE 1528) (property_name 1657) (simple_variable 1658) ("{" 1659)) 771 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 1654) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 772 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 1652) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 773 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 1653)) 774 (("]" 1655)) 775 (("(" 1630) (argument_list 1662)) 776 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 1660) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 777 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 1661)) 778 (("(" 1630) (argument_list 1664)) 779 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 8771) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 780 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 8769) (encaps_var 5299)) 781 (("$" 1667) (T_VARIABLE 1715) (simple_variable 8765) ("{" 8766)) 782 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 8763) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 783 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 8762) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 784 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 8761) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 785 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 8760) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 786 (("(" 8757)) 787 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 8756) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 788 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 8755) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 789 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 8754) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 790 (("\"" 1509) ("$" 6946) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 6947) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 6948) ("[" 1529) (array_object_dereferenceable 6949) (callable_expr 6950) (callable_variable 6951) (class_constant 1533) (class_name 6952) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 6953) (name 6954) (simple_variable 6955) (static_member 6956) (variable 8753) (variable_class_name 6958)) 791 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 8752) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 792 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 8751) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 793 (("(" 8748)) 794 (("(" 8745)) 795 (("(" 8741) (exit_expr 8742)) 796 (("\"" 1509) ("$" 6946) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 6947) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 6948) ("[" 1529) (array_object_dereferenceable 6949) (callable_expr 6950) (callable_variable 6951) (class_constant 1533) (class_name 6952) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 6953) (name 6954) (simple_variable 6955) (static_member 6956) (variable 8740) (variable_class_name 6958)) 797 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 8739) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 798 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 8738) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 799 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 8737) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 800 (("(" 8733)) 801 (("(" 8730)) 802 (("(" 8724)) 803 (("$" 7327) ("(" 7457) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 7458) (T_NAME_QUALIFIED 7459) (T_NAME_RELATIVE 7460) (T_READONLY 2936) (T_STATIC 7461) (T_STRING 7462) (T_VARIABLE 7329) (anonymous_class 8702) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 8703) (attribute 2943) (attributes 8704) (class_modifier 2945) (class_name 7466) (class_name_reference 8705) (name 7468) (new_variable 7469) (simple_variable 7470)) 804 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 8701) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 805 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 8700) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 806 (("(" 6907) (argument_list 8699)) 807 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 8698) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 808 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 8697) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 809 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 8692) (T_END_HEREDOC 8693) (T_VARIABLE 2900) (encaps_list 8694) (encaps_var 2902)) 810 ((T_FN 35) (T_FUNCTION 127) (fn 1732) #'1733 (inline_function 8691)) 811 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 8690) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 812 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 8689) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 813 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 8688) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 814 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 8685) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 815 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 8684) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 816 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 8680) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 817 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 8678) (encaps_list 2805) (encaps_var 2806)) 818 (("\"" 1509) ("$" 8502) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 8503) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 8504) ("[" 1529) (array_object_dereferenceable 8505) (callable_expr 8506) (callable_variable 8507) (class_constant 1533) (class_name 8508) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 8509) (name 8510) (simple_variable 8511) (static_member 8512) (variable 8677) (variable_class_name 8514)) 819 ((T_NULLSAFE_OBJECT_OPERATOR 8660) (T_OBJECT_OPERATOR 8661) ("[" 8662) ("{" 8663)) 820 (("]" 8659)) 821 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 8656) (attribute 2728) (fn 1732) #'1733 (inline_function 8657)) 822 (("(" 6907) (argument_list 8655)) 823 ((T_PAAMAYIM_NEKUDOTAYIM 8647)) 824 (("%" 1750) ("*" 1751) ("+" 1752) ("-" 1753) ("." 1754) ("/" 1755) ("<" 1756) (">" 1757) ("?" 1758) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1759) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1760) (T_BOOLEAN_AND 1761) (T_BOOLEAN_OR 1762) (T_COALESCE 1763) (T_DOUBLE_ARROW 7554) (T_INSTANCEOF 1764) (T_IS_EQUAL 1765) (T_IS_GREATER_OR_EQUAL 1766) (T_IS_IDENTICAL 1767) (T_IS_NOT_EQUAL 1768) (T_IS_NOT_IDENTICAL 1769) (T_IS_SMALLER_OR_EQUAL 1770) (T_LOGICAL_AND 1771) (T_LOGICAL_OR 1772) (T_LOGICAL_XOR 1773) (T_POW 1774) (T_SL 1775) (T_SPACESHIP 1776) (T_SR 1777) ("^" 1778) ("|" 1779)) 825 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 7013)) 826 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 7001)) 827 (("(" 6907) (argument_list 7000)) 828 (("," 6998)) 829 (("=" 6915) (T_AND_EQUAL 6916) (T_COALESCE_EQUAL 6917) (T_CONCAT_EQUAL 6918) (T_DEC 6919) (T_DIV_EQUAL 6920) (T_INC 6921) (T_MINUS_EQUAL 6922) (T_MOD_EQUAL 6923) (T_MUL_EQUAL 6924) (T_OR_EQUAL 6925) (T_PLUS_EQUAL 6926) (T_POW_EQUAL 6927) (T_SL_EQUAL 6928) (T_SR_EQUAL 6929) (T_XOR_EQUAL 6930)) 830 ((T_PAAMAYIM_NEKUDOTAYIM 6820)) 831 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1749) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 832 (("(" 1851)) 833 (("%" 1750) ("*" 1751) ("+" 1752) ("-" 1753) ("." 1754) ("/" 1755) ("<" 1756) (">" 1757) ("?" 1758) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1759) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1760) (T_BOOLEAN_AND 1761) (T_BOOLEAN_OR 1762) (T_COALESCE 1763) (T_INSTANCEOF 1764) (T_IS_EQUAL 1765) (T_IS_GREATER_OR_EQUAL 1766) (T_IS_IDENTICAL 1767) (T_IS_NOT_EQUAL 1768) (T_IS_NOT_IDENTICAL 1769) (T_IS_SMALLER_OR_EQUAL 1770) (T_LOGICAL_AND 1771) (T_LOGICAL_OR 1772) (T_LOGICAL_XOR 1773) (T_POW 1774) (T_SL 1775) (T_SPACESHIP 1776) (T_SR 1777) ("^" 1778) ("|" 1779)) 834 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1850) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 835 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1849) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 836 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1848) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 837 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1847) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 838 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1846) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 839 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1845) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 840 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1844) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 841 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1843) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 842 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 1838) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 1839) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 843 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1837) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 844 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1836) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 845 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1835) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 846 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1834) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 847 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1833) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 848 (("$" 1795) ("(" 1796) (T_NAME_FULLY_QUALIFIED 1797) (T_NAME_QUALIFIED 1798) (T_NAME_RELATIVE 1799) (T_STATIC 1800) (T_STRING 1801) (T_VARIABLE 1802) (class_name 1803) (class_name_reference 1804) (name 1805) (new_variable 1806) (simple_variable 1807)) 849 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1794) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 850 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1793) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 851 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1792) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 852 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1791) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 853 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1790) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 854 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1789) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 855 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1788) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 856 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1787) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 857 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1786) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 858 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1785) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 859 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1784) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 860 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1783) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 861 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1782) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 862 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1781) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 863 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1780) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 864 (("$" 1795) (T_VARIABLE 1802) (simple_variable 1829) ("{" 1830)) 865 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 1827) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 866 ((T_PAAMAYIM_NEKUDOTAYIM 1825)) 867 ((T_NULLSAFE_OBJECT_OPERATOR 1808) (T_OBJECT_OPERATOR 1809) (T_PAAMAYIM_NEKUDOTAYIM 1810) ("[" 1811) ("{" 1812)) 868 (("$" 1795) (T_STRING 1818) (T_VARIABLE 1802) (property_name 1824) (simple_variable 1820) ("{" 1821)) 869 (("$" 1795) (T_STRING 1818) (T_VARIABLE 1802) (property_name 1819) (simple_variable 1820) ("{" 1821)) 870 (("$" 1795) (T_VARIABLE 1802) (simple_variable 1817)) 871 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 1815) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 872 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 1813) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 873 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 1814)) 874 (("]" 1816)) 875 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 1822) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 876 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 1823)) 877 (("$" 1795) (T_VARIABLE 1802) (simple_variable 1826)) 878 (("%" 292) (")" 1828) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 879 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 1831) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 880 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 1832)) 881 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1842) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 882 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 1840) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 883 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1841) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 884 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 1910) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 885 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 6819) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 886 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 6817) (encaps_var 5299)) 887 (("$" 1854) (T_VARIABLE 1902) (simple_variable 6813) ("{" 6814)) 888 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 6811) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 889 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 6810) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 890 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 6809) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 891 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 6808) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 892 (("(" 6805)) 893 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 6804) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 894 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 6803) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 895 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 6802) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 896 (("\"" 1509) ("$" 2169) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 2170) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 2171) ("[" 1529) (array_object_dereferenceable 2172) (callable_expr 2173) (callable_variable 2174) (class_constant 1533) (class_name 2175) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 2176) (name 2177) (simple_variable 2178) (static_member 2179) (variable 6801) (variable_class_name 2181)) 897 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 6800) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 898 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 6799) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 899 (("(" 6796)) 900 (("(" 6793)) 901 (("(" 6789) (exit_expr 6790)) 902 (("\"" 1509) ("$" 2169) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 2170) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 2171) ("[" 1529) (array_object_dereferenceable 2172) (callable_expr 2173) (callable_variable 2174) (class_constant 1533) (class_name 2175) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 2176) (name 2177) (simple_variable 2178) (static_member 2179) (variable 6788) (variable_class_name 2181)) 903 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 6787) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 904 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 6786) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 905 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 6785) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 906 (("(" 6781)) 907 (("(" 6778)) 908 (("(" 6772)) 909 (("$" 1510) ("(" 6724) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 6725) (T_NAME_QUALIFIED 6726) (T_NAME_RELATIVE 6727) (T_READONLY 2936) (T_STATIC 6728) (T_STRING 6729) (T_VARIABLE 1528) (anonymous_class 6730) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 6731) (attribute 2943) (attributes 6732) (class_modifier 2945) (class_name 6733) (class_name_reference 6734) (name 6735) (new_variable 6736) (simple_variable 6737)) 910 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 6723) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 911 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 6722) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 912 (("(" 2130) (argument_list 6721)) 913 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 6720) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 914 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 6719) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 915 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 6714) (T_END_HEREDOC 6715) (T_VARIABLE 2900) (encaps_list 6716) (encaps_var 2902)) 916 ((T_FN 35) (T_FUNCTION 127) (fn 1919) #'1920 (inline_function 6713)) 917 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 6712) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 918 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 6711) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 919 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 6710) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 920 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 6707) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 921 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 6706) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 922 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 6702) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 923 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 6700) (encaps_list 2805) (encaps_var 2806)) 924 (("\"" 1509) ("$" 2748) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 2749) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 2750) ("[" 1529) (array_object_dereferenceable 2751) (callable_expr 2752) (callable_variable 2753) (class_constant 1533) (class_name 2754) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 2755) (name 2756) (simple_variable 2757) (static_member 2758) (variable 6699) (variable_class_name 2760)) 925 ((T_NULLSAFE_OBJECT_OPERATOR 6682) (T_OBJECT_OPERATOR 6683) ("[" 6684) ("{" 6685)) 926 ((")" 6679)) 927 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 6676) (attribute 2728) (fn 1919) #'1920 (inline_function 6677)) 928 (("(" 2130) (argument_list 6675)) 929 ((T_PAAMAYIM_NEKUDOTAYIM 6667)) 930 (("%" 1937) ("*" 1938) ("+" 1939) ("-" 1940) ("." 1941) ("/" 1942) ("<" 1943) (">" 1944) ("?" 1945) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1946) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1947) (T_BOOLEAN_AND 1948) (T_BOOLEAN_OR 1949) (T_COALESCE 1950) (T_DOUBLE_ARROW 2329) (T_INSTANCEOF 1951) (T_IS_EQUAL 1952) (T_IS_GREATER_OR_EQUAL 1953) (T_IS_IDENTICAL 1954) (T_IS_NOT_EQUAL 1955) (T_IS_NOT_IDENTICAL 1956) (T_IS_SMALLER_OR_EQUAL 1957) (T_LOGICAL_AND 1958) (T_LOGICAL_OR 1959) (T_LOGICAL_XOR 1960) (T_POW 1961) (T_SL 1962) (T_SPACESHIP 1963) (T_SR 1964) ("^" 1965) ("|" 1966)) 931 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 2236)) 932 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 2224)) 933 (("(" 2130) (argument_list 2223)) 934 (("," 2221)) 935 (("=" 2138) (T_AND_EQUAL 2139) (T_COALESCE_EQUAL 2140) (T_CONCAT_EQUAL 2141) (T_DEC 2142) (T_DIV_EQUAL 2143) (T_INC 2144) (T_MINUS_EQUAL 2145) (T_MOD_EQUAL 2146) (T_MUL_EQUAL 2147) (T_OR_EQUAL 2148) (T_PLUS_EQUAL 2149) (T_POW_EQUAL 2150) (T_SL_EQUAL 2151) (T_SR_EQUAL 2152) (T_XOR_EQUAL 2153)) 936 ((T_PAAMAYIM_NEKUDOTAYIM 2043)) 937 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1936) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 938 (("(" 2038)) 939 (("%" 1937) ("*" 1938) ("+" 1939) ("-" 1940) ("." 1941) ("/" 1942) ("<" 1943) (">" 1944) ("?" 1945) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1946) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1947) (T_BOOLEAN_AND 1948) (T_BOOLEAN_OR 1949) (T_COALESCE 1950) (T_INSTANCEOF 1951) (T_IS_EQUAL 1952) (T_IS_GREATER_OR_EQUAL 1953) (T_IS_IDENTICAL 1954) (T_IS_NOT_EQUAL 1955) (T_IS_NOT_IDENTICAL 1956) (T_IS_SMALLER_OR_EQUAL 1957) (T_LOGICAL_AND 1958) (T_LOGICAL_OR 1959) (T_LOGICAL_XOR 1960) (T_POW 1961) (T_SL 1962) (T_SPACESHIP 1963) (T_SR 1964) ("^" 1965) ("|" 1966)) 940 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 2037) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 941 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 2036) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 942 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 2035) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 943 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 2034) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 944 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 2033) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 945 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 2032) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 946 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 2031) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 947 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 2030) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 948 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 2025) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 2026) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 949 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 2024) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 950 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 2023) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 951 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 2022) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 952 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 2021) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 953 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 2020) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 954 (("$" 1982) ("(" 1983) (T_NAME_FULLY_QUALIFIED 1984) (T_NAME_QUALIFIED 1985) (T_NAME_RELATIVE 1986) (T_STATIC 1987) (T_STRING 1988) (T_VARIABLE 1989) (class_name 1990) (class_name_reference 1991) (name 1992) (new_variable 1993) (simple_variable 1994)) 955 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1981) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 956 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1980) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 957 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1979) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 958 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1978) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 959 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1977) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 960 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1976) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 961 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1975) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 962 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1974) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 963 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1973) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 964 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1972) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 965 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1971) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 966 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1970) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 967 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1969) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 968 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1968) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 969 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1967) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 970 (("$" 1982) (T_VARIABLE 1989) (simple_variable 2016) ("{" 2017)) 971 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 2014) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 972 ((T_PAAMAYIM_NEKUDOTAYIM 2012)) 973 ((T_NULLSAFE_OBJECT_OPERATOR 1995) (T_OBJECT_OPERATOR 1996) (T_PAAMAYIM_NEKUDOTAYIM 1997) ("[" 1998) ("{" 1999)) 974 (("$" 1982) (T_STRING 2005) (T_VARIABLE 1989) (property_name 2011) (simple_variable 2007) ("{" 2008)) 975 (("$" 1982) (T_STRING 2005) (T_VARIABLE 1989) (property_name 2006) (simple_variable 2007) ("{" 2008)) 976 (("$" 1982) (T_VARIABLE 1989) (simple_variable 2004)) 977 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 2002) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 978 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 2000) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 979 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 2001)) 980 (("]" 2003)) 981 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 2009) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 982 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 2010)) 983 (("$" 1982) (T_VARIABLE 1989) (simple_variable 2013)) 984 (("%" 292) (")" 2015) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 985 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 2018) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 986 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 2019)) 987 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 2029) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 988 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 2027) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 989 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 2028) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 990 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 2039) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 991 ((")" 2040)) 992 (("=" 2041)) 993 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 2042) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 994 (("$" 1854) (T_ABSTRACT 2044) (T_ARRAY 2045) (T_AS 2046) (T_BREAK 2047) (T_CALLABLE 2048) (T_CASE 2049) (T_CATCH 2050) (T_CLASS 2051) (T_CLASS_C 2052) (T_CLONE 2053) (T_CONST 2054) (T_CONTINUE 2055) (T_DECLARE 2056) (T_DEFAULT 2057) (T_DIR 2058) (T_DO 2059) (T_ECHO 2060) (T_ELSE 2061) (T_ELSEIF 2062) (T_EMPTY 2063) (T_ENDDECLARE 2064) (T_ENDFOR 2065) (T_ENDFOREACH 2066) (T_ENDIF 2067) (T_ENDSWITCH 2068) (T_ENDWHILE 2069) (T_ENUM 2070) (T_EVAL 2071) (T_EXIT 2072) (T_EXTENDS 2073) (T_FILE 2074) (T_FINAL 2075) (T_FINALLY 2076) (T_FN 2077) (T_FOR 2078) (T_FOREACH 2079) (T_FUNCTION 2080) (T_FUNC_C 2081) (T_GLOBAL 2082) (T_GOTO 2083) (T_IF 2084) (T_IMPLEMENTS 2085) (T_INCLUDE 2086) (T_INCLUDE_ONCE 2087) (T_INSTANCEOF 2088) (T_INSTEADOF 2089) (T_INTERFACE 2090) (T_ISSET 2091) (T_LINE 2092) (T_LIST 2093) (T_LOGICAL_AND 2094) (T_LOGICAL_OR 2095) (T_LOGICAL_XOR 2096) (T_MATCH 2097) (T_METHOD_C 2098) (T_NAMESPACE 2099) (T_NEW 2100) (T_NS_C 2101) (T_PRINT 2102) (T_PRIVATE 2103) (T_PROTECTED 2104) (T_PUBLIC 2105) (T_READONLY 2106) (T_REQUIRE 2107) (T_REQUIRE_ONCE 2108) (T_RETURN 2109) (T_STATIC 2110) (T_STRING 2111) (T_SWITCH 2112) (T_THROW 2113) (T_TRAIT 2114) (T_TRAIT_C 2115) (T_TRY 2116) (T_UNSET 2117) (T_USE 2118) (T_VAR 2119) (T_VARIABLE 1902) (T_WHILE 2120) (T_YIELD 2121) (identifier 2122) (member_name 2123) (reserved_non_modifiers 2124) (semi_reserved 2125) (simple_variable 2126) ("{" 2127)) 995 (("(" 2130) (argument_list 2131)) 996 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 2128) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 997 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 2129)) 998 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 2132) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 2133) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 2134) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 999 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 2137) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 1000 (("," 1469) (possible_comma 2135)) 1001 ((")" 2136)) 1002 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 2167) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 2168) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 1003 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 2166) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 1004 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 2165) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 1005 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 2164) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 1006 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 2163) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 1007 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 2162) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 1008 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 2161) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 1009 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 2160) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 1010 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 2159) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 1011 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 2158) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 1012 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 2157) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 1013 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 2156) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 1014 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 2155) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 1015 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 2154) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 1016 (("\"" 1509) ("$" 2169) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 2170) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 2171) ("[" 1529) (array_object_dereferenceable 2172) (callable_expr 2173) (callable_variable 2174) (class_constant 1533) (class_name 2175) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 2176) (name 2177) (simple_variable 2178) (static_member 2179) (variable 2180) (variable_class_name 2181)) 1017 (("$" 2169) (T_VARIABLE 2171) (simple_variable 2217) ("{" 2218)) 1018 (("(" 2185) (argument_list 2216)) 1019 ((T_NULLSAFE_OBJECT_OPERATOR 2199) (T_OBJECT_OPERATOR 2200) ("[" 2201) ("{" 2202)) 1020 (("(" 2185) (argument_list 2198)) 1021 ((T_PAAMAYIM_NEKUDOTAYIM 2194)) 1022 (("(" 2185) (argument_list 2193)) 1023 ((T_PAAMAYIM_NEKUDOTAYIM 2182)) 1024 (("$" 2169) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 2171) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 2183) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 2184) ("{" 1627)) 1025 (("(" 2185) (argument_list 2186)) 1026 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 2187) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 2188) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 2189) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 1027 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 2192) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 1028 (("," 1469) (possible_comma 2190)) 1029 ((")" 2191)) 1030 (("$" 2169) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 2171) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 2195) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 2196) ("{" 1643)) 1031 (("(" 2185) (argument_list 2197)) 1032 (("$" 2169) (T_STRING 2207) (T_VARIABLE 2171) (property_name 2214) (simple_variable 2209) ("{" 2210)) 1033 (("$" 2169) (T_STRING 2207) (T_VARIABLE 2171) (property_name 2208) (simple_variable 2209) ("{" 2210)) 1034 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 2205) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 1035 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 2203) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1036 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 2204)) 1037 (("]" 2206)) 1038 (("(" 2185) (argument_list 2213)) 1039 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 2211) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1040 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 2212)) 1041 (("(" 2185) (argument_list 2215)) 1042 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 2219) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1043 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 2220)) 1044 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (possible_array_pair 2222) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 1045 ((backup_doc_comment 2225)) 1046 (("(" 2226)) 1047 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 2227)) 1048 ((")" 2228)) 1049 ((T_USE 159) (lexical_vars 2229)) 1050 ((":" 161) (return_type 2230)) 1051 ((backup_fn_flags 2231)) 1052 (("{" 2232)) 1053 ((inner_statement_list 2233)) 1054 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 2234) ("~" 125)) 1055 ((backup_fn_flags 2235)) 1056 ((backup_doc_comment 2237)) 1057 (("(" 2238)) 1058 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 2239)) 1059 ((")" 2240)) 1060 ((":" 2241) (return_type 2242)) 1061 (("(" 2248) ("?" 2249) (T_ARRAY 2250) (T_CALLABLE 2251) (T_NAME_FULLY_QUALIFIED 2252) (T_NAME_QUALIFIED 2253) (T_NAME_RELATIVE 2254) (T_STATIC 2255) (T_STRING 2256) (intersection_type 2257) (name 2258) (type 2259) (type_expr 2260) (type_without_static 2261) (union_type 2262) (union_type_element 2263)) 1062 ((T_DOUBLE_ARROW 2243)) 1063 ((backup_fn_flags 2244)) 1064 ((backup_lex_pos 2245)) 1065 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 2246) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 1066 (("%" 1276) ("*" 1277) ("+" 1278) ("-" 1279) ("." 1280) ("/" 1281) ("<" 1282) (">" 1283) ("?" 1284) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1285) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1286) (T_BOOLEAN_AND 1287) (T_BOOLEAN_OR 1288) (T_COALESCE 1289) (T_INSTANCEOF 1290) (T_IS_EQUAL 1291) (T_IS_GREATER_OR_EQUAL 1292) (T_IS_IDENTICAL 1293) (T_IS_NOT_EQUAL 1294) (T_IS_NOT_IDENTICAL 1295) (T_IS_SMALLER_OR_EQUAL 1296) (T_LOGICAL_AND 1297) (T_LOGICAL_OR 1298) (T_LOGICAL_XOR 1299) (T_POW 1300) (T_SL 1301) (T_SPACESHIP 1302) (T_SR 1303) ("^" 1304) (backup_fn_flags 2247) ("|" 1305)) 1067 ((T_ARRAY 2277) (T_CALLABLE 2278) (T_NAME_FULLY_QUALIFIED 2279) (T_NAME_QUALIFIED 2280) (T_NAME_RELATIVE 2281) (T_STATIC 2282) (T_STRING 2283) (intersection_type 2327) (name 2285) (type 2286) (type_without_static 2287)) 1068 ((T_ARRAY 2317) (T_CALLABLE 2318) (T_NAME_FULLY_QUALIFIED 2319) (T_NAME_QUALIFIED 2320) (T_NAME_RELATIVE 2321) (T_STATIC 2322) (T_STRING 2323) (name 2324) (type 2325) (type_without_static 2326)) 1069 ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 2315)) 1070 ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 2304)) 1071 (("|" 2302)) 1072 (("|" 2264)) 1073 (("(" 2265) (T_ARRAY 2266) (T_CALLABLE 2267) (T_NAME_FULLY_QUALIFIED 2268) (T_NAME_QUALIFIED 2269) (T_NAME_RELATIVE 2270) (T_STATIC 2271) (T_STRING 2272) (name 2273) (type 2274) (type_without_static 2275) (union_type_element 2276)) 1074 ((T_ARRAY 2277) (T_CALLABLE 2278) (T_NAME_FULLY_QUALIFIED 2279) (T_NAME_QUALIFIED 2280) (T_NAME_RELATIVE 2281) (T_STATIC 2282) (T_STRING 2283) (intersection_type 2284) (name 2285) (type 2286) (type_without_static 2287)) 1075 ((")" 2299) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 2300)) 1076 ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 2288)) 1077 ((T_ARRAY 2289) (T_CALLABLE 2290) (T_NAME_FULLY_QUALIFIED 2291) (T_NAME_QUALIFIED 2292) (T_NAME_RELATIVE 2293) (T_STATIC 2294) (T_STRING 2295) (name 2296) (type 2297) (type_without_static 2298)) 1078 ((T_ARRAY 2289) (T_CALLABLE 2290) (T_NAME_FULLY_QUALIFIED 2291) (T_NAME_QUALIFIED 2292) (T_NAME_RELATIVE 2293) (T_STATIC 2294) (T_STRING 2295) (name 2296) (type 2301) (type_without_static 2298)) 1079 (("(" 2265) (T_ARRAY 2266) (T_CALLABLE 2267) (T_NAME_FULLY_QUALIFIED 2268) (T_NAME_QUALIFIED 2269) (T_NAME_RELATIVE 2270) (T_STATIC 2271) (T_STRING 2272) (name 2273) (type 2274) (type_without_static 2275) (union_type_element 2303)) 1080 ((T_ARRAY 2305) (T_CALLABLE 2306) (T_NAME_FULLY_QUALIFIED 2307) (T_NAME_QUALIFIED 2308) (T_NAME_RELATIVE 2309) (T_STATIC 2310) (T_STRING 2311) (name 2312) (type 2313) (type_without_static 2314)) 1081 ((T_ARRAY 2305) (T_CALLABLE 2306) (T_NAME_FULLY_QUALIFIED 2307) (T_NAME_QUALIFIED 2308) (T_NAME_RELATIVE 2309) (T_STATIC 2310) (T_STRING 2311) (name 2312) (type 2316) (type_without_static 2314)) 1082 ((")" 2328) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 2300)) 1083 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2358) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (ampersand 2384) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2393) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1084 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 6666) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1085 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 6664) (encaps_var 5299)) 1086 (("$" 2332) (T_VARIABLE 2379) (simple_variable 6660) ("{" 6661)) 1087 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 6658) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 1088 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 6657) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1089 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 6656) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1090 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 6655) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1091 (("(" 6652)) 1092 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 6651) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1093 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 6650) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1094 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 6649) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1095 (("\"" 1509) ("$" 2642) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 2643) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 2644) ("[" 1529) (array_object_dereferenceable 2645) (callable_expr 2646) (callable_variable 2647) (class_constant 1533) (class_name 2648) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 2649) (name 2650) (simple_variable 2651) (static_member 2652) (variable 6648) (variable_class_name 2654)) 1096 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 6647) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1097 (("(" 6644)) 1098 (("(" 6641)) 1099 (("(" 6637) (exit_expr 6638)) 1100 (("\"" 1509) ("$" 2642) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 2643) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 2644) ("[" 1529) (array_object_dereferenceable 2645) (callable_expr 2646) (callable_variable 2647) (class_constant 1533) (class_name 2648) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 2649) (name 2650) (simple_variable 2651) (static_member 2652) (variable 6636) (variable_class_name 2654)) 1101 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 6635) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1102 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 6634) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1103 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 6633) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1104 (("(" 6629)) 1105 (("(" 6626)) 1106 (("(" 6620)) 1107 (("$" 2930) ("(" 2931) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 2933) (T_NAME_QUALIFIED 2934) (T_NAME_RELATIVE 2935) (T_READONLY 2936) (T_STATIC 2937) (T_STRING 2938) (T_VARIABLE 2939) (anonymous_class 2940) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 2942) (attribute 2943) (attributes 2944) (class_modifier 2945) (class_name 2946) (class_name_reference 2947) (name 2948) (new_variable 2949) (simple_variable 2950)) 1108 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2929) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1109 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2928) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1110 (("(" 2603) (argument_list 2927)) 1111 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2926) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1112 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2925) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1113 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2898) (T_END_HEREDOC 2899) (T_VARIABLE 2900) (encaps_list 2901) (encaps_var 2902)) 1114 ((T_FN 35) (T_FUNCTION 127) (fn 2394) #'2395 (inline_function 2895)) 1115 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2894) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1116 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2893) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1117 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2892) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1118 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 2889) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 1119 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2888) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1120 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 2884) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 1121 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 2804) (encaps_list 2805) (encaps_var 2806)) 1122 (("\"" 1509) ("$" 2748) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 2749) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 2750) ("[" 1529) (array_object_dereferenceable 2751) (callable_expr 2752) (callable_variable 2753) (class_constant 1533) (class_name 2754) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 2755) (name 2756) (simple_variable 2757) (static_member 2758) (variable 2759) (variable_class_name 2760)) 1123 ((T_NULLSAFE_OBJECT_OPERATOR 2731) (T_OBJECT_OPERATOR 2732) ("[" 2733) ("{" 2734)) 1124 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 2727) (attribute 2728) (fn 2394) #'2395 (inline_function 2729)) 1125 (("(" 2603) (argument_list 2726)) 1126 ((T_PAAMAYIM_NEKUDOTAYIM 2718)) 1127 (("%" 2410) ("*" 2411) ("+" 2412) ("-" 2413) ("." 2414) ("/" 2415) ("<" 2416) (">" 2417) ("?" 2418) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 2419) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 2420) (T_BOOLEAN_AND 2421) (T_BOOLEAN_OR 2422) (T_COALESCE 2423) (T_INSTANCEOF 2424) (T_IS_EQUAL 2425) (T_IS_GREATER_OR_EQUAL 2426) (T_IS_IDENTICAL 2427) (T_IS_NOT_EQUAL 2428) (T_IS_NOT_IDENTICAL 2429) (T_IS_SMALLER_OR_EQUAL 2430) (T_LOGICAL_AND 2431) (T_LOGICAL_OR 2432) (T_LOGICAL_XOR 2433) (T_POW 2434) (T_SL 2435) (T_SPACESHIP 2436) (T_SR 2437) ("^" 2438) ("|" 2439)) 1128 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 2707)) 1129 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 2695)) 1130 (("(" 2603) (argument_list 2694)) 1131 (("=" 2611) (T_AND_EQUAL 2612) (T_COALESCE_EQUAL 2613) (T_CONCAT_EQUAL 2614) (T_DEC 2615) (T_DIV_EQUAL 2616) (T_INC 2617) (T_MINUS_EQUAL 2618) (T_MOD_EQUAL 2619) (T_MUL_EQUAL 2620) (T_OR_EQUAL 2621) (T_PLUS_EQUAL 2622) (T_POW_EQUAL 2623) (T_SL_EQUAL 2624) (T_SR_EQUAL 2625) (T_XOR_EQUAL 2626)) 1132 ((T_PAAMAYIM_NEKUDOTAYIM 2516)) 1133 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2409) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1134 (("(" 2511)) 1135 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2510) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1136 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2509) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1137 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2508) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1138 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2507) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1139 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2506) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1140 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2505) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1141 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2504) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1142 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2503) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1143 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 2498) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 2499) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 1144 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2497) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1145 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2496) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1146 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2495) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1147 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2494) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1148 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2493) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1149 (("$" 2455) ("(" 2456) (T_NAME_FULLY_QUALIFIED 2457) (T_NAME_QUALIFIED 2458) (T_NAME_RELATIVE 2459) (T_STATIC 2460) (T_STRING 2461) (T_VARIABLE 2462) (class_name 2463) (class_name_reference 2464) (name 2465) (new_variable 2466) (simple_variable 2467)) 1150 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2454) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1151 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2453) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1152 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2452) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1153 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2451) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1154 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2450) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1155 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2449) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1156 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2448) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1157 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2447) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1158 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2446) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1159 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2445) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1160 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2444) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1161 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2443) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1162 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2442) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1163 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2441) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1164 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2440) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1165 (("$" 2455) (T_VARIABLE 2462) (simple_variable 2489) ("{" 2490)) 1166 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 2487) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 1167 ((T_PAAMAYIM_NEKUDOTAYIM 2485)) 1168 ((T_NULLSAFE_OBJECT_OPERATOR 2468) (T_OBJECT_OPERATOR 2469) (T_PAAMAYIM_NEKUDOTAYIM 2470) ("[" 2471) ("{" 2472)) 1169 (("$" 2455) (T_STRING 2478) (T_VARIABLE 2462) (property_name 2484) (simple_variable 2480) ("{" 2481)) 1170 (("$" 2455) (T_STRING 2478) (T_VARIABLE 2462) (property_name 2479) (simple_variable 2480) ("{" 2481)) 1171 (("$" 2455) (T_VARIABLE 2462) (simple_variable 2477)) 1172 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 2475) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 1173 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 2473) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1174 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 2474)) 1175 (("]" 2476)) 1176 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 2482) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1177 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 2483)) 1178 (("$" 2455) (T_VARIABLE 2462) (simple_variable 2486)) 1179 (("%" 292) (")" 2488) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 1180 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 2491) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1181 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 2492)) 1182 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2502) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1183 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 2500) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 1184 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2501) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1185 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 2512) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 1186 ((")" 2513)) 1187 (("=" 2514)) 1188 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2515) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1189 (("$" 2332) (T_ABSTRACT 2517) (T_ARRAY 2518) (T_AS 2519) (T_BREAK 2520) (T_CALLABLE 2521) (T_CASE 2522) (T_CATCH 2523) (T_CLASS 2524) (T_CLASS_C 2525) (T_CLONE 2526) (T_CONST 2527) (T_CONTINUE 2528) (T_DECLARE 2529) (T_DEFAULT 2530) (T_DIR 2531) (T_DO 2532) (T_ECHO 2533) (T_ELSE 2534) (T_ELSEIF 2535) (T_EMPTY 2536) (T_ENDDECLARE 2537) (T_ENDFOR 2538) (T_ENDFOREACH 2539) (T_ENDIF 2540) (T_ENDSWITCH 2541) (T_ENDWHILE 2542) (T_ENUM 2543) (T_EVAL 2544) (T_EXIT 2545) (T_EXTENDS 2546) (T_FILE 2547) (T_FINAL 2548) (T_FINALLY 2549) (T_FN 2550) (T_FOR 2551) (T_FOREACH 2552) (T_FUNCTION 2553) (T_FUNC_C 2554) (T_GLOBAL 2555) (T_GOTO 2556) (T_IF 2557) (T_IMPLEMENTS 2558) (T_INCLUDE 2559) (T_INCLUDE_ONCE 2560) (T_INSTANCEOF 2561) (T_INSTEADOF 2562) (T_INTERFACE 2563) (T_ISSET 2564) (T_LINE 2565) (T_LIST 2566) (T_LOGICAL_AND 2567) (T_LOGICAL_OR 2568) (T_LOGICAL_XOR 2569) (T_MATCH 2570) (T_METHOD_C 2571) (T_NAMESPACE 2572) (T_NEW 2573) (T_NS_C 2574) (T_PRINT 2575) (T_PRIVATE 2576) (T_PROTECTED 2577) (T_PUBLIC 2578) (T_READONLY 2579) (T_REQUIRE 2580) (T_REQUIRE_ONCE 2581) (T_RETURN 2582) (T_STATIC 2583) (T_STRING 2584) (T_SWITCH 2585) (T_THROW 2586) (T_TRAIT 2587) (T_TRAIT_C 2588) (T_TRY 2589) (T_UNSET 2590) (T_USE 2591) (T_VAR 2592) (T_VARIABLE 2379) (T_WHILE 2593) (T_YIELD 2594) (identifier 2595) (member_name 2596) (reserved_non_modifiers 2597) (semi_reserved 2598) (simple_variable 2599) ("{" 2600)) 1190 (("(" 2603) (argument_list 2604)) 1191 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 2601) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1192 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 2602)) 1193 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 2605) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 2606) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 2607) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 1194 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 2610) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 1195 (("," 1469) (possible_comma 2608)) 1196 ((")" 2609)) 1197 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (ampersand 2640) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2641) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1198 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2639) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1199 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2638) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1200 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2637) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1201 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2636) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1202 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2635) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1203 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2634) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1204 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2633) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1205 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2632) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1206 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2631) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1207 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2630) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1208 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2629) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1209 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2628) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1210 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2627) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1211 (("\"" 1509) ("$" 2642) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 2643) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 2644) ("[" 1529) (array_object_dereferenceable 2645) (callable_expr 2646) (callable_variable 2647) (class_constant 1533) (class_name 2648) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 2649) (name 2650) (simple_variable 2651) (static_member 2652) (variable 2653) (variable_class_name 2654)) 1212 (("$" 2642) (T_VARIABLE 2644) (simple_variable 2690) ("{" 2691)) 1213 (("(" 2658) (argument_list 2689)) 1214 ((T_NULLSAFE_OBJECT_OPERATOR 2672) (T_OBJECT_OPERATOR 2673) ("[" 2674) ("{" 2675)) 1215 (("(" 2658) (argument_list 2671)) 1216 ((T_PAAMAYIM_NEKUDOTAYIM 2667)) 1217 (("(" 2658) (argument_list 2666)) 1218 ((T_PAAMAYIM_NEKUDOTAYIM 2655)) 1219 (("$" 2642) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 2644) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 2656) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 2657) ("{" 1627)) 1220 (("(" 2658) (argument_list 2659)) 1221 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 2660) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 2661) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 2662) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 1222 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 2665) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 1223 (("," 1469) (possible_comma 2663)) 1224 ((")" 2664)) 1225 (("$" 2642) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 2644) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 2668) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 2669) ("{" 1643)) 1226 (("(" 2658) (argument_list 2670)) 1227 (("$" 2642) (T_STRING 2680) (T_VARIABLE 2644) (property_name 2687) (simple_variable 2682) ("{" 2683)) 1228 (("$" 2642) (T_STRING 2680) (T_VARIABLE 2644) (property_name 2681) (simple_variable 2682) ("{" 2683)) 1229 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 2678) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 1230 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 2676) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1231 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 2677)) 1232 (("]" 2679)) 1233 (("(" 2658) (argument_list 2686)) 1234 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 2684) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1235 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 2685)) 1236 (("(" 2658) (argument_list 2688)) 1237 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 2692) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1238 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 2693)) 1239 ((backup_doc_comment 2696)) 1240 (("(" 2697)) 1241 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 2698)) 1242 ((")" 2699)) 1243 ((T_USE 159) (lexical_vars 2700)) 1244 ((":" 161) (return_type 2701)) 1245 ((backup_fn_flags 2702)) 1246 (("{" 2703)) 1247 ((inner_statement_list 2704)) 1248 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 2705) ("~" 125)) 1249 ((backup_fn_flags 2706)) 1250 ((backup_doc_comment 2708)) 1251 (("(" 2709)) 1252 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 2710)) 1253 ((")" 2711)) 1254 ((":" 2241) (return_type 2712)) 1255 ((T_DOUBLE_ARROW 2713)) 1256 ((backup_fn_flags 2714)) 1257 ((backup_lex_pos 2715)) 1258 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 2716) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 1259 (("%" 1097) ("*" 1098) ("+" 1099) ("-" 1100) ("." 1101) ("/" 1102) ("<" 1103) (">" 1104) ("?" 1105) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1106) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1107) (T_BOOLEAN_AND 1108) (T_BOOLEAN_OR 1109) (T_COALESCE 1110) (T_INSTANCEOF 1111) (T_IS_EQUAL 1112) (T_IS_GREATER_OR_EQUAL 1113) (T_IS_IDENTICAL 1114) (T_IS_NOT_EQUAL 1115) (T_IS_NOT_IDENTICAL 1116) (T_IS_SMALLER_OR_EQUAL 1117) (T_LOGICAL_AND 1118) (T_LOGICAL_OR 1119) (T_LOGICAL_XOR 1120) (T_POW 1121) (T_SL 1122) (T_SPACESHIP 1123) (T_SR 1124) ("^" 1125) (backup_fn_flags 2717) ("|" 1126)) 1260 (("$" 2332) (T_ABSTRACT 2517) (T_ARRAY 2518) (T_AS 2519) (T_BREAK 2520) (T_CALLABLE 2521) (T_CASE 2522) (T_CATCH 2523) (T_CLASS 2524) (T_CLASS_C 2525) (T_CLONE 2526) (T_CONST 2527) (T_CONTINUE 2528) (T_DECLARE 2529) (T_DEFAULT 2530) (T_DIR 2531) (T_DO 2532) (T_ECHO 2533) (T_ELSE 2534) (T_ELSEIF 2535) (T_EMPTY 2536) (T_ENDDECLARE 2537) (T_ENDFOR 2538) (T_ENDFOREACH 2539) (T_ENDIF 2540) (T_ENDSWITCH 2541) (T_ENDWHILE 2542) (T_ENUM 2543) (T_EVAL 2544) (T_EXIT 2545) (T_EXTENDS 2546) (T_FILE 2547) (T_FINAL 2548) (T_FINALLY 2549) (T_FN 2550) (T_FOR 2551) (T_FOREACH 2552) (T_FUNCTION 2553) (T_FUNC_C 2554) (T_GLOBAL 2555) (T_GOTO 2556) (T_IF 2557) (T_IMPLEMENTS 2558) (T_INCLUDE 2559) (T_INCLUDE_ONCE 2560) (T_INSTANCEOF 2561) (T_INSTEADOF 2562) (T_INTERFACE 2563) (T_ISSET 2564) (T_LINE 2565) (T_LIST 2566) (T_LOGICAL_AND 2567) (T_LOGICAL_OR 2568) (T_LOGICAL_XOR 2569) (T_MATCH 2570) (T_METHOD_C 2571) (T_NAMESPACE 2572) (T_NEW 2573) (T_NS_C 2574) (T_PRINT 2575) (T_PRIVATE 2576) (T_PROTECTED 2577) (T_PUBLIC 2578) (T_READONLY 2579) (T_REQUIRE 2580) (T_REQUIRE_ONCE 2581) (T_RETURN 2582) (T_STATIC 2583) (T_STRING 2584) (T_SWITCH 2585) (T_THROW 2586) (T_TRAIT 2587) (T_TRAIT_C 2588) (T_TRY 2589) (T_UNSET 2590) (T_USE 2591) (T_VAR 2592) (T_VARIABLE 2379) (T_WHILE 2593) (T_YIELD 2594) (identifier 2719) (member_name 2720) (reserved_non_modifiers 2597) (semi_reserved 2598) (simple_variable 2721) ("{" 2722)) 1261 (("(" 2603) (argument_list 2725)) 1262 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 2723) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1263 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 2724)) 1264 ((T_FN 35) (T_FUNCTION 127) (fn 2394) #'2395 (inline_function 2730)) 1265 (("$" 2332) (T_STRING 2739) (T_VARIABLE 2379) (property_name 2746) (simple_variable 2741) ("{" 2742)) 1266 (("$" 2332) (T_STRING 2739) (T_VARIABLE 2379) (property_name 2740) (simple_variable 2741) ("{" 2742)) 1267 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 2737) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 1268 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 2735) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1269 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 2736)) 1270 (("]" 2738)) 1271 (("(" 2603) (argument_list 2745)) 1272 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 2743) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1273 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 2744)) 1274 (("(" 2603) (argument_list 2747)) 1275 (("$" 2748) (T_VARIABLE 2750) (simple_variable 2796) ("{" 2797)) 1276 (("(" 2764) (argument_list 2795)) 1277 ((T_NULLSAFE_OBJECT_OPERATOR 2778) (T_OBJECT_OPERATOR 2779) ("[" 2780) ("{" 2781)) 1278 (("(" 2764) (argument_list 2777)) 1279 ((T_PAAMAYIM_NEKUDOTAYIM 2773)) 1280 (("(" 2764) (argument_list 2772)) 1281 ((T_PAAMAYIM_NEKUDOTAYIM 2761)) 1282 (("$" 2748) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 2750) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 2762) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 2763) ("{" 1627)) 1283 (("(" 2764) (argument_list 2765)) 1284 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 2766) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 2767) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 2768) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 1285 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 2771) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 1286 (("," 1469) (possible_comma 2769)) 1287 ((")" 2770)) 1288 (("$" 2748) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 2750) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 2774) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 2775) ("{" 1643)) 1289 (("(" 2764) (argument_list 2776)) 1290 (("$" 2748) (T_STRING 2786) (T_VARIABLE 2750) (property_name 2793) (simple_variable 2788) ("{" 2789)) 1291 (("$" 2748) (T_STRING 2786) (T_VARIABLE 2750) (property_name 2787) (simple_variable 2788) ("{" 2789)) 1292 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 2784) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 1293 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 2782) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1294 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 2783)) 1295 (("]" 2785)) 1296 (("(" 2764) (argument_list 2792)) 1297 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 2790) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1298 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 2791)) 1299 (("(" 2764) (argument_list 2794)) 1300 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 2798) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1301 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 2799)) 1302 (("\"" 1509) ("$" 2831) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 2832) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 2833) ("[" 1529) (array_object_dereferenceable 2834) (callable_expr 2835) (callable_variable 2836) (class_constant 1533) (class_name 2837) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 2838) (name 2839) (simple_variable 2840) (static_member 2841) (variable 2842) (variable_class_name 2843)) 1303 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_STRING_VARNAME 2823) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 2824) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1304 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_VARIABLE 2803) (encaps_var 2822)) 1305 ((T_NULLSAFE_OBJECT_OPERATOR 2810) (T_OBJECT_OPERATOR 2811) ("[" 2812)) 1306 (("`" 2809)) 1307 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2807) (T_VARIABLE 2803) (encaps_var 2808)) 1308 ((T_STRING 2821)) 1309 ((T_STRING 2820)) 1310 (("-" 2813) (T_NUM_STRING 2814) (T_STRING 2815) (T_VARIABLE 2816) (encaps_var_offset 2817)) 1311 ((T_NUM_STRING 2819)) 1312 (("]" 2818)) 1313 (("[" 2826) ("}" 2827)) 1314 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 2825)) 1315 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 2828) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 1316 (("%" 577) ("*" 578) ("+" 579) ("-" 580) ("." 581) ("/" 582) ("<" 583) (">" 584) ("?" 585) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 586) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 587) (T_BOOLEAN_AND 588) (T_BOOLEAN_OR 589) (T_COALESCE 590) (T_INSTANCEOF 591) (T_IS_EQUAL 592) (T_IS_GREATER_OR_EQUAL 593) (T_IS_IDENTICAL 594) (T_IS_NOT_EQUAL 595) (T_IS_NOT_IDENTICAL 596) (T_IS_SMALLER_OR_EQUAL 597) (T_LOGICAL_AND 598) (T_LOGICAL_OR 599) (T_LOGICAL_XOR 600) (T_POW 601) (T_SL 602) (T_SPACESHIP 603) (T_SR 604) ("]" 2829) ("^" 605) ("|" 606)) 1317 (("}" 2830)) 1318 (("$" 2831) (T_VARIABLE 2833) (simple_variable 2880) ("{" 2881)) 1319 (("(" 2847) (argument_list 2879)) 1320 ((T_NULLSAFE_OBJECT_OPERATOR 2862) (T_OBJECT_OPERATOR 2863) ("[" 2864) ("{" 2865)) 1321 (("(" 2847) (argument_list 2861)) 1322 ((T_PAAMAYIM_NEKUDOTAYIM 2857)) 1323 (("(" 2847) (argument_list 2856)) 1324 (("}" 2855)) 1325 ((T_PAAMAYIM_NEKUDOTAYIM 2844)) 1326 (("$" 2831) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 2833) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 2845) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 2846) ("{" 1627)) 1327 (("(" 2847) (argument_list 2848)) 1328 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 2849) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 2850) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 2851) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 1329 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 2854) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 1330 (("," 1469) (possible_comma 2852)) 1331 ((")" 2853)) 1332 (("$" 2831) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 2833) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 2858) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 2859) ("{" 1643)) 1333 (("(" 2847) (argument_list 2860)) 1334 (("$" 2831) (T_STRING 2870) (T_VARIABLE 2833) (property_name 2877) (simple_variable 2872) ("{" 2873)) 1335 (("$" 2831) (T_STRING 2870) (T_VARIABLE 2833) (property_name 2871) (simple_variable 2872) ("{" 2873)) 1336 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 2868) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 1337 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 2866) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1338 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 2867)) 1339 (("]" 2869)) 1340 (("(" 2847) (argument_list 2876)) 1341 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 2874) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1342 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 2875)) 1343 (("(" 2847) (argument_list 2878)) 1344 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 2882) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1345 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 2883)) 1346 (("]" 2885)) 1347 (("=" 2886)) 1348 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2887) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1349 (("%" 1937) ("*" 1938) ("+" 1939) ("-" 1940) ("." 1941) ("/" 1942) ("<" 1943) (">" 1944) ("?" 1945) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1946) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1947) (T_BOOLEAN_AND 1948) (T_BOOLEAN_OR 1949) (T_COALESCE 1950) (T_DOUBLE_ARROW 2890) (T_INSTANCEOF 1951) (T_IS_EQUAL 1952) (T_IS_GREATER_OR_EQUAL 1953) (T_IS_IDENTICAL 1954) (T_IS_NOT_EQUAL 1955) (T_IS_NOT_IDENTICAL 1956) (T_IS_SMALLER_OR_EQUAL 1957) (T_LOGICAL_AND 1958) (T_LOGICAL_OR 1959) (T_LOGICAL_XOR 1960) (T_POW 1961) (T_SL 1962) (T_SPACESHIP 1963) (T_SR 1964) ("^" 1965) ("|" 1966)) 1350 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 2891) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 1351 (("\"" 1509) ("$" 2831) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 2832) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 2833) ("[" 1529) (array_object_dereferenceable 2834) (callable_expr 2835) (callable_variable 2836) (class_constant 1533) (class_name 2837) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 2838) (name 2839) (simple_variable 2840) (static_member 2841) (variable 2923) (variable_class_name 2843)) 1352 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_STRING_VARNAME 2915) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 2916) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1353 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 2913) (T_VARIABLE 2900) (encaps_var 2914)) 1354 ((T_NULLSAFE_OBJECT_OPERATOR 2906) (T_OBJECT_OPERATOR 2907) ("[" 2908)) 1355 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 2904) (T_VARIABLE 2900) (encaps_var 2905)) 1356 ((T_STRING 2912)) 1357 ((T_STRING 2911)) 1358 (("-" 2813) (T_NUM_STRING 2814) (T_STRING 2815) (T_VARIABLE 2816) (encaps_var_offset 2909)) 1359 (("]" 2910)) 1360 (("[" 2918) ("}" 2919)) 1361 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 2917)) 1362 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 2920) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 1363 (("%" 577) ("*" 578) ("+" 579) ("-" 580) ("." 581) ("/" 582) ("<" 583) (">" 584) ("?" 585) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 586) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 587) (T_BOOLEAN_AND 588) (T_BOOLEAN_OR 589) (T_COALESCE 590) (T_INSTANCEOF 591) (T_IS_EQUAL 592) (T_IS_GREATER_OR_EQUAL 593) (T_IS_IDENTICAL 594) (T_IS_NOT_EQUAL 595) (T_IS_NOT_IDENTICAL 596) (T_IS_SMALLER_OR_EQUAL 597) (T_LOGICAL_AND 598) (T_LOGICAL_OR 599) (T_LOGICAL_XOR 600) (T_POW 601) (T_SL 602) (T_SPACESHIP 603) (T_SR 604) ("]" 2921) ("^" 605) ("|" 606)) 1364 (("}" 2922)) 1365 (("}" 2924)) 1366 (("$" 2930) (T_VARIABLE 2939) (simple_variable 6616) ("{" 6617)) 1367 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 6614) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 1368 ((T_NAME_FULLY_QUALIFIED 6566) (T_NAME_QUALIFIED 6567) (T_NAME_RELATIVE 6568) (T_STATIC 6569) (T_STRING 6570) (attribute_decl 6571) (attribute_group 6611) (class_name 6573) (name 6574)) 1369 ((T_ABSTRACT 10) (T_FINAL 34) (T_READONLY 2936) (class_modifier 6610)) 1370 ((T_CLASS 2981)) 1371 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 2979) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 2942) (attribute 2980) (class_modifier 2945)) 1372 ((T_PAAMAYIM_NEKUDOTAYIM 2977)) 1373 (("(" 2968) (argument_list 2969) (ctor_arguments 2970)) 1374 ((T_NULLSAFE_OBJECT_OPERATOR 2951) (T_OBJECT_OPERATOR 2952) (T_PAAMAYIM_NEKUDOTAYIM 2953) ("[" 2954) ("{" 2955)) 1375 (("$" 2930) (T_STRING 2961) (T_VARIABLE 2939) (property_name 2967) (simple_variable 2963) ("{" 2964)) 1376 (("$" 2930) (T_STRING 2961) (T_VARIABLE 2939) (property_name 2962) (simple_variable 2963) ("{" 2964)) 1377 (("$" 2930) (T_VARIABLE 2939) (simple_variable 2960)) 1378 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 2958) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 1379 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 2956) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1380 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 2957)) 1381 (("]" 2959)) 1382 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 2965) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1383 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 2966)) 1384 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 2971) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 2972) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 2973) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 1385 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 2976) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 1386 (("," 1469) (possible_comma 2974)) 1387 ((")" 2975)) 1388 (("$" 2930) (T_VARIABLE 2939) (simple_variable 2978)) 1389 (("(" 2982) (argument_list 2983) (ctor_arguments 2984)) 1390 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 6604) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 6605) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 6606) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 1391 ((T_EXTENDS 2985) (extends_from 2986)) 1392 ((T_NAME_FULLY_QUALIFIED 6597) (T_NAME_QUALIFIED 6598) (T_NAME_RELATIVE 6599) (T_STATIC 6600) (T_STRING 6601) (class_name 6602) (name 6603)) 1393 ((T_IMPLEMENTS 2987) (implements_list 2988)) 1394 ((T_NAME_FULLY_QUALIFIED 6587) (T_NAME_QUALIFIED 6588) (T_NAME_RELATIVE 6589) (T_STATIC 6590) (T_STRING 6591) (class_name 6592) (class_name_list 6593) (name 6594)) 1395 ((backup_doc_comment 2989)) 1396 (("{" 2990)) 1397 ((class_statement_list 2991)) 1398 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 3013)) 1399 ((T_NAME_FULLY_QUALIFIED 6566) (T_NAME_QUALIFIED 6567) (T_NAME_RELATIVE 6568) (T_STATIC 6569) (T_STRING 6570) (attribute_decl 6571) (attribute_group 6572) (class_name 6573) (name 6574)) 1400 ((backup_doc_comment 6379)) 1401 ((T_NAME_FULLY_QUALIFIED 6084) (T_NAME_QUALIFIED 6085) (T_NAME_RELATIVE 6086) (T_STATIC 6087) (T_STRING 6088) (class_name 6089) (class_name_list 6090) (name 6091)) 1402 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_VAR 3002) (attribute 6082) (attributed_class_statement 6083) (class_const_modifiers 3006) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012)) 1403 ((T_CONST 5933)) 1404 ((T_FUNCTION 5778) #'5779) 1405 ((T_ABSTRACT 2992) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (member_modifier 5777)) 1406 (("(" 3014) ("?" 3015) (T_ARRAY 3016) (T_CALLABLE 3017) (T_NAME_FULLY_QUALIFIED 3018) (T_NAME_QUALIFIED 3019) (T_NAME_RELATIVE 3020) (T_STRING 3021) (intersection_type_without_static 3022) (name 3023) (optional_type_without_static 3024) (type_expr_without_static 3025) (type_without_static 3026) (union_type_without_static 3027) (union_type_without_static_element 3028)) 1407 ((T_ARRAY 2277) (T_CALLABLE 2278) (T_NAME_FULLY_QUALIFIED 2279) (T_NAME_QUALIFIED 2280) (T_NAME_RELATIVE 2281) (T_STRING 2283) (intersection_type_without_static 5775) (name 2285) (type_without_static 3041)) 1408 ((T_ARRAY 5767) (T_CALLABLE 5768) (T_NAME_FULLY_QUALIFIED 5769) (T_NAME_QUALIFIED 5770) (T_NAME_RELATIVE 5771) (T_STRING 5772) (name 5773) (type_without_static 5774)) 1409 ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 5765)) 1410 ((T_VARIABLE 3058) (property 3059) (property_list 3060)) 1411 ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 3049)) 1412 (("|" 3047)) 1413 (("|" 3029)) 1414 (("(" 3030) (T_ARRAY 3031) (T_CALLABLE 3032) (T_NAME_FULLY_QUALIFIED 3033) (T_NAME_QUALIFIED 3034) (T_NAME_RELATIVE 3035) (T_STRING 3036) (name 3037) (type_without_static 3038) (union_type_without_static_element 3039)) 1415 ((T_ARRAY 2277) (T_CALLABLE 2278) (T_NAME_FULLY_QUALIFIED 2279) (T_NAME_QUALIFIED 2280) (T_NAME_RELATIVE 2281) (T_STRING 2283) (intersection_type_without_static 3040) (name 2285) (type_without_static 3041)) 1416 ((")" 3044) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 3045)) 1417 ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 3042)) 1418 ((T_ARRAY 2289) (T_CALLABLE 2290) (T_NAME_FULLY_QUALIFIED 2291) (T_NAME_QUALIFIED 2292) (T_NAME_RELATIVE 2293) (T_STRING 2295) (name 2296) (type_without_static 3043)) 1419 ((T_ARRAY 2289) (T_CALLABLE 2290) (T_NAME_FULLY_QUALIFIED 2291) (T_NAME_QUALIFIED 2292) (T_NAME_RELATIVE 2293) (T_STRING 2295) (name 2296) (type_without_static 3046)) 1420 (("(" 3030) (T_ARRAY 3031) (T_CALLABLE 3032) (T_NAME_FULLY_QUALIFIED 3033) (T_NAME_QUALIFIED 3034) (T_NAME_RELATIVE 3035) (T_STRING 3036) (name 3037) (type_without_static 3038) (union_type_without_static_element 3048)) 1421 ((T_ARRAY 3050) (T_CALLABLE 3051) (T_NAME_FULLY_QUALIFIED 3052) (T_NAME_QUALIFIED 3053) (T_NAME_RELATIVE 3054) (T_STRING 3055) (name 3056) (type_without_static 3057)) 1422 (("=" 3064) (backup_doc_comment 3065)) 1423 (("," 3061) (";" 3062)) 1424 ((T_VARIABLE 3058) (property 3063)) 1425 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3128) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1426 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 5764) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1427 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 5762) (encaps_var 5299)) 1428 (("$" 3068) (T_VARIABLE 3115) (simple_variable 5758) ("{" 5759)) 1429 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5756) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 1430 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 5755) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1431 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 5754) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1432 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 5753) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1433 (("(" 5750)) 1434 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 5749) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1435 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 5748) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1436 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 5747) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1437 (("\"" 1509) ("$" 3371) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 3372) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 3373) ("[" 1529) (array_object_dereferenceable 3374) (callable_expr 3375) (callable_variable 3376) (class_constant 1533) (class_name 3377) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 3378) (name 3379) (simple_variable 3380) (static_member 3381) (variable 5746) (variable_class_name 3383)) 1438 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 5745) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1439 (("(" 5742)) 1440 (("(" 5739)) 1441 (("(" 5735) (exit_expr 5736)) 1442 (("\"" 1509) ("$" 3371) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 3372) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 3373) ("[" 1529) (array_object_dereferenceable 3374) (callable_expr 3375) (callable_variable 3376) (class_constant 1533) (class_name 3377) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 3378) (name 3379) (simple_variable 3380) (static_member 3381) (variable 5734) (variable_class_name 3383)) 1443 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 5733) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1444 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 5732) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1445 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 5731) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1446 (("(" 5727)) 1447 (("(" 5722)) 1448 (("(" 5716)) 1449 (("$" 3371) ("(" 5668) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 5669) (T_NAME_QUALIFIED 5670) (T_NAME_RELATIVE 5671) (T_READONLY 2936) (T_STATIC 5672) (T_STRING 5673) (T_VARIABLE 3373) (anonymous_class 5674) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 5675) (attribute 2943) (attributes 5676) (class_modifier 2945) (class_name 5677) (class_name_reference 5678) (name 5679) (new_variable 5680) (simple_variable 5681)) 1450 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 5667) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1451 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 5666) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1452 (("(" 3332) (argument_list 5665)) 1453 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 5664) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1454 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 5663) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1455 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 5658) (T_END_HEREDOC 5659) (T_VARIABLE 2900) (encaps_list 5660) (encaps_var 2902)) 1456 ((T_FN 35) (T_FUNCTION 127) (fn 3129) #'3130 (inline_function 5657)) 1457 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 5656) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1458 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 5655) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1459 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 5654) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1460 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3546) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1461 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3483) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1462 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 3479) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 1463 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 3477) (encaps_list 2805) (encaps_var 2806)) 1464 ((T_NULLSAFE_OBJECT_OPERATOR 3460) (T_OBJECT_OPERATOR 3461) ("[" 3462) ("{" 3463)) 1465 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 3457) (attribute 2728) (fn 3129) #'3130 (inline_function 3458)) 1466 (("(" 3332) (argument_list 3456)) 1467 ((T_PAAMAYIM_NEKUDOTAYIM 3448)) 1468 (("%" 3144) ("*" 3145) ("+" 3146) ("-" 3147) ("." 3148) ("/" 3149) ("<" 3150) (">" 3151) ("?" 3152) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 3153) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 3154) (T_BOOLEAN_AND 3155) (T_BOOLEAN_OR 3156) (T_COALESCE 3157) (T_INSTANCEOF 3158) (T_IS_EQUAL 3159) (T_IS_GREATER_OR_EQUAL 3160) (T_IS_IDENTICAL 3161) (T_IS_NOT_EQUAL 3162) (T_IS_NOT_IDENTICAL 3163) (T_IS_SMALLER_OR_EQUAL 3164) (T_LOGICAL_AND 3165) (T_LOGICAL_OR 3166) (T_LOGICAL_XOR 3167) (T_POW 3168) (T_SL 3169) (T_SPACESHIP 3170) (T_SR 3171) ("^" 3172) (backup_doc_comment 3447) ("|" 3173)) 1469 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 3436)) 1470 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 3424)) 1471 (("(" 3332) (argument_list 3423)) 1472 (("=" 3340) (T_AND_EQUAL 3341) (T_COALESCE_EQUAL 3342) (T_CONCAT_EQUAL 3343) (T_DEC 3344) (T_DIV_EQUAL 3345) (T_INC 3346) (T_MINUS_EQUAL 3347) (T_MOD_EQUAL 3348) (T_MUL_EQUAL 3349) (T_OR_EQUAL 3350) (T_PLUS_EQUAL 3351) (T_POW_EQUAL 3352) (T_SL_EQUAL 3353) (T_SR_EQUAL 3354) (T_XOR_EQUAL 3355)) 1473 ((T_PAAMAYIM_NEKUDOTAYIM 3245)) 1474 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3143) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1475 (("%" 3144) ("*" 3145) ("+" 3146) ("-" 3147) ("." 3148) ("/" 3149) ("<" 3150) (">" 3151) ("?" 3152) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 3153) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 3154) (T_BOOLEAN_AND 3155) (T_BOOLEAN_OR 3156) (T_COALESCE 3157) (T_INSTANCEOF 3158) (T_IS_EQUAL 3159) (T_IS_GREATER_OR_EQUAL 3160) (T_IS_IDENTICAL 3161) (T_IS_NOT_EQUAL 3162) (T_IS_NOT_IDENTICAL 3163) (T_IS_SMALLER_OR_EQUAL 3164) (T_LOGICAL_AND 3165) (T_LOGICAL_OR 3166) (T_LOGICAL_XOR 3167) (T_POW 3168) (T_SL 3169) (T_SPACESHIP 3170) (T_SR 3171) ("^" 3172) ("|" 3173)) 1476 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3244) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1477 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3243) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1478 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3242) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1479 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3241) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1480 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3240) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1481 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3239) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1482 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3238) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1483 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3237) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1484 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 3232) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 3233) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 1485 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3231) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1486 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3230) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1487 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3229) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1488 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3228) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1489 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3227) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1490 (("$" 3189) ("(" 3190) (T_NAME_FULLY_QUALIFIED 3191) (T_NAME_QUALIFIED 3192) (T_NAME_RELATIVE 3193) (T_STATIC 3194) (T_STRING 3195) (T_VARIABLE 3196) (class_name 3197) (class_name_reference 3198) (name 3199) (new_variable 3200) (simple_variable 3201)) 1491 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3188) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1492 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3187) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1493 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3186) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1494 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3185) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1495 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3184) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1496 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3183) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1497 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3182) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1498 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3181) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1499 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3180) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1500 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3179) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1501 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3178) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1502 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3177) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1503 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3176) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1504 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3175) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1505 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3174) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1506 (("$" 3189) (T_VARIABLE 3196) (simple_variable 3223) ("{" 3224)) 1507 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 3221) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 1508 ((T_PAAMAYIM_NEKUDOTAYIM 3219)) 1509 ((T_NULLSAFE_OBJECT_OPERATOR 3202) (T_OBJECT_OPERATOR 3203) (T_PAAMAYIM_NEKUDOTAYIM 3204) ("[" 3205) ("{" 3206)) 1510 (("$" 3189) (T_STRING 3212) (T_VARIABLE 3196) (property_name 3218) (simple_variable 3214) ("{" 3215)) 1511 (("$" 3189) (T_STRING 3212) (T_VARIABLE 3196) (property_name 3213) (simple_variable 3214) ("{" 3215)) 1512 (("$" 3189) (T_VARIABLE 3196) (simple_variable 3211)) 1513 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 3209) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 1514 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 3207) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1515 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 3208)) 1516 (("]" 3210)) 1517 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 3216) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1518 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 3217)) 1519 (("$" 3189) (T_VARIABLE 3196) (simple_variable 3220)) 1520 (("%" 292) (")" 3222) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 1521 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 3225) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1522 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 3226)) 1523 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3236) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1524 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 3234) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 1525 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3235) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1526 (("$" 3068) (T_ABSTRACT 3246) (T_ARRAY 3247) (T_AS 3248) (T_BREAK 3249) (T_CALLABLE 3250) (T_CASE 3251) (T_CATCH 3252) (T_CLASS 3253) (T_CLASS_C 3254) (T_CLONE 3255) (T_CONST 3256) (T_CONTINUE 3257) (T_DECLARE 3258) (T_DEFAULT 3259) (T_DIR 3260) (T_DO 3261) (T_ECHO 3262) (T_ELSE 3263) (T_ELSEIF 3264) (T_EMPTY 3265) (T_ENDDECLARE 3266) (T_ENDFOR 3267) (T_ENDFOREACH 3268) (T_ENDIF 3269) (T_ENDSWITCH 3270) (T_ENDWHILE 3271) (T_ENUM 3272) (T_EVAL 3273) (T_EXIT 3274) (T_EXTENDS 3275) (T_FILE 3276) (T_FINAL 3277) (T_FINALLY 3278) (T_FN 3279) (T_FOR 3280) (T_FOREACH 3281) (T_FUNCTION 3282) (T_FUNC_C 3283) (T_GLOBAL 3284) (T_GOTO 3285) (T_IF 3286) (T_IMPLEMENTS 3287) (T_INCLUDE 3288) (T_INCLUDE_ONCE 3289) (T_INSTANCEOF 3290) (T_INSTEADOF 3291) (T_INTERFACE 3292) (T_ISSET 3293) (T_LINE 3294) (T_LIST 3295) (T_LOGICAL_AND 3296) (T_LOGICAL_OR 3297) (T_LOGICAL_XOR 3298) (T_MATCH 3299) (T_METHOD_C 3300) (T_NAMESPACE 3301) (T_NEW 3302) (T_NS_C 3303) (T_PRINT 3304) (T_PRIVATE 3305) (T_PROTECTED 3306) (T_PUBLIC 3307) (T_READONLY 3308) (T_REQUIRE 3309) (T_REQUIRE_ONCE 3310) (T_RETURN 3311) (T_STATIC 3312) (T_STRING 3313) (T_SWITCH 3314) (T_THROW 3315) (T_TRAIT 3316) (T_TRAIT_C 3317) (T_TRY 3318) (T_UNSET 3319) (T_USE 3320) (T_VAR 3321) (T_VARIABLE 3115) (T_WHILE 3322) (T_YIELD 3323) (identifier 3324) (member_name 3325) (reserved_non_modifiers 3326) (semi_reserved 3327) (simple_variable 3328) ("{" 3329)) 1527 (("(" 3332) (argument_list 3333)) 1528 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 3330) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1529 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 3331)) 1530 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 3334) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 3335) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 3336) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 1531 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 3339) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 1532 (("," 1469) (possible_comma 3337)) 1533 ((")" 3338)) 1534 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (ampersand 3369) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3370) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1535 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3368) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1536 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3367) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1537 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3366) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1538 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3365) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1539 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3364) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1540 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3363) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1541 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3362) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1542 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3361) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1543 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3360) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1544 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3359) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1545 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3358) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1546 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3357) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1547 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3356) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1548 (("\"" 1509) ("$" 3371) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 3372) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 3373) ("[" 1529) (array_object_dereferenceable 3374) (callable_expr 3375) (callable_variable 3376) (class_constant 1533) (class_name 3377) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 3378) (name 3379) (simple_variable 3380) (static_member 3381) (variable 3382) (variable_class_name 3383)) 1549 (("$" 3371) (T_VARIABLE 3373) (simple_variable 3419) ("{" 3420)) 1550 (("(" 3387) (argument_list 3418)) 1551 ((T_NULLSAFE_OBJECT_OPERATOR 3401) (T_OBJECT_OPERATOR 3402) ("[" 3403) ("{" 3404)) 1552 (("(" 3387) (argument_list 3400)) 1553 ((T_PAAMAYIM_NEKUDOTAYIM 3396)) 1554 (("(" 3387) (argument_list 3395)) 1555 ((T_PAAMAYIM_NEKUDOTAYIM 3384)) 1556 (("$" 3371) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 3373) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 3385) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 3386) ("{" 1627)) 1557 (("(" 3387) (argument_list 3388)) 1558 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 3389) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 3390) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 3391) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 1559 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 3394) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 1560 (("," 1469) (possible_comma 3392)) 1561 ((")" 3393)) 1562 (("$" 3371) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 3373) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 3397) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 3398) ("{" 1643)) 1563 (("(" 3387) (argument_list 3399)) 1564 (("$" 3371) (T_STRING 3409) (T_VARIABLE 3373) (property_name 3416) (simple_variable 3411) ("{" 3412)) 1565 (("$" 3371) (T_STRING 3409) (T_VARIABLE 3373) (property_name 3410) (simple_variable 3411) ("{" 3412)) 1566 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 3407) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 1567 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 3405) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1568 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 3406)) 1569 (("]" 3408)) 1570 (("(" 3387) (argument_list 3415)) 1571 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 3413) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1572 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 3414)) 1573 (("(" 3387) (argument_list 3417)) 1574 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 3421) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1575 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 3422)) 1576 ((backup_doc_comment 3425)) 1577 (("(" 3426)) 1578 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 3427)) 1579 ((")" 3428)) 1580 ((T_USE 159) (lexical_vars 3429)) 1581 ((":" 161) (return_type 3430)) 1582 ((backup_fn_flags 3431)) 1583 (("{" 3432)) 1584 ((inner_statement_list 3433)) 1585 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 3434) ("~" 125)) 1586 ((backup_fn_flags 3435)) 1587 ((backup_doc_comment 3437)) 1588 (("(" 3438)) 1589 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 3439)) 1590 ((")" 3440)) 1591 ((":" 2241) (return_type 3441)) 1592 ((T_DOUBLE_ARROW 3442)) 1593 ((backup_fn_flags 3443)) 1594 ((backup_lex_pos 3444)) 1595 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3445) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1596 (("%" 3144) ("*" 3145) ("+" 3146) ("-" 3147) ("." 3148) ("/" 3149) ("<" 3150) (">" 3151) ("?" 3152) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 3153) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 3154) (T_BOOLEAN_AND 3155) (T_BOOLEAN_OR 3156) (T_COALESCE 3157) (T_INSTANCEOF 3158) (T_IS_EQUAL 3159) (T_IS_GREATER_OR_EQUAL 3160) (T_IS_IDENTICAL 3161) (T_IS_NOT_EQUAL 3162) (T_IS_NOT_IDENTICAL 3163) (T_IS_SMALLER_OR_EQUAL 3164) (T_LOGICAL_AND 3165) (T_LOGICAL_OR 3166) (T_LOGICAL_XOR 3167) (T_POW 3168) (T_SL 3169) (T_SPACESHIP 3170) (T_SR 3171) ("^" 3172) (backup_fn_flags 3446) ("|" 3173)) 1597 (("$" 3068) (T_ABSTRACT 3246) (T_ARRAY 3247) (T_AS 3248) (T_BREAK 3249) (T_CALLABLE 3250) (T_CASE 3251) (T_CATCH 3252) (T_CLASS 3253) (T_CLASS_C 3254) (T_CLONE 3255) (T_CONST 3256) (T_CONTINUE 3257) (T_DECLARE 3258) (T_DEFAULT 3259) (T_DIR 3260) (T_DO 3261) (T_ECHO 3262) (T_ELSE 3263) (T_ELSEIF 3264) (T_EMPTY 3265) (T_ENDDECLARE 3266) (T_ENDFOR 3267) (T_ENDFOREACH 3268) (T_ENDIF 3269) (T_ENDSWITCH 3270) (T_ENDWHILE 3271) (T_ENUM 3272) (T_EVAL 3273) (T_EXIT 3274) (T_EXTENDS 3275) (T_FILE 3276) (T_FINAL 3277) (T_FINALLY 3278) (T_FN 3279) (T_FOR 3280) (T_FOREACH 3281) (T_FUNCTION 3282) (T_FUNC_C 3283) (T_GLOBAL 3284) (T_GOTO 3285) (T_IF 3286) (T_IMPLEMENTS 3287) (T_INCLUDE 3288) (T_INCLUDE_ONCE 3289) (T_INSTANCEOF 3290) (T_INSTEADOF 3291) (T_INTERFACE 3292) (T_ISSET 3293) (T_LINE 3294) (T_LIST 3295) (T_LOGICAL_AND 3296) (T_LOGICAL_OR 3297) (T_LOGICAL_XOR 3298) (T_MATCH 3299) (T_METHOD_C 3300) (T_NAMESPACE 3301) (T_NEW 3302) (T_NS_C 3303) (T_PRINT 3304) (T_PRIVATE 3305) (T_PROTECTED 3306) (T_PUBLIC 3307) (T_READONLY 3308) (T_REQUIRE 3309) (T_REQUIRE_ONCE 3310) (T_RETURN 3311) (T_STATIC 3312) (T_STRING 3313) (T_SWITCH 3314) (T_THROW 3315) (T_TRAIT 3316) (T_TRAIT_C 3317) (T_TRY 3318) (T_UNSET 3319) (T_USE 3320) (T_VAR 3321) (T_VARIABLE 3115) (T_WHILE 3322) (T_YIELD 3323) (identifier 3449) (member_name 3450) (reserved_non_modifiers 3326) (semi_reserved 3327) (simple_variable 3451) ("{" 3452)) 1598 (("(" 3332) (argument_list 3455)) 1599 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 3453) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1600 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 3454)) 1601 ((T_FN 35) (T_FUNCTION 127) (fn 3129) #'3130 (inline_function 3459)) 1602 (("$" 3068) (T_STRING 3468) (T_VARIABLE 3115) (property_name 3475) (simple_variable 3470) ("{" 3471)) 1603 (("$" 3068) (T_STRING 3468) (T_VARIABLE 3115) (property_name 3469) (simple_variable 3470) ("{" 3471)) 1604 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 3466) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 1605 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 3464) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1606 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 3465)) 1607 (("]" 3467)) 1608 (("(" 3332) (argument_list 3474)) 1609 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 3472) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1610 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 3473)) 1611 (("(" 3332) (argument_list 3476)) 1612 (("`" 3478)) 1613 (("]" 3480)) 1614 (("=" 3481)) 1615 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3482) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1616 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 5653) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1617 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 5651) (encaps_var 5299)) 1618 (("$" 3486) (T_VARIABLE 3533) (simple_variable 5647) ("{" 5648)) 1619 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5645) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 1620 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 5644) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1621 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 5643) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1622 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 5642) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1623 (("(" 5639)) 1624 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 5638) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1625 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 5637) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1626 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 5636) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1627 (("\"" 1509) ("$" 3789) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 3790) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 3791) ("[" 1529) (array_object_dereferenceable 3792) (callable_expr 3793) (callable_variable 3794) (class_constant 1533) (class_name 3795) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 3796) (name 3797) (simple_variable 3798) (static_member 3799) (variable 5635) (variable_class_name 3801)) 1628 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 5634) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1629 (("(" 5631)) 1630 (("(" 5628)) 1631 (("(" 5624) (exit_expr 5625)) 1632 (("\"" 1509) ("$" 3789) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 3790) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 3791) ("[" 1529) (array_object_dereferenceable 3792) (callable_expr 3793) (callable_variable 3794) (class_constant 1533) (class_name 3795) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 3796) (name 3797) (simple_variable 3798) (static_member 3799) (variable 5623) (variable_class_name 3801)) 1633 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 5622) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1634 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 5621) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1635 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 5620) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1636 (("(" 5616)) 1637 (("(" 5611)) 1638 (("(" 3968)) 1639 (("$" 3789) ("(" 3920) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 3921) (T_NAME_QUALIFIED 3922) (T_NAME_RELATIVE 3923) (T_READONLY 2936) (T_STATIC 3924) (T_STRING 3925) (T_VARIABLE 3791) (anonymous_class 3926) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 3927) (attribute 2943) (attributes 3928) (class_modifier 2945) (class_name 3929) (class_name_reference 3930) (name 3931) (new_variable 3932) (simple_variable 3933)) 1640 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3919) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1641 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3918) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1642 (("(" 3750) (argument_list 3917)) 1643 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3916) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1644 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3915) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1645 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 3910) (T_END_HEREDOC 3911) (T_VARIABLE 2900) (encaps_list 3912) (encaps_var 2902)) 1646 ((T_FN 35) (T_FUNCTION 127) (fn 3547) #'3548 (inline_function 3909)) 1647 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3908) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1648 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3907) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1649 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3906) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1650 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3903) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1651 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3902) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1652 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 3898) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 1653 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 3896) (encaps_list 2805) (encaps_var 2806)) 1654 ((T_NULLSAFE_OBJECT_OPERATOR 3879) (T_OBJECT_OPERATOR 3880) ("[" 3881) ("{" 3882)) 1655 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 3876) (attribute 2728) (fn 3547) #'3548 (inline_function 3877)) 1656 (("(" 3750) (argument_list 3875)) 1657 ((T_PAAMAYIM_NEKUDOTAYIM 3867)) 1658 (("%" 3562) ("*" 3563) ("+" 3564) ("-" 3565) ("." 3566) ("/" 3567) ("<" 3568) (">" 3569) ("?" 3570) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 3571) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 3572) (T_BOOLEAN_AND 3573) (T_BOOLEAN_OR 3574) (T_COALESCE 3575) (T_DOUBLE_ARROW 3865) (T_INSTANCEOF 3576) (T_IS_EQUAL 3577) (T_IS_GREATER_OR_EQUAL 3578) (T_IS_IDENTICAL 3579) (T_IS_NOT_EQUAL 3580) (T_IS_NOT_IDENTICAL 3581) (T_IS_SMALLER_OR_EQUAL 3582) (T_LOGICAL_AND 3583) (T_LOGICAL_OR 3584) (T_LOGICAL_XOR 3585) (T_POW 3586) (T_SL 3587) (T_SPACESHIP 3588) (T_SR 3589) ("^" 3590) ("|" 3591)) 1659 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 3854)) 1660 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 3842)) 1661 (("(" 3750) (argument_list 3841)) 1662 (("=" 3758) (T_AND_EQUAL 3759) (T_COALESCE_EQUAL 3760) (T_CONCAT_EQUAL 3761) (T_DEC 3762) (T_DIV_EQUAL 3763) (T_INC 3764) (T_MINUS_EQUAL 3765) (T_MOD_EQUAL 3766) (T_MUL_EQUAL 3767) (T_OR_EQUAL 3768) (T_PLUS_EQUAL 3769) (T_POW_EQUAL 3770) (T_SL_EQUAL 3771) (T_SR_EQUAL 3772) (T_XOR_EQUAL 3773)) 1663 ((T_PAAMAYIM_NEKUDOTAYIM 3663)) 1664 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3561) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1665 (("%" 3562) ("*" 3563) ("+" 3564) ("-" 3565) ("." 3566) ("/" 3567) ("<" 3568) (">" 3569) ("?" 3570) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 3571) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 3572) (T_BOOLEAN_AND 3573) (T_BOOLEAN_OR 3574) (T_COALESCE 3575) (T_INSTANCEOF 3576) (T_IS_EQUAL 3577) (T_IS_GREATER_OR_EQUAL 3578) (T_IS_IDENTICAL 3579) (T_IS_NOT_EQUAL 3580) (T_IS_NOT_IDENTICAL 3581) (T_IS_SMALLER_OR_EQUAL 3582) (T_LOGICAL_AND 3583) (T_LOGICAL_OR 3584) (T_LOGICAL_XOR 3585) (T_POW 3586) (T_SL 3587) (T_SPACESHIP 3588) (T_SR 3589) ("^" 3590) ("|" 3591)) 1666 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3662) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1667 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3661) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1668 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3660) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1669 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3659) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1670 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3658) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1671 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3657) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1672 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3656) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1673 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3655) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1674 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 3650) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 3651) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 1675 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3649) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1676 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3648) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1677 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3647) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1678 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3646) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1679 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3645) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1680 (("$" 3607) ("(" 3608) (T_NAME_FULLY_QUALIFIED 3609) (T_NAME_QUALIFIED 3610) (T_NAME_RELATIVE 3611) (T_STATIC 3612) (T_STRING 3613) (T_VARIABLE 3614) (class_name 3615) (class_name_reference 3616) (name 3617) (new_variable 3618) (simple_variable 3619)) 1681 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3606) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1682 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3605) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1683 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3604) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1684 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3603) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1685 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3602) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1686 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3601) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1687 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3600) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1688 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3599) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1689 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3598) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1690 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3597) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1691 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3596) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1692 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3595) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1693 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3594) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1694 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3593) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1695 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3592) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1696 (("$" 3607) (T_VARIABLE 3614) (simple_variable 3641) ("{" 3642)) 1697 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 3639) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 1698 ((T_PAAMAYIM_NEKUDOTAYIM 3637)) 1699 ((T_NULLSAFE_OBJECT_OPERATOR 3620) (T_OBJECT_OPERATOR 3621) (T_PAAMAYIM_NEKUDOTAYIM 3622) ("[" 3623) ("{" 3624)) 1700 (("$" 3607) (T_STRING 3630) (T_VARIABLE 3614) (property_name 3636) (simple_variable 3632) ("{" 3633)) 1701 (("$" 3607) (T_STRING 3630) (T_VARIABLE 3614) (property_name 3631) (simple_variable 3632) ("{" 3633)) 1702 (("$" 3607) (T_VARIABLE 3614) (simple_variable 3629)) 1703 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 3627) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 1704 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 3625) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1705 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 3626)) 1706 (("]" 3628)) 1707 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 3634) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1708 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 3635)) 1709 (("$" 3607) (T_VARIABLE 3614) (simple_variable 3638)) 1710 (("%" 292) (")" 3640) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 1711 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 3643) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1712 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 3644)) 1713 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3654) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1714 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 3652) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 1715 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3653) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1716 (("$" 3486) (T_ABSTRACT 3664) (T_ARRAY 3665) (T_AS 3666) (T_BREAK 3667) (T_CALLABLE 3668) (T_CASE 3669) (T_CATCH 3670) (T_CLASS 3671) (T_CLASS_C 3672) (T_CLONE 3673) (T_CONST 3674) (T_CONTINUE 3675) (T_DECLARE 3676) (T_DEFAULT 3677) (T_DIR 3678) (T_DO 3679) (T_ECHO 3680) (T_ELSE 3681) (T_ELSEIF 3682) (T_EMPTY 3683) (T_ENDDECLARE 3684) (T_ENDFOR 3685) (T_ENDFOREACH 3686) (T_ENDIF 3687) (T_ENDSWITCH 3688) (T_ENDWHILE 3689) (T_ENUM 3690) (T_EVAL 3691) (T_EXIT 3692) (T_EXTENDS 3693) (T_FILE 3694) (T_FINAL 3695) (T_FINALLY 3696) (T_FN 3697) (T_FOR 3698) (T_FOREACH 3699) (T_FUNCTION 3700) (T_FUNC_C 3701) (T_GLOBAL 3702) (T_GOTO 3703) (T_IF 3704) (T_IMPLEMENTS 3705) (T_INCLUDE 3706) (T_INCLUDE_ONCE 3707) (T_INSTANCEOF 3708) (T_INSTEADOF 3709) (T_INTERFACE 3710) (T_ISSET 3711) (T_LINE 3712) (T_LIST 3713) (T_LOGICAL_AND 3714) (T_LOGICAL_OR 3715) (T_LOGICAL_XOR 3716) (T_MATCH 3717) (T_METHOD_C 3718) (T_NAMESPACE 3719) (T_NEW 3720) (T_NS_C 3721) (T_PRINT 3722) (T_PRIVATE 3723) (T_PROTECTED 3724) (T_PUBLIC 3725) (T_READONLY 3726) (T_REQUIRE 3727) (T_REQUIRE_ONCE 3728) (T_RETURN 3729) (T_STATIC 3730) (T_STRING 3731) (T_SWITCH 3732) (T_THROW 3733) (T_TRAIT 3734) (T_TRAIT_C 3735) (T_TRY 3736) (T_UNSET 3737) (T_USE 3738) (T_VAR 3739) (T_VARIABLE 3533) (T_WHILE 3740) (T_YIELD 3741) (identifier 3742) (member_name 3743) (reserved_non_modifiers 3744) (semi_reserved 3745) (simple_variable 3746) ("{" 3747)) 1717 (("(" 3750) (argument_list 3751)) 1718 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 3748) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1719 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 3749)) 1720 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 3752) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 3753) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 3754) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 1721 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 3757) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 1722 (("," 1469) (possible_comma 3755)) 1723 ((")" 3756)) 1724 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (ampersand 3787) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3788) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1725 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3786) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1726 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3785) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1727 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3784) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1728 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3783) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1729 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3782) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1730 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3781) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1731 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3780) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1732 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3779) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1733 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3778) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1734 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3777) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1735 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3776) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1736 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3775) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1737 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3774) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1738 (("\"" 1509) ("$" 3789) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 3790) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 3791) ("[" 1529) (array_object_dereferenceable 3792) (callable_expr 3793) (callable_variable 3794) (class_constant 1533) (class_name 3795) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 3796) (name 3797) (simple_variable 3798) (static_member 3799) (variable 3800) (variable_class_name 3801)) 1739 (("$" 3789) (T_VARIABLE 3791) (simple_variable 3837) ("{" 3838)) 1740 (("(" 3805) (argument_list 3836)) 1741 ((T_NULLSAFE_OBJECT_OPERATOR 3819) (T_OBJECT_OPERATOR 3820) ("[" 3821) ("{" 3822)) 1742 (("(" 3805) (argument_list 3818)) 1743 ((T_PAAMAYIM_NEKUDOTAYIM 3814)) 1744 (("(" 3805) (argument_list 3813)) 1745 ((T_PAAMAYIM_NEKUDOTAYIM 3802)) 1746 (("$" 3789) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 3791) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 3803) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 3804) ("{" 1627)) 1747 (("(" 3805) (argument_list 3806)) 1748 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 3807) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 3808) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 3809) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 1749 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 3812) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 1750 (("," 1469) (possible_comma 3810)) 1751 ((")" 3811)) 1752 (("$" 3789) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 3791) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 3815) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 3816) ("{" 1643)) 1753 (("(" 3805) (argument_list 3817)) 1754 (("$" 3789) (T_STRING 3827) (T_VARIABLE 3791) (property_name 3834) (simple_variable 3829) ("{" 3830)) 1755 (("$" 3789) (T_STRING 3827) (T_VARIABLE 3791) (property_name 3828) (simple_variable 3829) ("{" 3830)) 1756 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 3825) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 1757 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 3823) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1758 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 3824)) 1759 (("]" 3826)) 1760 (("(" 3805) (argument_list 3833)) 1761 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 3831) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1762 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 3832)) 1763 (("(" 3805) (argument_list 3835)) 1764 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 3839) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1765 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 3840)) 1766 ((backup_doc_comment 3843)) 1767 (("(" 3844)) 1768 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 3845)) 1769 ((")" 3846)) 1770 ((T_USE 159) (lexical_vars 3847)) 1771 ((":" 161) (return_type 3848)) 1772 ((backup_fn_flags 3849)) 1773 (("{" 3850)) 1774 ((inner_statement_list 3851)) 1775 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 3852) ("~" 125)) 1776 ((backup_fn_flags 3853)) 1777 ((backup_doc_comment 3855)) 1778 (("(" 3856)) 1779 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 3857)) 1780 ((")" 3858)) 1781 ((":" 2241) (return_type 3859)) 1782 ((T_DOUBLE_ARROW 3860)) 1783 ((backup_fn_flags 3861)) 1784 ((backup_lex_pos 3862)) 1785 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3863) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1786 (("%" 3562) ("*" 3563) ("+" 3564) ("-" 3565) ("." 3566) ("/" 3567) ("<" 3568) (">" 3569) ("?" 3570) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 3571) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 3572) (T_BOOLEAN_AND 3573) (T_BOOLEAN_OR 3574) (T_COALESCE 3575) (T_INSTANCEOF 3576) (T_IS_EQUAL 3577) (T_IS_GREATER_OR_EQUAL 3578) (T_IS_IDENTICAL 3579) (T_IS_NOT_EQUAL 3580) (T_IS_NOT_IDENTICAL 3581) (T_IS_SMALLER_OR_EQUAL 3582) (T_LOGICAL_AND 3583) (T_LOGICAL_OR 3584) (T_LOGICAL_XOR 3585) (T_POW 3586) (T_SL 3587) (T_SPACESHIP 3588) (T_SR 3589) ("^" 3590) (backup_fn_flags 3864) ("|" 3591)) 1787 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 3866) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 1788 (("$" 3486) (T_ABSTRACT 3664) (T_ARRAY 3665) (T_AS 3666) (T_BREAK 3667) (T_CALLABLE 3668) (T_CASE 3669) (T_CATCH 3670) (T_CLASS 3671) (T_CLASS_C 3672) (T_CLONE 3673) (T_CONST 3674) (T_CONTINUE 3675) (T_DECLARE 3676) (T_DEFAULT 3677) (T_DIR 3678) (T_DO 3679) (T_ECHO 3680) (T_ELSE 3681) (T_ELSEIF 3682) (T_EMPTY 3683) (T_ENDDECLARE 3684) (T_ENDFOR 3685) (T_ENDFOREACH 3686) (T_ENDIF 3687) (T_ENDSWITCH 3688) (T_ENDWHILE 3689) (T_ENUM 3690) (T_EVAL 3691) (T_EXIT 3692) (T_EXTENDS 3693) (T_FILE 3694) (T_FINAL 3695) (T_FINALLY 3696) (T_FN 3697) (T_FOR 3698) (T_FOREACH 3699) (T_FUNCTION 3700) (T_FUNC_C 3701) (T_GLOBAL 3702) (T_GOTO 3703) (T_IF 3704) (T_IMPLEMENTS 3705) (T_INCLUDE 3706) (T_INCLUDE_ONCE 3707) (T_INSTANCEOF 3708) (T_INSTEADOF 3709) (T_INTERFACE 3710) (T_ISSET 3711) (T_LINE 3712) (T_LIST 3713) (T_LOGICAL_AND 3714) (T_LOGICAL_OR 3715) (T_LOGICAL_XOR 3716) (T_MATCH 3717) (T_METHOD_C 3718) (T_NAMESPACE 3719) (T_NEW 3720) (T_NS_C 3721) (T_PRINT 3722) (T_PRIVATE 3723) (T_PROTECTED 3724) (T_PUBLIC 3725) (T_READONLY 3726) (T_REQUIRE 3727) (T_REQUIRE_ONCE 3728) (T_RETURN 3729) (T_STATIC 3730) (T_STRING 3731) (T_SWITCH 3732) (T_THROW 3733) (T_TRAIT 3734) (T_TRAIT_C 3735) (T_TRY 3736) (T_UNSET 3737) (T_USE 3738) (T_VAR 3739) (T_VARIABLE 3533) (T_WHILE 3740) (T_YIELD 3741) (identifier 3868) (member_name 3869) (reserved_non_modifiers 3744) (semi_reserved 3745) (simple_variable 3870) ("{" 3871)) 1789 (("(" 3750) (argument_list 3874)) 1790 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 3872) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1791 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 3873)) 1792 ((T_FN 35) (T_FUNCTION 127) (fn 3547) #'3548 (inline_function 3878)) 1793 (("$" 3486) (T_STRING 3887) (T_VARIABLE 3533) (property_name 3894) (simple_variable 3889) ("{" 3890)) 1794 (("$" 3486) (T_STRING 3887) (T_VARIABLE 3533) (property_name 3888) (simple_variable 3889) ("{" 3890)) 1795 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 3885) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 1796 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 3883) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1797 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 3884)) 1798 (("]" 3886)) 1799 (("(" 3750) (argument_list 3893)) 1800 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 3891) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1801 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 3892)) 1802 (("(" 3750) (argument_list 3895)) 1803 (("`" 3897)) 1804 (("]" 3899)) 1805 (("=" 3900)) 1806 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3901) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1807 (("%" 3562) ("*" 3563) ("+" 3564) ("-" 3565) ("." 3566) ("/" 3567) ("<" 3568) (">" 3569) ("?" 3570) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 3571) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 3572) (T_BOOLEAN_AND 3573) (T_BOOLEAN_OR 3574) (T_COALESCE 3575) (T_DOUBLE_ARROW 3904) (T_INSTANCEOF 3576) (T_IS_EQUAL 3577) (T_IS_GREATER_OR_EQUAL 3578) (T_IS_IDENTICAL 3579) (T_IS_NOT_EQUAL 3580) (T_IS_NOT_IDENTICAL 3581) (T_IS_SMALLER_OR_EQUAL 3582) (T_LOGICAL_AND 3583) (T_LOGICAL_OR 3584) (T_LOGICAL_XOR 3585) (T_POW 3586) (T_SL 3587) (T_SPACESHIP 3588) (T_SR 3589) ("^" 3590) ("|" 3591)) 1808 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 3905) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 1809 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 3914) (T_VARIABLE 2900) (encaps_var 2914)) 1810 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 3913) (T_VARIABLE 2900) (encaps_var 2905)) 1811 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 3966) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 1812 ((T_CLASS 3958)) 1813 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 3957) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 3927) (attribute 2980) (class_modifier 2945)) 1814 ((T_PAAMAYIM_NEKUDOTAYIM 3955)) 1815 (("(" 3946) (argument_list 3947) (ctor_arguments 3948)) 1816 ((T_NULLSAFE_OBJECT_OPERATOR 3934) (T_OBJECT_OPERATOR 3935) (T_PAAMAYIM_NEKUDOTAYIM 3936) ("[" 3937) ("{" 3938)) 1817 (("$" 3789) (T_STRING 3827) (T_VARIABLE 3791) (property_name 3945) (simple_variable 3829) ("{" 3830)) 1818 (("$" 3789) (T_STRING 3827) (T_VARIABLE 3791) (property_name 3944) (simple_variable 3829) ("{" 3830)) 1819 (("$" 3789) (T_VARIABLE 3791) (simple_variable 3943)) 1820 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 3941) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 1821 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 3939) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1822 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 3940)) 1823 (("]" 3942)) 1824 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 3949) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 3950) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 3951) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 1825 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 3954) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 1826 (("," 1469) (possible_comma 3952)) 1827 ((")" 3953)) 1828 (("$" 3789) (T_VARIABLE 3791) (simple_variable 3956)) 1829 (("(" 2982) (argument_list 2983) (ctor_arguments 3959)) 1830 ((T_EXTENDS 2985) (extends_from 3960)) 1831 ((T_IMPLEMENTS 2987) (implements_list 3961)) 1832 ((backup_doc_comment 3962)) 1833 (("{" 3963)) 1834 ((class_statement_list 3964)) 1835 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 3965)) 1836 (("%" 292) (")" 3967) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 1837 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 3969) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 1838 (("%" 292) (")" 3970) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 1839 (("{" 3971)) 1840 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 4044) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1841 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 5610) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1842 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 5608) (encaps_var 5299)) 1843 (("$" 3974) (T_VARIABLE 4022) (simple_variable 5604) ("{" 5605)) 1844 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5602) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 1845 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 5601) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1846 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 5600) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1847 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 5599) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1848 (("(" 5596)) 1849 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 5595) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1850 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 5594) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1851 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 5593) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1852 (("\"" 1509) ("$" 4282) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 4283) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 4284) ("[" 1529) (array_object_dereferenceable 4285) (callable_expr 4286) (callable_variable 4287) (class_constant 1533) (class_name 4288) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 4289) (name 4290) (simple_variable 4291) (static_member 4292) (variable 5592) (variable_class_name 4294)) 1853 (("," 5588) (possible_comma 5589)) 1854 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 5587) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1855 (("(" 5584)) 1856 (("(" 5581)) 1857 (("(" 5577) (exit_expr 5578)) 1858 (("\"" 1509) ("$" 4282) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 4283) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 4284) ("[" 1529) (array_object_dereferenceable 4285) (callable_expr 4286) (callable_variable 4287) (class_constant 1533) (class_name 4288) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 4289) (name 4290) (simple_variable 4291) (static_member 4292) (variable 5576) (variable_class_name 4294)) 1859 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 5575) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1860 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 5574) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1861 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 5573) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1862 (("(" 5569)) 1863 (("(" 5564)) 1864 (("(" 5558)) 1865 (("$" 4282) ("(" 5510) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 5511) (T_NAME_QUALIFIED 5512) (T_NAME_RELATIVE 5513) (T_READONLY 2936) (T_STATIC 5514) (T_STRING 5515) (T_VARIABLE 4284) (anonymous_class 5516) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 5517) (attribute 2943) (attributes 5518) (class_modifier 2945) (class_name 5519) (class_name_reference 5520) (name 5521) (new_variable 5522) (simple_variable 5523)) 1866 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 5509) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1867 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 5508) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1868 (("(" 4243) (argument_list 5507)) 1869 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 5506) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1870 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 5505) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1871 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 5500) (T_END_HEREDOC 5501) (T_VARIABLE 2900) (encaps_list 5502) (encaps_var 2902)) 1872 ((T_FN 35) (T_FUNCTION 127) (fn 4036) #'4037 (inline_function 5499)) 1873 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 5498) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1874 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 5497) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1875 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 5496) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1876 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 5493) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1877 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 5492) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1878 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 5488) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 1879 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 5486) (encaps_list 2805) (encaps_var 2806)) 1880 ((T_NULLSAFE_OBJECT_OPERATOR 5469) (T_OBJECT_OPERATOR 5470) ("[" 5471) ("{" 5472)) 1881 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 5466) (attribute 2728) (fn 4036) #'4037 (inline_function 5467)) 1882 (("(" 4243) (argument_list 5465)) 1883 ((T_PAAMAYIM_NEKUDOTAYIM 5457)) 1884 (("%" 4055) ("*" 4056) ("+" 4057) ("-" 4058) ("." 4059) ("/" 4060) ("<" 4061) (">" 4062) ("?" 4063) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 4064) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 4065) (T_BOOLEAN_AND 4066) (T_BOOLEAN_OR 4067) (T_COALESCE 4068) (T_INSTANCEOF 4069) (T_IS_EQUAL 4070) (T_IS_GREATER_OR_EQUAL 4071) (T_IS_IDENTICAL 4072) (T_IS_NOT_EQUAL 4073) (T_IS_NOT_IDENTICAL 4074) (T_IS_SMALLER_OR_EQUAL 4075) (T_LOGICAL_AND 4076) (T_LOGICAL_OR 4077) (T_LOGICAL_XOR 4078) (T_POW 4079) (T_SL 4080) (T_SPACESHIP 4081) (T_SR 4082) ("^" 4083) ("|" 4084)) 1885 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 5446)) 1886 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 5434)) 1887 (("," 4339) (possible_comma 4340)) 1888 (("}" 4338)) 1889 (("(" 4243) (argument_list 4337)) 1890 (("," 4334) (possible_comma 4335)) 1891 (("=" 4251) (T_AND_EQUAL 4252) (T_COALESCE_EQUAL 4253) (T_CONCAT_EQUAL 4254) (T_DEC 4255) (T_DIV_EQUAL 4256) (T_INC 4257) (T_MINUS_EQUAL 4258) (T_MOD_EQUAL 4259) (T_MUL_EQUAL 4260) (T_OR_EQUAL 4261) (T_PLUS_EQUAL 4262) (T_POW_EQUAL 4263) (T_SL_EQUAL 4264) (T_SR_EQUAL 4265) (T_XOR_EQUAL 4266)) 1892 ((T_PAAMAYIM_NEKUDOTAYIM 4156)) 1893 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4054) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1894 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4155) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1895 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4154) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1896 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4153) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1897 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4152) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1898 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4151) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1899 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4150) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1900 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4149) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1901 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4148) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1902 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 4143) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 4144) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 1903 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4142) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1904 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4141) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1905 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4140) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1906 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4139) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1907 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4138) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1908 (("$" 4100) ("(" 4101) (T_NAME_FULLY_QUALIFIED 4102) (T_NAME_QUALIFIED 4103) (T_NAME_RELATIVE 4104) (T_STATIC 4105) (T_STRING 4106) (T_VARIABLE 4107) (class_name 4108) (class_name_reference 4109) (name 4110) (new_variable 4111) (simple_variable 4112)) 1909 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4099) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1910 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4098) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1911 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4097) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1912 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4096) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1913 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4095) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1914 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4094) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1915 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4093) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1916 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4092) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1917 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4091) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1918 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4090) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1919 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4089) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1920 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4088) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1921 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4087) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1922 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4086) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1923 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4085) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1924 (("$" 4100) (T_VARIABLE 4107) (simple_variable 4134) ("{" 4135)) 1925 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 4132) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 1926 ((T_PAAMAYIM_NEKUDOTAYIM 4130)) 1927 ((T_NULLSAFE_OBJECT_OPERATOR 4113) (T_OBJECT_OPERATOR 4114) (T_PAAMAYIM_NEKUDOTAYIM 4115) ("[" 4116) ("{" 4117)) 1928 (("$" 4100) (T_STRING 4123) (T_VARIABLE 4107) (property_name 4129) (simple_variable 4125) ("{" 4126)) 1929 (("$" 4100) (T_STRING 4123) (T_VARIABLE 4107) (property_name 4124) (simple_variable 4125) ("{" 4126)) 1930 (("$" 4100) (T_VARIABLE 4107) (simple_variable 4122)) 1931 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 4120) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 1932 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 4118) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1933 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 4119)) 1934 (("]" 4121)) 1935 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 4127) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1936 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 4128)) 1937 (("$" 4100) (T_VARIABLE 4107) (simple_variable 4131)) 1938 (("%" 292) (")" 4133) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 1939 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 4136) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1940 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 4137)) 1941 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4147) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1942 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 4145) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 1943 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4146) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1944 (("$" 3974) (T_ABSTRACT 4157) (T_ARRAY 4158) (T_AS 4159) (T_BREAK 4160) (T_CALLABLE 4161) (T_CASE 4162) (T_CATCH 4163) (T_CLASS 4164) (T_CLASS_C 4165) (T_CLONE 4166) (T_CONST 4167) (T_CONTINUE 4168) (T_DECLARE 4169) (T_DEFAULT 4170) (T_DIR 4171) (T_DO 4172) (T_ECHO 4173) (T_ELSE 4174) (T_ELSEIF 4175) (T_EMPTY 4176) (T_ENDDECLARE 4177) (T_ENDFOR 4178) (T_ENDFOREACH 4179) (T_ENDIF 4180) (T_ENDSWITCH 4181) (T_ENDWHILE 4182) (T_ENUM 4183) (T_EVAL 4184) (T_EXIT 4185) (T_EXTENDS 4186) (T_FILE 4187) (T_FINAL 4188) (T_FINALLY 4189) (T_FN 4190) (T_FOR 4191) (T_FOREACH 4192) (T_FUNCTION 4193) (T_FUNC_C 4194) (T_GLOBAL 4195) (T_GOTO 4196) (T_IF 4197) (T_IMPLEMENTS 4198) (T_INCLUDE 4199) (T_INCLUDE_ONCE 4200) (T_INSTANCEOF 4201) (T_INSTEADOF 4202) (T_INTERFACE 4203) (T_ISSET 4204) (T_LINE 4205) (T_LIST 4206) (T_LOGICAL_AND 4207) (T_LOGICAL_OR 4208) (T_LOGICAL_XOR 4209) (T_MATCH 4210) (T_METHOD_C 4211) (T_NAMESPACE 4212) (T_NEW 4213) (T_NS_C 4214) (T_PRINT 4215) (T_PRIVATE 4216) (T_PROTECTED 4217) (T_PUBLIC 4218) (T_READONLY 4219) (T_REQUIRE 4220) (T_REQUIRE_ONCE 4221) (T_RETURN 4222) (T_STATIC 4223) (T_STRING 4224) (T_SWITCH 4225) (T_THROW 4226) (T_TRAIT 4227) (T_TRAIT_C 4228) (T_TRY 4229) (T_UNSET 4230) (T_USE 4231) (T_VAR 4232) (T_VARIABLE 4022) (T_WHILE 4233) (T_YIELD 4234) (identifier 4235) (member_name 4236) (reserved_non_modifiers 4237) (semi_reserved 4238) (simple_variable 4239) ("{" 4240)) 1945 (("(" 4243) (argument_list 4244)) 1946 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 4241) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1947 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 4242)) 1948 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 4245) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 4246) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 4247) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 1949 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 4250) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 1950 (("," 1469) (possible_comma 4248)) 1951 ((")" 4249)) 1952 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (ampersand 4280) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4281) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1953 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4279) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1954 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4278) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1955 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4277) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1956 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4276) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1957 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4275) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1958 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4274) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1959 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4273) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1960 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4272) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1961 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4271) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1962 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4270) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1963 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4269) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1964 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4268) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1965 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4267) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1966 (("\"" 1509) ("$" 4282) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 4283) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 4284) ("[" 1529) (array_object_dereferenceable 4285) (callable_expr 4286) (callable_variable 4287) (class_constant 1533) (class_name 4288) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 4289) (name 4290) (simple_variable 4291) (static_member 4292) (variable 4293) (variable_class_name 4294)) 1967 (("$" 4282) (T_VARIABLE 4284) (simple_variable 4330) ("{" 4331)) 1968 (("(" 4298) (argument_list 4329)) 1969 ((T_NULLSAFE_OBJECT_OPERATOR 4312) (T_OBJECT_OPERATOR 4313) ("[" 4314) ("{" 4315)) 1970 (("(" 4298) (argument_list 4311)) 1971 ((T_PAAMAYIM_NEKUDOTAYIM 4307)) 1972 (("(" 4298) (argument_list 4306)) 1973 ((T_PAAMAYIM_NEKUDOTAYIM 4295)) 1974 (("$" 4282) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 4284) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 4296) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 4297) ("{" 1627)) 1975 (("(" 4298) (argument_list 4299)) 1976 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 4300) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 4301) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 4302) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 1977 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 4305) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 1978 (("," 1469) (possible_comma 4303)) 1979 ((")" 4304)) 1980 (("$" 4282) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 4284) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 4308) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 4309) ("{" 1643)) 1981 (("(" 4298) (argument_list 4310)) 1982 (("$" 4282) (T_STRING 4320) (T_VARIABLE 4284) (property_name 4327) (simple_variable 4322) ("{" 4323)) 1983 (("$" 4282) (T_STRING 4320) (T_VARIABLE 4284) (property_name 4321) (simple_variable 4322) ("{" 4323)) 1984 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 4318) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 1985 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 4316) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1986 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 4317)) 1987 (("]" 4319)) 1988 (("(" 4298) (argument_list 4326)) 1989 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 4324) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1990 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 4325)) 1991 (("(" 4298) (argument_list 4328)) 1992 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 4332) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 1993 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 4333)) 1994 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4336) (match_arm_cond_list 4043) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1995 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 5433) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 1996 ((T_DOUBLE_ARROW 4341)) 1997 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4404) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 1998 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 5432) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 1999 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 5430) (encaps_var 5299)) 2000 (("$" 4344) (T_VARIABLE 4391) (simple_variable 5426) ("{" 5427)) 2001 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5424) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2002 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 5423) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2003 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 5422) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2004 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 5421) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2005 (("(" 5418)) 2006 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 5417) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2007 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 5416) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2008 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 5415) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2009 (("\"" 1509) ("$" 4647) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 4648) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 4649) ("[" 1529) (array_object_dereferenceable 4650) (callable_expr 4651) (callable_variable 4652) (class_constant 1533) (class_name 4653) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 4654) (name 4655) (simple_variable 4656) (static_member 4657) (variable 5414) (variable_class_name 4659)) 2010 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 5413) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2011 (("(" 5410)) 2012 (("(" 5407)) 2013 (("(" 5403) (exit_expr 5404)) 2014 (("\"" 1509) ("$" 4647) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 4648) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 4649) ("[" 1529) (array_object_dereferenceable 4650) (callable_expr 4651) (callable_variable 4652) (class_constant 1533) (class_name 4653) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 4654) (name 4655) (simple_variable 4656) (static_member 4657) (variable 5402) (variable_class_name 4659)) 2015 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 5401) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2016 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 5400) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2017 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 5399) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2018 (("(" 5395)) 2019 (("(" 5390)) 2020 (("(" 5384)) 2021 (("$" 4647) ("(" 5336) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 5337) (T_NAME_QUALIFIED 5338) (T_NAME_RELATIVE 5339) (T_READONLY 2936) (T_STATIC 5340) (T_STRING 5341) (T_VARIABLE 4649) (anonymous_class 5342) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 5343) (attribute 2943) (attributes 5344) (class_modifier 2945) (class_name 5345) (class_name_reference 5346) (name 5347) (new_variable 5348) (simple_variable 5349)) 2022 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 5335) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2023 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 5334) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2024 (("(" 4608) (argument_list 5333)) 2025 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 5332) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2026 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 5331) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2027 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 5326) (T_END_HEREDOC 5327) (T_VARIABLE 2900) (encaps_list 5328) (encaps_var 2902)) 2028 ((T_FN 35) (T_FUNCTION 127) (fn 4405) #'4406 (inline_function 5325)) 2029 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 5324) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2030 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 5323) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2031 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 5322) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2032 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 4821) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2033 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4758) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2034 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 4754) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 2035 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 4752) (encaps_list 2805) (encaps_var 2806)) 2036 ((T_NULLSAFE_OBJECT_OPERATOR 4735) (T_OBJECT_OPERATOR 4736) ("[" 4737) ("{" 4738)) 2037 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 4732) (attribute 2728) (fn 4405) #'4406 (inline_function 4733)) 2038 (("(" 4608) (argument_list 4731)) 2039 ((T_PAAMAYIM_NEKUDOTAYIM 4723)) 2040 (("%" 4420) ("*" 4421) ("+" 4422) ("-" 4423) ("." 4424) ("/" 4425) ("<" 4426) (">" 4427) ("?" 4428) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 4429) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 4430) (T_BOOLEAN_AND 4431) (T_BOOLEAN_OR 4432) (T_COALESCE 4433) (T_INSTANCEOF 4434) (T_IS_EQUAL 4435) (T_IS_GREATER_OR_EQUAL 4436) (T_IS_IDENTICAL 4437) (T_IS_NOT_EQUAL 4438) (T_IS_NOT_IDENTICAL 4439) (T_IS_SMALLER_OR_EQUAL 4440) (T_LOGICAL_AND 4441) (T_LOGICAL_OR 4442) (T_LOGICAL_XOR 4443) (T_POW 4444) (T_SL 4445) (T_SPACESHIP 4446) (T_SR 4447) ("^" 4448) ("|" 4449)) 2041 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 4712)) 2042 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 4700)) 2043 (("(" 4608) (argument_list 4699)) 2044 (("=" 4616) (T_AND_EQUAL 4617) (T_COALESCE_EQUAL 4618) (T_CONCAT_EQUAL 4619) (T_DEC 4620) (T_DIV_EQUAL 4621) (T_INC 4622) (T_MINUS_EQUAL 4623) (T_MOD_EQUAL 4624) (T_MUL_EQUAL 4625) (T_OR_EQUAL 4626) (T_PLUS_EQUAL 4627) (T_POW_EQUAL 4628) (T_SL_EQUAL 4629) (T_SR_EQUAL 4630) (T_XOR_EQUAL 4631)) 2045 ((T_PAAMAYIM_NEKUDOTAYIM 4521)) 2046 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4419) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2047 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4520) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2048 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4519) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2049 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4518) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2050 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4517) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2051 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4516) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2052 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4515) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2053 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4514) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2054 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4513) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2055 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 4508) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 4509) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 2056 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4507) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2057 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4506) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2058 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4505) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2059 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4504) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2060 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4503) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2061 (("$" 4465) ("(" 4466) (T_NAME_FULLY_QUALIFIED 4467) (T_NAME_QUALIFIED 4468) (T_NAME_RELATIVE 4469) (T_STATIC 4470) (T_STRING 4471) (T_VARIABLE 4472) (class_name 4473) (class_name_reference 4474) (name 4475) (new_variable 4476) (simple_variable 4477)) 2062 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4464) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2063 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4463) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2064 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4462) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2065 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4461) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2066 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4460) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2067 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4459) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2068 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4458) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2069 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4457) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2070 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4456) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2071 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4455) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2072 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4454) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2073 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4453) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2074 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4452) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2075 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4451) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2076 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4450) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2077 (("$" 4465) (T_VARIABLE 4472) (simple_variable 4499) ("{" 4500)) 2078 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 4497) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2079 ((T_PAAMAYIM_NEKUDOTAYIM 4495)) 2080 ((T_NULLSAFE_OBJECT_OPERATOR 4478) (T_OBJECT_OPERATOR 4479) (T_PAAMAYIM_NEKUDOTAYIM 4480) ("[" 4481) ("{" 4482)) 2081 (("$" 4465) (T_STRING 4488) (T_VARIABLE 4472) (property_name 4494) (simple_variable 4490) ("{" 4491)) 2082 (("$" 4465) (T_STRING 4488) (T_VARIABLE 4472) (property_name 4489) (simple_variable 4490) ("{" 4491)) 2083 (("$" 4465) (T_VARIABLE 4472) (simple_variable 4487)) 2084 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 4485) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 2085 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 4483) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2086 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 4484)) 2087 (("]" 4486)) 2088 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 4492) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2089 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 4493)) 2090 (("$" 4465) (T_VARIABLE 4472) (simple_variable 4496)) 2091 (("%" 292) (")" 4498) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2092 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 4501) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2093 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 4502)) 2094 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4512) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2095 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 4510) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 2096 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4511) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2097 (("$" 4344) (T_ABSTRACT 4522) (T_ARRAY 4523) (T_AS 4524) (T_BREAK 4525) (T_CALLABLE 4526) (T_CASE 4527) (T_CATCH 4528) (T_CLASS 4529) (T_CLASS_C 4530) (T_CLONE 4531) (T_CONST 4532) (T_CONTINUE 4533) (T_DECLARE 4534) (T_DEFAULT 4535) (T_DIR 4536) (T_DO 4537) (T_ECHO 4538) (T_ELSE 4539) (T_ELSEIF 4540) (T_EMPTY 4541) (T_ENDDECLARE 4542) (T_ENDFOR 4543) (T_ENDFOREACH 4544) (T_ENDIF 4545) (T_ENDSWITCH 4546) (T_ENDWHILE 4547) (T_ENUM 4548) (T_EVAL 4549) (T_EXIT 4550) (T_EXTENDS 4551) (T_FILE 4552) (T_FINAL 4553) (T_FINALLY 4554) (T_FN 4555) (T_FOR 4556) (T_FOREACH 4557) (T_FUNCTION 4558) (T_FUNC_C 4559) (T_GLOBAL 4560) (T_GOTO 4561) (T_IF 4562) (T_IMPLEMENTS 4563) (T_INCLUDE 4564) (T_INCLUDE_ONCE 4565) (T_INSTANCEOF 4566) (T_INSTEADOF 4567) (T_INTERFACE 4568) (T_ISSET 4569) (T_LINE 4570) (T_LIST 4571) (T_LOGICAL_AND 4572) (T_LOGICAL_OR 4573) (T_LOGICAL_XOR 4574) (T_MATCH 4575) (T_METHOD_C 4576) (T_NAMESPACE 4577) (T_NEW 4578) (T_NS_C 4579) (T_PRINT 4580) (T_PRIVATE 4581) (T_PROTECTED 4582) (T_PUBLIC 4583) (T_READONLY 4584) (T_REQUIRE 4585) (T_REQUIRE_ONCE 4586) (T_RETURN 4587) (T_STATIC 4588) (T_STRING 4589) (T_SWITCH 4590) (T_THROW 4591) (T_TRAIT 4592) (T_TRAIT_C 4593) (T_TRY 4594) (T_UNSET 4595) (T_USE 4596) (T_VAR 4597) (T_VARIABLE 4391) (T_WHILE 4598) (T_YIELD 4599) (identifier 4600) (member_name 4601) (reserved_non_modifiers 4602) (semi_reserved 4603) (simple_variable 4604) ("{" 4605)) 2098 (("(" 4608) (argument_list 4609)) 2099 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 4606) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2100 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 4607)) 2101 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 4610) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 4611) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 4612) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 2102 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 4615) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 2103 (("," 1469) (possible_comma 4613)) 2104 ((")" 4614)) 2105 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (ampersand 4645) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4646) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2106 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4644) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2107 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4643) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2108 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4642) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2109 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4641) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2110 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4640) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2111 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4639) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2112 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4638) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2113 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4637) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2114 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4636) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2115 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4635) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2116 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4634) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2117 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4633) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2118 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4632) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2119 (("\"" 1509) ("$" 4647) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 4648) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 4649) ("[" 1529) (array_object_dereferenceable 4650) (callable_expr 4651) (callable_variable 4652) (class_constant 1533) (class_name 4653) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 4654) (name 4655) (simple_variable 4656) (static_member 4657) (variable 4658) (variable_class_name 4659)) 2120 (("$" 4647) (T_VARIABLE 4649) (simple_variable 4695) ("{" 4696)) 2121 (("(" 4663) (argument_list 4694)) 2122 ((T_NULLSAFE_OBJECT_OPERATOR 4677) (T_OBJECT_OPERATOR 4678) ("[" 4679) ("{" 4680)) 2123 (("(" 4663) (argument_list 4676)) 2124 ((T_PAAMAYIM_NEKUDOTAYIM 4672)) 2125 (("(" 4663) (argument_list 4671)) 2126 ((T_PAAMAYIM_NEKUDOTAYIM 4660)) 2127 (("$" 4647) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 4649) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 4661) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 4662) ("{" 1627)) 2128 (("(" 4663) (argument_list 4664)) 2129 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 4665) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 4666) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 4667) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 2130 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 4670) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 2131 (("," 1469) (possible_comma 4668)) 2132 ((")" 4669)) 2133 (("$" 4647) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 4649) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 4673) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 4674) ("{" 1643)) 2134 (("(" 4663) (argument_list 4675)) 2135 (("$" 4647) (T_STRING 4685) (T_VARIABLE 4649) (property_name 4692) (simple_variable 4687) ("{" 4688)) 2136 (("$" 4647) (T_STRING 4685) (T_VARIABLE 4649) (property_name 4686) (simple_variable 4687) ("{" 4688)) 2137 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 4683) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 2138 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 4681) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2139 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 4682)) 2140 (("]" 4684)) 2141 (("(" 4663) (argument_list 4691)) 2142 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 4689) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2143 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 4690)) 2144 (("(" 4663) (argument_list 4693)) 2145 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 4697) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2146 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 4698)) 2147 ((backup_doc_comment 4701)) 2148 (("(" 4702)) 2149 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 4703)) 2150 ((")" 4704)) 2151 ((T_USE 159) (lexical_vars 4705)) 2152 ((":" 161) (return_type 4706)) 2153 ((backup_fn_flags 4707)) 2154 (("{" 4708)) 2155 ((inner_statement_list 4709)) 2156 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 4710) ("~" 125)) 2157 ((backup_fn_flags 4711)) 2158 ((backup_doc_comment 4713)) 2159 (("(" 4714)) 2160 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 4715)) 2161 ((")" 4716)) 2162 ((":" 2241) (return_type 4717)) 2163 ((T_DOUBLE_ARROW 4718)) 2164 ((backup_fn_flags 4719)) 2165 ((backup_lex_pos 4720)) 2166 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4721) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2167 (("%" 4420) ("*" 4421) ("+" 4422) ("-" 4423) ("." 4424) ("/" 4425) ("<" 4426) (">" 4427) ("?" 4428) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 4429) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 4430) (T_BOOLEAN_AND 4431) (T_BOOLEAN_OR 4432) (T_COALESCE 4433) (T_INSTANCEOF 4434) (T_IS_EQUAL 4435) (T_IS_GREATER_OR_EQUAL 4436) (T_IS_IDENTICAL 4437) (T_IS_NOT_EQUAL 4438) (T_IS_NOT_IDENTICAL 4439) (T_IS_SMALLER_OR_EQUAL 4440) (T_LOGICAL_AND 4441) (T_LOGICAL_OR 4442) (T_LOGICAL_XOR 4443) (T_POW 4444) (T_SL 4445) (T_SPACESHIP 4446) (T_SR 4447) ("^" 4448) (backup_fn_flags 4722) ("|" 4449)) 2168 (("$" 4344) (T_ABSTRACT 4522) (T_ARRAY 4523) (T_AS 4524) (T_BREAK 4525) (T_CALLABLE 4526) (T_CASE 4527) (T_CATCH 4528) (T_CLASS 4529) (T_CLASS_C 4530) (T_CLONE 4531) (T_CONST 4532) (T_CONTINUE 4533) (T_DECLARE 4534) (T_DEFAULT 4535) (T_DIR 4536) (T_DO 4537) (T_ECHO 4538) (T_ELSE 4539) (T_ELSEIF 4540) (T_EMPTY 4541) (T_ENDDECLARE 4542) (T_ENDFOR 4543) (T_ENDFOREACH 4544) (T_ENDIF 4545) (T_ENDSWITCH 4546) (T_ENDWHILE 4547) (T_ENUM 4548) (T_EVAL 4549) (T_EXIT 4550) (T_EXTENDS 4551) (T_FILE 4552) (T_FINAL 4553) (T_FINALLY 4554) (T_FN 4555) (T_FOR 4556) (T_FOREACH 4557) (T_FUNCTION 4558) (T_FUNC_C 4559) (T_GLOBAL 4560) (T_GOTO 4561) (T_IF 4562) (T_IMPLEMENTS 4563) (T_INCLUDE 4564) (T_INCLUDE_ONCE 4565) (T_INSTANCEOF 4566) (T_INSTEADOF 4567) (T_INTERFACE 4568) (T_ISSET 4569) (T_LINE 4570) (T_LIST 4571) (T_LOGICAL_AND 4572) (T_LOGICAL_OR 4573) (T_LOGICAL_XOR 4574) (T_MATCH 4575) (T_METHOD_C 4576) (T_NAMESPACE 4577) (T_NEW 4578) (T_NS_C 4579) (T_PRINT 4580) (T_PRIVATE 4581) (T_PROTECTED 4582) (T_PUBLIC 4583) (T_READONLY 4584) (T_REQUIRE 4585) (T_REQUIRE_ONCE 4586) (T_RETURN 4587) (T_STATIC 4588) (T_STRING 4589) (T_SWITCH 4590) (T_THROW 4591) (T_TRAIT 4592) (T_TRAIT_C 4593) (T_TRY 4594) (T_UNSET 4595) (T_USE 4596) (T_VAR 4597) (T_VARIABLE 4391) (T_WHILE 4598) (T_YIELD 4599) (identifier 4724) (member_name 4725) (reserved_non_modifiers 4602) (semi_reserved 4603) (simple_variable 4726) ("{" 4727)) 2169 (("(" 4608) (argument_list 4730)) 2170 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 4728) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2171 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 4729)) 2172 ((T_FN 35) (T_FUNCTION 127) (fn 4405) #'4406 (inline_function 4734)) 2173 (("$" 4344) (T_STRING 4743) (T_VARIABLE 4391) (property_name 4750) (simple_variable 4745) ("{" 4746)) 2174 (("$" 4344) (T_STRING 4743) (T_VARIABLE 4391) (property_name 4744) (simple_variable 4745) ("{" 4746)) 2175 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 4741) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 2176 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 4739) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2177 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 4740)) 2178 (("]" 4742)) 2179 (("(" 4608) (argument_list 4749)) 2180 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 4747) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2181 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 4748)) 2182 (("(" 4608) (argument_list 4751)) 2183 (("`" 4753)) 2184 (("]" 4755)) 2185 (("=" 4756)) 2186 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 4757) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2187 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5321) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2188 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 5298) (encaps_var 5299)) 2189 (("$" 4761) (T_VARIABLE 4808) (simple_variable 5290) ("{" 5291)) 2190 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5288) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2191 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5287) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2192 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5286) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2193 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5285) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2194 (("(" 5282)) 2195 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5281) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2196 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5280) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2197 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5279) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2198 (("\"" 1509) ("$" 5064) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 5065) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 5066) ("[" 1529) (array_object_dereferenceable 5067) (callable_expr 5068) (callable_variable 5069) (class_constant 1533) (class_name 5070) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 5071) (name 5072) (simple_variable 5073) (static_member 5074) (variable 5278) (variable_class_name 5076)) 2199 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5277) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2200 (("(" 5274)) 2201 (("(" 5271)) 2202 (("(" 5266) (exit_expr 5267)) 2203 (("\"" 1509) ("$" 5064) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 5065) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 5066) ("[" 1529) (array_object_dereferenceable 5067) (callable_expr 5068) (callable_variable 5069) (class_constant 1533) (class_name 5070) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 5071) (name 5072) (simple_variable 5073) (static_member 5074) (variable 5265) (variable_class_name 5076)) 2204 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5264) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2205 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5263) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2206 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5262) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2207 (("(" 5254)) 2208 (("(" 5249)) 2209 (("(" 5243)) 2210 (("$" 5064) ("(" 5195) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 5196) (T_NAME_QUALIFIED 5197) (T_NAME_RELATIVE 5198) (T_READONLY 2936) (T_STATIC 5199) (T_STRING 5200) (T_VARIABLE 5066) (anonymous_class 5201) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 5202) (attribute 2943) (attributes 5203) (class_modifier 2945) (class_name 5204) (class_name_reference 5205) (name 5206) (new_variable 5207) (simple_variable 5208)) 2211 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5194) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2212 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5193) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2213 (("(" 5025) (argument_list 5192)) 2214 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5191) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2215 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5190) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2216 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 5185) (T_END_HEREDOC 5186) (T_VARIABLE 2900) (encaps_list 5187) (encaps_var 2902)) 2217 ((T_FN 35) (T_FUNCTION 127) (fn 4822) #'4823 (inline_function 5184)) 2218 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5183) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2219 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5182) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2220 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5181) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2221 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5178) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2222 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5177) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2223 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 5173) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 2224 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 5171) (encaps_list 2805) (encaps_var 2806)) 2225 ((T_NULLSAFE_OBJECT_OPERATOR 5154) (T_OBJECT_OPERATOR 5155) ("[" 5156) ("{" 5157)) 2226 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 5151) (attribute 2728) (fn 4822) #'4823 (inline_function 5152)) 2227 (("(" 5025) (argument_list 5150)) 2228 ((T_PAAMAYIM_NEKUDOTAYIM 5142)) 2229 (("%" 4837) ("*" 4838) ("+" 4839) ("-" 4840) ("." 4841) ("/" 4842) ("<" 4843) (">" 4844) ("?" 4845) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 4846) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 4847) (T_BOOLEAN_AND 4848) (T_BOOLEAN_OR 4849) (T_COALESCE 4850) (T_DOUBLE_ARROW 5140) (T_INSTANCEOF 4851) (T_IS_EQUAL 4852) (T_IS_GREATER_OR_EQUAL 4853) (T_IS_IDENTICAL 4854) (T_IS_NOT_EQUAL 4855) (T_IS_NOT_IDENTICAL 4856) (T_IS_SMALLER_OR_EQUAL 4857) (T_LOGICAL_AND 4858) (T_LOGICAL_OR 4859) (T_LOGICAL_XOR 4860) (T_POW 4861) (T_SL 4862) (T_SPACESHIP 4863) (T_SR 4864) ("^" 4865) ("|" 4866)) 2230 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 5129)) 2231 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 5117)) 2232 (("(" 5025) (argument_list 5116)) 2233 (("=" 5033) (T_AND_EQUAL 5034) (T_COALESCE_EQUAL 5035) (T_CONCAT_EQUAL 5036) (T_DEC 5037) (T_DIV_EQUAL 5038) (T_INC 5039) (T_MINUS_EQUAL 5040) (T_MOD_EQUAL 5041) (T_MUL_EQUAL 5042) (T_OR_EQUAL 5043) (T_PLUS_EQUAL 5044) (T_POW_EQUAL 5045) (T_SL_EQUAL 5046) (T_SR_EQUAL 5047) (T_XOR_EQUAL 5048)) 2234 ((T_PAAMAYIM_NEKUDOTAYIM 4938)) 2235 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 4836) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2236 (("%" 4837) ("*" 4838) ("+" 4839) ("-" 4840) ("." 4841) ("/" 4842) ("<" 4843) (">" 4844) ("?" 4845) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 4846) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 4847) (T_BOOLEAN_AND 4848) (T_BOOLEAN_OR 4849) (T_COALESCE 4850) (T_INSTANCEOF 4851) (T_IS_EQUAL 4852) (T_IS_GREATER_OR_EQUAL 4853) (T_IS_IDENTICAL 4854) (T_IS_NOT_EQUAL 4855) (T_IS_NOT_IDENTICAL 4856) (T_IS_SMALLER_OR_EQUAL 4857) (T_LOGICAL_AND 4858) (T_LOGICAL_OR 4859) (T_LOGICAL_XOR 4860) (T_POW 4861) (T_SL 4862) (T_SPACESHIP 4863) (T_SR 4864) ("^" 4865) ("|" 4866)) 2237 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 4937) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2238 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 4936) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2239 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 4935) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2240 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 4934) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2241 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 4933) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2242 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 4932) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2243 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 4931) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2244 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 4930) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2245 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 4925) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 4926) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 2246 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 4924) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2247 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 4923) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2248 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 4922) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2249 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 4921) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2250 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 4920) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2251 (("$" 4882) ("(" 4883) (T_NAME_FULLY_QUALIFIED 4884) (T_NAME_QUALIFIED 4885) (T_NAME_RELATIVE 4886) (T_STATIC 4887) (T_STRING 4888) (T_VARIABLE 4889) (class_name 4890) (class_name_reference 4891) (name 4892) (new_variable 4893) (simple_variable 4894)) 2252 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 4881) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2253 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 4880) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2254 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 4879) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2255 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 4878) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2256 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 4877) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2257 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 4876) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2258 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 4875) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2259 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 4874) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2260 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 4873) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2261 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 4872) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2262 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 4871) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2263 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 4870) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2264 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 4869) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2265 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 4868) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2266 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 4867) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2267 (("$" 4882) (T_VARIABLE 4889) (simple_variable 4916) ("{" 4917)) 2268 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 4914) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2269 ((T_PAAMAYIM_NEKUDOTAYIM 4912)) 2270 ((T_NULLSAFE_OBJECT_OPERATOR 4895) (T_OBJECT_OPERATOR 4896) (T_PAAMAYIM_NEKUDOTAYIM 4897) ("[" 4898) ("{" 4899)) 2271 (("$" 4882) (T_STRING 4905) (T_VARIABLE 4889) (property_name 4911) (simple_variable 4907) ("{" 4908)) 2272 (("$" 4882) (T_STRING 4905) (T_VARIABLE 4889) (property_name 4906) (simple_variable 4907) ("{" 4908)) 2273 (("$" 4882) (T_VARIABLE 4889) (simple_variable 4904)) 2274 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 4902) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 2275 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 4900) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2276 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 4901)) 2277 (("]" 4903)) 2278 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 4909) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2279 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 4910)) 2280 (("$" 4882) (T_VARIABLE 4889) (simple_variable 4913)) 2281 (("%" 292) (")" 4915) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2282 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 4918) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2283 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 4919)) 2284 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 4929) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2285 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 4927) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 2286 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 4928) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2287 (("$" 4761) (T_ABSTRACT 4939) (T_ARRAY 4940) (T_AS 4941) (T_BREAK 4942) (T_CALLABLE 4943) (T_CASE 4944) (T_CATCH 4945) (T_CLASS 4946) (T_CLASS_C 4947) (T_CLONE 4948) (T_CONST 4949) (T_CONTINUE 4950) (T_DECLARE 4951) (T_DEFAULT 4952) (T_DIR 4953) (T_DO 4954) (T_ECHO 4955) (T_ELSE 4956) (T_ELSEIF 4957) (T_EMPTY 4958) (T_ENDDECLARE 4959) (T_ENDFOR 4960) (T_ENDFOREACH 4961) (T_ENDIF 4962) (T_ENDSWITCH 4963) (T_ENDWHILE 4964) (T_ENUM 4965) (T_EVAL 4966) (T_EXIT 4967) (T_EXTENDS 4968) (T_FILE 4969) (T_FINAL 4970) (T_FINALLY 4971) (T_FN 4972) (T_FOR 4973) (T_FOREACH 4974) (T_FUNCTION 4975) (T_FUNC_C 4976) (T_GLOBAL 4977) (T_GOTO 4978) (T_IF 4979) (T_IMPLEMENTS 4980) (T_INCLUDE 4981) (T_INCLUDE_ONCE 4982) (T_INSTANCEOF 4983) (T_INSTEADOF 4984) (T_INTERFACE 4985) (T_ISSET 4986) (T_LINE 4987) (T_LIST 4988) (T_LOGICAL_AND 4989) (T_LOGICAL_OR 4990) (T_LOGICAL_XOR 4991) (T_MATCH 4992) (T_METHOD_C 4993) (T_NAMESPACE 4994) (T_NEW 4995) (T_NS_C 4996) (T_PRINT 4997) (T_PRIVATE 4998) (T_PROTECTED 4999) (T_PUBLIC 5000) (T_READONLY 5001) (T_REQUIRE 5002) (T_REQUIRE_ONCE 5003) (T_RETURN 5004) (T_STATIC 5005) (T_STRING 5006) (T_SWITCH 5007) (T_THROW 5008) (T_TRAIT 5009) (T_TRAIT_C 5010) (T_TRY 5011) (T_UNSET 5012) (T_USE 5013) (T_VAR 5014) (T_VARIABLE 4808) (T_WHILE 5015) (T_YIELD 5016) (identifier 5017) (member_name 5018) (reserved_non_modifiers 5019) (semi_reserved 5020) (simple_variable 5021) ("{" 5022)) 2288 (("(" 5025) (argument_list 5026)) 2289 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 5023) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2290 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 5024)) 2291 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 5027) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 5028) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 5029) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 2292 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 5032) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 2293 (("," 1469) (possible_comma 5030)) 2294 ((")" 5031)) 2295 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (ampersand 5062) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5063) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2296 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5061) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2297 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5060) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2298 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5059) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2299 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5058) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2300 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5057) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2301 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5056) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2302 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5055) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2303 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5054) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2304 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5053) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2305 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5052) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2306 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5051) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2307 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5050) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2308 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5049) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2309 (("\"" 1509) ("$" 5064) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 5065) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 5066) ("[" 1529) (array_object_dereferenceable 5067) (callable_expr 5068) (callable_variable 5069) (class_constant 1533) (class_name 5070) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 5071) (name 5072) (simple_variable 5073) (static_member 5074) (variable 5075) (variable_class_name 5076)) 2310 (("$" 5064) (T_VARIABLE 5066) (simple_variable 5112) ("{" 5113)) 2311 (("(" 5080) (argument_list 5111)) 2312 ((T_NULLSAFE_OBJECT_OPERATOR 5094) (T_OBJECT_OPERATOR 5095) ("[" 5096) ("{" 5097)) 2313 (("(" 5080) (argument_list 5093)) 2314 ((T_PAAMAYIM_NEKUDOTAYIM 5089)) 2315 (("(" 5080) (argument_list 5088)) 2316 ((T_PAAMAYIM_NEKUDOTAYIM 5077)) 2317 (("$" 5064) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 5066) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 5078) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 5079) ("{" 1627)) 2318 (("(" 5080) (argument_list 5081)) 2319 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 5082) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 5083) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 5084) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 2320 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 5087) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 2321 (("," 1469) (possible_comma 5085)) 2322 ((")" 5086)) 2323 (("$" 5064) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 5066) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 5090) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 5091) ("{" 1643)) 2324 (("(" 5080) (argument_list 5092)) 2325 (("$" 5064) (T_STRING 5102) (T_VARIABLE 5066) (property_name 5109) (simple_variable 5104) ("{" 5105)) 2326 (("$" 5064) (T_STRING 5102) (T_VARIABLE 5066) (property_name 5103) (simple_variable 5104) ("{" 5105)) 2327 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 5100) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 2328 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 5098) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2329 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 5099)) 2330 (("]" 5101)) 2331 (("(" 5080) (argument_list 5108)) 2332 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 5106) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2333 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 5107)) 2334 (("(" 5080) (argument_list 5110)) 2335 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 5114) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2336 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 5115)) 2337 ((backup_doc_comment 5118)) 2338 (("(" 5119)) 2339 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 5120)) 2340 ((")" 5121)) 2341 ((T_USE 159) (lexical_vars 5122)) 2342 ((":" 161) (return_type 5123)) 2343 ((backup_fn_flags 5124)) 2344 (("{" 5125)) 2345 ((inner_statement_list 5126)) 2346 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 5127) ("~" 125)) 2347 ((backup_fn_flags 5128)) 2348 ((backup_doc_comment 5130)) 2349 (("(" 5131)) 2350 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 5132)) 2351 ((")" 5133)) 2352 ((":" 2241) (return_type 5134)) 2353 ((T_DOUBLE_ARROW 5135)) 2354 ((backup_fn_flags 5136)) 2355 ((backup_lex_pos 5137)) 2356 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5138) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2357 (("%" 4837) ("*" 4838) ("+" 4839) ("-" 4840) ("." 4841) ("/" 4842) ("<" 4843) (">" 4844) ("?" 4845) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 4846) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 4847) (T_BOOLEAN_AND 4848) (T_BOOLEAN_OR 4849) (T_COALESCE 4850) (T_INSTANCEOF 4851) (T_IS_EQUAL 4852) (T_IS_GREATER_OR_EQUAL 4853) (T_IS_IDENTICAL 4854) (T_IS_NOT_EQUAL 4855) (T_IS_NOT_IDENTICAL 4856) (T_IS_SMALLER_OR_EQUAL 4857) (T_LOGICAL_AND 4858) (T_LOGICAL_OR 4859) (T_LOGICAL_XOR 4860) (T_POW 4861) (T_SL 4862) (T_SPACESHIP 4863) (T_SR 4864) ("^" 4865) (backup_fn_flags 5139) ("|" 4866)) 2358 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 5141) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2359 (("$" 4761) (T_ABSTRACT 4939) (T_ARRAY 4940) (T_AS 4941) (T_BREAK 4942) (T_CALLABLE 4943) (T_CASE 4944) (T_CATCH 4945) (T_CLASS 4946) (T_CLASS_C 4947) (T_CLONE 4948) (T_CONST 4949) (T_CONTINUE 4950) (T_DECLARE 4951) (T_DEFAULT 4952) (T_DIR 4953) (T_DO 4954) (T_ECHO 4955) (T_ELSE 4956) (T_ELSEIF 4957) (T_EMPTY 4958) (T_ENDDECLARE 4959) (T_ENDFOR 4960) (T_ENDFOREACH 4961) (T_ENDIF 4962) (T_ENDSWITCH 4963) (T_ENDWHILE 4964) (T_ENUM 4965) (T_EVAL 4966) (T_EXIT 4967) (T_EXTENDS 4968) (T_FILE 4969) (T_FINAL 4970) (T_FINALLY 4971) (T_FN 4972) (T_FOR 4973) (T_FOREACH 4974) (T_FUNCTION 4975) (T_FUNC_C 4976) (T_GLOBAL 4977) (T_GOTO 4978) (T_IF 4979) (T_IMPLEMENTS 4980) (T_INCLUDE 4981) (T_INCLUDE_ONCE 4982) (T_INSTANCEOF 4983) (T_INSTEADOF 4984) (T_INTERFACE 4985) (T_ISSET 4986) (T_LINE 4987) (T_LIST 4988) (T_LOGICAL_AND 4989) (T_LOGICAL_OR 4990) (T_LOGICAL_XOR 4991) (T_MATCH 4992) (T_METHOD_C 4993) (T_NAMESPACE 4994) (T_NEW 4995) (T_NS_C 4996) (T_PRINT 4997) (T_PRIVATE 4998) (T_PROTECTED 4999) (T_PUBLIC 5000) (T_READONLY 5001) (T_REQUIRE 5002) (T_REQUIRE_ONCE 5003) (T_RETURN 5004) (T_STATIC 5005) (T_STRING 5006) (T_SWITCH 5007) (T_THROW 5008) (T_TRAIT 5009) (T_TRAIT_C 5010) (T_TRY 5011) (T_UNSET 5012) (T_USE 5013) (T_VAR 5014) (T_VARIABLE 4808) (T_WHILE 5015) (T_YIELD 5016) (identifier 5143) (member_name 5144) (reserved_non_modifiers 5019) (semi_reserved 5020) (simple_variable 5145) ("{" 5146)) 2360 (("(" 5025) (argument_list 5149)) 2361 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 5147) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2362 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 5148)) 2363 ((T_FN 35) (T_FUNCTION 127) (fn 4822) #'4823 (inline_function 5153)) 2364 (("$" 4761) (T_STRING 5162) (T_VARIABLE 4808) (property_name 5169) (simple_variable 5164) ("{" 5165)) 2365 (("$" 4761) (T_STRING 5162) (T_VARIABLE 4808) (property_name 5163) (simple_variable 5164) ("{" 5165)) 2366 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 5160) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 2367 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 5158) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2368 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 5159)) 2369 (("]" 5161)) 2370 (("(" 5025) (argument_list 5168)) 2371 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 5166) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2372 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 5167)) 2373 (("(" 5025) (argument_list 5170)) 2374 (("`" 5172)) 2375 (("]" 5174)) 2376 (("=" 5175)) 2377 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5176) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2378 (("%" 4837) ("*" 4838) ("+" 4839) ("-" 4840) ("." 4841) ("/" 4842) ("<" 4843) (">" 4844) ("?" 4845) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 4846) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 4847) (T_BOOLEAN_AND 4848) (T_BOOLEAN_OR 4849) (T_COALESCE 4850) (T_DOUBLE_ARROW 5179) (T_INSTANCEOF 4851) (T_IS_EQUAL 4852) (T_IS_GREATER_OR_EQUAL 4853) (T_IS_IDENTICAL 4854) (T_IS_NOT_EQUAL 4855) (T_IS_NOT_IDENTICAL 4856) (T_IS_SMALLER_OR_EQUAL 4857) (T_LOGICAL_AND 4858) (T_LOGICAL_OR 4859) (T_LOGICAL_XOR 4860) (T_POW 4861) (T_SL 4862) (T_SPACESHIP 4863) (T_SR 4864) ("^" 4865) ("|" 4866)) 2379 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5180) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2380 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 5189) (T_VARIABLE 2900) (encaps_var 2914)) 2381 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 5188) (T_VARIABLE 2900) (encaps_var 2905)) 2382 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5241) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2383 ((T_CLASS 5233)) 2384 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 5232) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 5202) (attribute 2980) (class_modifier 2945)) 2385 ((T_PAAMAYIM_NEKUDOTAYIM 5230)) 2386 (("(" 5221) (argument_list 5222) (ctor_arguments 5223)) 2387 ((T_NULLSAFE_OBJECT_OPERATOR 5209) (T_OBJECT_OPERATOR 5210) (T_PAAMAYIM_NEKUDOTAYIM 5211) ("[" 5212) ("{" 5213)) 2388 (("$" 5064) (T_STRING 5102) (T_VARIABLE 5066) (property_name 5220) (simple_variable 5104) ("{" 5105)) 2389 (("$" 5064) (T_STRING 5102) (T_VARIABLE 5066) (property_name 5219) (simple_variable 5104) ("{" 5105)) 2390 (("$" 5064) (T_VARIABLE 5066) (simple_variable 5218)) 2391 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 5216) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 2392 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 5214) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2393 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 5215)) 2394 (("]" 5217)) 2395 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 5224) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 5225) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 5226) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 2396 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 5229) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 2397 (("," 1469) (possible_comma 5227)) 2398 ((")" 5228)) 2399 (("$" 5064) (T_VARIABLE 5066) (simple_variable 5231)) 2400 (("(" 2982) (argument_list 2983) (ctor_arguments 5234)) 2401 ((T_EXTENDS 2985) (extends_from 5235)) 2402 ((T_IMPLEMENTS 2987) (implements_list 5236)) 2403 ((backup_doc_comment 5237)) 2404 (("{" 5238)) 2405 ((class_statement_list 5239)) 2406 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 5240)) 2407 (("%" 292) (")" 5242) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2408 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5244) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2409 (("%" 292) (")" 5245) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2410 (("{" 5246)) 2411 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 5247) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 2412 (("}" 5248)) 2413 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 5250) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 2414 ((")" 5251)) 2415 (("=" 5252)) 2416 (("!" 4759) ("\"" 4760) ("$" 4761) ("(" 4762) ("+" 4763) ("-" 4764) ("@" 4765) (T_ARRAY 4766) (T_ARRAY_CAST 4767) (T_ATTRIBUTE 126) (T_BOOL_CAST 4768) (T_CLASS_C 4769) (T_CLONE 4770) (T_CONSTANT_ENCAPSED_STRING 4771) (T_DEC 4772) (T_DIR 4773) (T_DNUMBER 4774) (T_DOUBLE_CAST 4775) (T_EMPTY 4776) (T_EVAL 4777) (T_EXIT 4778) (T_FILE 4779) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4780) (T_INC 4781) (T_INCLUDE 4782) (T_INCLUDE_ONCE 4783) (T_INT_CAST 4784) (T_ISSET 4785) (T_LINE 4786) (T_LIST 4787) (T_LNUMBER 4788) (T_MATCH 4789) (T_METHOD_C 4790) (T_NAME_FULLY_QUALIFIED 4791) (T_NAME_QUALIFIED 4792) (T_NAME_RELATIVE 4793) (T_NEW 4794) (T_NS_C 4795) (T_OBJECT_CAST 4796) (T_PRINT 4797) (T_READONLY 4798) (T_REQUIRE 4799) (T_REQUIRE_ONCE 4800) (T_START_HEREDOC 4801) (T_STATIC 4802) (T_STRING 4803) (T_STRING_CAST 4804) (T_THROW 4805) (T_TRAIT_C 4806) (T_UNSET_CAST 4807) (T_VARIABLE 4808) (T_YIELD 4809) (T_YIELD_FROM 4810) ("[" 4811) ("`" 4812) (array_object_dereferenceable 4813) (attribute 131) (attributes 4814) (callable_expr 4815) (callable_variable 4816) (class_constant 4817) (class_name 4818) (constant 4819) (dereferenceable_scalar 4820) (expr 5253) (fn 4822) (fully_dereferenceable 104) #'4823 (function_call 4824) (inline_function 4825) (internal_functions_in_yacc 4826) (match 4827) (name 4828) (new_expr 4829) (scalar 4830) (simple_variable 4831) (static_member 4832) (variable 4833) (variable_class_name 4834) ("~" 4835)) 2417 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 5257) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 2418 (("," 5258) (possible_comma 5259)) 2419 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5261) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 2420 ((")" 5260)) 2421 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 5269) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2422 ((")" 5270)) 2423 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5272) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2424 (("%" 292) (")" 5273) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2425 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5275) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2426 (("%" 292) (")" 5276) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2427 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 5283) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 2428 ((")" 5284)) 2429 (("%" 292) (")" 5289) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2430 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 5292) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2431 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 5293)) 2432 (("\"" 1509) ("$" 2831) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 2832) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 2833) ("[" 1529) (array_object_dereferenceable 2834) (callable_expr 2835) (callable_variable 2836) (class_constant 1533) (class_name 2837) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 2838) (name 2839) (simple_variable 2840) (static_member 2841) (variable 5319) (variable_class_name 2843)) 2433 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_STRING_VARNAME 5311) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 5312) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2434 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_VARIABLE 5297) (encaps_var 5310)) 2435 ((T_NULLSAFE_OBJECT_OPERATOR 5303) (T_OBJECT_OPERATOR 5304) ("[" 5305)) 2436 (("\"" 5300) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 2437 ((T_STRING 5309)) 2438 ((T_STRING 5308)) 2439 (("-" 2813) (T_NUM_STRING 2814) (T_STRING 2815) (T_VARIABLE 2816) (encaps_var_offset 5306)) 2440 (("]" 5307)) 2441 (("[" 5314) ("}" 5315)) 2442 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 5313)) 2443 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 5316) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 2444 (("%" 577) ("*" 578) ("+" 579) ("-" 580) ("." 581) ("/" 582) ("<" 583) (">" 584) ("?" 585) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 586) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 587) (T_BOOLEAN_AND 588) (T_BOOLEAN_OR 589) (T_COALESCE 590) (T_INSTANCEOF 591) (T_IS_EQUAL 592) (T_IS_GREATER_OR_EQUAL 593) (T_IS_IDENTICAL 594) (T_IS_NOT_EQUAL 595) (T_IS_NOT_IDENTICAL 596) (T_IS_SMALLER_OR_EQUAL 597) (T_LOGICAL_AND 598) (T_LOGICAL_OR 599) (T_LOGICAL_XOR 600) (T_POW 601) (T_SL 602) (T_SPACESHIP 603) (T_SR 604) ("]" 5317) ("^" 605) ("|" 606)) 2445 (("}" 5318)) 2446 (("}" 5320)) 2447 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 5330) (T_VARIABLE 2900) (encaps_var 2914)) 2448 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 5329) (T_VARIABLE 2900) (encaps_var 2905)) 2449 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5382) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2450 ((T_CLASS 5374)) 2451 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 5373) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 5343) (attribute 2980) (class_modifier 2945)) 2452 ((T_PAAMAYIM_NEKUDOTAYIM 5371)) 2453 (("(" 5362) (argument_list 5363) (ctor_arguments 5364)) 2454 ((T_NULLSAFE_OBJECT_OPERATOR 5350) (T_OBJECT_OPERATOR 5351) (T_PAAMAYIM_NEKUDOTAYIM 5352) ("[" 5353) ("{" 5354)) 2455 (("$" 4647) (T_STRING 4685) (T_VARIABLE 4649) (property_name 5361) (simple_variable 4687) ("{" 4688)) 2456 (("$" 4647) (T_STRING 4685) (T_VARIABLE 4649) (property_name 5360) (simple_variable 4687) ("{" 4688)) 2457 (("$" 4647) (T_VARIABLE 4649) (simple_variable 5359)) 2458 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 5357) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 2459 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 5355) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2460 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 5356)) 2461 (("]" 5358)) 2462 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 5365) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 5366) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 5367) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 2463 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 5370) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 2464 (("," 1469) (possible_comma 5368)) 2465 ((")" 5369)) 2466 (("$" 4647) (T_VARIABLE 4649) (simple_variable 5372)) 2467 (("(" 2982) (argument_list 2983) (ctor_arguments 5375)) 2468 ((T_EXTENDS 2985) (extends_from 5376)) 2469 ((T_IMPLEMENTS 2987) (implements_list 5377)) 2470 ((backup_doc_comment 5378)) 2471 (("{" 5379)) 2472 ((class_statement_list 5380)) 2473 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 5381)) 2474 (("%" 292) (")" 5383) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2475 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5385) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2476 (("%" 292) (")" 5386) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2477 (("{" 5387)) 2478 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 5388) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 2479 (("}" 5389)) 2480 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 5391) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 2481 ((")" 5392)) 2482 (("=" 5393)) 2483 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 5394) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2484 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 5396) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 2485 (("," 5258) (possible_comma 5397)) 2486 ((")" 5398)) 2487 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 5405) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2488 ((")" 5406)) 2489 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5408) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2490 (("%" 292) (")" 5409) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2491 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5411) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2492 (("%" 292) (")" 5412) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2493 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 5419) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 2494 ((")" 5420)) 2495 (("%" 292) (")" 5425) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2496 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 5428) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2497 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 5429)) 2498 (("\"" 5431) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 2499 ((backup_doc_comment 5435)) 2500 (("(" 5436)) 2501 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 5437)) 2502 ((")" 5438)) 2503 ((T_USE 159) (lexical_vars 5439)) 2504 ((":" 161) (return_type 5440)) 2505 ((backup_fn_flags 5441)) 2506 (("{" 5442)) 2507 ((inner_statement_list 5443)) 2508 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 5444) ("~" 125)) 2509 ((backup_fn_flags 5445)) 2510 ((backup_doc_comment 5447)) 2511 (("(" 5448)) 2512 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 5449)) 2513 ((")" 5450)) 2514 ((":" 2241) (return_type 5451)) 2515 ((T_DOUBLE_ARROW 5452)) 2516 ((backup_fn_flags 5453)) 2517 ((backup_lex_pos 5454)) 2518 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 5455) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 2519 (("%" 4055) ("*" 4056) ("+" 4057) ("-" 4058) ("." 4059) ("/" 4060) ("<" 4061) (">" 4062) ("?" 4063) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 4064) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 4065) (T_BOOLEAN_AND 4066) (T_BOOLEAN_OR 4067) (T_COALESCE 4068) (T_INSTANCEOF 4069) (T_IS_EQUAL 4070) (T_IS_GREATER_OR_EQUAL 4071) (T_IS_IDENTICAL 4072) (T_IS_NOT_EQUAL 4073) (T_IS_NOT_IDENTICAL 4074) (T_IS_SMALLER_OR_EQUAL 4075) (T_LOGICAL_AND 4076) (T_LOGICAL_OR 4077) (T_LOGICAL_XOR 4078) (T_POW 4079) (T_SL 4080) (T_SPACESHIP 4081) (T_SR 4082) ("^" 4083) (backup_fn_flags 5456) ("|" 4084)) 2520 (("$" 3974) (T_ABSTRACT 4157) (T_ARRAY 4158) (T_AS 4159) (T_BREAK 4160) (T_CALLABLE 4161) (T_CASE 4162) (T_CATCH 4163) (T_CLASS 4164) (T_CLASS_C 4165) (T_CLONE 4166) (T_CONST 4167) (T_CONTINUE 4168) (T_DECLARE 4169) (T_DEFAULT 4170) (T_DIR 4171) (T_DO 4172) (T_ECHO 4173) (T_ELSE 4174) (T_ELSEIF 4175) (T_EMPTY 4176) (T_ENDDECLARE 4177) (T_ENDFOR 4178) (T_ENDFOREACH 4179) (T_ENDIF 4180) (T_ENDSWITCH 4181) (T_ENDWHILE 4182) (T_ENUM 4183) (T_EVAL 4184) (T_EXIT 4185) (T_EXTENDS 4186) (T_FILE 4187) (T_FINAL 4188) (T_FINALLY 4189) (T_FN 4190) (T_FOR 4191) (T_FOREACH 4192) (T_FUNCTION 4193) (T_FUNC_C 4194) (T_GLOBAL 4195) (T_GOTO 4196) (T_IF 4197) (T_IMPLEMENTS 4198) (T_INCLUDE 4199) (T_INCLUDE_ONCE 4200) (T_INSTANCEOF 4201) (T_INSTEADOF 4202) (T_INTERFACE 4203) (T_ISSET 4204) (T_LINE 4205) (T_LIST 4206) (T_LOGICAL_AND 4207) (T_LOGICAL_OR 4208) (T_LOGICAL_XOR 4209) (T_MATCH 4210) (T_METHOD_C 4211) (T_NAMESPACE 4212) (T_NEW 4213) (T_NS_C 4214) (T_PRINT 4215) (T_PRIVATE 4216) (T_PROTECTED 4217) (T_PUBLIC 4218) (T_READONLY 4219) (T_REQUIRE 4220) (T_REQUIRE_ONCE 4221) (T_RETURN 4222) (T_STATIC 4223) (T_STRING 4224) (T_SWITCH 4225) (T_THROW 4226) (T_TRAIT 4227) (T_TRAIT_C 4228) (T_TRY 4229) (T_UNSET 4230) (T_USE 4231) (T_VAR 4232) (T_VARIABLE 4022) (T_WHILE 4233) (T_YIELD 4234) (identifier 5458) (member_name 5459) (reserved_non_modifiers 4237) (semi_reserved 4238) (simple_variable 5460) ("{" 5461)) 2521 (("(" 4243) (argument_list 5464)) 2522 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 5462) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2523 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 5463)) 2524 ((T_FN 35) (T_FUNCTION 127) (fn 4036) #'4037 (inline_function 5468)) 2525 (("$" 3974) (T_STRING 5477) (T_VARIABLE 4022) (property_name 5484) (simple_variable 5479) ("{" 5480)) 2526 (("$" 3974) (T_STRING 5477) (T_VARIABLE 4022) (property_name 5478) (simple_variable 5479) ("{" 5480)) 2527 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 5475) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 2528 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 5473) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2529 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 5474)) 2530 (("]" 5476)) 2531 (("(" 4243) (argument_list 5483)) 2532 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 5481) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2533 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 5482)) 2534 (("(" 4243) (argument_list 5485)) 2535 (("`" 5487)) 2536 (("]" 5489)) 2537 (("=" 5490)) 2538 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 5491) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 2539 (("%" 4055) ("*" 4056) ("+" 4057) ("-" 4058) ("." 4059) ("/" 4060) ("<" 4061) (">" 4062) ("?" 4063) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 4064) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 4065) (T_BOOLEAN_AND 4066) (T_BOOLEAN_OR 4067) (T_COALESCE 4068) (T_DOUBLE_ARROW 5494) (T_INSTANCEOF 4069) (T_IS_EQUAL 4070) (T_IS_GREATER_OR_EQUAL 4071) (T_IS_IDENTICAL 4072) (T_IS_NOT_EQUAL 4073) (T_IS_NOT_IDENTICAL 4074) (T_IS_SMALLER_OR_EQUAL 4075) (T_LOGICAL_AND 4076) (T_LOGICAL_OR 4077) (T_LOGICAL_XOR 4078) (T_POW 4079) (T_SL 4080) (T_SPACESHIP 4081) (T_SR 4082) ("^" 4083) ("|" 4084)) 2540 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 5495) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 2541 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 5504) (T_VARIABLE 2900) (encaps_var 2914)) 2542 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 5503) (T_VARIABLE 2900) (encaps_var 2905)) 2543 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5556) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2544 ((T_CLASS 5548)) 2545 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 5547) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 5517) (attribute 2980) (class_modifier 2945)) 2546 ((T_PAAMAYIM_NEKUDOTAYIM 5545)) 2547 (("(" 5536) (argument_list 5537) (ctor_arguments 5538)) 2548 ((T_NULLSAFE_OBJECT_OPERATOR 5524) (T_OBJECT_OPERATOR 5525) (T_PAAMAYIM_NEKUDOTAYIM 5526) ("[" 5527) ("{" 5528)) 2549 (("$" 4282) (T_STRING 4320) (T_VARIABLE 4284) (property_name 5535) (simple_variable 4322) ("{" 4323)) 2550 (("$" 4282) (T_STRING 4320) (T_VARIABLE 4284) (property_name 5534) (simple_variable 4322) ("{" 4323)) 2551 (("$" 4282) (T_VARIABLE 4284) (simple_variable 5533)) 2552 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 5531) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 2553 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 5529) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2554 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 5530)) 2555 (("]" 5532)) 2556 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 5539) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 5540) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 5541) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 2557 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 5544) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 2558 (("," 1469) (possible_comma 5542)) 2559 ((")" 5543)) 2560 (("$" 4282) (T_VARIABLE 4284) (simple_variable 5546)) 2561 (("(" 2982) (argument_list 2983) (ctor_arguments 5549)) 2562 ((T_EXTENDS 2985) (extends_from 5550)) 2563 ((T_IMPLEMENTS 2987) (implements_list 5551)) 2564 ((backup_doc_comment 5552)) 2565 (("{" 5553)) 2566 ((class_statement_list 5554)) 2567 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 5555)) 2568 (("%" 292) (")" 5557) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2569 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5559) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2570 (("%" 292) (")" 5560) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2571 (("{" 5561)) 2572 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 5562) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 2573 (("}" 5563)) 2574 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 5565) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 2575 ((")" 5566)) 2576 (("=" 5567)) 2577 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 5568) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (name 4045) (new_expr 4046) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 2578 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 5570) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 2579 (("," 5258) (possible_comma 5571)) 2580 ((")" 5572)) 2581 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 5579) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2582 ((")" 5580)) 2583 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5582) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2584 (("%" 292) (")" 5583) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2585 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5585) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2586 (("%" 292) (")" 5586) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2587 ((T_DOUBLE_ARROW 5590)) 2588 (("!" 4342) ("\"" 4343) ("$" 4344) ("(" 4345) ("+" 4346) ("-" 4347) ("@" 4348) (T_ARRAY 4349) (T_ARRAY_CAST 4350) (T_ATTRIBUTE 126) (T_BOOL_CAST 4351) (T_CLASS_C 4352) (T_CLONE 4353) (T_CONSTANT_ENCAPSED_STRING 4354) (T_DEC 4355) (T_DIR 4356) (T_DNUMBER 4357) (T_DOUBLE_CAST 4358) (T_EMPTY 4359) (T_EVAL 4360) (T_EXIT 4361) (T_FILE 4362) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 4363) (T_INC 4364) (T_INCLUDE 4365) (T_INCLUDE_ONCE 4366) (T_INT_CAST 4367) (T_ISSET 4368) (T_LINE 4369) (T_LIST 4370) (T_LNUMBER 4371) (T_MATCH 4372) (T_METHOD_C 4373) (T_NAME_FULLY_QUALIFIED 4374) (T_NAME_QUALIFIED 4375) (T_NAME_RELATIVE 4376) (T_NEW 4377) (T_NS_C 4378) (T_OBJECT_CAST 4379) (T_PRINT 4380) (T_READONLY 4381) (T_REQUIRE 4382) (T_REQUIRE_ONCE 4383) (T_START_HEREDOC 4384) (T_STATIC 4385) (T_STRING 4386) (T_STRING_CAST 4387) (T_THROW 4388) (T_TRAIT_C 4389) (T_UNSET_CAST 4390) (T_VARIABLE 4391) (T_YIELD 4392) (T_YIELD_FROM 4393) ("[" 4394) ("`" 4395) (array_object_dereferenceable 4396) (attribute 131) (attributes 4397) (callable_expr 4398) (callable_variable 4399) (class_constant 4400) (class_name 4401) (constant 4402) (dereferenceable_scalar 4403) (expr 5591) (fn 4405) (fully_dereferenceable 104) #'4406 (function_call 4407) (inline_function 4408) (internal_functions_in_yacc 4409) (match 4410) (name 4411) (new_expr 4412) (scalar 4413) (simple_variable 4414) (static_member 4415) (variable 4416) (variable_class_name 4417) ("~" 4418)) 2589 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 5597) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 2590 ((")" 5598)) 2591 (("%" 292) (")" 5603) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2592 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 5606) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2593 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 5607)) 2594 (("\"" 5609) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 2595 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 5612) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 2596 ((")" 5613)) 2597 (("=" 5614)) 2598 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 5615) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 2599 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 5617) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 2600 (("," 5258) (possible_comma 5618)) 2601 ((")" 5619)) 2602 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 5626) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2603 ((")" 5627)) 2604 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5629) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2605 (("%" 292) (")" 5630) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2606 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5632) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2607 (("%" 292) (")" 5633) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2608 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 5640) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 2609 ((")" 5641)) 2610 (("%" 292) (")" 5646) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2611 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 5649) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2612 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 5650)) 2613 (("\"" 5652) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 2614 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 5662) (T_VARIABLE 2900) (encaps_var 2914)) 2615 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 5661) (T_VARIABLE 2900) (encaps_var 2905)) 2616 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5714) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2617 ((T_CLASS 5706)) 2618 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 5705) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 5675) (attribute 2980) (class_modifier 2945)) 2619 ((T_PAAMAYIM_NEKUDOTAYIM 5703)) 2620 (("(" 5694) (argument_list 5695) (ctor_arguments 5696)) 2621 ((T_NULLSAFE_OBJECT_OPERATOR 5682) (T_OBJECT_OPERATOR 5683) (T_PAAMAYIM_NEKUDOTAYIM 5684) ("[" 5685) ("{" 5686)) 2622 (("$" 3371) (T_STRING 3409) (T_VARIABLE 3373) (property_name 5693) (simple_variable 3411) ("{" 3412)) 2623 (("$" 3371) (T_STRING 3409) (T_VARIABLE 3373) (property_name 5692) (simple_variable 3411) ("{" 3412)) 2624 (("$" 3371) (T_VARIABLE 3373) (simple_variable 5691)) 2625 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 5689) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 2626 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 5687) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2627 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 5688)) 2628 (("]" 5690)) 2629 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 5697) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 5698) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 5699) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 2630 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 5702) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 2631 (("," 1469) (possible_comma 5700)) 2632 ((")" 5701)) 2633 (("$" 3371) (T_VARIABLE 3373) (simple_variable 5704)) 2634 (("(" 2982) (argument_list 2983) (ctor_arguments 5707)) 2635 ((T_EXTENDS 2985) (extends_from 5708)) 2636 ((T_IMPLEMENTS 2987) (implements_list 5709)) 2637 ((backup_doc_comment 5710)) 2638 (("{" 5711)) 2639 ((class_statement_list 5712)) 2640 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 5713)) 2641 (("%" 292) (")" 5715) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2642 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5717) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2643 (("%" 292) (")" 5718) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2644 (("{" 5719)) 2645 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 5720) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 2646 (("}" 5721)) 2647 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 5723) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 2648 ((")" 5724)) 2649 (("=" 5725)) 2650 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 5726) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 2651 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 5728) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 2652 (("," 5258) (possible_comma 5729)) 2653 ((")" 5730)) 2654 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 5737) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2655 ((")" 5738)) 2656 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5740) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2657 (("%" 292) (")" 5741) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2658 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5743) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2659 (("%" 292) (")" 5744) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2660 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 5751) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 2661 ((")" 5752)) 2662 (("%" 292) (")" 5757) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2663 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 5760) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2664 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 5761)) 2665 (("\"" 5763) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 2666 ((T_ARRAY 3050) (T_CALLABLE 3051) (T_NAME_FULLY_QUALIFIED 3052) (T_NAME_QUALIFIED 3053) (T_NAME_RELATIVE 3054) (T_STRING 3055) (name 3056) (type_without_static 5766)) 2667 ((")" 5776) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 3045)) 2668 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 5780) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 5781) (ampersand 5782) (returns_ref 5783)) 2669 ((T_ABSTRACT 5784) (T_ARRAY 5785) (T_AS 5786) (T_BREAK 5787) (T_CALLABLE 5788) (T_CASE 5789) (T_CATCH 5790) (T_CLASS 5791) (T_CLASS_C 5792) (T_CLONE 5793) (T_CONST 5794) (T_CONTINUE 5795) (T_DECLARE 5796) (T_DEFAULT 5797) (T_DIR 5798) (T_DO 5799) (T_ECHO 5800) (T_ELSE 5801) (T_ELSEIF 5802) (T_EMPTY 5803) (T_ENDDECLARE 5804) (T_ENDFOR 5805) (T_ENDFOREACH 5806) (T_ENDIF 5807) (T_ENDSWITCH 5808) (T_ENDWHILE 5809) (T_ENUM 5810) (T_EVAL 5811) (T_EXIT 5812) (T_EXTENDS 5813) (T_FILE 5814) (T_FINAL 5815) (T_FINALLY 5816) (T_FN 5817) (T_FOR 5818) (T_FOREACH 5819) (T_FUNCTION 5820) (T_FUNC_C 5821) (T_GLOBAL 5822) (T_GOTO 5823) (T_IF 5824) (T_IMPLEMENTS 5825) (T_INCLUDE 5826) (T_INCLUDE_ONCE 5827) (T_INSTANCEOF 5828) (T_INSTEADOF 5829) (T_INTERFACE 5830) (T_ISSET 5831) (T_LINE 5832) (T_LIST 5833) (T_LOGICAL_AND 5834) (T_LOGICAL_OR 5835) (T_LOGICAL_XOR 5836) (T_MATCH 5837) (T_METHOD_C 5838) (T_NAMESPACE 5839) (T_NEW 5840) (T_NS_C 5841) (T_PRINT 5842) (T_PRIVATE 5843) (T_PROTECTED 5844) (T_PUBLIC 5845) (T_READONLY 5846) (T_REQUIRE 5847) (T_REQUIRE_ONCE 5848) (T_RETURN 5849) (T_STATIC 5850) (T_STRING 5851) (T_SWITCH 5852) (T_THROW 5853) (T_TRAIT 5854) (T_TRAIT_C 5855) (T_TRY 5856) (T_UNSET 5857) (T_USE 5858) (T_VAR 5859) (T_WHILE 5860) (T_YIELD 5861) (identifier 5862) (reserved_non_modifiers 5863) (semi_reserved 5864)) 2670 ((backup_doc_comment 5865)) 2671 (("(" 5866)) 2672 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 5867)) 2673 ((")" 5868)) 2674 ((":" 5869) (return_type 5870)) 2675 (("(" 2248) ("?" 5878) (T_ARRAY 5879) (T_CALLABLE 5880) (T_NAME_FULLY_QUALIFIED 5881) (T_NAME_QUALIFIED 5882) (T_NAME_RELATIVE 5883) (T_STATIC 5884) (T_STRING 5885) (intersection_type 5886) (name 5887) (type 5888) (type_expr 5889) (type_without_static 5890) (union_type 5891) (union_type_element 5892)) 2676 ((backup_fn_flags 5871)) 2677 ((";" 5872) (method_body 5873) ("{" 5874)) 2678 ((backup_fn_flags 5877)) 2679 ((inner_statement_list 5875)) 2680 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 5876) ("~" 125)) 2681 ((T_ARRAY 5923) (T_CALLABLE 5924) (T_NAME_FULLY_QUALIFIED 5925) (T_NAME_QUALIFIED 5926) (T_NAME_RELATIVE 5927) (T_STATIC 5928) (T_STRING 5929) (name 5930) (type 5931) (type_without_static 5932)) 2682 ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 5921)) 2683 ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 5910)) 2684 (("|" 5908)) 2685 (("|" 5893)) 2686 (("(" 5894) (T_ARRAY 5895) (T_CALLABLE 5896) (T_NAME_FULLY_QUALIFIED 5897) (T_NAME_QUALIFIED 5898) (T_NAME_RELATIVE 5899) (T_STATIC 5900) (T_STRING 5901) (name 5902) (type 5903) (type_without_static 5904) (union_type_element 5905)) 2687 ((T_ARRAY 2277) (T_CALLABLE 2278) (T_NAME_FULLY_QUALIFIED 2279) (T_NAME_QUALIFIED 2280) (T_NAME_RELATIVE 2281) (T_STATIC 2282) (T_STRING 2283) (intersection_type 5906) (name 2285) (type 2286) (type_without_static 2287)) 2688 ((")" 5907) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 2300)) 2689 (("(" 5894) (T_ARRAY 5895) (T_CALLABLE 5896) (T_NAME_FULLY_QUALIFIED 5897) (T_NAME_QUALIFIED 5898) (T_NAME_RELATIVE 5899) (T_STATIC 5900) (T_STRING 5901) (name 5902) (type 5903) (type_without_static 5904) (union_type_element 5909)) 2690 ((T_ARRAY 5911) (T_CALLABLE 5912) (T_NAME_FULLY_QUALIFIED 5913) (T_NAME_QUALIFIED 5914) (T_NAME_RELATIVE 5915) (T_STATIC 5916) (T_STRING 5917) (name 5918) (type 5919) (type_without_static 5920)) 2691 ((T_ARRAY 5911) (T_CALLABLE 5912) (T_NAME_FULLY_QUALIFIED 5913) (T_NAME_QUALIFIED 5914) (T_NAME_RELATIVE 5915) (T_STATIC 5916) (T_STRING 5917) (name 5918) (type 5922) (type_without_static 5920)) 2692 (("(" 2248) ("?" 5934) (T_ABSTRACT 5935) (T_ARRAY 5936) (T_AS 5937) (T_BREAK 5938) (T_CALLABLE 5939) (T_CASE 5940) (T_CATCH 5941) (T_CLASS 5942) (T_CLASS_C 5943) (T_CLONE 5944) (T_CONST 5945) (T_CONTINUE 5946) (T_DECLARE 5947) (T_DEFAULT 5948) (T_DIR 5949) (T_DO 5950) (T_ECHO 5951) (T_ELSE 5952) (T_ELSEIF 5953) (T_EMPTY 5954) (T_ENDDECLARE 5955) (T_ENDFOR 5956) (T_ENDFOREACH 5957) (T_ENDIF 5958) (T_ENDSWITCH 5959) (T_ENDWHILE 5960) (T_ENUM 5961) (T_EVAL 5962) (T_EXIT 5963) (T_EXTENDS 5964) (T_FILE 5965) (T_FINAL 5966) (T_FINALLY 5967) (T_FN 5968) (T_FOR 5969) (T_FOREACH 5970) (T_FUNCTION 5971) (T_FUNC_C 5972) (T_GLOBAL 5973) (T_GOTO 5974) (T_IF 5975) (T_IMPLEMENTS 5976) (T_INCLUDE 5977) (T_INCLUDE_ONCE 5978) (T_INSTANCEOF 5979) (T_INSTEADOF 5980) (T_INTERFACE 5981) (T_ISSET 5982) (T_LINE 5983) (T_LIST 5984) (T_LOGICAL_AND 5985) (T_LOGICAL_OR 5986) (T_LOGICAL_XOR 5987) (T_MATCH 5988) (T_METHOD_C 5989) (T_NAMESPACE 5990) (T_NAME_FULLY_QUALIFIED 5991) (T_NAME_QUALIFIED 5992) (T_NAME_RELATIVE 5993) (T_NEW 5994) (T_NS_C 5995) (T_PRINT 5996) (T_PRIVATE 5997) (T_PROTECTED 5998) (T_PUBLIC 5999) (T_READONLY 6000) (T_REQUIRE 6001) (T_REQUIRE_ONCE 6002) (T_RETURN 6003) (T_STATIC 6004) (T_STRING 6005) (T_SWITCH 6006) (T_THROW 6007) (T_TRAIT 6008) (T_TRAIT_C 6009) (T_TRY 6010) (T_UNSET 6011) (T_USE 6012) (T_VAR 6013) (T_WHILE 6014) (T_YIELD 6015) (class_const_decl 6016) (class_const_list 6017) (intersection_type 6018) (name 6019) (reserved_non_modifiers 6020) (semi_reserved 6021) (type 6022) (type_expr 6023) (type_without_static 6024) (union_type 6025) (union_type_element 6026)) 2693 ((T_ARRAY 6072) (T_CALLABLE 6073) (T_NAME_FULLY_QUALIFIED 6074) (T_NAME_QUALIFIED 6075) (T_NAME_RELATIVE 6076) (T_STATIC 6077) (T_STRING 6078) (name 6079) (type 6080) (type_without_static 6081)) 2694 (("=" 6052)) 2695 (("," 6049) (";" 6071)) 2696 ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 6069)) 2697 (("=" 6066)) 2698 ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 6055)) 2699 ((T_ABSTRACT 5935) (T_ARRAY 6044) (T_AS 5937) (T_BREAK 5938) (T_CALLABLE 6045) (T_CASE 5940) (T_CATCH 5941) (T_CLASS 5942) (T_CLASS_C 5943) (T_CLONE 5944) (T_CONST 5945) (T_CONTINUE 5946) (T_DECLARE 5947) (T_DEFAULT 5948) (T_DIR 5949) (T_DO 5950) (T_ECHO 5951) (T_ELSE 5952) (T_ELSEIF 5953) (T_EMPTY 5954) (T_ENDDECLARE 5955) (T_ENDFOR 5956) (T_ENDFOREACH 5957) (T_ENDIF 5958) (T_ENDSWITCH 5959) (T_ENDWHILE 5960) (T_ENUM 5961) (T_EVAL 5962) (T_EXIT 5963) (T_EXTENDS 5964) (T_FILE 5965) (T_FINAL 5966) (T_FINALLY 5967) (T_FN 5968) (T_FOR 5969) (T_FOREACH 5970) (T_FUNCTION 5971) (T_FUNC_C 5972) (T_GLOBAL 5973) (T_GOTO 5974) (T_IF 5975) (T_IMPLEMENTS 5976) (T_INCLUDE 5977) (T_INCLUDE_ONCE 5978) (T_INSTANCEOF 5979) (T_INSTEADOF 5980) (T_INTERFACE 5981) (T_ISSET 5982) (T_LINE 5983) (T_LIST 5984) (T_LOGICAL_AND 5985) (T_LOGICAL_OR 5986) (T_LOGICAL_XOR 5987) (T_MATCH 5988) (T_METHOD_C 5989) (T_NAMESPACE 5990) (T_NEW 5994) (T_NS_C 5995) (T_PRINT 5996) (T_PRIVATE 5997) (T_PROTECTED 5998) (T_PUBLIC 5999) (T_READONLY 6000) (T_REQUIRE 6001) (T_REQUIRE_ONCE 6002) (T_RETURN 6003) (T_STATIC 6046) (T_STRING 6047) (T_SWITCH 6006) (T_THROW 6007) (T_TRAIT 6008) (T_TRAIT_C 6009) (T_TRY 6010) (T_UNSET 6011) (T_USE 6012) (T_VAR 6013) (T_WHILE 6014) (T_YIELD 6015) (class_const_decl 6016) (class_const_list 6048) (reserved_non_modifiers 6020) (semi_reserved 6021)) 2700 (("|" 6042)) 2701 (("|" 6027)) 2702 (("(" 6028) (T_ARRAY 6029) (T_CALLABLE 6030) (T_NAME_FULLY_QUALIFIED 6031) (T_NAME_QUALIFIED 6032) (T_NAME_RELATIVE 6033) (T_STATIC 6034) (T_STRING 6035) (name 6036) (type 6037) (type_without_static 6038) (union_type_element 6039)) 2703 ((T_ARRAY 2277) (T_CALLABLE 2278) (T_NAME_FULLY_QUALIFIED 2279) (T_NAME_QUALIFIED 2280) (T_NAME_RELATIVE 2281) (T_STATIC 2282) (T_STRING 2283) (intersection_type 6040) (name 2285) (type 2286) (type_without_static 2287)) 2704 ((")" 6041) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 2300)) 2705 (("(" 6028) (T_ARRAY 6029) (T_CALLABLE 6030) (T_NAME_FULLY_QUALIFIED 6031) (T_NAME_QUALIFIED 6032) (T_NAME_RELATIVE 6033) (T_STATIC 6034) (T_STRING 6035) (name 6036) (type 6037) (type_without_static 6038) (union_type_element 6043)) 2706 (("," 6049) (";" 6050)) 2707 ((T_ABSTRACT 5935) (T_ARRAY 6044) (T_AS 5937) (T_BREAK 5938) (T_CALLABLE 6045) (T_CASE 5940) (T_CATCH 5941) (T_CLASS 5942) (T_CLASS_C 5943) (T_CLONE 5944) (T_CONST 5945) (T_CONTINUE 5946) (T_DECLARE 5947) (T_DEFAULT 5948) (T_DIR 5949) (T_DO 5950) (T_ECHO 5951) (T_ELSE 5952) (T_ELSEIF 5953) (T_EMPTY 5954) (T_ENDDECLARE 5955) (T_ENDFOR 5956) (T_ENDFOREACH 5957) (T_ENDIF 5958) (T_ENDSWITCH 5959) (T_ENDWHILE 5960) (T_ENUM 5961) (T_EVAL 5962) (T_EXIT 5963) (T_EXTENDS 5964) (T_FILE 5965) (T_FINAL 5966) (T_FINALLY 5967) (T_FN 5968) (T_FOR 5969) (T_FOREACH 5970) (T_FUNCTION 5971) (T_FUNC_C 5972) (T_GLOBAL 5973) (T_GOTO 5974) (T_IF 5975) (T_IMPLEMENTS 5976) (T_INCLUDE 5977) (T_INCLUDE_ONCE 5978) (T_INSTANCEOF 5979) (T_INSTEADOF 5980) (T_INTERFACE 5981) (T_ISSET 5982) (T_LINE 5983) (T_LIST 5984) (T_LOGICAL_AND 5985) (T_LOGICAL_OR 5986) (T_LOGICAL_XOR 5987) (T_MATCH 5988) (T_METHOD_C 5989) (T_NAMESPACE 5990) (T_NEW 5994) (T_NS_C 5995) (T_PRINT 5996) (T_PRIVATE 5997) (T_PROTECTED 5998) (T_PUBLIC 5999) (T_READONLY 6000) (T_REQUIRE 6001) (T_REQUIRE_ONCE 6002) (T_RETURN 6003) (T_STATIC 6046) (T_STRING 6047) (T_SWITCH 6006) (T_THROW 6007) (T_TRAIT 6008) (T_TRAIT_C 6009) (T_TRY 6010) (T_UNSET 6011) (T_USE 6012) (T_VAR 6013) (T_WHILE 6014) (T_YIELD 6015) (class_const_decl 6051) (reserved_non_modifiers 6020) (semi_reserved 6021)) 2708 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 6053) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 2709 (("%" 3144) ("*" 3145) ("+" 3146) ("-" 3147) ("." 3148) ("/" 3149) ("<" 3150) (">" 3151) ("?" 3152) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 3153) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 3154) (T_BOOLEAN_AND 3155) (T_BOOLEAN_OR 3156) (T_COALESCE 3157) (T_INSTANCEOF 3158) (T_IS_EQUAL 3159) (T_IS_GREATER_OR_EQUAL 3160) (T_IS_IDENTICAL 3161) (T_IS_NOT_EQUAL 3162) (T_IS_NOT_IDENTICAL 3163) (T_IS_SMALLER_OR_EQUAL 3164) (T_LOGICAL_AND 3165) (T_LOGICAL_OR 3166) (T_LOGICAL_XOR 3167) (T_POW 3168) (T_SL 3169) (T_SPACESHIP 3170) (T_SR 3171) ("^" 3172) (backup_doc_comment 6054) ("|" 3173)) 2710 ((T_ARRAY 6056) (T_CALLABLE 6057) (T_NAME_FULLY_QUALIFIED 6058) (T_NAME_QUALIFIED 6059) (T_NAME_RELATIVE 6060) (T_STATIC 6061) (T_STRING 6062) (name 6063) (type 6064) (type_without_static 6065)) 2711 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 6067) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 2712 (("%" 3144) ("*" 3145) ("+" 3146) ("-" 3147) ("." 3148) ("/" 3149) ("<" 3150) (">" 3151) ("?" 3152) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 3153) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 3154) (T_BOOLEAN_AND 3155) (T_BOOLEAN_OR 3156) (T_COALESCE 3157) (T_INSTANCEOF 3158) (T_IS_EQUAL 3159) (T_IS_GREATER_OR_EQUAL 3160) (T_IS_IDENTICAL 3161) (T_IS_NOT_EQUAL 3162) (T_IS_NOT_IDENTICAL 3163) (T_IS_SMALLER_OR_EQUAL 3164) (T_LOGICAL_AND 3165) (T_LOGICAL_OR 3166) (T_LOGICAL_XOR 3167) (T_POW 3168) (T_SL 3169) (T_SPACESHIP 3170) (T_SR 3171) ("^" 3172) (backup_doc_comment 6068) ("|" 3173)) 2713 ((T_ARRAY 6056) (T_CALLABLE 6057) (T_NAME_FULLY_QUALIFIED 6058) (T_NAME_QUALIFIED 6059) (T_NAME_RELATIVE 6060) (T_STATIC 6061) (T_STRING 6062) (name 6063) (type 6070) (type_without_static 6065)) 2714 (("," 6092) (";" 6093) (trait_adaptations 6094) ("{" 6095)) 2715 ((T_NAME_FULLY_QUALIFIED 6084) (T_NAME_QUALIFIED 6085) (T_NAME_RELATIVE 6086) (T_STATIC 6087) (T_STRING 6088) (class_name 6378) (name 6091)) 2716 ((T_ABSTRACT 6096) (T_ARRAY 6097) (T_AS 6098) (T_BREAK 6099) (T_CALLABLE 6100) (T_CASE 6101) (T_CATCH 6102) (T_CLASS 6103) (T_CLASS_C 6104) (T_CLONE 6105) (T_CONST 6106) (T_CONTINUE 6107) (T_DECLARE 6108) (T_DEFAULT 6109) (T_DIR 6110) (T_DO 6111) (T_ECHO 6112) (T_ELSE 6113) (T_ELSEIF 6114) (T_EMPTY 6115) (T_ENDDECLARE 6116) (T_ENDFOR 6117) (T_ENDFOREACH 6118) (T_ENDIF 6119) (T_ENDSWITCH 6120) (T_ENDWHILE 6121) (T_ENUM 6122) (T_EVAL 6123) (T_EXIT 6124) (T_EXTENDS 6125) (T_FILE 6126) (T_FINAL 6127) (T_FINALLY 6128) (T_FN 6129) (T_FOR 6130) (T_FOREACH 6131) (T_FUNCTION 6132) (T_FUNC_C 6133) (T_GLOBAL 6134) (T_GOTO 6135) (T_IF 6136) (T_IMPLEMENTS 6137) (T_INCLUDE 6138) (T_INCLUDE_ONCE 6139) (T_INSTANCEOF 6140) (T_INSTEADOF 6141) (T_INTERFACE 6142) (T_ISSET 6143) (T_LINE 6144) (T_LIST 6145) (T_LOGICAL_AND 6146) (T_LOGICAL_OR 6147) (T_LOGICAL_XOR 6148) (T_MATCH 6149) (T_METHOD_C 6150) (T_NAMESPACE 6151) (T_NAME_FULLY_QUALIFIED 6152) (T_NAME_QUALIFIED 6153) (T_NAME_RELATIVE 6154) (T_NEW 6155) (T_NS_C 6156) (T_PRINT 6157) (T_PRIVATE 6158) (T_PROTECTED 6159) (T_PUBLIC 6160) (T_READONLY 6161) (T_REQUIRE 6162) (T_REQUIRE_ONCE 6163) (T_RETURN 6164) (T_STATIC 6165) (T_STRING 6166) (T_SWITCH 6167) (T_THROW 6168) (T_TRAIT 6169) (T_TRAIT_C 6170) (T_TRY 6171) (T_UNSET 6172) (T_USE 6173) (T_VAR 6174) (T_WHILE 6175) (T_YIELD 6176) (absolute_trait_method_reference 6177) (class_name 6178) (identifier 6179) (name 6180) (reserved_non_modifiers 6181) (semi_reserved 6182) (trait_adaptation 6183) (trait_adaptation_list 6184) (trait_alias 6185) (trait_method_reference 6186) (trait_precedence 6187) ("}" 6188)) 2717 ((T_INSTEADOF 6367)) 2718 ((T_PAAMAYIM_NEKUDOTAYIM 6285)) 2719 ((T_ABSTRACT 6096) (T_ARRAY 6097) (T_AS 6098) (T_BREAK 6099) (T_CALLABLE 6100) (T_CASE 6101) (T_CATCH 6102) (T_CLASS 6103) (T_CLASS_C 6104) (T_CLONE 6105) (T_CONST 6106) (T_CONTINUE 6107) (T_DECLARE 6108) (T_DEFAULT 6109) (T_DIR 6110) (T_DO 6111) (T_ECHO 6112) (T_ELSE 6113) (T_ELSEIF 6114) (T_EMPTY 6115) (T_ENDDECLARE 6116) (T_ENDFOR 6117) (T_ENDFOREACH 6118) (T_ENDIF 6119) (T_ENDSWITCH 6120) (T_ENDWHILE 6121) (T_ENUM 6122) (T_EVAL 6123) (T_EXIT 6124) (T_EXTENDS 6125) (T_FILE 6126) (T_FINAL 6127) (T_FINALLY 6128) (T_FN 6129) (T_FOR 6130) (T_FOREACH 6131) (T_FUNCTION 6132) (T_FUNC_C 6133) (T_GLOBAL 6134) (T_GOTO 6135) (T_IF 6136) (T_IMPLEMENTS 6137) (T_INCLUDE 6138) (T_INCLUDE_ONCE 6139) (T_INSTANCEOF 6140) (T_INSTEADOF 6141) (T_INTERFACE 6142) (T_ISSET 6143) (T_LINE 6144) (T_LIST 6145) (T_LOGICAL_AND 6146) (T_LOGICAL_OR 6147) (T_LOGICAL_XOR 6148) (T_MATCH 6149) (T_METHOD_C 6150) (T_NAMESPACE 6151) (T_NAME_FULLY_QUALIFIED 6152) (T_NAME_QUALIFIED 6153) (T_NAME_RELATIVE 6154) (T_NEW 6155) (T_NS_C 6156) (T_PRINT 6157) (T_PRIVATE 6158) (T_PROTECTED 6159) (T_PUBLIC 6160) (T_READONLY 6161) (T_REQUIRE 6162) (T_REQUIRE_ONCE 6163) (T_RETURN 6164) (T_STATIC 6165) (T_STRING 6166) (T_SWITCH 6167) (T_THROW 6168) (T_TRAIT 6169) (T_TRAIT_C 6170) (T_TRY 6171) (T_UNSET 6172) (T_USE 6173) (T_VAR 6174) (T_WHILE 6175) (T_YIELD 6176) (absolute_trait_method_reference 6177) (class_name 6178) (identifier 6179) (name 6180) (reserved_non_modifiers 6181) (semi_reserved 6182) (trait_adaptation 6283) (trait_alias 6185) (trait_method_reference 6186) (trait_precedence 6187) ("}" 6284)) 2720 ((";" 6282)) 2721 ((T_AS 6190)) 2722 ((";" 6189)) 2723 ((T_ABSTRACT 6191) (T_ARRAY 6192) (T_AS 6193) (T_BREAK 6194) (T_CALLABLE 6195) (T_CASE 6196) (T_CATCH 6197) (T_CLASS 6198) (T_CLASS_C 6199) (T_CLONE 6200) (T_CONST 6201) (T_CONTINUE 6202) (T_DECLARE 6203) (T_DEFAULT 6204) (T_DIR 6205) (T_DO 6206) (T_ECHO 6207) (T_ELSE 6208) (T_ELSEIF 6209) (T_EMPTY 6210) (T_ENDDECLARE 6211) (T_ENDFOR 6212) (T_ENDFOREACH 6213) (T_ENDIF 6214) (T_ENDSWITCH 6215) (T_ENDWHILE 6216) (T_ENUM 6217) (T_EVAL 6218) (T_EXIT 6219) (T_EXTENDS 6220) (T_FILE 6221) (T_FINAL 6222) (T_FINALLY 6223) (T_FN 6224) (T_FOR 6225) (T_FOREACH 6226) (T_FUNCTION 6227) (T_FUNC_C 6228) (T_GLOBAL 6229) (T_GOTO 6230) (T_IF 6231) (T_IMPLEMENTS 6232) (T_INCLUDE 6233) (T_INCLUDE_ONCE 6234) (T_INSTANCEOF 6235) (T_INSTEADOF 6236) (T_INTERFACE 6237) (T_ISSET 6238) (T_LINE 6239) (T_LIST 6240) (T_LOGICAL_AND 6241) (T_LOGICAL_OR 6242) (T_LOGICAL_XOR 6243) (T_MATCH 6244) (T_METHOD_C 6245) (T_NAMESPACE 6246) (T_NEW 6247) (T_NS_C 6248) (T_PRINT 6249) (T_PRIVATE 6250) (T_PROTECTED 6251) (T_PUBLIC 6252) (T_READONLY 6253) (T_REQUIRE 6254) (T_REQUIRE_ONCE 6255) (T_RETURN 6256) (T_STATIC 6257) (T_STRING 6258) (T_SWITCH 6259) (T_THROW 6260) (T_TRAIT 6261) (T_TRAIT_C 6262) (T_TRY 6263) (T_UNSET 6264) (T_USE 6265) (T_VAR 6266) (T_WHILE 6267) (T_YIELD 6268) (member_modifier 6269) (reserved_non_modifiers 6270)) 2724 ((T_ABSTRACT 6271) (T_ARRAY 6192) (T_AS 6193) (T_BREAK 6194) (T_CALLABLE 6195) (T_CASE 6196) (T_CATCH 6197) (T_CLASS 6198) (T_CLASS_C 6199) (T_CLONE 6200) (T_CONST 6201) (T_CONTINUE 6202) (T_DECLARE 6203) (T_DEFAULT 6204) (T_DIR 6205) (T_DO 6206) (T_ECHO 6207) (T_ELSE 6208) (T_ELSEIF 6209) (T_EMPTY 6210) (T_ENDDECLARE 6211) (T_ENDFOR 6212) (T_ENDFOREACH 6213) (T_ENDIF 6214) (T_ENDSWITCH 6215) (T_ENDWHILE 6216) (T_ENUM 6217) (T_EVAL 6218) (T_EXIT 6219) (T_EXTENDS 6220) (T_FILE 6221) (T_FINAL 6272) (T_FINALLY 6223) (T_FN 6224) (T_FOR 6225) (T_FOREACH 6226) (T_FUNCTION 6227) (T_FUNC_C 6228) (T_GLOBAL 6229) (T_GOTO 6230) (T_IF 6231) (T_IMPLEMENTS 6232) (T_INCLUDE 6233) (T_INCLUDE_ONCE 6234) (T_INSTANCEOF 6235) (T_INSTEADOF 6236) (T_INTERFACE 6237) (T_ISSET 6238) (T_LINE 6239) (T_LIST 6240) (T_LOGICAL_AND 6241) (T_LOGICAL_OR 6242) (T_LOGICAL_XOR 6243) (T_MATCH 6244) (T_METHOD_C 6245) (T_NAMESPACE 6246) (T_NEW 6247) (T_NS_C 6248) (T_PRINT 6249) (T_PRIVATE 6273) (T_PROTECTED 6274) (T_PUBLIC 6275) (T_READONLY 6276) (T_REQUIRE 6254) (T_REQUIRE_ONCE 6255) (T_RETURN 6256) (T_STATIC 6277) (T_STRING 6278) (T_SWITCH 6259) (T_THROW 6260) (T_TRAIT 6261) (T_TRAIT_C 6262) (T_TRY 6263) (T_UNSET 6264) (T_USE 6265) (T_VAR 6266) (T_WHILE 6267) (T_YIELD 6268) (identifier 6279) (reserved_non_modifiers 6280) (semi_reserved 6281)) 2725 ((T_ABSTRACT 6286) (T_ARRAY 6287) (T_AS 6288) (T_BREAK 6289) (T_CALLABLE 6290) (T_CASE 6291) (T_CATCH 6292) (T_CLASS 6293) (T_CLASS_C 6294) (T_CLONE 6295) (T_CONST 6296) (T_CONTINUE 6297) (T_DECLARE 6298) (T_DEFAULT 6299) (T_DIR 6300) (T_DO 6301) (T_ECHO 6302) (T_ELSE 6303) (T_ELSEIF 6304) (T_EMPTY 6305) (T_ENDDECLARE 6306) (T_ENDFOR 6307) (T_ENDFOREACH 6308) (T_ENDIF 6309) (T_ENDSWITCH 6310) (T_ENDWHILE 6311) (T_ENUM 6312) (T_EVAL 6313) (T_EXIT 6314) (T_EXTENDS 6315) (T_FILE 6316) (T_FINAL 6317) (T_FINALLY 6318) (T_FN 6319) (T_FOR 6320) (T_FOREACH 6321) (T_FUNCTION 6322) (T_FUNC_C 6323) (T_GLOBAL 6324) (T_GOTO 6325) (T_IF 6326) (T_IMPLEMENTS 6327) (T_INCLUDE 6328) (T_INCLUDE_ONCE 6329) (T_INSTANCEOF 6330) (T_INSTEADOF 6331) (T_INTERFACE 6332) (T_ISSET 6333) (T_LINE 6334) (T_LIST 6335) (T_LOGICAL_AND 6336) (T_LOGICAL_OR 6337) (T_LOGICAL_XOR 6338) (T_MATCH 6339) (T_METHOD_C 6340) (T_NAMESPACE 6341) (T_NEW 6342) (T_NS_C 6343) (T_PRINT 6344) (T_PRIVATE 6345) (T_PROTECTED 6346) (T_PUBLIC 6347) (T_READONLY 6348) (T_REQUIRE 6349) (T_REQUIRE_ONCE 6350) (T_RETURN 6351) (T_STATIC 6352) (T_STRING 6353) (T_SWITCH 6354) (T_THROW 6355) (T_TRAIT 6356) (T_TRAIT_C 6357) (T_TRY 6358) (T_UNSET 6359) (T_USE 6360) (T_VAR 6361) (T_WHILE 6362) (T_YIELD 6363) (identifier 6364) (reserved_non_modifiers 6365) (semi_reserved 6366)) 2726 ((T_NAME_FULLY_QUALIFIED 6368) (T_NAME_QUALIFIED 6369) (T_NAME_RELATIVE 6370) (T_STATIC 6371) (T_STRING 6372) (class_name 6373) (class_name_list 6374) (name 6375)) 2727 (("," 6376)) 2728 ((T_NAME_FULLY_QUALIFIED 6368) (T_NAME_QUALIFIED 6369) (T_NAME_RELATIVE 6370) (T_STATIC 6371) (T_STRING 6372) (class_name 6377) (name 6375)) 2729 ((T_ABSTRACT 6380) (T_ARRAY 6381) (T_AS 6382) (T_BREAK 6383) (T_CALLABLE 6384) (T_CASE 6385) (T_CATCH 6386) (T_CLASS 6387) (T_CLASS_C 6388) (T_CLONE 6389) (T_CONST 6390) (T_CONTINUE 6391) (T_DECLARE 6392) (T_DEFAULT 6393) (T_DIR 6394) (T_DO 6395) (T_ECHO 6396) (T_ELSE 6397) (T_ELSEIF 6398) (T_EMPTY 6399) (T_ENDDECLARE 6400) (T_ENDFOR 6401) (T_ENDFOREACH 6402) (T_ENDIF 6403) (T_ENDSWITCH 6404) (T_ENDWHILE 6405) (T_ENUM 6406) (T_EVAL 6407) (T_EXIT 6408) (T_EXTENDS 6409) (T_FILE 6410) (T_FINAL 6411) (T_FINALLY 6412) (T_FN 6413) (T_FOR 6414) (T_FOREACH 6415) (T_FUNCTION 6416) (T_FUNC_C 6417) (T_GLOBAL 6418) (T_GOTO 6419) (T_IF 6420) (T_IMPLEMENTS 6421) (T_INCLUDE 6422) (T_INCLUDE_ONCE 6423) (T_INSTANCEOF 6424) (T_INSTEADOF 6425) (T_INTERFACE 6426) (T_ISSET 6427) (T_LINE 6428) (T_LIST 6429) (T_LOGICAL_AND 6430) (T_LOGICAL_OR 6431) (T_LOGICAL_XOR 6432) (T_MATCH 6433) (T_METHOD_C 6434) (T_NAMESPACE 6435) (T_NEW 6436) (T_NS_C 6437) (T_PRINT 6438) (T_PRIVATE 6439) (T_PROTECTED 6440) (T_PUBLIC 6441) (T_READONLY 6442) (T_REQUIRE 6443) (T_REQUIRE_ONCE 6444) (T_RETURN 6445) (T_STATIC 6446) (T_STRING 6447) (T_SWITCH 6448) (T_THROW 6449) (T_TRAIT 6450) (T_TRAIT_C 6451) (T_TRY 6452) (T_UNSET 6453) (T_USE 6454) (T_VAR 6455) (T_WHILE 6456) (T_YIELD 6457) (identifier 6458) (reserved_non_modifiers 6459) (semi_reserved 6460)) 2730 (("=" 6461) (enum_case_expr 6462)) 2731 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 6464) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 2732 ((";" 6463)) 2733 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 6565) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 2734 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 6564) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 2735 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 6563) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 2736 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 6562) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 2737 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 6561) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 2738 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 6560) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 2739 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 6559) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 2740 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 6558) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 2741 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 6553) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 6554) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 2742 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 6552) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 2743 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 6551) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 2744 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 6550) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 2745 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 6549) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 2746 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 6548) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 2747 (("$" 6510) ("(" 6511) (T_NAME_FULLY_QUALIFIED 6512) (T_NAME_QUALIFIED 6513) (T_NAME_RELATIVE 6514) (T_STATIC 6515) (T_STRING 6516) (T_VARIABLE 6517) (class_name 6518) (class_name_reference 6519) (name 6520) (new_variable 6521) (simple_variable 6522)) 2748 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 6509) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 2749 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 6508) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 2750 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 6507) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 2751 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 6506) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 2752 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 6505) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 2753 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 6504) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 2754 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 6503) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 2755 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 6502) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 2756 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 6501) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 2757 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 6500) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 2758 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 6499) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 2759 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 6498) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 2760 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 6497) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 2761 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 6496) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 2762 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 6495) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 2763 (("$" 6510) (T_VARIABLE 6517) (simple_variable 6544) ("{" 6545)) 2764 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 6542) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2765 ((T_PAAMAYIM_NEKUDOTAYIM 6540)) 2766 ((T_NULLSAFE_OBJECT_OPERATOR 6523) (T_OBJECT_OPERATOR 6524) (T_PAAMAYIM_NEKUDOTAYIM 6525) ("[" 6526) ("{" 6527)) 2767 (("$" 6510) (T_STRING 6533) (T_VARIABLE 6517) (property_name 6539) (simple_variable 6535) ("{" 6536)) 2768 (("$" 6510) (T_STRING 6533) (T_VARIABLE 6517) (property_name 6534) (simple_variable 6535) ("{" 6536)) 2769 (("$" 6510) (T_VARIABLE 6517) (simple_variable 6532)) 2770 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 6530) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 2771 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 6528) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2772 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 6529)) 2773 (("]" 6531)) 2774 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 6537) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2775 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 6538)) 2776 (("$" 6510) (T_VARIABLE 6517) (simple_variable 6541)) 2777 (("%" 292) (")" 6543) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2778 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 6546) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2779 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 6547)) 2780 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 6557) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 2781 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 6555) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 2782 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 6556) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 2783 (("," 6583) (possible_comma 6584)) 2784 (("(" 6575) (argument_list 6576)) 2785 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 6577) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 6578) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 6579) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 2786 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 6582) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 2787 (("," 1469) (possible_comma 6580)) 2788 ((")" 6581)) 2789 ((T_NAME_FULLY_QUALIFIED 6566) (T_NAME_QUALIFIED 6567) (T_NAME_RELATIVE 6568) (T_STATIC 6569) (T_STRING 6570) (attribute_decl 6586) (class_name 6573) (name 6574)) 2790 (("]" 6585)) 2791 (("," 6595)) 2792 ((T_NAME_FULLY_QUALIFIED 6587) (T_NAME_QUALIFIED 6588) (T_NAME_RELATIVE 6589) (T_STATIC 6590) (T_STRING 6591) (class_name 6596) (name 6594)) 2793 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 6609) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 2794 (("," 1469) (possible_comma 6607)) 2795 ((")" 6608)) 2796 (("," 6583) (possible_comma 6612)) 2797 (("]" 6613)) 2798 (("%" 292) (")" 6615) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2799 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 6618) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2800 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 6619)) 2801 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 6621) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2802 (("%" 292) (")" 6622) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2803 (("{" 6623)) 2804 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 6624) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 2805 (("}" 6625)) 2806 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 6627) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 2807 ((")" 6628)) 2808 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 6630) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 2809 (("," 5258) (possible_comma 6631)) 2810 ((")" 6632)) 2811 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 6639) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2812 ((")" 6640)) 2813 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 6642) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2814 (("%" 292) (")" 6643) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2815 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 6645) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2816 (("%" 292) (")" 6646) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2817 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 6653) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 2818 ((")" 6654)) 2819 (("%" 292) (")" 6659) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2820 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 6662) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2821 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 6663)) 2822 (("\"" 6665) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 2823 (("$" 1854) (T_ABSTRACT 2044) (T_ARRAY 2045) (T_AS 2046) (T_BREAK 2047) (T_CALLABLE 2048) (T_CASE 2049) (T_CATCH 2050) (T_CLASS 2051) (T_CLASS_C 2052) (T_CLONE 2053) (T_CONST 2054) (T_CONTINUE 2055) (T_DECLARE 2056) (T_DEFAULT 2057) (T_DIR 2058) (T_DO 2059) (T_ECHO 2060) (T_ELSE 2061) (T_ELSEIF 2062) (T_EMPTY 2063) (T_ENDDECLARE 2064) (T_ENDFOR 2065) (T_ENDFOREACH 2066) (T_ENDIF 2067) (T_ENDSWITCH 2068) (T_ENDWHILE 2069) (T_ENUM 2070) (T_EVAL 2071) (T_EXIT 2072) (T_EXTENDS 2073) (T_FILE 2074) (T_FINAL 2075) (T_FINALLY 2076) (T_FN 2077) (T_FOR 2078) (T_FOREACH 2079) (T_FUNCTION 2080) (T_FUNC_C 2081) (T_GLOBAL 2082) (T_GOTO 2083) (T_IF 2084) (T_IMPLEMENTS 2085) (T_INCLUDE 2086) (T_INCLUDE_ONCE 2087) (T_INSTANCEOF 2088) (T_INSTEADOF 2089) (T_INTERFACE 2090) (T_ISSET 2091) (T_LINE 2092) (T_LIST 2093) (T_LOGICAL_AND 2094) (T_LOGICAL_OR 2095) (T_LOGICAL_XOR 2096) (T_MATCH 2097) (T_METHOD_C 2098) (T_NAMESPACE 2099) (T_NEW 2100) (T_NS_C 2101) (T_PRINT 2102) (T_PRIVATE 2103) (T_PROTECTED 2104) (T_PUBLIC 2105) (T_READONLY 2106) (T_REQUIRE 2107) (T_REQUIRE_ONCE 2108) (T_RETURN 2109) (T_STATIC 2110) (T_STRING 2111) (T_SWITCH 2112) (T_THROW 2113) (T_TRAIT 2114) (T_TRAIT_C 2115) (T_TRY 2116) (T_UNSET 2117) (T_USE 2118) (T_VAR 2119) (T_VARIABLE 1902) (T_WHILE 2120) (T_YIELD 2121) (identifier 6668) (member_name 6669) (reserved_non_modifiers 2124) (semi_reserved 2125) (simple_variable 6670) ("{" 6671)) 2824 (("(" 2130) (argument_list 6674)) 2825 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 6672) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2826 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 6673)) 2827 ((T_FN 35) (T_FUNCTION 127) (fn 1919) #'1920 (inline_function 6678)) 2828 (("=" 6680)) 2829 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 6681) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 2830 (("$" 1854) (T_STRING 6690) (T_VARIABLE 1902) (property_name 6697) (simple_variable 6692) ("{" 6693)) 2831 (("$" 1854) (T_STRING 6690) (T_VARIABLE 1902) (property_name 6691) (simple_variable 6692) ("{" 6693)) 2832 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 6688) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 2833 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 6686) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2834 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 6687)) 2835 (("]" 6689)) 2836 (("(" 2130) (argument_list 6696)) 2837 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 6694) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2838 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 6695)) 2839 (("(" 2130) (argument_list 6698)) 2840 (("`" 6701)) 2841 (("]" 6703)) 2842 (("=" 6704)) 2843 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 6705) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 2844 (("%" 1937) ("*" 1938) ("+" 1939) ("-" 1940) ("." 1941) ("/" 1942) ("<" 1943) (">" 1944) ("?" 1945) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1946) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1947) (T_BOOLEAN_AND 1948) (T_BOOLEAN_OR 1949) (T_COALESCE 1950) (T_DOUBLE_ARROW 6708) (T_INSTANCEOF 1951) (T_IS_EQUAL 1952) (T_IS_GREATER_OR_EQUAL 1953) (T_IS_IDENTICAL 1954) (T_IS_NOT_EQUAL 1955) (T_IS_NOT_IDENTICAL 1956) (T_IS_SMALLER_OR_EQUAL 1957) (T_LOGICAL_AND 1958) (T_LOGICAL_OR 1959) (T_LOGICAL_XOR 1960) (T_POW 1961) (T_SL 1962) (T_SPACESHIP 1963) (T_SR 1964) ("^" 1965) ("|" 1966)) 2845 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1935) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (array_object_dereferenceable 1908) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 6709) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 2846 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 6718) (T_VARIABLE 2900) (encaps_var 2914)) 2847 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 6717) (T_VARIABLE 2900) (encaps_var 2905)) 2848 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 6770) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2849 ((T_CLASS 6762)) 2850 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 6761) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 6731) (attribute 2980) (class_modifier 2945)) 2851 ((T_PAAMAYIM_NEKUDOTAYIM 6759)) 2852 (("(" 6750) (argument_list 6751) (ctor_arguments 6752)) 2853 ((T_NULLSAFE_OBJECT_OPERATOR 6738) (T_OBJECT_OPERATOR 6739) (T_PAAMAYIM_NEKUDOTAYIM 6740) ("[" 6741) ("{" 6742)) 2854 (("$" 1510) (T_STRING 1656) (T_VARIABLE 1528) (property_name 6749) (simple_variable 1658) ("{" 1659)) 2855 (("$" 1510) (T_STRING 1656) (T_VARIABLE 1528) (property_name 6748) (simple_variable 1658) ("{" 1659)) 2856 (("$" 1510) (T_VARIABLE 1528) (simple_variable 6747)) 2857 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 6745) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 2858 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 6743) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2859 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 6744)) 2860 (("]" 6746)) 2861 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 6753) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 6754) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 6755) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 2862 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 6758) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 2863 (("," 1469) (possible_comma 6756)) 2864 ((")" 6757)) 2865 (("$" 1510) (T_VARIABLE 1528) (simple_variable 6760)) 2866 (("(" 2982) (argument_list 2983) (ctor_arguments 6763)) 2867 ((T_EXTENDS 2985) (extends_from 6764)) 2868 ((T_IMPLEMENTS 2987) (implements_list 6765)) 2869 ((backup_doc_comment 6766)) 2870 (("{" 6767)) 2871 ((class_statement_list 6768)) 2872 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 6769)) 2873 (("%" 292) (")" 6771) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2874 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 6773) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2875 (("%" 292) (")" 6774) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2876 (("{" 6775)) 2877 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 6776) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 2878 (("}" 6777)) 2879 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 6779) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 2880 ((")" 6780)) 2881 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 6782) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 2882 (("," 5258) (possible_comma 6783)) 2883 ((")" 6784)) 2884 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 6791) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2885 ((")" 6792)) 2886 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 6794) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2887 (("%" 292) (")" 6795) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2888 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 6797) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2889 (("%" 292) (")" 6798) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2890 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 6806) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 2891 ((")" 6807)) 2892 (("%" 292) (")" 6812) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 2893 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 6815) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2894 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 6816)) 2895 (("\"" 6818) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 2896 (("$" 1667) (T_ABSTRACT 6821) (T_ARRAY 6822) (T_AS 6823) (T_BREAK 6824) (T_CALLABLE 6825) (T_CASE 6826) (T_CATCH 6827) (T_CLASS 6828) (T_CLASS_C 6829) (T_CLONE 6830) (T_CONST 6831) (T_CONTINUE 6832) (T_DECLARE 6833) (T_DEFAULT 6834) (T_DIR 6835) (T_DO 6836) (T_ECHO 6837) (T_ELSE 6838) (T_ELSEIF 6839) (T_EMPTY 6840) (T_ENDDECLARE 6841) (T_ENDFOR 6842) (T_ENDFOREACH 6843) (T_ENDIF 6844) (T_ENDSWITCH 6845) (T_ENDWHILE 6846) (T_ENUM 6847) (T_EVAL 6848) (T_EXIT 6849) (T_EXTENDS 6850) (T_FILE 6851) (T_FINAL 6852) (T_FINALLY 6853) (T_FN 6854) (T_FOR 6855) (T_FOREACH 6856) (T_FUNCTION 6857) (T_FUNC_C 6858) (T_GLOBAL 6859) (T_GOTO 6860) (T_IF 6861) (T_IMPLEMENTS 6862) (T_INCLUDE 6863) (T_INCLUDE_ONCE 6864) (T_INSTANCEOF 6865) (T_INSTEADOF 6866) (T_INTERFACE 6867) (T_ISSET 6868) (T_LINE 6869) (T_LIST 6870) (T_LOGICAL_AND 6871) (T_LOGICAL_OR 6872) (T_LOGICAL_XOR 6873) (T_MATCH 6874) (T_METHOD_C 6875) (T_NAMESPACE 6876) (T_NEW 6877) (T_NS_C 6878) (T_PRINT 6879) (T_PRIVATE 6880) (T_PROTECTED 6881) (T_PUBLIC 6882) (T_READONLY 6883) (T_REQUIRE 6884) (T_REQUIRE_ONCE 6885) (T_RETURN 6886) (T_STATIC 6887) (T_STRING 6888) (T_SWITCH 6889) (T_THROW 6890) (T_TRAIT 6891) (T_TRAIT_C 6892) (T_TRY 6893) (T_UNSET 6894) (T_USE 6895) (T_VAR 6896) (T_VARIABLE 1715) (T_WHILE 6897) (T_YIELD 6898) (identifier 6899) (member_name 6900) (reserved_non_modifiers 6901) (semi_reserved 6902) (simple_variable 6903) ("{" 6904)) 2897 (("(" 6907) (argument_list 6908)) 2898 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 6905) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2899 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 6906)) 2900 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 6909) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 6910) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 6911) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 2901 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 6914) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 2902 (("," 1469) (possible_comma 6912)) 2903 ((")" 6913)) 2904 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 6944) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 6945) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 2905 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 6943) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 2906 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 6942) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 2907 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 6941) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 2908 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 6940) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 2909 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 6939) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 2910 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 6938) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 2911 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 6937) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 2912 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 6936) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 2913 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 6935) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 2914 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 6934) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 2915 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 6933) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 2916 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 6932) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 2917 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 6931) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 2918 (("\"" 1509) ("$" 6946) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 6947) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 6948) ("[" 1529) (array_object_dereferenceable 6949) (callable_expr 6950) (callable_variable 6951) (class_constant 1533) (class_name 6952) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 6953) (name 6954) (simple_variable 6955) (static_member 6956) (variable 6957) (variable_class_name 6958)) 2919 (("$" 6946) (T_VARIABLE 6948) (simple_variable 6994) ("{" 6995)) 2920 (("(" 6962) (argument_list 6993)) 2921 ((T_NULLSAFE_OBJECT_OPERATOR 6976) (T_OBJECT_OPERATOR 6977) ("[" 6978) ("{" 6979)) 2922 (("(" 6962) (argument_list 6975)) 2923 ((T_PAAMAYIM_NEKUDOTAYIM 6971)) 2924 (("(" 6962) (argument_list 6970)) 2925 ((T_PAAMAYIM_NEKUDOTAYIM 6959)) 2926 (("$" 6946) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 6948) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 6960) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 6961) ("{" 1627)) 2927 (("(" 6962) (argument_list 6963)) 2928 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 6964) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 6965) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 6966) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 2929 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 6969) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 2930 (("," 1469) (possible_comma 6967)) 2931 ((")" 6968)) 2932 (("$" 6946) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 6948) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 6972) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 6973) ("{" 1643)) 2933 (("(" 6962) (argument_list 6974)) 2934 (("$" 6946) (T_STRING 6984) (T_VARIABLE 6948) (property_name 6991) (simple_variable 6986) ("{" 6987)) 2935 (("$" 6946) (T_STRING 6984) (T_VARIABLE 6948) (property_name 6985) (simple_variable 6986) ("{" 6987)) 2936 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 6982) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 2937 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 6980) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2938 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 6981)) 2939 (("]" 6983)) 2940 (("(" 6962) (argument_list 6990)) 2941 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 6988) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2942 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 6989)) 2943 (("(" 6962) (argument_list 6992)) 2944 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 6996) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 2945 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 6997)) 2946 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (possible_array_pair 6999) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 2947 ((backup_doc_comment 7002)) 2948 (("(" 7003)) 2949 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 7004)) 2950 ((")" 7005)) 2951 ((T_USE 159) (lexical_vars 7006)) 2952 ((":" 161) (return_type 7007)) 2953 ((backup_fn_flags 7008)) 2954 (("{" 7009)) 2955 ((inner_statement_list 7010)) 2956 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 7011) ("~" 125)) 2957 ((backup_fn_flags 7012)) 2958 ((backup_doc_comment 7014)) 2959 (("(" 7015)) 2960 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 7016)) 2961 ((")" 7017)) 2962 ((":" 2241) (return_type 7018)) 2963 ((T_DOUBLE_ARROW 7019)) 2964 ((backup_fn_flags 7020)) 2965 ((backup_lex_pos 7021)) 2966 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7084) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 2967 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7553) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 2968 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 7551) (encaps_var 5299)) 2969 (("$" 7024) (T_VARIABLE 7071) (simple_variable 7547) ("{" 7548)) 2970 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 7545) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 2971 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7544) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 2972 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7543) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 2973 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7542) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 2974 (("(" 7539)) 2975 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7538) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 2976 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7537) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 2977 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7536) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 2978 (("\"" 1509) ("$" 7327) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 7328) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 7329) ("[" 1529) (array_object_dereferenceable 7330) (callable_expr 7331) (callable_variable 7332) (class_constant 1533) (class_name 7333) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 7334) (name 7335) (simple_variable 7336) (static_member 7337) (variable 7535) (variable_class_name 7339)) 2979 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7534) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 2980 (("(" 7531)) 2981 (("(" 7528)) 2982 (("(" 7524) (exit_expr 7525)) 2983 (("\"" 1509) ("$" 7327) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 7328) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 7329) ("[" 1529) (array_object_dereferenceable 7330) (callable_expr 7331) (callable_variable 7332) (class_constant 1533) (class_name 7333) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 7334) (name 7335) (simple_variable 7336) (static_member 7337) (variable 7523) (variable_class_name 7339)) 2984 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7522) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 2985 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7521) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 2986 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7520) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 2987 (("(" 7516)) 2988 (("(" 7511)) 2989 (("(" 7505)) 2990 (("$" 7327) ("(" 7457) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 7458) (T_NAME_QUALIFIED 7459) (T_NAME_RELATIVE 7460) (T_READONLY 2936) (T_STATIC 7461) (T_STRING 7462) (T_VARIABLE 7329) (anonymous_class 7463) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 7464) (attribute 2943) (attributes 7465) (class_modifier 2945) (class_name 7466) (class_name_reference 7467) (name 7468) (new_variable 7469) (simple_variable 7470)) 2991 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7456) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 2992 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7455) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 2993 (("(" 7288) (argument_list 7454)) 2994 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7453) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 2995 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7452) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 2996 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 7447) (T_END_HEREDOC 7448) (T_VARIABLE 2900) (encaps_list 7449) (encaps_var 2902)) 2997 ((T_FN 35) (T_FUNCTION 127) (fn 7085) #'7086 (inline_function 7446)) 2998 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7445) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 2999 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7444) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3000 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7443) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3001 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7440) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3002 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7439) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3003 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 7435) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 3004 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 7433) (encaps_list 2805) (encaps_var 2806)) 3005 ((T_NULLSAFE_OBJECT_OPERATOR 7416) (T_OBJECT_OPERATOR 7417) ("[" 7418) ("{" 7419)) 3006 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 7413) (attribute 2728) (fn 7085) #'7086 (inline_function 7414)) 3007 (("(" 7288) (argument_list 7412)) 3008 ((T_PAAMAYIM_NEKUDOTAYIM 7404)) 3009 (("%" 7100) ("*" 7101) ("+" 7102) ("-" 7103) ("." 7104) ("/" 7105) ("<" 7106) (">" 7107) ("?" 7108) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 7109) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 7110) (T_BOOLEAN_AND 7111) (T_BOOLEAN_OR 7112) (T_COALESCE 7113) (T_INSTANCEOF 7114) (T_IS_EQUAL 7115) (T_IS_GREATER_OR_EQUAL 7116) (T_IS_IDENTICAL 7117) (T_IS_NOT_EQUAL 7118) (T_IS_NOT_IDENTICAL 7119) (T_IS_SMALLER_OR_EQUAL 7120) (T_LOGICAL_AND 7121) (T_LOGICAL_OR 7122) (T_LOGICAL_XOR 7123) (T_POW 7124) (T_SL 7125) (T_SPACESHIP 7126) (T_SR 7127) ("^" 7128) (backup_fn_flags 7403) ("|" 7129)) 3010 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 7392)) 3011 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 7380)) 3012 (("(" 7288) (argument_list 7379)) 3013 (("=" 7296) (T_AND_EQUAL 7297) (T_COALESCE_EQUAL 7298) (T_CONCAT_EQUAL 7299) (T_DEC 7300) (T_DIV_EQUAL 7301) (T_INC 7302) (T_MINUS_EQUAL 7303) (T_MOD_EQUAL 7304) (T_MUL_EQUAL 7305) (T_OR_EQUAL 7306) (T_PLUS_EQUAL 7307) (T_POW_EQUAL 7308) (T_SL_EQUAL 7309) (T_SR_EQUAL 7310) (T_XOR_EQUAL 7311)) 3014 ((T_PAAMAYIM_NEKUDOTAYIM 7201)) 3015 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7099) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3016 (("%" 7100) ("*" 7101) ("+" 7102) ("-" 7103) ("." 7104) ("/" 7105) ("<" 7106) (">" 7107) ("?" 7108) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 7109) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 7110) (T_BOOLEAN_AND 7111) (T_BOOLEAN_OR 7112) (T_COALESCE 7113) (T_INSTANCEOF 7114) (T_IS_EQUAL 7115) (T_IS_GREATER_OR_EQUAL 7116) (T_IS_IDENTICAL 7117) (T_IS_NOT_EQUAL 7118) (T_IS_NOT_IDENTICAL 7119) (T_IS_SMALLER_OR_EQUAL 7120) (T_LOGICAL_AND 7121) (T_LOGICAL_OR 7122) (T_LOGICAL_XOR 7123) (T_POW 7124) (T_SL 7125) (T_SPACESHIP 7126) (T_SR 7127) ("^" 7128) ("|" 7129)) 3017 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7200) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3018 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7199) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3019 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7198) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3020 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7197) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3021 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7196) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3022 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7195) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3023 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7194) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3024 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7193) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3025 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 7188) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 7189) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 3026 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7187) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3027 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7186) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3028 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7185) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3029 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7184) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3030 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7183) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3031 (("$" 7145) ("(" 7146) (T_NAME_FULLY_QUALIFIED 7147) (T_NAME_QUALIFIED 7148) (T_NAME_RELATIVE 7149) (T_STATIC 7150) (T_STRING 7151) (T_VARIABLE 7152) (class_name 7153) (class_name_reference 7154) (name 7155) (new_variable 7156) (simple_variable 7157)) 3032 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7144) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3033 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7143) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3034 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7142) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3035 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7141) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3036 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7140) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3037 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7139) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3038 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7138) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3039 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7137) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3040 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7136) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3041 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7135) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3042 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7134) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3043 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7133) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3044 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7132) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3045 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7131) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3046 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7130) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3047 (("$" 7145) (T_VARIABLE 7152) (simple_variable 7179) ("{" 7180)) 3048 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 7177) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 3049 ((T_PAAMAYIM_NEKUDOTAYIM 7175)) 3050 ((T_NULLSAFE_OBJECT_OPERATOR 7158) (T_OBJECT_OPERATOR 7159) (T_PAAMAYIM_NEKUDOTAYIM 7160) ("[" 7161) ("{" 7162)) 3051 (("$" 7145) (T_STRING 7168) (T_VARIABLE 7152) (property_name 7174) (simple_variable 7170) ("{" 7171)) 3052 (("$" 7145) (T_STRING 7168) (T_VARIABLE 7152) (property_name 7169) (simple_variable 7170) ("{" 7171)) 3053 (("$" 7145) (T_VARIABLE 7152) (simple_variable 7167)) 3054 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 7165) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 3055 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 7163) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3056 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 7164)) 3057 (("]" 7166)) 3058 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 7172) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3059 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 7173)) 3060 (("$" 7145) (T_VARIABLE 7152) (simple_variable 7176)) 3061 (("%" 292) (")" 7178) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 3062 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 7181) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3063 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 7182)) 3064 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7192) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3065 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 7190) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 3066 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7191) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3067 (("$" 7024) (T_ABSTRACT 7202) (T_ARRAY 7203) (T_AS 7204) (T_BREAK 7205) (T_CALLABLE 7206) (T_CASE 7207) (T_CATCH 7208) (T_CLASS 7209) (T_CLASS_C 7210) (T_CLONE 7211) (T_CONST 7212) (T_CONTINUE 7213) (T_DECLARE 7214) (T_DEFAULT 7215) (T_DIR 7216) (T_DO 7217) (T_ECHO 7218) (T_ELSE 7219) (T_ELSEIF 7220) (T_EMPTY 7221) (T_ENDDECLARE 7222) (T_ENDFOR 7223) (T_ENDFOREACH 7224) (T_ENDIF 7225) (T_ENDSWITCH 7226) (T_ENDWHILE 7227) (T_ENUM 7228) (T_EVAL 7229) (T_EXIT 7230) (T_EXTENDS 7231) (T_FILE 7232) (T_FINAL 7233) (T_FINALLY 7234) (T_FN 7235) (T_FOR 7236) (T_FOREACH 7237) (T_FUNCTION 7238) (T_FUNC_C 7239) (T_GLOBAL 7240) (T_GOTO 7241) (T_IF 7242) (T_IMPLEMENTS 7243) (T_INCLUDE 7244) (T_INCLUDE_ONCE 7245) (T_INSTANCEOF 7246) (T_INSTEADOF 7247) (T_INTERFACE 7248) (T_ISSET 7249) (T_LINE 7250) (T_LIST 7251) (T_LOGICAL_AND 7252) (T_LOGICAL_OR 7253) (T_LOGICAL_XOR 7254) (T_MATCH 7255) (T_METHOD_C 7256) (T_NAMESPACE 7257) (T_NEW 7258) (T_NS_C 7259) (T_PRINT 7260) (T_PRIVATE 7261) (T_PROTECTED 7262) (T_PUBLIC 7263) (T_READONLY 7264) (T_REQUIRE 7265) (T_REQUIRE_ONCE 7266) (T_RETURN 7267) (T_STATIC 7268) (T_STRING 7269) (T_SWITCH 7270) (T_THROW 7271) (T_TRAIT 7272) (T_TRAIT_C 7273) (T_TRY 7274) (T_UNSET 7275) (T_USE 7276) (T_VAR 7277) (T_VARIABLE 7071) (T_WHILE 7278) (T_YIELD 7279) (identifier 7280) (member_name 7281) (reserved_non_modifiers 7282) (semi_reserved 7283) (simple_variable 7284) ("{" 7285)) 3068 (("(" 7288) (argument_list 7289)) 3069 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 7286) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3070 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 7287)) 3071 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 7290) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 7291) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 7292) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3072 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 7295) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3073 (("," 1469) (possible_comma 7293)) 3074 ((")" 7294)) 3075 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (ampersand 7325) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7326) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3076 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7324) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3077 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7323) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3078 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7322) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3079 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7321) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3080 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7320) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3081 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7319) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3082 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7318) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3083 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7317) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3084 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7316) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3085 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7315) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3086 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7314) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3087 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7313) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3088 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7312) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3089 (("\"" 1509) ("$" 7327) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 7328) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 7329) ("[" 1529) (array_object_dereferenceable 7330) (callable_expr 7331) (callable_variable 7332) (class_constant 1533) (class_name 7333) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 7334) (name 7335) (simple_variable 7336) (static_member 7337) (variable 7338) (variable_class_name 7339)) 3090 (("$" 7327) (T_VARIABLE 7329) (simple_variable 7375) ("{" 7376)) 3091 (("(" 7343) (argument_list 7374)) 3092 ((T_NULLSAFE_OBJECT_OPERATOR 7357) (T_OBJECT_OPERATOR 7358) ("[" 7359) ("{" 7360)) 3093 (("(" 7343) (argument_list 7356)) 3094 ((T_PAAMAYIM_NEKUDOTAYIM 7352)) 3095 (("(" 7343) (argument_list 7351)) 3096 ((T_PAAMAYIM_NEKUDOTAYIM 7340)) 3097 (("$" 7327) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 7329) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 7341) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 7342) ("{" 1627)) 3098 (("(" 7343) (argument_list 7344)) 3099 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 7345) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 7346) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 7347) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3100 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 7350) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3101 (("," 1469) (possible_comma 7348)) 3102 ((")" 7349)) 3103 (("$" 7327) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 7329) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 7353) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 7354) ("{" 1643)) 3104 (("(" 7343) (argument_list 7355)) 3105 (("$" 7327) (T_STRING 7365) (T_VARIABLE 7329) (property_name 7372) (simple_variable 7367) ("{" 7368)) 3106 (("$" 7327) (T_STRING 7365) (T_VARIABLE 7329) (property_name 7366) (simple_variable 7367) ("{" 7368)) 3107 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 7363) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 3108 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 7361) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3109 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 7362)) 3110 (("]" 7364)) 3111 (("(" 7343) (argument_list 7371)) 3112 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 7369) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3113 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 7370)) 3114 (("(" 7343) (argument_list 7373)) 3115 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 7377) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3116 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 7378)) 3117 ((backup_doc_comment 7381)) 3118 (("(" 7382)) 3119 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 7383)) 3120 ((")" 7384)) 3121 ((T_USE 159) (lexical_vars 7385)) 3122 ((":" 161) (return_type 7386)) 3123 ((backup_fn_flags 7387)) 3124 (("{" 7388)) 3125 ((inner_statement_list 7389)) 3126 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 7390) ("~" 125)) 3127 ((backup_fn_flags 7391)) 3128 ((backup_doc_comment 7393)) 3129 (("(" 7394)) 3130 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 7395)) 3131 ((")" 7396)) 3132 ((":" 2241) (return_type 7397)) 3133 ((T_DOUBLE_ARROW 7398)) 3134 ((backup_fn_flags 7399)) 3135 ((backup_lex_pos 7400)) 3136 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7401) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3137 (("%" 7100) ("*" 7101) ("+" 7102) ("-" 7103) ("." 7104) ("/" 7105) ("<" 7106) (">" 7107) ("?" 7108) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 7109) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 7110) (T_BOOLEAN_AND 7111) (T_BOOLEAN_OR 7112) (T_COALESCE 7113) (T_INSTANCEOF 7114) (T_IS_EQUAL 7115) (T_IS_GREATER_OR_EQUAL 7116) (T_IS_IDENTICAL 7117) (T_IS_NOT_EQUAL 7118) (T_IS_NOT_IDENTICAL 7119) (T_IS_SMALLER_OR_EQUAL 7120) (T_LOGICAL_AND 7121) (T_LOGICAL_OR 7122) (T_LOGICAL_XOR 7123) (T_POW 7124) (T_SL 7125) (T_SPACESHIP 7126) (T_SR 7127) ("^" 7128) (backup_fn_flags 7402) ("|" 7129)) 3138 (("$" 7024) (T_ABSTRACT 7202) (T_ARRAY 7203) (T_AS 7204) (T_BREAK 7205) (T_CALLABLE 7206) (T_CASE 7207) (T_CATCH 7208) (T_CLASS 7209) (T_CLASS_C 7210) (T_CLONE 7211) (T_CONST 7212) (T_CONTINUE 7213) (T_DECLARE 7214) (T_DEFAULT 7215) (T_DIR 7216) (T_DO 7217) (T_ECHO 7218) (T_ELSE 7219) (T_ELSEIF 7220) (T_EMPTY 7221) (T_ENDDECLARE 7222) (T_ENDFOR 7223) (T_ENDFOREACH 7224) (T_ENDIF 7225) (T_ENDSWITCH 7226) (T_ENDWHILE 7227) (T_ENUM 7228) (T_EVAL 7229) (T_EXIT 7230) (T_EXTENDS 7231) (T_FILE 7232) (T_FINAL 7233) (T_FINALLY 7234) (T_FN 7235) (T_FOR 7236) (T_FOREACH 7237) (T_FUNCTION 7238) (T_FUNC_C 7239) (T_GLOBAL 7240) (T_GOTO 7241) (T_IF 7242) (T_IMPLEMENTS 7243) (T_INCLUDE 7244) (T_INCLUDE_ONCE 7245) (T_INSTANCEOF 7246) (T_INSTEADOF 7247) (T_INTERFACE 7248) (T_ISSET 7249) (T_LINE 7250) (T_LIST 7251) (T_LOGICAL_AND 7252) (T_LOGICAL_OR 7253) (T_LOGICAL_XOR 7254) (T_MATCH 7255) (T_METHOD_C 7256) (T_NAMESPACE 7257) (T_NEW 7258) (T_NS_C 7259) (T_PRINT 7260) (T_PRIVATE 7261) (T_PROTECTED 7262) (T_PUBLIC 7263) (T_READONLY 7264) (T_REQUIRE 7265) (T_REQUIRE_ONCE 7266) (T_RETURN 7267) (T_STATIC 7268) (T_STRING 7269) (T_SWITCH 7270) (T_THROW 7271) (T_TRAIT 7272) (T_TRAIT_C 7273) (T_TRY 7274) (T_UNSET 7275) (T_USE 7276) (T_VAR 7277) (T_VARIABLE 7071) (T_WHILE 7278) (T_YIELD 7279) (identifier 7405) (member_name 7406) (reserved_non_modifiers 7282) (semi_reserved 7283) (simple_variable 7407) ("{" 7408)) 3139 (("(" 7288) (argument_list 7411)) 3140 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 7409) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3141 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 7410)) 3142 ((T_FN 35) (T_FUNCTION 127) (fn 7085) #'7086 (inline_function 7415)) 3143 (("$" 7024) (T_STRING 7424) (T_VARIABLE 7071) (property_name 7431) (simple_variable 7426) ("{" 7427)) 3144 (("$" 7024) (T_STRING 7424) (T_VARIABLE 7071) (property_name 7425) (simple_variable 7426) ("{" 7427)) 3145 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 7422) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 3146 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 7420) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3147 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 7421)) 3148 (("]" 7423)) 3149 (("(" 7288) (argument_list 7430)) 3150 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 7428) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3151 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 7429)) 3152 (("(" 7288) (argument_list 7432)) 3153 (("`" 7434)) 3154 (("]" 7436)) 3155 (("=" 7437)) 3156 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7438) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3157 (("%" 7100) ("*" 7101) ("+" 7102) ("-" 7103) ("." 7104) ("/" 7105) ("<" 7106) (">" 7107) ("?" 7108) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 7109) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 7110) (T_BOOLEAN_AND 7111) (T_BOOLEAN_OR 7112) (T_COALESCE 7113) (T_DOUBLE_ARROW 7441) (T_INSTANCEOF 7114) (T_IS_EQUAL 7115) (T_IS_GREATER_OR_EQUAL 7116) (T_IS_IDENTICAL 7117) (T_IS_NOT_EQUAL 7118) (T_IS_NOT_IDENTICAL 7119) (T_IS_SMALLER_OR_EQUAL 7120) (T_LOGICAL_AND 7121) (T_LOGICAL_OR 7122) (T_LOGICAL_XOR 7123) (T_POW 7124) (T_SL 7125) (T_SPACESHIP 7126) (T_SR 7127) ("^" 7128) ("|" 7129)) 3158 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7442) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3159 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 7451) (T_VARIABLE 2900) (encaps_var 2914)) 3160 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 7450) (T_VARIABLE 2900) (encaps_var 2905)) 3161 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 7503) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 3162 ((T_CLASS 7495)) 3163 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 7494) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 7464) (attribute 2980) (class_modifier 2945)) 3164 ((T_PAAMAYIM_NEKUDOTAYIM 7492)) 3165 (("(" 7483) (argument_list 7484) (ctor_arguments 7485)) 3166 ((T_NULLSAFE_OBJECT_OPERATOR 7471) (T_OBJECT_OPERATOR 7472) (T_PAAMAYIM_NEKUDOTAYIM 7473) ("[" 7474) ("{" 7475)) 3167 (("$" 7327) (T_STRING 7365) (T_VARIABLE 7329) (property_name 7482) (simple_variable 7367) ("{" 7368)) 3168 (("$" 7327) (T_STRING 7365) (T_VARIABLE 7329) (property_name 7481) (simple_variable 7367) ("{" 7368)) 3169 (("$" 7327) (T_VARIABLE 7329) (simple_variable 7480)) 3170 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 7478) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 3171 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 7476) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3172 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 7477)) 3173 (("]" 7479)) 3174 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 7486) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 7487) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 7488) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3175 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 7491) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3176 (("," 1469) (possible_comma 7489)) 3177 ((")" 7490)) 3178 (("$" 7327) (T_VARIABLE 7329) (simple_variable 7493)) 3179 (("(" 2982) (argument_list 2983) (ctor_arguments 7496)) 3180 ((T_EXTENDS 2985) (extends_from 7497)) 3181 ((T_IMPLEMENTS 2987) (implements_list 7498)) 3182 ((backup_doc_comment 7499)) 3183 (("{" 7500)) 3184 ((class_statement_list 7501)) 3185 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 7502)) 3186 (("%" 292) (")" 7504) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 3187 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 7506) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 3188 (("%" 292) (")" 7507) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 3189 (("{" 7508)) 3190 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 7509) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 3191 (("}" 7510)) 3192 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 7512) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 3193 ((")" 7513)) 3194 (("=" 7514)) 3195 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 7515) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3196 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 7517) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3197 (("," 5258) (possible_comma 7518)) 3198 ((")" 7519)) 3199 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 7526) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 3200 ((")" 7527)) 3201 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 7529) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 3202 (("%" 292) (")" 7530) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 3203 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 7532) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 3204 (("%" 292) (")" 7533) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 3205 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 7540) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 3206 ((")" 7541)) 3207 (("%" 292) (")" 7546) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 3208 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 7549) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3209 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 7550)) 3210 (("\"" 7552) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 3211 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7583) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (ampersand 7609) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7618) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3212 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 8646) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3213 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 8644) (encaps_var 5299)) 3214 (("$" 7557) (T_VARIABLE 7604) (simple_variable 8640) ("{" 8641)) 3215 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 8638) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 3216 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 8637) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3217 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 8636) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3218 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 8635) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3219 (("(" 8632)) 3220 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 8631) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3221 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 8630) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3222 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 8629) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3223 (("\"" 1509) ("$" 7867) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 7868) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 7869) ("[" 1529) (array_object_dereferenceable 7870) (callable_expr 7871) (callable_variable 7872) (class_constant 1533) (class_name 7873) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 7874) (name 7875) (simple_variable 7876) (static_member 7877) (variable 8628) (variable_class_name 7879)) 3224 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 8627) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3225 (("(" 8624)) 3226 (("(" 8621)) 3227 (("(" 8617) (exit_expr 8618)) 3228 (("\"" 1509) ("$" 7867) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 7868) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 7869) ("[" 1529) (array_object_dereferenceable 7870) (callable_expr 7871) (callable_variable 7872) (class_constant 1533) (class_name 7873) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 7874) (name 7875) (simple_variable 7876) (static_member 7877) (variable 8616) (variable_class_name 7879)) 3229 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 8615) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3230 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 8614) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3231 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 8613) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3232 (("(" 8609)) 3233 (("(" 8606)) 3234 (("(" 8600)) 3235 (("$" 8246) ("(" 8376) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 8377) (T_NAME_QUALIFIED 8378) (T_NAME_RELATIVE 8379) (T_READONLY 2936) (T_STATIC 8380) (T_STRING 8381) (T_VARIABLE 8248) (anonymous_class 8578) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 8579) (attribute 2943) (attributes 8580) (class_modifier 2945) (class_name 8385) (class_name_reference 8581) (name 8387) (new_variable 8388) (simple_variable 8389)) 3236 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 8577) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3237 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 8576) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3238 (("(" 7828) (argument_list 8575)) 3239 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 8574) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3240 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 8573) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3241 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 8568) (T_END_HEREDOC 8569) (T_VARIABLE 2900) (encaps_list 8570) (encaps_var 2902)) 3242 ((T_FN 35) (T_FUNCTION 127) (fn 7619) #'7620 (inline_function 8567)) 3243 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 8566) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3244 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 8565) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3245 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 8564) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3246 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 8561) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 3247 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 8560) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3248 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 8556) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 3249 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 8554) (encaps_list 2805) (encaps_var 2806)) 3250 (("\"" 1509) ("$" 8502) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 8503) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 8504) ("[" 1529) (array_object_dereferenceable 8505) (callable_expr 8506) (callable_variable 8507) (class_constant 1533) (class_name 8508) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 8509) (name 8510) (simple_variable 8511) (static_member 8512) (variable 8513) (variable_class_name 8514)) 3251 ((T_NULLSAFE_OBJECT_OPERATOR 8485) (T_OBJECT_OPERATOR 8486) ("[" 8487) ("{" 8488)) 3252 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 8482) (attribute 2728) (fn 7619) #'7620 (inline_function 8483)) 3253 (("(" 7828) (argument_list 8481)) 3254 ((T_PAAMAYIM_NEKUDOTAYIM 8473)) 3255 (("%" 7635) ("*" 7636) ("+" 7637) ("-" 7638) ("." 7639) ("/" 7640) ("<" 7641) (">" 7642) ("?" 7643) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 7644) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 7645) (T_BOOLEAN_AND 7646) (T_BOOLEAN_OR 7647) (T_COALESCE 7648) (T_INSTANCEOF 7649) (T_IS_EQUAL 7650) (T_IS_GREATER_OR_EQUAL 7651) (T_IS_IDENTICAL 7652) (T_IS_NOT_EQUAL 7653) (T_IS_NOT_IDENTICAL 7654) (T_IS_SMALLER_OR_EQUAL 7655) (T_LOGICAL_AND 7656) (T_LOGICAL_OR 7657) (T_LOGICAL_XOR 7658) (T_POW 7659) (T_SL 7660) (T_SPACESHIP 7661) (T_SR 7662) ("^" 7663) ("|" 7664)) 3256 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 7932)) 3257 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 7920)) 3258 (("(" 7828) (argument_list 7919)) 3259 (("=" 7836) (T_AND_EQUAL 7837) (T_COALESCE_EQUAL 7838) (T_CONCAT_EQUAL 7839) (T_DEC 7840) (T_DIV_EQUAL 7841) (T_INC 7842) (T_MINUS_EQUAL 7843) (T_MOD_EQUAL 7844) (T_MUL_EQUAL 7845) (T_OR_EQUAL 7846) (T_PLUS_EQUAL 7847) (T_POW_EQUAL 7848) (T_SL_EQUAL 7849) (T_SR_EQUAL 7850) (T_XOR_EQUAL 7851)) 3260 ((T_PAAMAYIM_NEKUDOTAYIM 7741)) 3261 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7634) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3262 (("(" 7736)) 3263 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7735) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3264 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7734) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3265 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7733) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3266 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7732) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3267 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7731) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3268 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7730) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3269 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7729) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3270 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7728) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3271 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 7723) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 7724) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 3272 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7722) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3273 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7721) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3274 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7720) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3275 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7719) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3276 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7718) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3277 (("$" 7680) ("(" 7681) (T_NAME_FULLY_QUALIFIED 7682) (T_NAME_QUALIFIED 7683) (T_NAME_RELATIVE 7684) (T_STATIC 7685) (T_STRING 7686) (T_VARIABLE 7687) (class_name 7688) (class_name_reference 7689) (name 7690) (new_variable 7691) (simple_variable 7692)) 3278 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7679) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3279 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7678) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3280 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7677) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3281 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7676) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3282 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7675) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3283 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7674) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3284 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7673) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3285 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7672) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3286 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7671) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3287 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7670) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3288 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7669) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3289 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7668) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3290 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7667) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3291 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7666) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3292 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7665) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3293 (("$" 7680) (T_VARIABLE 7687) (simple_variable 7714) ("{" 7715)) 3294 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 7712) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 3295 ((T_PAAMAYIM_NEKUDOTAYIM 7710)) 3296 ((T_NULLSAFE_OBJECT_OPERATOR 7693) (T_OBJECT_OPERATOR 7694) (T_PAAMAYIM_NEKUDOTAYIM 7695) ("[" 7696) ("{" 7697)) 3297 (("$" 7680) (T_STRING 7703) (T_VARIABLE 7687) (property_name 7709) (simple_variable 7705) ("{" 7706)) 3298 (("$" 7680) (T_STRING 7703) (T_VARIABLE 7687) (property_name 7704) (simple_variable 7705) ("{" 7706)) 3299 (("$" 7680) (T_VARIABLE 7687) (simple_variable 7702)) 3300 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 7700) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 3301 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 7698) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3302 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 7699)) 3303 (("]" 7701)) 3304 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 7707) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3305 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 7708)) 3306 (("$" 7680) (T_VARIABLE 7687) (simple_variable 7711)) 3307 (("%" 292) (")" 7713) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 3308 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 7716) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3309 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 7717)) 3310 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7727) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3311 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 7725) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 3312 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7726) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3313 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 7737) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 3314 ((")" 7738)) 3315 (("=" 7739)) 3316 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7740) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3317 (("$" 7557) (T_ABSTRACT 7742) (T_ARRAY 7743) (T_AS 7744) (T_BREAK 7745) (T_CALLABLE 7746) (T_CASE 7747) (T_CATCH 7748) (T_CLASS 7749) (T_CLASS_C 7750) (T_CLONE 7751) (T_CONST 7752) (T_CONTINUE 7753) (T_DECLARE 7754) (T_DEFAULT 7755) (T_DIR 7756) (T_DO 7757) (T_ECHO 7758) (T_ELSE 7759) (T_ELSEIF 7760) (T_EMPTY 7761) (T_ENDDECLARE 7762) (T_ENDFOR 7763) (T_ENDFOREACH 7764) (T_ENDIF 7765) (T_ENDSWITCH 7766) (T_ENDWHILE 7767) (T_ENUM 7768) (T_EVAL 7769) (T_EXIT 7770) (T_EXTENDS 7771) (T_FILE 7772) (T_FINAL 7773) (T_FINALLY 7774) (T_FN 7775) (T_FOR 7776) (T_FOREACH 7777) (T_FUNCTION 7778) (T_FUNC_C 7779) (T_GLOBAL 7780) (T_GOTO 7781) (T_IF 7782) (T_IMPLEMENTS 7783) (T_INCLUDE 7784) (T_INCLUDE_ONCE 7785) (T_INSTANCEOF 7786) (T_INSTEADOF 7787) (T_INTERFACE 7788) (T_ISSET 7789) (T_LINE 7790) (T_LIST 7791) (T_LOGICAL_AND 7792) (T_LOGICAL_OR 7793) (T_LOGICAL_XOR 7794) (T_MATCH 7795) (T_METHOD_C 7796) (T_NAMESPACE 7797) (T_NEW 7798) (T_NS_C 7799) (T_PRINT 7800) (T_PRIVATE 7801) (T_PROTECTED 7802) (T_PUBLIC 7803) (T_READONLY 7804) (T_REQUIRE 7805) (T_REQUIRE_ONCE 7806) (T_RETURN 7807) (T_STATIC 7808) (T_STRING 7809) (T_SWITCH 7810) (T_THROW 7811) (T_TRAIT 7812) (T_TRAIT_C 7813) (T_TRY 7814) (T_UNSET 7815) (T_USE 7816) (T_VAR 7817) (T_VARIABLE 7604) (T_WHILE 7818) (T_YIELD 7819) (identifier 7820) (member_name 7821) (reserved_non_modifiers 7822) (semi_reserved 7823) (simple_variable 7824) ("{" 7825)) 3318 (("(" 7828) (argument_list 7829)) 3319 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 7826) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3320 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 7827)) 3321 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 7830) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 7831) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 7832) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3322 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 7835) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3323 (("," 1469) (possible_comma 7833)) 3324 ((")" 7834)) 3325 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (ampersand 7865) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7866) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3326 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7864) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3327 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7863) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3328 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7862) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3329 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7861) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3330 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7860) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3331 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7859) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3332 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7858) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3333 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7857) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3334 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7856) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3335 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7855) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3336 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7854) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3337 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7853) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3338 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 7852) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3339 (("\"" 1509) ("$" 7867) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 7868) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 7869) ("[" 1529) (array_object_dereferenceable 7870) (callable_expr 7871) (callable_variable 7872) (class_constant 1533) (class_name 7873) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 7874) (name 7875) (simple_variable 7876) (static_member 7877) (variable 7878) (variable_class_name 7879)) 3340 (("$" 7867) (T_VARIABLE 7869) (simple_variable 7915) ("{" 7916)) 3341 (("(" 7883) (argument_list 7914)) 3342 ((T_NULLSAFE_OBJECT_OPERATOR 7897) (T_OBJECT_OPERATOR 7898) ("[" 7899) ("{" 7900)) 3343 (("(" 7883) (argument_list 7896)) 3344 ((T_PAAMAYIM_NEKUDOTAYIM 7892)) 3345 (("(" 7883) (argument_list 7891)) 3346 ((T_PAAMAYIM_NEKUDOTAYIM 7880)) 3347 (("$" 7867) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 7869) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 7881) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 7882) ("{" 1627)) 3348 (("(" 7883) (argument_list 7884)) 3349 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 7885) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 7886) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 7887) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3350 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 7890) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3351 (("," 1469) (possible_comma 7888)) 3352 ((")" 7889)) 3353 (("$" 7867) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 7869) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 7893) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 7894) ("{" 1643)) 3354 (("(" 7883) (argument_list 7895)) 3355 (("$" 7867) (T_STRING 7905) (T_VARIABLE 7869) (property_name 7912) (simple_variable 7907) ("{" 7908)) 3356 (("$" 7867) (T_STRING 7905) (T_VARIABLE 7869) (property_name 7906) (simple_variable 7907) ("{" 7908)) 3357 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 7903) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 3358 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 7901) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3359 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 7902)) 3360 (("]" 7904)) 3361 (("(" 7883) (argument_list 7911)) 3362 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 7909) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3363 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 7910)) 3364 (("(" 7883) (argument_list 7913)) 3365 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 7917) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3366 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 7918)) 3367 ((backup_doc_comment 7921)) 3368 (("(" 7922)) 3369 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 7923)) 3370 ((")" 7924)) 3371 ((T_USE 159) (lexical_vars 7925)) 3372 ((":" 161) (return_type 7926)) 3373 ((backup_fn_flags 7927)) 3374 (("{" 7928)) 3375 ((inner_statement_list 7929)) 3376 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 7930) ("~" 125)) 3377 ((backup_fn_flags 7931)) 3378 ((backup_doc_comment 7933)) 3379 (("(" 7934)) 3380 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 7935)) 3381 ((")" 7936)) 3382 ((":" 2241) (return_type 7937)) 3383 ((T_DOUBLE_ARROW 7938)) 3384 ((backup_fn_flags 7939)) 3385 ((backup_lex_pos 7940)) 3386 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8003) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3387 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8472) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3388 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 8470) (encaps_var 5299)) 3389 (("$" 7943) (T_VARIABLE 7990) (simple_variable 8466) ("{" 8467)) 3390 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 8464) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 3391 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8463) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3392 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8462) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3393 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8461) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3394 (("(" 8458)) 3395 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8457) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3396 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8456) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3397 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8455) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3398 (("\"" 1509) ("$" 8246) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 8247) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 8248) ("[" 1529) (array_object_dereferenceable 8249) (callable_expr 8250) (callable_variable 8251) (class_constant 1533) (class_name 8252) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 8253) (name 8254) (simple_variable 8255) (static_member 8256) (variable 8454) (variable_class_name 8258)) 3399 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8453) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3400 (("(" 8450)) 3401 (("(" 8447)) 3402 (("(" 8443) (exit_expr 8444)) 3403 (("\"" 1509) ("$" 8246) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 8247) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 8248) ("[" 1529) (array_object_dereferenceable 8249) (callable_expr 8250) (callable_variable 8251) (class_constant 1533) (class_name 8252) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 8253) (name 8254) (simple_variable 8255) (static_member 8256) (variable 8442) (variable_class_name 8258)) 3404 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8441) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3405 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8440) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3406 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8439) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3407 (("(" 8435)) 3408 (("(" 8430)) 3409 (("(" 8424)) 3410 (("$" 8246) ("(" 8376) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 8377) (T_NAME_QUALIFIED 8378) (T_NAME_RELATIVE 8379) (T_READONLY 2936) (T_STATIC 8380) (T_STRING 8381) (T_VARIABLE 8248) (anonymous_class 8382) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 8383) (attribute 2943) (attributes 8384) (class_modifier 2945) (class_name 8385) (class_name_reference 8386) (name 8387) (new_variable 8388) (simple_variable 8389)) 3411 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8375) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3412 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8374) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3413 (("(" 8207) (argument_list 8373)) 3414 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8372) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3415 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8371) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3416 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 8366) (T_END_HEREDOC 8367) (T_VARIABLE 2900) (encaps_list 8368) (encaps_var 2902)) 3417 ((T_FN 35) (T_FUNCTION 127) (fn 8004) #'8005 (inline_function 8365)) 3418 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8364) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3419 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8363) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3420 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8362) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3421 (("!" 7022) ("\"" 7023) ("$" 7024) ("(" 7025) ("+" 7026) ("-" 7027) ("@" 7028) (T_ARRAY 7029) (T_ARRAY_CAST 7030) (T_ATTRIBUTE 126) (T_BOOL_CAST 7031) (T_CLASS_C 7032) (T_CLONE 7033) (T_CONSTANT_ENCAPSED_STRING 7034) (T_DEC 7035) (T_DIR 7036) (T_DNUMBER 7037) (T_DOUBLE_CAST 7038) (T_EMPTY 7039) (T_EVAL 7040) (T_EXIT 7041) (T_FILE 7042) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7043) (T_INC 7044) (T_INCLUDE 7045) (T_INCLUDE_ONCE 7046) (T_INT_CAST 7047) (T_ISSET 7048) (T_LINE 7049) (T_LIST 7050) (T_LNUMBER 7051) (T_MATCH 7052) (T_METHOD_C 7053) (T_NAME_FULLY_QUALIFIED 7054) (T_NAME_QUALIFIED 7055) (T_NAME_RELATIVE 7056) (T_NEW 7057) (T_NS_C 7058) (T_OBJECT_CAST 7059) (T_PRINT 7060) (T_READONLY 7061) (T_REQUIRE 7062) (T_REQUIRE_ONCE 7063) (T_START_HEREDOC 7064) (T_STATIC 7065) (T_STRING 7066) (T_STRING_CAST 7067) (T_THROW 7068) (T_TRAIT_C 7069) (T_UNSET_CAST 7070) (T_VARIABLE 7071) (T_YIELD 7072) (T_YIELD_FROM 7073) ("[" 7074) ("`" 7075) (array_object_dereferenceable 7076) (attribute 131) (attributes 7077) (callable_expr 7078) (callable_variable 7079) (class_constant 7080) (class_name 7081) (constant 7082) (dereferenceable_scalar 7083) (expr 8359) (fn 7085) (fully_dereferenceable 104) #'7086 (function_call 7087) (inline_function 7088) (internal_functions_in_yacc 7089) (match 7090) (name 7091) (new_expr 7092) (scalar 7093) (simple_variable 7094) (static_member 7095) (variable 7096) (variable_class_name 7097) ("~" 7098)) 3422 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8358) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3423 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 8354) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 3424 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 8352) (encaps_list 2805) (encaps_var 2806)) 3425 ((T_NULLSAFE_OBJECT_OPERATOR 8335) (T_OBJECT_OPERATOR 8336) ("[" 8337) ("{" 8338)) 3426 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 8332) (attribute 2728) (fn 8004) #'8005 (inline_function 8333)) 3427 (("(" 8207) (argument_list 8331)) 3428 ((T_PAAMAYIM_NEKUDOTAYIM 8323)) 3429 (("%" 8019) ("*" 8020) ("+" 8021) ("-" 8022) ("." 8023) ("/" 8024) ("<" 8025) (">" 8026) ("?" 8027) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 8028) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 8029) (T_BOOLEAN_AND 8030) (T_BOOLEAN_OR 8031) (T_COALESCE 8032) (T_INSTANCEOF 8033) (T_IS_EQUAL 8034) (T_IS_GREATER_OR_EQUAL 8035) (T_IS_IDENTICAL 8036) (T_IS_NOT_EQUAL 8037) (T_IS_NOT_IDENTICAL 8038) (T_IS_SMALLER_OR_EQUAL 8039) (T_LOGICAL_AND 8040) (T_LOGICAL_OR 8041) (T_LOGICAL_XOR 8042) (T_POW 8043) (T_SL 8044) (T_SPACESHIP 8045) (T_SR 8046) ("^" 8047) (backup_fn_flags 8322) ("|" 8048)) 3430 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 8311)) 3431 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 8299)) 3432 (("(" 8207) (argument_list 8298)) 3433 (("=" 8215) (T_AND_EQUAL 8216) (T_COALESCE_EQUAL 8217) (T_CONCAT_EQUAL 8218) (T_DEC 8219) (T_DIV_EQUAL 8220) (T_INC 8221) (T_MINUS_EQUAL 8222) (T_MOD_EQUAL 8223) (T_MUL_EQUAL 8224) (T_OR_EQUAL 8225) (T_PLUS_EQUAL 8226) (T_POW_EQUAL 8227) (T_SL_EQUAL 8228) (T_SR_EQUAL 8229) (T_XOR_EQUAL 8230)) 3434 ((T_PAAMAYIM_NEKUDOTAYIM 8120)) 3435 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8018) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3436 (("%" 8019) ("*" 8020) ("+" 8021) ("-" 8022) ("." 8023) ("/" 8024) ("<" 8025) (">" 8026) ("?" 8027) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 8028) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 8029) (T_BOOLEAN_AND 8030) (T_BOOLEAN_OR 8031) (T_COALESCE 8032) (T_INSTANCEOF 8033) (T_IS_EQUAL 8034) (T_IS_GREATER_OR_EQUAL 8035) (T_IS_IDENTICAL 8036) (T_IS_NOT_EQUAL 8037) (T_IS_NOT_IDENTICAL 8038) (T_IS_SMALLER_OR_EQUAL 8039) (T_LOGICAL_AND 8040) (T_LOGICAL_OR 8041) (T_LOGICAL_XOR 8042) (T_POW 8043) (T_SL 8044) (T_SPACESHIP 8045) (T_SR 8046) ("^" 8047) ("|" 8048)) 3437 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8119) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3438 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8118) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3439 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8117) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3440 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8116) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3441 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8115) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3442 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8114) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3443 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8113) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3444 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8112) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3445 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 8107) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 8108) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 3446 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8106) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3447 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8105) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3448 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8104) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3449 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8103) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3450 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8102) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3451 (("$" 8064) ("(" 8065) (T_NAME_FULLY_QUALIFIED 8066) (T_NAME_QUALIFIED 8067) (T_NAME_RELATIVE 8068) (T_STATIC 8069) (T_STRING 8070) (T_VARIABLE 8071) (class_name 8072) (class_name_reference 8073) (name 8074) (new_variable 8075) (simple_variable 8076)) 3452 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8063) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3453 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8062) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3454 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8061) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3455 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8060) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3456 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8059) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3457 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8058) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3458 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8057) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3459 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8056) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3460 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8055) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3461 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8054) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3462 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8053) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3463 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8052) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3464 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8051) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3465 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8050) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3466 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8049) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3467 (("$" 8064) (T_VARIABLE 8071) (simple_variable 8098) ("{" 8099)) 3468 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 8096) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 3469 ((T_PAAMAYIM_NEKUDOTAYIM 8094)) 3470 ((T_NULLSAFE_OBJECT_OPERATOR 8077) (T_OBJECT_OPERATOR 8078) (T_PAAMAYIM_NEKUDOTAYIM 8079) ("[" 8080) ("{" 8081)) 3471 (("$" 8064) (T_STRING 8087) (T_VARIABLE 8071) (property_name 8093) (simple_variable 8089) ("{" 8090)) 3472 (("$" 8064) (T_STRING 8087) (T_VARIABLE 8071) (property_name 8088) (simple_variable 8089) ("{" 8090)) 3473 (("$" 8064) (T_VARIABLE 8071) (simple_variable 8086)) 3474 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 8084) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 3475 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 8082) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3476 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 8083)) 3477 (("]" 8085)) 3478 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 8091) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3479 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 8092)) 3480 (("$" 8064) (T_VARIABLE 8071) (simple_variable 8095)) 3481 (("%" 292) (")" 8097) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 3482 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 8100) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3483 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 8101)) 3484 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8111) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3485 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 8109) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 3486 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8110) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3487 (("$" 7943) (T_ABSTRACT 8121) (T_ARRAY 8122) (T_AS 8123) (T_BREAK 8124) (T_CALLABLE 8125) (T_CASE 8126) (T_CATCH 8127) (T_CLASS 8128) (T_CLASS_C 8129) (T_CLONE 8130) (T_CONST 8131) (T_CONTINUE 8132) (T_DECLARE 8133) (T_DEFAULT 8134) (T_DIR 8135) (T_DO 8136) (T_ECHO 8137) (T_ELSE 8138) (T_ELSEIF 8139) (T_EMPTY 8140) (T_ENDDECLARE 8141) (T_ENDFOR 8142) (T_ENDFOREACH 8143) (T_ENDIF 8144) (T_ENDSWITCH 8145) (T_ENDWHILE 8146) (T_ENUM 8147) (T_EVAL 8148) (T_EXIT 8149) (T_EXTENDS 8150) (T_FILE 8151) (T_FINAL 8152) (T_FINALLY 8153) (T_FN 8154) (T_FOR 8155) (T_FOREACH 8156) (T_FUNCTION 8157) (T_FUNC_C 8158) (T_GLOBAL 8159) (T_GOTO 8160) (T_IF 8161) (T_IMPLEMENTS 8162) (T_INCLUDE 8163) (T_INCLUDE_ONCE 8164) (T_INSTANCEOF 8165) (T_INSTEADOF 8166) (T_INTERFACE 8167) (T_ISSET 8168) (T_LINE 8169) (T_LIST 8170) (T_LOGICAL_AND 8171) (T_LOGICAL_OR 8172) (T_LOGICAL_XOR 8173) (T_MATCH 8174) (T_METHOD_C 8175) (T_NAMESPACE 8176) (T_NEW 8177) (T_NS_C 8178) (T_PRINT 8179) (T_PRIVATE 8180) (T_PROTECTED 8181) (T_PUBLIC 8182) (T_READONLY 8183) (T_REQUIRE 8184) (T_REQUIRE_ONCE 8185) (T_RETURN 8186) (T_STATIC 8187) (T_STRING 8188) (T_SWITCH 8189) (T_THROW 8190) (T_TRAIT 8191) (T_TRAIT_C 8192) (T_TRY 8193) (T_UNSET 8194) (T_USE 8195) (T_VAR 8196) (T_VARIABLE 7990) (T_WHILE 8197) (T_YIELD 8198) (identifier 8199) (member_name 8200) (reserved_non_modifiers 8201) (semi_reserved 8202) (simple_variable 8203) ("{" 8204)) 3488 (("(" 8207) (argument_list 8208)) 3489 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 8205) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3490 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 8206)) 3491 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 8209) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 8210) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 8211) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3492 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 8214) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3493 (("," 1469) (possible_comma 8212)) 3494 ((")" 8213)) 3495 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (ampersand 8244) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8245) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3496 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8243) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3497 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8242) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3498 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8241) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3499 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8240) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3500 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8239) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3501 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8238) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3502 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8237) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3503 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8236) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3504 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8235) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3505 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8234) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3506 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8233) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3507 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8232) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3508 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8231) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3509 (("\"" 1509) ("$" 8246) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 8247) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 8248) ("[" 1529) (array_object_dereferenceable 8249) (callable_expr 8250) (callable_variable 8251) (class_constant 1533) (class_name 8252) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 8253) (name 8254) (simple_variable 8255) (static_member 8256) (variable 8257) (variable_class_name 8258)) 3510 (("$" 8246) (T_VARIABLE 8248) (simple_variable 8294) ("{" 8295)) 3511 (("(" 8262) (argument_list 8293)) 3512 ((T_NULLSAFE_OBJECT_OPERATOR 8276) (T_OBJECT_OPERATOR 8277) ("[" 8278) ("{" 8279)) 3513 (("(" 8262) (argument_list 8275)) 3514 ((T_PAAMAYIM_NEKUDOTAYIM 8271)) 3515 (("(" 8262) (argument_list 8270)) 3516 ((T_PAAMAYIM_NEKUDOTAYIM 8259)) 3517 (("$" 8246) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 8248) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 8260) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 8261) ("{" 1627)) 3518 (("(" 8262) (argument_list 8263)) 3519 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 8264) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 8265) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 8266) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3520 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 8269) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3521 (("," 1469) (possible_comma 8267)) 3522 ((")" 8268)) 3523 (("$" 8246) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 8248) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 8272) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 8273) ("{" 1643)) 3524 (("(" 8262) (argument_list 8274)) 3525 (("$" 8246) (T_STRING 8284) (T_VARIABLE 8248) (property_name 8291) (simple_variable 8286) ("{" 8287)) 3526 (("$" 8246) (T_STRING 8284) (T_VARIABLE 8248) (property_name 8285) (simple_variable 8286) ("{" 8287)) 3527 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 8282) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 3528 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 8280) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3529 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 8281)) 3530 (("]" 8283)) 3531 (("(" 8262) (argument_list 8290)) 3532 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 8288) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3533 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 8289)) 3534 (("(" 8262) (argument_list 8292)) 3535 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 8296) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3536 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 8297)) 3537 ((backup_doc_comment 8300)) 3538 (("(" 8301)) 3539 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 8302)) 3540 ((")" 8303)) 3541 ((T_USE 159) (lexical_vars 8304)) 3542 ((":" 161) (return_type 8305)) 3543 ((backup_fn_flags 8306)) 3544 (("{" 8307)) 3545 ((inner_statement_list 8308)) 3546 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 8309) ("~" 125)) 3547 ((backup_fn_flags 8310)) 3548 ((backup_doc_comment 8312)) 3549 (("(" 8313)) 3550 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 8314)) 3551 ((")" 8315)) 3552 ((":" 2241) (return_type 8316)) 3553 ((T_DOUBLE_ARROW 8317)) 3554 ((backup_fn_flags 8318)) 3555 ((backup_lex_pos 8319)) 3556 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8320) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3557 (("%" 8019) ("*" 8020) ("+" 8021) ("-" 8022) ("." 8023) ("/" 8024) ("<" 8025) (">" 8026) ("?" 8027) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 8028) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 8029) (T_BOOLEAN_AND 8030) (T_BOOLEAN_OR 8031) (T_COALESCE 8032) (T_INSTANCEOF 8033) (T_IS_EQUAL 8034) (T_IS_GREATER_OR_EQUAL 8035) (T_IS_IDENTICAL 8036) (T_IS_NOT_EQUAL 8037) (T_IS_NOT_IDENTICAL 8038) (T_IS_SMALLER_OR_EQUAL 8039) (T_LOGICAL_AND 8040) (T_LOGICAL_OR 8041) (T_LOGICAL_XOR 8042) (T_POW 8043) (T_SL 8044) (T_SPACESHIP 8045) (T_SR 8046) ("^" 8047) (backup_fn_flags 8321) ("|" 8048)) 3558 (("$" 7943) (T_ABSTRACT 8121) (T_ARRAY 8122) (T_AS 8123) (T_BREAK 8124) (T_CALLABLE 8125) (T_CASE 8126) (T_CATCH 8127) (T_CLASS 8128) (T_CLASS_C 8129) (T_CLONE 8130) (T_CONST 8131) (T_CONTINUE 8132) (T_DECLARE 8133) (T_DEFAULT 8134) (T_DIR 8135) (T_DO 8136) (T_ECHO 8137) (T_ELSE 8138) (T_ELSEIF 8139) (T_EMPTY 8140) (T_ENDDECLARE 8141) (T_ENDFOR 8142) (T_ENDFOREACH 8143) (T_ENDIF 8144) (T_ENDSWITCH 8145) (T_ENDWHILE 8146) (T_ENUM 8147) (T_EVAL 8148) (T_EXIT 8149) (T_EXTENDS 8150) (T_FILE 8151) (T_FINAL 8152) (T_FINALLY 8153) (T_FN 8154) (T_FOR 8155) (T_FOREACH 8156) (T_FUNCTION 8157) (T_FUNC_C 8158) (T_GLOBAL 8159) (T_GOTO 8160) (T_IF 8161) (T_IMPLEMENTS 8162) (T_INCLUDE 8163) (T_INCLUDE_ONCE 8164) (T_INSTANCEOF 8165) (T_INSTEADOF 8166) (T_INTERFACE 8167) (T_ISSET 8168) (T_LINE 8169) (T_LIST 8170) (T_LOGICAL_AND 8171) (T_LOGICAL_OR 8172) (T_LOGICAL_XOR 8173) (T_MATCH 8174) (T_METHOD_C 8175) (T_NAMESPACE 8176) (T_NEW 8177) (T_NS_C 8178) (T_PRINT 8179) (T_PRIVATE 8180) (T_PROTECTED 8181) (T_PUBLIC 8182) (T_READONLY 8183) (T_REQUIRE 8184) (T_REQUIRE_ONCE 8185) (T_RETURN 8186) (T_STATIC 8187) (T_STRING 8188) (T_SWITCH 8189) (T_THROW 8190) (T_TRAIT 8191) (T_TRAIT_C 8192) (T_TRY 8193) (T_UNSET 8194) (T_USE 8195) (T_VAR 8196) (T_VARIABLE 7990) (T_WHILE 8197) (T_YIELD 8198) (identifier 8324) (member_name 8325) (reserved_non_modifiers 8201) (semi_reserved 8202) (simple_variable 8326) ("{" 8327)) 3559 (("(" 8207) (argument_list 8330)) 3560 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 8328) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3561 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 8329)) 3562 ((T_FN 35) (T_FUNCTION 127) (fn 8004) #'8005 (inline_function 8334)) 3563 (("$" 7943) (T_STRING 8343) (T_VARIABLE 7990) (property_name 8350) (simple_variable 8345) ("{" 8346)) 3564 (("$" 7943) (T_STRING 8343) (T_VARIABLE 7990) (property_name 8344) (simple_variable 8345) ("{" 8346)) 3565 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 8341) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 3566 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 8339) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3567 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 8340)) 3568 (("]" 8342)) 3569 (("(" 8207) (argument_list 8349)) 3570 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 8347) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3571 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 8348)) 3572 (("(" 8207) (argument_list 8351)) 3573 (("`" 8353)) 3574 (("]" 8355)) 3575 (("=" 8356)) 3576 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8357) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3577 (("%" 7100) ("*" 7101) ("+" 7102) ("-" 7103) ("." 7104) ("/" 7105) ("<" 7106) (">" 7107) ("?" 7108) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 7109) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 7110) (T_BOOLEAN_AND 7111) (T_BOOLEAN_OR 7112) (T_COALESCE 7113) (T_DOUBLE_ARROW 8360) (T_INSTANCEOF 7114) (T_IS_EQUAL 7115) (T_IS_GREATER_OR_EQUAL 7116) (T_IS_IDENTICAL 7117) (T_IS_NOT_EQUAL 7118) (T_IS_NOT_IDENTICAL 7119) (T_IS_SMALLER_OR_EQUAL 7120) (T_LOGICAL_AND 7121) (T_LOGICAL_OR 7122) (T_LOGICAL_XOR 7123) (T_POW 7124) (T_SL 7125) (T_SPACESHIP 7126) (T_SR 7127) ("^" 7128) ("|" 7129)) 3578 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8361) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3579 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 8370) (T_VARIABLE 2900) (encaps_var 2914)) 3580 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 8369) (T_VARIABLE 2900) (encaps_var 2905)) 3581 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 8422) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 3582 ((T_CLASS 8414)) 3583 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 8413) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 8383) (attribute 2980) (class_modifier 2945)) 3584 ((T_PAAMAYIM_NEKUDOTAYIM 8411)) 3585 (("(" 8402) (argument_list 8403) (ctor_arguments 8404)) 3586 ((T_NULLSAFE_OBJECT_OPERATOR 8390) (T_OBJECT_OPERATOR 8391) (T_PAAMAYIM_NEKUDOTAYIM 8392) ("[" 8393) ("{" 8394)) 3587 (("$" 8246) (T_STRING 8284) (T_VARIABLE 8248) (property_name 8401) (simple_variable 8286) ("{" 8287)) 3588 (("$" 8246) (T_STRING 8284) (T_VARIABLE 8248) (property_name 8400) (simple_variable 8286) ("{" 8287)) 3589 (("$" 8246) (T_VARIABLE 8248) (simple_variable 8399)) 3590 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 8397) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 3591 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 8395) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3592 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 8396)) 3593 (("]" 8398)) 3594 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 8405) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 8406) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 8407) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3595 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 8410) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3596 (("," 1469) (possible_comma 8408)) 3597 ((")" 8409)) 3598 (("$" 8246) (T_VARIABLE 8248) (simple_variable 8412)) 3599 (("(" 2982) (argument_list 2983) (ctor_arguments 8415)) 3600 ((T_EXTENDS 2985) (extends_from 8416)) 3601 ((T_IMPLEMENTS 2987) (implements_list 8417)) 3602 ((backup_doc_comment 8418)) 3603 (("{" 8419)) 3604 ((class_statement_list 8420)) 3605 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 8421)) 3606 (("%" 292) (")" 8423) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 3607 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 8425) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 3608 (("%" 292) (")" 8426) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 3609 (("{" 8427)) 3610 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 8428) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 3611 (("}" 8429)) 3612 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 8431) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 3613 ((")" 8432)) 3614 (("=" 8433)) 3615 (("!" 7941) ("\"" 7942) ("$" 7943) ("(" 7944) ("+" 7945) ("-" 7946) ("@" 7947) (T_ARRAY 7948) (T_ARRAY_CAST 7949) (T_ATTRIBUTE 126) (T_BOOL_CAST 7950) (T_CLASS_C 7951) (T_CLONE 7952) (T_CONSTANT_ENCAPSED_STRING 7953) (T_DEC 7954) (T_DIR 7955) (T_DNUMBER 7956) (T_DOUBLE_CAST 7957) (T_EMPTY 7958) (T_EVAL 7959) (T_EXIT 7960) (T_FILE 7961) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7962) (T_INC 7963) (T_INCLUDE 7964) (T_INCLUDE_ONCE 7965) (T_INT_CAST 7966) (T_ISSET 7967) (T_LINE 7968) (T_LIST 7969) (T_LNUMBER 7970) (T_MATCH 7971) (T_METHOD_C 7972) (T_NAME_FULLY_QUALIFIED 7973) (T_NAME_QUALIFIED 7974) (T_NAME_RELATIVE 7975) (T_NEW 7976) (T_NS_C 7977) (T_OBJECT_CAST 7978) (T_PRINT 7979) (T_READONLY 7980) (T_REQUIRE 7981) (T_REQUIRE_ONCE 7982) (T_START_HEREDOC 7983) (T_STATIC 7984) (T_STRING 7985) (T_STRING_CAST 7986) (T_THROW 7987) (T_TRAIT_C 7988) (T_UNSET_CAST 7989) (T_VARIABLE 7990) (T_YIELD 7991) (T_YIELD_FROM 7992) ("[" 7993) ("`" 7994) (array_object_dereferenceable 7995) (attribute 131) (attributes 7996) (callable_expr 7997) (callable_variable 7998) (class_constant 7999) (class_name 8000) (constant 8001) (dereferenceable_scalar 8002) (expr 8434) (fn 8004) (fully_dereferenceable 104) #'8005 (function_call 8006) (inline_function 8007) (internal_functions_in_yacc 8008) (match 8009) (name 8010) (new_expr 8011) (scalar 8012) (simple_variable 8013) (static_member 8014) (variable 8015) (variable_class_name 8016) ("~" 8017)) 3616 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 8436) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3617 (("," 5258) (possible_comma 8437)) 3618 ((")" 8438)) 3619 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 8445) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 3620 ((")" 8446)) 3621 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 8448) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 3622 (("%" 292) (")" 8449) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 3623 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 8451) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 3624 (("%" 292) (")" 8452) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 3625 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 8459) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 3626 ((")" 8460)) 3627 (("%" 292) (")" 8465) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 3628 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 8468) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3629 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 8469)) 3630 (("\"" 8471) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 3631 (("$" 7557) (T_ABSTRACT 7742) (T_ARRAY 7743) (T_AS 7744) (T_BREAK 7745) (T_CALLABLE 7746) (T_CASE 7747) (T_CATCH 7748) (T_CLASS 7749) (T_CLASS_C 7750) (T_CLONE 7751) (T_CONST 7752) (T_CONTINUE 7753) (T_DECLARE 7754) (T_DEFAULT 7755) (T_DIR 7756) (T_DO 7757) (T_ECHO 7758) (T_ELSE 7759) (T_ELSEIF 7760) (T_EMPTY 7761) (T_ENDDECLARE 7762) (T_ENDFOR 7763) (T_ENDFOREACH 7764) (T_ENDIF 7765) (T_ENDSWITCH 7766) (T_ENDWHILE 7767) (T_ENUM 7768) (T_EVAL 7769) (T_EXIT 7770) (T_EXTENDS 7771) (T_FILE 7772) (T_FINAL 7773) (T_FINALLY 7774) (T_FN 7775) (T_FOR 7776) (T_FOREACH 7777) (T_FUNCTION 7778) (T_FUNC_C 7779) (T_GLOBAL 7780) (T_GOTO 7781) (T_IF 7782) (T_IMPLEMENTS 7783) (T_INCLUDE 7784) (T_INCLUDE_ONCE 7785) (T_INSTANCEOF 7786) (T_INSTEADOF 7787) (T_INTERFACE 7788) (T_ISSET 7789) (T_LINE 7790) (T_LIST 7791) (T_LOGICAL_AND 7792) (T_LOGICAL_OR 7793) (T_LOGICAL_XOR 7794) (T_MATCH 7795) (T_METHOD_C 7796) (T_NAMESPACE 7797) (T_NEW 7798) (T_NS_C 7799) (T_PRINT 7800) (T_PRIVATE 7801) (T_PROTECTED 7802) (T_PUBLIC 7803) (T_READONLY 7804) (T_REQUIRE 7805) (T_REQUIRE_ONCE 7806) (T_RETURN 7807) (T_STATIC 7808) (T_STRING 7809) (T_SWITCH 7810) (T_THROW 7811) (T_TRAIT 7812) (T_TRAIT_C 7813) (T_TRY 7814) (T_UNSET 7815) (T_USE 7816) (T_VAR 7817) (T_VARIABLE 7604) (T_WHILE 7818) (T_YIELD 7819) (identifier 8474) (member_name 8475) (reserved_non_modifiers 7822) (semi_reserved 7823) (simple_variable 8476) ("{" 8477)) 3632 (("(" 7828) (argument_list 8480)) 3633 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 8478) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3634 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 8479)) 3635 ((T_FN 35) (T_FUNCTION 127) (fn 7619) #'7620 (inline_function 8484)) 3636 (("$" 7557) (T_STRING 8493) (T_VARIABLE 7604) (property_name 8500) (simple_variable 8495) ("{" 8496)) 3637 (("$" 7557) (T_STRING 8493) (T_VARIABLE 7604) (property_name 8494) (simple_variable 8495) ("{" 8496)) 3638 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 8491) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 3639 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 8489) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3640 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 8490)) 3641 (("]" 8492)) 3642 (("(" 7828) (argument_list 8499)) 3643 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 8497) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3644 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 8498)) 3645 (("(" 7828) (argument_list 8501)) 3646 (("$" 8502) (T_VARIABLE 8504) (simple_variable 8550) ("{" 8551)) 3647 (("(" 8518) (argument_list 8549)) 3648 ((T_NULLSAFE_OBJECT_OPERATOR 8532) (T_OBJECT_OPERATOR 8533) ("[" 8534) ("{" 8535)) 3649 (("(" 8518) (argument_list 8531)) 3650 ((T_PAAMAYIM_NEKUDOTAYIM 8527)) 3651 (("(" 8518) (argument_list 8526)) 3652 ((T_PAAMAYIM_NEKUDOTAYIM 8515)) 3653 (("$" 8502) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 8504) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 8516) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 8517) ("{" 1627)) 3654 (("(" 8518) (argument_list 8519)) 3655 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 8520) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 8521) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 8522) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3656 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 8525) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3657 (("," 1469) (possible_comma 8523)) 3658 ((")" 8524)) 3659 (("$" 8502) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 8504) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 8528) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 8529) ("{" 1643)) 3660 (("(" 8518) (argument_list 8530)) 3661 (("$" 8502) (T_STRING 8540) (T_VARIABLE 8504) (property_name 8547) (simple_variable 8542) ("{" 8543)) 3662 (("$" 8502) (T_STRING 8540) (T_VARIABLE 8504) (property_name 8541) (simple_variable 8542) ("{" 8543)) 3663 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 8538) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 3664 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 8536) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3665 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 8537)) 3666 (("]" 8539)) 3667 (("(" 8518) (argument_list 8546)) 3668 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 8544) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3669 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 8545)) 3670 (("(" 8518) (argument_list 8548)) 3671 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 8552) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3672 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 8553)) 3673 (("`" 8555)) 3674 (("]" 8557)) 3675 (("=" 8558)) 3676 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 8559) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3677 (("%" 1750) ("*" 1751) ("+" 1752) ("-" 1753) ("." 1754) ("/" 1755) ("<" 1756) (">" 1757) ("?" 1758) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1759) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1760) (T_BOOLEAN_AND 1761) (T_BOOLEAN_OR 1762) (T_COALESCE 1763) (T_DOUBLE_ARROW 8562) (T_INSTANCEOF 1764) (T_IS_EQUAL 1765) (T_IS_GREATER_OR_EQUAL 1766) (T_IS_IDENTICAL 1767) (T_IS_NOT_EQUAL 1768) (T_IS_NOT_IDENTICAL 1769) (T_IS_SMALLER_OR_EQUAL 1770) (T_LOGICAL_AND 1771) (T_LOGICAL_OR 1772) (T_LOGICAL_XOR 1773) (T_POW 1774) (T_SL 1775) (T_SPACESHIP 1776) (T_SR 1777) ("^" 1778) ("|" 1779)) 3678 (("!" 7555) ("\"" 7556) ("$" 7557) ("(" 7558) ("+" 7559) ("-" 7560) ("@" 7561) (T_ARRAY 7562) (T_ARRAY_CAST 7563) (T_ATTRIBUTE 126) (T_BOOL_CAST 7564) (T_CLASS_C 7565) (T_CLONE 7566) (T_CONSTANT_ENCAPSED_STRING 7567) (T_DEC 7568) (T_DIR 7569) (T_DNUMBER 7570) (T_DOUBLE_CAST 7571) (T_EMPTY 7572) (T_EVAL 7573) (T_EXIT 7574) (T_FILE 7575) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 7576) (T_INC 7577) (T_INCLUDE 7578) (T_INCLUDE_ONCE 7579) (T_INT_CAST 7580) (T_ISSET 7581) (T_LINE 7582) (T_LIST 7633) (T_LNUMBER 7584) (T_MATCH 7585) (T_METHOD_C 7586) (T_NAME_FULLY_QUALIFIED 7587) (T_NAME_QUALIFIED 7588) (T_NAME_RELATIVE 7589) (T_NEW 7590) (T_NS_C 7591) (T_OBJECT_CAST 7592) (T_PRINT 7593) (T_READONLY 7594) (T_REQUIRE 7595) (T_REQUIRE_ONCE 7596) (T_START_HEREDOC 7597) (T_STATIC 7598) (T_STRING 7599) (T_STRING_CAST 7600) (T_THROW 7601) (T_TRAIT_C 7602) (T_UNSET_CAST 7603) (T_VARIABLE 7604) (T_YIELD 7605) (T_YIELD_FROM 7606) ("[" 7607) ("`" 7608) (array_object_dereferenceable 7610) (attribute 131) (attributes 7611) (callable_expr 7612) (callable_variable 7613) (class_constant 7614) (class_name 7615) (constant 7616) (dereferenceable_scalar 7617) (expr 8563) (fn 7619) (fully_dereferenceable 104) #'7620 (function_call 7621) (inline_function 7622) (internal_functions_in_yacc 7623) (match 7624) (name 7625) (new_expr 7626) (scalar 7627) (simple_variable 7628) (static_member 7629) (variable 7630) (variable_class_name 7631) ("~" 7632)) 3679 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 8572) (T_VARIABLE 2900) (encaps_var 2914)) 3680 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 8571) (T_VARIABLE 2900) (encaps_var 2905)) 3681 ((T_CLASS 8592)) 3682 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 8591) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 8579) (attribute 2980) (class_modifier 2945)) 3683 (("(" 8582) (argument_list 8583) (ctor_arguments 8584)) 3684 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 8585) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 8586) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 8587) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3685 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 8590) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3686 (("," 1469) (possible_comma 8588)) 3687 ((")" 8589)) 3688 (("(" 2982) (argument_list 2983) (ctor_arguments 8593)) 3689 ((T_EXTENDS 2985) (extends_from 8594)) 3690 ((T_IMPLEMENTS 2987) (implements_list 8595)) 3691 ((backup_doc_comment 8596)) 3692 (("{" 8597)) 3693 ((class_statement_list 8598)) 3694 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 8599)) 3695 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 8601) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 3696 (("%" 292) (")" 8602) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 3697 (("{" 8603)) 3698 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 8604) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 3699 (("}" 8605)) 3700 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 8607) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 3701 ((")" 8608)) 3702 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 8610) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3703 (("," 5258) (possible_comma 8611)) 3704 ((")" 8612)) 3705 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 8619) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 3706 ((")" 8620)) 3707 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 8622) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 3708 (("%" 292) (")" 8623) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 3709 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 8625) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 3710 (("%" 292) (")" 8626) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 3711 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 8633) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 3712 ((")" 8634)) 3713 (("%" 292) (")" 8639) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 3714 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 8642) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3715 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 8643)) 3716 (("\"" 8645) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 3717 (("$" 1667) (T_ABSTRACT 6821) (T_ARRAY 6822) (T_AS 6823) (T_BREAK 6824) (T_CALLABLE 6825) (T_CASE 6826) (T_CATCH 6827) (T_CLASS 6828) (T_CLASS_C 6829) (T_CLONE 6830) (T_CONST 6831) (T_CONTINUE 6832) (T_DECLARE 6833) (T_DEFAULT 6834) (T_DIR 6835) (T_DO 6836) (T_ECHO 6837) (T_ELSE 6838) (T_ELSEIF 6839) (T_EMPTY 6840) (T_ENDDECLARE 6841) (T_ENDFOR 6842) (T_ENDFOREACH 6843) (T_ENDIF 6844) (T_ENDSWITCH 6845) (T_ENDWHILE 6846) (T_ENUM 6847) (T_EVAL 6848) (T_EXIT 6849) (T_EXTENDS 6850) (T_FILE 6851) (T_FINAL 6852) (T_FINALLY 6853) (T_FN 6854) (T_FOR 6855) (T_FOREACH 6856) (T_FUNCTION 6857) (T_FUNC_C 6858) (T_GLOBAL 6859) (T_GOTO 6860) (T_IF 6861) (T_IMPLEMENTS 6862) (T_INCLUDE 6863) (T_INCLUDE_ONCE 6864) (T_INSTANCEOF 6865) (T_INSTEADOF 6866) (T_INTERFACE 6867) (T_ISSET 6868) (T_LINE 6869) (T_LIST 6870) (T_LOGICAL_AND 6871) (T_LOGICAL_OR 6872) (T_LOGICAL_XOR 6873) (T_MATCH 6874) (T_METHOD_C 6875) (T_NAMESPACE 6876) (T_NEW 6877) (T_NS_C 6878) (T_PRINT 6879) (T_PRIVATE 6880) (T_PROTECTED 6881) (T_PUBLIC 6882) (T_READONLY 6883) (T_REQUIRE 6884) (T_REQUIRE_ONCE 6885) (T_RETURN 6886) (T_STATIC 6887) (T_STRING 6888) (T_SWITCH 6889) (T_THROW 6890) (T_TRAIT 6891) (T_TRAIT_C 6892) (T_TRY 6893) (T_UNSET 6894) (T_USE 6895) (T_VAR 6896) (T_VARIABLE 1715) (T_WHILE 6897) (T_YIELD 6898) (identifier 8648) (member_name 8649) (reserved_non_modifiers 6901) (semi_reserved 6902) (simple_variable 8650) ("{" 8651)) 3718 (("(" 6907) (argument_list 8654)) 3719 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 8652) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3720 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 8653)) 3721 ((T_FN 35) (T_FUNCTION 127) (fn 1732) #'1733 (inline_function 8658)) 3722 (("$" 1667) (T_STRING 8668) (T_VARIABLE 1715) (property_name 8675) (simple_variable 8670) ("{" 8671)) 3723 (("$" 1667) (T_STRING 8668) (T_VARIABLE 1715) (property_name 8669) (simple_variable 8670) ("{" 8671)) 3724 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 8666) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 3725 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 8664) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3726 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 8665)) 3727 (("]" 8667)) 3728 (("(" 6907) (argument_list 8674)) 3729 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 8672) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3730 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 8673)) 3731 (("(" 6907) (argument_list 8676)) 3732 (("`" 8679)) 3733 (("]" 8681)) 3734 (("=" 8682)) 3735 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 8683) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 3736 (("%" 1750) ("*" 1751) ("+" 1752) ("-" 1753) ("." 1754) ("/" 1755) ("<" 1756) (">" 1757) ("?" 1758) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1759) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1760) (T_BOOLEAN_AND 1761) (T_BOOLEAN_OR 1762) (T_COALESCE 1763) (T_DOUBLE_ARROW 8686) (T_INSTANCEOF 1764) (T_IS_EQUAL 1765) (T_IS_GREATER_OR_EQUAL 1766) (T_IS_IDENTICAL 1767) (T_IS_NOT_EQUAL 1768) (T_IS_NOT_IDENTICAL 1769) (T_IS_SMALLER_OR_EQUAL 1770) (T_LOGICAL_AND 1771) (T_LOGICAL_OR 1772) (T_LOGICAL_XOR 1773) (T_POW 1774) (T_SL 1775) (T_SPACESHIP 1776) (T_SR 1777) ("^" 1778) ("|" 1779)) 3737 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1748) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (array_object_dereferenceable 1721) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 8687) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 3738 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 8696) (T_VARIABLE 2900) (encaps_var 2914)) 3739 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 8695) (T_VARIABLE 2900) (encaps_var 2905)) 3740 ((T_CLASS 8716)) 3741 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 8715) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 8703) (attribute 2980) (class_modifier 2945)) 3742 (("(" 8706) (argument_list 8707) (ctor_arguments 8708)) 3743 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 8709) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 8710) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 8711) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3744 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 8714) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3745 (("," 1469) (possible_comma 8712)) 3746 ((")" 8713)) 3747 (("(" 2982) (argument_list 2983) (ctor_arguments 8717)) 3748 ((T_EXTENDS 2985) (extends_from 8718)) 3749 ((T_IMPLEMENTS 2987) (implements_list 8719)) 3750 ((backup_doc_comment 8720)) 3751 (("{" 8721)) 3752 ((class_statement_list 8722)) 3753 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 8723)) 3754 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 8725) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 3755 (("%" 292) (")" 8726) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 3756 (("{" 8727)) 3757 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 8728) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 3758 (("}" 8729)) 3759 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 8731) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 3760 ((")" 8732)) 3761 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 8734) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3762 (("," 5258) (possible_comma 8735)) 3763 ((")" 8736)) 3764 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 8743) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 3765 ((")" 8744)) 3766 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 8746) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 3767 (("%" 292) (")" 8747) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 3768 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 8749) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 3769 (("%" 292) (")" 8750) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 3770 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 8758) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 3771 ((")" 8759)) 3772 (("%" 292) (")" 8764) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 3773 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 8767) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3774 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 8768)) 3775 (("\"" 8770) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 3776 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 8774) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 3777 ((")" 8775)) 3778 (("%" 292) (")" 8777) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 3779 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 8780) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3780 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 8781)) 3781 (("\"" 8783) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 3782 ((backup_doc_comment 8786)) 3783 (("(" 8787)) 3784 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 8788)) 3785 ((")" 8789)) 3786 ((T_USE 159) (lexical_vars 8790)) 3787 ((":" 161) (return_type 8791)) 3788 ((backup_fn_flags 8792)) 3789 (("{" 8793)) 3790 ((inner_statement_list 8794)) 3791 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 8795) ("~" 125)) 3792 ((backup_fn_flags 8796)) 3793 ((backup_doc_comment 8798)) 3794 (("(" 8799)) 3795 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 8800)) 3796 ((")" 8801)) 3797 ((":" 2241) (return_type 8802)) 3798 ((T_DOUBLE_ARROW 8803)) 3799 ((backup_fn_flags 8804)) 3800 ((backup_lex_pos 8805)) 3801 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 8806) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 3802 (("%" 1276) ("*" 1277) ("+" 1278) ("-" 1279) ("." 1280) ("/" 1281) ("<" 1282) (">" 1283) ("?" 1284) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1285) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1286) (T_BOOLEAN_AND 1287) (T_BOOLEAN_OR 1288) (T_COALESCE 1289) (T_INSTANCEOF 1290) (T_IS_EQUAL 1291) (T_IS_GREATER_OR_EQUAL 1292) (T_IS_IDENTICAL 1293) (T_IS_NOT_EQUAL 1294) (T_IS_NOT_IDENTICAL 1295) (T_IS_SMALLER_OR_EQUAL 1296) (T_LOGICAL_AND 1297) (T_LOGICAL_OR 1298) (T_LOGICAL_XOR 1299) (T_POW 1300) (T_SL 1301) (T_SPACESHIP 1302) (T_SR 1303) ("^" 1304) (backup_fn_flags 8807) ("|" 1305)) 3803 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 8809) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3804 (("$" 1200) (T_ABSTRACT 1378) (T_ARRAY 1379) (T_AS 1380) (T_BREAK 1381) (T_CALLABLE 1382) (T_CASE 1383) (T_CATCH 1384) (T_CLASS 1385) (T_CLASS_C 1386) (T_CLONE 1387) (T_CONST 1388) (T_CONTINUE 1389) (T_DECLARE 1390) (T_DEFAULT 1391) (T_DIR 1392) (T_DO 1393) (T_ECHO 1394) (T_ELSE 1395) (T_ELSEIF 1396) (T_EMPTY 1397) (T_ENDDECLARE 1398) (T_ENDFOR 1399) (T_ENDFOREACH 1400) (T_ENDIF 1401) (T_ENDSWITCH 1402) (T_ENDWHILE 1403) (T_ENUM 1404) (T_EVAL 1405) (T_EXIT 1406) (T_EXTENDS 1407) (T_FILE 1408) (T_FINAL 1409) (T_FINALLY 1410) (T_FN 1411) (T_FOR 1412) (T_FOREACH 1413) (T_FUNCTION 1414) (T_FUNC_C 1415) (T_GLOBAL 1416) (T_GOTO 1417) (T_IF 1418) (T_IMPLEMENTS 1419) (T_INCLUDE 1420) (T_INCLUDE_ONCE 1421) (T_INSTANCEOF 1422) (T_INSTEADOF 1423) (T_INTERFACE 1424) (T_ISSET 1425) (T_LINE 1426) (T_LIST 1427) (T_LOGICAL_AND 1428) (T_LOGICAL_OR 1429) (T_LOGICAL_XOR 1430) (T_MATCH 1431) (T_METHOD_C 1432) (T_NAMESPACE 1433) (T_NEW 1434) (T_NS_C 1435) (T_PRINT 1436) (T_PRIVATE 1437) (T_PROTECTED 1438) (T_PUBLIC 1439) (T_READONLY 1440) (T_REQUIRE 1441) (T_REQUIRE_ONCE 1442) (T_RETURN 1443) (T_STATIC 1444) (T_STRING 1445) (T_SWITCH 1446) (T_THROW 1447) (T_TRAIT 1448) (T_TRAIT_C 1449) (T_TRY 1450) (T_UNSET 1451) (T_USE 1452) (T_VAR 1453) (T_VARIABLE 1247) (T_WHILE 1454) (T_YIELD 1455) (identifier 8811) (member_name 8812) (reserved_non_modifiers 1458) (semi_reserved 1459) (simple_variable 8813) ("{" 8814)) 3805 (("(" 1464) (argument_list 8817)) 3806 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 8815) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3807 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 8816)) 3808 ((T_FN 35) (T_FUNCTION 127) (fn 1261) #'1262 (inline_function 8821)) 3809 (("$" 1200) (T_STRING 8830) (T_VARIABLE 1247) (property_name 8837) (simple_variable 8832) ("{" 8833)) 3810 (("$" 1200) (T_STRING 8830) (T_VARIABLE 1247) (property_name 8831) (simple_variable 8832) ("{" 8833)) 3811 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 8828) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 3812 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 8826) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3813 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 8827)) 3814 (("]" 8829)) 3815 (("(" 1464) (argument_list 8836)) 3816 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 8834) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3817 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 8835)) 3818 (("(" 1464) (argument_list 8838)) 3819 (("`" 8840)) 3820 (("]" 8842)) 3821 (("=" 8843)) 3822 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 8844) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 3823 (("%" 1276) ("*" 1277) ("+" 1278) ("-" 1279) ("." 1280) ("/" 1281) ("<" 1282) (">" 1283) ("?" 1284) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1285) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1286) (T_BOOLEAN_AND 1287) (T_BOOLEAN_OR 1288) (T_COALESCE 1289) (T_DOUBLE_ARROW 8847) (T_INSTANCEOF 1290) (T_IS_EQUAL 1291) (T_IS_GREATER_OR_EQUAL 1292) (T_IS_IDENTICAL 1293) (T_IS_NOT_EQUAL 1294) (T_IS_NOT_IDENTICAL 1295) (T_IS_SMALLER_OR_EQUAL 1296) (T_LOGICAL_AND 1297) (T_LOGICAL_OR 1298) (T_LOGICAL_XOR 1299) (T_POW 1300) (T_SL 1301) (T_SPACESHIP 1302) (T_SR 1303) ("^" 1304) ("|" 1305)) 3824 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 8848) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 3825 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 8857) (T_VARIABLE 2900) (encaps_var 2914)) 3826 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 8856) (T_VARIABLE 2900) (encaps_var 2905)) 3827 ((T_CLASS 8877)) 3828 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 8876) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 8864) (attribute 2980) (class_modifier 2945)) 3829 (("(" 8867) (argument_list 8868) (ctor_arguments 8869)) 3830 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 8870) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 8871) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 8872) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3831 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 8875) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3832 (("," 1469) (possible_comma 8873)) 3833 ((")" 8874)) 3834 (("(" 2982) (argument_list 2983) (ctor_arguments 8878)) 3835 ((T_EXTENDS 2985) (extends_from 8879)) 3836 ((T_IMPLEMENTS 2987) (implements_list 8880)) 3837 ((backup_doc_comment 8881)) 3838 (("{" 8882)) 3839 ((class_statement_list 8883)) 3840 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 8884)) 3841 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 8886) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 3842 (("%" 292) (")" 8887) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 3843 (("{" 8888)) 3844 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 8889) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 3845 (("}" 8890)) 3846 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 8892) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 3847 ((")" 8893)) 3848 (("=" 8894)) 3849 (("!" 1198) ("\"" 1199) ("$" 1200) ("(" 1201) ("+" 1202) ("-" 1203) ("@" 1204) (T_ARRAY 1205) (T_ARRAY_CAST 1206) (T_ATTRIBUTE 126) (T_BOOL_CAST 1207) (T_CLASS_C 1208) (T_CLONE 1209) (T_CONSTANT_ENCAPSED_STRING 1210) (T_DEC 1211) (T_DIR 1212) (T_DNUMBER 1213) (T_DOUBLE_CAST 1214) (T_EMPTY 1215) (T_EVAL 1216) (T_EXIT 1217) (T_FILE 1218) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1219) (T_INC 1220) (T_INCLUDE 1221) (T_INCLUDE_ONCE 1222) (T_INT_CAST 1223) (T_ISSET 1224) (T_LINE 1225) (T_LIST 1226) (T_LNUMBER 1227) (T_MATCH 1228) (T_METHOD_C 1229) (T_NAME_FULLY_QUALIFIED 1230) (T_NAME_QUALIFIED 1231) (T_NAME_RELATIVE 1232) (T_NEW 1233) (T_NS_C 1234) (T_OBJECT_CAST 1235) (T_PRINT 1236) (T_READONLY 1237) (T_REQUIRE 1238) (T_REQUIRE_ONCE 1239) (T_START_HEREDOC 1240) (T_STATIC 1241) (T_STRING 1242) (T_STRING_CAST 1243) (T_THROW 1244) (T_TRAIT_C 1245) (T_UNSET_CAST 1246) (T_VARIABLE 1247) (T_YIELD 1248) (T_YIELD_FROM 1249) ("[" 1250) ("`" 1251) (array_object_dereferenceable 1252) (attribute 131) (attributes 1253) (callable_expr 1254) (callable_variable 1255) (class_constant 1256) (class_name 1257) (constant 1258) (dereferenceable_scalar 1259) (expr 8895) (fn 1261) (fully_dereferenceable 104) #'1262 (function_call 1263) (inline_function 1264) (internal_functions_in_yacc 1265) (match 1266) (name 1267) (new_expr 1268) (scalar 1269) (simple_variable 1270) (static_member 1271) (variable 1272) (variable_class_name 1273) ("~" 1274)) 3850 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 8897) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3851 (("," 5258) (possible_comma 8898)) 3852 ((")" 8899)) 3853 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 8906) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 3854 ((")" 8907)) 3855 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 8909) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 3856 (("%" 292) (")" 8910) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 3857 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 8912) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 3858 (("%" 292) (")" 8913) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 3859 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 8920) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 3860 ((")" 8921)) 3861 (("%" 292) (")" 8926) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 3862 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 8929) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3863 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 8930)) 3864 (("\"" 8932) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 3865 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 8940) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 8941) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 8942) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3866 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 8945) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3867 (("," 1469) (possible_comma 8943)) 3868 ((")" 8944)) 3869 ((T_CLASS 8961)) 3870 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 8960) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 8948) (attribute 2980) (class_modifier 2945)) 3871 (("(" 8951) (argument_list 8952) (ctor_arguments 8953)) 3872 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 8954) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 8955) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 8956) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3873 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 8959) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3874 (("," 1469) (possible_comma 8957)) 3875 ((")" 8958)) 3876 (("(" 2982) (argument_list 2983) (ctor_arguments 8962)) 3877 ((T_EXTENDS 2985) (extends_from 8963)) 3878 ((T_IMPLEMENTS 2987) (implements_list 8964)) 3879 ((backup_doc_comment 8965)) 3880 (("{" 8966)) 3881 ((class_statement_list 8967)) 3882 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 8968)) 3883 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 8970) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 3884 (("%" 292) (")" 8971) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 3885 (("{" 8972)) 3886 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 8973) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 3887 (("}" 8974)) 3888 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 8976) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 3889 ((")" 8977)) 3890 (("=" 8978)) 3891 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 8979) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3892 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 8981) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3893 (("," 5258) (possible_comma 8982)) 3894 ((")" 8983)) 3895 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 8988) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 3896 ((")" 8989)) 3897 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 8991) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 3898 (("%" 292) (")" 8992) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 3899 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 8994) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 3900 (("%" 292) (")" 8995) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 3901 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 8998) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 3902 ((")" 8999)) 3903 (("$" 936) (T_ABSTRACT 9001) (T_ARRAY 9002) (T_AS 9003) (T_BREAK 9004) (T_CALLABLE 9005) (T_CASE 9006) (T_CATCH 9007) (T_CLASS 9008) (T_CLASS_C 9009) (T_CLONE 9010) (T_CONST 9011) (T_CONTINUE 9012) (T_DECLARE 9013) (T_DEFAULT 9014) (T_DIR 9015) (T_DO 9016) (T_ECHO 9017) (T_ELSE 9018) (T_ELSEIF 9019) (T_EMPTY 9020) (T_ENDDECLARE 9021) (T_ENDFOR 9022) (T_ENDFOREACH 9023) (T_ENDIF 9024) (T_ENDSWITCH 9025) (T_ENDWHILE 9026) (T_ENUM 9027) (T_EVAL 9028) (T_EXIT 9029) (T_EXTENDS 9030) (T_FILE 9031) (T_FINAL 9032) (T_FINALLY 9033) (T_FN 9034) (T_FOR 9035) (T_FOREACH 9036) (T_FUNCTION 9037) (T_FUNC_C 9038) (T_GLOBAL 9039) (T_GOTO 9040) (T_IF 9041) (T_IMPLEMENTS 9042) (T_INCLUDE 9043) (T_INCLUDE_ONCE 9044) (T_INSTANCEOF 9045) (T_INSTEADOF 9046) (T_INTERFACE 9047) (T_ISSET 9048) (T_LINE 9049) (T_LIST 9050) (T_LOGICAL_AND 9051) (T_LOGICAL_OR 9052) (T_LOGICAL_XOR 9053) (T_MATCH 9054) (T_METHOD_C 9055) (T_NAMESPACE 9056) (T_NEW 9057) (T_NS_C 9058) (T_PRINT 9059) (T_PRIVATE 9060) (T_PROTECTED 9061) (T_PUBLIC 9062) (T_READONLY 9063) (T_REQUIRE 9064) (T_REQUIRE_ONCE 9065) (T_RETURN 9066) (T_STATIC 9067) (T_STRING 9068) (T_SWITCH 9069) (T_THROW 9070) (T_TRAIT 9071) (T_TRAIT_C 9072) (T_TRY 9073) (T_UNSET 9074) (T_USE 9075) (T_VAR 9076) (T_VARIABLE 1035) (T_WHILE 9077) (T_YIELD 9078) (identifier 9079) (member_name 9080) (reserved_non_modifiers 9081) (semi_reserved 9082) (simple_variable 9083) ("{" 9084)) 3904 (("(" 8938) (argument_list 9087)) 3905 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 9085) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3906 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 9086)) 3907 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (ampersand 9117) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 9118) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3908 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 9116) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3909 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 9115) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3910 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 9114) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3911 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 9113) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3912 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 9112) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3913 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 9111) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3914 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 9110) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3915 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 9109) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3916 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 9108) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3917 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 9107) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3918 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 9106) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3919 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 9105) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3920 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 9104) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3921 (("\"" 1509) ("$" 2930) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 9119) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 2939) ("[" 1529) (array_object_dereferenceable 9120) (callable_expr 9121) (callable_variable 9122) (class_constant 1533) (class_name 9123) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 9124) (name 9125) (simple_variable 9126) (static_member 9127) (variable 9128) (variable_class_name 9129)) 3922 (("(" 9133) (argument_list 9159)) 3923 ((T_NULLSAFE_OBJECT_OPERATOR 9147) (T_OBJECT_OPERATOR 9148) ("[" 9149) ("{" 9150)) 3924 (("(" 9133) (argument_list 9146)) 3925 ((T_PAAMAYIM_NEKUDOTAYIM 9142)) 3926 (("(" 9133) (argument_list 9141)) 3927 ((T_PAAMAYIM_NEKUDOTAYIM 9130)) 3928 (("$" 2930) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 2939) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 9131) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 9132) ("{" 1627)) 3929 (("(" 9133) (argument_list 9134)) 3930 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 9135) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 9136) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 9137) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3931 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 9140) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3932 (("," 1469) (possible_comma 9138)) 3933 ((")" 9139)) 3934 (("$" 2930) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 2939) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 9143) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 9144) ("{" 1643)) 3935 (("(" 9133) (argument_list 9145)) 3936 (("$" 2930) (T_STRING 2961) (T_VARIABLE 2939) (property_name 9157) (simple_variable 2963) ("{" 2964)) 3937 (("$" 2930) (T_STRING 2961) (T_VARIABLE 2939) (property_name 9155) (simple_variable 2963) ("{" 2964)) 3938 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 9153) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 3939 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 9151) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3940 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 9152)) 3941 (("]" 9154)) 3942 (("(" 9133) (argument_list 9156)) 3943 (("(" 9133) (argument_list 9158)) 3944 ((")" 9161)) 3945 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 9164) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3946 ((backup_doc_comment 9166)) 3947 (("(" 9167)) 3948 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 9168)) 3949 ((")" 9169)) 3950 ((T_USE 159) (lexical_vars 9170)) 3951 ((":" 161) (return_type 9171)) 3952 ((backup_fn_flags 9172)) 3953 (("{" 9173)) 3954 ((inner_statement_list 9174)) 3955 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 9175) ("~" 125)) 3956 ((backup_fn_flags 9176)) 3957 ((backup_doc_comment 9178)) 3958 (("(" 9179)) 3959 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 9180)) 3960 ((")" 9181)) 3961 ((":" 2241) (return_type 9182)) 3962 ((T_DOUBLE_ARROW 9183)) 3963 ((backup_fn_flags 9184)) 3964 ((backup_lex_pos 9185)) 3965 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 9186) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3966 (("%" 1097) ("*" 1098) ("+" 1099) ("-" 1100) ("." 1101) ("/" 1102) ("<" 1103) (">" 1104) ("?" 1105) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1106) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1107) (T_BOOLEAN_AND 1108) (T_BOOLEAN_OR 1109) (T_COALESCE 1110) (T_INSTANCEOF 1111) (T_IS_EQUAL 1112) (T_IS_GREATER_OR_EQUAL 1113) (T_IS_IDENTICAL 1114) (T_IS_NOT_EQUAL 1115) (T_IS_NOT_IDENTICAL 1116) (T_IS_SMALLER_OR_EQUAL 1117) (T_LOGICAL_AND 1118) (T_LOGICAL_OR 1119) (T_LOGICAL_XOR 1120) (T_POW 1121) (T_SL 1122) (T_SPACESHIP 1123) (T_SR 1124) ("^" 1125) (backup_fn_flags 9187) ("|" 1126)) 3967 (("$" 936) (T_ABSTRACT 9001) (T_ARRAY 9002) (T_AS 9003) (T_BREAK 9004) (T_CALLABLE 9005) (T_CASE 9006) (T_CATCH 9007) (T_CLASS 9008) (T_CLASS_C 9009) (T_CLONE 9010) (T_CONST 9011) (T_CONTINUE 9012) (T_DECLARE 9013) (T_DEFAULT 9014) (T_DIR 9015) (T_DO 9016) (T_ECHO 9017) (T_ELSE 9018) (T_ELSEIF 9019) (T_EMPTY 9020) (T_ENDDECLARE 9021) (T_ENDFOR 9022) (T_ENDFOREACH 9023) (T_ENDIF 9024) (T_ENDSWITCH 9025) (T_ENDWHILE 9026) (T_ENUM 9027) (T_EVAL 9028) (T_EXIT 9029) (T_EXTENDS 9030) (T_FILE 9031) (T_FINAL 9032) (T_FINALLY 9033) (T_FN 9034) (T_FOR 9035) (T_FOREACH 9036) (T_FUNCTION 9037) (T_FUNC_C 9038) (T_GLOBAL 9039) (T_GOTO 9040) (T_IF 9041) (T_IMPLEMENTS 9042) (T_INCLUDE 9043) (T_INCLUDE_ONCE 9044) (T_INSTANCEOF 9045) (T_INSTEADOF 9046) (T_INTERFACE 9047) (T_ISSET 9048) (T_LINE 9049) (T_LIST 9050) (T_LOGICAL_AND 9051) (T_LOGICAL_OR 9052) (T_LOGICAL_XOR 9053) (T_MATCH 9054) (T_METHOD_C 9055) (T_NAMESPACE 9056) (T_NEW 9057) (T_NS_C 9058) (T_PRINT 9059) (T_PRIVATE 9060) (T_PROTECTED 9061) (T_PUBLIC 9062) (T_READONLY 9063) (T_REQUIRE 9064) (T_REQUIRE_ONCE 9065) (T_RETURN 9066) (T_STATIC 9067) (T_STRING 9068) (T_SWITCH 9069) (T_THROW 9070) (T_TRAIT 9071) (T_TRAIT_C 9072) (T_TRY 9073) (T_UNSET 9074) (T_USE 9075) (T_VAR 9076) (T_VARIABLE 1035) (T_WHILE 9077) (T_YIELD 9078) (identifier 9189) (member_name 9190) (reserved_non_modifiers 9081) (semi_reserved 9082) (simple_variable 9191) ("{" 9192)) 3968 (("(" 8938) (argument_list 9195)) 3969 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 9193) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3970 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 9194)) 3971 ((T_FN 35) (T_FUNCTION 127) (fn 1051) #'1052 (inline_function 9199)) 3972 (("$" 936) (T_STRING 9208) (T_VARIABLE 1035) (property_name 9215) (simple_variable 9210) ("{" 9211)) 3973 (("$" 936) (T_STRING 9208) (T_VARIABLE 1035) (property_name 9209) (simple_variable 9210) ("{" 9211)) 3974 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 9206) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 3975 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 9204) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3976 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 9205)) 3977 (("]" 9207)) 3978 (("(" 8938) (argument_list 9214)) 3979 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 9212) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3980 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 9213)) 3981 (("(" 8938) (argument_list 9216)) 3982 (("`" 9218)) 3983 (("]" 9220)) 3984 (("=" 9221)) 3985 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 9222) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 3986 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 9230) (T_VARIABLE 2900) (encaps_var 2914)) 3987 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 9229) (T_VARIABLE 2900) (encaps_var 2905)) 3988 (("%" 292) (")" 9243) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 3989 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 9246) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 3990 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 9247)) 3991 (("\"" 9249) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 3992 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (ampersand 9280) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 9281) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 3993 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 9279) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 3994 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 9278) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 3995 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 9277) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 3996 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 9276) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 3997 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 9275) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 3998 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 9274) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 3999 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 9273) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 4000 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 9272) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 4001 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 9271) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 4002 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 9270) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 4003 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 9269) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 4004 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 9268) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 4005 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 9267) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 4006 (("\"" 1509) ("$" 9282) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 9283) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 9284) ("[" 1529) (array_object_dereferenceable 9285) (callable_expr 9286) (callable_variable 9287) (class_constant 1533) (class_name 9288) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 9289) (name 9290) (simple_variable 9291) (static_member 9292) (variable 9293) (variable_class_name 9294)) 4007 (("$" 9282) (T_VARIABLE 9284) (simple_variable 9330) ("{" 9331)) 4008 (("(" 9298) (argument_list 9329)) 4009 ((T_NULLSAFE_OBJECT_OPERATOR 9312) (T_OBJECT_OPERATOR 9313) ("[" 9314) ("{" 9315)) 4010 (("(" 9298) (argument_list 9311)) 4011 ((T_PAAMAYIM_NEKUDOTAYIM 9307)) 4012 (("(" 9298) (argument_list 9306)) 4013 ((T_PAAMAYIM_NEKUDOTAYIM 9295)) 4014 (("$" 9282) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 9284) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 9296) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 9297) ("{" 1627)) 4015 (("(" 9298) (argument_list 9299)) 4016 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 9300) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 9301) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 9302) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 4017 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 9305) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 4018 (("," 1469) (possible_comma 9303)) 4019 ((")" 9304)) 4020 (("$" 9282) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 9284) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 9308) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 9309) ("{" 1643)) 4021 (("(" 9298) (argument_list 9310)) 4022 (("$" 9282) (T_STRING 9320) (T_VARIABLE 9284) (property_name 9327) (simple_variable 9322) ("{" 9323)) 4023 (("$" 9282) (T_STRING 9320) (T_VARIABLE 9284) (property_name 9321) (simple_variable 9322) ("{" 9323)) 4024 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 9318) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 4025 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 9316) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4026 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 9317)) 4027 (("]" 9319)) 4028 (("(" 9298) (argument_list 9326)) 4029 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 9324) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4030 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 9325)) 4031 (("(" 9298) (argument_list 9328)) 4032 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 9332) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4033 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 9333)) 4034 ((backup_doc_comment 9336)) 4035 (("(" 9337)) 4036 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 9338)) 4037 ((")" 9339)) 4038 ((T_USE 159) (lexical_vars 9340)) 4039 ((":" 161) (return_type 9341)) 4040 ((backup_fn_flags 9342)) 4041 (("{" 9343)) 4042 ((inner_statement_list 9344)) 4043 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 9345) ("~" 125)) 4044 ((backup_fn_flags 9346)) 4045 ((backup_doc_comment 9348)) 4046 (("(" 9349)) 4047 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 9350)) 4048 ((")" 9351)) 4049 ((":" 2241) (return_type 9352)) 4050 ((T_DOUBLE_ARROW 9353)) 4051 ((backup_fn_flags 9354)) 4052 ((backup_lex_pos 9355)) 4053 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9418) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4054 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 10417) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4055 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 10415) (encaps_var 5299)) 4056 (("$" 9358) (T_VARIABLE 9405) (simple_variable 10411) ("{" 10412)) 4057 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 10409) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 4058 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 10408) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4059 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 10407) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4060 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 10406) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4061 (("(" 10403)) 4062 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 10402) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4063 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 10401) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4064 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 10400) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4065 (("\"" 1509) ("$" 9661) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 9662) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 9663) ("[" 1529) (array_object_dereferenceable 9664) (callable_expr 9665) (callable_variable 9666) (class_constant 1533) (class_name 9667) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 9668) (name 9669) (simple_variable 9670) (static_member 9671) (variable 10399) (variable_class_name 9673)) 4066 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 10398) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4067 (("(" 10395)) 4068 (("(" 10392)) 4069 (("(" 10388) (exit_expr 10389)) 4070 (("\"" 1509) ("$" 9661) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 9662) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 9663) ("[" 1529) (array_object_dereferenceable 9664) (callable_expr 9665) (callable_variable 9666) (class_constant 1533) (class_name 9667) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 9668) (name 9669) (simple_variable 9670) (static_member 9671) (variable 10387) (variable_class_name 9673)) 4071 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 10386) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4072 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 10385) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4073 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 10384) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4074 (("(" 10380)) 4075 (("(" 10375)) 4076 (("(" 10369)) 4077 (("$" 9661) ("(" 10321) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 10322) (T_NAME_QUALIFIED 10323) (T_NAME_RELATIVE 10324) (T_READONLY 2936) (T_STATIC 10325) (T_STRING 10326) (T_VARIABLE 9663) (anonymous_class 10327) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 10328) (attribute 2943) (attributes 10329) (class_modifier 2945) (class_name 10330) (class_name_reference 10331) (name 10332) (new_variable 10333) (simple_variable 10334)) 4078 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 10320) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4079 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 10319) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4080 (("(" 9622) (argument_list 10318)) 4081 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 10317) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4082 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 10316) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4083 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 10311) (T_END_HEREDOC 10312) (T_VARIABLE 2900) (encaps_list 10313) (encaps_var 2902)) 4084 ((T_FN 35) (T_FUNCTION 127) (fn 9419) #'9420 (inline_function 10310)) 4085 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 10309) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4086 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 10308) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4087 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 10307) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4088 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 9836) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4089 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9773) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4090 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 9769) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 4091 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 9767) (encaps_list 2805) (encaps_var 2806)) 4092 ((T_NULLSAFE_OBJECT_OPERATOR 9750) (T_OBJECT_OPERATOR 9751) ("[" 9752) ("{" 9753)) 4093 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 9747) (attribute 2728) (fn 9419) #'9420 (inline_function 9748)) 4094 (("(" 9622) (argument_list 9746)) 4095 ((T_PAAMAYIM_NEKUDOTAYIM 9738)) 4096 (("%" 9434) ("*" 9435) ("+" 9436) ("-" 9437) ("." 9438) ("/" 9439) ("<" 9440) (">" 9441) ("?" 9442) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 9443) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 9444) (T_BOOLEAN_AND 9445) (T_BOOLEAN_OR 9446) (T_COALESCE 9447) (T_INSTANCEOF 9448) (T_IS_EQUAL 9449) (T_IS_GREATER_OR_EQUAL 9450) (T_IS_IDENTICAL 9451) (T_IS_NOT_EQUAL 9452) (T_IS_NOT_IDENTICAL 9453) (T_IS_SMALLER_OR_EQUAL 9454) (T_LOGICAL_AND 9455) (T_LOGICAL_OR 9456) (T_LOGICAL_XOR 9457) (T_POW 9458) (T_SL 9459) (T_SPACESHIP 9460) (T_SR 9461) ("^" 9462) (backup_fn_flags 9737) ("|" 9463)) 4097 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 9726)) 4098 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 9714)) 4099 (("(" 9622) (argument_list 9713)) 4100 (("=" 9630) (T_AND_EQUAL 9631) (T_COALESCE_EQUAL 9632) (T_CONCAT_EQUAL 9633) (T_DEC 9634) (T_DIV_EQUAL 9635) (T_INC 9636) (T_MINUS_EQUAL 9637) (T_MOD_EQUAL 9638) (T_MUL_EQUAL 9639) (T_OR_EQUAL 9640) (T_PLUS_EQUAL 9641) (T_POW_EQUAL 9642) (T_SL_EQUAL 9643) (T_SR_EQUAL 9644) (T_XOR_EQUAL 9645)) 4101 ((T_PAAMAYIM_NEKUDOTAYIM 9535)) 4102 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9433) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4103 (("%" 9434) ("*" 9435) ("+" 9436) ("-" 9437) ("." 9438) ("/" 9439) ("<" 9440) (">" 9441) ("?" 9442) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 9443) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 9444) (T_BOOLEAN_AND 9445) (T_BOOLEAN_OR 9446) (T_COALESCE 9447) (T_INSTANCEOF 9448) (T_IS_EQUAL 9449) (T_IS_GREATER_OR_EQUAL 9450) (T_IS_IDENTICAL 9451) (T_IS_NOT_EQUAL 9452) (T_IS_NOT_IDENTICAL 9453) (T_IS_SMALLER_OR_EQUAL 9454) (T_LOGICAL_AND 9455) (T_LOGICAL_OR 9456) (T_LOGICAL_XOR 9457) (T_POW 9458) (T_SL 9459) (T_SPACESHIP 9460) (T_SR 9461) ("^" 9462) ("|" 9463)) 4104 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9534) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4105 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9533) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4106 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9532) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4107 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9531) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4108 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9530) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4109 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9529) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4110 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9528) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4111 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9527) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4112 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 9522) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 9523) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 4113 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9521) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4114 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9520) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4115 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9519) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4116 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9518) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4117 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9517) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4118 (("$" 9479) ("(" 9480) (T_NAME_FULLY_QUALIFIED 9481) (T_NAME_QUALIFIED 9482) (T_NAME_RELATIVE 9483) (T_STATIC 9484) (T_STRING 9485) (T_VARIABLE 9486) (class_name 9487) (class_name_reference 9488) (name 9489) (new_variable 9490) (simple_variable 9491)) 4119 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9478) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4120 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9477) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4121 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9476) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4122 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9475) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4123 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9474) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4124 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9473) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4125 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9472) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4126 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9471) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4127 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9470) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4128 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9469) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4129 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9468) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4130 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9467) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4131 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9466) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4132 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9465) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4133 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9464) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4134 (("$" 9479) (T_VARIABLE 9486) (simple_variable 9513) ("{" 9514)) 4135 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 9511) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 4136 ((T_PAAMAYIM_NEKUDOTAYIM 9509)) 4137 ((T_NULLSAFE_OBJECT_OPERATOR 9492) (T_OBJECT_OPERATOR 9493) (T_PAAMAYIM_NEKUDOTAYIM 9494) ("[" 9495) ("{" 9496)) 4138 (("$" 9479) (T_STRING 9502) (T_VARIABLE 9486) (property_name 9508) (simple_variable 9504) ("{" 9505)) 4139 (("$" 9479) (T_STRING 9502) (T_VARIABLE 9486) (property_name 9503) (simple_variable 9504) ("{" 9505)) 4140 (("$" 9479) (T_VARIABLE 9486) (simple_variable 9501)) 4141 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 9499) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 4142 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 9497) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4143 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 9498)) 4144 (("]" 9500)) 4145 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 9506) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4146 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 9507)) 4147 (("$" 9479) (T_VARIABLE 9486) (simple_variable 9510)) 4148 (("%" 292) (")" 9512) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 4149 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 9515) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4150 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 9516)) 4151 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9526) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4152 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 9524) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 4153 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9525) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4154 (("$" 9358) (T_ABSTRACT 9536) (T_ARRAY 9537) (T_AS 9538) (T_BREAK 9539) (T_CALLABLE 9540) (T_CASE 9541) (T_CATCH 9542) (T_CLASS 9543) (T_CLASS_C 9544) (T_CLONE 9545) (T_CONST 9546) (T_CONTINUE 9547) (T_DECLARE 9548) (T_DEFAULT 9549) (T_DIR 9550) (T_DO 9551) (T_ECHO 9552) (T_ELSE 9553) (T_ELSEIF 9554) (T_EMPTY 9555) (T_ENDDECLARE 9556) (T_ENDFOR 9557) (T_ENDFOREACH 9558) (T_ENDIF 9559) (T_ENDSWITCH 9560) (T_ENDWHILE 9561) (T_ENUM 9562) (T_EVAL 9563) (T_EXIT 9564) (T_EXTENDS 9565) (T_FILE 9566) (T_FINAL 9567) (T_FINALLY 9568) (T_FN 9569) (T_FOR 9570) (T_FOREACH 9571) (T_FUNCTION 9572) (T_FUNC_C 9573) (T_GLOBAL 9574) (T_GOTO 9575) (T_IF 9576) (T_IMPLEMENTS 9577) (T_INCLUDE 9578) (T_INCLUDE_ONCE 9579) (T_INSTANCEOF 9580) (T_INSTEADOF 9581) (T_INTERFACE 9582) (T_ISSET 9583) (T_LINE 9584) (T_LIST 9585) (T_LOGICAL_AND 9586) (T_LOGICAL_OR 9587) (T_LOGICAL_XOR 9588) (T_MATCH 9589) (T_METHOD_C 9590) (T_NAMESPACE 9591) (T_NEW 9592) (T_NS_C 9593) (T_PRINT 9594) (T_PRIVATE 9595) (T_PROTECTED 9596) (T_PUBLIC 9597) (T_READONLY 9598) (T_REQUIRE 9599) (T_REQUIRE_ONCE 9600) (T_RETURN 9601) (T_STATIC 9602) (T_STRING 9603) (T_SWITCH 9604) (T_THROW 9605) (T_TRAIT 9606) (T_TRAIT_C 9607) (T_TRY 9608) (T_UNSET 9609) (T_USE 9610) (T_VAR 9611) (T_VARIABLE 9405) (T_WHILE 9612) (T_YIELD 9613) (identifier 9614) (member_name 9615) (reserved_non_modifiers 9616) (semi_reserved 9617) (simple_variable 9618) ("{" 9619)) 4155 (("(" 9622) (argument_list 9623)) 4156 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 9620) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4157 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 9621)) 4158 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 9624) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 9625) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 9626) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 4159 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 9629) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 4160 (("," 1469) (possible_comma 9627)) 4161 ((")" 9628)) 4162 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (ampersand 9659) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9660) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4163 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9658) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4164 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9657) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4165 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9656) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4166 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9655) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4167 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9654) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4168 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9653) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4169 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9652) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4170 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9651) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4171 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9650) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4172 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9649) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4173 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9648) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4174 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9647) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4175 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9646) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4176 (("\"" 1509) ("$" 9661) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 9662) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 9663) ("[" 1529) (array_object_dereferenceable 9664) (callable_expr 9665) (callable_variable 9666) (class_constant 1533) (class_name 9667) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 9668) (name 9669) (simple_variable 9670) (static_member 9671) (variable 9672) (variable_class_name 9673)) 4177 (("$" 9661) (T_VARIABLE 9663) (simple_variable 9709) ("{" 9710)) 4178 (("(" 9677) (argument_list 9708)) 4179 ((T_NULLSAFE_OBJECT_OPERATOR 9691) (T_OBJECT_OPERATOR 9692) ("[" 9693) ("{" 9694)) 4180 (("(" 9677) (argument_list 9690)) 4181 ((T_PAAMAYIM_NEKUDOTAYIM 9686)) 4182 (("(" 9677) (argument_list 9685)) 4183 ((T_PAAMAYIM_NEKUDOTAYIM 9674)) 4184 (("$" 9661) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 9663) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 9675) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 9676) ("{" 1627)) 4185 (("(" 9677) (argument_list 9678)) 4186 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 9679) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 9680) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 9681) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 4187 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 9684) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 4188 (("," 1469) (possible_comma 9682)) 4189 ((")" 9683)) 4190 (("$" 9661) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 9663) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 9687) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 9688) ("{" 1643)) 4191 (("(" 9677) (argument_list 9689)) 4192 (("$" 9661) (T_STRING 9699) (T_VARIABLE 9663) (property_name 9706) (simple_variable 9701) ("{" 9702)) 4193 (("$" 9661) (T_STRING 9699) (T_VARIABLE 9663) (property_name 9700) (simple_variable 9701) ("{" 9702)) 4194 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 9697) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 4195 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 9695) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4196 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 9696)) 4197 (("]" 9698)) 4198 (("(" 9677) (argument_list 9705)) 4199 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 9703) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4200 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 9704)) 4201 (("(" 9677) (argument_list 9707)) 4202 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 9711) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4203 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 9712)) 4204 ((backup_doc_comment 9715)) 4205 (("(" 9716)) 4206 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 9717)) 4207 ((")" 9718)) 4208 ((T_USE 159) (lexical_vars 9719)) 4209 ((":" 161) (return_type 9720)) 4210 ((backup_fn_flags 9721)) 4211 (("{" 9722)) 4212 ((inner_statement_list 9723)) 4213 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 9724) ("~" 125)) 4214 ((backup_fn_flags 9725)) 4215 ((backup_doc_comment 9727)) 4216 (("(" 9728)) 4217 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 9729)) 4218 ((")" 9730)) 4219 ((":" 2241) (return_type 9731)) 4220 ((T_DOUBLE_ARROW 9732)) 4221 ((backup_fn_flags 9733)) 4222 ((backup_lex_pos 9734)) 4223 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9735) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4224 (("%" 9434) ("*" 9435) ("+" 9436) ("-" 9437) ("." 9438) ("/" 9439) ("<" 9440) (">" 9441) ("?" 9442) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 9443) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 9444) (T_BOOLEAN_AND 9445) (T_BOOLEAN_OR 9446) (T_COALESCE 9447) (T_INSTANCEOF 9448) (T_IS_EQUAL 9449) (T_IS_GREATER_OR_EQUAL 9450) (T_IS_IDENTICAL 9451) (T_IS_NOT_EQUAL 9452) (T_IS_NOT_IDENTICAL 9453) (T_IS_SMALLER_OR_EQUAL 9454) (T_LOGICAL_AND 9455) (T_LOGICAL_OR 9456) (T_LOGICAL_XOR 9457) (T_POW 9458) (T_SL 9459) (T_SPACESHIP 9460) (T_SR 9461) ("^" 9462) (backup_fn_flags 9736) ("|" 9463)) 4225 (("$" 9358) (T_ABSTRACT 9536) (T_ARRAY 9537) (T_AS 9538) (T_BREAK 9539) (T_CALLABLE 9540) (T_CASE 9541) (T_CATCH 9542) (T_CLASS 9543) (T_CLASS_C 9544) (T_CLONE 9545) (T_CONST 9546) (T_CONTINUE 9547) (T_DECLARE 9548) (T_DEFAULT 9549) (T_DIR 9550) (T_DO 9551) (T_ECHO 9552) (T_ELSE 9553) (T_ELSEIF 9554) (T_EMPTY 9555) (T_ENDDECLARE 9556) (T_ENDFOR 9557) (T_ENDFOREACH 9558) (T_ENDIF 9559) (T_ENDSWITCH 9560) (T_ENDWHILE 9561) (T_ENUM 9562) (T_EVAL 9563) (T_EXIT 9564) (T_EXTENDS 9565) (T_FILE 9566) (T_FINAL 9567) (T_FINALLY 9568) (T_FN 9569) (T_FOR 9570) (T_FOREACH 9571) (T_FUNCTION 9572) (T_FUNC_C 9573) (T_GLOBAL 9574) (T_GOTO 9575) (T_IF 9576) (T_IMPLEMENTS 9577) (T_INCLUDE 9578) (T_INCLUDE_ONCE 9579) (T_INSTANCEOF 9580) (T_INSTEADOF 9581) (T_INTERFACE 9582) (T_ISSET 9583) (T_LINE 9584) (T_LIST 9585) (T_LOGICAL_AND 9586) (T_LOGICAL_OR 9587) (T_LOGICAL_XOR 9588) (T_MATCH 9589) (T_METHOD_C 9590) (T_NAMESPACE 9591) (T_NEW 9592) (T_NS_C 9593) (T_PRINT 9594) (T_PRIVATE 9595) (T_PROTECTED 9596) (T_PUBLIC 9597) (T_READONLY 9598) (T_REQUIRE 9599) (T_REQUIRE_ONCE 9600) (T_RETURN 9601) (T_STATIC 9602) (T_STRING 9603) (T_SWITCH 9604) (T_THROW 9605) (T_TRAIT 9606) (T_TRAIT_C 9607) (T_TRY 9608) (T_UNSET 9609) (T_USE 9610) (T_VAR 9611) (T_VARIABLE 9405) (T_WHILE 9612) (T_YIELD 9613) (identifier 9739) (member_name 9740) (reserved_non_modifiers 9616) (semi_reserved 9617) (simple_variable 9741) ("{" 9742)) 4226 (("(" 9622) (argument_list 9745)) 4227 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 9743) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4228 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 9744)) 4229 ((T_FN 35) (T_FUNCTION 127) (fn 9419) #'9420 (inline_function 9749)) 4230 (("$" 9358) (T_STRING 9758) (T_VARIABLE 9405) (property_name 9765) (simple_variable 9760) ("{" 9761)) 4231 (("$" 9358) (T_STRING 9758) (T_VARIABLE 9405) (property_name 9759) (simple_variable 9760) ("{" 9761)) 4232 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 9756) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 4233 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 9754) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4234 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 9755)) 4235 (("]" 9757)) 4236 (("(" 9622) (argument_list 9764)) 4237 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 9762) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4238 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 9763)) 4239 (("(" 9622) (argument_list 9766)) 4240 (("`" 9768)) 4241 (("]" 9770)) 4242 (("=" 9771)) 4243 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 9772) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4244 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10306) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4245 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 10304) (encaps_var 5299)) 4246 (("$" 9776) (T_VARIABLE 9823) (simple_variable 10300) ("{" 10301)) 4247 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 10298) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 4248 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10297) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4249 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10296) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4250 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10295) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4251 (("(" 10292)) 4252 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10291) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4253 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10290) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4254 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10289) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4255 (("\"" 1509) ("$" 10079) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 10080) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 10081) ("[" 1529) (array_object_dereferenceable 10082) (callable_expr 10083) (callable_variable 10084) (class_constant 1533) (class_name 10085) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 10086) (name 10087) (simple_variable 10088) (static_member 10089) (variable 10288) (variable_class_name 10091)) 4256 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10287) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4257 (("(" 10284)) 4258 (("(" 10281)) 4259 (("(" 10277) (exit_expr 10278)) 4260 (("\"" 1509) ("$" 10079) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 10080) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 10081) ("[" 1529) (array_object_dereferenceable 10082) (callable_expr 10083) (callable_variable 10084) (class_constant 1533) (class_name 10085) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 10086) (name 10087) (simple_variable 10088) (static_member 10089) (variable 10276) (variable_class_name 10091)) 4261 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10275) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4262 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10274) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4263 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10273) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4264 (("(" 10269)) 4265 (("(" 10264)) 4266 (("(" 10258)) 4267 (("$" 10079) ("(" 10210) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 10211) (T_NAME_QUALIFIED 10212) (T_NAME_RELATIVE 10213) (T_READONLY 2936) (T_STATIC 10214) (T_STRING 10215) (T_VARIABLE 10081) (anonymous_class 10216) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 10217) (attribute 2943) (attributes 10218) (class_modifier 2945) (class_name 10219) (class_name_reference 10220) (name 10221) (new_variable 10222) (simple_variable 10223)) 4268 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10209) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4269 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10208) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4270 (("(" 10040) (argument_list 10207)) 4271 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10206) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4272 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10205) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4273 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 10200) (T_END_HEREDOC 10201) (T_VARIABLE 2900) (encaps_list 10202) (encaps_var 2902)) 4274 ((T_FN 35) (T_FUNCTION 127) (fn 9837) #'9838 (inline_function 10199)) 4275 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10198) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4276 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10197) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4277 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10196) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4278 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10193) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4279 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10192) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4280 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 10188) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 4281 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 10186) (encaps_list 2805) (encaps_var 2806)) 4282 ((T_NULLSAFE_OBJECT_OPERATOR 10169) (T_OBJECT_OPERATOR 10170) ("[" 10171) ("{" 10172)) 4283 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 10166) (attribute 2728) (fn 9837) #'9838 (inline_function 10167)) 4284 (("(" 10040) (argument_list 10165)) 4285 ((T_PAAMAYIM_NEKUDOTAYIM 10157)) 4286 (("%" 9852) ("*" 9853) ("+" 9854) ("-" 9855) ("." 9856) ("/" 9857) ("<" 9858) (">" 9859) ("?" 9860) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 9861) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 9862) (T_BOOLEAN_AND 9863) (T_BOOLEAN_OR 9864) (T_COALESCE 9865) (T_DOUBLE_ARROW 10155) (T_INSTANCEOF 9866) (T_IS_EQUAL 9867) (T_IS_GREATER_OR_EQUAL 9868) (T_IS_IDENTICAL 9869) (T_IS_NOT_EQUAL 9870) (T_IS_NOT_IDENTICAL 9871) (T_IS_SMALLER_OR_EQUAL 9872) (T_LOGICAL_AND 9873) (T_LOGICAL_OR 9874) (T_LOGICAL_XOR 9875) (T_POW 9876) (T_SL 9877) (T_SPACESHIP 9878) (T_SR 9879) ("^" 9880) ("|" 9881)) 4287 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 10144)) 4288 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 10132)) 4289 (("(" 10040) (argument_list 10131)) 4290 (("=" 10048) (T_AND_EQUAL 10049) (T_COALESCE_EQUAL 10050) (T_CONCAT_EQUAL 10051) (T_DEC 10052) (T_DIV_EQUAL 10053) (T_INC 10054) (T_MINUS_EQUAL 10055) (T_MOD_EQUAL 10056) (T_MUL_EQUAL 10057) (T_OR_EQUAL 10058) (T_PLUS_EQUAL 10059) (T_POW_EQUAL 10060) (T_SL_EQUAL 10061) (T_SR_EQUAL 10062) (T_XOR_EQUAL 10063)) 4291 ((T_PAAMAYIM_NEKUDOTAYIM 9953)) 4292 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 9851) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4293 (("%" 9852) ("*" 9853) ("+" 9854) ("-" 9855) ("." 9856) ("/" 9857) ("<" 9858) (">" 9859) ("?" 9860) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 9861) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 9862) (T_BOOLEAN_AND 9863) (T_BOOLEAN_OR 9864) (T_COALESCE 9865) (T_INSTANCEOF 9866) (T_IS_EQUAL 9867) (T_IS_GREATER_OR_EQUAL 9868) (T_IS_IDENTICAL 9869) (T_IS_NOT_EQUAL 9870) (T_IS_NOT_IDENTICAL 9871) (T_IS_SMALLER_OR_EQUAL 9872) (T_LOGICAL_AND 9873) (T_LOGICAL_OR 9874) (T_LOGICAL_XOR 9875) (T_POW 9876) (T_SL 9877) (T_SPACESHIP 9878) (T_SR 9879) ("^" 9880) ("|" 9881)) 4294 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 9952) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4295 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 9951) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4296 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 9950) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4297 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 9949) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4298 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 9948) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4299 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 9947) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4300 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 9946) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4301 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 9945) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4302 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 9940) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 9941) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 4303 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 9939) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4304 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 9938) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4305 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 9937) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4306 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 9936) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4307 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 9935) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4308 (("$" 9897) ("(" 9898) (T_NAME_FULLY_QUALIFIED 9899) (T_NAME_QUALIFIED 9900) (T_NAME_RELATIVE 9901) (T_STATIC 9902) (T_STRING 9903) (T_VARIABLE 9904) (class_name 9905) (class_name_reference 9906) (name 9907) (new_variable 9908) (simple_variable 9909)) 4309 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 9896) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4310 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 9895) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4311 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 9894) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4312 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 9893) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4313 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 9892) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4314 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 9891) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4315 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 9890) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4316 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 9889) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4317 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 9888) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4318 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 9887) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4319 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 9886) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4320 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 9885) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4321 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 9884) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4322 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 9883) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4323 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 9882) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4324 (("$" 9897) (T_VARIABLE 9904) (simple_variable 9931) ("{" 9932)) 4325 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 9929) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 4326 ((T_PAAMAYIM_NEKUDOTAYIM 9927)) 4327 ((T_NULLSAFE_OBJECT_OPERATOR 9910) (T_OBJECT_OPERATOR 9911) (T_PAAMAYIM_NEKUDOTAYIM 9912) ("[" 9913) ("{" 9914)) 4328 (("$" 9897) (T_STRING 9920) (T_VARIABLE 9904) (property_name 9926) (simple_variable 9922) ("{" 9923)) 4329 (("$" 9897) (T_STRING 9920) (T_VARIABLE 9904) (property_name 9921) (simple_variable 9922) ("{" 9923)) 4330 (("$" 9897) (T_VARIABLE 9904) (simple_variable 9919)) 4331 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 9917) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 4332 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 9915) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4333 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 9916)) 4334 (("]" 9918)) 4335 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 9924) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4336 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 9925)) 4337 (("$" 9897) (T_VARIABLE 9904) (simple_variable 9928)) 4338 (("%" 292) (")" 9930) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 4339 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 9933) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4340 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 9934)) 4341 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 9944) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4342 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 9942) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 4343 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 9943) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4344 (("$" 9776) (T_ABSTRACT 9954) (T_ARRAY 9955) (T_AS 9956) (T_BREAK 9957) (T_CALLABLE 9958) (T_CASE 9959) (T_CATCH 9960) (T_CLASS 9961) (T_CLASS_C 9962) (T_CLONE 9963) (T_CONST 9964) (T_CONTINUE 9965) (T_DECLARE 9966) (T_DEFAULT 9967) (T_DIR 9968) (T_DO 9969) (T_ECHO 9970) (T_ELSE 9971) (T_ELSEIF 9972) (T_EMPTY 9973) (T_ENDDECLARE 9974) (T_ENDFOR 9975) (T_ENDFOREACH 9976) (T_ENDIF 9977) (T_ENDSWITCH 9978) (T_ENDWHILE 9979) (T_ENUM 9980) (T_EVAL 9981) (T_EXIT 9982) (T_EXTENDS 9983) (T_FILE 9984) (T_FINAL 9985) (T_FINALLY 9986) (T_FN 9987) (T_FOR 9988) (T_FOREACH 9989) (T_FUNCTION 9990) (T_FUNC_C 9991) (T_GLOBAL 9992) (T_GOTO 9993) (T_IF 9994) (T_IMPLEMENTS 9995) (T_INCLUDE 9996) (T_INCLUDE_ONCE 9997) (T_INSTANCEOF 9998) (T_INSTEADOF 9999) (T_INTERFACE 10000) (T_ISSET 10001) (T_LINE 10002) (T_LIST 10003) (T_LOGICAL_AND 10004) (T_LOGICAL_OR 10005) (T_LOGICAL_XOR 10006) (T_MATCH 10007) (T_METHOD_C 10008) (T_NAMESPACE 10009) (T_NEW 10010) (T_NS_C 10011) (T_PRINT 10012) (T_PRIVATE 10013) (T_PROTECTED 10014) (T_PUBLIC 10015) (T_READONLY 10016) (T_REQUIRE 10017) (T_REQUIRE_ONCE 10018) (T_RETURN 10019) (T_STATIC 10020) (T_STRING 10021) (T_SWITCH 10022) (T_THROW 10023) (T_TRAIT 10024) (T_TRAIT_C 10025) (T_TRY 10026) (T_UNSET 10027) (T_USE 10028) (T_VAR 10029) (T_VARIABLE 9823) (T_WHILE 10030) (T_YIELD 10031) (identifier 10032) (member_name 10033) (reserved_non_modifiers 10034) (semi_reserved 10035) (simple_variable 10036) ("{" 10037)) 4345 (("(" 10040) (argument_list 10041)) 4346 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 10038) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4347 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 10039)) 4348 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 10042) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 10043) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 10044) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 4349 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 10047) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 4350 (("," 1469) (possible_comma 10045)) 4351 ((")" 10046)) 4352 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (ampersand 10077) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10078) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4353 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10076) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4354 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10075) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4355 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10074) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4356 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10073) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4357 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10072) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4358 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10071) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4359 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10070) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4360 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10069) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4361 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10068) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4362 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10067) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4363 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10066) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4364 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10065) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4365 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10064) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4366 (("\"" 1509) ("$" 10079) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 10080) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 10081) ("[" 1529) (array_object_dereferenceable 10082) (callable_expr 10083) (callable_variable 10084) (class_constant 1533) (class_name 10085) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 10086) (name 10087) (simple_variable 10088) (static_member 10089) (variable 10090) (variable_class_name 10091)) 4367 (("$" 10079) (T_VARIABLE 10081) (simple_variable 10127) ("{" 10128)) 4368 (("(" 10095) (argument_list 10126)) 4369 ((T_NULLSAFE_OBJECT_OPERATOR 10109) (T_OBJECT_OPERATOR 10110) ("[" 10111) ("{" 10112)) 4370 (("(" 10095) (argument_list 10108)) 4371 ((T_PAAMAYIM_NEKUDOTAYIM 10104)) 4372 (("(" 10095) (argument_list 10103)) 4373 ((T_PAAMAYIM_NEKUDOTAYIM 10092)) 4374 (("$" 10079) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 10081) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 10093) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 10094) ("{" 1627)) 4375 (("(" 10095) (argument_list 10096)) 4376 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 10097) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 10098) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 10099) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 4377 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 10102) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 4378 (("," 1469) (possible_comma 10100)) 4379 ((")" 10101)) 4380 (("$" 10079) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 10081) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 10105) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 10106) ("{" 1643)) 4381 (("(" 10095) (argument_list 10107)) 4382 (("$" 10079) (T_STRING 10117) (T_VARIABLE 10081) (property_name 10124) (simple_variable 10119) ("{" 10120)) 4383 (("$" 10079) (T_STRING 10117) (T_VARIABLE 10081) (property_name 10118) (simple_variable 10119) ("{" 10120)) 4384 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 10115) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 4385 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 10113) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4386 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 10114)) 4387 (("]" 10116)) 4388 (("(" 10095) (argument_list 10123)) 4389 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 10121) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4390 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 10122)) 4391 (("(" 10095) (argument_list 10125)) 4392 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 10129) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4393 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 10130)) 4394 ((backup_doc_comment 10133)) 4395 (("(" 10134)) 4396 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 10135)) 4397 ((")" 10136)) 4398 ((T_USE 159) (lexical_vars 10137)) 4399 ((":" 161) (return_type 10138)) 4400 ((backup_fn_flags 10139)) 4401 (("{" 10140)) 4402 ((inner_statement_list 10141)) 4403 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 10142) ("~" 125)) 4404 ((backup_fn_flags 10143)) 4405 ((backup_doc_comment 10145)) 4406 (("(" 10146)) 4407 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 10147)) 4408 ((")" 10148)) 4409 ((":" 2241) (return_type 10149)) 4410 ((T_DOUBLE_ARROW 10150)) 4411 ((backup_fn_flags 10151)) 4412 ((backup_lex_pos 10152)) 4413 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10153) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4414 (("%" 9852) ("*" 9853) ("+" 9854) ("-" 9855) ("." 9856) ("/" 9857) ("<" 9858) (">" 9859) ("?" 9860) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 9861) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 9862) (T_BOOLEAN_AND 9863) (T_BOOLEAN_OR 9864) (T_COALESCE 9865) (T_INSTANCEOF 9866) (T_IS_EQUAL 9867) (T_IS_GREATER_OR_EQUAL 9868) (T_IS_IDENTICAL 9869) (T_IS_NOT_EQUAL 9870) (T_IS_NOT_IDENTICAL 9871) (T_IS_SMALLER_OR_EQUAL 9872) (T_LOGICAL_AND 9873) (T_LOGICAL_OR 9874) (T_LOGICAL_XOR 9875) (T_POW 9876) (T_SL 9877) (T_SPACESHIP 9878) (T_SR 9879) ("^" 9880) (backup_fn_flags 10154) ("|" 9881)) 4415 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 10156) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4416 (("$" 9776) (T_ABSTRACT 9954) (T_ARRAY 9955) (T_AS 9956) (T_BREAK 9957) (T_CALLABLE 9958) (T_CASE 9959) (T_CATCH 9960) (T_CLASS 9961) (T_CLASS_C 9962) (T_CLONE 9963) (T_CONST 9964) (T_CONTINUE 9965) (T_DECLARE 9966) (T_DEFAULT 9967) (T_DIR 9968) (T_DO 9969) (T_ECHO 9970) (T_ELSE 9971) (T_ELSEIF 9972) (T_EMPTY 9973) (T_ENDDECLARE 9974) (T_ENDFOR 9975) (T_ENDFOREACH 9976) (T_ENDIF 9977) (T_ENDSWITCH 9978) (T_ENDWHILE 9979) (T_ENUM 9980) (T_EVAL 9981) (T_EXIT 9982) (T_EXTENDS 9983) (T_FILE 9984) (T_FINAL 9985) (T_FINALLY 9986) (T_FN 9987) (T_FOR 9988) (T_FOREACH 9989) (T_FUNCTION 9990) (T_FUNC_C 9991) (T_GLOBAL 9992) (T_GOTO 9993) (T_IF 9994) (T_IMPLEMENTS 9995) (T_INCLUDE 9996) (T_INCLUDE_ONCE 9997) (T_INSTANCEOF 9998) (T_INSTEADOF 9999) (T_INTERFACE 10000) (T_ISSET 10001) (T_LINE 10002) (T_LIST 10003) (T_LOGICAL_AND 10004) (T_LOGICAL_OR 10005) (T_LOGICAL_XOR 10006) (T_MATCH 10007) (T_METHOD_C 10008) (T_NAMESPACE 10009) (T_NEW 10010) (T_NS_C 10011) (T_PRINT 10012) (T_PRIVATE 10013) (T_PROTECTED 10014) (T_PUBLIC 10015) (T_READONLY 10016) (T_REQUIRE 10017) (T_REQUIRE_ONCE 10018) (T_RETURN 10019) (T_STATIC 10020) (T_STRING 10021) (T_SWITCH 10022) (T_THROW 10023) (T_TRAIT 10024) (T_TRAIT_C 10025) (T_TRY 10026) (T_UNSET 10027) (T_USE 10028) (T_VAR 10029) (T_VARIABLE 9823) (T_WHILE 10030) (T_YIELD 10031) (identifier 10158) (member_name 10159) (reserved_non_modifiers 10034) (semi_reserved 10035) (simple_variable 10160) ("{" 10161)) 4417 (("(" 10040) (argument_list 10164)) 4418 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 10162) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4419 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 10163)) 4420 ((T_FN 35) (T_FUNCTION 127) (fn 9837) #'9838 (inline_function 10168)) 4421 (("$" 9776) (T_STRING 10177) (T_VARIABLE 9823) (property_name 10184) (simple_variable 10179) ("{" 10180)) 4422 (("$" 9776) (T_STRING 10177) (T_VARIABLE 9823) (property_name 10178) (simple_variable 10179) ("{" 10180)) 4423 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 10175) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 4424 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 10173) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4425 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 10174)) 4426 (("]" 10176)) 4427 (("(" 10040) (argument_list 10183)) 4428 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 10181) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4429 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 10182)) 4430 (("(" 10040) (argument_list 10185)) 4431 (("`" 10187)) 4432 (("]" 10189)) 4433 (("=" 10190)) 4434 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10191) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4435 (("%" 9852) ("*" 9853) ("+" 9854) ("-" 9855) ("." 9856) ("/" 9857) ("<" 9858) (">" 9859) ("?" 9860) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 9861) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 9862) (T_BOOLEAN_AND 9863) (T_BOOLEAN_OR 9864) (T_COALESCE 9865) (T_DOUBLE_ARROW 10194) (T_INSTANCEOF 9866) (T_IS_EQUAL 9867) (T_IS_GREATER_OR_EQUAL 9868) (T_IS_IDENTICAL 9869) (T_IS_NOT_EQUAL 9870) (T_IS_NOT_IDENTICAL 9871) (T_IS_SMALLER_OR_EQUAL 9872) (T_LOGICAL_AND 9873) (T_LOGICAL_OR 9874) (T_LOGICAL_XOR 9875) (T_POW 9876) (T_SL 9877) (T_SPACESHIP 9878) (T_SR 9879) ("^" 9880) ("|" 9881)) 4436 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10195) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4437 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 10204) (T_VARIABLE 2900) (encaps_var 2914)) 4438 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 10203) (T_VARIABLE 2900) (encaps_var 2905)) 4439 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 10256) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 4440 ((T_CLASS 10248)) 4441 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 10247) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 10217) (attribute 2980) (class_modifier 2945)) 4442 ((T_PAAMAYIM_NEKUDOTAYIM 10245)) 4443 (("(" 10236) (argument_list 10237) (ctor_arguments 10238)) 4444 ((T_NULLSAFE_OBJECT_OPERATOR 10224) (T_OBJECT_OPERATOR 10225) (T_PAAMAYIM_NEKUDOTAYIM 10226) ("[" 10227) ("{" 10228)) 4445 (("$" 10079) (T_STRING 10117) (T_VARIABLE 10081) (property_name 10235) (simple_variable 10119) ("{" 10120)) 4446 (("$" 10079) (T_STRING 10117) (T_VARIABLE 10081) (property_name 10234) (simple_variable 10119) ("{" 10120)) 4447 (("$" 10079) (T_VARIABLE 10081) (simple_variable 10233)) 4448 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 10231) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 4449 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 10229) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4450 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 10230)) 4451 (("]" 10232)) 4452 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 10239) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 10240) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 10241) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 4453 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 10244) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 4454 (("," 1469) (possible_comma 10242)) 4455 ((")" 10243)) 4456 (("$" 10079) (T_VARIABLE 10081) (simple_variable 10246)) 4457 (("(" 2982) (argument_list 2983) (ctor_arguments 10249)) 4458 ((T_EXTENDS 2985) (extends_from 10250)) 4459 ((T_IMPLEMENTS 2987) (implements_list 10251)) 4460 ((backup_doc_comment 10252)) 4461 (("{" 10253)) 4462 ((class_statement_list 10254)) 4463 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 10255)) 4464 (("%" 292) (")" 10257) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 4465 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 10259) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 4466 (("%" 292) (")" 10260) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 4467 (("{" 10261)) 4468 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 10262) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 4469 (("}" 10263)) 4470 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 10265) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 4471 ((")" 10266)) 4472 (("=" 10267)) 4473 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10268) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4474 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 10270) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 4475 (("," 5258) (possible_comma 10271)) 4476 ((")" 10272)) 4477 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 10279) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 4478 ((")" 10280)) 4479 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 10282) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 4480 (("%" 292) (")" 10283) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 4481 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 10285) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 4482 (("%" 292) (")" 10286) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 4483 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 10293) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 4484 ((")" 10294)) 4485 (("%" 292) (")" 10299) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 4486 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 10302) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4487 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 10303)) 4488 (("\"" 10305) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 4489 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 10315) (T_VARIABLE 2900) (encaps_var 2914)) 4490 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 10314) (T_VARIABLE 2900) (encaps_var 2905)) 4491 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 10367) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 4492 ((T_CLASS 10359)) 4493 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 10358) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 10328) (attribute 2980) (class_modifier 2945)) 4494 ((T_PAAMAYIM_NEKUDOTAYIM 10356)) 4495 (("(" 10347) (argument_list 10348) (ctor_arguments 10349)) 4496 ((T_NULLSAFE_OBJECT_OPERATOR 10335) (T_OBJECT_OPERATOR 10336) (T_PAAMAYIM_NEKUDOTAYIM 10337) ("[" 10338) ("{" 10339)) 4497 (("$" 9661) (T_STRING 9699) (T_VARIABLE 9663) (property_name 10346) (simple_variable 9701) ("{" 9702)) 4498 (("$" 9661) (T_STRING 9699) (T_VARIABLE 9663) (property_name 10345) (simple_variable 9701) ("{" 9702)) 4499 (("$" 9661) (T_VARIABLE 9663) (simple_variable 10344)) 4500 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 10342) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 4501 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 10340) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4502 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 10341)) 4503 (("]" 10343)) 4504 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 10350) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 10351) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 10352) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 4505 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 10355) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 4506 (("," 1469) (possible_comma 10353)) 4507 ((")" 10354)) 4508 (("$" 9661) (T_VARIABLE 9663) (simple_variable 10357)) 4509 (("(" 2982) (argument_list 2983) (ctor_arguments 10360)) 4510 ((T_EXTENDS 2985) (extends_from 10361)) 4511 ((T_IMPLEMENTS 2987) (implements_list 10362)) 4512 ((backup_doc_comment 10363)) 4513 (("{" 10364)) 4514 ((class_statement_list 10365)) 4515 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 10366)) 4516 (("%" 292) (")" 10368) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 4517 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 10370) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 4518 (("%" 292) (")" 10371) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 4519 (("{" 10372)) 4520 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 10373) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 4521 (("}" 10374)) 4522 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 10376) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 4523 ((")" 10377)) 4524 (("=" 10378)) 4525 (("!" 9356) ("\"" 9357) ("$" 9358) ("(" 9359) ("+" 9360) ("-" 9361) ("@" 9362) (T_ARRAY 9363) (T_ARRAY_CAST 9364) (T_ATTRIBUTE 126) (T_BOOL_CAST 9365) (T_CLASS_C 9366) (T_CLONE 9367) (T_CONSTANT_ENCAPSED_STRING 9368) (T_DEC 9369) (T_DIR 9370) (T_DNUMBER 9371) (T_DOUBLE_CAST 9372) (T_EMPTY 9373) (T_EVAL 9374) (T_EXIT 9375) (T_FILE 9376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9377) (T_INC 9378) (T_INCLUDE 9379) (T_INCLUDE_ONCE 9380) (T_INT_CAST 9381) (T_ISSET 9382) (T_LINE 9383) (T_LIST 9384) (T_LNUMBER 9385) (T_MATCH 9386) (T_METHOD_C 9387) (T_NAME_FULLY_QUALIFIED 9388) (T_NAME_QUALIFIED 9389) (T_NAME_RELATIVE 9390) (T_NEW 9391) (T_NS_C 9392) (T_OBJECT_CAST 9393) (T_PRINT 9394) (T_READONLY 9395) (T_REQUIRE 9396) (T_REQUIRE_ONCE 9397) (T_START_HEREDOC 9398) (T_STATIC 9399) (T_STRING 9400) (T_STRING_CAST 9401) (T_THROW 9402) (T_TRAIT_C 9403) (T_UNSET_CAST 9404) (T_VARIABLE 9405) (T_YIELD 9406) (T_YIELD_FROM 9407) ("[" 9408) ("`" 9409) (array_object_dereferenceable 9410) (attribute 131) (attributes 9411) (callable_expr 9412) (callable_variable 9413) (class_constant 9414) (class_name 9415) (constant 9416) (dereferenceable_scalar 9417) (expr 10379) (fn 9419) (fully_dereferenceable 104) #'9420 (function_call 9421) (inline_function 9422) (internal_functions_in_yacc 9423) (match 9424) (name 9425) (new_expr 9426) (scalar 9427) (simple_variable 9428) (static_member 9429) (variable 9430) (variable_class_name 9431) ("~" 9432)) 4526 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 10381) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 4527 (("," 5258) (possible_comma 10382)) 4528 ((")" 10383)) 4529 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 10390) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 4530 ((")" 10391)) 4531 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 10393) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 4532 (("%" 292) (")" 10394) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 4533 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 10396) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 4534 (("%" 292) (")" 10397) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 4535 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 10404) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 4536 ((")" 10405)) 4537 (("%" 292) (")" 10410) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 4538 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 10413) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4539 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 10414)) 4540 (("\"" 10416) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 4541 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 10419) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 4542 (("$" 667) (T_ABSTRACT 846) (T_ARRAY 847) (T_AS 848) (T_BREAK 849) (T_CALLABLE 850) (T_CASE 851) (T_CATCH 852) (T_CLASS 853) (T_CLASS_C 854) (T_CLONE 855) (T_CONST 856) (T_CONTINUE 857) (T_DECLARE 858) (T_DEFAULT 859) (T_DIR 860) (T_DO 861) (T_ECHO 862) (T_ELSE 863) (T_ELSEIF 864) (T_EMPTY 865) (T_ENDDECLARE 866) (T_ENDFOR 867) (T_ENDFOREACH 868) (T_ENDIF 869) (T_ENDSWITCH 870) (T_ENDWHILE 871) (T_ENUM 872) (T_EVAL 873) (T_EXIT 874) (T_EXTENDS 875) (T_FILE 876) (T_FINAL 877) (T_FINALLY 878) (T_FN 879) (T_FOR 880) (T_FOREACH 881) (T_FUNCTION 882) (T_FUNC_C 883) (T_GLOBAL 884) (T_GOTO 885) (T_IF 886) (T_IMPLEMENTS 887) (T_INCLUDE 888) (T_INCLUDE_ONCE 889) (T_INSTANCEOF 890) (T_INSTEADOF 891) (T_INTERFACE 892) (T_ISSET 893) (T_LINE 894) (T_LIST 895) (T_LOGICAL_AND 896) (T_LOGICAL_OR 897) (T_LOGICAL_XOR 898) (T_MATCH 899) (T_METHOD_C 900) (T_NAMESPACE 901) (T_NEW 902) (T_NS_C 903) (T_PRINT 904) (T_PRIVATE 905) (T_PROTECTED 906) (T_PUBLIC 907) (T_READONLY 908) (T_REQUIRE 909) (T_REQUIRE_ONCE 910) (T_RETURN 911) (T_STATIC 912) (T_STRING 913) (T_SWITCH 914) (T_THROW 915) (T_TRAIT 916) (T_TRAIT_C 917) (T_TRY 918) (T_UNSET 919) (T_USE 920) (T_VAR 921) (T_VARIABLE 715) (T_WHILE 922) (T_YIELD 923) (identifier 10421) (member_name 10422) (reserved_non_modifiers 926) (semi_reserved 927) (simple_variable 10423) ("{" 10424)) 4543 (("(" 932) (argument_list 10427)) 4544 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 10425) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4545 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 10426)) 4546 ((T_FN 35) (T_FUNCTION 127) (fn 729) #'730 (inline_function 10431)) 4547 (("$" 667) (T_STRING 10440) (T_VARIABLE 715) (property_name 10447) (simple_variable 10442) ("{" 10443)) 4548 (("$" 667) (T_STRING 10440) (T_VARIABLE 715) (property_name 10441) (simple_variable 10442) ("{" 10443)) 4549 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 10438) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 4550 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 10436) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4551 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 10437)) 4552 (("]" 10439)) 4553 (("(" 932) (argument_list 10446)) 4554 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 10444) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4555 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 10445)) 4556 (("(" 932) (argument_list 10448)) 4557 (("`" 10450)) 4558 (("]" 10452)) 4559 (("=" 10453)) 4560 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 10454) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 4561 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10962) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4562 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 10960) (encaps_var 5299)) 4563 (("$" 10458) (T_VARIABLE 10505) (simple_variable 10956) ("{" 10957)) 4564 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 10954) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 4565 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10953) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4566 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10952) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4567 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10951) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4568 (("(" 10948)) 4569 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10947) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4570 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10946) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4571 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10945) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4572 (("\"" 1509) ("$" 10761) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 10762) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 10763) ("[" 1529) (array_object_dereferenceable 10764) (callable_expr 10765) (callable_variable 10766) (class_constant 1533) (class_name 10767) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 10768) (name 10769) (simple_variable 10770) (static_member 10771) (variable 10944) (variable_class_name 10773)) 4573 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10943) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4574 (("(" 10940)) 4575 (("(" 10937)) 4576 (("(" 10933) (exit_expr 10934)) 4577 (("\"" 1509) ("$" 10761) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 10762) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 10763) ("[" 1529) (array_object_dereferenceable 10764) (callable_expr 10765) (callable_variable 10766) (class_constant 1533) (class_name 10767) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 10768) (name 10769) (simple_variable 10770) (static_member 10771) (variable 10932) (variable_class_name 10773)) 4578 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10931) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4579 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10930) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4580 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10929) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4581 (("(" 10925)) 4582 (("(" 10920)) 4583 (("(" 10914)) 4584 (("$" 10079) ("(" 10210) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 10211) (T_NAME_QUALIFIED 10212) (T_NAME_RELATIVE 10213) (T_READONLY 2936) (T_STATIC 10214) (T_STRING 10215) (T_VARIABLE 10081) (anonymous_class 10892) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 10893) (attribute 2943) (attributes 10894) (class_modifier 2945) (class_name 10219) (class_name_reference 10895) (name 10221) (new_variable 10222) (simple_variable 10223)) 4585 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10891) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4586 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10890) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4587 (("(" 10722) (argument_list 10889)) 4588 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10888) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4589 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10887) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4590 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 10882) (T_END_HEREDOC 10883) (T_VARIABLE 2900) (encaps_list 10884) (encaps_var 2902)) 4591 ((T_FN 35) (T_FUNCTION 127) (fn 10519) #'10520 (inline_function 10881)) 4592 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10880) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4593 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10879) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4594 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10878) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4595 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10875) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4596 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10874) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4597 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 10870) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 4598 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 10868) (encaps_list 2805) (encaps_var 2806)) 4599 ((T_NULLSAFE_OBJECT_OPERATOR 10851) (T_OBJECT_OPERATOR 10852) ("[" 10853) ("{" 10854)) 4600 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 10848) (attribute 2728) (fn 10519) #'10520 (inline_function 10849)) 4601 (("(" 10722) (argument_list 10847)) 4602 ((T_PAAMAYIM_NEKUDOTAYIM 10839)) 4603 (("%" 10534) ("*" 10535) ("+" 10536) ("-" 10537) ("." 10538) ("/" 10539) ("<" 10540) (">" 10541) ("?" 10542) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 10543) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 10544) (T_BOOLEAN_AND 10545) (T_BOOLEAN_OR 10546) (T_COALESCE 10547) (T_DOUBLE_ARROW 10837) (T_INSTANCEOF 10548) (T_IS_EQUAL 10549) (T_IS_GREATER_OR_EQUAL 10550) (T_IS_IDENTICAL 10551) (T_IS_NOT_EQUAL 10552) (T_IS_NOT_IDENTICAL 10553) (T_IS_SMALLER_OR_EQUAL 10554) (T_LOGICAL_AND 10555) (T_LOGICAL_OR 10556) (T_LOGICAL_XOR 10557) (T_POW 10558) (T_SL 10559) (T_SPACESHIP 10560) (T_SR 10561) ("^" 10562) ("|" 10563)) 4604 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 10826)) 4605 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 10814)) 4606 (("(" 10722) (argument_list 10813)) 4607 (("=" 10730) (T_AND_EQUAL 10731) (T_COALESCE_EQUAL 10732) (T_CONCAT_EQUAL 10733) (T_DEC 10734) (T_DIV_EQUAL 10735) (T_INC 10736) (T_MINUS_EQUAL 10737) (T_MOD_EQUAL 10738) (T_MUL_EQUAL 10739) (T_OR_EQUAL 10740) (T_PLUS_EQUAL 10741) (T_POW_EQUAL 10742) (T_SL_EQUAL 10743) (T_SR_EQUAL 10744) (T_XOR_EQUAL 10745)) 4608 ((T_PAAMAYIM_NEKUDOTAYIM 10635)) 4609 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10533) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4610 (("%" 10534) ("*" 10535) ("+" 10536) ("-" 10537) ("." 10538) ("/" 10539) ("<" 10540) (">" 10541) ("?" 10542) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 10543) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 10544) (T_BOOLEAN_AND 10545) (T_BOOLEAN_OR 10546) (T_COALESCE 10547) (T_INSTANCEOF 10548) (T_IS_EQUAL 10549) (T_IS_GREATER_OR_EQUAL 10550) (T_IS_IDENTICAL 10551) (T_IS_NOT_EQUAL 10552) (T_IS_NOT_IDENTICAL 10553) (T_IS_SMALLER_OR_EQUAL 10554) (T_LOGICAL_AND 10555) (T_LOGICAL_OR 10556) (T_LOGICAL_XOR 10557) (T_POW 10558) (T_SL 10559) (T_SPACESHIP 10560) (T_SR 10561) ("^" 10562) ("|" 10563)) 4611 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10634) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4612 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10633) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4613 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10632) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4614 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10631) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4615 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10630) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4616 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10629) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4617 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10628) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4618 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10627) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4619 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 10622) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 10623) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 4620 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10621) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4621 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10620) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4622 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10619) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4623 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10618) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4624 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10617) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4625 (("$" 10579) ("(" 10580) (T_NAME_FULLY_QUALIFIED 10581) (T_NAME_QUALIFIED 10582) (T_NAME_RELATIVE 10583) (T_STATIC 10584) (T_STRING 10585) (T_VARIABLE 10586) (class_name 10587) (class_name_reference 10588) (name 10589) (new_variable 10590) (simple_variable 10591)) 4626 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10578) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4627 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10577) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4628 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10576) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4629 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10575) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4630 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10574) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4631 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10573) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4632 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10572) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4633 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10571) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4634 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10570) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4635 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10569) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4636 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10568) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4637 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10567) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4638 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10566) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4639 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10565) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4640 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10564) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4641 (("$" 10579) (T_VARIABLE 10586) (simple_variable 10613) ("{" 10614)) 4642 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 10611) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 4643 ((T_PAAMAYIM_NEKUDOTAYIM 10609)) 4644 ((T_NULLSAFE_OBJECT_OPERATOR 10592) (T_OBJECT_OPERATOR 10593) (T_PAAMAYIM_NEKUDOTAYIM 10594) ("[" 10595) ("{" 10596)) 4645 (("$" 10579) (T_STRING 10602) (T_VARIABLE 10586) (property_name 10608) (simple_variable 10604) ("{" 10605)) 4646 (("$" 10579) (T_STRING 10602) (T_VARIABLE 10586) (property_name 10603) (simple_variable 10604) ("{" 10605)) 4647 (("$" 10579) (T_VARIABLE 10586) (simple_variable 10601)) 4648 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 10599) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 4649 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 10597) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4650 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 10598)) 4651 (("]" 10600)) 4652 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 10606) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4653 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 10607)) 4654 (("$" 10579) (T_VARIABLE 10586) (simple_variable 10610)) 4655 (("%" 292) (")" 10612) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 4656 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 10615) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4657 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 10616)) 4658 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10626) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4659 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 10624) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 4660 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10625) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4661 (("$" 10458) (T_ABSTRACT 10636) (T_ARRAY 10637) (T_AS 10638) (T_BREAK 10639) (T_CALLABLE 10640) (T_CASE 10641) (T_CATCH 10642) (T_CLASS 10643) (T_CLASS_C 10644) (T_CLONE 10645) (T_CONST 10646) (T_CONTINUE 10647) (T_DECLARE 10648) (T_DEFAULT 10649) (T_DIR 10650) (T_DO 10651) (T_ECHO 10652) (T_ELSE 10653) (T_ELSEIF 10654) (T_EMPTY 10655) (T_ENDDECLARE 10656) (T_ENDFOR 10657) (T_ENDFOREACH 10658) (T_ENDIF 10659) (T_ENDSWITCH 10660) (T_ENDWHILE 10661) (T_ENUM 10662) (T_EVAL 10663) (T_EXIT 10664) (T_EXTENDS 10665) (T_FILE 10666) (T_FINAL 10667) (T_FINALLY 10668) (T_FN 10669) (T_FOR 10670) (T_FOREACH 10671) (T_FUNCTION 10672) (T_FUNC_C 10673) (T_GLOBAL 10674) (T_GOTO 10675) (T_IF 10676) (T_IMPLEMENTS 10677) (T_INCLUDE 10678) (T_INCLUDE_ONCE 10679) (T_INSTANCEOF 10680) (T_INSTEADOF 10681) (T_INTERFACE 10682) (T_ISSET 10683) (T_LINE 10684) (T_LIST 10685) (T_LOGICAL_AND 10686) (T_LOGICAL_OR 10687) (T_LOGICAL_XOR 10688) (T_MATCH 10689) (T_METHOD_C 10690) (T_NAMESPACE 10691) (T_NEW 10692) (T_NS_C 10693) (T_PRINT 10694) (T_PRIVATE 10695) (T_PROTECTED 10696) (T_PUBLIC 10697) (T_READONLY 10698) (T_REQUIRE 10699) (T_REQUIRE_ONCE 10700) (T_RETURN 10701) (T_STATIC 10702) (T_STRING 10703) (T_SWITCH 10704) (T_THROW 10705) (T_TRAIT 10706) (T_TRAIT_C 10707) (T_TRY 10708) (T_UNSET 10709) (T_USE 10710) (T_VAR 10711) (T_VARIABLE 10505) (T_WHILE 10712) (T_YIELD 10713) (identifier 10714) (member_name 10715) (reserved_non_modifiers 10716) (semi_reserved 10717) (simple_variable 10718) ("{" 10719)) 4662 (("(" 10722) (argument_list 10723)) 4663 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 10720) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4664 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 10721)) 4665 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 10724) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 10725) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 10726) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 4666 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 10729) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 4667 (("," 1469) (possible_comma 10727)) 4668 ((")" 10728)) 4669 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (ampersand 10759) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10760) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4670 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10758) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4671 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10757) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4672 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10756) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4673 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10755) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4674 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10754) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4675 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10753) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4676 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10752) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4677 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10751) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4678 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10750) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4679 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10749) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4680 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10748) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4681 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10747) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4682 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10746) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4683 (("\"" 1509) ("$" 10761) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 10762) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 10763) ("[" 1529) (array_object_dereferenceable 10764) (callable_expr 10765) (callable_variable 10766) (class_constant 1533) (class_name 10767) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 10768) (name 10769) (simple_variable 10770) (static_member 10771) (variable 10772) (variable_class_name 10773)) 4684 (("$" 10761) (T_VARIABLE 10763) (simple_variable 10809) ("{" 10810)) 4685 (("(" 10777) (argument_list 10808)) 4686 ((T_NULLSAFE_OBJECT_OPERATOR 10791) (T_OBJECT_OPERATOR 10792) ("[" 10793) ("{" 10794)) 4687 (("(" 10777) (argument_list 10790)) 4688 ((T_PAAMAYIM_NEKUDOTAYIM 10786)) 4689 (("(" 10777) (argument_list 10785)) 4690 ((T_PAAMAYIM_NEKUDOTAYIM 10774)) 4691 (("$" 10761) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 10763) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 10775) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 10776) ("{" 1627)) 4692 (("(" 10777) (argument_list 10778)) 4693 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 10779) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 10780) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 10781) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 4694 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 10784) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 4695 (("," 1469) (possible_comma 10782)) 4696 ((")" 10783)) 4697 (("$" 10761) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 10763) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 10787) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 10788) ("{" 1643)) 4698 (("(" 10777) (argument_list 10789)) 4699 (("$" 10761) (T_STRING 10799) (T_VARIABLE 10763) (property_name 10806) (simple_variable 10801) ("{" 10802)) 4700 (("$" 10761) (T_STRING 10799) (T_VARIABLE 10763) (property_name 10800) (simple_variable 10801) ("{" 10802)) 4701 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 10797) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 4702 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 10795) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4703 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 10796)) 4704 (("]" 10798)) 4705 (("(" 10777) (argument_list 10805)) 4706 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 10803) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4707 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 10804)) 4708 (("(" 10777) (argument_list 10807)) 4709 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 10811) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4710 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 10812)) 4711 ((backup_doc_comment 10815)) 4712 (("(" 10816)) 4713 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 10817)) 4714 ((")" 10818)) 4715 ((T_USE 159) (lexical_vars 10819)) 4716 ((":" 161) (return_type 10820)) 4717 ((backup_fn_flags 10821)) 4718 (("{" 10822)) 4719 ((inner_statement_list 10823)) 4720 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 10824) ("~" 125)) 4721 ((backup_fn_flags 10825)) 4722 ((backup_doc_comment 10827)) 4723 (("(" 10828)) 4724 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 10829)) 4725 ((")" 10830)) 4726 ((":" 2241) (return_type 10831)) 4727 ((T_DOUBLE_ARROW 10832)) 4728 ((backup_fn_flags 10833)) 4729 ((backup_lex_pos 10834)) 4730 (("!" 9774) ("\"" 9775) ("$" 9776) ("(" 9777) ("+" 9778) ("-" 9779) ("@" 9780) (T_ARRAY 9781) (T_ARRAY_CAST 9782) (T_ATTRIBUTE 126) (T_BOOL_CAST 9783) (T_CLASS_C 9784) (T_CLONE 9785) (T_CONSTANT_ENCAPSED_STRING 9786) (T_DEC 9787) (T_DIR 9788) (T_DNUMBER 9789) (T_DOUBLE_CAST 9790) (T_EMPTY 9791) (T_EVAL 9792) (T_EXIT 9793) (T_FILE 9794) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 9795) (T_INC 9796) (T_INCLUDE 9797) (T_INCLUDE_ONCE 9798) (T_INT_CAST 9799) (T_ISSET 9800) (T_LINE 9801) (T_LIST 9802) (T_LNUMBER 9803) (T_MATCH 9804) (T_METHOD_C 9805) (T_NAME_FULLY_QUALIFIED 9806) (T_NAME_QUALIFIED 9807) (T_NAME_RELATIVE 9808) (T_NEW 9809) (T_NS_C 9810) (T_OBJECT_CAST 9811) (T_PRINT 9812) (T_READONLY 9813) (T_REQUIRE 9814) (T_REQUIRE_ONCE 9815) (T_START_HEREDOC 9816) (T_STATIC 9817) (T_STRING 9818) (T_STRING_CAST 9819) (T_THROW 9820) (T_TRAIT_C 9821) (T_UNSET_CAST 9822) (T_VARIABLE 9823) (T_YIELD 9824) (T_YIELD_FROM 9825) ("[" 9826) ("`" 9827) (array_object_dereferenceable 9828) (attribute 131) (attributes 9829) (callable_expr 9830) (callable_variable 9831) (class_constant 9832) (class_name 9833) (constant 9834) (dereferenceable_scalar 9835) (expr 10835) (fn 9837) (fully_dereferenceable 104) #'9838 (function_call 9839) (inline_function 9840) (internal_functions_in_yacc 9841) (match 9842) (name 9843) (new_expr 9844) (scalar 9845) (simple_variable 9846) (static_member 9847) (variable 9848) (variable_class_name 9849) ("~" 9850)) 4731 (("%" 9852) ("*" 9853) ("+" 9854) ("-" 9855) ("." 9856) ("/" 9857) ("<" 9858) (">" 9859) ("?" 9860) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 9861) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 9862) (T_BOOLEAN_AND 9863) (T_BOOLEAN_OR 9864) (T_COALESCE 9865) (T_INSTANCEOF 9866) (T_IS_EQUAL 9867) (T_IS_GREATER_OR_EQUAL 9868) (T_IS_IDENTICAL 9869) (T_IS_NOT_EQUAL 9870) (T_IS_NOT_IDENTICAL 9871) (T_IS_SMALLER_OR_EQUAL 9872) (T_LOGICAL_AND 9873) (T_LOGICAL_OR 9874) (T_LOGICAL_XOR 9875) (T_POW 9876) (T_SL 9877) (T_SPACESHIP 9878) (T_SR 9879) ("^" 9880) (backup_fn_flags 10836) ("|" 9881)) 4732 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 10838) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 4733 (("$" 10458) (T_ABSTRACT 10636) (T_ARRAY 10637) (T_AS 10638) (T_BREAK 10639) (T_CALLABLE 10640) (T_CASE 10641) (T_CATCH 10642) (T_CLASS 10643) (T_CLASS_C 10644) (T_CLONE 10645) (T_CONST 10646) (T_CONTINUE 10647) (T_DECLARE 10648) (T_DEFAULT 10649) (T_DIR 10650) (T_DO 10651) (T_ECHO 10652) (T_ELSE 10653) (T_ELSEIF 10654) (T_EMPTY 10655) (T_ENDDECLARE 10656) (T_ENDFOR 10657) (T_ENDFOREACH 10658) (T_ENDIF 10659) (T_ENDSWITCH 10660) (T_ENDWHILE 10661) (T_ENUM 10662) (T_EVAL 10663) (T_EXIT 10664) (T_EXTENDS 10665) (T_FILE 10666) (T_FINAL 10667) (T_FINALLY 10668) (T_FN 10669) (T_FOR 10670) (T_FOREACH 10671) (T_FUNCTION 10672) (T_FUNC_C 10673) (T_GLOBAL 10674) (T_GOTO 10675) (T_IF 10676) (T_IMPLEMENTS 10677) (T_INCLUDE 10678) (T_INCLUDE_ONCE 10679) (T_INSTANCEOF 10680) (T_INSTEADOF 10681) (T_INTERFACE 10682) (T_ISSET 10683) (T_LINE 10684) (T_LIST 10685) (T_LOGICAL_AND 10686) (T_LOGICAL_OR 10687) (T_LOGICAL_XOR 10688) (T_MATCH 10689) (T_METHOD_C 10690) (T_NAMESPACE 10691) (T_NEW 10692) (T_NS_C 10693) (T_PRINT 10694) (T_PRIVATE 10695) (T_PROTECTED 10696) (T_PUBLIC 10697) (T_READONLY 10698) (T_REQUIRE 10699) (T_REQUIRE_ONCE 10700) (T_RETURN 10701) (T_STATIC 10702) (T_STRING 10703) (T_SWITCH 10704) (T_THROW 10705) (T_TRAIT 10706) (T_TRAIT_C 10707) (T_TRY 10708) (T_UNSET 10709) (T_USE 10710) (T_VAR 10711) (T_VARIABLE 10505) (T_WHILE 10712) (T_YIELD 10713) (identifier 10840) (member_name 10841) (reserved_non_modifiers 10716) (semi_reserved 10717) (simple_variable 10842) ("{" 10843)) 4734 (("(" 10722) (argument_list 10846)) 4735 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 10844) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4736 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 10845)) 4737 ((T_FN 35) (T_FUNCTION 127) (fn 10519) #'10520 (inline_function 10850)) 4738 (("$" 10458) (T_STRING 10859) (T_VARIABLE 10505) (property_name 10866) (simple_variable 10861) ("{" 10862)) 4739 (("$" 10458) (T_STRING 10859) (T_VARIABLE 10505) (property_name 10860) (simple_variable 10861) ("{" 10862)) 4740 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 10857) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 4741 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 10855) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4742 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 10856)) 4743 (("]" 10858)) 4744 (("(" 10722) (argument_list 10865)) 4745 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 10863) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4746 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 10864)) 4747 (("(" 10722) (argument_list 10867)) 4748 (("`" 10869)) 4749 (("]" 10871)) 4750 (("=" 10872)) 4751 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10873) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4752 (("%" 10534) ("*" 10535) ("+" 10536) ("-" 10537) ("." 10538) ("/" 10539) ("<" 10540) (">" 10541) ("?" 10542) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 10543) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 10544) (T_BOOLEAN_AND 10545) (T_BOOLEAN_OR 10546) (T_COALESCE 10547) (T_DOUBLE_ARROW 10876) (T_INSTANCEOF 10548) (T_IS_EQUAL 10549) (T_IS_GREATER_OR_EQUAL 10550) (T_IS_IDENTICAL 10551) (T_IS_NOT_EQUAL 10552) (T_IS_NOT_IDENTICAL 10553) (T_IS_SMALLER_OR_EQUAL 10554) (T_LOGICAL_AND 10555) (T_LOGICAL_OR 10556) (T_LOGICAL_XOR 10557) (T_POW 10558) (T_SL 10559) (T_SPACESHIP 10560) (T_SR 10561) ("^" 10562) ("|" 10563)) 4753 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10877) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4754 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 10886) (T_VARIABLE 2900) (encaps_var 2914)) 4755 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 10885) (T_VARIABLE 2900) (encaps_var 2905)) 4756 ((T_CLASS 10906)) 4757 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 10905) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 10893) (attribute 2980) (class_modifier 2945)) 4758 (("(" 10896) (argument_list 10897) (ctor_arguments 10898)) 4759 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 10899) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 10900) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 10901) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 4760 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 10904) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 4761 (("," 1469) (possible_comma 10902)) 4762 ((")" 10903)) 4763 (("(" 2982) (argument_list 2983) (ctor_arguments 10907)) 4764 ((T_EXTENDS 2985) (extends_from 10908)) 4765 ((T_IMPLEMENTS 2987) (implements_list 10909)) 4766 ((backup_doc_comment 10910)) 4767 (("{" 10911)) 4768 ((class_statement_list 10912)) 4769 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 10913)) 4770 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 10915) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 4771 (("%" 292) (")" 10916) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 4772 (("{" 10917)) 4773 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 10918) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 4774 (("}" 10919)) 4775 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 10921) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 4776 ((")" 10922)) 4777 (("=" 10923)) 4778 (("!" 10456) ("\"" 10457) ("$" 10458) ("(" 10459) ("+" 10460) ("-" 10461) ("@" 10462) (T_ARRAY 10463) (T_ARRAY_CAST 10464) (T_ATTRIBUTE 126) (T_BOOL_CAST 10465) (T_CLASS_C 10466) (T_CLONE 10467) (T_CONSTANT_ENCAPSED_STRING 10468) (T_DEC 10469) (T_DIR 10470) (T_DNUMBER 10471) (T_DOUBLE_CAST 10472) (T_EMPTY 10473) (T_EVAL 10474) (T_EXIT 10475) (T_FILE 10476) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 10477) (T_INC 10478) (T_INCLUDE 10479) (T_INCLUDE_ONCE 10480) (T_INT_CAST 10481) (T_ISSET 10482) (T_LINE 10483) (T_LIST 10484) (T_LNUMBER 10485) (T_MATCH 10486) (T_METHOD_C 10487) (T_NAME_FULLY_QUALIFIED 10488) (T_NAME_QUALIFIED 10489) (T_NAME_RELATIVE 10490) (T_NEW 10491) (T_NS_C 10492) (T_OBJECT_CAST 10493) (T_PRINT 10494) (T_READONLY 10495) (T_REQUIRE 10496) (T_REQUIRE_ONCE 10497) (T_START_HEREDOC 10498) (T_STATIC 10499) (T_STRING 10500) (T_STRING_CAST 10501) (T_THROW 10502) (T_TRAIT_C 10503) (T_UNSET_CAST 10504) (T_VARIABLE 10505) (T_YIELD 10506) (T_YIELD_FROM 10507) ("[" 10508) ("`" 10509) (array_object_dereferenceable 10510) (attribute 131) (attributes 10511) (callable_expr 10512) (callable_variable 10513) (class_constant 10514) (class_name 10515) (constant 10516) (dereferenceable_scalar 10517) (expr 10924) (fn 10519) (fully_dereferenceable 104) #'10520 (function_call 10521) (inline_function 10522) (internal_functions_in_yacc 10523) (match 10524) (name 10525) (new_expr 10526) (scalar 10527) (simple_variable 10528) (static_member 10529) (variable 10530) (variable_class_name 10531) ("~" 10532)) 4779 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 10926) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 4780 (("," 5258) (possible_comma 10927)) 4781 ((")" 10928)) 4782 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 10935) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 4783 ((")" 10936)) 4784 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 10938) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 4785 (("%" 292) (")" 10939) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 4786 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 10941) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 4787 (("%" 292) (")" 10942) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 4788 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 10949) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 4789 ((")" 10950)) 4790 (("%" 292) (")" 10955) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 4791 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 10958) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4792 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 10959)) 4793 (("\"" 10961) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 4794 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 10971) (T_VARIABLE 2900) (encaps_var 2914)) 4795 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 10970) (T_VARIABLE 2900) (encaps_var 2905)) 4796 ((T_CLASS 10991)) 4797 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 10990) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 10978) (attribute 2980) (class_modifier 2945)) 4798 (("(" 10981) (argument_list 10982) (ctor_arguments 10983)) 4799 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 10984) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 10985) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 10986) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 4800 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 10989) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 4801 (("," 1469) (possible_comma 10987)) 4802 ((")" 10988)) 4803 (("(" 2982) (argument_list 2983) (ctor_arguments 10992)) 4804 ((T_EXTENDS 2985) (extends_from 10993)) 4805 ((T_IMPLEMENTS 2987) (implements_list 10994)) 4806 ((backup_doc_comment 10995)) 4807 (("{" 10996)) 4808 ((class_statement_list 10997)) 4809 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 10998)) 4810 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 11000) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 4811 (("%" 292) (")" 11001) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 4812 (("{" 11002)) 4813 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 11003) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 4814 (("}" 11004)) 4815 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 11006) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 4816 ((")" 11007)) 4817 (("=" 11008)) 4818 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 11009) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 4819 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 11011) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 4820 (("," 5258) (possible_comma 11012)) 4821 ((")" 11013)) 4822 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 11020) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 4823 ((")" 11021)) 4824 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 11023) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 4825 (("%" 292) (")" 11024) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 4826 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 11026) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 4827 (("%" 292) (")" 11027) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 4828 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 11034) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 4829 ((")" 11035)) 4830 (("%" 292) (")" 11041) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 4831 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 11044) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4832 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 11045)) 4833 (("\"" 11047) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 4834 (("$" 500) (T_ABSTRACT 11058) (T_ARRAY 11059) (T_AS 11060) (T_BREAK 11061) (T_CALLABLE 11062) (T_CASE 11063) (T_CATCH 11064) (T_CLASS 11065) (T_CLASS_C 11066) (T_CLONE 11067) (T_CONST 11068) (T_CONTINUE 11069) (T_DECLARE 11070) (T_DEFAULT 11071) (T_DIR 11072) (T_DO 11073) (T_ECHO 11074) (T_ELSE 11075) (T_ELSEIF 11076) (T_EMPTY 11077) (T_ENDDECLARE 11078) (T_ENDFOR 11079) (T_ENDFOREACH 11080) (T_ENDIF 11081) (T_ENDSWITCH 11082) (T_ENDWHILE 11083) (T_ENUM 11084) (T_EVAL 11085) (T_EXIT 11086) (T_EXTENDS 11087) (T_FILE 11088) (T_FINAL 11089) (T_FINALLY 11090) (T_FN 11091) (T_FOR 11092) (T_FOREACH 11093) (T_FUNCTION 11094) (T_FUNC_C 11095) (T_GLOBAL 11096) (T_GOTO 11097) (T_IF 11098) (T_IMPLEMENTS 11099) (T_INCLUDE 11100) (T_INCLUDE_ONCE 11101) (T_INSTANCEOF 11102) (T_INSTEADOF 11103) (T_INTERFACE 11104) (T_ISSET 11105) (T_LINE 11106) (T_LIST 11107) (T_LOGICAL_AND 11108) (T_LOGICAL_OR 11109) (T_LOGICAL_XOR 11110) (T_MATCH 11111) (T_METHOD_C 11112) (T_NAMESPACE 11113) (T_NEW 11114) (T_NS_C 11115) (T_PRINT 11116) (T_PRIVATE 11117) (T_PROTECTED 11118) (T_PUBLIC 11119) (T_READONLY 11120) (T_REQUIRE 11121) (T_REQUIRE_ONCE 11122) (T_RETURN 11123) (T_STATIC 11124) (T_STRING 11125) (T_SWITCH 11126) (T_THROW 11127) (T_TRAIT 11128) (T_TRAIT_C 11129) (T_TRY 11130) (T_UNSET 11131) (T_USE 11132) (T_VAR 11133) (T_VARIABLE 547) (T_WHILE 11134) (T_YIELD 11135) (identifier 11136) (member_name 11137) (reserved_non_modifiers 11138) (semi_reserved 11139) (simple_variable 11140) ("{" 11141)) 4835 (("(" 11144) (argument_list 11145)) 4836 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 11142) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4837 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 11143)) 4838 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 11146) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 11147) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 11148) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 4839 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 11151) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 4840 (("," 1469) (possible_comma 11149)) 4841 ((")" 11150)) 4842 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (ampersand 11181) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 11182) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 4843 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 11180) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 4844 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 11179) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 4845 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 11178) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 4846 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 11177) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 4847 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 11176) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 4848 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 11175) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 4849 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 11174) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 4850 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 11173) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 4851 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 11172) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 4852 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 11171) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 4853 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 11170) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 4854 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 11169) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 4855 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 11168) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 4856 (("\"" 1509) ("$" 11183) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 11184) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 11185) ("[" 1529) (array_object_dereferenceable 11186) (callable_expr 11187) (callable_variable 11188) (class_constant 1533) (class_name 11189) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 11190) (name 11191) (simple_variable 11192) (static_member 11193) (variable 11194) (variable_class_name 11195)) 4857 (("$" 11183) (T_VARIABLE 11185) (simple_variable 11231) ("{" 11232)) 4858 (("(" 11199) (argument_list 11230)) 4859 ((T_NULLSAFE_OBJECT_OPERATOR 11213) (T_OBJECT_OPERATOR 11214) ("[" 11215) ("{" 11216)) 4860 (("(" 11199) (argument_list 11212)) 4861 ((T_PAAMAYIM_NEKUDOTAYIM 11208)) 4862 (("(" 11199) (argument_list 11207)) 4863 ((T_PAAMAYIM_NEKUDOTAYIM 11196)) 4864 (("$" 11183) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 11185) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 11197) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 11198) ("{" 1627)) 4865 (("(" 11199) (argument_list 11200)) 4866 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 11201) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 11202) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 11203) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 4867 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 11206) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 4868 (("," 1469) (possible_comma 11204)) 4869 ((")" 11205)) 4870 (("$" 11183) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 11185) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 11209) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 11210) ("{" 1643)) 4871 (("(" 11199) (argument_list 11211)) 4872 (("$" 11183) (T_STRING 11221) (T_VARIABLE 11185) (property_name 11228) (simple_variable 11223) ("{" 11224)) 4873 (("$" 11183) (T_STRING 11221) (T_VARIABLE 11185) (property_name 11222) (simple_variable 11223) ("{" 11224)) 4874 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 11219) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 4875 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 11217) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4876 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 11218)) 4877 (("]" 11220)) 4878 (("(" 11199) (argument_list 11227)) 4879 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 11225) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4880 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 11226)) 4881 (("(" 11199) (argument_list 11229)) 4882 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 11233) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4883 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 11234)) 4884 ((backup_doc_comment 11238)) 4885 (("(" 11239)) 4886 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 11240)) 4887 ((")" 11241)) 4888 ((T_USE 159) (lexical_vars 11242)) 4889 ((":" 161) (return_type 11243)) 4890 ((backup_fn_flags 11244)) 4891 (("{" 11245)) 4892 ((inner_statement_list 11246)) 4893 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 11247) ("~" 125)) 4894 ((backup_fn_flags 11248)) 4895 ((backup_doc_comment 11250)) 4896 (("(" 11251)) 4897 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 11252)) 4898 ((")" 11253)) 4899 ((":" 2241) (return_type 11254)) 4900 ((T_DOUBLE_ARROW 11255)) 4901 ((backup_fn_flags 11256)) 4902 ((backup_lex_pos 11257)) 4903 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11320) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4904 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 12319) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4905 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 12317) (encaps_var 5299)) 4906 (("$" 11260) (T_VARIABLE 11307) (simple_variable 12313) ("{" 12314)) 4907 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 12311) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 4908 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 12310) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4909 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 12309) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4910 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 12308) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4911 (("(" 12305)) 4912 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 12304) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4913 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 12303) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4914 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 12302) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4915 (("\"" 1509) ("$" 11563) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 11564) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 11565) ("[" 1529) (array_object_dereferenceable 11566) (callable_expr 11567) (callable_variable 11568) (class_constant 1533) (class_name 11569) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 11570) (name 11571) (simple_variable 11572) (static_member 11573) (variable 12301) (variable_class_name 11575)) 4916 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 12300) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4917 (("(" 12297)) 4918 (("(" 12294)) 4919 (("(" 12290) (exit_expr 12291)) 4920 (("\"" 1509) ("$" 11563) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 11564) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 11565) ("[" 1529) (array_object_dereferenceable 11566) (callable_expr 11567) (callable_variable 11568) (class_constant 1533) (class_name 11569) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 11570) (name 11571) (simple_variable 11572) (static_member 11573) (variable 12289) (variable_class_name 11575)) 4921 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 12288) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4922 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 12287) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4923 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 12286) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4924 (("(" 12282)) 4925 (("(" 12277)) 4926 (("(" 12271)) 4927 (("$" 11563) ("(" 12223) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 12224) (T_NAME_QUALIFIED 12225) (T_NAME_RELATIVE 12226) (T_READONLY 2936) (T_STATIC 12227) (T_STRING 12228) (T_VARIABLE 11565) (anonymous_class 12229) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 12230) (attribute 2943) (attributes 12231) (class_modifier 2945) (class_name 12232) (class_name_reference 12233) (name 12234) (new_variable 12235) (simple_variable 12236)) 4928 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 12222) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4929 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 12221) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4930 (("(" 11524) (argument_list 12220)) 4931 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 12219) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4932 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 12218) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4933 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 12213) (T_END_HEREDOC 12214) (T_VARIABLE 2900) (encaps_list 12215) (encaps_var 2902)) 4934 ((T_FN 35) (T_FUNCTION 127) (fn 11321) #'11322 (inline_function 12212)) 4935 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 12211) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4936 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 12210) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4937 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 12209) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4938 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11738) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 4939 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11675) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4940 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 11671) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 4941 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 11669) (encaps_list 2805) (encaps_var 2806)) 4942 ((T_NULLSAFE_OBJECT_OPERATOR 11652) (T_OBJECT_OPERATOR 11653) ("[" 11654) ("{" 11655)) 4943 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 11649) (attribute 2728) (fn 11321) #'11322 (inline_function 11650)) 4944 (("(" 11524) (argument_list 11648)) 4945 ((T_PAAMAYIM_NEKUDOTAYIM 11640)) 4946 (("%" 11336) ("*" 11337) ("+" 11338) ("-" 11339) ("." 11340) ("/" 11341) ("<" 11342) (">" 11343) ("?" 11344) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 11345) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 11346) (T_BOOLEAN_AND 11347) (T_BOOLEAN_OR 11348) (T_COALESCE 11349) (T_INSTANCEOF 11350) (T_IS_EQUAL 11351) (T_IS_GREATER_OR_EQUAL 11352) (T_IS_IDENTICAL 11353) (T_IS_NOT_EQUAL 11354) (T_IS_NOT_IDENTICAL 11355) (T_IS_SMALLER_OR_EQUAL 11356) (T_LOGICAL_AND 11357) (T_LOGICAL_OR 11358) (T_LOGICAL_XOR 11359) (T_POW 11360) (T_SL 11361) (T_SPACESHIP 11362) (T_SR 11363) ("^" 11364) (backup_fn_flags 11639) ("|" 11365)) 4947 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 11628)) 4948 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 11616)) 4949 (("(" 11524) (argument_list 11615)) 4950 (("=" 11532) (T_AND_EQUAL 11533) (T_COALESCE_EQUAL 11534) (T_CONCAT_EQUAL 11535) (T_DEC 11536) (T_DIV_EQUAL 11537) (T_INC 11538) (T_MINUS_EQUAL 11539) (T_MOD_EQUAL 11540) (T_MUL_EQUAL 11541) (T_OR_EQUAL 11542) (T_PLUS_EQUAL 11543) (T_POW_EQUAL 11544) (T_SL_EQUAL 11545) (T_SR_EQUAL 11546) (T_XOR_EQUAL 11547)) 4951 ((T_PAAMAYIM_NEKUDOTAYIM 11437)) 4952 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11335) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4953 (("%" 11336) ("*" 11337) ("+" 11338) ("-" 11339) ("." 11340) ("/" 11341) ("<" 11342) (">" 11343) ("?" 11344) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 11345) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 11346) (T_BOOLEAN_AND 11347) (T_BOOLEAN_OR 11348) (T_COALESCE 11349) (T_INSTANCEOF 11350) (T_IS_EQUAL 11351) (T_IS_GREATER_OR_EQUAL 11352) (T_IS_IDENTICAL 11353) (T_IS_NOT_EQUAL 11354) (T_IS_NOT_IDENTICAL 11355) (T_IS_SMALLER_OR_EQUAL 11356) (T_LOGICAL_AND 11357) (T_LOGICAL_OR 11358) (T_LOGICAL_XOR 11359) (T_POW 11360) (T_SL 11361) (T_SPACESHIP 11362) (T_SR 11363) ("^" 11364) ("|" 11365)) 4954 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11436) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4955 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11435) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4956 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11434) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4957 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11433) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4958 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11432) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4959 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11431) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4960 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11430) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4961 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11429) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4962 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 11424) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 11425) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 4963 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11423) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4964 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11422) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4965 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11421) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4966 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11420) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4967 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11419) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4968 (("$" 11381) ("(" 11382) (T_NAME_FULLY_QUALIFIED 11383) (T_NAME_QUALIFIED 11384) (T_NAME_RELATIVE 11385) (T_STATIC 11386) (T_STRING 11387) (T_VARIABLE 11388) (class_name 11389) (class_name_reference 11390) (name 11391) (new_variable 11392) (simple_variable 11393)) 4969 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11380) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4970 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11379) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4971 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11378) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4972 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11377) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4973 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11376) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4974 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11375) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4975 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11374) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4976 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11373) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4977 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11372) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4978 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11371) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4979 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11370) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4980 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11369) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4981 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11368) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4982 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11367) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4983 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11366) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 4984 (("$" 11381) (T_VARIABLE 11388) (simple_variable 11415) ("{" 11416)) 4985 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 11413) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 4986 ((T_PAAMAYIM_NEKUDOTAYIM 11411)) 4987 ((T_NULLSAFE_OBJECT_OPERATOR 11394) (T_OBJECT_OPERATOR 11395) (T_PAAMAYIM_NEKUDOTAYIM 11396) ("[" 11397) ("{" 11398)) 4988 (("$" 11381) (T_STRING 11404) (T_VARIABLE 11388) (property_name 11410) (simple_variable 11406) ("{" 11407)) 4989 (("$" 11381) (T_STRING 11404) (T_VARIABLE 11388) (property_name 11405) (simple_variable 11406) ("{" 11407)) 4990 (("$" 11381) (T_VARIABLE 11388) (simple_variable 11403)) 4991 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 11401) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 4992 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 11399) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4993 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 11400)) 4994 (("]" 11402)) 4995 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 11408) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 4996 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 11409)) 4997 (("$" 11381) (T_VARIABLE 11388) (simple_variable 11412)) 4998 (("%" 292) (")" 11414) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 4999 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 11417) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5000 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 11418)) 5001 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11428) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 5002 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 11426) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 5003 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11427) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 5004 (("$" 11260) (T_ABSTRACT 11438) (T_ARRAY 11439) (T_AS 11440) (T_BREAK 11441) (T_CALLABLE 11442) (T_CASE 11443) (T_CATCH 11444) (T_CLASS 11445) (T_CLASS_C 11446) (T_CLONE 11447) (T_CONST 11448) (T_CONTINUE 11449) (T_DECLARE 11450) (T_DEFAULT 11451) (T_DIR 11452) (T_DO 11453) (T_ECHO 11454) (T_ELSE 11455) (T_ELSEIF 11456) (T_EMPTY 11457) (T_ENDDECLARE 11458) (T_ENDFOR 11459) (T_ENDFOREACH 11460) (T_ENDIF 11461) (T_ENDSWITCH 11462) (T_ENDWHILE 11463) (T_ENUM 11464) (T_EVAL 11465) (T_EXIT 11466) (T_EXTENDS 11467) (T_FILE 11468) (T_FINAL 11469) (T_FINALLY 11470) (T_FN 11471) (T_FOR 11472) (T_FOREACH 11473) (T_FUNCTION 11474) (T_FUNC_C 11475) (T_GLOBAL 11476) (T_GOTO 11477) (T_IF 11478) (T_IMPLEMENTS 11479) (T_INCLUDE 11480) (T_INCLUDE_ONCE 11481) (T_INSTANCEOF 11482) (T_INSTEADOF 11483) (T_INTERFACE 11484) (T_ISSET 11485) (T_LINE 11486) (T_LIST 11487) (T_LOGICAL_AND 11488) (T_LOGICAL_OR 11489) (T_LOGICAL_XOR 11490) (T_MATCH 11491) (T_METHOD_C 11492) (T_NAMESPACE 11493) (T_NEW 11494) (T_NS_C 11495) (T_PRINT 11496) (T_PRIVATE 11497) (T_PROTECTED 11498) (T_PUBLIC 11499) (T_READONLY 11500) (T_REQUIRE 11501) (T_REQUIRE_ONCE 11502) (T_RETURN 11503) (T_STATIC 11504) (T_STRING 11505) (T_SWITCH 11506) (T_THROW 11507) (T_TRAIT 11508) (T_TRAIT_C 11509) (T_TRY 11510) (T_UNSET 11511) (T_USE 11512) (T_VAR 11513) (T_VARIABLE 11307) (T_WHILE 11514) (T_YIELD 11515) (identifier 11516) (member_name 11517) (reserved_non_modifiers 11518) (semi_reserved 11519) (simple_variable 11520) ("{" 11521)) 5005 (("(" 11524) (argument_list 11525)) 5006 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 11522) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5007 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 11523)) 5008 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 11526) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 11527) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 11528) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 5009 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 11531) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 5010 (("," 1469) (possible_comma 11529)) 5011 ((")" 11530)) 5012 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (ampersand 11561) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11562) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 5013 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11560) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 5014 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11559) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 5015 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11558) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 5016 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11557) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 5017 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11556) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 5018 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11555) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 5019 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11554) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 5020 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11553) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 5021 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11552) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 5022 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11551) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 5023 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11550) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 5024 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11549) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 5025 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11548) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 5026 (("\"" 1509) ("$" 11563) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 11564) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 11565) ("[" 1529) (array_object_dereferenceable 11566) (callable_expr 11567) (callable_variable 11568) (class_constant 1533) (class_name 11569) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 11570) (name 11571) (simple_variable 11572) (static_member 11573) (variable 11574) (variable_class_name 11575)) 5027 (("$" 11563) (T_VARIABLE 11565) (simple_variable 11611) ("{" 11612)) 5028 (("(" 11579) (argument_list 11610)) 5029 ((T_NULLSAFE_OBJECT_OPERATOR 11593) (T_OBJECT_OPERATOR 11594) ("[" 11595) ("{" 11596)) 5030 (("(" 11579) (argument_list 11592)) 5031 ((T_PAAMAYIM_NEKUDOTAYIM 11588)) 5032 (("(" 11579) (argument_list 11587)) 5033 ((T_PAAMAYIM_NEKUDOTAYIM 11576)) 5034 (("$" 11563) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 11565) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 11577) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 11578) ("{" 1627)) 5035 (("(" 11579) (argument_list 11580)) 5036 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 11581) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 11582) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 11583) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 5037 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 11586) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 5038 (("," 1469) (possible_comma 11584)) 5039 ((")" 11585)) 5040 (("$" 11563) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 11565) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 11589) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 11590) ("{" 1643)) 5041 (("(" 11579) (argument_list 11591)) 5042 (("$" 11563) (T_STRING 11601) (T_VARIABLE 11565) (property_name 11608) (simple_variable 11603) ("{" 11604)) 5043 (("$" 11563) (T_STRING 11601) (T_VARIABLE 11565) (property_name 11602) (simple_variable 11603) ("{" 11604)) 5044 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 11599) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 5045 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 11597) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5046 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 11598)) 5047 (("]" 11600)) 5048 (("(" 11579) (argument_list 11607)) 5049 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 11605) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5050 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 11606)) 5051 (("(" 11579) (argument_list 11609)) 5052 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 11613) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5053 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 11614)) 5054 ((backup_doc_comment 11617)) 5055 (("(" 11618)) 5056 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 11619)) 5057 ((")" 11620)) 5058 ((T_USE 159) (lexical_vars 11621)) 5059 ((":" 161) (return_type 11622)) 5060 ((backup_fn_flags 11623)) 5061 (("{" 11624)) 5062 ((inner_statement_list 11625)) 5063 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 11626) ("~" 125)) 5064 ((backup_fn_flags 11627)) 5065 ((backup_doc_comment 11629)) 5066 (("(" 11630)) 5067 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 11631)) 5068 ((")" 11632)) 5069 ((":" 2241) (return_type 11633)) 5070 ((T_DOUBLE_ARROW 11634)) 5071 ((backup_fn_flags 11635)) 5072 ((backup_lex_pos 11636)) 5073 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11637) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 5074 (("%" 11336) ("*" 11337) ("+" 11338) ("-" 11339) ("." 11340) ("/" 11341) ("<" 11342) (">" 11343) ("?" 11344) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 11345) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 11346) (T_BOOLEAN_AND 11347) (T_BOOLEAN_OR 11348) (T_COALESCE 11349) (T_INSTANCEOF 11350) (T_IS_EQUAL 11351) (T_IS_GREATER_OR_EQUAL 11352) (T_IS_IDENTICAL 11353) (T_IS_NOT_EQUAL 11354) (T_IS_NOT_IDENTICAL 11355) (T_IS_SMALLER_OR_EQUAL 11356) (T_LOGICAL_AND 11357) (T_LOGICAL_OR 11358) (T_LOGICAL_XOR 11359) (T_POW 11360) (T_SL 11361) (T_SPACESHIP 11362) (T_SR 11363) ("^" 11364) (backup_fn_flags 11638) ("|" 11365)) 5075 (("$" 11260) (T_ABSTRACT 11438) (T_ARRAY 11439) (T_AS 11440) (T_BREAK 11441) (T_CALLABLE 11442) (T_CASE 11443) (T_CATCH 11444) (T_CLASS 11445) (T_CLASS_C 11446) (T_CLONE 11447) (T_CONST 11448) (T_CONTINUE 11449) (T_DECLARE 11450) (T_DEFAULT 11451) (T_DIR 11452) (T_DO 11453) (T_ECHO 11454) (T_ELSE 11455) (T_ELSEIF 11456) (T_EMPTY 11457) (T_ENDDECLARE 11458) (T_ENDFOR 11459) (T_ENDFOREACH 11460) (T_ENDIF 11461) (T_ENDSWITCH 11462) (T_ENDWHILE 11463) (T_ENUM 11464) (T_EVAL 11465) (T_EXIT 11466) (T_EXTENDS 11467) (T_FILE 11468) (T_FINAL 11469) (T_FINALLY 11470) (T_FN 11471) (T_FOR 11472) (T_FOREACH 11473) (T_FUNCTION 11474) (T_FUNC_C 11475) (T_GLOBAL 11476) (T_GOTO 11477) (T_IF 11478) (T_IMPLEMENTS 11479) (T_INCLUDE 11480) (T_INCLUDE_ONCE 11481) (T_INSTANCEOF 11482) (T_INSTEADOF 11483) (T_INTERFACE 11484) (T_ISSET 11485) (T_LINE 11486) (T_LIST 11487) (T_LOGICAL_AND 11488) (T_LOGICAL_OR 11489) (T_LOGICAL_XOR 11490) (T_MATCH 11491) (T_METHOD_C 11492) (T_NAMESPACE 11493) (T_NEW 11494) (T_NS_C 11495) (T_PRINT 11496) (T_PRIVATE 11497) (T_PROTECTED 11498) (T_PUBLIC 11499) (T_READONLY 11500) (T_REQUIRE 11501) (T_REQUIRE_ONCE 11502) (T_RETURN 11503) (T_STATIC 11504) (T_STRING 11505) (T_SWITCH 11506) (T_THROW 11507) (T_TRAIT 11508) (T_TRAIT_C 11509) (T_TRY 11510) (T_UNSET 11511) (T_USE 11512) (T_VAR 11513) (T_VARIABLE 11307) (T_WHILE 11514) (T_YIELD 11515) (identifier 11641) (member_name 11642) (reserved_non_modifiers 11518) (semi_reserved 11519) (simple_variable 11643) ("{" 11644)) 5076 (("(" 11524) (argument_list 11647)) 5077 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 11645) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5078 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 11646)) 5079 ((T_FN 35) (T_FUNCTION 127) (fn 11321) #'11322 (inline_function 11651)) 5080 (("$" 11260) (T_STRING 11660) (T_VARIABLE 11307) (property_name 11667) (simple_variable 11662) ("{" 11663)) 5081 (("$" 11260) (T_STRING 11660) (T_VARIABLE 11307) (property_name 11661) (simple_variable 11662) ("{" 11663)) 5082 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 11658) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 5083 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 11656) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5084 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 11657)) 5085 (("]" 11659)) 5086 (("(" 11524) (argument_list 11666)) 5087 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 11664) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5088 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 11665)) 5089 (("(" 11524) (argument_list 11668)) 5090 (("`" 11670)) 5091 (("]" 11672)) 5092 (("=" 11673)) 5093 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 11674) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 5094 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 12208) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5095 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 12206) (encaps_var 5299)) 5096 (("$" 11678) (T_VARIABLE 11725) (simple_variable 12202) ("{" 12203)) 5097 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 12200) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 5098 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 12199) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5099 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 12198) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5100 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 12197) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5101 (("(" 12194)) 5102 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 12193) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5103 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 12192) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5104 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 12191) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5105 (("\"" 1509) ("$" 11981) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 11982) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 11983) ("[" 1529) (array_object_dereferenceable 11984) (callable_expr 11985) (callable_variable 11986) (class_constant 1533) (class_name 11987) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 11988) (name 11989) (simple_variable 11990) (static_member 11991) (variable 12190) (variable_class_name 11993)) 5106 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 12189) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5107 (("(" 12186)) 5108 (("(" 12183)) 5109 (("(" 12179) (exit_expr 12180)) 5110 (("\"" 1509) ("$" 11981) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 11982) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 11983) ("[" 1529) (array_object_dereferenceable 11984) (callable_expr 11985) (callable_variable 11986) (class_constant 1533) (class_name 11987) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 11988) (name 11989) (simple_variable 11990) (static_member 11991) (variable 12178) (variable_class_name 11993)) 5111 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 12177) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5112 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 12176) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5113 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 12175) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5114 (("(" 12171)) 5115 (("(" 12166)) 5116 (("(" 12160)) 5117 (("$" 11981) ("(" 12112) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 12113) (T_NAME_QUALIFIED 12114) (T_NAME_RELATIVE 12115) (T_READONLY 2936) (T_STATIC 12116) (T_STRING 12117) (T_VARIABLE 11983) (anonymous_class 12118) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 12119) (attribute 2943) (attributes 12120) (class_modifier 2945) (class_name 12121) (class_name_reference 12122) (name 12123) (new_variable 12124) (simple_variable 12125)) 5118 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 12111) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5119 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 12110) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5120 (("(" 11942) (argument_list 12109)) 5121 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 12108) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5122 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 12107) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5123 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 12102) (T_END_HEREDOC 12103) (T_VARIABLE 2900) (encaps_list 12104) (encaps_var 2902)) 5124 ((T_FN 35) (T_FUNCTION 127) (fn 11739) #'11740 (inline_function 12101)) 5125 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 12100) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5126 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 12099) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5127 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 12098) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5128 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 12095) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5129 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 12094) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5130 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 12090) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 5131 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 12088) (encaps_list 2805) (encaps_var 2806)) 5132 ((T_NULLSAFE_OBJECT_OPERATOR 12071) (T_OBJECT_OPERATOR 12072) ("[" 12073) ("{" 12074)) 5133 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 12068) (attribute 2728) (fn 11739) #'11740 (inline_function 12069)) 5134 (("(" 11942) (argument_list 12067)) 5135 ((T_PAAMAYIM_NEKUDOTAYIM 12059)) 5136 (("%" 11754) ("*" 11755) ("+" 11756) ("-" 11757) ("." 11758) ("/" 11759) ("<" 11760) (">" 11761) ("?" 11762) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 11763) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 11764) (T_BOOLEAN_AND 11765) (T_BOOLEAN_OR 11766) (T_COALESCE 11767) (T_DOUBLE_ARROW 12057) (T_INSTANCEOF 11768) (T_IS_EQUAL 11769) (T_IS_GREATER_OR_EQUAL 11770) (T_IS_IDENTICAL 11771) (T_IS_NOT_EQUAL 11772) (T_IS_NOT_IDENTICAL 11773) (T_IS_SMALLER_OR_EQUAL 11774) (T_LOGICAL_AND 11775) (T_LOGICAL_OR 11776) (T_LOGICAL_XOR 11777) (T_POW 11778) (T_SL 11779) (T_SPACESHIP 11780) (T_SR 11781) ("^" 11782) ("|" 11783)) 5137 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 12046)) 5138 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 12034)) 5139 (("(" 11942) (argument_list 12033)) 5140 (("=" 11950) (T_AND_EQUAL 11951) (T_COALESCE_EQUAL 11952) (T_CONCAT_EQUAL 11953) (T_DEC 11954) (T_DIV_EQUAL 11955) (T_INC 11956) (T_MINUS_EQUAL 11957) (T_MOD_EQUAL 11958) (T_MUL_EQUAL 11959) (T_OR_EQUAL 11960) (T_PLUS_EQUAL 11961) (T_POW_EQUAL 11962) (T_SL_EQUAL 11963) (T_SR_EQUAL 11964) (T_XOR_EQUAL 11965)) 5141 ((T_PAAMAYIM_NEKUDOTAYIM 11855)) 5142 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11753) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5143 (("%" 11754) ("*" 11755) ("+" 11756) ("-" 11757) ("." 11758) ("/" 11759) ("<" 11760) (">" 11761) ("?" 11762) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 11763) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 11764) (T_BOOLEAN_AND 11765) (T_BOOLEAN_OR 11766) (T_COALESCE 11767) (T_INSTANCEOF 11768) (T_IS_EQUAL 11769) (T_IS_GREATER_OR_EQUAL 11770) (T_IS_IDENTICAL 11771) (T_IS_NOT_EQUAL 11772) (T_IS_NOT_IDENTICAL 11773) (T_IS_SMALLER_OR_EQUAL 11774) (T_LOGICAL_AND 11775) (T_LOGICAL_OR 11776) (T_LOGICAL_XOR 11777) (T_POW 11778) (T_SL 11779) (T_SPACESHIP 11780) (T_SR 11781) ("^" 11782) ("|" 11783)) 5144 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11854) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5145 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11853) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5146 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11852) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5147 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11851) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5148 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11850) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5149 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11849) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5150 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11848) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5151 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11847) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5152 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 11842) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 11843) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 5153 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11841) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5154 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11840) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5155 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11839) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5156 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11838) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5157 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11837) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5158 (("$" 11799) ("(" 11800) (T_NAME_FULLY_QUALIFIED 11801) (T_NAME_QUALIFIED 11802) (T_NAME_RELATIVE 11803) (T_STATIC 11804) (T_STRING 11805) (T_VARIABLE 11806) (class_name 11807) (class_name_reference 11808) (name 11809) (new_variable 11810) (simple_variable 11811)) 5159 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11798) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5160 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11797) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5161 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11796) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5162 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11795) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5163 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11794) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5164 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11793) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5165 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11792) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5166 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11791) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5167 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11790) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5168 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11789) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5169 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11788) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5170 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11787) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5171 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11786) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5172 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11785) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5173 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11784) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5174 (("$" 11799) (T_VARIABLE 11806) (simple_variable 11833) ("{" 11834)) 5175 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 11831) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 5176 ((T_PAAMAYIM_NEKUDOTAYIM 11829)) 5177 ((T_NULLSAFE_OBJECT_OPERATOR 11812) (T_OBJECT_OPERATOR 11813) (T_PAAMAYIM_NEKUDOTAYIM 11814) ("[" 11815) ("{" 11816)) 5178 (("$" 11799) (T_STRING 11822) (T_VARIABLE 11806) (property_name 11828) (simple_variable 11824) ("{" 11825)) 5179 (("$" 11799) (T_STRING 11822) (T_VARIABLE 11806) (property_name 11823) (simple_variable 11824) ("{" 11825)) 5180 (("$" 11799) (T_VARIABLE 11806) (simple_variable 11821)) 5181 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 11819) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 5182 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 11817) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5183 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 11818)) 5184 (("]" 11820)) 5185 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 11826) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5186 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 11827)) 5187 (("$" 11799) (T_VARIABLE 11806) (simple_variable 11830)) 5188 (("%" 292) (")" 11832) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 5189 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 11835) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5190 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 11836)) 5191 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11846) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5192 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 11844) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 5193 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11845) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5194 (("$" 11678) (T_ABSTRACT 11856) (T_ARRAY 11857) (T_AS 11858) (T_BREAK 11859) (T_CALLABLE 11860) (T_CASE 11861) (T_CATCH 11862) (T_CLASS 11863) (T_CLASS_C 11864) (T_CLONE 11865) (T_CONST 11866) (T_CONTINUE 11867) (T_DECLARE 11868) (T_DEFAULT 11869) (T_DIR 11870) (T_DO 11871) (T_ECHO 11872) (T_ELSE 11873) (T_ELSEIF 11874) (T_EMPTY 11875) (T_ENDDECLARE 11876) (T_ENDFOR 11877) (T_ENDFOREACH 11878) (T_ENDIF 11879) (T_ENDSWITCH 11880) (T_ENDWHILE 11881) (T_ENUM 11882) (T_EVAL 11883) (T_EXIT 11884) (T_EXTENDS 11885) (T_FILE 11886) (T_FINAL 11887) (T_FINALLY 11888) (T_FN 11889) (T_FOR 11890) (T_FOREACH 11891) (T_FUNCTION 11892) (T_FUNC_C 11893) (T_GLOBAL 11894) (T_GOTO 11895) (T_IF 11896) (T_IMPLEMENTS 11897) (T_INCLUDE 11898) (T_INCLUDE_ONCE 11899) (T_INSTANCEOF 11900) (T_INSTEADOF 11901) (T_INTERFACE 11902) (T_ISSET 11903) (T_LINE 11904) (T_LIST 11905) (T_LOGICAL_AND 11906) (T_LOGICAL_OR 11907) (T_LOGICAL_XOR 11908) (T_MATCH 11909) (T_METHOD_C 11910) (T_NAMESPACE 11911) (T_NEW 11912) (T_NS_C 11913) (T_PRINT 11914) (T_PRIVATE 11915) (T_PROTECTED 11916) (T_PUBLIC 11917) (T_READONLY 11918) (T_REQUIRE 11919) (T_REQUIRE_ONCE 11920) (T_RETURN 11921) (T_STATIC 11922) (T_STRING 11923) (T_SWITCH 11924) (T_THROW 11925) (T_TRAIT 11926) (T_TRAIT_C 11927) (T_TRY 11928) (T_UNSET 11929) (T_USE 11930) (T_VAR 11931) (T_VARIABLE 11725) (T_WHILE 11932) (T_YIELD 11933) (identifier 11934) (member_name 11935) (reserved_non_modifiers 11936) (semi_reserved 11937) (simple_variable 11938) ("{" 11939)) 5195 (("(" 11942) (argument_list 11943)) 5196 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 11940) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5197 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 11941)) 5198 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 11944) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 11945) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 11946) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 5199 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 11949) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 5200 (("," 1469) (possible_comma 11947)) 5201 ((")" 11948)) 5202 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (ampersand 11979) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11980) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5203 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11978) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5204 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11977) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5205 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11976) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5206 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11975) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5207 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11974) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5208 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11973) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5209 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11972) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5210 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11971) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5211 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11970) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5212 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11969) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5213 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11968) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5214 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11967) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5215 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 11966) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5216 (("\"" 1509) ("$" 11981) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 11982) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 11983) ("[" 1529) (array_object_dereferenceable 11984) (callable_expr 11985) (callable_variable 11986) (class_constant 1533) (class_name 11987) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 11988) (name 11989) (simple_variable 11990) (static_member 11991) (variable 11992) (variable_class_name 11993)) 5217 (("$" 11981) (T_VARIABLE 11983) (simple_variable 12029) ("{" 12030)) 5218 (("(" 11997) (argument_list 12028)) 5219 ((T_NULLSAFE_OBJECT_OPERATOR 12011) (T_OBJECT_OPERATOR 12012) ("[" 12013) ("{" 12014)) 5220 (("(" 11997) (argument_list 12010)) 5221 ((T_PAAMAYIM_NEKUDOTAYIM 12006)) 5222 (("(" 11997) (argument_list 12005)) 5223 ((T_PAAMAYIM_NEKUDOTAYIM 11994)) 5224 (("$" 11981) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 11983) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 11995) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 11996) ("{" 1627)) 5225 (("(" 11997) (argument_list 11998)) 5226 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 11999) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 12000) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 12001) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 5227 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 12004) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 5228 (("," 1469) (possible_comma 12002)) 5229 ((")" 12003)) 5230 (("$" 11981) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 11983) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 12007) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 12008) ("{" 1643)) 5231 (("(" 11997) (argument_list 12009)) 5232 (("$" 11981) (T_STRING 12019) (T_VARIABLE 11983) (property_name 12026) (simple_variable 12021) ("{" 12022)) 5233 (("$" 11981) (T_STRING 12019) (T_VARIABLE 11983) (property_name 12020) (simple_variable 12021) ("{" 12022)) 5234 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 12017) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 5235 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12015) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5236 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 12016)) 5237 (("]" 12018)) 5238 (("(" 11997) (argument_list 12025)) 5239 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12023) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5240 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 12024)) 5241 (("(" 11997) (argument_list 12027)) 5242 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12031) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5243 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 12032)) 5244 ((backup_doc_comment 12035)) 5245 (("(" 12036)) 5246 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 12037)) 5247 ((")" 12038)) 5248 ((T_USE 159) (lexical_vars 12039)) 5249 ((":" 161) (return_type 12040)) 5250 ((backup_fn_flags 12041)) 5251 (("{" 12042)) 5252 ((inner_statement_list 12043)) 5253 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 12044) ("~" 125)) 5254 ((backup_fn_flags 12045)) 5255 ((backup_doc_comment 12047)) 5256 (("(" 12048)) 5257 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 12049)) 5258 ((")" 12050)) 5259 ((":" 2241) (return_type 12051)) 5260 ((T_DOUBLE_ARROW 12052)) 5261 ((backup_fn_flags 12053)) 5262 ((backup_lex_pos 12054)) 5263 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 12055) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5264 (("%" 11754) ("*" 11755) ("+" 11756) ("-" 11757) ("." 11758) ("/" 11759) ("<" 11760) (">" 11761) ("?" 11762) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 11763) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 11764) (T_BOOLEAN_AND 11765) (T_BOOLEAN_OR 11766) (T_COALESCE 11767) (T_INSTANCEOF 11768) (T_IS_EQUAL 11769) (T_IS_GREATER_OR_EQUAL 11770) (T_IS_IDENTICAL 11771) (T_IS_NOT_EQUAL 11772) (T_IS_NOT_IDENTICAL 11773) (T_IS_SMALLER_OR_EQUAL 11774) (T_LOGICAL_AND 11775) (T_LOGICAL_OR 11776) (T_LOGICAL_XOR 11777) (T_POW 11778) (T_SL 11779) (T_SPACESHIP 11780) (T_SR 11781) ("^" 11782) (backup_fn_flags 12056) ("|" 11783)) 5265 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 12058) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 5266 (("$" 11678) (T_ABSTRACT 11856) (T_ARRAY 11857) (T_AS 11858) (T_BREAK 11859) (T_CALLABLE 11860) (T_CASE 11861) (T_CATCH 11862) (T_CLASS 11863) (T_CLASS_C 11864) (T_CLONE 11865) (T_CONST 11866) (T_CONTINUE 11867) (T_DECLARE 11868) (T_DEFAULT 11869) (T_DIR 11870) (T_DO 11871) (T_ECHO 11872) (T_ELSE 11873) (T_ELSEIF 11874) (T_EMPTY 11875) (T_ENDDECLARE 11876) (T_ENDFOR 11877) (T_ENDFOREACH 11878) (T_ENDIF 11879) (T_ENDSWITCH 11880) (T_ENDWHILE 11881) (T_ENUM 11882) (T_EVAL 11883) (T_EXIT 11884) (T_EXTENDS 11885) (T_FILE 11886) (T_FINAL 11887) (T_FINALLY 11888) (T_FN 11889) (T_FOR 11890) (T_FOREACH 11891) (T_FUNCTION 11892) (T_FUNC_C 11893) (T_GLOBAL 11894) (T_GOTO 11895) (T_IF 11896) (T_IMPLEMENTS 11897) (T_INCLUDE 11898) (T_INCLUDE_ONCE 11899) (T_INSTANCEOF 11900) (T_INSTEADOF 11901) (T_INTERFACE 11902) (T_ISSET 11903) (T_LINE 11904) (T_LIST 11905) (T_LOGICAL_AND 11906) (T_LOGICAL_OR 11907) (T_LOGICAL_XOR 11908) (T_MATCH 11909) (T_METHOD_C 11910) (T_NAMESPACE 11911) (T_NEW 11912) (T_NS_C 11913) (T_PRINT 11914) (T_PRIVATE 11915) (T_PROTECTED 11916) (T_PUBLIC 11917) (T_READONLY 11918) (T_REQUIRE 11919) (T_REQUIRE_ONCE 11920) (T_RETURN 11921) (T_STATIC 11922) (T_STRING 11923) (T_SWITCH 11924) (T_THROW 11925) (T_TRAIT 11926) (T_TRAIT_C 11927) (T_TRY 11928) (T_UNSET 11929) (T_USE 11930) (T_VAR 11931) (T_VARIABLE 11725) (T_WHILE 11932) (T_YIELD 11933) (identifier 12060) (member_name 12061) (reserved_non_modifiers 11936) (semi_reserved 11937) (simple_variable 12062) ("{" 12063)) 5267 (("(" 11942) (argument_list 12066)) 5268 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12064) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5269 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 12065)) 5270 ((T_FN 35) (T_FUNCTION 127) (fn 11739) #'11740 (inline_function 12070)) 5271 (("$" 11678) (T_STRING 12079) (T_VARIABLE 11725) (property_name 12086) (simple_variable 12081) ("{" 12082)) 5272 (("$" 11678) (T_STRING 12079) (T_VARIABLE 11725) (property_name 12080) (simple_variable 12081) ("{" 12082)) 5273 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 12077) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 5274 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12075) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5275 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 12076)) 5276 (("]" 12078)) 5277 (("(" 11942) (argument_list 12085)) 5278 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12083) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5279 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 12084)) 5280 (("(" 11942) (argument_list 12087)) 5281 (("`" 12089)) 5282 (("]" 12091)) 5283 (("=" 12092)) 5284 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 12093) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5285 (("%" 11754) ("*" 11755) ("+" 11756) ("-" 11757) ("." 11758) ("/" 11759) ("<" 11760) (">" 11761) ("?" 11762) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 11763) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 11764) (T_BOOLEAN_AND 11765) (T_BOOLEAN_OR 11766) (T_COALESCE 11767) (T_DOUBLE_ARROW 12096) (T_INSTANCEOF 11768) (T_IS_EQUAL 11769) (T_IS_GREATER_OR_EQUAL 11770) (T_IS_IDENTICAL 11771) (T_IS_NOT_EQUAL 11772) (T_IS_NOT_IDENTICAL 11773) (T_IS_SMALLER_OR_EQUAL 11774) (T_LOGICAL_AND 11775) (T_LOGICAL_OR 11776) (T_LOGICAL_XOR 11777) (T_POW 11778) (T_SL 11779) (T_SPACESHIP 11780) (T_SR 11781) ("^" 11782) ("|" 11783)) 5286 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 12097) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5287 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 12106) (T_VARIABLE 2900) (encaps_var 2914)) 5288 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 12105) (T_VARIABLE 2900) (encaps_var 2905)) 5289 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 12158) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 5290 ((T_CLASS 12150)) 5291 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 12149) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 12119) (attribute 2980) (class_modifier 2945)) 5292 ((T_PAAMAYIM_NEKUDOTAYIM 12147)) 5293 (("(" 12138) (argument_list 12139) (ctor_arguments 12140)) 5294 ((T_NULLSAFE_OBJECT_OPERATOR 12126) (T_OBJECT_OPERATOR 12127) (T_PAAMAYIM_NEKUDOTAYIM 12128) ("[" 12129) ("{" 12130)) 5295 (("$" 11981) (T_STRING 12019) (T_VARIABLE 11983) (property_name 12137) (simple_variable 12021) ("{" 12022)) 5296 (("$" 11981) (T_STRING 12019) (T_VARIABLE 11983) (property_name 12136) (simple_variable 12021) ("{" 12022)) 5297 (("$" 11981) (T_VARIABLE 11983) (simple_variable 12135)) 5298 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 12133) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 5299 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12131) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5300 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 12132)) 5301 (("]" 12134)) 5302 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 12141) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 12142) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 12143) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 5303 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 12146) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 5304 (("," 1469) (possible_comma 12144)) 5305 ((")" 12145)) 5306 (("$" 11981) (T_VARIABLE 11983) (simple_variable 12148)) 5307 (("(" 2982) (argument_list 2983) (ctor_arguments 12151)) 5308 ((T_EXTENDS 2985) (extends_from 12152)) 5309 ((T_IMPLEMENTS 2987) (implements_list 12153)) 5310 ((backup_doc_comment 12154)) 5311 (("{" 12155)) 5312 ((class_statement_list 12156)) 5313 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 12157)) 5314 (("%" 292) (")" 12159) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 5315 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 12161) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 5316 (("%" 292) (")" 12162) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 5317 (("{" 12163)) 5318 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 12164) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 5319 (("}" 12165)) 5320 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 12167) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 5321 ((")" 12168)) 5322 (("=" 12169)) 5323 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 12170) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5324 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 12172) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 5325 (("," 5258) (possible_comma 12173)) 5326 ((")" 12174)) 5327 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 12181) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 5328 ((")" 12182)) 5329 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 12184) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 5330 (("%" 292) (")" 12185) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 5331 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 12187) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 5332 (("%" 292) (")" 12188) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 5333 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 12195) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 5334 ((")" 12196)) 5335 (("%" 292) (")" 12201) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 5336 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12204) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5337 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 12205)) 5338 (("\"" 12207) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 5339 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 12217) (T_VARIABLE 2900) (encaps_var 2914)) 5340 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 12216) (T_VARIABLE 2900) (encaps_var 2905)) 5341 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 12269) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 5342 ((T_CLASS 12261)) 5343 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 12260) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 12230) (attribute 2980) (class_modifier 2945)) 5344 ((T_PAAMAYIM_NEKUDOTAYIM 12258)) 5345 (("(" 12249) (argument_list 12250) (ctor_arguments 12251)) 5346 ((T_NULLSAFE_OBJECT_OPERATOR 12237) (T_OBJECT_OPERATOR 12238) (T_PAAMAYIM_NEKUDOTAYIM 12239) ("[" 12240) ("{" 12241)) 5347 (("$" 11563) (T_STRING 11601) (T_VARIABLE 11565) (property_name 12248) (simple_variable 11603) ("{" 11604)) 5348 (("$" 11563) (T_STRING 11601) (T_VARIABLE 11565) (property_name 12247) (simple_variable 11603) ("{" 11604)) 5349 (("$" 11563) (T_VARIABLE 11565) (simple_variable 12246)) 5350 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 12244) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 5351 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12242) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5352 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 12243)) 5353 (("]" 12245)) 5354 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 12252) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 12253) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 12254) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 5355 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 12257) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 5356 (("," 1469) (possible_comma 12255)) 5357 ((")" 12256)) 5358 (("$" 11563) (T_VARIABLE 11565) (simple_variable 12259)) 5359 (("(" 2982) (argument_list 2983) (ctor_arguments 12262)) 5360 ((T_EXTENDS 2985) (extends_from 12263)) 5361 ((T_IMPLEMENTS 2987) (implements_list 12264)) 5362 ((backup_doc_comment 12265)) 5363 (("{" 12266)) 5364 ((class_statement_list 12267)) 5365 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 12268)) 5366 (("%" 292) (")" 12270) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 5367 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 12272) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 5368 (("%" 292) (")" 12273) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 5369 (("{" 12274)) 5370 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 12275) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 5371 (("}" 12276)) 5372 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 12278) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 5373 ((")" 12279)) 5374 (("=" 12280)) 5375 (("!" 11258) ("\"" 11259) ("$" 11260) ("(" 11261) ("+" 11262) ("-" 11263) ("@" 11264) (T_ARRAY 11265) (T_ARRAY_CAST 11266) (T_ATTRIBUTE 126) (T_BOOL_CAST 11267) (T_CLASS_C 11268) (T_CLONE 11269) (T_CONSTANT_ENCAPSED_STRING 11270) (T_DEC 11271) (T_DIR 11272) (T_DNUMBER 11273) (T_DOUBLE_CAST 11274) (T_EMPTY 11275) (T_EVAL 11276) (T_EXIT 11277) (T_FILE 11278) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11279) (T_INC 11280) (T_INCLUDE 11281) (T_INCLUDE_ONCE 11282) (T_INT_CAST 11283) (T_ISSET 11284) (T_LINE 11285) (T_LIST 11286) (T_LNUMBER 11287) (T_MATCH 11288) (T_METHOD_C 11289) (T_NAME_FULLY_QUALIFIED 11290) (T_NAME_QUALIFIED 11291) (T_NAME_RELATIVE 11292) (T_NEW 11293) (T_NS_C 11294) (T_OBJECT_CAST 11295) (T_PRINT 11296) (T_READONLY 11297) (T_REQUIRE 11298) (T_REQUIRE_ONCE 11299) (T_START_HEREDOC 11300) (T_STATIC 11301) (T_STRING 11302) (T_STRING_CAST 11303) (T_THROW 11304) (T_TRAIT_C 11305) (T_UNSET_CAST 11306) (T_VARIABLE 11307) (T_YIELD 11308) (T_YIELD_FROM 11309) ("[" 11310) ("`" 11311) (array_object_dereferenceable 11312) (attribute 131) (attributes 11313) (callable_expr 11314) (callable_variable 11315) (class_constant 11316) (class_name 11317) (constant 11318) (dereferenceable_scalar 11319) (expr 12281) (fn 11321) (fully_dereferenceable 104) #'11322 (function_call 11323) (inline_function 11324) (internal_functions_in_yacc 11325) (match 11326) (name 11327) (new_expr 11328) (scalar 11329) (simple_variable 11330) (static_member 11331) (variable 11332) (variable_class_name 11333) ("~" 11334)) 5376 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 12283) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 5377 (("," 5258) (possible_comma 12284)) 5378 ((")" 12285)) 5379 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 12292) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 5380 ((")" 12293)) 5381 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 12295) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 5382 (("%" 292) (")" 12296) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 5383 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 12298) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 5384 (("%" 292) (")" 12299) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 5385 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 12306) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 5386 ((")" 12307)) 5387 (("%" 292) (")" 12312) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 5388 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12315) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5389 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 12316)) 5390 (("\"" 12318) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 5391 (("$" 500) (T_ABSTRACT 11058) (T_ARRAY 11059) (T_AS 11060) (T_BREAK 11061) (T_CALLABLE 11062) (T_CASE 11063) (T_CATCH 11064) (T_CLASS 11065) (T_CLASS_C 11066) (T_CLONE 11067) (T_CONST 11068) (T_CONTINUE 11069) (T_DECLARE 11070) (T_DEFAULT 11071) (T_DIR 11072) (T_DO 11073) (T_ECHO 11074) (T_ELSE 11075) (T_ELSEIF 11076) (T_EMPTY 11077) (T_ENDDECLARE 11078) (T_ENDFOR 11079) (T_ENDFOREACH 11080) (T_ENDIF 11081) (T_ENDSWITCH 11082) (T_ENDWHILE 11083) (T_ENUM 11084) (T_EVAL 11085) (T_EXIT 11086) (T_EXTENDS 11087) (T_FILE 11088) (T_FINAL 11089) (T_FINALLY 11090) (T_FN 11091) (T_FOR 11092) (T_FOREACH 11093) (T_FUNCTION 11094) (T_FUNC_C 11095) (T_GLOBAL 11096) (T_GOTO 11097) (T_IF 11098) (T_IMPLEMENTS 11099) (T_INCLUDE 11100) (T_INCLUDE_ONCE 11101) (T_INSTANCEOF 11102) (T_INSTEADOF 11103) (T_INTERFACE 11104) (T_ISSET 11105) (T_LINE 11106) (T_LIST 11107) (T_LOGICAL_AND 11108) (T_LOGICAL_OR 11109) (T_LOGICAL_XOR 11110) (T_MATCH 11111) (T_METHOD_C 11112) (T_NAMESPACE 11113) (T_NEW 11114) (T_NS_C 11115) (T_PRINT 11116) (T_PRIVATE 11117) (T_PROTECTED 11118) (T_PUBLIC 11119) (T_READONLY 11120) (T_REQUIRE 11121) (T_REQUIRE_ONCE 11122) (T_RETURN 11123) (T_STATIC 11124) (T_STRING 11125) (T_SWITCH 11126) (T_THROW 11127) (T_TRAIT 11128) (T_TRAIT_C 11129) (T_TRY 11130) (T_UNSET 11131) (T_USE 11132) (T_VAR 11133) (T_VARIABLE 547) (T_WHILE 11134) (T_YIELD 11135) (identifier 12321) (member_name 12322) (reserved_non_modifiers 11138) (semi_reserved 11139) (simple_variable 12323) ("{" 12324)) 5392 (("(" 11144) (argument_list 12327)) 5393 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12325) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5394 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 12326)) 5395 ((T_FN 35) (T_FUNCTION 127) (fn 561) #'562 (inline_function 12331)) 5396 (("$" 500) (T_STRING 12340) (T_VARIABLE 547) (property_name 12347) (simple_variable 12342) ("{" 12343)) 5397 (("$" 500) (T_STRING 12340) (T_VARIABLE 547) (property_name 12341) (simple_variable 12342) ("{" 12343)) 5398 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 12338) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 5399 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12336) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5400 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 12337)) 5401 (("]" 12339)) 5402 (("(" 11144) (argument_list 12346)) 5403 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12344) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5404 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 12345)) 5405 (("(" 11144) (argument_list 12348)) 5406 (("`" 12350)) 5407 (("]" 12352)) 5408 (("=" 12353)) 5409 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 12354) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 5410 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12862) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5411 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 12860) (encaps_var 5299)) 5412 (("$" 12358) (T_VARIABLE 12405) (simple_variable 12856) ("{" 12857)) 5413 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 12854) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 5414 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12853) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5415 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12852) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5416 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12851) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5417 (("(" 12848)) 5418 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12847) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5419 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12846) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5420 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12845) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5421 (("\"" 1509) ("$" 12661) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 12662) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 12663) ("[" 1529) (array_object_dereferenceable 12664) (callable_expr 12665) (callable_variable 12666) (class_constant 1533) (class_name 12667) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 12668) (name 12669) (simple_variable 12670) (static_member 12671) (variable 12844) (variable_class_name 12673)) 5422 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12843) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5423 (("(" 12840)) 5424 (("(" 12837)) 5425 (("(" 12833) (exit_expr 12834)) 5426 (("\"" 1509) ("$" 12661) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 12662) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 12663) ("[" 1529) (array_object_dereferenceable 12664) (callable_expr 12665) (callable_variable 12666) (class_constant 1533) (class_name 12667) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 12668) (name 12669) (simple_variable 12670) (static_member 12671) (variable 12832) (variable_class_name 12673)) 5427 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12831) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5428 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12830) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5429 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12829) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5430 (("(" 12825)) 5431 (("(" 12820)) 5432 (("(" 12814)) 5433 (("$" 11981) ("(" 12112) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 12113) (T_NAME_QUALIFIED 12114) (T_NAME_RELATIVE 12115) (T_READONLY 2936) (T_STATIC 12116) (T_STRING 12117) (T_VARIABLE 11983) (anonymous_class 12792) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 12793) (attribute 2943) (attributes 12794) (class_modifier 2945) (class_name 12121) (class_name_reference 12795) (name 12123) (new_variable 12124) (simple_variable 12125)) 5434 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12791) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5435 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12790) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5436 (("(" 12622) (argument_list 12789)) 5437 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12788) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5438 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12787) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5439 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 12782) (T_END_HEREDOC 12783) (T_VARIABLE 2900) (encaps_list 12784) (encaps_var 2902)) 5440 ((T_FN 35) (T_FUNCTION 127) (fn 12419) #'12420 (inline_function 12781)) 5441 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12780) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5442 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12779) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5443 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12778) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5444 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12775) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5445 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12774) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5446 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 12770) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 5447 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 12768) (encaps_list 2805) (encaps_var 2806)) 5448 ((T_NULLSAFE_OBJECT_OPERATOR 12751) (T_OBJECT_OPERATOR 12752) ("[" 12753) ("{" 12754)) 5449 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 12748) (attribute 2728) (fn 12419) #'12420 (inline_function 12749)) 5450 (("(" 12622) (argument_list 12747)) 5451 ((T_PAAMAYIM_NEKUDOTAYIM 12739)) 5452 (("%" 12434) ("*" 12435) ("+" 12436) ("-" 12437) ("." 12438) ("/" 12439) ("<" 12440) (">" 12441) ("?" 12442) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 12443) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 12444) (T_BOOLEAN_AND 12445) (T_BOOLEAN_OR 12446) (T_COALESCE 12447) (T_DOUBLE_ARROW 12737) (T_INSTANCEOF 12448) (T_IS_EQUAL 12449) (T_IS_GREATER_OR_EQUAL 12450) (T_IS_IDENTICAL 12451) (T_IS_NOT_EQUAL 12452) (T_IS_NOT_IDENTICAL 12453) (T_IS_SMALLER_OR_EQUAL 12454) (T_LOGICAL_AND 12455) (T_LOGICAL_OR 12456) (T_LOGICAL_XOR 12457) (T_POW 12458) (T_SL 12459) (T_SPACESHIP 12460) (T_SR 12461) ("^" 12462) ("|" 12463)) 5453 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 12726)) 5454 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 12714)) 5455 (("(" 12622) (argument_list 12713)) 5456 (("=" 12630) (T_AND_EQUAL 12631) (T_COALESCE_EQUAL 12632) (T_CONCAT_EQUAL 12633) (T_DEC 12634) (T_DIV_EQUAL 12635) (T_INC 12636) (T_MINUS_EQUAL 12637) (T_MOD_EQUAL 12638) (T_MUL_EQUAL 12639) (T_OR_EQUAL 12640) (T_PLUS_EQUAL 12641) (T_POW_EQUAL 12642) (T_SL_EQUAL 12643) (T_SR_EQUAL 12644) (T_XOR_EQUAL 12645)) 5457 ((T_PAAMAYIM_NEKUDOTAYIM 12535)) 5458 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12433) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5459 (("%" 12434) ("*" 12435) ("+" 12436) ("-" 12437) ("." 12438) ("/" 12439) ("<" 12440) (">" 12441) ("?" 12442) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 12443) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 12444) (T_BOOLEAN_AND 12445) (T_BOOLEAN_OR 12446) (T_COALESCE 12447) (T_INSTANCEOF 12448) (T_IS_EQUAL 12449) (T_IS_GREATER_OR_EQUAL 12450) (T_IS_IDENTICAL 12451) (T_IS_NOT_EQUAL 12452) (T_IS_NOT_IDENTICAL 12453) (T_IS_SMALLER_OR_EQUAL 12454) (T_LOGICAL_AND 12455) (T_LOGICAL_OR 12456) (T_LOGICAL_XOR 12457) (T_POW 12458) (T_SL 12459) (T_SPACESHIP 12460) (T_SR 12461) ("^" 12462) ("|" 12463)) 5460 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12534) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5461 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12533) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5462 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12532) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5463 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12531) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5464 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12530) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5465 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12529) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5466 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12528) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5467 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12527) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5468 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 12522) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 12523) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 5469 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12521) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5470 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12520) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5471 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12519) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5472 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12518) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5473 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12517) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5474 (("$" 12479) ("(" 12480) (T_NAME_FULLY_QUALIFIED 12481) (T_NAME_QUALIFIED 12482) (T_NAME_RELATIVE 12483) (T_STATIC 12484) (T_STRING 12485) (T_VARIABLE 12486) (class_name 12487) (class_name_reference 12488) (name 12489) (new_variable 12490) (simple_variable 12491)) 5475 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12478) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5476 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12477) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5477 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12476) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5478 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12475) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5479 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12474) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5480 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12473) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5481 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12472) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5482 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12471) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5483 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12470) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5484 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12469) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5485 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12468) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5486 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12467) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5487 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12466) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5488 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12465) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5489 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12464) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5490 (("$" 12479) (T_VARIABLE 12486) (simple_variable 12513) ("{" 12514)) 5491 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 12511) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 5492 ((T_PAAMAYIM_NEKUDOTAYIM 12509)) 5493 ((T_NULLSAFE_OBJECT_OPERATOR 12492) (T_OBJECT_OPERATOR 12493) (T_PAAMAYIM_NEKUDOTAYIM 12494) ("[" 12495) ("{" 12496)) 5494 (("$" 12479) (T_STRING 12502) (T_VARIABLE 12486) (property_name 12508) (simple_variable 12504) ("{" 12505)) 5495 (("$" 12479) (T_STRING 12502) (T_VARIABLE 12486) (property_name 12503) (simple_variable 12504) ("{" 12505)) 5496 (("$" 12479) (T_VARIABLE 12486) (simple_variable 12501)) 5497 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 12499) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 5498 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12497) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5499 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 12498)) 5500 (("]" 12500)) 5501 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12506) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5502 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 12507)) 5503 (("$" 12479) (T_VARIABLE 12486) (simple_variable 12510)) 5504 (("%" 292) (")" 12512) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 5505 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12515) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5506 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 12516)) 5507 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12526) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5508 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 12524) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 5509 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12525) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5510 (("$" 12358) (T_ABSTRACT 12536) (T_ARRAY 12537) (T_AS 12538) (T_BREAK 12539) (T_CALLABLE 12540) (T_CASE 12541) (T_CATCH 12542) (T_CLASS 12543) (T_CLASS_C 12544) (T_CLONE 12545) (T_CONST 12546) (T_CONTINUE 12547) (T_DECLARE 12548) (T_DEFAULT 12549) (T_DIR 12550) (T_DO 12551) (T_ECHO 12552) (T_ELSE 12553) (T_ELSEIF 12554) (T_EMPTY 12555) (T_ENDDECLARE 12556) (T_ENDFOR 12557) (T_ENDFOREACH 12558) (T_ENDIF 12559) (T_ENDSWITCH 12560) (T_ENDWHILE 12561) (T_ENUM 12562) (T_EVAL 12563) (T_EXIT 12564) (T_EXTENDS 12565) (T_FILE 12566) (T_FINAL 12567) (T_FINALLY 12568) (T_FN 12569) (T_FOR 12570) (T_FOREACH 12571) (T_FUNCTION 12572) (T_FUNC_C 12573) (T_GLOBAL 12574) (T_GOTO 12575) (T_IF 12576) (T_IMPLEMENTS 12577) (T_INCLUDE 12578) (T_INCLUDE_ONCE 12579) (T_INSTANCEOF 12580) (T_INSTEADOF 12581) (T_INTERFACE 12582) (T_ISSET 12583) (T_LINE 12584) (T_LIST 12585) (T_LOGICAL_AND 12586) (T_LOGICAL_OR 12587) (T_LOGICAL_XOR 12588) (T_MATCH 12589) (T_METHOD_C 12590) (T_NAMESPACE 12591) (T_NEW 12592) (T_NS_C 12593) (T_PRINT 12594) (T_PRIVATE 12595) (T_PROTECTED 12596) (T_PUBLIC 12597) (T_READONLY 12598) (T_REQUIRE 12599) (T_REQUIRE_ONCE 12600) (T_RETURN 12601) (T_STATIC 12602) (T_STRING 12603) (T_SWITCH 12604) (T_THROW 12605) (T_TRAIT 12606) (T_TRAIT_C 12607) (T_TRY 12608) (T_UNSET 12609) (T_USE 12610) (T_VAR 12611) (T_VARIABLE 12405) (T_WHILE 12612) (T_YIELD 12613) (identifier 12614) (member_name 12615) (reserved_non_modifiers 12616) (semi_reserved 12617) (simple_variable 12618) ("{" 12619)) 5511 (("(" 12622) (argument_list 12623)) 5512 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12620) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5513 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 12621)) 5514 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 12624) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 12625) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 12626) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 5515 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 12629) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 5516 (("," 1469) (possible_comma 12627)) 5517 ((")" 12628)) 5518 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (ampersand 12659) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12660) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5519 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12658) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5520 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12657) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5521 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12656) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5522 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12655) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5523 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12654) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5524 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12653) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5525 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12652) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5526 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12651) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5527 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12650) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5528 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12649) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5529 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12648) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5530 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12647) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5531 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12646) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5532 (("\"" 1509) ("$" 12661) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 12662) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 12663) ("[" 1529) (array_object_dereferenceable 12664) (callable_expr 12665) (callable_variable 12666) (class_constant 1533) (class_name 12667) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 12668) (name 12669) (simple_variable 12670) (static_member 12671) (variable 12672) (variable_class_name 12673)) 5533 (("$" 12661) (T_VARIABLE 12663) (simple_variable 12709) ("{" 12710)) 5534 (("(" 12677) (argument_list 12708)) 5535 ((T_NULLSAFE_OBJECT_OPERATOR 12691) (T_OBJECT_OPERATOR 12692) ("[" 12693) ("{" 12694)) 5536 (("(" 12677) (argument_list 12690)) 5537 ((T_PAAMAYIM_NEKUDOTAYIM 12686)) 5538 (("(" 12677) (argument_list 12685)) 5539 ((T_PAAMAYIM_NEKUDOTAYIM 12674)) 5540 (("$" 12661) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 12663) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 12675) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 12676) ("{" 1627)) 5541 (("(" 12677) (argument_list 12678)) 5542 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 12679) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 12680) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 12681) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 5543 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 12684) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 5544 (("," 1469) (possible_comma 12682)) 5545 ((")" 12683)) 5546 (("$" 12661) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 12663) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 12687) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 12688) ("{" 1643)) 5547 (("(" 12677) (argument_list 12689)) 5548 (("$" 12661) (T_STRING 12699) (T_VARIABLE 12663) (property_name 12706) (simple_variable 12701) ("{" 12702)) 5549 (("$" 12661) (T_STRING 12699) (T_VARIABLE 12663) (property_name 12700) (simple_variable 12701) ("{" 12702)) 5550 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 12697) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 5551 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12695) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5552 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 12696)) 5553 (("]" 12698)) 5554 (("(" 12677) (argument_list 12705)) 5555 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12703) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5556 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 12704)) 5557 (("(" 12677) (argument_list 12707)) 5558 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12711) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5559 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 12712)) 5560 ((backup_doc_comment 12715)) 5561 (("(" 12716)) 5562 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 12717)) 5563 ((")" 12718)) 5564 ((T_USE 159) (lexical_vars 12719)) 5565 ((":" 161) (return_type 12720)) 5566 ((backup_fn_flags 12721)) 5567 (("{" 12722)) 5568 ((inner_statement_list 12723)) 5569 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 12724) ("~" 125)) 5570 ((backup_fn_flags 12725)) 5571 ((backup_doc_comment 12727)) 5572 (("(" 12728)) 5573 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 12729)) 5574 ((")" 12730)) 5575 ((":" 2241) (return_type 12731)) 5576 ((T_DOUBLE_ARROW 12732)) 5577 ((backup_fn_flags 12733)) 5578 ((backup_lex_pos 12734)) 5579 (("!" 11676) ("\"" 11677) ("$" 11678) ("(" 11679) ("+" 11680) ("-" 11681) ("@" 11682) (T_ARRAY 11683) (T_ARRAY_CAST 11684) (T_ATTRIBUTE 126) (T_BOOL_CAST 11685) (T_CLASS_C 11686) (T_CLONE 11687) (T_CONSTANT_ENCAPSED_STRING 11688) (T_DEC 11689) (T_DIR 11690) (T_DNUMBER 11691) (T_DOUBLE_CAST 11692) (T_EMPTY 11693) (T_EVAL 11694) (T_EXIT 11695) (T_FILE 11696) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 11697) (T_INC 11698) (T_INCLUDE 11699) (T_INCLUDE_ONCE 11700) (T_INT_CAST 11701) (T_ISSET 11702) (T_LINE 11703) (T_LIST 11704) (T_LNUMBER 11705) (T_MATCH 11706) (T_METHOD_C 11707) (T_NAME_FULLY_QUALIFIED 11708) (T_NAME_QUALIFIED 11709) (T_NAME_RELATIVE 11710) (T_NEW 11711) (T_NS_C 11712) (T_OBJECT_CAST 11713) (T_PRINT 11714) (T_READONLY 11715) (T_REQUIRE 11716) (T_REQUIRE_ONCE 11717) (T_START_HEREDOC 11718) (T_STATIC 11719) (T_STRING 11720) (T_STRING_CAST 11721) (T_THROW 11722) (T_TRAIT_C 11723) (T_UNSET_CAST 11724) (T_VARIABLE 11725) (T_YIELD 11726) (T_YIELD_FROM 11727) ("[" 11728) ("`" 11729) (array_object_dereferenceable 11730) (attribute 131) (attributes 11731) (callable_expr 11732) (callable_variable 11733) (class_constant 11734) (class_name 11735) (constant 11736) (dereferenceable_scalar 11737) (expr 12735) (fn 11739) (fully_dereferenceable 104) #'11740 (function_call 11741) (inline_function 11742) (internal_functions_in_yacc 11743) (match 11744) (name 11745) (new_expr 11746) (scalar 11747) (simple_variable 11748) (static_member 11749) (variable 11750) (variable_class_name 11751) ("~" 11752)) 5580 (("%" 11754) ("*" 11755) ("+" 11756) ("-" 11757) ("." 11758) ("/" 11759) ("<" 11760) (">" 11761) ("?" 11762) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 11763) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 11764) (T_BOOLEAN_AND 11765) (T_BOOLEAN_OR 11766) (T_COALESCE 11767) (T_INSTANCEOF 11768) (T_IS_EQUAL 11769) (T_IS_GREATER_OR_EQUAL 11770) (T_IS_IDENTICAL 11771) (T_IS_NOT_EQUAL 11772) (T_IS_NOT_IDENTICAL 11773) (T_IS_SMALLER_OR_EQUAL 11774) (T_LOGICAL_AND 11775) (T_LOGICAL_OR 11776) (T_LOGICAL_XOR 11777) (T_POW 11778) (T_SL 11779) (T_SPACESHIP 11780) (T_SR 11781) ("^" 11782) (backup_fn_flags 12736) ("|" 11783)) 5581 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 12738) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 5582 (("$" 12358) (T_ABSTRACT 12536) (T_ARRAY 12537) (T_AS 12538) (T_BREAK 12539) (T_CALLABLE 12540) (T_CASE 12541) (T_CATCH 12542) (T_CLASS 12543) (T_CLASS_C 12544) (T_CLONE 12545) (T_CONST 12546) (T_CONTINUE 12547) (T_DECLARE 12548) (T_DEFAULT 12549) (T_DIR 12550) (T_DO 12551) (T_ECHO 12552) (T_ELSE 12553) (T_ELSEIF 12554) (T_EMPTY 12555) (T_ENDDECLARE 12556) (T_ENDFOR 12557) (T_ENDFOREACH 12558) (T_ENDIF 12559) (T_ENDSWITCH 12560) (T_ENDWHILE 12561) (T_ENUM 12562) (T_EVAL 12563) (T_EXIT 12564) (T_EXTENDS 12565) (T_FILE 12566) (T_FINAL 12567) (T_FINALLY 12568) (T_FN 12569) (T_FOR 12570) (T_FOREACH 12571) (T_FUNCTION 12572) (T_FUNC_C 12573) (T_GLOBAL 12574) (T_GOTO 12575) (T_IF 12576) (T_IMPLEMENTS 12577) (T_INCLUDE 12578) (T_INCLUDE_ONCE 12579) (T_INSTANCEOF 12580) (T_INSTEADOF 12581) (T_INTERFACE 12582) (T_ISSET 12583) (T_LINE 12584) (T_LIST 12585) (T_LOGICAL_AND 12586) (T_LOGICAL_OR 12587) (T_LOGICAL_XOR 12588) (T_MATCH 12589) (T_METHOD_C 12590) (T_NAMESPACE 12591) (T_NEW 12592) (T_NS_C 12593) (T_PRINT 12594) (T_PRIVATE 12595) (T_PROTECTED 12596) (T_PUBLIC 12597) (T_READONLY 12598) (T_REQUIRE 12599) (T_REQUIRE_ONCE 12600) (T_RETURN 12601) (T_STATIC 12602) (T_STRING 12603) (T_SWITCH 12604) (T_THROW 12605) (T_TRAIT 12606) (T_TRAIT_C 12607) (T_TRY 12608) (T_UNSET 12609) (T_USE 12610) (T_VAR 12611) (T_VARIABLE 12405) (T_WHILE 12612) (T_YIELD 12613) (identifier 12740) (member_name 12741) (reserved_non_modifiers 12616) (semi_reserved 12617) (simple_variable 12742) ("{" 12743)) 5583 (("(" 12622) (argument_list 12746)) 5584 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12744) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5585 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 12745)) 5586 ((T_FN 35) (T_FUNCTION 127) (fn 12419) #'12420 (inline_function 12750)) 5587 (("$" 12358) (T_STRING 12759) (T_VARIABLE 12405) (property_name 12766) (simple_variable 12761) ("{" 12762)) 5588 (("$" 12358) (T_STRING 12759) (T_VARIABLE 12405) (property_name 12760) (simple_variable 12761) ("{" 12762)) 5589 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 12757) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 5590 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12755) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5591 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 12756)) 5592 (("]" 12758)) 5593 (("(" 12622) (argument_list 12765)) 5594 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12763) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5595 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 12764)) 5596 (("(" 12622) (argument_list 12767)) 5597 (("`" 12769)) 5598 (("]" 12771)) 5599 (("=" 12772)) 5600 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12773) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5601 (("%" 12434) ("*" 12435) ("+" 12436) ("-" 12437) ("." 12438) ("/" 12439) ("<" 12440) (">" 12441) ("?" 12442) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 12443) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 12444) (T_BOOLEAN_AND 12445) (T_BOOLEAN_OR 12446) (T_COALESCE 12447) (T_DOUBLE_ARROW 12776) (T_INSTANCEOF 12448) (T_IS_EQUAL 12449) (T_IS_GREATER_OR_EQUAL 12450) (T_IS_IDENTICAL 12451) (T_IS_NOT_EQUAL 12452) (T_IS_NOT_IDENTICAL 12453) (T_IS_SMALLER_OR_EQUAL 12454) (T_LOGICAL_AND 12455) (T_LOGICAL_OR 12456) (T_LOGICAL_XOR 12457) (T_POW 12458) (T_SL 12459) (T_SPACESHIP 12460) (T_SR 12461) ("^" 12462) ("|" 12463)) 5602 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12777) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5603 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 12786) (T_VARIABLE 2900) (encaps_var 2914)) 5604 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 12785) (T_VARIABLE 2900) (encaps_var 2905)) 5605 ((T_CLASS 12806)) 5606 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 12805) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 12793) (attribute 2980) (class_modifier 2945)) 5607 (("(" 12796) (argument_list 12797) (ctor_arguments 12798)) 5608 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 12799) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 12800) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 12801) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 5609 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 12804) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 5610 (("," 1469) (possible_comma 12802)) 5611 ((")" 12803)) 5612 (("(" 2982) (argument_list 2983) (ctor_arguments 12807)) 5613 ((T_EXTENDS 2985) (extends_from 12808)) 5614 ((T_IMPLEMENTS 2987) (implements_list 12809)) 5615 ((backup_doc_comment 12810)) 5616 (("{" 12811)) 5617 ((class_statement_list 12812)) 5618 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 12813)) 5619 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 12815) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 5620 (("%" 292) (")" 12816) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 5621 (("{" 12817)) 5622 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 12818) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 5623 (("}" 12819)) 5624 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 12821) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 5625 ((")" 12822)) 5626 (("=" 12823)) 5627 (("!" 12356) ("\"" 12357) ("$" 12358) ("(" 12359) ("+" 12360) ("-" 12361) ("@" 12362) (T_ARRAY 12363) (T_ARRAY_CAST 12364) (T_ATTRIBUTE 126) (T_BOOL_CAST 12365) (T_CLASS_C 12366) (T_CLONE 12367) (T_CONSTANT_ENCAPSED_STRING 12368) (T_DEC 12369) (T_DIR 12370) (T_DNUMBER 12371) (T_DOUBLE_CAST 12372) (T_EMPTY 12373) (T_EVAL 12374) (T_EXIT 12375) (T_FILE 12376) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 12377) (T_INC 12378) (T_INCLUDE 12379) (T_INCLUDE_ONCE 12380) (T_INT_CAST 12381) (T_ISSET 12382) (T_LINE 12383) (T_LIST 12384) (T_LNUMBER 12385) (T_MATCH 12386) (T_METHOD_C 12387) (T_NAME_FULLY_QUALIFIED 12388) (T_NAME_QUALIFIED 12389) (T_NAME_RELATIVE 12390) (T_NEW 12391) (T_NS_C 12392) (T_OBJECT_CAST 12393) (T_PRINT 12394) (T_READONLY 12395) (T_REQUIRE 12396) (T_REQUIRE_ONCE 12397) (T_START_HEREDOC 12398) (T_STATIC 12399) (T_STRING 12400) (T_STRING_CAST 12401) (T_THROW 12402) (T_TRAIT_C 12403) (T_UNSET_CAST 12404) (T_VARIABLE 12405) (T_YIELD 12406) (T_YIELD_FROM 12407) ("[" 12408) ("`" 12409) (array_object_dereferenceable 12410) (attribute 131) (attributes 12411) (callable_expr 12412) (callable_variable 12413) (class_constant 12414) (class_name 12415) (constant 12416) (dereferenceable_scalar 12417) (expr 12824) (fn 12419) (fully_dereferenceable 104) #'12420 (function_call 12421) (inline_function 12422) (internal_functions_in_yacc 12423) (match 12424) (name 12425) (new_expr 12426) (scalar 12427) (simple_variable 12428) (static_member 12429) (variable 12430) (variable_class_name 12431) ("~" 12432)) 5628 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 12826) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 5629 (("," 5258) (possible_comma 12827)) 5630 ((")" 12828)) 5631 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 12835) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 5632 ((")" 12836)) 5633 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 12838) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 5634 (("%" 292) (")" 12839) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 5635 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 12841) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 5636 (("%" 292) (")" 12842) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 5637 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 12849) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 5638 ((")" 12850)) 5639 (("%" 292) (")" 12855) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 5640 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12858) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5641 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 12859)) 5642 (("\"" 12861) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 5643 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 12871) (T_VARIABLE 2900) (encaps_var 2914)) 5644 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 12870) (T_VARIABLE 2900) (encaps_var 2905)) 5645 ((T_CLASS 12891)) 5646 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 12890) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 12878) (attribute 2980) (class_modifier 2945)) 5647 (("(" 12881) (argument_list 12882) (ctor_arguments 12883)) 5648 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 12884) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 12885) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 12886) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 5649 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 12889) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 5650 (("," 1469) (possible_comma 12887)) 5651 ((")" 12888)) 5652 (("(" 2982) (argument_list 2983) (ctor_arguments 12892)) 5653 ((T_EXTENDS 2985) (extends_from 12893)) 5654 ((T_IMPLEMENTS 2987) (implements_list 12894)) 5655 ((backup_doc_comment 12895)) 5656 (("{" 12896)) 5657 ((class_statement_list 12897)) 5658 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 12898)) 5659 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 12900) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 5660 (("%" 292) (")" 12901) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 5661 (("{" 12902)) 5662 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 12903) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 5663 (("}" 12904)) 5664 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 12906) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 5665 ((")" 12907)) 5666 (("=" 12908)) 5667 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 12909) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 5668 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 12911) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 5669 (("," 5258) (possible_comma 12912)) 5670 ((")" 12913)) 5671 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 12920) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 5672 ((")" 12921)) 5673 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 12923) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 5674 (("%" 292) (")" 12924) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 5675 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 12926) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 5676 (("%" 292) (")" 12927) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 5677 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 12934) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 5678 ((")" 12935)) 5679 (("%" 292) (")" 12940) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 5680 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12943) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5681 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 12944)) 5682 (("\"" 12946) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 5683 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12953) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5684 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 12954)) 5685 (("$" 478) (T_VARIABLE 485) (simple_variable 12957)) 5686 (("%" 292) (")" 12959) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 5687 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12962) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5688 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 12963)) 5689 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12973) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5690 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 12971) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 5691 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 12972) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5692 (("$" 357) (T_ABSTRACT 12983) (T_ARRAY 12984) (T_AS 12985) (T_BREAK 12986) (T_CALLABLE 12987) (T_CASE 12988) (T_CATCH 12989) (T_CLASS 12990) (T_CLASS_C 12991) (T_CLONE 12992) (T_CONST 12993) (T_CONTINUE 12994) (T_DECLARE 12995) (T_DEFAULT 12996) (T_DIR 12997) (T_DO 12998) (T_ECHO 12999) (T_ELSE 13000) (T_ELSEIF 13001) (T_EMPTY 13002) (T_ENDDECLARE 13003) (T_ENDFOR 13004) (T_ENDFOREACH 13005) (T_ENDIF 13006) (T_ENDSWITCH 13007) (T_ENDWHILE 13008) (T_ENUM 13009) (T_EVAL 13010) (T_EXIT 13011) (T_EXTENDS 13012) (T_FILE 13013) (T_FINAL 13014) (T_FINALLY 13015) (T_FN 13016) (T_FOR 13017) (T_FOREACH 13018) (T_FUNCTION 13019) (T_FUNC_C 13020) (T_GLOBAL 13021) (T_GOTO 13022) (T_IF 13023) (T_IMPLEMENTS 13024) (T_INCLUDE 13025) (T_INCLUDE_ONCE 13026) (T_INSTANCEOF 13027) (T_INSTEADOF 13028) (T_INTERFACE 13029) (T_ISSET 13030) (T_LINE 13031) (T_LIST 13032) (T_LOGICAL_AND 13033) (T_LOGICAL_OR 13034) (T_LOGICAL_XOR 13035) (T_MATCH 13036) (T_METHOD_C 13037) (T_NAMESPACE 13038) (T_NEW 13039) (T_NS_C 13040) (T_PRINT 13041) (T_PRIVATE 13042) (T_PROTECTED 13043) (T_PUBLIC 13044) (T_READONLY 13045) (T_REQUIRE 13046) (T_REQUIRE_ONCE 13047) (T_RETURN 13048) (T_STATIC 13049) (T_STRING 13050) (T_SWITCH 13051) (T_THROW 13052) (T_TRAIT 13053) (T_TRAIT_C 13054) (T_TRY 13055) (T_UNSET 13056) (T_USE 13057) (T_VAR 13058) (T_VARIABLE 404) (T_WHILE 13059) (T_YIELD 13060) (identifier 13061) (member_name 13062) (reserved_non_modifiers 13063) (semi_reserved 13064) (simple_variable 13065) ("{" 13066)) 5693 (("(" 13069) (argument_list 13070)) 5694 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13067) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5695 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 13068)) 5696 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 13071) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 13072) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 13073) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 5697 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 13076) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 5698 (("," 1469) (possible_comma 13074)) 5699 ((")" 13075)) 5700 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (ampersand 13106) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13107) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5701 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13105) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5702 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13104) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5703 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13103) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5704 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13102) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5705 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13101) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5706 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13100) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5707 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13099) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5708 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13098) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5709 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13097) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5710 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13096) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5711 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13095) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5712 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13094) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5713 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13093) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5714 (("\"" 1509) ("$" 13108) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 13109) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 13110) ("[" 1529) (array_object_dereferenceable 13111) (callable_expr 13112) (callable_variable 13113) (class_constant 1533) (class_name 13114) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 13115) (name 13116) (simple_variable 13117) (static_member 13118) (variable 13119) (variable_class_name 13120)) 5715 (("$" 13108) (T_VARIABLE 13110) (simple_variable 13156) ("{" 13157)) 5716 (("(" 13124) (argument_list 13155)) 5717 ((T_NULLSAFE_OBJECT_OPERATOR 13138) (T_OBJECT_OPERATOR 13139) ("[" 13140) ("{" 13141)) 5718 (("(" 13124) (argument_list 13137)) 5719 ((T_PAAMAYIM_NEKUDOTAYIM 13133)) 5720 (("(" 13124) (argument_list 13132)) 5721 ((T_PAAMAYIM_NEKUDOTAYIM 13121)) 5722 (("$" 13108) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 13110) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 13122) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 13123) ("{" 1627)) 5723 (("(" 13124) (argument_list 13125)) 5724 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 13126) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 13127) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 13128) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 5725 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 13131) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 5726 (("," 1469) (possible_comma 13129)) 5727 ((")" 13130)) 5728 (("$" 13108) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 13110) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 13134) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 13135) ("{" 1643)) 5729 (("(" 13124) (argument_list 13136)) 5730 (("$" 13108) (T_STRING 13146) (T_VARIABLE 13110) (property_name 13153) (simple_variable 13148) ("{" 13149)) 5731 (("$" 13108) (T_STRING 13146) (T_VARIABLE 13110) (property_name 13147) (simple_variable 13148) ("{" 13149)) 5732 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 13144) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 5733 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13142) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5734 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 13143)) 5735 (("]" 13145)) 5736 (("(" 13124) (argument_list 13152)) 5737 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13150) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5738 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 13151)) 5739 (("(" 13124) (argument_list 13154)) 5740 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13158) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5741 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 13159)) 5742 ((backup_doc_comment 13162)) 5743 (("(" 13163)) 5744 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 13164)) 5745 ((")" 13165)) 5746 ((T_USE 159) (lexical_vars 13166)) 5747 ((":" 161) (return_type 13167)) 5748 ((backup_fn_flags 13168)) 5749 (("{" 13169)) 5750 ((inner_statement_list 13170)) 5751 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 13171) ("~" 125)) 5752 ((backup_fn_flags 13172)) 5753 ((backup_doc_comment 13174)) 5754 (("(" 13175)) 5755 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 13176)) 5756 ((")" 13177)) 5757 ((":" 2241) (return_type 13178)) 5758 ((T_DOUBLE_ARROW 13179)) 5759 ((backup_fn_flags 13180)) 5760 ((backup_lex_pos 13181)) 5761 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13244) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5762 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 14243) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5763 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 14241) (encaps_var 5299)) 5764 (("$" 13184) (T_VARIABLE 13231) (simple_variable 14237) ("{" 14238)) 5765 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14235) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 5766 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 14234) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5767 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 14233) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5768 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 14232) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5769 (("(" 14229)) 5770 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 14228) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5771 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 14227) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5772 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 14226) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5773 (("\"" 1509) ("$" 13487) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 13488) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 13489) ("[" 1529) (array_object_dereferenceable 13490) (callable_expr 13491) (callable_variable 13492) (class_constant 1533) (class_name 13493) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 13494) (name 13495) (simple_variable 13496) (static_member 13497) (variable 14225) (variable_class_name 13499)) 5774 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 14224) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5775 (("(" 14221)) 5776 (("(" 14218)) 5777 (("(" 14214) (exit_expr 14215)) 5778 (("\"" 1509) ("$" 13487) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 13488) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 13489) ("[" 1529) (array_object_dereferenceable 13490) (callable_expr 13491) (callable_variable 13492) (class_constant 1533) (class_name 13493) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 13494) (name 13495) (simple_variable 13496) (static_member 13497) (variable 14213) (variable_class_name 13499)) 5779 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 14212) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5780 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 14211) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5781 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 14210) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5782 (("(" 14206)) 5783 (("(" 14201)) 5784 (("(" 14195)) 5785 (("$" 13487) ("(" 14147) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 14148) (T_NAME_QUALIFIED 14149) (T_NAME_RELATIVE 14150) (T_READONLY 2936) (T_STATIC 14151) (T_STRING 14152) (T_VARIABLE 13489) (anonymous_class 14153) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 14154) (attribute 2943) (attributes 14155) (class_modifier 2945) (class_name 14156) (class_name_reference 14157) (name 14158) (new_variable 14159) (simple_variable 14160)) 5786 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 14146) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5787 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 14145) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5788 (("(" 13448) (argument_list 14144)) 5789 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 14143) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5790 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 14142) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5791 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 14137) (T_END_HEREDOC 14138) (T_VARIABLE 2900) (encaps_list 14139) (encaps_var 2902)) 5792 ((T_FN 35) (T_FUNCTION 127) (fn 13245) #'13246 (inline_function 14136)) 5793 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 14135) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5794 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 14134) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5795 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 14133) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5796 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13662) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 5797 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13599) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5798 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 13595) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 5799 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 13593) (encaps_list 2805) (encaps_var 2806)) 5800 ((T_NULLSAFE_OBJECT_OPERATOR 13576) (T_OBJECT_OPERATOR 13577) ("[" 13578) ("{" 13579)) 5801 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 13573) (attribute 2728) (fn 13245) #'13246 (inline_function 13574)) 5802 (("(" 13448) (argument_list 13572)) 5803 ((T_PAAMAYIM_NEKUDOTAYIM 13564)) 5804 (("%" 13260) ("*" 13261) ("+" 13262) ("-" 13263) ("." 13264) ("/" 13265) ("<" 13266) (">" 13267) ("?" 13268) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 13269) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 13270) (T_BOOLEAN_AND 13271) (T_BOOLEAN_OR 13272) (T_COALESCE 13273) (T_INSTANCEOF 13274) (T_IS_EQUAL 13275) (T_IS_GREATER_OR_EQUAL 13276) (T_IS_IDENTICAL 13277) (T_IS_NOT_EQUAL 13278) (T_IS_NOT_IDENTICAL 13279) (T_IS_SMALLER_OR_EQUAL 13280) (T_LOGICAL_AND 13281) (T_LOGICAL_OR 13282) (T_LOGICAL_XOR 13283) (T_POW 13284) (T_SL 13285) (T_SPACESHIP 13286) (T_SR 13287) ("^" 13288) (backup_fn_flags 13563) ("|" 13289)) 5805 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 13552)) 5806 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 13540)) 5807 (("(" 13448) (argument_list 13539)) 5808 (("=" 13456) (T_AND_EQUAL 13457) (T_COALESCE_EQUAL 13458) (T_CONCAT_EQUAL 13459) (T_DEC 13460) (T_DIV_EQUAL 13461) (T_INC 13462) (T_MINUS_EQUAL 13463) (T_MOD_EQUAL 13464) (T_MUL_EQUAL 13465) (T_OR_EQUAL 13466) (T_PLUS_EQUAL 13467) (T_POW_EQUAL 13468) (T_SL_EQUAL 13469) (T_SR_EQUAL 13470) (T_XOR_EQUAL 13471)) 5809 ((T_PAAMAYIM_NEKUDOTAYIM 13361)) 5810 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13259) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5811 (("%" 13260) ("*" 13261) ("+" 13262) ("-" 13263) ("." 13264) ("/" 13265) ("<" 13266) (">" 13267) ("?" 13268) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 13269) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 13270) (T_BOOLEAN_AND 13271) (T_BOOLEAN_OR 13272) (T_COALESCE 13273) (T_INSTANCEOF 13274) (T_IS_EQUAL 13275) (T_IS_GREATER_OR_EQUAL 13276) (T_IS_IDENTICAL 13277) (T_IS_NOT_EQUAL 13278) (T_IS_NOT_IDENTICAL 13279) (T_IS_SMALLER_OR_EQUAL 13280) (T_LOGICAL_AND 13281) (T_LOGICAL_OR 13282) (T_LOGICAL_XOR 13283) (T_POW 13284) (T_SL 13285) (T_SPACESHIP 13286) (T_SR 13287) ("^" 13288) ("|" 13289)) 5812 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13360) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5813 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13359) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5814 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13358) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5815 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13357) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5816 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13356) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5817 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13355) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5818 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13354) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5819 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13353) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5820 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 13348) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 13349) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 5821 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13347) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5822 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13346) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5823 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13345) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5824 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13344) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5825 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13343) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5826 (("$" 13305) ("(" 13306) (T_NAME_FULLY_QUALIFIED 13307) (T_NAME_QUALIFIED 13308) (T_NAME_RELATIVE 13309) (T_STATIC 13310) (T_STRING 13311) (T_VARIABLE 13312) (class_name 13313) (class_name_reference 13314) (name 13315) (new_variable 13316) (simple_variable 13317)) 5827 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13304) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5828 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13303) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5829 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13302) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5830 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13301) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5831 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13300) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5832 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13299) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5833 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13298) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5834 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13297) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5835 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13296) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5836 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13295) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5837 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13294) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5838 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13293) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5839 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13292) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5840 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13291) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5841 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13290) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5842 (("$" 13305) (T_VARIABLE 13312) (simple_variable 13339) ("{" 13340)) 5843 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 13337) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 5844 ((T_PAAMAYIM_NEKUDOTAYIM 13335)) 5845 ((T_NULLSAFE_OBJECT_OPERATOR 13318) (T_OBJECT_OPERATOR 13319) (T_PAAMAYIM_NEKUDOTAYIM 13320) ("[" 13321) ("{" 13322)) 5846 (("$" 13305) (T_STRING 13328) (T_VARIABLE 13312) (property_name 13334) (simple_variable 13330) ("{" 13331)) 5847 (("$" 13305) (T_STRING 13328) (T_VARIABLE 13312) (property_name 13329) (simple_variable 13330) ("{" 13331)) 5848 (("$" 13305) (T_VARIABLE 13312) (simple_variable 13327)) 5849 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 13325) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 5850 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13323) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5851 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 13324)) 5852 (("]" 13326)) 5853 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13332) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5854 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 13333)) 5855 (("$" 13305) (T_VARIABLE 13312) (simple_variable 13336)) 5856 (("%" 292) (")" 13338) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 5857 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13341) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5858 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 13342)) 5859 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13352) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5860 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 13350) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 5861 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13351) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5862 (("$" 13184) (T_ABSTRACT 13362) (T_ARRAY 13363) (T_AS 13364) (T_BREAK 13365) (T_CALLABLE 13366) (T_CASE 13367) (T_CATCH 13368) (T_CLASS 13369) (T_CLASS_C 13370) (T_CLONE 13371) (T_CONST 13372) (T_CONTINUE 13373) (T_DECLARE 13374) (T_DEFAULT 13375) (T_DIR 13376) (T_DO 13377) (T_ECHO 13378) (T_ELSE 13379) (T_ELSEIF 13380) (T_EMPTY 13381) (T_ENDDECLARE 13382) (T_ENDFOR 13383) (T_ENDFOREACH 13384) (T_ENDIF 13385) (T_ENDSWITCH 13386) (T_ENDWHILE 13387) (T_ENUM 13388) (T_EVAL 13389) (T_EXIT 13390) (T_EXTENDS 13391) (T_FILE 13392) (T_FINAL 13393) (T_FINALLY 13394) (T_FN 13395) (T_FOR 13396) (T_FOREACH 13397) (T_FUNCTION 13398) (T_FUNC_C 13399) (T_GLOBAL 13400) (T_GOTO 13401) (T_IF 13402) (T_IMPLEMENTS 13403) (T_INCLUDE 13404) (T_INCLUDE_ONCE 13405) (T_INSTANCEOF 13406) (T_INSTEADOF 13407) (T_INTERFACE 13408) (T_ISSET 13409) (T_LINE 13410) (T_LIST 13411) (T_LOGICAL_AND 13412) (T_LOGICAL_OR 13413) (T_LOGICAL_XOR 13414) (T_MATCH 13415) (T_METHOD_C 13416) (T_NAMESPACE 13417) (T_NEW 13418) (T_NS_C 13419) (T_PRINT 13420) (T_PRIVATE 13421) (T_PROTECTED 13422) (T_PUBLIC 13423) (T_READONLY 13424) (T_REQUIRE 13425) (T_REQUIRE_ONCE 13426) (T_RETURN 13427) (T_STATIC 13428) (T_STRING 13429) (T_SWITCH 13430) (T_THROW 13431) (T_TRAIT 13432) (T_TRAIT_C 13433) (T_TRY 13434) (T_UNSET 13435) (T_USE 13436) (T_VAR 13437) (T_VARIABLE 13231) (T_WHILE 13438) (T_YIELD 13439) (identifier 13440) (member_name 13441) (reserved_non_modifiers 13442) (semi_reserved 13443) (simple_variable 13444) ("{" 13445)) 5863 (("(" 13448) (argument_list 13449)) 5864 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13446) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5865 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 13447)) 5866 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 13450) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 13451) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 13452) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 5867 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 13455) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 5868 (("," 1469) (possible_comma 13453)) 5869 ((")" 13454)) 5870 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (ampersand 13485) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13486) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5871 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13484) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5872 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13483) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5873 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13482) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5874 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13481) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5875 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13480) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5876 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13479) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5877 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13478) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5878 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13477) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5879 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13476) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5880 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13475) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5881 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13474) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5882 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13473) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5883 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13472) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5884 (("\"" 1509) ("$" 13487) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 13488) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 13489) ("[" 1529) (array_object_dereferenceable 13490) (callable_expr 13491) (callable_variable 13492) (class_constant 1533) (class_name 13493) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 13494) (name 13495) (simple_variable 13496) (static_member 13497) (variable 13498) (variable_class_name 13499)) 5885 (("$" 13487) (T_VARIABLE 13489) (simple_variable 13535) ("{" 13536)) 5886 (("(" 13503) (argument_list 13534)) 5887 ((T_NULLSAFE_OBJECT_OPERATOR 13517) (T_OBJECT_OPERATOR 13518) ("[" 13519) ("{" 13520)) 5888 (("(" 13503) (argument_list 13516)) 5889 ((T_PAAMAYIM_NEKUDOTAYIM 13512)) 5890 (("(" 13503) (argument_list 13511)) 5891 ((T_PAAMAYIM_NEKUDOTAYIM 13500)) 5892 (("$" 13487) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 13489) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 13501) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 13502) ("{" 1627)) 5893 (("(" 13503) (argument_list 13504)) 5894 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 13505) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 13506) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 13507) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 5895 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 13510) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 5896 (("," 1469) (possible_comma 13508)) 5897 ((")" 13509)) 5898 (("$" 13487) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 13489) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 13513) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 13514) ("{" 1643)) 5899 (("(" 13503) (argument_list 13515)) 5900 (("$" 13487) (T_STRING 13525) (T_VARIABLE 13489) (property_name 13532) (simple_variable 13527) ("{" 13528)) 5901 (("$" 13487) (T_STRING 13525) (T_VARIABLE 13489) (property_name 13526) (simple_variable 13527) ("{" 13528)) 5902 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 13523) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 5903 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13521) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5904 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 13522)) 5905 (("]" 13524)) 5906 (("(" 13503) (argument_list 13531)) 5907 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13529) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5908 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 13530)) 5909 (("(" 13503) (argument_list 13533)) 5910 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13537) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5911 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 13538)) 5912 ((backup_doc_comment 13541)) 5913 (("(" 13542)) 5914 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 13543)) 5915 ((")" 13544)) 5916 ((T_USE 159) (lexical_vars 13545)) 5917 ((":" 161) (return_type 13546)) 5918 ((backup_fn_flags 13547)) 5919 (("{" 13548)) 5920 ((inner_statement_list 13549)) 5921 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 13550) ("~" 125)) 5922 ((backup_fn_flags 13551)) 5923 ((backup_doc_comment 13553)) 5924 (("(" 13554)) 5925 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 13555)) 5926 ((")" 13556)) 5927 ((":" 2241) (return_type 13557)) 5928 ((T_DOUBLE_ARROW 13558)) 5929 ((backup_fn_flags 13559)) 5930 ((backup_lex_pos 13560)) 5931 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13561) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5932 (("%" 13260) ("*" 13261) ("+" 13262) ("-" 13263) ("." 13264) ("/" 13265) ("<" 13266) (">" 13267) ("?" 13268) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 13269) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 13270) (T_BOOLEAN_AND 13271) (T_BOOLEAN_OR 13272) (T_COALESCE 13273) (T_INSTANCEOF 13274) (T_IS_EQUAL 13275) (T_IS_GREATER_OR_EQUAL 13276) (T_IS_IDENTICAL 13277) (T_IS_NOT_EQUAL 13278) (T_IS_NOT_IDENTICAL 13279) (T_IS_SMALLER_OR_EQUAL 13280) (T_LOGICAL_AND 13281) (T_LOGICAL_OR 13282) (T_LOGICAL_XOR 13283) (T_POW 13284) (T_SL 13285) (T_SPACESHIP 13286) (T_SR 13287) ("^" 13288) (backup_fn_flags 13562) ("|" 13289)) 5933 (("$" 13184) (T_ABSTRACT 13362) (T_ARRAY 13363) (T_AS 13364) (T_BREAK 13365) (T_CALLABLE 13366) (T_CASE 13367) (T_CATCH 13368) (T_CLASS 13369) (T_CLASS_C 13370) (T_CLONE 13371) (T_CONST 13372) (T_CONTINUE 13373) (T_DECLARE 13374) (T_DEFAULT 13375) (T_DIR 13376) (T_DO 13377) (T_ECHO 13378) (T_ELSE 13379) (T_ELSEIF 13380) (T_EMPTY 13381) (T_ENDDECLARE 13382) (T_ENDFOR 13383) (T_ENDFOREACH 13384) (T_ENDIF 13385) (T_ENDSWITCH 13386) (T_ENDWHILE 13387) (T_ENUM 13388) (T_EVAL 13389) (T_EXIT 13390) (T_EXTENDS 13391) (T_FILE 13392) (T_FINAL 13393) (T_FINALLY 13394) (T_FN 13395) (T_FOR 13396) (T_FOREACH 13397) (T_FUNCTION 13398) (T_FUNC_C 13399) (T_GLOBAL 13400) (T_GOTO 13401) (T_IF 13402) (T_IMPLEMENTS 13403) (T_INCLUDE 13404) (T_INCLUDE_ONCE 13405) (T_INSTANCEOF 13406) (T_INSTEADOF 13407) (T_INTERFACE 13408) (T_ISSET 13409) (T_LINE 13410) (T_LIST 13411) (T_LOGICAL_AND 13412) (T_LOGICAL_OR 13413) (T_LOGICAL_XOR 13414) (T_MATCH 13415) (T_METHOD_C 13416) (T_NAMESPACE 13417) (T_NEW 13418) (T_NS_C 13419) (T_PRINT 13420) (T_PRIVATE 13421) (T_PROTECTED 13422) (T_PUBLIC 13423) (T_READONLY 13424) (T_REQUIRE 13425) (T_REQUIRE_ONCE 13426) (T_RETURN 13427) (T_STATIC 13428) (T_STRING 13429) (T_SWITCH 13430) (T_THROW 13431) (T_TRAIT 13432) (T_TRAIT_C 13433) (T_TRY 13434) (T_UNSET 13435) (T_USE 13436) (T_VAR 13437) (T_VARIABLE 13231) (T_WHILE 13438) (T_YIELD 13439) (identifier 13565) (member_name 13566) (reserved_non_modifiers 13442) (semi_reserved 13443) (simple_variable 13567) ("{" 13568)) 5934 (("(" 13448) (argument_list 13571)) 5935 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13569) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5936 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 13570)) 5937 ((T_FN 35) (T_FUNCTION 127) (fn 13245) #'13246 (inline_function 13575)) 5938 (("$" 13184) (T_STRING 13584) (T_VARIABLE 13231) (property_name 13591) (simple_variable 13586) ("{" 13587)) 5939 (("$" 13184) (T_STRING 13584) (T_VARIABLE 13231) (property_name 13585) (simple_variable 13586) ("{" 13587)) 5940 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 13582) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 5941 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13580) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5942 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 13581)) 5943 (("]" 13583)) 5944 (("(" 13448) (argument_list 13590)) 5945 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13588) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 5946 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 13589)) 5947 (("(" 13448) (argument_list 13592)) 5948 (("`" 13594)) 5949 (("]" 13596)) 5950 (("=" 13597)) 5951 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13598) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 5952 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 14132) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 5953 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 14130) (encaps_var 5299)) 5954 (("$" 13602) (T_VARIABLE 13649) (simple_variable 14126) ("{" 14127)) 5955 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14124) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 5956 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 14123) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 5957 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 14122) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 5958 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 14121) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 5959 (("(" 14118)) 5960 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 14117) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 5961 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 14116) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 5962 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 14115) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 5963 (("\"" 1509) ("$" 13905) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 13906) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 13907) ("[" 1529) (array_object_dereferenceable 13908) (callable_expr 13909) (callable_variable 13910) (class_constant 1533) (class_name 13911) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 13912) (name 13913) (simple_variable 13914) (static_member 13915) (variable 14114) (variable_class_name 13917)) 5964 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 14113) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 5965 (("(" 14110)) 5966 (("(" 14107)) 5967 (("(" 14103) (exit_expr 14104)) 5968 (("\"" 1509) ("$" 13905) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 13906) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 13907) ("[" 1529) (array_object_dereferenceable 13908) (callable_expr 13909) (callable_variable 13910) (class_constant 1533) (class_name 13911) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 13912) (name 13913) (simple_variable 13914) (static_member 13915) (variable 14102) (variable_class_name 13917)) 5969 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 14101) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 5970 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 14100) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 5971 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 14099) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 5972 (("(" 14095)) 5973 (("(" 14090)) 5974 (("(" 14084)) 5975 (("$" 13905) ("(" 14036) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 14037) (T_NAME_QUALIFIED 14038) (T_NAME_RELATIVE 14039) (T_READONLY 2936) (T_STATIC 14040) (T_STRING 14041) (T_VARIABLE 13907) (anonymous_class 14042) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 14043) (attribute 2943) (attributes 14044) (class_modifier 2945) (class_name 14045) (class_name_reference 14046) (name 14047) (new_variable 14048) (simple_variable 14049)) 5976 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 14035) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 5977 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 14034) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 5978 (("(" 13866) (argument_list 14033)) 5979 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 14032) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 5980 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 14031) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 5981 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 14026) (T_END_HEREDOC 14027) (T_VARIABLE 2900) (encaps_list 14028) (encaps_var 2902)) 5982 ((T_FN 35) (T_FUNCTION 127) (fn 13663) #'13664 (inline_function 14025)) 5983 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 14024) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 5984 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 14023) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 5985 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 14022) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 5986 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 14019) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 5987 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 14018) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 5988 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 14014) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 5989 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 14012) (encaps_list 2805) (encaps_var 2806)) 5990 ((T_NULLSAFE_OBJECT_OPERATOR 13995) (T_OBJECT_OPERATOR 13996) ("[" 13997) ("{" 13998)) 5991 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 13992) (attribute 2728) (fn 13663) #'13664 (inline_function 13993)) 5992 (("(" 13866) (argument_list 13991)) 5993 ((T_PAAMAYIM_NEKUDOTAYIM 13983)) 5994 (("%" 13678) ("*" 13679) ("+" 13680) ("-" 13681) ("." 13682) ("/" 13683) ("<" 13684) (">" 13685) ("?" 13686) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 13687) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 13688) (T_BOOLEAN_AND 13689) (T_BOOLEAN_OR 13690) (T_COALESCE 13691) (T_DOUBLE_ARROW 13981) (T_INSTANCEOF 13692) (T_IS_EQUAL 13693) (T_IS_GREATER_OR_EQUAL 13694) (T_IS_IDENTICAL 13695) (T_IS_NOT_EQUAL 13696) (T_IS_NOT_IDENTICAL 13697) (T_IS_SMALLER_OR_EQUAL 13698) (T_LOGICAL_AND 13699) (T_LOGICAL_OR 13700) (T_LOGICAL_XOR 13701) (T_POW 13702) (T_SL 13703) (T_SPACESHIP 13704) (T_SR 13705) ("^" 13706) ("|" 13707)) 5995 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 13970)) 5996 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 13958)) 5997 (("(" 13866) (argument_list 13957)) 5998 (("=" 13874) (T_AND_EQUAL 13875) (T_COALESCE_EQUAL 13876) (T_CONCAT_EQUAL 13877) (T_DEC 13878) (T_DIV_EQUAL 13879) (T_INC 13880) (T_MINUS_EQUAL 13881) (T_MOD_EQUAL 13882) (T_MUL_EQUAL 13883) (T_OR_EQUAL 13884) (T_PLUS_EQUAL 13885) (T_POW_EQUAL 13886) (T_SL_EQUAL 13887) (T_SR_EQUAL 13888) (T_XOR_EQUAL 13889)) 5999 ((T_PAAMAYIM_NEKUDOTAYIM 13779)) 6000 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13677) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6001 (("%" 13678) ("*" 13679) ("+" 13680) ("-" 13681) ("." 13682) ("/" 13683) ("<" 13684) (">" 13685) ("?" 13686) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 13687) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 13688) (T_BOOLEAN_AND 13689) (T_BOOLEAN_OR 13690) (T_COALESCE 13691) (T_INSTANCEOF 13692) (T_IS_EQUAL 13693) (T_IS_GREATER_OR_EQUAL 13694) (T_IS_IDENTICAL 13695) (T_IS_NOT_EQUAL 13696) (T_IS_NOT_IDENTICAL 13697) (T_IS_SMALLER_OR_EQUAL 13698) (T_LOGICAL_AND 13699) (T_LOGICAL_OR 13700) (T_LOGICAL_XOR 13701) (T_POW 13702) (T_SL 13703) (T_SPACESHIP 13704) (T_SR 13705) ("^" 13706) ("|" 13707)) 6002 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13778) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6003 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13777) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6004 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13776) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6005 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13775) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6006 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13774) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6007 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13773) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6008 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13772) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6009 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13771) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6010 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 13766) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 13767) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 6011 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13765) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6012 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13764) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6013 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13763) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6014 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13762) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6015 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13761) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6016 (("$" 13723) ("(" 13724) (T_NAME_FULLY_QUALIFIED 13725) (T_NAME_QUALIFIED 13726) (T_NAME_RELATIVE 13727) (T_STATIC 13728) (T_STRING 13729) (T_VARIABLE 13730) (class_name 13731) (class_name_reference 13732) (name 13733) (new_variable 13734) (simple_variable 13735)) 6017 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13722) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6018 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13721) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6019 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13720) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6020 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13719) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6021 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13718) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6022 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13717) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6023 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13716) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6024 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13715) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6025 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13714) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6026 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13713) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6027 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13712) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6028 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13711) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6029 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13710) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6030 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13709) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6031 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13708) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6032 (("$" 13723) (T_VARIABLE 13730) (simple_variable 13757) ("{" 13758)) 6033 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 13755) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6034 ((T_PAAMAYIM_NEKUDOTAYIM 13753)) 6035 ((T_NULLSAFE_OBJECT_OPERATOR 13736) (T_OBJECT_OPERATOR 13737) (T_PAAMAYIM_NEKUDOTAYIM 13738) ("[" 13739) ("{" 13740)) 6036 (("$" 13723) (T_STRING 13746) (T_VARIABLE 13730) (property_name 13752) (simple_variable 13748) ("{" 13749)) 6037 (("$" 13723) (T_STRING 13746) (T_VARIABLE 13730) (property_name 13747) (simple_variable 13748) ("{" 13749)) 6038 (("$" 13723) (T_VARIABLE 13730) (simple_variable 13745)) 6039 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 13743) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 6040 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13741) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6041 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 13742)) 6042 (("]" 13744)) 6043 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13750) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6044 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 13751)) 6045 (("$" 13723) (T_VARIABLE 13730) (simple_variable 13754)) 6046 (("%" 292) (")" 13756) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 6047 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13759) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6048 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 13760)) 6049 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13770) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6050 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 13768) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 6051 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13769) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6052 (("$" 13602) (T_ABSTRACT 13780) (T_ARRAY 13781) (T_AS 13782) (T_BREAK 13783) (T_CALLABLE 13784) (T_CASE 13785) (T_CATCH 13786) (T_CLASS 13787) (T_CLASS_C 13788) (T_CLONE 13789) (T_CONST 13790) (T_CONTINUE 13791) (T_DECLARE 13792) (T_DEFAULT 13793) (T_DIR 13794) (T_DO 13795) (T_ECHO 13796) (T_ELSE 13797) (T_ELSEIF 13798) (T_EMPTY 13799) (T_ENDDECLARE 13800) (T_ENDFOR 13801) (T_ENDFOREACH 13802) (T_ENDIF 13803) (T_ENDSWITCH 13804) (T_ENDWHILE 13805) (T_ENUM 13806) (T_EVAL 13807) (T_EXIT 13808) (T_EXTENDS 13809) (T_FILE 13810) (T_FINAL 13811) (T_FINALLY 13812) (T_FN 13813) (T_FOR 13814) (T_FOREACH 13815) (T_FUNCTION 13816) (T_FUNC_C 13817) (T_GLOBAL 13818) (T_GOTO 13819) (T_IF 13820) (T_IMPLEMENTS 13821) (T_INCLUDE 13822) (T_INCLUDE_ONCE 13823) (T_INSTANCEOF 13824) (T_INSTEADOF 13825) (T_INTERFACE 13826) (T_ISSET 13827) (T_LINE 13828) (T_LIST 13829) (T_LOGICAL_AND 13830) (T_LOGICAL_OR 13831) (T_LOGICAL_XOR 13832) (T_MATCH 13833) (T_METHOD_C 13834) (T_NAMESPACE 13835) (T_NEW 13836) (T_NS_C 13837) (T_PRINT 13838) (T_PRIVATE 13839) (T_PROTECTED 13840) (T_PUBLIC 13841) (T_READONLY 13842) (T_REQUIRE 13843) (T_REQUIRE_ONCE 13844) (T_RETURN 13845) (T_STATIC 13846) (T_STRING 13847) (T_SWITCH 13848) (T_THROW 13849) (T_TRAIT 13850) (T_TRAIT_C 13851) (T_TRY 13852) (T_UNSET 13853) (T_USE 13854) (T_VAR 13855) (T_VARIABLE 13649) (T_WHILE 13856) (T_YIELD 13857) (identifier 13858) (member_name 13859) (reserved_non_modifiers 13860) (semi_reserved 13861) (simple_variable 13862) ("{" 13863)) 6053 (("(" 13866) (argument_list 13867)) 6054 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13864) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6055 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 13865)) 6056 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 13868) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 13869) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 13870) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 6057 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 13873) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 6058 (("," 1469) (possible_comma 13871)) 6059 ((")" 13872)) 6060 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (ampersand 13903) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13904) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6061 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13902) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6062 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13901) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6063 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13900) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6064 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13899) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6065 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13898) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6066 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13897) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6067 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13896) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6068 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13895) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6069 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13894) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6070 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13893) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6071 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13892) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6072 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13891) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6073 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13890) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6074 (("\"" 1509) ("$" 13905) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 13906) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 13907) ("[" 1529) (array_object_dereferenceable 13908) (callable_expr 13909) (callable_variable 13910) (class_constant 1533) (class_name 13911) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 13912) (name 13913) (simple_variable 13914) (static_member 13915) (variable 13916) (variable_class_name 13917)) 6075 (("$" 13905) (T_VARIABLE 13907) (simple_variable 13953) ("{" 13954)) 6076 (("(" 13921) (argument_list 13952)) 6077 ((T_NULLSAFE_OBJECT_OPERATOR 13935) (T_OBJECT_OPERATOR 13936) ("[" 13937) ("{" 13938)) 6078 (("(" 13921) (argument_list 13934)) 6079 ((T_PAAMAYIM_NEKUDOTAYIM 13930)) 6080 (("(" 13921) (argument_list 13929)) 6081 ((T_PAAMAYIM_NEKUDOTAYIM 13918)) 6082 (("$" 13905) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 13907) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 13919) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 13920) ("{" 1627)) 6083 (("(" 13921) (argument_list 13922)) 6084 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 13923) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 13924) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 13925) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 6085 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 13928) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 6086 (("," 1469) (possible_comma 13926)) 6087 ((")" 13927)) 6088 (("$" 13905) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 13907) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 13931) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 13932) ("{" 1643)) 6089 (("(" 13921) (argument_list 13933)) 6090 (("$" 13905) (T_STRING 13943) (T_VARIABLE 13907) (property_name 13950) (simple_variable 13945) ("{" 13946)) 6091 (("$" 13905) (T_STRING 13943) (T_VARIABLE 13907) (property_name 13944) (simple_variable 13945) ("{" 13946)) 6092 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 13941) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 6093 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13939) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6094 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 13940)) 6095 (("]" 13942)) 6096 (("(" 13921) (argument_list 13949)) 6097 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13947) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6098 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 13948)) 6099 (("(" 13921) (argument_list 13951)) 6100 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13955) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6101 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 13956)) 6102 ((backup_doc_comment 13959)) 6103 (("(" 13960)) 6104 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 13961)) 6105 ((")" 13962)) 6106 ((T_USE 159) (lexical_vars 13963)) 6107 ((":" 161) (return_type 13964)) 6108 ((backup_fn_flags 13965)) 6109 (("{" 13966)) 6110 ((inner_statement_list 13967)) 6111 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 13968) ("~" 125)) 6112 ((backup_fn_flags 13969)) 6113 ((backup_doc_comment 13971)) 6114 (("(" 13972)) 6115 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 13973)) 6116 ((")" 13974)) 6117 ((":" 2241) (return_type 13975)) 6118 ((T_DOUBLE_ARROW 13976)) 6119 ((backup_fn_flags 13977)) 6120 ((backup_lex_pos 13978)) 6121 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 13979) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6122 (("%" 13678) ("*" 13679) ("+" 13680) ("-" 13681) ("." 13682) ("/" 13683) ("<" 13684) (">" 13685) ("?" 13686) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 13687) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 13688) (T_BOOLEAN_AND 13689) (T_BOOLEAN_OR 13690) (T_COALESCE 13691) (T_INSTANCEOF 13692) (T_IS_EQUAL 13693) (T_IS_GREATER_OR_EQUAL 13694) (T_IS_IDENTICAL 13695) (T_IS_NOT_EQUAL 13696) (T_IS_NOT_IDENTICAL 13697) (T_IS_SMALLER_OR_EQUAL 13698) (T_LOGICAL_AND 13699) (T_LOGICAL_OR 13700) (T_LOGICAL_XOR 13701) (T_POW 13702) (T_SL 13703) (T_SPACESHIP 13704) (T_SR 13705) ("^" 13706) (backup_fn_flags 13980) ("|" 13707)) 6123 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 13982) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 6124 (("$" 13602) (T_ABSTRACT 13780) (T_ARRAY 13781) (T_AS 13782) (T_BREAK 13783) (T_CALLABLE 13784) (T_CASE 13785) (T_CATCH 13786) (T_CLASS 13787) (T_CLASS_C 13788) (T_CLONE 13789) (T_CONST 13790) (T_CONTINUE 13791) (T_DECLARE 13792) (T_DEFAULT 13793) (T_DIR 13794) (T_DO 13795) (T_ECHO 13796) (T_ELSE 13797) (T_ELSEIF 13798) (T_EMPTY 13799) (T_ENDDECLARE 13800) (T_ENDFOR 13801) (T_ENDFOREACH 13802) (T_ENDIF 13803) (T_ENDSWITCH 13804) (T_ENDWHILE 13805) (T_ENUM 13806) (T_EVAL 13807) (T_EXIT 13808) (T_EXTENDS 13809) (T_FILE 13810) (T_FINAL 13811) (T_FINALLY 13812) (T_FN 13813) (T_FOR 13814) (T_FOREACH 13815) (T_FUNCTION 13816) (T_FUNC_C 13817) (T_GLOBAL 13818) (T_GOTO 13819) (T_IF 13820) (T_IMPLEMENTS 13821) (T_INCLUDE 13822) (T_INCLUDE_ONCE 13823) (T_INSTANCEOF 13824) (T_INSTEADOF 13825) (T_INTERFACE 13826) (T_ISSET 13827) (T_LINE 13828) (T_LIST 13829) (T_LOGICAL_AND 13830) (T_LOGICAL_OR 13831) (T_LOGICAL_XOR 13832) (T_MATCH 13833) (T_METHOD_C 13834) (T_NAMESPACE 13835) (T_NEW 13836) (T_NS_C 13837) (T_PRINT 13838) (T_PRIVATE 13839) (T_PROTECTED 13840) (T_PUBLIC 13841) (T_READONLY 13842) (T_REQUIRE 13843) (T_REQUIRE_ONCE 13844) (T_RETURN 13845) (T_STATIC 13846) (T_STRING 13847) (T_SWITCH 13848) (T_THROW 13849) (T_TRAIT 13850) (T_TRAIT_C 13851) (T_TRY 13852) (T_UNSET 13853) (T_USE 13854) (T_VAR 13855) (T_VARIABLE 13649) (T_WHILE 13856) (T_YIELD 13857) (identifier 13984) (member_name 13985) (reserved_non_modifiers 13860) (semi_reserved 13861) (simple_variable 13986) ("{" 13987)) 6125 (("(" 13866) (argument_list 13990)) 6126 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13988) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6127 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 13989)) 6128 ((T_FN 35) (T_FUNCTION 127) (fn 13663) #'13664 (inline_function 13994)) 6129 (("$" 13602) (T_STRING 14003) (T_VARIABLE 13649) (property_name 14010) (simple_variable 14005) ("{" 14006)) 6130 (("$" 13602) (T_STRING 14003) (T_VARIABLE 13649) (property_name 14004) (simple_variable 14005) ("{" 14006)) 6131 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 14001) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 6132 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 13999) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6133 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 14000)) 6134 (("]" 14002)) 6135 (("(" 13866) (argument_list 14009)) 6136 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14007) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6137 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 14008)) 6138 (("(" 13866) (argument_list 14011)) 6139 (("`" 14013)) 6140 (("]" 14015)) 6141 (("=" 14016)) 6142 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 14017) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6143 (("%" 13678) ("*" 13679) ("+" 13680) ("-" 13681) ("." 13682) ("/" 13683) ("<" 13684) (">" 13685) ("?" 13686) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 13687) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 13688) (T_BOOLEAN_AND 13689) (T_BOOLEAN_OR 13690) (T_COALESCE 13691) (T_DOUBLE_ARROW 14020) (T_INSTANCEOF 13692) (T_IS_EQUAL 13693) (T_IS_GREATER_OR_EQUAL 13694) (T_IS_IDENTICAL 13695) (T_IS_NOT_EQUAL 13696) (T_IS_NOT_IDENTICAL 13697) (T_IS_SMALLER_OR_EQUAL 13698) (T_LOGICAL_AND 13699) (T_LOGICAL_OR 13700) (T_LOGICAL_XOR 13701) (T_POW 13702) (T_SL 13703) (T_SPACESHIP 13704) (T_SR 13705) ("^" 13706) ("|" 13707)) 6144 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 14021) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6145 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 14030) (T_VARIABLE 2900) (encaps_var 2914)) 6146 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 14029) (T_VARIABLE 2900) (encaps_var 2905)) 6147 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14082) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6148 ((T_CLASS 14074)) 6149 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 14073) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 14043) (attribute 2980) (class_modifier 2945)) 6150 ((T_PAAMAYIM_NEKUDOTAYIM 14071)) 6151 (("(" 14062) (argument_list 14063) (ctor_arguments 14064)) 6152 ((T_NULLSAFE_OBJECT_OPERATOR 14050) (T_OBJECT_OPERATOR 14051) (T_PAAMAYIM_NEKUDOTAYIM 14052) ("[" 14053) ("{" 14054)) 6153 (("$" 13905) (T_STRING 13943) (T_VARIABLE 13907) (property_name 14061) (simple_variable 13945) ("{" 13946)) 6154 (("$" 13905) (T_STRING 13943) (T_VARIABLE 13907) (property_name 14060) (simple_variable 13945) ("{" 13946)) 6155 (("$" 13905) (T_VARIABLE 13907) (simple_variable 14059)) 6156 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 14057) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 6157 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14055) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6158 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 14056)) 6159 (("]" 14058)) 6160 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 14065) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 14066) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 14067) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 6161 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 14070) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 6162 (("," 1469) (possible_comma 14068)) 6163 ((")" 14069)) 6164 (("$" 13905) (T_VARIABLE 13907) (simple_variable 14072)) 6165 (("(" 2982) (argument_list 2983) (ctor_arguments 14075)) 6166 ((T_EXTENDS 2985) (extends_from 14076)) 6167 ((T_IMPLEMENTS 2987) (implements_list 14077)) 6168 ((backup_doc_comment 14078)) 6169 (("{" 14079)) 6170 ((class_statement_list 14080)) 6171 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 14081)) 6172 (("%" 292) (")" 14083) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 6173 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14085) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6174 (("%" 292) (")" 14086) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 6175 (("{" 14087)) 6176 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 14088) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 6177 (("}" 14089)) 6178 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 14091) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 6179 ((")" 14092)) 6180 (("=" 14093)) 6181 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 14094) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6182 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 14096) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 6183 (("," 5258) (possible_comma 14097)) 6184 ((")" 14098)) 6185 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 14105) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6186 ((")" 14106)) 6187 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14108) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6188 (("%" 292) (")" 14109) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 6189 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14111) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6190 (("%" 292) (")" 14112) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 6191 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 14119) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 6192 ((")" 14120)) 6193 (("%" 292) (")" 14125) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 6194 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14128) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6195 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 14129)) 6196 (("\"" 14131) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 6197 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 14141) (T_VARIABLE 2900) (encaps_var 2914)) 6198 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 14140) (T_VARIABLE 2900) (encaps_var 2905)) 6199 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14193) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6200 ((T_CLASS 14185)) 6201 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 14184) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 14154) (attribute 2980) (class_modifier 2945)) 6202 ((T_PAAMAYIM_NEKUDOTAYIM 14182)) 6203 (("(" 14173) (argument_list 14174) (ctor_arguments 14175)) 6204 ((T_NULLSAFE_OBJECT_OPERATOR 14161) (T_OBJECT_OPERATOR 14162) (T_PAAMAYIM_NEKUDOTAYIM 14163) ("[" 14164) ("{" 14165)) 6205 (("$" 13487) (T_STRING 13525) (T_VARIABLE 13489) (property_name 14172) (simple_variable 13527) ("{" 13528)) 6206 (("$" 13487) (T_STRING 13525) (T_VARIABLE 13489) (property_name 14171) (simple_variable 13527) ("{" 13528)) 6207 (("$" 13487) (T_VARIABLE 13489) (simple_variable 14170)) 6208 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 14168) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 6209 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14166) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6210 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 14167)) 6211 (("]" 14169)) 6212 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 14176) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 14177) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 14178) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 6213 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 14181) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 6214 (("," 1469) (possible_comma 14179)) 6215 ((")" 14180)) 6216 (("$" 13487) (T_VARIABLE 13489) (simple_variable 14183)) 6217 (("(" 2982) (argument_list 2983) (ctor_arguments 14186)) 6218 ((T_EXTENDS 2985) (extends_from 14187)) 6219 ((T_IMPLEMENTS 2987) (implements_list 14188)) 6220 ((backup_doc_comment 14189)) 6221 (("{" 14190)) 6222 ((class_statement_list 14191)) 6223 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 14192)) 6224 (("%" 292) (")" 14194) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 6225 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14196) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6226 (("%" 292) (")" 14197) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 6227 (("{" 14198)) 6228 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 14199) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 6229 (("}" 14200)) 6230 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 14202) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 6231 ((")" 14203)) 6232 (("=" 14204)) 6233 (("!" 13182) ("\"" 13183) ("$" 13184) ("(" 13185) ("+" 13186) ("-" 13187) ("@" 13188) (T_ARRAY 13189) (T_ARRAY_CAST 13190) (T_ATTRIBUTE 126) (T_BOOL_CAST 13191) (T_CLASS_C 13192) (T_CLONE 13193) (T_CONSTANT_ENCAPSED_STRING 13194) (T_DEC 13195) (T_DIR 13196) (T_DNUMBER 13197) (T_DOUBLE_CAST 13198) (T_EMPTY 13199) (T_EVAL 13200) (T_EXIT 13201) (T_FILE 13202) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13203) (T_INC 13204) (T_INCLUDE 13205) (T_INCLUDE_ONCE 13206) (T_INT_CAST 13207) (T_ISSET 13208) (T_LINE 13209) (T_LIST 13210) (T_LNUMBER 13211) (T_MATCH 13212) (T_METHOD_C 13213) (T_NAME_FULLY_QUALIFIED 13214) (T_NAME_QUALIFIED 13215) (T_NAME_RELATIVE 13216) (T_NEW 13217) (T_NS_C 13218) (T_OBJECT_CAST 13219) (T_PRINT 13220) (T_READONLY 13221) (T_REQUIRE 13222) (T_REQUIRE_ONCE 13223) (T_START_HEREDOC 13224) (T_STATIC 13225) (T_STRING 13226) (T_STRING_CAST 13227) (T_THROW 13228) (T_TRAIT_C 13229) (T_UNSET_CAST 13230) (T_VARIABLE 13231) (T_YIELD 13232) (T_YIELD_FROM 13233) ("[" 13234) ("`" 13235) (array_object_dereferenceable 13236) (attribute 131) (attributes 13237) (callable_expr 13238) (callable_variable 13239) (class_constant 13240) (class_name 13241) (constant 13242) (dereferenceable_scalar 13243) (expr 14205) (fn 13245) (fully_dereferenceable 104) #'13246 (function_call 13247) (inline_function 13248) (internal_functions_in_yacc 13249) (match 13250) (name 13251) (new_expr 13252) (scalar 13253) (simple_variable 13254) (static_member 13255) (variable 13256) (variable_class_name 13257) ("~" 13258)) 6234 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 14207) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 6235 (("," 5258) (possible_comma 14208)) 6236 ((")" 14209)) 6237 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 14216) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6238 ((")" 14217)) 6239 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14219) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6240 (("%" 292) (")" 14220) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 6241 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14222) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6242 (("%" 292) (")" 14223) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 6243 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 14230) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 6244 ((")" 14231)) 6245 (("%" 292) (")" 14236) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 6246 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14239) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6247 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 14240)) 6248 (("\"" 14242) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 6249 (("$" 357) (T_ABSTRACT 12983) (T_ARRAY 12984) (T_AS 12985) (T_BREAK 12986) (T_CALLABLE 12987) (T_CASE 12988) (T_CATCH 12989) (T_CLASS 12990) (T_CLASS_C 12991) (T_CLONE 12992) (T_CONST 12993) (T_CONTINUE 12994) (T_DECLARE 12995) (T_DEFAULT 12996) (T_DIR 12997) (T_DO 12998) (T_ECHO 12999) (T_ELSE 13000) (T_ELSEIF 13001) (T_EMPTY 13002) (T_ENDDECLARE 13003) (T_ENDFOR 13004) (T_ENDFOREACH 13005) (T_ENDIF 13006) (T_ENDSWITCH 13007) (T_ENDWHILE 13008) (T_ENUM 13009) (T_EVAL 13010) (T_EXIT 13011) (T_EXTENDS 13012) (T_FILE 13013) (T_FINAL 13014) (T_FINALLY 13015) (T_FN 13016) (T_FOR 13017) (T_FOREACH 13018) (T_FUNCTION 13019) (T_FUNC_C 13020) (T_GLOBAL 13021) (T_GOTO 13022) (T_IF 13023) (T_IMPLEMENTS 13024) (T_INCLUDE 13025) (T_INCLUDE_ONCE 13026) (T_INSTANCEOF 13027) (T_INSTEADOF 13028) (T_INTERFACE 13029) (T_ISSET 13030) (T_LINE 13031) (T_LIST 13032) (T_LOGICAL_AND 13033) (T_LOGICAL_OR 13034) (T_LOGICAL_XOR 13035) (T_MATCH 13036) (T_METHOD_C 13037) (T_NAMESPACE 13038) (T_NEW 13039) (T_NS_C 13040) (T_PRINT 13041) (T_PRIVATE 13042) (T_PROTECTED 13043) (T_PUBLIC 13044) (T_READONLY 13045) (T_REQUIRE 13046) (T_REQUIRE_ONCE 13047) (T_RETURN 13048) (T_STATIC 13049) (T_STRING 13050) (T_SWITCH 13051) (T_THROW 13052) (T_TRAIT 13053) (T_TRAIT_C 13054) (T_TRY 13055) (T_UNSET 13056) (T_USE 13057) (T_VAR 13058) (T_VARIABLE 404) (T_WHILE 13059) (T_YIELD 13060) (identifier 14246) (member_name 14247) (reserved_non_modifiers 13063) (semi_reserved 13064) (simple_variable 14248) ("{" 14249)) 6250 (("(" 13069) (argument_list 14252)) 6251 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14250) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6252 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 14251)) 6253 ((T_FN 35) (T_FUNCTION 127) (fn 418) #'419 (inline_function 14256)) 6254 (("$" 357) (T_STRING 14265) (T_VARIABLE 404) (property_name 14272) (simple_variable 14267) ("{" 14268)) 6255 (("$" 357) (T_STRING 14265) (T_VARIABLE 404) (property_name 14266) (simple_variable 14267) ("{" 14268)) 6256 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 14263) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 6257 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14261) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6258 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 14262)) 6259 (("]" 14264)) 6260 (("(" 13069) (argument_list 14271)) 6261 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14269) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6262 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 14270)) 6263 (("(" 13069) (argument_list 14273)) 6264 (("`" 14275)) 6265 (("]" 14277)) 6266 (("=" 14278)) 6267 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14279) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6268 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14787) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6269 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 14785) (encaps_var 5299)) 6270 (("$" 14283) (T_VARIABLE 14330) (simple_variable 14781) ("{" 14782)) 6271 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14779) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6272 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14778) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6273 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14777) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6274 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14776) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6275 (("(" 14773)) 6276 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14772) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6277 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14771) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6278 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14770) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6279 (("\"" 1509) ("$" 14586) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 14587) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 14588) ("[" 1529) (array_object_dereferenceable 14589) (callable_expr 14590) (callable_variable 14591) (class_constant 1533) (class_name 14592) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 14593) (name 14594) (simple_variable 14595) (static_member 14596) (variable 14769) (variable_class_name 14598)) 6280 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14768) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6281 (("(" 14765)) 6282 (("(" 14762)) 6283 (("(" 14758) (exit_expr 14759)) 6284 (("\"" 1509) ("$" 14586) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 14587) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 14588) ("[" 1529) (array_object_dereferenceable 14589) (callable_expr 14590) (callable_variable 14591) (class_constant 1533) (class_name 14592) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 14593) (name 14594) (simple_variable 14595) (static_member 14596) (variable 14757) (variable_class_name 14598)) 6285 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14756) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6286 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14755) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6287 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14754) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6288 (("(" 14750)) 6289 (("(" 14745)) 6290 (("(" 14739)) 6291 (("$" 13905) ("(" 14036) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 14037) (T_NAME_QUALIFIED 14038) (T_NAME_RELATIVE 14039) (T_READONLY 2936) (T_STATIC 14040) (T_STRING 14041) (T_VARIABLE 13907) (anonymous_class 14717) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 14718) (attribute 2943) (attributes 14719) (class_modifier 2945) (class_name 14045) (class_name_reference 14720) (name 14047) (new_variable 14048) (simple_variable 14049)) 6292 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14716) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6293 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14715) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6294 (("(" 14547) (argument_list 14714)) 6295 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14713) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6296 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14712) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6297 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 14707) (T_END_HEREDOC 14708) (T_VARIABLE 2900) (encaps_list 14709) (encaps_var 2902)) 6298 ((T_FN 35) (T_FUNCTION 127) (fn 14344) #'14345 (inline_function 14706)) 6299 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14705) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6300 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14704) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6301 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14703) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6302 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14700) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6303 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14699) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6304 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 14695) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 6305 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 14693) (encaps_list 2805) (encaps_var 2806)) 6306 ((T_NULLSAFE_OBJECT_OPERATOR 14676) (T_OBJECT_OPERATOR 14677) ("[" 14678) ("{" 14679)) 6307 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 14673) (attribute 2728) (fn 14344) #'14345 (inline_function 14674)) 6308 (("(" 14547) (argument_list 14672)) 6309 ((T_PAAMAYIM_NEKUDOTAYIM 14664)) 6310 (("%" 14359) ("*" 14360) ("+" 14361) ("-" 14362) ("." 14363) ("/" 14364) ("<" 14365) (">" 14366) ("?" 14367) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 14368) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 14369) (T_BOOLEAN_AND 14370) (T_BOOLEAN_OR 14371) (T_COALESCE 14372) (T_DOUBLE_ARROW 14662) (T_INSTANCEOF 14373) (T_IS_EQUAL 14374) (T_IS_GREATER_OR_EQUAL 14375) (T_IS_IDENTICAL 14376) (T_IS_NOT_EQUAL 14377) (T_IS_NOT_IDENTICAL 14378) (T_IS_SMALLER_OR_EQUAL 14379) (T_LOGICAL_AND 14380) (T_LOGICAL_OR 14381) (T_LOGICAL_XOR 14382) (T_POW 14383) (T_SL 14384) (T_SPACESHIP 14385) (T_SR 14386) ("^" 14387) ("|" 14388)) 6311 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 14651)) 6312 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 14639)) 6313 (("(" 14547) (argument_list 14638)) 6314 (("=" 14555) (T_AND_EQUAL 14556) (T_COALESCE_EQUAL 14557) (T_CONCAT_EQUAL 14558) (T_DEC 14559) (T_DIV_EQUAL 14560) (T_INC 14561) (T_MINUS_EQUAL 14562) (T_MOD_EQUAL 14563) (T_MUL_EQUAL 14564) (T_OR_EQUAL 14565) (T_PLUS_EQUAL 14566) (T_POW_EQUAL 14567) (T_SL_EQUAL 14568) (T_SR_EQUAL 14569) (T_XOR_EQUAL 14570)) 6315 ((T_PAAMAYIM_NEKUDOTAYIM 14460)) 6316 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14358) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6317 (("%" 14359) ("*" 14360) ("+" 14361) ("-" 14362) ("." 14363) ("/" 14364) ("<" 14365) (">" 14366) ("?" 14367) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 14368) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 14369) (T_BOOLEAN_AND 14370) (T_BOOLEAN_OR 14371) (T_COALESCE 14372) (T_INSTANCEOF 14373) (T_IS_EQUAL 14374) (T_IS_GREATER_OR_EQUAL 14375) (T_IS_IDENTICAL 14376) (T_IS_NOT_EQUAL 14377) (T_IS_NOT_IDENTICAL 14378) (T_IS_SMALLER_OR_EQUAL 14379) (T_LOGICAL_AND 14380) (T_LOGICAL_OR 14381) (T_LOGICAL_XOR 14382) (T_POW 14383) (T_SL 14384) (T_SPACESHIP 14385) (T_SR 14386) ("^" 14387) ("|" 14388)) 6318 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14459) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6319 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14458) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6320 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14457) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6321 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14456) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6322 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14455) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6323 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14454) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6324 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14453) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6325 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14452) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6326 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 14447) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 14448) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 6327 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14446) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6328 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14445) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6329 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14444) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6330 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14443) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6331 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14442) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6332 (("$" 14404) ("(" 14405) (T_NAME_FULLY_QUALIFIED 14406) (T_NAME_QUALIFIED 14407) (T_NAME_RELATIVE 14408) (T_STATIC 14409) (T_STRING 14410) (T_VARIABLE 14411) (class_name 14412) (class_name_reference 14413) (name 14414) (new_variable 14415) (simple_variable 14416)) 6333 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14403) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6334 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14402) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6335 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14401) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6336 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14400) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6337 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14399) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6338 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14398) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6339 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14397) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6340 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14396) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6341 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14395) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6342 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14394) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6343 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14393) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6344 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14392) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6345 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14391) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6346 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14390) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6347 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14389) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6348 (("$" 14404) (T_VARIABLE 14411) (simple_variable 14438) ("{" 14439)) 6349 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14436) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6350 ((T_PAAMAYIM_NEKUDOTAYIM 14434)) 6351 ((T_NULLSAFE_OBJECT_OPERATOR 14417) (T_OBJECT_OPERATOR 14418) (T_PAAMAYIM_NEKUDOTAYIM 14419) ("[" 14420) ("{" 14421)) 6352 (("$" 14404) (T_STRING 14427) (T_VARIABLE 14411) (property_name 14433) (simple_variable 14429) ("{" 14430)) 6353 (("$" 14404) (T_STRING 14427) (T_VARIABLE 14411) (property_name 14428) (simple_variable 14429) ("{" 14430)) 6354 (("$" 14404) (T_VARIABLE 14411) (simple_variable 14426)) 6355 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 14424) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 6356 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14422) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6357 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 14423)) 6358 (("]" 14425)) 6359 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14431) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6360 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 14432)) 6361 (("$" 14404) (T_VARIABLE 14411) (simple_variable 14435)) 6362 (("%" 292) (")" 14437) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 6363 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14440) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6364 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 14441)) 6365 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14451) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6366 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 14449) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 6367 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14450) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6368 (("$" 14283) (T_ABSTRACT 14461) (T_ARRAY 14462) (T_AS 14463) (T_BREAK 14464) (T_CALLABLE 14465) (T_CASE 14466) (T_CATCH 14467) (T_CLASS 14468) (T_CLASS_C 14469) (T_CLONE 14470) (T_CONST 14471) (T_CONTINUE 14472) (T_DECLARE 14473) (T_DEFAULT 14474) (T_DIR 14475) (T_DO 14476) (T_ECHO 14477) (T_ELSE 14478) (T_ELSEIF 14479) (T_EMPTY 14480) (T_ENDDECLARE 14481) (T_ENDFOR 14482) (T_ENDFOREACH 14483) (T_ENDIF 14484) (T_ENDSWITCH 14485) (T_ENDWHILE 14486) (T_ENUM 14487) (T_EVAL 14488) (T_EXIT 14489) (T_EXTENDS 14490) (T_FILE 14491) (T_FINAL 14492) (T_FINALLY 14493) (T_FN 14494) (T_FOR 14495) (T_FOREACH 14496) (T_FUNCTION 14497) (T_FUNC_C 14498) (T_GLOBAL 14499) (T_GOTO 14500) (T_IF 14501) (T_IMPLEMENTS 14502) (T_INCLUDE 14503) (T_INCLUDE_ONCE 14504) (T_INSTANCEOF 14505) (T_INSTEADOF 14506) (T_INTERFACE 14507) (T_ISSET 14508) (T_LINE 14509) (T_LIST 14510) (T_LOGICAL_AND 14511) (T_LOGICAL_OR 14512) (T_LOGICAL_XOR 14513) (T_MATCH 14514) (T_METHOD_C 14515) (T_NAMESPACE 14516) (T_NEW 14517) (T_NS_C 14518) (T_PRINT 14519) (T_PRIVATE 14520) (T_PROTECTED 14521) (T_PUBLIC 14522) (T_READONLY 14523) (T_REQUIRE 14524) (T_REQUIRE_ONCE 14525) (T_RETURN 14526) (T_STATIC 14527) (T_STRING 14528) (T_SWITCH 14529) (T_THROW 14530) (T_TRAIT 14531) (T_TRAIT_C 14532) (T_TRY 14533) (T_UNSET 14534) (T_USE 14535) (T_VAR 14536) (T_VARIABLE 14330) (T_WHILE 14537) (T_YIELD 14538) (identifier 14539) (member_name 14540) (reserved_non_modifiers 14541) (semi_reserved 14542) (simple_variable 14543) ("{" 14544)) 6369 (("(" 14547) (argument_list 14548)) 6370 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14545) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6371 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 14546)) 6372 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 14549) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 14550) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 14551) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 6373 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 14554) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 6374 (("," 1469) (possible_comma 14552)) 6375 ((")" 14553)) 6376 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (ampersand 14584) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14585) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6377 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14583) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6378 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14582) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6379 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14581) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6380 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14580) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6381 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14579) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6382 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14578) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6383 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14577) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6384 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14576) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6385 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14575) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6386 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14574) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6387 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14573) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6388 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14572) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6389 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14571) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6390 (("\"" 1509) ("$" 14586) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 14587) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 14588) ("[" 1529) (array_object_dereferenceable 14589) (callable_expr 14590) (callable_variable 14591) (class_constant 1533) (class_name 14592) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 14593) (name 14594) (simple_variable 14595) (static_member 14596) (variable 14597) (variable_class_name 14598)) 6391 (("$" 14586) (T_VARIABLE 14588) (simple_variable 14634) ("{" 14635)) 6392 (("(" 14602) (argument_list 14633)) 6393 ((T_NULLSAFE_OBJECT_OPERATOR 14616) (T_OBJECT_OPERATOR 14617) ("[" 14618) ("{" 14619)) 6394 (("(" 14602) (argument_list 14615)) 6395 ((T_PAAMAYIM_NEKUDOTAYIM 14611)) 6396 (("(" 14602) (argument_list 14610)) 6397 ((T_PAAMAYIM_NEKUDOTAYIM 14599)) 6398 (("$" 14586) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 14588) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 14600) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 14601) ("{" 1627)) 6399 (("(" 14602) (argument_list 14603)) 6400 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 14604) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 14605) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 14606) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 6401 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 14609) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 6402 (("," 1469) (possible_comma 14607)) 6403 ((")" 14608)) 6404 (("$" 14586) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 14588) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 14612) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 14613) ("{" 1643)) 6405 (("(" 14602) (argument_list 14614)) 6406 (("$" 14586) (T_STRING 14624) (T_VARIABLE 14588) (property_name 14631) (simple_variable 14626) ("{" 14627)) 6407 (("$" 14586) (T_STRING 14624) (T_VARIABLE 14588) (property_name 14625) (simple_variable 14626) ("{" 14627)) 6408 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 14622) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 6409 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14620) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6410 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 14621)) 6411 (("]" 14623)) 6412 (("(" 14602) (argument_list 14630)) 6413 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14628) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6414 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 14629)) 6415 (("(" 14602) (argument_list 14632)) 6416 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14636) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6417 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 14637)) 6418 ((backup_doc_comment 14640)) 6419 (("(" 14641)) 6420 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 14642)) 6421 ((")" 14643)) 6422 ((T_USE 159) (lexical_vars 14644)) 6423 ((":" 161) (return_type 14645)) 6424 ((backup_fn_flags 14646)) 6425 (("{" 14647)) 6426 ((inner_statement_list 14648)) 6427 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 14649) ("~" 125)) 6428 ((backup_fn_flags 14650)) 6429 ((backup_doc_comment 14652)) 6430 (("(" 14653)) 6431 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 14654)) 6432 ((")" 14655)) 6433 ((":" 2241) (return_type 14656)) 6434 ((T_DOUBLE_ARROW 14657)) 6435 ((backup_fn_flags 14658)) 6436 ((backup_lex_pos 14659)) 6437 (("!" 13600) ("\"" 13601) ("$" 13602) ("(" 13603) ("+" 13604) ("-" 13605) ("@" 13606) (T_ARRAY 13607) (T_ARRAY_CAST 13608) (T_ATTRIBUTE 126) (T_BOOL_CAST 13609) (T_CLASS_C 13610) (T_CLONE 13611) (T_CONSTANT_ENCAPSED_STRING 13612) (T_DEC 13613) (T_DIR 13614) (T_DNUMBER 13615) (T_DOUBLE_CAST 13616) (T_EMPTY 13617) (T_EVAL 13618) (T_EXIT 13619) (T_FILE 13620) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 13621) (T_INC 13622) (T_INCLUDE 13623) (T_INCLUDE_ONCE 13624) (T_INT_CAST 13625) (T_ISSET 13626) (T_LINE 13627) (T_LIST 13628) (T_LNUMBER 13629) (T_MATCH 13630) (T_METHOD_C 13631) (T_NAME_FULLY_QUALIFIED 13632) (T_NAME_QUALIFIED 13633) (T_NAME_RELATIVE 13634) (T_NEW 13635) (T_NS_C 13636) (T_OBJECT_CAST 13637) (T_PRINT 13638) (T_READONLY 13639) (T_REQUIRE 13640) (T_REQUIRE_ONCE 13641) (T_START_HEREDOC 13642) (T_STATIC 13643) (T_STRING 13644) (T_STRING_CAST 13645) (T_THROW 13646) (T_TRAIT_C 13647) (T_UNSET_CAST 13648) (T_VARIABLE 13649) (T_YIELD 13650) (T_YIELD_FROM 13651) ("[" 13652) ("`" 13653) (array_object_dereferenceable 13654) (attribute 131) (attributes 13655) (callable_expr 13656) (callable_variable 13657) (class_constant 13658) (class_name 13659) (constant 13660) (dereferenceable_scalar 13661) (expr 14660) (fn 13663) (fully_dereferenceable 104) #'13664 (function_call 13665) (inline_function 13666) (internal_functions_in_yacc 13667) (match 13668) (name 13669) (new_expr 13670) (scalar 13671) (simple_variable 13672) (static_member 13673) (variable 13674) (variable_class_name 13675) ("~" 13676)) 6438 (("%" 13678) ("*" 13679) ("+" 13680) ("-" 13681) ("." 13682) ("/" 13683) ("<" 13684) (">" 13685) ("?" 13686) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 13687) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 13688) (T_BOOLEAN_AND 13689) (T_BOOLEAN_OR 13690) (T_COALESCE 13691) (T_INSTANCEOF 13692) (T_IS_EQUAL 13693) (T_IS_GREATER_OR_EQUAL 13694) (T_IS_IDENTICAL 13695) (T_IS_NOT_EQUAL 13696) (T_IS_NOT_IDENTICAL 13697) (T_IS_SMALLER_OR_EQUAL 13698) (T_LOGICAL_AND 13699) (T_LOGICAL_OR 13700) (T_LOGICAL_XOR 13701) (T_POW 13702) (T_SL 13703) (T_SPACESHIP 13704) (T_SR 13705) ("^" 13706) (backup_fn_flags 14661) ("|" 13707)) 6439 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14663) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6440 (("$" 14283) (T_ABSTRACT 14461) (T_ARRAY 14462) (T_AS 14463) (T_BREAK 14464) (T_CALLABLE 14465) (T_CASE 14466) (T_CATCH 14467) (T_CLASS 14468) (T_CLASS_C 14469) (T_CLONE 14470) (T_CONST 14471) (T_CONTINUE 14472) (T_DECLARE 14473) (T_DEFAULT 14474) (T_DIR 14475) (T_DO 14476) (T_ECHO 14477) (T_ELSE 14478) (T_ELSEIF 14479) (T_EMPTY 14480) (T_ENDDECLARE 14481) (T_ENDFOR 14482) (T_ENDFOREACH 14483) (T_ENDIF 14484) (T_ENDSWITCH 14485) (T_ENDWHILE 14486) (T_ENUM 14487) (T_EVAL 14488) (T_EXIT 14489) (T_EXTENDS 14490) (T_FILE 14491) (T_FINAL 14492) (T_FINALLY 14493) (T_FN 14494) (T_FOR 14495) (T_FOREACH 14496) (T_FUNCTION 14497) (T_FUNC_C 14498) (T_GLOBAL 14499) (T_GOTO 14500) (T_IF 14501) (T_IMPLEMENTS 14502) (T_INCLUDE 14503) (T_INCLUDE_ONCE 14504) (T_INSTANCEOF 14505) (T_INSTEADOF 14506) (T_INTERFACE 14507) (T_ISSET 14508) (T_LINE 14509) (T_LIST 14510) (T_LOGICAL_AND 14511) (T_LOGICAL_OR 14512) (T_LOGICAL_XOR 14513) (T_MATCH 14514) (T_METHOD_C 14515) (T_NAMESPACE 14516) (T_NEW 14517) (T_NS_C 14518) (T_PRINT 14519) (T_PRIVATE 14520) (T_PROTECTED 14521) (T_PUBLIC 14522) (T_READONLY 14523) (T_REQUIRE 14524) (T_REQUIRE_ONCE 14525) (T_RETURN 14526) (T_STATIC 14527) (T_STRING 14528) (T_SWITCH 14529) (T_THROW 14530) (T_TRAIT 14531) (T_TRAIT_C 14532) (T_TRY 14533) (T_UNSET 14534) (T_USE 14535) (T_VAR 14536) (T_VARIABLE 14330) (T_WHILE 14537) (T_YIELD 14538) (identifier 14665) (member_name 14666) (reserved_non_modifiers 14541) (semi_reserved 14542) (simple_variable 14667) ("{" 14668)) 6441 (("(" 14547) (argument_list 14671)) 6442 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14669) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6443 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 14670)) 6444 ((T_FN 35) (T_FUNCTION 127) (fn 14344) #'14345 (inline_function 14675)) 6445 (("$" 14283) (T_STRING 14684) (T_VARIABLE 14330) (property_name 14691) (simple_variable 14686) ("{" 14687)) 6446 (("$" 14283) (T_STRING 14684) (T_VARIABLE 14330) (property_name 14685) (simple_variable 14686) ("{" 14687)) 6447 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 14682) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 6448 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14680) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6449 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 14681)) 6450 (("]" 14683)) 6451 (("(" 14547) (argument_list 14690)) 6452 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14688) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6453 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 14689)) 6454 (("(" 14547) (argument_list 14692)) 6455 (("`" 14694)) 6456 (("]" 14696)) 6457 (("=" 14697)) 6458 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14698) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6459 (("%" 14359) ("*" 14360) ("+" 14361) ("-" 14362) ("." 14363) ("/" 14364) ("<" 14365) (">" 14366) ("?" 14367) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 14368) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 14369) (T_BOOLEAN_AND 14370) (T_BOOLEAN_OR 14371) (T_COALESCE 14372) (T_DOUBLE_ARROW 14701) (T_INSTANCEOF 14373) (T_IS_EQUAL 14374) (T_IS_GREATER_OR_EQUAL 14375) (T_IS_IDENTICAL 14376) (T_IS_NOT_EQUAL 14377) (T_IS_NOT_IDENTICAL 14378) (T_IS_SMALLER_OR_EQUAL 14379) (T_LOGICAL_AND 14380) (T_LOGICAL_OR 14381) (T_LOGICAL_XOR 14382) (T_POW 14383) (T_SL 14384) (T_SPACESHIP 14385) (T_SR 14386) ("^" 14387) ("|" 14388)) 6460 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14702) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6461 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 14711) (T_VARIABLE 2900) (encaps_var 2914)) 6462 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 14710) (T_VARIABLE 2900) (encaps_var 2905)) 6463 ((T_CLASS 14731)) 6464 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 14730) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 14718) (attribute 2980) (class_modifier 2945)) 6465 (("(" 14721) (argument_list 14722) (ctor_arguments 14723)) 6466 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 14724) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 14725) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 14726) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 6467 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 14729) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 6468 (("," 1469) (possible_comma 14727)) 6469 ((")" 14728)) 6470 (("(" 2982) (argument_list 2983) (ctor_arguments 14732)) 6471 ((T_EXTENDS 2985) (extends_from 14733)) 6472 ((T_IMPLEMENTS 2987) (implements_list 14734)) 6473 ((backup_doc_comment 14735)) 6474 (("{" 14736)) 6475 ((class_statement_list 14737)) 6476 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 14738)) 6477 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14740) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6478 (("%" 292) (")" 14741) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 6479 (("{" 14742)) 6480 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 14743) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 6481 (("}" 14744)) 6482 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 14746) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 6483 ((")" 14747)) 6484 (("=" 14748)) 6485 (("!" 14281) ("\"" 14282) ("$" 14283) ("(" 14284) ("+" 14285) ("-" 14286) ("@" 14287) (T_ARRAY 14288) (T_ARRAY_CAST 14289) (T_ATTRIBUTE 126) (T_BOOL_CAST 14290) (T_CLASS_C 14291) (T_CLONE 14292) (T_CONSTANT_ENCAPSED_STRING 14293) (T_DEC 14294) (T_DIR 14295) (T_DNUMBER 14296) (T_DOUBLE_CAST 14297) (T_EMPTY 14298) (T_EVAL 14299) (T_EXIT 14300) (T_FILE 14301) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 14302) (T_INC 14303) (T_INCLUDE 14304) (T_INCLUDE_ONCE 14305) (T_INT_CAST 14306) (T_ISSET 14307) (T_LINE 14308) (T_LIST 14309) (T_LNUMBER 14310) (T_MATCH 14311) (T_METHOD_C 14312) (T_NAME_FULLY_QUALIFIED 14313) (T_NAME_QUALIFIED 14314) (T_NAME_RELATIVE 14315) (T_NEW 14316) (T_NS_C 14317) (T_OBJECT_CAST 14318) (T_PRINT 14319) (T_READONLY 14320) (T_REQUIRE 14321) (T_REQUIRE_ONCE 14322) (T_START_HEREDOC 14323) (T_STATIC 14324) (T_STRING 14325) (T_STRING_CAST 14326) (T_THROW 14327) (T_TRAIT_C 14328) (T_UNSET_CAST 14329) (T_VARIABLE 14330) (T_YIELD 14331) (T_YIELD_FROM 14332) ("[" 14333) ("`" 14334) (array_object_dereferenceable 14335) (attribute 131) (attributes 14336) (callable_expr 14337) (callable_variable 14338) (class_constant 14339) (class_name 14340) (constant 14341) (dereferenceable_scalar 14342) (expr 14749) (fn 14344) (fully_dereferenceable 104) #'14345 (function_call 14346) (inline_function 14347) (internal_functions_in_yacc 14348) (match 14349) (name 14350) (new_expr 14351) (scalar 14352) (simple_variable 14353) (static_member 14354) (variable 14355) (variable_class_name 14356) ("~" 14357)) 6486 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 14751) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 6487 (("," 5258) (possible_comma 14752)) 6488 ((")" 14753)) 6489 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 14760) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6490 ((")" 14761)) 6491 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14763) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6492 (("%" 292) (")" 14764) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 6493 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14766) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6494 (("%" 292) (")" 14767) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 6495 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 14774) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 6496 ((")" 14775)) 6497 (("%" 292) (")" 14780) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 6498 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14783) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6499 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 14784)) 6500 (("\"" 14786) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 6501 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 14796) (T_VARIABLE 2900) (encaps_var 2914)) 6502 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 14795) (T_VARIABLE 2900) (encaps_var 2905)) 6503 ((T_CLASS 14816)) 6504 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 14815) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 14803) (attribute 2980) (class_modifier 2945)) 6505 (("(" 14806) (argument_list 14807) (ctor_arguments 14808)) 6506 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 14809) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 14810) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 14811) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 6507 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 14814) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 6508 (("," 1469) (possible_comma 14812)) 6509 ((")" 14813)) 6510 (("(" 2982) (argument_list 2983) (ctor_arguments 14817)) 6511 ((T_EXTENDS 2985) (extends_from 14818)) 6512 ((T_IMPLEMENTS 2987) (implements_list 14819)) 6513 ((backup_doc_comment 14820)) 6514 (("{" 14821)) 6515 ((class_statement_list 14822)) 6516 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 14823)) 6517 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14825) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6518 (("%" 292) (")" 14826) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 6519 (("{" 14827)) 6520 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 14828) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 6521 (("}" 14829)) 6522 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 14831) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 6523 ((")" 14832)) 6524 (("=" 14833)) 6525 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14834) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6526 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 14836) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 6527 (("," 5258) (possible_comma 14837)) 6528 ((")" 14838)) 6529 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 14845) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6530 ((")" 14846)) 6531 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14848) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6532 (("%" 292) (")" 14849) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 6533 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14851) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6534 (("%" 292) (")" 14852) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 6535 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 14859) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 6536 ((")" 14860)) 6537 (("%" 292) (")" 14865) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 6538 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14868) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6539 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 14869)) 6540 (("\"" 14871) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 6541 (("]" 14874)) 6542 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14880) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6543 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 14881)) 6544 (("$" 337) (T_VARIABLE 344) (simple_variable 14884)) 6545 (("%" 292) (")" 14886) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 6546 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14889) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6547 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 14890)) 6548 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14900) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6549 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 14898) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 6550 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 14899) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6551 (("$" 216) (T_ABSTRACT 14910) (T_ARRAY 14911) (T_AS 14912) (T_BREAK 14913) (T_CALLABLE 14914) (T_CASE 14915) (T_CATCH 14916) (T_CLASS 14917) (T_CLASS_C 14918) (T_CLONE 14919) (T_CONST 14920) (T_CONTINUE 14921) (T_DECLARE 14922) (T_DEFAULT 14923) (T_DIR 14924) (T_DO 14925) (T_ECHO 14926) (T_ELSE 14927) (T_ELSEIF 14928) (T_EMPTY 14929) (T_ENDDECLARE 14930) (T_ENDFOR 14931) (T_ENDFOREACH 14932) (T_ENDIF 14933) (T_ENDSWITCH 14934) (T_ENDWHILE 14935) (T_ENUM 14936) (T_EVAL 14937) (T_EXIT 14938) (T_EXTENDS 14939) (T_FILE 14940) (T_FINAL 14941) (T_FINALLY 14942) (T_FN 14943) (T_FOR 14944) (T_FOREACH 14945) (T_FUNCTION 14946) (T_FUNC_C 14947) (T_GLOBAL 14948) (T_GOTO 14949) (T_IF 14950) (T_IMPLEMENTS 14951) (T_INCLUDE 14952) (T_INCLUDE_ONCE 14953) (T_INSTANCEOF 14954) (T_INSTEADOF 14955) (T_INTERFACE 14956) (T_ISSET 14957) (T_LINE 14958) (T_LIST 14959) (T_LOGICAL_AND 14960) (T_LOGICAL_OR 14961) (T_LOGICAL_XOR 14962) (T_MATCH 14963) (T_METHOD_C 14964) (T_NAMESPACE 14965) (T_NEW 14966) (T_NS_C 14967) (T_PRINT 14968) (T_PRIVATE 14969) (T_PROTECTED 14970) (T_PUBLIC 14971) (T_READONLY 14972) (T_REQUIRE 14973) (T_REQUIRE_ONCE 14974) (T_RETURN 14975) (T_STATIC 14976) (T_STRING 14977) (T_SWITCH 14978) (T_THROW 14979) (T_TRAIT 14980) (T_TRAIT_C 14981) (T_TRY 14982) (T_UNSET 14983) (T_USE 14984) (T_VAR 14985) (T_VARIABLE 263) (T_WHILE 14986) (T_YIELD 14987) (identifier 14988) (member_name 14989) (reserved_non_modifiers 14990) (semi_reserved 14991) (simple_variable 14992) ("{" 14993)) 6552 (("(" 14996) (argument_list 14997)) 6553 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 14994) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6554 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 14995)) 6555 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 14998) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 14999) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 15000) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 6556 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 15003) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 6557 (("," 1469) (possible_comma 15001)) 6558 ((")" 15002)) 6559 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (ampersand 15033) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 15034) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6560 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 15032) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6561 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 15031) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6562 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 15030) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6563 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 15029) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6564 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 15028) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6565 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 15027) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6566 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 15026) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6567 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 15025) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6568 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 15024) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6569 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 15023) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6570 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 15022) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6571 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 15021) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6572 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 15020) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6573 (("\"" 1509) ("$" 15035) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 15036) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 15037) ("[" 1529) (array_object_dereferenceable 15038) (callable_expr 15039) (callable_variable 15040) (class_constant 1533) (class_name 15041) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 15042) (name 15043) (simple_variable 15044) (static_member 15045) (variable 15046) (variable_class_name 15047)) 6574 (("$" 15035) (T_VARIABLE 15037) (simple_variable 15083) ("{" 15084)) 6575 (("(" 15051) (argument_list 15082)) 6576 ((T_NULLSAFE_OBJECT_OPERATOR 15065) (T_OBJECT_OPERATOR 15066) ("[" 15067) ("{" 15068)) 6577 (("(" 15051) (argument_list 15064)) 6578 ((T_PAAMAYIM_NEKUDOTAYIM 15060)) 6579 (("(" 15051) (argument_list 15059)) 6580 ((T_PAAMAYIM_NEKUDOTAYIM 15048)) 6581 (("$" 15035) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 15037) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 15049) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 15050) ("{" 1627)) 6582 (("(" 15051) (argument_list 15052)) 6583 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 15053) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 15054) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 15055) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 6584 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 15058) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 6585 (("," 1469) (possible_comma 15056)) 6586 ((")" 15057)) 6587 (("$" 15035) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 15037) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 15061) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 15062) ("{" 1643)) 6588 (("(" 15051) (argument_list 15063)) 6589 (("$" 15035) (T_STRING 15073) (T_VARIABLE 15037) (property_name 15080) (simple_variable 15075) ("{" 15076)) 6590 (("$" 15035) (T_STRING 15073) (T_VARIABLE 15037) (property_name 15074) (simple_variable 15075) ("{" 15076)) 6591 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 15071) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 6592 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 15069) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6593 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 15070)) 6594 (("]" 15072)) 6595 (("(" 15051) (argument_list 15079)) 6596 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 15077) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6597 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 15078)) 6598 (("(" 15051) (argument_list 15081)) 6599 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 15085) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6600 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 15086)) 6601 ((backup_doc_comment 15089)) 6602 (("(" 15090)) 6603 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 15091)) 6604 ((")" 15092)) 6605 ((T_USE 159) (lexical_vars 15093)) 6606 ((":" 161) (return_type 15094)) 6607 ((backup_fn_flags 15095)) 6608 (("{" 15096)) 6609 ((inner_statement_list 15097)) 6610 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 15098) ("~" 125)) 6611 ((backup_fn_flags 15099)) 6612 ((backup_doc_comment 15101)) 6613 (("(" 15102)) 6614 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 15103)) 6615 ((")" 15104)) 6616 ((":" 2241) (return_type 15105)) 6617 ((T_DOUBLE_ARROW 15106)) 6618 ((backup_fn_flags 15107)) 6619 ((backup_lex_pos 15108)) 6620 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15171) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6621 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 16170) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6622 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 16168) (encaps_var 5299)) 6623 (("$" 15111) (T_VARIABLE 15158) (simple_variable 16164) ("{" 16165)) 6624 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 16162) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6625 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 16161) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6626 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 16160) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6627 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 16159) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6628 (("(" 16156)) 6629 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 16155) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6630 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 16154) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6631 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 16153) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6632 (("\"" 1509) ("$" 15414) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 15415) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 15416) ("[" 1529) (array_object_dereferenceable 15417) (callable_expr 15418) (callable_variable 15419) (class_constant 1533) (class_name 15420) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 15421) (name 15422) (simple_variable 15423) (static_member 15424) (variable 16152) (variable_class_name 15426)) 6633 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 16151) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6634 (("(" 16148)) 6635 (("(" 16145)) 6636 (("(" 16141) (exit_expr 16142)) 6637 (("\"" 1509) ("$" 15414) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 15415) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 15416) ("[" 1529) (array_object_dereferenceable 15417) (callable_expr 15418) (callable_variable 15419) (class_constant 1533) (class_name 15420) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 15421) (name 15422) (simple_variable 15423) (static_member 15424) (variable 16140) (variable_class_name 15426)) 6638 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 16139) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6639 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 16138) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6640 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 16137) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6641 (("(" 16133)) 6642 (("(" 16128)) 6643 (("(" 16122)) 6644 (("$" 15414) ("(" 16074) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 16075) (T_NAME_QUALIFIED 16076) (T_NAME_RELATIVE 16077) (T_READONLY 2936) (T_STATIC 16078) (T_STRING 16079) (T_VARIABLE 15416) (anonymous_class 16080) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 16081) (attribute 2943) (attributes 16082) (class_modifier 2945) (class_name 16083) (class_name_reference 16084) (name 16085) (new_variable 16086) (simple_variable 16087)) 6645 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 16073) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6646 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 16072) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6647 (("(" 15375) (argument_list 16071)) 6648 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 16070) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6649 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 16069) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6650 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 16064) (T_END_HEREDOC 16065) (T_VARIABLE 2900) (encaps_list 16066) (encaps_var 2902)) 6651 ((T_FN 35) (T_FUNCTION 127) (fn 15172) #'15173 (inline_function 16063)) 6652 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 16062) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6653 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 16061) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6654 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 16060) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6655 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15589) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6656 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15526) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6657 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 15522) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 6658 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 15520) (encaps_list 2805) (encaps_var 2806)) 6659 ((T_NULLSAFE_OBJECT_OPERATOR 15503) (T_OBJECT_OPERATOR 15504) ("[" 15505) ("{" 15506)) 6660 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 15500) (attribute 2728) (fn 15172) #'15173 (inline_function 15501)) 6661 (("(" 15375) (argument_list 15499)) 6662 ((T_PAAMAYIM_NEKUDOTAYIM 15491)) 6663 (("%" 15187) ("*" 15188) ("+" 15189) ("-" 15190) ("." 15191) ("/" 15192) ("<" 15193) (">" 15194) ("?" 15195) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 15196) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 15197) (T_BOOLEAN_AND 15198) (T_BOOLEAN_OR 15199) (T_COALESCE 15200) (T_INSTANCEOF 15201) (T_IS_EQUAL 15202) (T_IS_GREATER_OR_EQUAL 15203) (T_IS_IDENTICAL 15204) (T_IS_NOT_EQUAL 15205) (T_IS_NOT_IDENTICAL 15206) (T_IS_SMALLER_OR_EQUAL 15207) (T_LOGICAL_AND 15208) (T_LOGICAL_OR 15209) (T_LOGICAL_XOR 15210) (T_POW 15211) (T_SL 15212) (T_SPACESHIP 15213) (T_SR 15214) ("^" 15215) (backup_fn_flags 15490) ("|" 15216)) 6664 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 15479)) 6665 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 15467)) 6666 (("(" 15375) (argument_list 15466)) 6667 (("=" 15383) (T_AND_EQUAL 15384) (T_COALESCE_EQUAL 15385) (T_CONCAT_EQUAL 15386) (T_DEC 15387) (T_DIV_EQUAL 15388) (T_INC 15389) (T_MINUS_EQUAL 15390) (T_MOD_EQUAL 15391) (T_MUL_EQUAL 15392) (T_OR_EQUAL 15393) (T_PLUS_EQUAL 15394) (T_POW_EQUAL 15395) (T_SL_EQUAL 15396) (T_SR_EQUAL 15397) (T_XOR_EQUAL 15398)) 6668 ((T_PAAMAYIM_NEKUDOTAYIM 15288)) 6669 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15186) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6670 (("%" 15187) ("*" 15188) ("+" 15189) ("-" 15190) ("." 15191) ("/" 15192) ("<" 15193) (">" 15194) ("?" 15195) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 15196) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 15197) (T_BOOLEAN_AND 15198) (T_BOOLEAN_OR 15199) (T_COALESCE 15200) (T_INSTANCEOF 15201) (T_IS_EQUAL 15202) (T_IS_GREATER_OR_EQUAL 15203) (T_IS_IDENTICAL 15204) (T_IS_NOT_EQUAL 15205) (T_IS_NOT_IDENTICAL 15206) (T_IS_SMALLER_OR_EQUAL 15207) (T_LOGICAL_AND 15208) (T_LOGICAL_OR 15209) (T_LOGICAL_XOR 15210) (T_POW 15211) (T_SL 15212) (T_SPACESHIP 15213) (T_SR 15214) ("^" 15215) ("|" 15216)) 6671 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15287) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6672 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15286) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6673 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15285) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6674 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15284) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6675 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15283) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6676 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15282) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6677 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15281) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6678 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15280) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6679 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 15275) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 15276) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 6680 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15274) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6681 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15273) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6682 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15272) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6683 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15271) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6684 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15270) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6685 (("$" 15232) ("(" 15233) (T_NAME_FULLY_QUALIFIED 15234) (T_NAME_QUALIFIED 15235) (T_NAME_RELATIVE 15236) (T_STATIC 15237) (T_STRING 15238) (T_VARIABLE 15239) (class_name 15240) (class_name_reference 15241) (name 15242) (new_variable 15243) (simple_variable 15244)) 6686 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15231) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6687 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15230) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6688 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15229) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6689 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15228) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6690 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15227) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6691 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15226) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6692 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15225) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6693 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15224) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6694 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15223) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6695 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15222) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6696 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15221) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6697 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15220) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6698 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15219) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6699 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15218) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6700 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15217) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6701 (("$" 15232) (T_VARIABLE 15239) (simple_variable 15266) ("{" 15267)) 6702 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 15264) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6703 ((T_PAAMAYIM_NEKUDOTAYIM 15262)) 6704 ((T_NULLSAFE_OBJECT_OPERATOR 15245) (T_OBJECT_OPERATOR 15246) (T_PAAMAYIM_NEKUDOTAYIM 15247) ("[" 15248) ("{" 15249)) 6705 (("$" 15232) (T_STRING 15255) (T_VARIABLE 15239) (property_name 15261) (simple_variable 15257) ("{" 15258)) 6706 (("$" 15232) (T_STRING 15255) (T_VARIABLE 15239) (property_name 15256) (simple_variable 15257) ("{" 15258)) 6707 (("$" 15232) (T_VARIABLE 15239) (simple_variable 15254)) 6708 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 15252) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 6709 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 15250) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6710 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 15251)) 6711 (("]" 15253)) 6712 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 15259) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6713 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 15260)) 6714 (("$" 15232) (T_VARIABLE 15239) (simple_variable 15263)) 6715 (("%" 292) (")" 15265) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 6716 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 15268) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6717 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 15269)) 6718 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15279) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6719 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 15277) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 6720 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15278) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6721 (("$" 15111) (T_ABSTRACT 15289) (T_ARRAY 15290) (T_AS 15291) (T_BREAK 15292) (T_CALLABLE 15293) (T_CASE 15294) (T_CATCH 15295) (T_CLASS 15296) (T_CLASS_C 15297) (T_CLONE 15298) (T_CONST 15299) (T_CONTINUE 15300) (T_DECLARE 15301) (T_DEFAULT 15302) (T_DIR 15303) (T_DO 15304) (T_ECHO 15305) (T_ELSE 15306) (T_ELSEIF 15307) (T_EMPTY 15308) (T_ENDDECLARE 15309) (T_ENDFOR 15310) (T_ENDFOREACH 15311) (T_ENDIF 15312) (T_ENDSWITCH 15313) (T_ENDWHILE 15314) (T_ENUM 15315) (T_EVAL 15316) (T_EXIT 15317) (T_EXTENDS 15318) (T_FILE 15319) (T_FINAL 15320) (T_FINALLY 15321) (T_FN 15322) (T_FOR 15323) (T_FOREACH 15324) (T_FUNCTION 15325) (T_FUNC_C 15326) (T_GLOBAL 15327) (T_GOTO 15328) (T_IF 15329) (T_IMPLEMENTS 15330) (T_INCLUDE 15331) (T_INCLUDE_ONCE 15332) (T_INSTANCEOF 15333) (T_INSTEADOF 15334) (T_INTERFACE 15335) (T_ISSET 15336) (T_LINE 15337) (T_LIST 15338) (T_LOGICAL_AND 15339) (T_LOGICAL_OR 15340) (T_LOGICAL_XOR 15341) (T_MATCH 15342) (T_METHOD_C 15343) (T_NAMESPACE 15344) (T_NEW 15345) (T_NS_C 15346) (T_PRINT 15347) (T_PRIVATE 15348) (T_PROTECTED 15349) (T_PUBLIC 15350) (T_READONLY 15351) (T_REQUIRE 15352) (T_REQUIRE_ONCE 15353) (T_RETURN 15354) (T_STATIC 15355) (T_STRING 15356) (T_SWITCH 15357) (T_THROW 15358) (T_TRAIT 15359) (T_TRAIT_C 15360) (T_TRY 15361) (T_UNSET 15362) (T_USE 15363) (T_VAR 15364) (T_VARIABLE 15158) (T_WHILE 15365) (T_YIELD 15366) (identifier 15367) (member_name 15368) (reserved_non_modifiers 15369) (semi_reserved 15370) (simple_variable 15371) ("{" 15372)) 6722 (("(" 15375) (argument_list 15376)) 6723 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 15373) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6724 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 15374)) 6725 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 15377) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 15378) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 15379) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 6726 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 15382) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 6727 (("," 1469) (possible_comma 15380)) 6728 ((")" 15381)) 6729 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (ampersand 15412) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15413) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6730 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15411) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6731 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15410) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6732 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15409) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6733 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15408) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6734 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15407) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6735 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15406) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6736 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15405) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6737 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15404) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6738 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15403) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6739 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15402) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6740 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15401) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6741 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15400) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6742 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15399) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6743 (("\"" 1509) ("$" 15414) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 15415) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 15416) ("[" 1529) (array_object_dereferenceable 15417) (callable_expr 15418) (callable_variable 15419) (class_constant 1533) (class_name 15420) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 15421) (name 15422) (simple_variable 15423) (static_member 15424) (variable 15425) (variable_class_name 15426)) 6744 (("$" 15414) (T_VARIABLE 15416) (simple_variable 15462) ("{" 15463)) 6745 (("(" 15430) (argument_list 15461)) 6746 ((T_NULLSAFE_OBJECT_OPERATOR 15444) (T_OBJECT_OPERATOR 15445) ("[" 15446) ("{" 15447)) 6747 (("(" 15430) (argument_list 15443)) 6748 ((T_PAAMAYIM_NEKUDOTAYIM 15439)) 6749 (("(" 15430) (argument_list 15438)) 6750 ((T_PAAMAYIM_NEKUDOTAYIM 15427)) 6751 (("$" 15414) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 15416) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 15428) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 15429) ("{" 1627)) 6752 (("(" 15430) (argument_list 15431)) 6753 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 15432) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 15433) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 15434) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 6754 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 15437) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 6755 (("," 1469) (possible_comma 15435)) 6756 ((")" 15436)) 6757 (("$" 15414) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 15416) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 15440) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 15441) ("{" 1643)) 6758 (("(" 15430) (argument_list 15442)) 6759 (("$" 15414) (T_STRING 15452) (T_VARIABLE 15416) (property_name 15459) (simple_variable 15454) ("{" 15455)) 6760 (("$" 15414) (T_STRING 15452) (T_VARIABLE 15416) (property_name 15453) (simple_variable 15454) ("{" 15455)) 6761 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 15450) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 6762 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 15448) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6763 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 15449)) 6764 (("]" 15451)) 6765 (("(" 15430) (argument_list 15458)) 6766 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 15456) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6767 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 15457)) 6768 (("(" 15430) (argument_list 15460)) 6769 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 15464) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6770 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 15465)) 6771 ((backup_doc_comment 15468)) 6772 (("(" 15469)) 6773 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 15470)) 6774 ((")" 15471)) 6775 ((T_USE 159) (lexical_vars 15472)) 6776 ((":" 161) (return_type 15473)) 6777 ((backup_fn_flags 15474)) 6778 (("{" 15475)) 6779 ((inner_statement_list 15476)) 6780 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 15477) ("~" 125)) 6781 ((backup_fn_flags 15478)) 6782 ((backup_doc_comment 15480)) 6783 (("(" 15481)) 6784 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 15482)) 6785 ((")" 15483)) 6786 ((":" 2241) (return_type 15484)) 6787 ((T_DOUBLE_ARROW 15485)) 6788 ((backup_fn_flags 15486)) 6789 ((backup_lex_pos 15487)) 6790 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15488) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6791 (("%" 15187) ("*" 15188) ("+" 15189) ("-" 15190) ("." 15191) ("/" 15192) ("<" 15193) (">" 15194) ("?" 15195) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 15196) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 15197) (T_BOOLEAN_AND 15198) (T_BOOLEAN_OR 15199) (T_COALESCE 15200) (T_INSTANCEOF 15201) (T_IS_EQUAL 15202) (T_IS_GREATER_OR_EQUAL 15203) (T_IS_IDENTICAL 15204) (T_IS_NOT_EQUAL 15205) (T_IS_NOT_IDENTICAL 15206) (T_IS_SMALLER_OR_EQUAL 15207) (T_LOGICAL_AND 15208) (T_LOGICAL_OR 15209) (T_LOGICAL_XOR 15210) (T_POW 15211) (T_SL 15212) (T_SPACESHIP 15213) (T_SR 15214) ("^" 15215) (backup_fn_flags 15489) ("|" 15216)) 6792 (("$" 15111) (T_ABSTRACT 15289) (T_ARRAY 15290) (T_AS 15291) (T_BREAK 15292) (T_CALLABLE 15293) (T_CASE 15294) (T_CATCH 15295) (T_CLASS 15296) (T_CLASS_C 15297) (T_CLONE 15298) (T_CONST 15299) (T_CONTINUE 15300) (T_DECLARE 15301) (T_DEFAULT 15302) (T_DIR 15303) (T_DO 15304) (T_ECHO 15305) (T_ELSE 15306) (T_ELSEIF 15307) (T_EMPTY 15308) (T_ENDDECLARE 15309) (T_ENDFOR 15310) (T_ENDFOREACH 15311) (T_ENDIF 15312) (T_ENDSWITCH 15313) (T_ENDWHILE 15314) (T_ENUM 15315) (T_EVAL 15316) (T_EXIT 15317) (T_EXTENDS 15318) (T_FILE 15319) (T_FINAL 15320) (T_FINALLY 15321) (T_FN 15322) (T_FOR 15323) (T_FOREACH 15324) (T_FUNCTION 15325) (T_FUNC_C 15326) (T_GLOBAL 15327) (T_GOTO 15328) (T_IF 15329) (T_IMPLEMENTS 15330) (T_INCLUDE 15331) (T_INCLUDE_ONCE 15332) (T_INSTANCEOF 15333) (T_INSTEADOF 15334) (T_INTERFACE 15335) (T_ISSET 15336) (T_LINE 15337) (T_LIST 15338) (T_LOGICAL_AND 15339) (T_LOGICAL_OR 15340) (T_LOGICAL_XOR 15341) (T_MATCH 15342) (T_METHOD_C 15343) (T_NAMESPACE 15344) (T_NEW 15345) (T_NS_C 15346) (T_PRINT 15347) (T_PRIVATE 15348) (T_PROTECTED 15349) (T_PUBLIC 15350) (T_READONLY 15351) (T_REQUIRE 15352) (T_REQUIRE_ONCE 15353) (T_RETURN 15354) (T_STATIC 15355) (T_STRING 15356) (T_SWITCH 15357) (T_THROW 15358) (T_TRAIT 15359) (T_TRAIT_C 15360) (T_TRY 15361) (T_UNSET 15362) (T_USE 15363) (T_VAR 15364) (T_VARIABLE 15158) (T_WHILE 15365) (T_YIELD 15366) (identifier 15492) (member_name 15493) (reserved_non_modifiers 15369) (semi_reserved 15370) (simple_variable 15494) ("{" 15495)) 6793 (("(" 15375) (argument_list 15498)) 6794 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 15496) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6795 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 15497)) 6796 ((T_FN 35) (T_FUNCTION 127) (fn 15172) #'15173 (inline_function 15502)) 6797 (("$" 15111) (T_STRING 15511) (T_VARIABLE 15158) (property_name 15518) (simple_variable 15513) ("{" 15514)) 6798 (("$" 15111) (T_STRING 15511) (T_VARIABLE 15158) (property_name 15512) (simple_variable 15513) ("{" 15514)) 6799 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 15509) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 6800 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 15507) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6801 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 15508)) 6802 (("]" 15510)) 6803 (("(" 15375) (argument_list 15517)) 6804 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 15515) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6805 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 15516)) 6806 (("(" 15375) (argument_list 15519)) 6807 (("`" 15521)) 6808 (("]" 15523)) 6809 (("=" 15524)) 6810 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15525) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6811 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 16059) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6812 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 16057) (encaps_var 5299)) 6813 (("$" 15529) (T_VARIABLE 15576) (simple_variable 16053) ("{" 16054)) 6814 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 16051) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6815 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 16050) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6816 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 16049) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6817 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 16048) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6818 (("(" 16045)) 6819 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 16044) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6820 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 16043) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6821 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 16042) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6822 (("\"" 1509) ("$" 15832) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 15833) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 15834) ("[" 1529) (array_object_dereferenceable 15835) (callable_expr 15836) (callable_variable 15837) (class_constant 1533) (class_name 15838) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 15839) (name 15840) (simple_variable 15841) (static_member 15842) (variable 16041) (variable_class_name 15844)) 6823 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 16040) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6824 (("(" 16037)) 6825 (("(" 16034)) 6826 (("(" 16030) (exit_expr 16031)) 6827 (("\"" 1509) ("$" 15832) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 15833) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 15834) ("[" 1529) (array_object_dereferenceable 15835) (callable_expr 15836) (callable_variable 15837) (class_constant 1533) (class_name 15838) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 15839) (name 15840) (simple_variable 15841) (static_member 15842) (variable 16029) (variable_class_name 15844)) 6828 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 16028) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6829 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 16027) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6830 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 16026) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6831 (("(" 16022)) 6832 (("(" 16017)) 6833 (("(" 16011)) 6834 (("$" 15832) ("(" 15963) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 15964) (T_NAME_QUALIFIED 15965) (T_NAME_RELATIVE 15966) (T_READONLY 2936) (T_STATIC 15967) (T_STRING 15968) (T_VARIABLE 15834) (anonymous_class 15969) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 15970) (attribute 2943) (attributes 15971) (class_modifier 2945) (class_name 15972) (class_name_reference 15973) (name 15974) (new_variable 15975) (simple_variable 15976)) 6835 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15962) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6836 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15961) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6837 (("(" 15793) (argument_list 15960)) 6838 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15959) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6839 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15958) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6840 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 15953) (T_END_HEREDOC 15954) (T_VARIABLE 2900) (encaps_list 15955) (encaps_var 2902)) 6841 ((T_FN 35) (T_FUNCTION 127) (fn 15590) #'15591 (inline_function 15952)) 6842 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15951) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6843 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15950) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6844 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15949) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6845 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15946) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6846 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15945) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6847 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 15941) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 6848 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 15939) (encaps_list 2805) (encaps_var 2806)) 6849 ((T_NULLSAFE_OBJECT_OPERATOR 15922) (T_OBJECT_OPERATOR 15923) ("[" 15924) ("{" 15925)) 6850 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 15919) (attribute 2728) (fn 15590) #'15591 (inline_function 15920)) 6851 (("(" 15793) (argument_list 15918)) 6852 ((T_PAAMAYIM_NEKUDOTAYIM 15910)) 6853 (("%" 15605) ("*" 15606) ("+" 15607) ("-" 15608) ("." 15609) ("/" 15610) ("<" 15611) (">" 15612) ("?" 15613) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 15614) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 15615) (T_BOOLEAN_AND 15616) (T_BOOLEAN_OR 15617) (T_COALESCE 15618) (T_DOUBLE_ARROW 15908) (T_INSTANCEOF 15619) (T_IS_EQUAL 15620) (T_IS_GREATER_OR_EQUAL 15621) (T_IS_IDENTICAL 15622) (T_IS_NOT_EQUAL 15623) (T_IS_NOT_IDENTICAL 15624) (T_IS_SMALLER_OR_EQUAL 15625) (T_LOGICAL_AND 15626) (T_LOGICAL_OR 15627) (T_LOGICAL_XOR 15628) (T_POW 15629) (T_SL 15630) (T_SPACESHIP 15631) (T_SR 15632) ("^" 15633) ("|" 15634)) 6854 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 15897)) 6855 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 15885)) 6856 (("(" 15793) (argument_list 15884)) 6857 (("=" 15801) (T_AND_EQUAL 15802) (T_COALESCE_EQUAL 15803) (T_CONCAT_EQUAL 15804) (T_DEC 15805) (T_DIV_EQUAL 15806) (T_INC 15807) (T_MINUS_EQUAL 15808) (T_MOD_EQUAL 15809) (T_MUL_EQUAL 15810) (T_OR_EQUAL 15811) (T_PLUS_EQUAL 15812) (T_POW_EQUAL 15813) (T_SL_EQUAL 15814) (T_SR_EQUAL 15815) (T_XOR_EQUAL 15816)) 6858 ((T_PAAMAYIM_NEKUDOTAYIM 15706)) 6859 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15604) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6860 (("%" 15605) ("*" 15606) ("+" 15607) ("-" 15608) ("." 15609) ("/" 15610) ("<" 15611) (">" 15612) ("?" 15613) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 15614) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 15615) (T_BOOLEAN_AND 15616) (T_BOOLEAN_OR 15617) (T_COALESCE 15618) (T_INSTANCEOF 15619) (T_IS_EQUAL 15620) (T_IS_GREATER_OR_EQUAL 15621) (T_IS_IDENTICAL 15622) (T_IS_NOT_EQUAL 15623) (T_IS_NOT_IDENTICAL 15624) (T_IS_SMALLER_OR_EQUAL 15625) (T_LOGICAL_AND 15626) (T_LOGICAL_OR 15627) (T_LOGICAL_XOR 15628) (T_POW 15629) (T_SL 15630) (T_SPACESHIP 15631) (T_SR 15632) ("^" 15633) ("|" 15634)) 6861 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15705) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6862 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15704) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6863 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15703) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6864 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15702) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6865 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15701) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6866 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15700) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6867 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15699) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6868 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15698) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6869 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 15693) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 15694) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 6870 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15692) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6871 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15691) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6872 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15690) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6873 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15689) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6874 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15688) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6875 (("$" 15650) ("(" 15651) (T_NAME_FULLY_QUALIFIED 15652) (T_NAME_QUALIFIED 15653) (T_NAME_RELATIVE 15654) (T_STATIC 15655) (T_STRING 15656) (T_VARIABLE 15657) (class_name 15658) (class_name_reference 15659) (name 15660) (new_variable 15661) (simple_variable 15662)) 6876 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15649) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6877 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15648) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6878 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15647) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6879 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15646) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6880 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15645) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6881 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15644) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6882 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15643) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6883 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15642) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6884 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15641) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6885 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15640) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6886 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15639) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6887 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15638) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6888 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15637) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6889 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15636) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6890 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15635) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6891 (("$" 15650) (T_VARIABLE 15657) (simple_variable 15684) ("{" 15685)) 6892 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 15682) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 6893 ((T_PAAMAYIM_NEKUDOTAYIM 15680)) 6894 ((T_NULLSAFE_OBJECT_OPERATOR 15663) (T_OBJECT_OPERATOR 15664) (T_PAAMAYIM_NEKUDOTAYIM 15665) ("[" 15666) ("{" 15667)) 6895 (("$" 15650) (T_STRING 15673) (T_VARIABLE 15657) (property_name 15679) (simple_variable 15675) ("{" 15676)) 6896 (("$" 15650) (T_STRING 15673) (T_VARIABLE 15657) (property_name 15674) (simple_variable 15675) ("{" 15676)) 6897 (("$" 15650) (T_VARIABLE 15657) (simple_variable 15672)) 6898 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 15670) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 6899 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 15668) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6900 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 15669)) 6901 (("]" 15671)) 6902 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 15677) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6903 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 15678)) 6904 (("$" 15650) (T_VARIABLE 15657) (simple_variable 15681)) 6905 (("%" 292) (")" 15683) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 6906 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 15686) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6907 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 15687)) 6908 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15697) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6909 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 15695) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 6910 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15696) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6911 (("$" 15529) (T_ABSTRACT 15707) (T_ARRAY 15708) (T_AS 15709) (T_BREAK 15710) (T_CALLABLE 15711) (T_CASE 15712) (T_CATCH 15713) (T_CLASS 15714) (T_CLASS_C 15715) (T_CLONE 15716) (T_CONST 15717) (T_CONTINUE 15718) (T_DECLARE 15719) (T_DEFAULT 15720) (T_DIR 15721) (T_DO 15722) (T_ECHO 15723) (T_ELSE 15724) (T_ELSEIF 15725) (T_EMPTY 15726) (T_ENDDECLARE 15727) (T_ENDFOR 15728) (T_ENDFOREACH 15729) (T_ENDIF 15730) (T_ENDSWITCH 15731) (T_ENDWHILE 15732) (T_ENUM 15733) (T_EVAL 15734) (T_EXIT 15735) (T_EXTENDS 15736) (T_FILE 15737) (T_FINAL 15738) (T_FINALLY 15739) (T_FN 15740) (T_FOR 15741) (T_FOREACH 15742) (T_FUNCTION 15743) (T_FUNC_C 15744) (T_GLOBAL 15745) (T_GOTO 15746) (T_IF 15747) (T_IMPLEMENTS 15748) (T_INCLUDE 15749) (T_INCLUDE_ONCE 15750) (T_INSTANCEOF 15751) (T_INSTEADOF 15752) (T_INTERFACE 15753) (T_ISSET 15754) (T_LINE 15755) (T_LIST 15756) (T_LOGICAL_AND 15757) (T_LOGICAL_OR 15758) (T_LOGICAL_XOR 15759) (T_MATCH 15760) (T_METHOD_C 15761) (T_NAMESPACE 15762) (T_NEW 15763) (T_NS_C 15764) (T_PRINT 15765) (T_PRIVATE 15766) (T_PROTECTED 15767) (T_PUBLIC 15768) (T_READONLY 15769) (T_REQUIRE 15770) (T_REQUIRE_ONCE 15771) (T_RETURN 15772) (T_STATIC 15773) (T_STRING 15774) (T_SWITCH 15775) (T_THROW 15776) (T_TRAIT 15777) (T_TRAIT_C 15778) (T_TRY 15779) (T_UNSET 15780) (T_USE 15781) (T_VAR 15782) (T_VARIABLE 15576) (T_WHILE 15783) (T_YIELD 15784) (identifier 15785) (member_name 15786) (reserved_non_modifiers 15787) (semi_reserved 15788) (simple_variable 15789) ("{" 15790)) 6912 (("(" 15793) (argument_list 15794)) 6913 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 15791) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6914 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 15792)) 6915 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 15795) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 15796) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 15797) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 6916 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 15800) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 6917 (("," 1469) (possible_comma 15798)) 6918 ((")" 15799)) 6919 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (ampersand 15830) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15831) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6920 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15829) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6921 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15828) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6922 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15827) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6923 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15826) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6924 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15825) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6925 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15824) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6926 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15823) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6927 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15822) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6928 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15821) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6929 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15820) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6930 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15819) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6931 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15818) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6932 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15817) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6933 (("\"" 1509) ("$" 15832) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 15833) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 15834) ("[" 1529) (array_object_dereferenceable 15835) (callable_expr 15836) (callable_variable 15837) (class_constant 1533) (class_name 15838) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 15839) (name 15840) (simple_variable 15841) (static_member 15842) (variable 15843) (variable_class_name 15844)) 6934 (("$" 15832) (T_VARIABLE 15834) (simple_variable 15880) ("{" 15881)) 6935 (("(" 15848) (argument_list 15879)) 6936 ((T_NULLSAFE_OBJECT_OPERATOR 15862) (T_OBJECT_OPERATOR 15863) ("[" 15864) ("{" 15865)) 6937 (("(" 15848) (argument_list 15861)) 6938 ((T_PAAMAYIM_NEKUDOTAYIM 15857)) 6939 (("(" 15848) (argument_list 15856)) 6940 ((T_PAAMAYIM_NEKUDOTAYIM 15845)) 6941 (("$" 15832) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 15834) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 15846) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 15847) ("{" 1627)) 6942 (("(" 15848) (argument_list 15849)) 6943 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 15850) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 15851) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 15852) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 6944 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 15855) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 6945 (("," 1469) (possible_comma 15853)) 6946 ((")" 15854)) 6947 (("$" 15832) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 15834) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 15858) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 15859) ("{" 1643)) 6948 (("(" 15848) (argument_list 15860)) 6949 (("$" 15832) (T_STRING 15870) (T_VARIABLE 15834) (property_name 15877) (simple_variable 15872) ("{" 15873)) 6950 (("$" 15832) (T_STRING 15870) (T_VARIABLE 15834) (property_name 15871) (simple_variable 15872) ("{" 15873)) 6951 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 15868) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 6952 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 15866) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6953 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 15867)) 6954 (("]" 15869)) 6955 (("(" 15848) (argument_list 15876)) 6956 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 15874) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6957 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 15875)) 6958 (("(" 15848) (argument_list 15878)) 6959 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 15882) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6960 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 15883)) 6961 ((backup_doc_comment 15886)) 6962 (("(" 15887)) 6963 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 15888)) 6964 ((")" 15889)) 6965 ((T_USE 159) (lexical_vars 15890)) 6966 ((":" 161) (return_type 15891)) 6967 ((backup_fn_flags 15892)) 6968 (("{" 15893)) 6969 ((inner_statement_list 15894)) 6970 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 15895) ("~" 125)) 6971 ((backup_fn_flags 15896)) 6972 ((backup_doc_comment 15898)) 6973 (("(" 15899)) 6974 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 15900)) 6975 ((")" 15901)) 6976 ((":" 2241) (return_type 15902)) 6977 ((T_DOUBLE_ARROW 15903)) 6978 ((backup_fn_flags 15904)) 6979 ((backup_lex_pos 15905)) 6980 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15906) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 6981 (("%" 15605) ("*" 15606) ("+" 15607) ("-" 15608) ("." 15609) ("/" 15610) ("<" 15611) (">" 15612) ("?" 15613) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 15614) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 15615) (T_BOOLEAN_AND 15616) (T_BOOLEAN_OR 15617) (T_COALESCE 15618) (T_INSTANCEOF 15619) (T_IS_EQUAL 15620) (T_IS_GREATER_OR_EQUAL 15621) (T_IS_IDENTICAL 15622) (T_IS_NOT_EQUAL 15623) (T_IS_NOT_IDENTICAL 15624) (T_IS_SMALLER_OR_EQUAL 15625) (T_LOGICAL_AND 15626) (T_LOGICAL_OR 15627) (T_LOGICAL_XOR 15628) (T_POW 15629) (T_SL 15630) (T_SPACESHIP 15631) (T_SR 15632) ("^" 15633) (backup_fn_flags 15907) ("|" 15634)) 6982 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 15909) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 6983 (("$" 15529) (T_ABSTRACT 15707) (T_ARRAY 15708) (T_AS 15709) (T_BREAK 15710) (T_CALLABLE 15711) (T_CASE 15712) (T_CATCH 15713) (T_CLASS 15714) (T_CLASS_C 15715) (T_CLONE 15716) (T_CONST 15717) (T_CONTINUE 15718) (T_DECLARE 15719) (T_DEFAULT 15720) (T_DIR 15721) (T_DO 15722) (T_ECHO 15723) (T_ELSE 15724) (T_ELSEIF 15725) (T_EMPTY 15726) (T_ENDDECLARE 15727) (T_ENDFOR 15728) (T_ENDFOREACH 15729) (T_ENDIF 15730) (T_ENDSWITCH 15731) (T_ENDWHILE 15732) (T_ENUM 15733) (T_EVAL 15734) (T_EXIT 15735) (T_EXTENDS 15736) (T_FILE 15737) (T_FINAL 15738) (T_FINALLY 15739) (T_FN 15740) (T_FOR 15741) (T_FOREACH 15742) (T_FUNCTION 15743) (T_FUNC_C 15744) (T_GLOBAL 15745) (T_GOTO 15746) (T_IF 15747) (T_IMPLEMENTS 15748) (T_INCLUDE 15749) (T_INCLUDE_ONCE 15750) (T_INSTANCEOF 15751) (T_INSTEADOF 15752) (T_INTERFACE 15753) (T_ISSET 15754) (T_LINE 15755) (T_LIST 15756) (T_LOGICAL_AND 15757) (T_LOGICAL_OR 15758) (T_LOGICAL_XOR 15759) (T_MATCH 15760) (T_METHOD_C 15761) (T_NAMESPACE 15762) (T_NEW 15763) (T_NS_C 15764) (T_PRINT 15765) (T_PRIVATE 15766) (T_PROTECTED 15767) (T_PUBLIC 15768) (T_READONLY 15769) (T_REQUIRE 15770) (T_REQUIRE_ONCE 15771) (T_RETURN 15772) (T_STATIC 15773) (T_STRING 15774) (T_SWITCH 15775) (T_THROW 15776) (T_TRAIT 15777) (T_TRAIT_C 15778) (T_TRY 15779) (T_UNSET 15780) (T_USE 15781) (T_VAR 15782) (T_VARIABLE 15576) (T_WHILE 15783) (T_YIELD 15784) (identifier 15911) (member_name 15912) (reserved_non_modifiers 15787) (semi_reserved 15788) (simple_variable 15913) ("{" 15914)) 6984 (("(" 15793) (argument_list 15917)) 6985 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 15915) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6986 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 15916)) 6987 ((T_FN 35) (T_FUNCTION 127) (fn 15590) #'15591 (inline_function 15921)) 6988 (("$" 15529) (T_STRING 15930) (T_VARIABLE 15576) (property_name 15937) (simple_variable 15932) ("{" 15933)) 6989 (("$" 15529) (T_STRING 15930) (T_VARIABLE 15576) (property_name 15931) (simple_variable 15932) ("{" 15933)) 6990 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 15928) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 6991 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 15926) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6992 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 15927)) 6993 (("]" 15929)) 6994 (("(" 15793) (argument_list 15936)) 6995 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 15934) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 6996 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 15935)) 6997 (("(" 15793) (argument_list 15938)) 6998 (("`" 15940)) 6999 (("]" 15942)) 7000 (("=" 15943)) 7001 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15944) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 7002 (("%" 15605) ("*" 15606) ("+" 15607) ("-" 15608) ("." 15609) ("/" 15610) ("<" 15611) (">" 15612) ("?" 15613) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 15614) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 15615) (T_BOOLEAN_AND 15616) (T_BOOLEAN_OR 15617) (T_COALESCE 15618) (T_DOUBLE_ARROW 15947) (T_INSTANCEOF 15619) (T_IS_EQUAL 15620) (T_IS_GREATER_OR_EQUAL 15621) (T_IS_IDENTICAL 15622) (T_IS_NOT_EQUAL 15623) (T_IS_NOT_IDENTICAL 15624) (T_IS_SMALLER_OR_EQUAL 15625) (T_LOGICAL_AND 15626) (T_LOGICAL_OR 15627) (T_LOGICAL_XOR 15628) (T_POW 15629) (T_SL 15630) (T_SPACESHIP 15631) (T_SR 15632) ("^" 15633) ("|" 15634)) 7003 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 15948) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 7004 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 15957) (T_VARIABLE 2900) (encaps_var 2914)) 7005 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 15956) (T_VARIABLE 2900) (encaps_var 2905)) 7006 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 16009) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 7007 ((T_CLASS 16001)) 7008 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 16000) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 15970) (attribute 2980) (class_modifier 2945)) 7009 ((T_PAAMAYIM_NEKUDOTAYIM 15998)) 7010 (("(" 15989) (argument_list 15990) (ctor_arguments 15991)) 7011 ((T_NULLSAFE_OBJECT_OPERATOR 15977) (T_OBJECT_OPERATOR 15978) (T_PAAMAYIM_NEKUDOTAYIM 15979) ("[" 15980) ("{" 15981)) 7012 (("$" 15832) (T_STRING 15870) (T_VARIABLE 15834) (property_name 15988) (simple_variable 15872) ("{" 15873)) 7013 (("$" 15832) (T_STRING 15870) (T_VARIABLE 15834) (property_name 15987) (simple_variable 15872) ("{" 15873)) 7014 (("$" 15832) (T_VARIABLE 15834) (simple_variable 15986)) 7015 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 15984) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 7016 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 15982) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 7017 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 15983)) 7018 (("]" 15985)) 7019 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 15992) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 15993) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 15994) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 7020 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 15997) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 7021 (("," 1469) (possible_comma 15995)) 7022 ((")" 15996)) 7023 (("$" 15832) (T_VARIABLE 15834) (simple_variable 15999)) 7024 (("(" 2982) (argument_list 2983) (ctor_arguments 16002)) 7025 ((T_EXTENDS 2985) (extends_from 16003)) 7026 ((T_IMPLEMENTS 2987) (implements_list 16004)) 7027 ((backup_doc_comment 16005)) 7028 (("{" 16006)) 7029 ((class_statement_list 16007)) 7030 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 16008)) 7031 (("%" 292) (")" 16010) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 7032 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 16012) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 7033 (("%" 292) (")" 16013) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 7034 (("{" 16014)) 7035 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 16015) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 7036 (("}" 16016)) 7037 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 16018) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 7038 ((")" 16019)) 7039 (("=" 16020)) 7040 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 16021) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 7041 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 16023) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 7042 (("," 5258) (possible_comma 16024)) 7043 ((")" 16025)) 7044 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 16032) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 7045 ((")" 16033)) 7046 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 16035) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 7047 (("%" 292) (")" 16036) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 7048 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 16038) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 7049 (("%" 292) (")" 16039) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 7050 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 16046) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 7051 ((")" 16047)) 7052 (("%" 292) (")" 16052) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 7053 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 16055) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 7054 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 16056)) 7055 (("\"" 16058) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 7056 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 16068) (T_VARIABLE 2900) (encaps_var 2914)) 7057 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 16067) (T_VARIABLE 2900) (encaps_var 2905)) 7058 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 16120) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 7059 ((T_CLASS 16112)) 7060 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 16111) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 16081) (attribute 2980) (class_modifier 2945)) 7061 ((T_PAAMAYIM_NEKUDOTAYIM 16109)) 7062 (("(" 16100) (argument_list 16101) (ctor_arguments 16102)) 7063 ((T_NULLSAFE_OBJECT_OPERATOR 16088) (T_OBJECT_OPERATOR 16089) (T_PAAMAYIM_NEKUDOTAYIM 16090) ("[" 16091) ("{" 16092)) 7064 (("$" 15414) (T_STRING 15452) (T_VARIABLE 15416) (property_name 16099) (simple_variable 15454) ("{" 15455)) 7065 (("$" 15414) (T_STRING 15452) (T_VARIABLE 15416) (property_name 16098) (simple_variable 15454) ("{" 15455)) 7066 (("$" 15414) (T_VARIABLE 15416) (simple_variable 16097)) 7067 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 16095) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 7068 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 16093) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 7069 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 16094)) 7070 (("]" 16096)) 7071 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 16103) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 16104) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 16105) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 7072 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 16108) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 7073 (("," 1469) (possible_comma 16106)) 7074 ((")" 16107)) 7075 (("$" 15414) (T_VARIABLE 15416) (simple_variable 16110)) 7076 (("(" 2982) (argument_list 2983) (ctor_arguments 16113)) 7077 ((T_EXTENDS 2985) (extends_from 16114)) 7078 ((T_IMPLEMENTS 2987) (implements_list 16115)) 7079 ((backup_doc_comment 16116)) 7080 (("{" 16117)) 7081 ((class_statement_list 16118)) 7082 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 16119)) 7083 (("%" 292) (")" 16121) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 7084 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 16123) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 7085 (("%" 292) (")" 16124) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 7086 (("{" 16125)) 7087 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 16126) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 7088 (("}" 16127)) 7089 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 16129) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 7090 ((")" 16130)) 7091 (("=" 16131)) 7092 (("!" 15109) ("\"" 15110) ("$" 15111) ("(" 15112) ("+" 15113) ("-" 15114) ("@" 15115) (T_ARRAY 15116) (T_ARRAY_CAST 15117) (T_ATTRIBUTE 126) (T_BOOL_CAST 15118) (T_CLASS_C 15119) (T_CLONE 15120) (T_CONSTANT_ENCAPSED_STRING 15121) (T_DEC 15122) (T_DIR 15123) (T_DNUMBER 15124) (T_DOUBLE_CAST 15125) (T_EMPTY 15126) (T_EVAL 15127) (T_EXIT 15128) (T_FILE 15129) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15130) (T_INC 15131) (T_INCLUDE 15132) (T_INCLUDE_ONCE 15133) (T_INT_CAST 15134) (T_ISSET 15135) (T_LINE 15136) (T_LIST 15137) (T_LNUMBER 15138) (T_MATCH 15139) (T_METHOD_C 15140) (T_NAME_FULLY_QUALIFIED 15141) (T_NAME_QUALIFIED 15142) (T_NAME_RELATIVE 15143) (T_NEW 15144) (T_NS_C 15145) (T_OBJECT_CAST 15146) (T_PRINT 15147) (T_READONLY 15148) (T_REQUIRE 15149) (T_REQUIRE_ONCE 15150) (T_START_HEREDOC 15151) (T_STATIC 15152) (T_STRING 15153) (T_STRING_CAST 15154) (T_THROW 15155) (T_TRAIT_C 15156) (T_UNSET_CAST 15157) (T_VARIABLE 15158) (T_YIELD 15159) (T_YIELD_FROM 15160) ("[" 15161) ("`" 15162) (array_object_dereferenceable 15163) (attribute 131) (attributes 15164) (callable_expr 15165) (callable_variable 15166) (class_constant 15167) (class_name 15168) (constant 15169) (dereferenceable_scalar 15170) (expr 16132) (fn 15172) (fully_dereferenceable 104) #'15173 (function_call 15174) (inline_function 15175) (internal_functions_in_yacc 15176) (match 15177) (name 15178) (new_expr 15179) (scalar 15180) (simple_variable 15181) (static_member 15182) (variable 15183) (variable_class_name 15184) ("~" 15185)) 7093 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 16134) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 7094 (("," 5258) (possible_comma 16135)) 7095 ((")" 16136)) 7096 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 16143) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 7097 ((")" 16144)) 7098 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 16146) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 7099 (("%" 292) (")" 16147) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 7100 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 16149) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 7101 (("%" 292) (")" 16150) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 7102 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 16157) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 7103 ((")" 16158)) 7104 (("%" 292) (")" 16163) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 7105 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 16166) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 7106 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 16167)) 7107 (("\"" 16169) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 7108 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16172) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16173) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16174) (T_DEC 22) (T_DECLARE 16175) (T_DIR 24) (T_DNUMBER 25) (T_DO 16176) (T_DOUBLE_CAST 27) (T_ECHO 16177) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16178) (T_FOREACH 16179) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16180) (T_GOTO 16181) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16182) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16183) (T_START_HEREDOC 68) (T_STATIC 16184) (T_STRING 16185) (T_STRING_CAST 71) (T_SWITCH 16186) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16187) (T_UNSET 16188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16190) (alt_if_stmt_without_else 16191) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16192) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16193) (if_stmt_without_else 16194) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16195) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16196) ("~" 125)) 7109 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 24660) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 7110 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 24658) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 7111 (("(" 24649)) 7112 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19746) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19747) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19748) (T_DEC 22) (T_DECLARE 19749) (T_DIR 24) (T_DNUMBER 25) (T_DO 19750) (T_DOUBLE_CAST 27) (T_ECHO 19751) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19752) (T_FOREACH 19753) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19754) (T_GOTO 19755) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19757) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19758) (T_START_HEREDOC 68) (T_STATIC 19759) (T_STRING 19760) (T_STRING_CAST 71) (T_SWITCH 19761) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19762) (T_UNSET 19763) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19764) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19765) (alt_if_stmt_without_else 19766) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19767) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19768) (if_stmt_without_else 19769) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 24643) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19771) ("~" 125)) 7113 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (echo_expr 19740) (echo_expr_list 24641) (expr 19742) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7114 (("(" 24628)) 7115 (("(" 24613)) 7116 (("$" 17870) (T_VARIABLE 17871) (global_var 17872) (global_var_list 24611) (simple_variable 17874)) 7117 ((T_STRING 24609)) 7118 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 24607) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 7119 ((T_FN 35) (T_FUNCTION 127) (T_VARIABLE 16848) (fn 103) #'134 (inline_function 16849) (static_var 16850) (static_var_list 24605)) 7120 ((":" 24604)) 7121 (("(" 24586)) 7122 (("{" 24569)) 7123 (("(" 24564)) 7124 (("(" 24555)) 7125 ((T_ELSE 16202) (T_ELSEIF 16203) (T_ENDIF 16204)) 7126 (("%" 6465) ("*" 6466) ("+" 6467) ("-" 6468) ("." 6469) ("/" 6470) (";" 16201) ("<" 6471) (">" 6472) ("?" 6473) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 6474) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 6475) (T_BOOLEAN_AND 6476) (T_BOOLEAN_OR 6477) (T_COALESCE 6478) (T_INSTANCEOF 6479) (T_IS_EQUAL 6480) (T_IS_GREATER_OR_EQUAL 6481) (T_IS_IDENTICAL 6482) (T_IS_NOT_EQUAL 6483) (T_IS_NOT_IDENTICAL 6484) (T_IS_SMALLER_OR_EQUAL 6485) (T_LOGICAL_AND 6486) (T_LOGICAL_OR 6487) (T_LOGICAL_XOR 6488) (T_POW 6489) (T_SL 6490) (T_SPACESHIP 6491) (T_SR 6492) ("^" 6493) ("|" 6494)) 7127 ((T_ELSE 16199) (T_ELSEIF 212)) 7128 ((inner_statement_list 16197)) 7129 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 16198) ("~" 125)) 7130 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16172) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16173) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16174) (T_DEC 22) (T_DECLARE 16175) (T_DIR 24) (T_DNUMBER 25) (T_DO 16176) (T_DOUBLE_CAST 27) (T_ECHO 16177) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16178) (T_FOREACH 16179) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16180) (T_GOTO 16181) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16182) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16183) (T_START_HEREDOC 68) (T_STATIC 16184) (T_STRING 16185) (T_STRING_CAST 71) (T_SWITCH 16186) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16187) (T_UNSET 16188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16190) (alt_if_stmt_without_else 16191) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16192) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16193) (if_stmt_without_else 16194) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16200) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16196) ("~" 125)) 7131 ((":" 24551)) 7132 (("(" 16206)) 7133 ((";" 16205)) 7134 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 16207) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 7135 (("%" 292) (")" 16208) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 7136 ((":" 16209)) 7137 ((inner_statement_list 16210)) 7138 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16211) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16212) (T_CLASS 16213) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16214) (T_DEC 22) (T_DECLARE 16215) (T_DIR 24) (T_DNUMBER 25) (T_DO 16216) (T_DOUBLE_CAST 27) (T_ECHO 16217) (T_EMPTY 29) (T_ENUM 16218) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16219) (T_FOREACH 16220) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16221) (T_GOTO 16222) (T_HALT_COMPILER 16223) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16225) (T_INTERFACE 16226) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16227) (T_START_HEREDOC 68) (T_STATIC 16228) (T_STRING 16229) (T_STRING_CAST 71) (T_SWITCH 16230) (T_THROW 73) (T_TRAIT 16231) (T_TRAIT_C 75) (T_TRY 16232) (T_UNSET 16233) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16234) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16235) (alt_if_stmt_without_else 16236) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16237) (attributes 16238) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16239) (class_modifier 96) (class_modifiers 16240) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16241) (expr 16242) (fn 103) (fully_dereferenceable 104) #'16243 (function_call 106) (function_declaration_statement 16244) (if_stmt 16245) (if_stmt_without_else 16246) (inline_function 110) (inner_statement 16247) (interface_declaration_statement 16248) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16249) (static_member 119) (trait_declaration_statement 16250) (variable 122) (variable_class_name 123) ("{" 16251) ("~" 125)) 7139 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 24549) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 7140 ((T_STRING 24542)) 7141 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 24540) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 7142 (("(" 24531)) 7143 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19746) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19747) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19748) (T_DEC 22) (T_DECLARE 19749) (T_DIR 24) (T_DNUMBER 25) (T_DO 19750) (T_DOUBLE_CAST 27) (T_ECHO 19751) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19752) (T_FOREACH 19753) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19754) (T_GOTO 19755) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19757) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19758) (T_START_HEREDOC 68) (T_STATIC 19759) (T_STRING 19760) (T_STRING_CAST 71) (T_SWITCH 19761) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19762) (T_UNSET 19763) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19764) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19765) (alt_if_stmt_without_else 19766) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19767) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19768) (if_stmt_without_else 19769) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 24525) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19771) ("~" 125)) 7144 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (echo_expr 19740) (echo_expr_list 24523) (expr 19742) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7145 ((T_STRING 24516)) 7146 (("(" 24503)) 7147 (("(" 24488)) 7148 (("$" 17870) (T_VARIABLE 17871) (global_var 17872) (global_var_list 24486) (simple_variable 17874)) 7149 ((T_STRING 24484)) 7150 (("(" 24481)) 7151 (("(" 24477)) 7152 ((T_STRING 24471)) 7153 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 24469) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 7154 ((T_FN 35) (T_FUNCTION 127) (T_VARIABLE 16848) (fn 103) #'134 (inline_function 16849) (static_var 16850) (static_var_list 24467)) 7155 ((":" 24466)) 7156 (("(" 24448)) 7157 ((T_STRING 24443)) 7158 (("{" 24426)) 7159 (("(" 24421)) 7160 (("(" 24412)) 7161 ((T_ELSE 16293) (T_ELSEIF 16203) (T_ENDIF 16294)) 7162 ((T_ABSTRACT 10) (T_ATTRIBUTE 13) (T_CLASS 16213) (T_ENUM 16218) (T_FINAL 34) (T_FN 35) (T_FUNCTION 38) (T_INTERFACE 16226) (T_READONLY 2936) (T_STATIC 16288) (T_TRAIT 16231) (attribute 16289) (attributed_statement 16290) (class_declaration_statement 16239) (class_modifier 96) (class_modifiers 16240) (enum_declaration_statement 16241) (fn 103) #'16243 (function_declaration_statement 16244) (inline_function 16291) (interface_declaration_statement 16248) (trait_declaration_statement 16250)) 7163 ((T_ABSTRACT 10) (T_CLASS 16279) (T_FINAL 34) (T_READONLY 2936) (class_modifier 16280)) 7164 (("%" 6465) ("*" 6466) ("+" 6467) ("-" 6468) ("." 6469) ("/" 6470) (";" 16278) ("<" 6471) (">" 6472) ("?" 6473) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 6474) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 6475) (T_BOOLEAN_AND 6476) (T_BOOLEAN_OR 6477) (T_COALESCE 6478) (T_INSTANCEOF 6479) (T_IS_EQUAL 6480) (T_IS_GREATER_OR_EQUAL 6481) (T_IS_IDENTICAL 6482) (T_IS_NOT_EQUAL 6483) (T_IS_NOT_IDENTICAL 6484) (T_IS_SMALLER_OR_EQUAL 6485) (T_LOGICAL_AND 6486) (T_LOGICAL_OR 6487) (T_LOGICAL_XOR 6488) (T_POW 6489) (T_SL 6490) (T_SPACESHIP 6491) (T_SR 6492) ("^" 6493) ("|" 6494)) 7165 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 16261) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 16262) (ampersand 16263) (returns_ref 16264)) 7166 ((T_ELSE 16254) (T_ELSEIF 16255)) 7167 ((inner_statement_list 16252)) 7168 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 16253) ("~" 125)) 7169 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16211) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16212) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16214) (T_DEC 22) (T_DECLARE 16215) (T_DIR 24) (T_DNUMBER 25) (T_DO 16216) (T_DOUBLE_CAST 27) (T_ECHO 16217) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16219) (T_FOREACH 16220) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16221) (T_GOTO 16222) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16225) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16227) (T_START_HEREDOC 68) (T_STATIC 16228) (T_STRING 16229) (T_STRING_CAST 71) (T_SWITCH 16230) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16232) (T_UNSET 16233) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16234) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16235) (alt_if_stmt_without_else 16236) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16242) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16245) (if_stmt_without_else 16246) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16260) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16251) ("~" 125)) 7170 (("(" 16256)) 7171 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 16257) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 7172 (("%" 292) (")" 16258) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 7173 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16211) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16212) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16214) (T_DEC 22) (T_DECLARE 16215) (T_DIR 24) (T_DNUMBER 25) (T_DO 16216) (T_DOUBLE_CAST 27) (T_ECHO 16217) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16219) (T_FOREACH 16220) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16221) (T_GOTO 16222) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16225) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16227) (T_START_HEREDOC 68) (T_STATIC 16228) (T_STRING 16229) (T_STRING_CAST 71) (T_SWITCH 16230) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16232) (T_UNSET 16233) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16234) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16235) (alt_if_stmt_without_else 16236) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16242) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16245) (if_stmt_without_else 16246) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16259) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16251) ("~" 125)) 7174 ((T_READONLY 16265) (T_STRING 16266) (backup_doc_comment 139) (function_name 16267)) 7175 ((backup_doc_comment 16268)) 7176 (("(" 16269)) 7177 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 16270)) 7178 ((")" 16271)) 7179 ((":" 161) (return_type 16272)) 7180 ((backup_fn_flags 16273)) 7181 (("{" 16274)) 7182 ((inner_statement_list 16275)) 7183 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 16276) ("~" 125)) 7184 ((backup_fn_flags 16277)) 7185 ((T_STRING 16281)) 7186 ((T_EXTENDS 2985) (extends_from 16282)) 7187 ((T_IMPLEMENTS 2987) (implements_list 16283)) 7188 ((backup_doc_comment 16284)) 7189 (("{" 16285)) 7190 ((class_statement_list 16286)) 7191 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 16287)) 7192 ((T_FN 35) (T_FUNCTION 127) (fn 103) #'134 (inline_function 16292)) 7193 ((":" 16296)) 7194 ((";" 16295)) 7195 ((inner_statement_list 16297)) 7196 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16298) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16299) (T_CLASS 16300) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16301) (T_DEC 22) (T_DECLARE 16302) (T_DIR 24) (T_DNUMBER 25) (T_DO 16303) (T_DOUBLE_CAST 27) (T_ECHO 16304) (T_EMPTY 29) (T_ENDIF 16305) (T_ENUM 16306) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16307) (T_FOREACH 16308) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16309) (T_GOTO 16310) (T_HALT_COMPILER 16311) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16312) (T_INTERFACE 16313) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16314) (T_START_HEREDOC 68) (T_STATIC 16315) (T_STRING 16316) (T_STRING_CAST 71) (T_SWITCH 16317) (T_THROW 73) (T_TRAIT 16318) (T_TRAIT_C 75) (T_TRY 16319) (T_UNSET 16320) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16321) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16322) (alt_if_stmt_without_else 16323) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16324) (attributes 16325) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16326) (class_modifier 96) (class_modifiers 16327) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16328) (expr 16329) (fn 103) (fully_dereferenceable 104) #'16330 (function_call 106) (function_declaration_statement 16331) (if_stmt 16332) (if_stmt_without_else 16333) (inline_function 110) (inner_statement 16334) (interface_declaration_statement 16335) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16336) (static_member 119) (trait_declaration_statement 16337) (variable 122) (variable_class_name 123) ("{" 16338) ("~" 125)) 7197 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 24410) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 7198 ((T_STRING 24403)) 7199 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 24401) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 7200 (("(" 24392)) 7201 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19746) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19747) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19748) (T_DEC 22) (T_DECLARE 19749) (T_DIR 24) (T_DNUMBER 25) (T_DO 19750) (T_DOUBLE_CAST 27) (T_ECHO 19751) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19752) (T_FOREACH 19753) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19754) (T_GOTO 19755) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19757) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19758) (T_START_HEREDOC 68) (T_STATIC 19759) (T_STRING 19760) (T_STRING_CAST 71) (T_SWITCH 19761) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19762) (T_UNSET 19763) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19764) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19765) (alt_if_stmt_without_else 19766) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19767) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19768) (if_stmt_without_else 19769) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 24386) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19771) ("~" 125)) 7202 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (echo_expr 19740) (echo_expr_list 24384) (expr 19742) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7203 ((";" 24383)) 7204 ((T_STRING 24376)) 7205 (("(" 24363)) 7206 (("(" 24348)) 7207 (("$" 17870) (T_VARIABLE 17871) (global_var 17872) (global_var_list 24346) (simple_variable 17874)) 7208 ((T_STRING 24344)) 7209 (("(" 24341)) 7210 ((T_STRING 24335)) 7211 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 24333) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 7212 ((T_FN 35) (T_FUNCTION 127) (T_VARIABLE 16848) (fn 103) #'134 (inline_function 16849) (static_var 16850) (static_var_list 24331)) 7213 ((":" 24330)) 7214 (("(" 24312)) 7215 ((T_STRING 24307)) 7216 (("{" 24290)) 7217 (("(" 24285)) 7218 (("(" 16372)) 7219 ((T_ELSE 16365) (T_ELSEIF 16203) (T_ENDIF 16366)) 7220 ((T_ABSTRACT 10) (T_ATTRIBUTE 13) (T_CLASS 16300) (T_ENUM 16306) (T_FINAL 34) (T_FN 35) (T_FUNCTION 38) (T_INTERFACE 16313) (T_READONLY 2936) (T_STATIC 16288) (T_TRAIT 16318) (attribute 16289) (attributed_statement 16364) (class_declaration_statement 16326) (class_modifier 96) (class_modifiers 16327) (enum_declaration_statement 16328) (fn 103) #'16330 (function_declaration_statement 16331) (inline_function 16291) (interface_declaration_statement 16335) (trait_declaration_statement 16337)) 7221 ((T_ABSTRACT 10) (T_CLASS 16356) (T_FINAL 34) (T_READONLY 2936) (class_modifier 16280)) 7222 (("%" 6465) ("*" 6466) ("+" 6467) ("-" 6468) ("." 6469) ("/" 6470) (";" 16355) ("<" 6471) (">" 6472) ("?" 6473) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 6474) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 6475) (T_BOOLEAN_AND 6476) (T_BOOLEAN_OR 6477) (T_COALESCE 6478) (T_INSTANCEOF 6479) (T_IS_EQUAL 6480) (T_IS_GREATER_OR_EQUAL 6481) (T_IS_IDENTICAL 6482) (T_IS_NOT_EQUAL 6483) (T_IS_NOT_IDENTICAL 6484) (T_IS_SMALLER_OR_EQUAL 6485) (T_LOGICAL_AND 6486) (T_LOGICAL_OR 6487) (T_LOGICAL_XOR 6488) (T_POW 6489) (T_SL 6490) (T_SPACESHIP 6491) (T_SR 6492) ("^" 6493) ("|" 6494)) 7223 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 16261) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 16262) (ampersand 16263) (returns_ref 16343)) 7224 ((T_ELSE 16341) (T_ELSEIF 16255)) 7225 ((inner_statement_list 16339)) 7226 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 16340) ("~" 125)) 7227 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16298) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16299) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16301) (T_DEC 22) (T_DECLARE 16302) (T_DIR 24) (T_DNUMBER 25) (T_DO 16303) (T_DOUBLE_CAST 27) (T_ECHO 16304) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16307) (T_FOREACH 16308) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16309) (T_GOTO 16310) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16312) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16314) (T_START_HEREDOC 68) (T_STATIC 16315) (T_STRING 16316) (T_STRING_CAST 71) (T_SWITCH 16317) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16319) (T_UNSET 16320) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16321) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16322) (alt_if_stmt_without_else 16323) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16329) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16332) (if_stmt_without_else 16333) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16342) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16338) ("~" 125)) 7228 ((T_READONLY 16265) (T_STRING 16266) (backup_doc_comment 139) (function_name 16344)) 7229 ((backup_doc_comment 16345)) 7230 (("(" 16346)) 7231 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 16347)) 7232 ((")" 16348)) 7233 ((":" 161) (return_type 16349)) 7234 ((backup_fn_flags 16350)) 7235 (("{" 16351)) 7236 ((inner_statement_list 16352)) 7237 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 16353) ("~" 125)) 7238 ((backup_fn_flags 16354)) 7239 ((T_STRING 16357)) 7240 ((T_EXTENDS 2985) (extends_from 16358)) 7241 ((T_IMPLEMENTS 2987) (implements_list 16359)) 7242 ((backup_doc_comment 16360)) 7243 (("{" 16361)) 7244 ((class_statement_list 16362)) 7245 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 16363)) 7246 ((":" 16368)) 7247 ((";" 16367)) 7248 ((inner_statement_list 16369)) 7249 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16298) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16299) (T_CLASS 16300) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16301) (T_DEC 22) (T_DECLARE 16302) (T_DIR 24) (T_DNUMBER 25) (T_DO 16303) (T_DOUBLE_CAST 27) (T_ECHO 16304) (T_EMPTY 29) (T_ENDIF 16370) (T_ENUM 16306) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16307) (T_FOREACH 16308) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16309) (T_GOTO 16310) (T_HALT_COMPILER 16311) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16312) (T_INTERFACE 16313) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16314) (T_START_HEREDOC 68) (T_STATIC 16315) (T_STRING 16316) (T_STRING_CAST 71) (T_SWITCH 16317) (T_THROW 73) (T_TRAIT 16318) (T_TRAIT_C 75) (T_TRY 16319) (T_UNSET 16320) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16321) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16322) (alt_if_stmt_without_else 16323) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16324) (attributes 16325) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16326) (class_modifier 96) (class_modifiers 16327) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16328) (expr 16329) (fn 103) (fully_dereferenceable 104) #'16330 (function_call 106) (function_declaration_statement 16331) (if_stmt 16332) (if_stmt_without_else 16333) (inline_function 110) (inner_statement 16334) (interface_declaration_statement 16335) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16336) (static_member 119) (trait_declaration_statement 16337) (variable 122) (variable_class_name 123) ("{" 16338) ("~" 125)) 7250 ((";" 16371)) 7251 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 16373) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 7252 (("%" 292) (")" 16374) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 7253 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 16375) (";" 16298) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16299) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16301) (T_DEC 22) (T_DECLARE 16302) (T_DIR 24) (T_DNUMBER 25) (T_DO 16303) (T_DOUBLE_CAST 27) (T_ECHO 16304) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16307) (T_FOREACH 16308) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16309) (T_GOTO 16310) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16312) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16314) (T_START_HEREDOC 68) (T_STATIC 16315) (T_STRING 16316) (T_STRING_CAST 71) (T_SWITCH 16317) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16319) (T_UNSET 16320) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16321) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16322) (alt_if_stmt_without_else 16323) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16329) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16332) (if_stmt_without_else 16333) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16376) (static_member 119) (variable 122) (variable_class_name 123) (while_statement 16377) ("{" 16338) ("~" 125)) 7254 ((inner_statement_list 16378)) 7255 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16379) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16380) (T_CLASS 16381) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16382) (T_DEC 22) (T_DECLARE 16383) (T_DIR 24) (T_DNUMBER 25) (T_DO 16384) (T_DOUBLE_CAST 27) (T_ECHO 16385) (T_EMPTY 29) (T_ENDWHILE 16386) (T_ENUM 16387) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16388) (T_FOREACH 16389) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16390) (T_GOTO 16391) (T_HALT_COMPILER 16392) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16394) (T_INTERFACE 16395) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16396) (T_START_HEREDOC 68) (T_STATIC 16397) (T_STRING 16398) (T_STRING_CAST 71) (T_SWITCH 16399) (T_THROW 73) (T_TRAIT 16400) (T_TRAIT_C 75) (T_TRY 16401) (T_UNSET 16402) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16403) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16404) (alt_if_stmt_without_else 16405) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16406) (attributes 16407) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16408) (class_modifier 96) (class_modifiers 16409) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16410) (expr 16411) (fn 103) (fully_dereferenceable 104) #'16412 (function_call 106) (function_declaration_statement 16413) (if_stmt 16414) (if_stmt_without_else 16415) (inline_function 110) (inner_statement 16416) (interface_declaration_statement 16417) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16418) (static_member 119) (trait_declaration_statement 16419) (variable 122) (variable_class_name 123) ("{" 16420) ("~" 125)) 7256 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 24283) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 7257 ((T_STRING 24276)) 7258 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 24274) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 7259 (("(" 24265)) 7260 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19746) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19747) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19748) (T_DEC 22) (T_DECLARE 19749) (T_DIR 24) (T_DNUMBER 25) (T_DO 19750) (T_DOUBLE_CAST 27) (T_ECHO 19751) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19752) (T_FOREACH 19753) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19754) (T_GOTO 19755) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19757) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19758) (T_START_HEREDOC 68) (T_STATIC 19759) (T_STRING 19760) (T_STRING_CAST 71) (T_SWITCH 19761) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19762) (T_UNSET 19763) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19764) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19765) (alt_if_stmt_without_else 19766) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19767) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19768) (if_stmt_without_else 19769) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 24259) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19771) ("~" 125)) 7261 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (echo_expr 19740) (echo_expr_list 24257) (expr 19742) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7262 ((";" 24256)) 7263 ((T_STRING 24249)) 7264 (("(" 24236)) 7265 (("(" 24221)) 7266 (("$" 17870) (T_VARIABLE 17871) (global_var 17872) (global_var_list 24219) (simple_variable 17874)) 7267 ((T_STRING 24217)) 7268 (("(" 24214)) 7269 (("(" 24210)) 7270 ((T_STRING 24204)) 7271 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 24202) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 7272 ((T_FN 35) (T_FUNCTION 127) (T_VARIABLE 16848) (fn 103) #'134 (inline_function 16849) (static_var 16850) (static_var_list 24200)) 7273 ((":" 24199)) 7274 (("(" 24181)) 7275 ((T_STRING 24176)) 7276 (("{" 24159)) 7277 (("(" 24154)) 7278 (("(" 24145)) 7279 ((T_ELSE 24138) (T_ELSEIF 16203) (T_ENDIF 24139)) 7280 ((T_ABSTRACT 10) (T_ATTRIBUTE 13) (T_CLASS 16381) (T_ENUM 16387) (T_FINAL 34) (T_FN 35) (T_FUNCTION 38) (T_INTERFACE 16395) (T_READONLY 2936) (T_STATIC 16288) (T_TRAIT 16400) (attribute 16289) (attributed_statement 24137) (class_declaration_statement 16408) (class_modifier 96) (class_modifiers 16409) (enum_declaration_statement 16410) (fn 103) #'16412 (function_declaration_statement 16413) (inline_function 16291) (interface_declaration_statement 16417) (trait_declaration_statement 16419)) 7281 ((T_ABSTRACT 10) (T_CLASS 24129) (T_FINAL 34) (T_READONLY 2936) (class_modifier 16280)) 7282 (("%" 6465) ("*" 6466) ("+" 6467) ("-" 6468) ("." 6469) ("/" 6470) (";" 24128) ("<" 6471) (">" 6472) ("?" 6473) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 6474) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 6475) (T_BOOLEAN_AND 6476) (T_BOOLEAN_OR 6477) (T_COALESCE 6478) (T_INSTANCEOF 6479) (T_IS_EQUAL 6480) (T_IS_GREATER_OR_EQUAL 6481) (T_IS_IDENTICAL 6482) (T_IS_NOT_EQUAL 6483) (T_IS_NOT_IDENTICAL 6484) (T_IS_SMALLER_OR_EQUAL 6485) (T_LOGICAL_AND 6486) (T_LOGICAL_OR 6487) (T_LOGICAL_XOR 6488) (T_POW 6489) (T_SL 6490) (T_SPACESHIP 6491) (T_SR 6492) ("^" 6493) ("|" 6494)) 7283 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 16261) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 16262) (ampersand 16263) (returns_ref 24116)) 7284 ((T_ELSE 16423) (T_ELSEIF 16424)) 7285 ((inner_statement_list 16421)) 7286 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 16422) ("~" 125)) 7287 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16379) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16380) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16382) (T_DEC 22) (T_DECLARE 16383) (T_DIR 24) (T_DNUMBER 25) (T_DO 16384) (T_DOUBLE_CAST 27) (T_ECHO 16385) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16388) (T_FOREACH 16389) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16390) (T_GOTO 16391) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16394) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16396) (T_START_HEREDOC 68) (T_STATIC 16397) (T_STRING 16398) (T_STRING_CAST 71) (T_SWITCH 16399) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16401) (T_UNSET 16402) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16403) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16404) (alt_if_stmt_without_else 16405) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16411) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16414) (if_stmt_without_else 16415) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 24115) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16420) ("~" 125)) 7288 (("(" 16425)) 7289 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 16426) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 7290 (("%" 292) (")" 16427) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 7291 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16428) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16429) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16430) (T_DEC 22) (T_DECLARE 16431) (T_DIR 24) (T_DNUMBER 25) (T_DO 16432) (T_DOUBLE_CAST 27) (T_ECHO 16433) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16434) (T_FOREACH 16435) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16436) (T_GOTO 16437) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16438) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16439) (T_START_HEREDOC 68) (T_STATIC 16440) (T_STRING 16441) (T_STRING_CAST 71) (T_SWITCH 16442) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16443) (T_UNSET 16444) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16445) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16446) (alt_if_stmt_without_else 16447) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16448) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16449) (if_stmt_without_else 16450) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16451) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16452) ("~" 125)) 7292 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 24113) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 7293 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 24111) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 7294 (("(" 24102)) 7295 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19746) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19747) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19748) (T_DEC 22) (T_DECLARE 19749) (T_DIR 24) (T_DNUMBER 25) (T_DO 19750) (T_DOUBLE_CAST 27) (T_ECHO 19751) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19752) (T_FOREACH 19753) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19754) (T_GOTO 19755) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19757) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19758) (T_START_HEREDOC 68) (T_STATIC 19759) (T_STRING 19760) (T_STRING_CAST 71) (T_SWITCH 19761) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19762) (T_UNSET 19763) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19764) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19765) (alt_if_stmt_without_else 19766) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19767) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19768) (if_stmt_without_else 19769) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 24096) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19771) ("~" 125)) 7296 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (echo_expr 19740) (echo_expr_list 24094) (expr 19742) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7297 (("(" 24081)) 7298 (("(" 24066)) 7299 (("$" 17870) (T_VARIABLE 17871) (global_var 17872) (global_var_list 24064) (simple_variable 17874)) 7300 ((T_STRING 24062)) 7301 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 24060) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 7302 ((T_FN 35) (T_FUNCTION 127) (T_VARIABLE 16848) (fn 103) #'134 (inline_function 16849) (static_var 16850) (static_var_list 24058)) 7303 ((":" 24057)) 7304 (("(" 16561)) 7305 (("{" 16534)) 7306 (("(" 16474)) 7307 (("(" 16465)) 7308 ((T_ELSE 16458) (T_ELSEIF 16203) (T_ENDIF 16459)) 7309 (("%" 6465) ("*" 6466) ("+" 6467) ("-" 6468) ("." 6469) ("/" 6470) (";" 16457) ("<" 6471) (">" 6472) ("?" 6473) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 6474) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 6475) (T_BOOLEAN_AND 6476) (T_BOOLEAN_OR 6477) (T_COALESCE 6478) (T_INSTANCEOF 6479) (T_IS_EQUAL 6480) (T_IS_GREATER_OR_EQUAL 6481) (T_IS_IDENTICAL 6482) (T_IS_NOT_EQUAL 6483) (T_IS_NOT_IDENTICAL 6484) (T_IS_SMALLER_OR_EQUAL 6485) (T_LOGICAL_AND 6486) (T_LOGICAL_OR 6487) (T_LOGICAL_XOR 6488) (T_POW 6489) (T_SL 6490) (T_SPACESHIP 6491) (T_SR 6492) ("^" 6493) ("|" 6494)) 7310 ((T_ELSE 16455) (T_ELSEIF 16424)) 7311 ((inner_statement_list 16453)) 7312 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 16454) ("~" 125)) 7313 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16428) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16429) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16430) (T_DEC 22) (T_DECLARE 16431) (T_DIR 24) (T_DNUMBER 25) (T_DO 16432) (T_DOUBLE_CAST 27) (T_ECHO 16433) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16434) (T_FOREACH 16435) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16436) (T_GOTO 16437) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16438) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16439) (T_START_HEREDOC 68) (T_STATIC 16440) (T_STRING 16441) (T_STRING_CAST 71) (T_SWITCH 16442) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16443) (T_UNSET 16444) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16445) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16446) (alt_if_stmt_without_else 16447) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16448) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16449) (if_stmt_without_else 16450) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16456) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16452) ("~" 125)) 7314 ((":" 16461)) 7315 ((";" 16460)) 7316 ((inner_statement_list 16462)) 7317 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16298) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16299) (T_CLASS 16300) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16301) (T_DEC 22) (T_DECLARE 16302) (T_DIR 24) (T_DNUMBER 25) (T_DO 16303) (T_DOUBLE_CAST 27) (T_ECHO 16304) (T_EMPTY 29) (T_ENDIF 16463) (T_ENUM 16306) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16307) (T_FOREACH 16308) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16309) (T_GOTO 16310) (T_HALT_COMPILER 16311) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16312) (T_INTERFACE 16313) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16314) (T_START_HEREDOC 68) (T_STATIC 16315) (T_STRING 16316) (T_STRING_CAST 71) (T_SWITCH 16317) (T_THROW 73) (T_TRAIT 16318) (T_TRAIT_C 75) (T_TRY 16319) (T_UNSET 16320) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16321) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16322) (alt_if_stmt_without_else 16323) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16324) (attributes 16325) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16326) (class_modifier 96) (class_modifiers 16327) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16328) (expr 16329) (fn 103) (fully_dereferenceable 104) #'16330 (function_call 106) (function_declaration_statement 16331) (if_stmt 16332) (if_stmt_without_else 16333) (inline_function 110) (inner_statement 16334) (interface_declaration_statement 16335) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16336) (static_member 119) (trait_declaration_statement 16337) (variable 122) (variable_class_name 123) ("{" 16338) ("~" 125)) 7318 ((";" 16464)) 7319 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 16466) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 7320 (("%" 292) (")" 16467) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 7321 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 16468) (";" 16428) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16429) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16430) (T_DEC 22) (T_DECLARE 16431) (T_DIR 24) (T_DNUMBER 25) (T_DO 16432) (T_DOUBLE_CAST 27) (T_ECHO 16433) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16434) (T_FOREACH 16435) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16436) (T_GOTO 16437) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16438) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16439) (T_START_HEREDOC 68) (T_STATIC 16440) (T_STRING 16441) (T_STRING_CAST 71) (T_SWITCH 16442) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16443) (T_UNSET 16444) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16445) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16446) (alt_if_stmt_without_else 16447) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16448) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16449) (if_stmt_without_else 16450) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16469) (static_member 119) (variable 122) (variable_class_name 123) (while_statement 16470) ("{" 16452) ("~" 125)) 7322 ((inner_statement_list 16471)) 7323 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16379) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16380) (T_CLASS 16381) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16382) (T_DEC 22) (T_DECLARE 16383) (T_DIR 24) (T_DNUMBER 25) (T_DO 16384) (T_DOUBLE_CAST 27) (T_ECHO 16385) (T_EMPTY 29) (T_ENDWHILE 16472) (T_ENUM 16387) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16388) (T_FOREACH 16389) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16390) (T_GOTO 16391) (T_HALT_COMPILER 16392) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16394) (T_INTERFACE 16395) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16396) (T_START_HEREDOC 68) (T_STATIC 16397) (T_STRING 16398) (T_STRING_CAST 71) (T_SWITCH 16399) (T_THROW 73) (T_TRAIT 16400) (T_TRAIT_C 75) (T_TRY 16401) (T_UNSET 16402) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16403) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16404) (alt_if_stmt_without_else 16405) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16406) (attributes 16407) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16408) (class_modifier 96) (class_modifiers 16409) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16410) (expr 16411) (fn 103) (fully_dereferenceable 104) #'16412 (function_call 106) (function_declaration_statement 16413) (if_stmt 16414) (if_stmt_without_else 16415) (inline_function 110) (inner_statement 16416) (interface_declaration_statement 16417) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16418) (static_member 119) (trait_declaration_statement 16419) (variable 122) (variable_class_name 123) ("{" 16420) ("~" 125)) 7324 ((";" 16473)) 7325 (("\"" 1509) ("$" 16475) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 16476) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 16477) ("[" 1529) (array_object_dereferenceable 16478) (callable_expr 16479) (callable_variable 16480) (class_constant 1533) (class_name 16481) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 16482) (name 16483) (simple_variable 16484) (static_member 16485) (unset_variable 16486) (unset_variables 16487) (variable 16488) (variable_class_name 16489)) 7326 (("$" 16475) (T_VARIABLE 16477) (simple_variable 16530) ("{" 16531)) 7327 (("(" 16493) (argument_list 16529)) 7328 ((T_NULLSAFE_OBJECT_OPERATOR 16512) (T_OBJECT_OPERATOR 16513) ("[" 16514) ("{" 16515)) 7329 (("(" 16493) (argument_list 16511)) 7330 ((T_PAAMAYIM_NEKUDOTAYIM 16507)) 7331 (("(" 16493) (argument_list 16506)) 7332 (("," 16501) (possible_comma 16502)) 7333 ((T_PAAMAYIM_NEKUDOTAYIM 16490)) 7334 (("$" 16475) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 16477) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 16491) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 16492) ("{" 1627)) 7335 (("(" 16493) (argument_list 16494)) 7336 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 16495) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 16496) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 16497) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 7337 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 16500) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 7338 (("," 1469) (possible_comma 16498)) 7339 ((")" 16499)) 7340 (("\"" 1509) ("$" 16475) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 16476) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 16477) ("[" 1529) (array_object_dereferenceable 16478) (callable_expr 16479) (callable_variable 16480) (class_constant 1533) (class_name 16481) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 16482) (name 16483) (simple_variable 16484) (static_member 16485) (unset_variable 16505) (variable 16488) (variable_class_name 16489)) 7341 ((")" 16503)) 7342 ((";" 16504)) 7343 (("$" 16475) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 16477) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 16508) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 16509) ("{" 1643)) 7344 (("(" 16493) (argument_list 16510)) 7345 (("$" 16475) (T_STRING 16520) (T_VARIABLE 16477) (property_name 16527) (simple_variable 16522) ("{" 16523)) 7346 (("$" 16475) (T_STRING 16520) (T_VARIABLE 16477) (property_name 16521) (simple_variable 16522) ("{" 16523)) 7347 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 16518) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 7348 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 16516) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 7349 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 16517)) 7350 (("]" 16519)) 7351 (("(" 16493) (argument_list 16526)) 7352 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 16524) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 7353 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 16525)) 7354 (("(" 16493) (argument_list 16528)) 7355 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 16532) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 7356 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 16533)) 7357 ((inner_statement_list 16535)) 7358 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 16536) ("~" 125)) 7359 ((catch_list 16537)) 7360 ((T_CATCH 16538) (T_FINALLY 16539) (finally_statement 16540)) 7361 (("(" 16544)) 7362 (("{" 16541)) 7363 ((inner_statement_list 16542)) 7364 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 16543) ("~" 125)) 7365 ((T_NAME_FULLY_QUALIFIED 16545) (T_NAME_QUALIFIED 16546) (T_NAME_RELATIVE 16547) (T_STATIC 16548) (T_STRING 16549) (catch_name_list 16550) (class_name 16551) (name 16552)) 7366 ((T_VARIABLE 16553) (optional_variable 16554) ("|" 16555)) 7367 ((")" 16557)) 7368 ((T_NAME_FULLY_QUALIFIED 16545) (T_NAME_QUALIFIED 16546) (T_NAME_RELATIVE 16547) (T_STATIC 16548) (T_STRING 16549) (class_name 16556) (name 16552)) 7369 (("{" 16558)) 7370 ((inner_statement_list 16559)) 7371 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 16560) ("~" 125)) 7372 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 16562) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 7373 (("%" 292) (")" 16563) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 7374 ((":" 16564) (switch_case_list 16565) ("{" 16566)) 7375 ((";" 24050) (case_list 24051)) 7376 ((";" 16567) (case_list 16568)) 7377 ((case_list 24048)) 7378 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 16571)) 7379 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 24045) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 7380 ((":" 16572) (";" 16573) (case_separator 16574)) 7381 ((inner_statement_list 16575)) 7382 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16576) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16577) (T_CLASS 16578) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16579) (T_DEC 22) (T_DECLARE 16580) (T_DIR 24) (T_DNUMBER 25) (T_DO 16581) (T_DOUBLE_CAST 27) (T_ECHO 16582) (T_EMPTY 29) (T_ENUM 16583) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16584) (T_FOREACH 16585) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16586) (T_GOTO 16587) (T_HALT_COMPILER 16588) (T_IF 16589) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16590) (T_INTERFACE 16591) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16592) (T_START_HEREDOC 68) (T_STATIC 16593) (T_STRING 16594) (T_STRING_CAST 71) (T_SWITCH 16595) (T_THROW 73) (T_TRAIT 16596) (T_TRAIT_C 75) (T_TRY 16597) (T_UNSET 16598) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16599) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16600) (alt_if_stmt_without_else 16601) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16602) (attributes 16603) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16604) (class_modifier 96) (class_modifiers 16605) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16606) (expr 16607) (fn 103) (fully_dereferenceable 104) #'16608 (function_call 106) (function_declaration_statement 16609) (if_stmt 16610) (if_stmt_without_else 16611) (inline_function 110) (inner_statement 16612) (interface_declaration_statement 16613) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16614) (static_member 119) (trait_declaration_statement 16615) (variable 122) (variable_class_name 123) ("{" 16616) ("~" 125)) 7383 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 24043) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 7384 ((T_STRING 24036)) 7385 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 24034) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 7386 (("(" 24025)) 7387 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19746) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19747) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19748) (T_DEC 22) (T_DECLARE 19749) (T_DIR 24) (T_DNUMBER 25) (T_DO 19750) (T_DOUBLE_CAST 27) (T_ECHO 19751) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19752) (T_FOREACH 19753) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19754) (T_GOTO 19755) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19757) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19758) (T_START_HEREDOC 68) (T_STATIC 19759) (T_STRING 19760) (T_STRING_CAST 71) (T_SWITCH 19761) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19762) (T_UNSET 19763) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19764) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19765) (alt_if_stmt_without_else 19766) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19767) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19768) (if_stmt_without_else 19769) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 24019) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19771) ("~" 125)) 7388 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (echo_expr 19740) (echo_expr_list 24017) (expr 19742) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7389 ((T_STRING 24010)) 7390 (("(" 23997)) 7391 (("(" 23982)) 7392 (("$" 17870) (T_VARIABLE 17871) (global_var 17872) (global_var_list 23980) (simple_variable 17874)) 7393 ((T_STRING 23978)) 7394 (("(" 23975)) 7395 (("(" 23971)) 7396 ((T_STRING 23965)) 7397 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 23963) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 7398 ((T_FN 35) (T_FUNCTION 127) (T_VARIABLE 16848) (fn 103) #'134 (inline_function 16849) (static_var 16850) (static_var_list 23961)) 7399 ((":" 23960)) 7400 (("(" 23942)) 7401 ((T_STRING 23937)) 7402 (("{" 23920)) 7403 (("(" 23915)) 7404 (("(" 23906)) 7405 ((T_ELSE 23899) (T_ELSEIF 16203) (T_ENDIF 23900)) 7406 ((T_ABSTRACT 10) (T_ATTRIBUTE 13) (T_CLASS 16578) (T_ENUM 16583) (T_FINAL 34) (T_FN 35) (T_FUNCTION 38) (T_INTERFACE 16591) (T_READONLY 2936) (T_STATIC 16288) (T_TRAIT 16596) (attribute 16289) (attributed_statement 23898) (class_declaration_statement 16604) (class_modifier 96) (class_modifiers 16605) (enum_declaration_statement 16606) (fn 103) #'16608 (function_declaration_statement 16609) (inline_function 16291) (interface_declaration_statement 16613) (trait_declaration_statement 16615)) 7407 ((T_ABSTRACT 10) (T_CLASS 23890) (T_FINAL 34) (T_READONLY 2936) (class_modifier 16280)) 7408 (("%" 6465) ("*" 6466) ("+" 6467) ("-" 6468) ("." 6469) ("/" 6470) (";" 23889) ("<" 6471) (">" 6472) ("?" 6473) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 6474) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 6475) (T_BOOLEAN_AND 6476) (T_BOOLEAN_OR 6477) (T_COALESCE 6478) (T_INSTANCEOF 6479) (T_IS_EQUAL 6480) (T_IS_GREATER_OR_EQUAL 6481) (T_IS_IDENTICAL 6482) (T_IS_NOT_EQUAL 6483) (T_IS_NOT_IDENTICAL 6484) (T_IS_SMALLER_OR_EQUAL 6485) (T_LOGICAL_AND 6486) (T_LOGICAL_OR 6487) (T_LOGICAL_XOR 6488) (T_POW 6489) (T_SL 6490) (T_SPACESHIP 6491) (T_SR 6492) ("^" 6493) ("|" 6494)) 7409 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 16261) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 16262) (ampersand 16263) (returns_ref 23877)) 7410 ((T_ELSE 16619) (T_ELSEIF 16620)) 7411 ((inner_statement_list 16617)) 7412 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 16618) ("~" 125)) 7413 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16576) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16577) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16579) (T_DEC 22) (T_DECLARE 16580) (T_DIR 24) (T_DNUMBER 25) (T_DO 16581) (T_DOUBLE_CAST 27) (T_ECHO 16582) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16584) (T_FOREACH 16585) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16586) (T_GOTO 16587) (T_IF 16589) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16590) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16592) (T_START_HEREDOC 68) (T_STATIC 16593) (T_STRING 16594) (T_STRING_CAST 71) (T_SWITCH 16595) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16597) (T_UNSET 16598) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16599) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16600) (alt_if_stmt_without_else 16601) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16607) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16610) (if_stmt_without_else 16611) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 23876) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16616) ("~" 125)) 7414 (("(" 16621)) 7415 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 16622) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 7416 (("%" 292) (")" 16623) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 7417 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16624) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16625) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16626) (T_DEC 22) (T_DECLARE 16627) (T_DIR 24) (T_DNUMBER 25) (T_DO 16628) (T_DOUBLE_CAST 27) (T_ECHO 16629) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16630) (T_FOREACH 16631) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16632) (T_GOTO 16633) (T_IF 16589) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16634) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16635) (T_START_HEREDOC 68) (T_STATIC 16636) (T_STRING 16637) (T_STRING_CAST 71) (T_SWITCH 16638) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16639) (T_UNSET 16640) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16641) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16642) (alt_if_stmt_without_else 16643) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16644) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16645) (if_stmt_without_else 16646) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16647) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16648) ("~" 125)) 7418 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 23874) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 7419 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 23872) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 7420 (("(" 23863)) 7421 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19746) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19747) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19748) (T_DEC 22) (T_DECLARE 19749) (T_DIR 24) (T_DNUMBER 25) (T_DO 19750) (T_DOUBLE_CAST 27) (T_ECHO 19751) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19752) (T_FOREACH 19753) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19754) (T_GOTO 19755) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19757) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19758) (T_START_HEREDOC 68) (T_STATIC 19759) (T_STRING 19760) (T_STRING_CAST 71) (T_SWITCH 19761) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19762) (T_UNSET 19763) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19764) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19765) (alt_if_stmt_without_else 19766) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19767) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19768) (if_stmt_without_else 19769) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 23857) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19771) ("~" 125)) 7422 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (echo_expr 19740) (echo_expr_list 23855) (expr 19742) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7423 (("(" 23842)) 7424 (("(" 23827)) 7425 (("$" 17870) (T_VARIABLE 17871) (global_var 17872) (global_var_list 23825) (simple_variable 17874)) 7426 ((T_STRING 23823)) 7427 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 23821) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 7428 ((T_FN 35) (T_FUNCTION 127) (T_VARIABLE 16848) (fn 103) #'134 (inline_function 16849) (static_var 16850) (static_var_list 23819)) 7429 ((":" 23818)) 7430 (("(" 16692)) 7431 (("{" 16675)) 7432 (("(" 16670)) 7433 (("(" 16661)) 7434 ((T_ELSE 16654) (T_ELSEIF 16203) (T_ENDIF 16655)) 7435 (("%" 6465) ("*" 6466) ("+" 6467) ("-" 6468) ("." 6469) ("/" 6470) (";" 16653) ("<" 6471) (">" 6472) ("?" 6473) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 6474) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 6475) (T_BOOLEAN_AND 6476) (T_BOOLEAN_OR 6477) (T_COALESCE 6478) (T_INSTANCEOF 6479) (T_IS_EQUAL 6480) (T_IS_GREATER_OR_EQUAL 6481) (T_IS_IDENTICAL 6482) (T_IS_NOT_EQUAL 6483) (T_IS_NOT_IDENTICAL 6484) (T_IS_SMALLER_OR_EQUAL 6485) (T_LOGICAL_AND 6486) (T_LOGICAL_OR 6487) (T_LOGICAL_XOR 6488) (T_POW 6489) (T_SL 6490) (T_SPACESHIP 6491) (T_SR 6492) ("^" 6493) ("|" 6494)) 7436 ((T_ELSE 16651) (T_ELSEIF 16620)) 7437 ((inner_statement_list 16649)) 7438 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 16650) ("~" 125)) 7439 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16624) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16625) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16626) (T_DEC 22) (T_DECLARE 16627) (T_DIR 24) (T_DNUMBER 25) (T_DO 16628) (T_DOUBLE_CAST 27) (T_ECHO 16629) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16630) (T_FOREACH 16631) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16632) (T_GOTO 16633) (T_IF 16589) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16634) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16635) (T_START_HEREDOC 68) (T_STATIC 16636) (T_STRING 16637) (T_STRING_CAST 71) (T_SWITCH 16638) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16639) (T_UNSET 16640) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16641) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16642) (alt_if_stmt_without_else 16643) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16644) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16645) (if_stmt_without_else 16646) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16652) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16648) ("~" 125)) 7440 ((":" 16657)) 7441 ((";" 16656)) 7442 ((inner_statement_list 16658)) 7443 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16298) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16299) (T_CLASS 16300) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16301) (T_DEC 22) (T_DECLARE 16302) (T_DIR 24) (T_DNUMBER 25) (T_DO 16303) (T_DOUBLE_CAST 27) (T_ECHO 16304) (T_EMPTY 29) (T_ENDIF 16659) (T_ENUM 16306) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16307) (T_FOREACH 16308) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16309) (T_GOTO 16310) (T_HALT_COMPILER 16311) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16312) (T_INTERFACE 16313) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16314) (T_START_HEREDOC 68) (T_STATIC 16315) (T_STRING 16316) (T_STRING_CAST 71) (T_SWITCH 16317) (T_THROW 73) (T_TRAIT 16318) (T_TRAIT_C 75) (T_TRY 16319) (T_UNSET 16320) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16321) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16322) (alt_if_stmt_without_else 16323) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16324) (attributes 16325) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16326) (class_modifier 96) (class_modifiers 16327) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16328) (expr 16329) (fn 103) (fully_dereferenceable 104) #'16330 (function_call 106) (function_declaration_statement 16331) (if_stmt 16332) (if_stmt_without_else 16333) (inline_function 110) (inner_statement 16334) (interface_declaration_statement 16335) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16336) (static_member 119) (trait_declaration_statement 16337) (variable 122) (variable_class_name 123) ("{" 16338) ("~" 125)) 7444 ((";" 16660)) 7445 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 16662) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 7446 (("%" 292) (")" 16663) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 7447 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 16664) (";" 16624) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16625) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16626) (T_DEC 22) (T_DECLARE 16627) (T_DIR 24) (T_DNUMBER 25) (T_DO 16628) (T_DOUBLE_CAST 27) (T_ECHO 16629) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16630) (T_FOREACH 16631) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16632) (T_GOTO 16633) (T_IF 16589) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16634) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16635) (T_START_HEREDOC 68) (T_STATIC 16636) (T_STRING 16637) (T_STRING_CAST 71) (T_SWITCH 16638) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16639) (T_UNSET 16640) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16641) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16642) (alt_if_stmt_without_else 16643) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16644) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16645) (if_stmt_without_else 16646) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16665) (static_member 119) (variable 122) (variable_class_name 123) (while_statement 16666) ("{" 16648) ("~" 125)) 7448 ((inner_statement_list 16667)) 7449 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16379) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16380) (T_CLASS 16381) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16382) (T_DEC 22) (T_DECLARE 16383) (T_DIR 24) (T_DNUMBER 25) (T_DO 16384) (T_DOUBLE_CAST 27) (T_ECHO 16385) (T_EMPTY 29) (T_ENDWHILE 16668) (T_ENUM 16387) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16388) (T_FOREACH 16389) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16390) (T_GOTO 16391) (T_HALT_COMPILER 16392) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16394) (T_INTERFACE 16395) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16396) (T_START_HEREDOC 68) (T_STATIC 16397) (T_STRING 16398) (T_STRING_CAST 71) (T_SWITCH 16399) (T_THROW 73) (T_TRAIT 16400) (T_TRAIT_C 75) (T_TRY 16401) (T_UNSET 16402) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16403) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16404) (alt_if_stmt_without_else 16405) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16406) (attributes 16407) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16408) (class_modifier 96) (class_modifiers 16409) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16410) (expr 16411) (fn 103) (fully_dereferenceable 104) #'16412 (function_call 106) (function_declaration_statement 16413) (if_stmt 16414) (if_stmt_without_else 16415) (inline_function 110) (inner_statement 16416) (interface_declaration_statement 16417) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16418) (static_member 119) (trait_declaration_statement 16419) (variable 122) (variable_class_name 123) ("{" 16420) ("~" 125)) 7450 ((";" 16669)) 7451 (("\"" 1509) ("$" 16475) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 16476) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 16477) ("[" 1529) (array_object_dereferenceable 16478) (callable_expr 16479) (callable_variable 16480) (class_constant 1533) (class_name 16481) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 16482) (name 16483) (simple_variable 16484) (static_member 16485) (unset_variable 16486) (unset_variables 16671) (variable 16488) (variable_class_name 16489)) 7452 (("," 16501) (possible_comma 16672)) 7453 ((")" 16673)) 7454 ((";" 16674)) 7455 ((inner_statement_list 16676)) 7456 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 16677) ("~" 125)) 7457 ((catch_list 16678)) 7458 ((T_CATCH 16679) (T_FINALLY 16680) (finally_statement 16681)) 7459 (("(" 16685)) 7460 (("{" 16682)) 7461 ((inner_statement_list 16683)) 7462 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 16684) ("~" 125)) 7463 ((T_NAME_FULLY_QUALIFIED 16545) (T_NAME_QUALIFIED 16546) (T_NAME_RELATIVE 16547) (T_STATIC 16548) (T_STRING 16549) (catch_name_list 16686) (class_name 16551) (name 16552)) 7464 ((T_VARIABLE 16553) (optional_variable 16687) ("|" 16555)) 7465 ((")" 16688)) 7466 (("{" 16689)) 7467 ((inner_statement_list 16690)) 7468 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 16691) ("~" 125)) 7469 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 16693) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 7470 (("%" 292) (")" 16694) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 7471 ((":" 16695) (switch_case_list 16696) ("{" 16697)) 7472 ((";" 16703) (case_list 16704)) 7473 ((";" 16698) (case_list 16699)) 7474 ((case_list 16701)) 7475 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 16700)) 7476 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 16702)) 7477 ((case_list 23815)) 7478 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 16707)) 7479 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 21806) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 7480 ((":" 16709) (";" 16710) (case_separator 16711)) 7481 ((";" 16708)) 7482 ((inner_statement_list 16712)) 7483 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16713) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16714) (T_CLASS 16715) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16716) (T_DEC 22) (T_DECLARE 16717) (T_DIR 24) (T_DNUMBER 25) (T_DO 16718) (T_DOUBLE_CAST 27) (T_ECHO 16719) (T_EMPTY 29) (T_ENUM 16720) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16721) (T_FOREACH 16722) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16723) (T_GOTO 16724) (T_HALT_COMPILER 16725) (T_IF 16726) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16727) (T_INTERFACE 16728) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16729) (T_START_HEREDOC 68) (T_STATIC 16730) (T_STRING 16731) (T_STRING_CAST 71) (T_SWITCH 16732) (T_THROW 73) (T_TRAIT 16733) (T_TRAIT_C 75) (T_TRY 16734) (T_UNSET 16735) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16736) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16737) (alt_if_stmt_without_else 16738) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16739) (attributes 16740) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16741) (class_modifier 96) (class_modifiers 16742) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16743) (expr 16744) (fn 103) (fully_dereferenceable 104) #'16745 (function_call 106) (function_declaration_statement 16746) (if_stmt 16747) (if_stmt_without_else 16748) (inline_function 110) (inner_statement 16749) (interface_declaration_statement 16750) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16751) (static_member 119) (trait_declaration_statement 16752) (variable 122) (variable_class_name 123) ("{" 16753) ("~" 125)) 7484 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 21742) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 7485 ((T_STRING 21735)) 7486 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 21733) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 7487 (("(" 21724)) 7488 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19746) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19747) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19748) (T_DEC 22) (T_DECLARE 19749) (T_DIR 24) (T_DNUMBER 25) (T_DO 19750) (T_DOUBLE_CAST 27) (T_ECHO 19751) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19752) (T_FOREACH 19753) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19754) (T_GOTO 19755) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19757) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19758) (T_START_HEREDOC 68) (T_STATIC 19759) (T_STRING 19760) (T_STRING_CAST 71) (T_SWITCH 19761) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19762) (T_UNSET 19763) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19764) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19765) (alt_if_stmt_without_else 19766) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19767) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19768) (if_stmt_without_else 19769) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 21718) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19771) ("~" 125)) 7489 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (echo_expr 19740) (echo_expr_list 21716) (expr 19742) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7490 ((T_STRING 21709)) 7491 (("(" 21696)) 7492 (("(" 21681)) 7493 (("$" 17870) (T_VARIABLE 17871) (global_var 17872) (global_var_list 21679) (simple_variable 17874)) 7494 ((T_STRING 21677)) 7495 (("(" 21674)) 7496 (("(" 21670)) 7497 ((T_STRING 21664)) 7498 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 21662) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 7499 ((T_FN 35) (T_FUNCTION 127) (T_VARIABLE 16848) (fn 103) #'134 (inline_function 16849) (static_var 16850) (static_var_list 21660)) 7500 ((":" 21659)) 7501 (("(" 21641)) 7502 ((T_STRING 21636)) 7503 (("{" 21619)) 7504 (("(" 21614)) 7505 (("(" 21605)) 7506 ((T_ELSE 21598) (T_ELSEIF 16203) (T_ENDIF 21599)) 7507 ((T_ABSTRACT 10) (T_ATTRIBUTE 13) (T_CLASS 16715) (T_ENUM 16720) (T_FINAL 34) (T_FN 35) (T_FUNCTION 38) (T_INTERFACE 16728) (T_READONLY 2936) (T_STATIC 16288) (T_TRAIT 16733) (attribute 16289) (attributed_statement 21597) (class_declaration_statement 16741) (class_modifier 96) (class_modifiers 16742) (enum_declaration_statement 16743) (fn 103) #'16745 (function_declaration_statement 16746) (inline_function 16291) (interface_declaration_statement 16750) (trait_declaration_statement 16752)) 7508 ((T_ABSTRACT 10) (T_CLASS 21589) (T_FINAL 34) (T_READONLY 2936) (class_modifier 16280)) 7509 (("%" 6465) ("*" 6466) ("+" 6467) ("-" 6468) ("." 6469) ("/" 6470) (";" 21588) ("<" 6471) (">" 6472) ("?" 6473) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 6474) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 6475) (T_BOOLEAN_AND 6476) (T_BOOLEAN_OR 6477) (T_COALESCE 6478) (T_INSTANCEOF 6479) (T_IS_EQUAL 6480) (T_IS_GREATER_OR_EQUAL 6481) (T_IS_IDENTICAL 6482) (T_IS_NOT_EQUAL 6483) (T_IS_NOT_IDENTICAL 6484) (T_IS_SMALLER_OR_EQUAL 6485) (T_LOGICAL_AND 6486) (T_LOGICAL_OR 6487) (T_LOGICAL_XOR 6488) (T_POW 6489) (T_SL 6490) (T_SPACESHIP 6491) (T_SR 6492) ("^" 6493) ("|" 6494)) 7510 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 16261) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 16262) (ampersand 16263) (returns_ref 21576)) 7511 ((T_ELSE 16756) (T_ELSEIF 16757)) 7512 ((inner_statement_list 16754)) 7513 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 16755) ("~" 125)) 7514 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16713) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16714) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16716) (T_DEC 22) (T_DECLARE 16717) (T_DIR 24) (T_DNUMBER 25) (T_DO 16718) (T_DOUBLE_CAST 27) (T_ECHO 16719) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16721) (T_FOREACH 16722) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16723) (T_GOTO 16724) (T_IF 16726) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16727) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16729) (T_START_HEREDOC 68) (T_STATIC 16730) (T_STRING 16731) (T_STRING_CAST 71) (T_SWITCH 16732) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16734) (T_UNSET 16735) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16736) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16737) (alt_if_stmt_without_else 16738) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16744) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16747) (if_stmt_without_else 16748) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 21575) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16753) ("~" 125)) 7515 (("(" 16758)) 7516 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 16759) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 7517 (("%" 292) (")" 16760) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 7518 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16761) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16762) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16763) (T_DEC 22) (T_DECLARE 16764) (T_DIR 24) (T_DNUMBER 25) (T_DO 16765) (T_DOUBLE_CAST 27) (T_ECHO 16766) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16767) (T_FOREACH 16768) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16769) (T_GOTO 16770) (T_IF 16726) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16771) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16772) (T_START_HEREDOC 68) (T_STATIC 16773) (T_STRING 16774) (T_STRING_CAST 71) (T_SWITCH 16775) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16776) (T_UNSET 16777) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16778) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16779) (alt_if_stmt_without_else 16780) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16781) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16782) (if_stmt_without_else 16783) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16784) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16785) ("~" 125)) 7519 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 21573) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 7520 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 21571) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 7521 (("(" 21562)) 7522 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19746) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19747) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19748) (T_DEC 22) (T_DECLARE 19749) (T_DIR 24) (T_DNUMBER 25) (T_DO 19750) (T_DOUBLE_CAST 27) (T_ECHO 19751) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19752) (T_FOREACH 19753) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19754) (T_GOTO 19755) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19757) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19758) (T_START_HEREDOC 68) (T_STATIC 19759) (T_STRING 19760) (T_STRING_CAST 71) (T_SWITCH 19761) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19762) (T_UNSET 19763) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19764) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19765) (alt_if_stmt_without_else 19766) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19767) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19768) (if_stmt_without_else 19769) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 21556) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19771) ("~" 125)) 7523 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (echo_expr 19740) (echo_expr_list 21554) (expr 19742) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7524 (("(" 21541)) 7525 (("(" 17882)) 7526 (("$" 17870) (T_VARIABLE 17871) (global_var 17872) (global_var_list 17873) (simple_variable 17874)) 7527 ((T_STRING 17868)) 7528 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 17866) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 7529 ((T_FN 35) (T_FUNCTION 127) (T_VARIABLE 16848) (fn 103) #'134 (inline_function 16849) (static_var 16850) (static_var_list 16851)) 7530 ((":" 16847)) 7531 (("(" 16829)) 7532 (("{" 16812)) 7533 (("(" 16807)) 7534 (("(" 16798)) 7535 ((T_ELSE 16791) (T_ELSEIF 16203) (T_ENDIF 16792)) 7536 (("%" 6465) ("*" 6466) ("+" 6467) ("-" 6468) ("." 6469) ("/" 6470) (";" 16790) ("<" 6471) (">" 6472) ("?" 6473) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 6474) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 6475) (T_BOOLEAN_AND 6476) (T_BOOLEAN_OR 6477) (T_COALESCE 6478) (T_INSTANCEOF 6479) (T_IS_EQUAL 6480) (T_IS_GREATER_OR_EQUAL 6481) (T_IS_IDENTICAL 6482) (T_IS_NOT_EQUAL 6483) (T_IS_NOT_IDENTICAL 6484) (T_IS_SMALLER_OR_EQUAL 6485) (T_LOGICAL_AND 6486) (T_LOGICAL_OR 6487) (T_LOGICAL_XOR 6488) (T_POW 6489) (T_SL 6490) (T_SPACESHIP 6491) (T_SR 6492) ("^" 6493) ("|" 6494)) 7537 ((T_ELSE 16788) (T_ELSEIF 16757)) 7538 ((inner_statement_list 16786)) 7539 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 16787) ("~" 125)) 7540 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16761) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16762) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16763) (T_DEC 22) (T_DECLARE 16764) (T_DIR 24) (T_DNUMBER 25) (T_DO 16765) (T_DOUBLE_CAST 27) (T_ECHO 16766) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16767) (T_FOREACH 16768) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16769) (T_GOTO 16770) (T_IF 16726) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16771) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16772) (T_START_HEREDOC 68) (T_STATIC 16773) (T_STRING 16774) (T_STRING_CAST 71) (T_SWITCH 16775) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16776) (T_UNSET 16777) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16778) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16779) (alt_if_stmt_without_else 16780) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16781) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16782) (if_stmt_without_else 16783) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16789) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16785) ("~" 125)) 7541 ((":" 16794)) 7542 ((";" 16793)) 7543 ((inner_statement_list 16795)) 7544 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16298) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16299) (T_CLASS 16300) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16301) (T_DEC 22) (T_DECLARE 16302) (T_DIR 24) (T_DNUMBER 25) (T_DO 16303) (T_DOUBLE_CAST 27) (T_ECHO 16304) (T_EMPTY 29) (T_ENDIF 16796) (T_ENUM 16306) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16307) (T_FOREACH 16308) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16309) (T_GOTO 16310) (T_HALT_COMPILER 16311) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16312) (T_INTERFACE 16313) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16314) (T_START_HEREDOC 68) (T_STATIC 16315) (T_STRING 16316) (T_STRING_CAST 71) (T_SWITCH 16317) (T_THROW 73) (T_TRAIT 16318) (T_TRAIT_C 75) (T_TRY 16319) (T_UNSET 16320) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16321) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16322) (alt_if_stmt_without_else 16323) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16324) (attributes 16325) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16326) (class_modifier 96) (class_modifiers 16327) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16328) (expr 16329) (fn 103) (fully_dereferenceable 104) #'16330 (function_call 106) (function_declaration_statement 16331) (if_stmt 16332) (if_stmt_without_else 16333) (inline_function 110) (inner_statement 16334) (interface_declaration_statement 16335) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16336) (static_member 119) (trait_declaration_statement 16337) (variable 122) (variable_class_name 123) ("{" 16338) ("~" 125)) 7545 ((";" 16797)) 7546 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 16799) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 7547 (("%" 292) (")" 16800) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 7548 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 16801) (";" 16761) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16762) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16763) (T_DEC 22) (T_DECLARE 16764) (T_DIR 24) (T_DNUMBER 25) (T_DO 16765) (T_DOUBLE_CAST 27) (T_ECHO 16766) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16767) (T_FOREACH 16768) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16769) (T_GOTO 16770) (T_IF 16726) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16771) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16772) (T_START_HEREDOC 68) (T_STATIC 16773) (T_STRING 16774) (T_STRING_CAST 71) (T_SWITCH 16775) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16776) (T_UNSET 16777) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16778) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16779) (alt_if_stmt_without_else 16780) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16781) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16782) (if_stmt_without_else 16783) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16802) (static_member 119) (variable 122) (variable_class_name 123) (while_statement 16803) ("{" 16785) ("~" 125)) 7549 ((inner_statement_list 16804)) 7550 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16379) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16380) (T_CLASS 16381) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16382) (T_DEC 22) (T_DECLARE 16383) (T_DIR 24) (T_DNUMBER 25) (T_DO 16384) (T_DOUBLE_CAST 27) (T_ECHO 16385) (T_EMPTY 29) (T_ENDWHILE 16805) (T_ENUM 16387) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16388) (T_FOREACH 16389) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16390) (T_GOTO 16391) (T_HALT_COMPILER 16392) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16394) (T_INTERFACE 16395) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16396) (T_START_HEREDOC 68) (T_STATIC 16397) (T_STRING 16398) (T_STRING_CAST 71) (T_SWITCH 16399) (T_THROW 73) (T_TRAIT 16400) (T_TRAIT_C 75) (T_TRY 16401) (T_UNSET 16402) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16403) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16404) (alt_if_stmt_without_else 16405) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16406) (attributes 16407) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16408) (class_modifier 96) (class_modifiers 16409) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16410) (expr 16411) (fn 103) (fully_dereferenceable 104) #'16412 (function_call 106) (function_declaration_statement 16413) (if_stmt 16414) (if_stmt_without_else 16415) (inline_function 110) (inner_statement 16416) (interface_declaration_statement 16417) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16418) (static_member 119) (trait_declaration_statement 16419) (variable 122) (variable_class_name 123) ("{" 16420) ("~" 125)) 7551 ((";" 16806)) 7552 (("\"" 1509) ("$" 16475) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 16476) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 16477) ("[" 1529) (array_object_dereferenceable 16478) (callable_expr 16479) (callable_variable 16480) (class_constant 1533) (class_name 16481) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 16482) (name 16483) (simple_variable 16484) (static_member 16485) (unset_variable 16486) (unset_variables 16808) (variable 16488) (variable_class_name 16489)) 7553 (("," 16501) (possible_comma 16809)) 7554 ((")" 16810)) 7555 ((";" 16811)) 7556 ((inner_statement_list 16813)) 7557 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 16814) ("~" 125)) 7558 ((catch_list 16815)) 7559 ((T_CATCH 16816) (T_FINALLY 16817) (finally_statement 16818)) 7560 (("(" 16822)) 7561 (("{" 16819)) 7562 ((inner_statement_list 16820)) 7563 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 16821) ("~" 125)) 7564 ((T_NAME_FULLY_QUALIFIED 16545) (T_NAME_QUALIFIED 16546) (T_NAME_RELATIVE 16547) (T_STATIC 16548) (T_STRING 16549) (catch_name_list 16823) (class_name 16551) (name 16552)) 7565 ((T_VARIABLE 16553) (optional_variable 16824) ("|" 16555)) 7566 ((")" 16825)) 7567 (("{" 16826)) 7568 ((inner_statement_list 16827)) 7569 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 16828) ("~" 125)) 7570 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 16830) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 7571 (("%" 292) (")" 16831) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 7572 ((":" 16832) (switch_case_list 16833) ("{" 16834)) 7573 ((";" 16840) (case_list 16841)) 7574 ((";" 16835) (case_list 16836)) 7575 ((case_list 16838)) 7576 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 16837)) 7577 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 16839)) 7578 ((case_list 16844)) 7579 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 16842)) 7580 ((";" 16843)) 7581 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 16845)) 7582 ((";" 16846)) 7583 (("=" 16855)) 7584 (("," 16852) (";" 16853)) 7585 ((T_VARIABLE 16848) (static_var 16854)) 7586 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 16918) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7587 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17864) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7588 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 17862) (encaps_var 5299)) 7589 (("$" 16858) (T_VARIABLE 16905) (simple_variable 17858) ("{" 17859)) 7590 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 17856) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 7591 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17855) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7592 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17854) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7593 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17853) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7594 (("(" 17850)) 7595 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17849) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7596 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17848) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7597 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17847) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7598 (("\"" 1509) ("$" 17161) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 17162) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 17163) ("[" 1529) (array_object_dereferenceable 17164) (callable_expr 17165) (callable_variable 17166) (class_constant 1533) (class_name 17167) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 17168) (name 17169) (simple_variable 17170) (static_member 17171) (variable 17846) (variable_class_name 17173)) 7599 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17845) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7600 (("(" 17842)) 7601 (("(" 17839)) 7602 (("(" 17835) (exit_expr 17836)) 7603 (("\"" 1509) ("$" 17161) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 17162) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 17163) ("[" 1529) (array_object_dereferenceable 17164) (callable_expr 17165) (callable_variable 17166) (class_constant 1533) (class_name 17167) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 17168) (name 17169) (simple_variable 17170) (static_member 17171) (variable 17834) (variable_class_name 17173)) 7604 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17833) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7605 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17832) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7606 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17831) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7607 (("(" 17827)) 7608 (("(" 17822)) 7609 (("(" 17816)) 7610 (("$" 3371) ("(" 5668) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 5669) (T_NAME_QUALIFIED 5670) (T_NAME_RELATIVE 5671) (T_READONLY 2936) (T_STATIC 5672) (T_STRING 5673) (T_VARIABLE 3373) (anonymous_class 17794) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 17795) (attribute 2943) (attributes 17796) (class_modifier 2945) (class_name 5677) (class_name_reference 17797) (name 5679) (new_variable 5680) (simple_variable 5681)) 7611 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17793) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7612 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17792) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7613 (("(" 17122) (argument_list 17791)) 7614 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17790) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7615 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17789) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7616 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 17784) (T_END_HEREDOC 17785) (T_VARIABLE 2900) (encaps_list 17786) (encaps_var 2902)) 7617 ((T_FN 35) (T_FUNCTION 127) (fn 16919) #'16920 (inline_function 17783)) 7618 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17782) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7619 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17781) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7620 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17780) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7621 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17335) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7622 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17272) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7623 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 17268) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 7624 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 17266) (encaps_list 2805) (encaps_var 2806)) 7625 ((T_NULLSAFE_OBJECT_OPERATOR 17249) (T_OBJECT_OPERATOR 17250) ("[" 17251) ("{" 17252)) 7626 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 17246) (attribute 2728) (fn 16919) #'16920 (inline_function 17247)) 7627 (("(" 17122) (argument_list 17245)) 7628 ((T_PAAMAYIM_NEKUDOTAYIM 17237)) 7629 (("%" 16934) ("*" 16935) ("+" 16936) ("-" 16937) ("." 16938) ("/" 16939) ("<" 16940) (">" 16941) ("?" 16942) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 16943) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 16944) (T_BOOLEAN_AND 16945) (T_BOOLEAN_OR 16946) (T_COALESCE 16947) (T_INSTANCEOF 16948) (T_IS_EQUAL 16949) (T_IS_GREATER_OR_EQUAL 16950) (T_IS_IDENTICAL 16951) (T_IS_NOT_EQUAL 16952) (T_IS_NOT_IDENTICAL 16953) (T_IS_SMALLER_OR_EQUAL 16954) (T_LOGICAL_AND 16955) (T_LOGICAL_OR 16956) (T_LOGICAL_XOR 16957) (T_POW 16958) (T_SL 16959) (T_SPACESHIP 16960) (T_SR 16961) ("^" 16962) ("|" 16963)) 7630 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 17226)) 7631 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 17214)) 7632 (("(" 17122) (argument_list 17213)) 7633 (("=" 17130) (T_AND_EQUAL 17131) (T_COALESCE_EQUAL 17132) (T_CONCAT_EQUAL 17133) (T_DEC 17134) (T_DIV_EQUAL 17135) (T_INC 17136) (T_MINUS_EQUAL 17137) (T_MOD_EQUAL 17138) (T_MUL_EQUAL 17139) (T_OR_EQUAL 17140) (T_PLUS_EQUAL 17141) (T_POW_EQUAL 17142) (T_SL_EQUAL 17143) (T_SR_EQUAL 17144) (T_XOR_EQUAL 17145)) 7634 ((T_PAAMAYIM_NEKUDOTAYIM 17035)) 7635 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 16933) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7636 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17034) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7637 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17033) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7638 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17032) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7639 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17031) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7640 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17030) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7641 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17029) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7642 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17028) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7643 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17027) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7644 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 17022) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 17023) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 7645 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17021) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7646 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17020) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7647 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17019) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7648 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17018) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7649 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17017) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7650 (("$" 16979) ("(" 16980) (T_NAME_FULLY_QUALIFIED 16981) (T_NAME_QUALIFIED 16982) (T_NAME_RELATIVE 16983) (T_STATIC 16984) (T_STRING 16985) (T_VARIABLE 16986) (class_name 16987) (class_name_reference 16988) (name 16989) (new_variable 16990) (simple_variable 16991)) 7651 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 16978) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7652 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 16977) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7653 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 16976) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7654 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 16975) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7655 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 16974) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7656 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 16973) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7657 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 16972) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7658 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 16971) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7659 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 16970) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7660 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 16969) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7661 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 16968) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7662 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 16967) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7663 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 16966) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7664 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 16965) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7665 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 16964) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7666 (("$" 16979) (T_VARIABLE 16986) (simple_variable 17013) ("{" 17014)) 7667 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 17011) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 7668 ((T_PAAMAYIM_NEKUDOTAYIM 17009)) 7669 ((T_NULLSAFE_OBJECT_OPERATOR 16992) (T_OBJECT_OPERATOR 16993) (T_PAAMAYIM_NEKUDOTAYIM 16994) ("[" 16995) ("{" 16996)) 7670 (("$" 16979) (T_STRING 17002) (T_VARIABLE 16986) (property_name 17008) (simple_variable 17004) ("{" 17005)) 7671 (("$" 16979) (T_STRING 17002) (T_VARIABLE 16986) (property_name 17003) (simple_variable 17004) ("{" 17005)) 7672 (("$" 16979) (T_VARIABLE 16986) (simple_variable 17001)) 7673 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 16999) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 7674 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 16997) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 7675 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 16998)) 7676 (("]" 17000)) 7677 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 17006) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 7678 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 17007)) 7679 (("$" 16979) (T_VARIABLE 16986) (simple_variable 17010)) 7680 (("%" 292) (")" 17012) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 7681 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 17015) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 7682 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 17016)) 7683 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17026) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7684 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 17024) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 7685 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17025) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7686 (("$" 16858) (T_ABSTRACT 17036) (T_ARRAY 17037) (T_AS 17038) (T_BREAK 17039) (T_CALLABLE 17040) (T_CASE 17041) (T_CATCH 17042) (T_CLASS 17043) (T_CLASS_C 17044) (T_CLONE 17045) (T_CONST 17046) (T_CONTINUE 17047) (T_DECLARE 17048) (T_DEFAULT 17049) (T_DIR 17050) (T_DO 17051) (T_ECHO 17052) (T_ELSE 17053) (T_ELSEIF 17054) (T_EMPTY 17055) (T_ENDDECLARE 17056) (T_ENDFOR 17057) (T_ENDFOREACH 17058) (T_ENDIF 17059) (T_ENDSWITCH 17060) (T_ENDWHILE 17061) (T_ENUM 17062) (T_EVAL 17063) (T_EXIT 17064) (T_EXTENDS 17065) (T_FILE 17066) (T_FINAL 17067) (T_FINALLY 17068) (T_FN 17069) (T_FOR 17070) (T_FOREACH 17071) (T_FUNCTION 17072) (T_FUNC_C 17073) (T_GLOBAL 17074) (T_GOTO 17075) (T_IF 17076) (T_IMPLEMENTS 17077) (T_INCLUDE 17078) (T_INCLUDE_ONCE 17079) (T_INSTANCEOF 17080) (T_INSTEADOF 17081) (T_INTERFACE 17082) (T_ISSET 17083) (T_LINE 17084) (T_LIST 17085) (T_LOGICAL_AND 17086) (T_LOGICAL_OR 17087) (T_LOGICAL_XOR 17088) (T_MATCH 17089) (T_METHOD_C 17090) (T_NAMESPACE 17091) (T_NEW 17092) (T_NS_C 17093) (T_PRINT 17094) (T_PRIVATE 17095) (T_PROTECTED 17096) (T_PUBLIC 17097) (T_READONLY 17098) (T_REQUIRE 17099) (T_REQUIRE_ONCE 17100) (T_RETURN 17101) (T_STATIC 17102) (T_STRING 17103) (T_SWITCH 17104) (T_THROW 17105) (T_TRAIT 17106) (T_TRAIT_C 17107) (T_TRY 17108) (T_UNSET 17109) (T_USE 17110) (T_VAR 17111) (T_VARIABLE 16905) (T_WHILE 17112) (T_YIELD 17113) (identifier 17114) (member_name 17115) (reserved_non_modifiers 17116) (semi_reserved 17117) (simple_variable 17118) ("{" 17119)) 7687 (("(" 17122) (argument_list 17123)) 7688 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 17120) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 7689 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 17121)) 7690 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 17124) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 17125) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 17126) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 7691 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 17129) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 7692 (("," 1469) (possible_comma 17127)) 7693 ((")" 17128)) 7694 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (ampersand 17159) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17160) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7695 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17158) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7696 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17157) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7697 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17156) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7698 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17155) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7699 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17154) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7700 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17153) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7701 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17152) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7702 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17151) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7703 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17150) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7704 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17149) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7705 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17148) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7706 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17147) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7707 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17146) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7708 (("\"" 1509) ("$" 17161) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 17162) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 17163) ("[" 1529) (array_object_dereferenceable 17164) (callable_expr 17165) (callable_variable 17166) (class_constant 1533) (class_name 17167) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 17168) (name 17169) (simple_variable 17170) (static_member 17171) (variable 17172) (variable_class_name 17173)) 7709 (("$" 17161) (T_VARIABLE 17163) (simple_variable 17209) ("{" 17210)) 7710 (("(" 17177) (argument_list 17208)) 7711 ((T_NULLSAFE_OBJECT_OPERATOR 17191) (T_OBJECT_OPERATOR 17192) ("[" 17193) ("{" 17194)) 7712 (("(" 17177) (argument_list 17190)) 7713 ((T_PAAMAYIM_NEKUDOTAYIM 17186)) 7714 (("(" 17177) (argument_list 17185)) 7715 ((T_PAAMAYIM_NEKUDOTAYIM 17174)) 7716 (("$" 17161) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 17163) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 17175) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 17176) ("{" 1627)) 7717 (("(" 17177) (argument_list 17178)) 7718 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 17179) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 17180) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 17181) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 7719 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 17184) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 7720 (("," 1469) (possible_comma 17182)) 7721 ((")" 17183)) 7722 (("$" 17161) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 17163) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 17187) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 17188) ("{" 1643)) 7723 (("(" 17177) (argument_list 17189)) 7724 (("$" 17161) (T_STRING 17199) (T_VARIABLE 17163) (property_name 17206) (simple_variable 17201) ("{" 17202)) 7725 (("$" 17161) (T_STRING 17199) (T_VARIABLE 17163) (property_name 17200) (simple_variable 17201) ("{" 17202)) 7726 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 17197) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 7727 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 17195) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 7728 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 17196)) 7729 (("]" 17198)) 7730 (("(" 17177) (argument_list 17205)) 7731 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 17203) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 7732 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 17204)) 7733 (("(" 17177) (argument_list 17207)) 7734 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 17211) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 7735 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 17212)) 7736 ((backup_doc_comment 17215)) 7737 (("(" 17216)) 7738 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 17217)) 7739 ((")" 17218)) 7740 ((T_USE 159) (lexical_vars 17219)) 7741 ((":" 161) (return_type 17220)) 7742 ((backup_fn_flags 17221)) 7743 (("{" 17222)) 7744 ((inner_statement_list 17223)) 7745 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 17224) ("~" 125)) 7746 ((backup_fn_flags 17225)) 7747 ((backup_doc_comment 17227)) 7748 (("(" 17228)) 7749 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 17229)) 7750 ((")" 17230)) 7751 ((":" 2241) (return_type 17231)) 7752 ((T_DOUBLE_ARROW 17232)) 7753 ((backup_fn_flags 17233)) 7754 ((backup_lex_pos 17234)) 7755 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 17235) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 7756 (("%" 3144) ("*" 3145) ("+" 3146) ("-" 3147) ("." 3148) ("/" 3149) ("<" 3150) (">" 3151) ("?" 3152) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 3153) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 3154) (T_BOOLEAN_AND 3155) (T_BOOLEAN_OR 3156) (T_COALESCE 3157) (T_INSTANCEOF 3158) (T_IS_EQUAL 3159) (T_IS_GREATER_OR_EQUAL 3160) (T_IS_IDENTICAL 3161) (T_IS_NOT_EQUAL 3162) (T_IS_NOT_IDENTICAL 3163) (T_IS_SMALLER_OR_EQUAL 3164) (T_LOGICAL_AND 3165) (T_LOGICAL_OR 3166) (T_LOGICAL_XOR 3167) (T_POW 3168) (T_SL 3169) (T_SPACESHIP 3170) (T_SR 3171) ("^" 3172) (backup_fn_flags 17236) ("|" 3173)) 7757 (("$" 16858) (T_ABSTRACT 17036) (T_ARRAY 17037) (T_AS 17038) (T_BREAK 17039) (T_CALLABLE 17040) (T_CASE 17041) (T_CATCH 17042) (T_CLASS 17043) (T_CLASS_C 17044) (T_CLONE 17045) (T_CONST 17046) (T_CONTINUE 17047) (T_DECLARE 17048) (T_DEFAULT 17049) (T_DIR 17050) (T_DO 17051) (T_ECHO 17052) (T_ELSE 17053) (T_ELSEIF 17054) (T_EMPTY 17055) (T_ENDDECLARE 17056) (T_ENDFOR 17057) (T_ENDFOREACH 17058) (T_ENDIF 17059) (T_ENDSWITCH 17060) (T_ENDWHILE 17061) (T_ENUM 17062) (T_EVAL 17063) (T_EXIT 17064) (T_EXTENDS 17065) (T_FILE 17066) (T_FINAL 17067) (T_FINALLY 17068) (T_FN 17069) (T_FOR 17070) (T_FOREACH 17071) (T_FUNCTION 17072) (T_FUNC_C 17073) (T_GLOBAL 17074) (T_GOTO 17075) (T_IF 17076) (T_IMPLEMENTS 17077) (T_INCLUDE 17078) (T_INCLUDE_ONCE 17079) (T_INSTANCEOF 17080) (T_INSTEADOF 17081) (T_INTERFACE 17082) (T_ISSET 17083) (T_LINE 17084) (T_LIST 17085) (T_LOGICAL_AND 17086) (T_LOGICAL_OR 17087) (T_LOGICAL_XOR 17088) (T_MATCH 17089) (T_METHOD_C 17090) (T_NAMESPACE 17091) (T_NEW 17092) (T_NS_C 17093) (T_PRINT 17094) (T_PRIVATE 17095) (T_PROTECTED 17096) (T_PUBLIC 17097) (T_READONLY 17098) (T_REQUIRE 17099) (T_REQUIRE_ONCE 17100) (T_RETURN 17101) (T_STATIC 17102) (T_STRING 17103) (T_SWITCH 17104) (T_THROW 17105) (T_TRAIT 17106) (T_TRAIT_C 17107) (T_TRY 17108) (T_UNSET 17109) (T_USE 17110) (T_VAR 17111) (T_VARIABLE 16905) (T_WHILE 17112) (T_YIELD 17113) (identifier 17238) (member_name 17239) (reserved_non_modifiers 17116) (semi_reserved 17117) (simple_variable 17240) ("{" 17241)) 7758 (("(" 17122) (argument_list 17244)) 7759 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 17242) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 7760 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 17243)) 7761 ((T_FN 35) (T_FUNCTION 127) (fn 16919) #'16920 (inline_function 17248)) 7762 (("$" 16858) (T_STRING 17257) (T_VARIABLE 16905) (property_name 17264) (simple_variable 17259) ("{" 17260)) 7763 (("$" 16858) (T_STRING 17257) (T_VARIABLE 16905) (property_name 17258) (simple_variable 17259) ("{" 17260)) 7764 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 17255) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 7765 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 17253) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 7766 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 17254)) 7767 (("]" 17256)) 7768 (("(" 17122) (argument_list 17263)) 7769 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 17261) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 7770 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 17262)) 7771 (("(" 17122) (argument_list 17265)) 7772 (("`" 17267)) 7773 (("]" 17269)) 7774 (("=" 17270)) 7775 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17271) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7776 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17779) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7777 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 17777) (encaps_var 5299)) 7778 (("$" 17275) (T_VARIABLE 17322) (simple_variable 17773) ("{" 17774)) 7779 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 17771) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 7780 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17770) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7781 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17769) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7782 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17768) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7783 (("(" 17765)) 7784 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17764) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7785 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17763) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7786 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17762) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7787 (("\"" 1509) ("$" 17578) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 17579) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 17580) ("[" 1529) (array_object_dereferenceable 17581) (callable_expr 17582) (callable_variable 17583) (class_constant 1533) (class_name 17584) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 17585) (name 17586) (simple_variable 17587) (static_member 17588) (variable 17761) (variable_class_name 17590)) 7788 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17760) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7789 (("(" 17757)) 7790 (("(" 17754)) 7791 (("(" 17750) (exit_expr 17751)) 7792 (("\"" 1509) ("$" 17578) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 17579) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 17580) ("[" 1529) (array_object_dereferenceable 17581) (callable_expr 17582) (callable_variable 17583) (class_constant 1533) (class_name 17584) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 17585) (name 17586) (simple_variable 17587) (static_member 17588) (variable 17749) (variable_class_name 17590)) 7793 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17748) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7794 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17747) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7795 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17746) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7796 (("(" 17742)) 7797 (("(" 17737)) 7798 (("(" 17731)) 7799 (("$" 3789) ("(" 3920) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 3921) (T_NAME_QUALIFIED 3922) (T_NAME_RELATIVE 3923) (T_READONLY 2936) (T_STATIC 3924) (T_STRING 3925) (T_VARIABLE 3791) (anonymous_class 17709) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 17710) (attribute 2943) (attributes 17711) (class_modifier 2945) (class_name 3929) (class_name_reference 17712) (name 3931) (new_variable 3932) (simple_variable 3933)) 7800 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17708) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7801 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17707) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7802 (("(" 17539) (argument_list 17706)) 7803 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17705) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7804 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17704) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7805 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 17699) (T_END_HEREDOC 17700) (T_VARIABLE 2900) (encaps_list 17701) (encaps_var 2902)) 7806 ((T_FN 35) (T_FUNCTION 127) (fn 17336) #'17337 (inline_function 17698)) 7807 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17697) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7808 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17696) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7809 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17695) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7810 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17692) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7811 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17691) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7812 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 17687) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 7813 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 17685) (encaps_list 2805) (encaps_var 2806)) 7814 ((T_NULLSAFE_OBJECT_OPERATOR 17668) (T_OBJECT_OPERATOR 17669) ("[" 17670) ("{" 17671)) 7815 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 17665) (attribute 2728) (fn 17336) #'17337 (inline_function 17666)) 7816 (("(" 17539) (argument_list 17664)) 7817 ((T_PAAMAYIM_NEKUDOTAYIM 17656)) 7818 (("%" 17351) ("*" 17352) ("+" 17353) ("-" 17354) ("." 17355) ("/" 17356) ("<" 17357) (">" 17358) ("?" 17359) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 17360) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 17361) (T_BOOLEAN_AND 17362) (T_BOOLEAN_OR 17363) (T_COALESCE 17364) (T_DOUBLE_ARROW 17654) (T_INSTANCEOF 17365) (T_IS_EQUAL 17366) (T_IS_GREATER_OR_EQUAL 17367) (T_IS_IDENTICAL 17368) (T_IS_NOT_EQUAL 17369) (T_IS_NOT_IDENTICAL 17370) (T_IS_SMALLER_OR_EQUAL 17371) (T_LOGICAL_AND 17372) (T_LOGICAL_OR 17373) (T_LOGICAL_XOR 17374) (T_POW 17375) (T_SL 17376) (T_SPACESHIP 17377) (T_SR 17378) ("^" 17379) ("|" 17380)) 7819 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 17643)) 7820 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 17631)) 7821 (("(" 17539) (argument_list 17630)) 7822 (("=" 17547) (T_AND_EQUAL 17548) (T_COALESCE_EQUAL 17549) (T_CONCAT_EQUAL 17550) (T_DEC 17551) (T_DIV_EQUAL 17552) (T_INC 17553) (T_MINUS_EQUAL 17554) (T_MOD_EQUAL 17555) (T_MUL_EQUAL 17556) (T_OR_EQUAL 17557) (T_PLUS_EQUAL 17558) (T_POW_EQUAL 17559) (T_SL_EQUAL 17560) (T_SR_EQUAL 17561) (T_XOR_EQUAL 17562)) 7823 ((T_PAAMAYIM_NEKUDOTAYIM 17452)) 7824 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17350) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7825 (("%" 17351) ("*" 17352) ("+" 17353) ("-" 17354) ("." 17355) ("/" 17356) ("<" 17357) (">" 17358) ("?" 17359) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 17360) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 17361) (T_BOOLEAN_AND 17362) (T_BOOLEAN_OR 17363) (T_COALESCE 17364) (T_INSTANCEOF 17365) (T_IS_EQUAL 17366) (T_IS_GREATER_OR_EQUAL 17367) (T_IS_IDENTICAL 17368) (T_IS_NOT_EQUAL 17369) (T_IS_NOT_IDENTICAL 17370) (T_IS_SMALLER_OR_EQUAL 17371) (T_LOGICAL_AND 17372) (T_LOGICAL_OR 17373) (T_LOGICAL_XOR 17374) (T_POW 17375) (T_SL 17376) (T_SPACESHIP 17377) (T_SR 17378) ("^" 17379) ("|" 17380)) 7826 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17451) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7827 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17450) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7828 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17449) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7829 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17448) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7830 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17447) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7831 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17446) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7832 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17445) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7833 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17444) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7834 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 17439) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 17440) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 7835 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17438) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7836 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17437) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7837 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17436) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7838 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17435) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7839 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17434) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7840 (("$" 17396) ("(" 17397) (T_NAME_FULLY_QUALIFIED 17398) (T_NAME_QUALIFIED 17399) (T_NAME_RELATIVE 17400) (T_STATIC 17401) (T_STRING 17402) (T_VARIABLE 17403) (class_name 17404) (class_name_reference 17405) (name 17406) (new_variable 17407) (simple_variable 17408)) 7841 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17395) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7842 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17394) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7843 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17393) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7844 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17392) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7845 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17391) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7846 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17390) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7847 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17389) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7848 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17388) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7849 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17387) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7850 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17386) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7851 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17385) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7852 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17384) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7853 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17383) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7854 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17382) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7855 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17381) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7856 (("$" 17396) (T_VARIABLE 17403) (simple_variable 17430) ("{" 17431)) 7857 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 17428) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 7858 ((T_PAAMAYIM_NEKUDOTAYIM 17426)) 7859 ((T_NULLSAFE_OBJECT_OPERATOR 17409) (T_OBJECT_OPERATOR 17410) (T_PAAMAYIM_NEKUDOTAYIM 17411) ("[" 17412) ("{" 17413)) 7860 (("$" 17396) (T_STRING 17419) (T_VARIABLE 17403) (property_name 17425) (simple_variable 17421) ("{" 17422)) 7861 (("$" 17396) (T_STRING 17419) (T_VARIABLE 17403) (property_name 17420) (simple_variable 17421) ("{" 17422)) 7862 (("$" 17396) (T_VARIABLE 17403) (simple_variable 17418)) 7863 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 17416) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 7864 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 17414) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 7865 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 17415)) 7866 (("]" 17417)) 7867 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 17423) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 7868 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 17424)) 7869 (("$" 17396) (T_VARIABLE 17403) (simple_variable 17427)) 7870 (("%" 292) (")" 17429) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 7871 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 17432) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 7872 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 17433)) 7873 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17443) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7874 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 17441) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 7875 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17442) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7876 (("$" 17275) (T_ABSTRACT 17453) (T_ARRAY 17454) (T_AS 17455) (T_BREAK 17456) (T_CALLABLE 17457) (T_CASE 17458) (T_CATCH 17459) (T_CLASS 17460) (T_CLASS_C 17461) (T_CLONE 17462) (T_CONST 17463) (T_CONTINUE 17464) (T_DECLARE 17465) (T_DEFAULT 17466) (T_DIR 17467) (T_DO 17468) (T_ECHO 17469) (T_ELSE 17470) (T_ELSEIF 17471) (T_EMPTY 17472) (T_ENDDECLARE 17473) (T_ENDFOR 17474) (T_ENDFOREACH 17475) (T_ENDIF 17476) (T_ENDSWITCH 17477) (T_ENDWHILE 17478) (T_ENUM 17479) (T_EVAL 17480) (T_EXIT 17481) (T_EXTENDS 17482) (T_FILE 17483) (T_FINAL 17484) (T_FINALLY 17485) (T_FN 17486) (T_FOR 17487) (T_FOREACH 17488) (T_FUNCTION 17489) (T_FUNC_C 17490) (T_GLOBAL 17491) (T_GOTO 17492) (T_IF 17493) (T_IMPLEMENTS 17494) (T_INCLUDE 17495) (T_INCLUDE_ONCE 17496) (T_INSTANCEOF 17497) (T_INSTEADOF 17498) (T_INTERFACE 17499) (T_ISSET 17500) (T_LINE 17501) (T_LIST 17502) (T_LOGICAL_AND 17503) (T_LOGICAL_OR 17504) (T_LOGICAL_XOR 17505) (T_MATCH 17506) (T_METHOD_C 17507) (T_NAMESPACE 17508) (T_NEW 17509) (T_NS_C 17510) (T_PRINT 17511) (T_PRIVATE 17512) (T_PROTECTED 17513) (T_PUBLIC 17514) (T_READONLY 17515) (T_REQUIRE 17516) (T_REQUIRE_ONCE 17517) (T_RETURN 17518) (T_STATIC 17519) (T_STRING 17520) (T_SWITCH 17521) (T_THROW 17522) (T_TRAIT 17523) (T_TRAIT_C 17524) (T_TRY 17525) (T_UNSET 17526) (T_USE 17527) (T_VAR 17528) (T_VARIABLE 17322) (T_WHILE 17529) (T_YIELD 17530) (identifier 17531) (member_name 17532) (reserved_non_modifiers 17533) (semi_reserved 17534) (simple_variable 17535) ("{" 17536)) 7877 (("(" 17539) (argument_list 17540)) 7878 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 17537) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 7879 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 17538)) 7880 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 17541) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 17542) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 17543) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 7881 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 17546) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 7882 (("," 1469) (possible_comma 17544)) 7883 ((")" 17545)) 7884 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (ampersand 17576) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17577) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7885 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17575) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7886 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17574) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7887 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17573) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7888 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17572) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7889 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17571) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7890 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17570) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7891 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17569) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7892 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17568) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7893 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17567) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7894 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17566) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7895 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17565) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7896 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17564) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7897 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17563) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7898 (("\"" 1509) ("$" 17578) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 17579) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 17580) ("[" 1529) (array_object_dereferenceable 17581) (callable_expr 17582) (callable_variable 17583) (class_constant 1533) (class_name 17584) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 17585) (name 17586) (simple_variable 17587) (static_member 17588) (variable 17589) (variable_class_name 17590)) 7899 (("$" 17578) (T_VARIABLE 17580) (simple_variable 17626) ("{" 17627)) 7900 (("(" 17594) (argument_list 17625)) 7901 ((T_NULLSAFE_OBJECT_OPERATOR 17608) (T_OBJECT_OPERATOR 17609) ("[" 17610) ("{" 17611)) 7902 (("(" 17594) (argument_list 17607)) 7903 ((T_PAAMAYIM_NEKUDOTAYIM 17603)) 7904 (("(" 17594) (argument_list 17602)) 7905 ((T_PAAMAYIM_NEKUDOTAYIM 17591)) 7906 (("$" 17578) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 17580) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 17592) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 17593) ("{" 1627)) 7907 (("(" 17594) (argument_list 17595)) 7908 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 17596) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 17597) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 17598) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 7909 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 17601) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 7910 (("," 1469) (possible_comma 17599)) 7911 ((")" 17600)) 7912 (("$" 17578) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 17580) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 17604) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 17605) ("{" 1643)) 7913 (("(" 17594) (argument_list 17606)) 7914 (("$" 17578) (T_STRING 17616) (T_VARIABLE 17580) (property_name 17623) (simple_variable 17618) ("{" 17619)) 7915 (("$" 17578) (T_STRING 17616) (T_VARIABLE 17580) (property_name 17617) (simple_variable 17618) ("{" 17619)) 7916 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 17614) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 7917 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 17612) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 7918 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 17613)) 7919 (("]" 17615)) 7920 (("(" 17594) (argument_list 17622)) 7921 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 17620) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 7922 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 17621)) 7923 (("(" 17594) (argument_list 17624)) 7924 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 17628) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 7925 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 17629)) 7926 ((backup_doc_comment 17632)) 7927 (("(" 17633)) 7928 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 17634)) 7929 ((")" 17635)) 7930 ((T_USE 159) (lexical_vars 17636)) 7931 ((":" 161) (return_type 17637)) 7932 ((backup_fn_flags 17638)) 7933 (("{" 17639)) 7934 ((inner_statement_list 17640)) 7935 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 17641) ("~" 125)) 7936 ((backup_fn_flags 17642)) 7937 ((backup_doc_comment 17644)) 7938 (("(" 17645)) 7939 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 17646)) 7940 ((")" 17647)) 7941 ((":" 2241) (return_type 17648)) 7942 ((T_DOUBLE_ARROW 17649)) 7943 ((backup_fn_flags 17650)) 7944 ((backup_lex_pos 17651)) 7945 (("!" 3484) ("\"" 3485) ("$" 3486) ("(" 3487) ("+" 3488) ("-" 3489) ("@" 3490) (T_ARRAY 3491) (T_ARRAY_CAST 3492) (T_ATTRIBUTE 126) (T_BOOL_CAST 3493) (T_CLASS_C 3494) (T_CLONE 3495) (T_CONSTANT_ENCAPSED_STRING 3496) (T_DEC 3497) (T_DIR 3498) (T_DNUMBER 3499) (T_DOUBLE_CAST 3500) (T_EMPTY 3501) (T_EVAL 3502) (T_EXIT 3503) (T_FILE 3504) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3505) (T_INC 3506) (T_INCLUDE 3507) (T_INCLUDE_ONCE 3508) (T_INT_CAST 3509) (T_ISSET 3510) (T_LINE 3511) (T_LIST 3512) (T_LNUMBER 3513) (T_MATCH 3514) (T_METHOD_C 3515) (T_NAME_FULLY_QUALIFIED 3516) (T_NAME_QUALIFIED 3517) (T_NAME_RELATIVE 3518) (T_NEW 3519) (T_NS_C 3520) (T_OBJECT_CAST 3521) (T_PRINT 3522) (T_READONLY 3523) (T_REQUIRE 3524) (T_REQUIRE_ONCE 3525) (T_START_HEREDOC 3526) (T_STATIC 3527) (T_STRING 3528) (T_STRING_CAST 3529) (T_THROW 3530) (T_TRAIT_C 3531) (T_UNSET_CAST 3532) (T_VARIABLE 3533) (T_YIELD 3534) (T_YIELD_FROM 3535) ("[" 3536) ("`" 3537) (array_object_dereferenceable 3538) (attribute 131) (attributes 3539) (callable_expr 3540) (callable_variable 3541) (class_constant 3542) (class_name 3543) (constant 3544) (dereferenceable_scalar 3545) (expr 17652) (fn 3547) (fully_dereferenceable 104) #'3548 (function_call 3549) (inline_function 3550) (internal_functions_in_yacc 3551) (match 3552) (name 3553) (new_expr 3554) (scalar 3555) (simple_variable 3556) (static_member 3557) (variable 3558) (variable_class_name 3559) ("~" 3560)) 7946 (("%" 3562) ("*" 3563) ("+" 3564) ("-" 3565) ("." 3566) ("/" 3567) ("<" 3568) (">" 3569) ("?" 3570) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 3571) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 3572) (T_BOOLEAN_AND 3573) (T_BOOLEAN_OR 3574) (T_COALESCE 3575) (T_INSTANCEOF 3576) (T_IS_EQUAL 3577) (T_IS_GREATER_OR_EQUAL 3578) (T_IS_IDENTICAL 3579) (T_IS_NOT_EQUAL 3580) (T_IS_NOT_IDENTICAL 3581) (T_IS_SMALLER_OR_EQUAL 3582) (T_LOGICAL_AND 3583) (T_LOGICAL_OR 3584) (T_LOGICAL_XOR 3585) (T_POW 3586) (T_SL 3587) (T_SPACESHIP 3588) (T_SR 3589) ("^" 3590) (backup_fn_flags 17653) ("|" 3591)) 7947 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17655) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 7948 (("$" 17275) (T_ABSTRACT 17453) (T_ARRAY 17454) (T_AS 17455) (T_BREAK 17456) (T_CALLABLE 17457) (T_CASE 17458) (T_CATCH 17459) (T_CLASS 17460) (T_CLASS_C 17461) (T_CLONE 17462) (T_CONST 17463) (T_CONTINUE 17464) (T_DECLARE 17465) (T_DEFAULT 17466) (T_DIR 17467) (T_DO 17468) (T_ECHO 17469) (T_ELSE 17470) (T_ELSEIF 17471) (T_EMPTY 17472) (T_ENDDECLARE 17473) (T_ENDFOR 17474) (T_ENDFOREACH 17475) (T_ENDIF 17476) (T_ENDSWITCH 17477) (T_ENDWHILE 17478) (T_ENUM 17479) (T_EVAL 17480) (T_EXIT 17481) (T_EXTENDS 17482) (T_FILE 17483) (T_FINAL 17484) (T_FINALLY 17485) (T_FN 17486) (T_FOR 17487) (T_FOREACH 17488) (T_FUNCTION 17489) (T_FUNC_C 17490) (T_GLOBAL 17491) (T_GOTO 17492) (T_IF 17493) (T_IMPLEMENTS 17494) (T_INCLUDE 17495) (T_INCLUDE_ONCE 17496) (T_INSTANCEOF 17497) (T_INSTEADOF 17498) (T_INTERFACE 17499) (T_ISSET 17500) (T_LINE 17501) (T_LIST 17502) (T_LOGICAL_AND 17503) (T_LOGICAL_OR 17504) (T_LOGICAL_XOR 17505) (T_MATCH 17506) (T_METHOD_C 17507) (T_NAMESPACE 17508) (T_NEW 17509) (T_NS_C 17510) (T_PRINT 17511) (T_PRIVATE 17512) (T_PROTECTED 17513) (T_PUBLIC 17514) (T_READONLY 17515) (T_REQUIRE 17516) (T_REQUIRE_ONCE 17517) (T_RETURN 17518) (T_STATIC 17519) (T_STRING 17520) (T_SWITCH 17521) (T_THROW 17522) (T_TRAIT 17523) (T_TRAIT_C 17524) (T_TRY 17525) (T_UNSET 17526) (T_USE 17527) (T_VAR 17528) (T_VARIABLE 17322) (T_WHILE 17529) (T_YIELD 17530) (identifier 17657) (member_name 17658) (reserved_non_modifiers 17533) (semi_reserved 17534) (simple_variable 17659) ("{" 17660)) 7949 (("(" 17539) (argument_list 17663)) 7950 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 17661) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 7951 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 17662)) 7952 ((T_FN 35) (T_FUNCTION 127) (fn 17336) #'17337 (inline_function 17667)) 7953 (("$" 17275) (T_STRING 17676) (T_VARIABLE 17322) (property_name 17683) (simple_variable 17678) ("{" 17679)) 7954 (("$" 17275) (T_STRING 17676) (T_VARIABLE 17322) (property_name 17677) (simple_variable 17678) ("{" 17679)) 7955 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 17674) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 7956 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 17672) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 7957 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 17673)) 7958 (("]" 17675)) 7959 (("(" 17539) (argument_list 17682)) 7960 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 17680) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 7961 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 17681)) 7962 (("(" 17539) (argument_list 17684)) 7963 (("`" 17686)) 7964 (("]" 17688)) 7965 (("=" 17689)) 7966 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17690) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7967 (("%" 17351) ("*" 17352) ("+" 17353) ("-" 17354) ("." 17355) ("/" 17356) ("<" 17357) (">" 17358) ("?" 17359) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 17360) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 17361) (T_BOOLEAN_AND 17362) (T_BOOLEAN_OR 17363) (T_COALESCE 17364) (T_DOUBLE_ARROW 17693) (T_INSTANCEOF 17365) (T_IS_EQUAL 17366) (T_IS_GREATER_OR_EQUAL 17367) (T_IS_IDENTICAL 17368) (T_IS_NOT_EQUAL 17369) (T_IS_NOT_IDENTICAL 17370) (T_IS_SMALLER_OR_EQUAL 17371) (T_LOGICAL_AND 17372) (T_LOGICAL_OR 17373) (T_LOGICAL_XOR 17374) (T_POW 17375) (T_SL 17376) (T_SPACESHIP 17377) (T_SR 17378) ("^" 17379) ("|" 17380)) 7968 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17694) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7969 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 17703) (T_VARIABLE 2900) (encaps_var 2914)) 7970 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 17702) (T_VARIABLE 2900) (encaps_var 2905)) 7971 ((T_CLASS 17723)) 7972 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 17722) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 17710) (attribute 2980) (class_modifier 2945)) 7973 (("(" 17713) (argument_list 17714) (ctor_arguments 17715)) 7974 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 17716) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 17717) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 17718) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 7975 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 17721) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 7976 (("," 1469) (possible_comma 17719)) 7977 ((")" 17720)) 7978 (("(" 2982) (argument_list 2983) (ctor_arguments 17724)) 7979 ((T_EXTENDS 2985) (extends_from 17725)) 7980 ((T_IMPLEMENTS 2987) (implements_list 17726)) 7981 ((backup_doc_comment 17727)) 7982 (("{" 17728)) 7983 ((class_statement_list 17729)) 7984 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 17730)) 7985 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 17732) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 7986 (("%" 292) (")" 17733) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 7987 (("{" 17734)) 7988 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 17735) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 7989 (("}" 17736)) 7990 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 17738) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 7991 ((")" 17739)) 7992 (("=" 17740)) 7993 (("!" 17273) ("\"" 17274) ("$" 17275) ("(" 17276) ("+" 17277) ("-" 17278) ("@" 17279) (T_ARRAY 17280) (T_ARRAY_CAST 17281) (T_ATTRIBUTE 126) (T_BOOL_CAST 17282) (T_CLASS_C 17283) (T_CLONE 17284) (T_CONSTANT_ENCAPSED_STRING 17285) (T_DEC 17286) (T_DIR 17287) (T_DNUMBER 17288) (T_DOUBLE_CAST 17289) (T_EMPTY 17290) (T_EVAL 17291) (T_EXIT 17292) (T_FILE 17293) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17294) (T_INC 17295) (T_INCLUDE 17296) (T_INCLUDE_ONCE 17297) (T_INT_CAST 17298) (T_ISSET 17299) (T_LINE 17300) (T_LIST 17301) (T_LNUMBER 17302) (T_MATCH 17303) (T_METHOD_C 17304) (T_NAME_FULLY_QUALIFIED 17305) (T_NAME_QUALIFIED 17306) (T_NAME_RELATIVE 17307) (T_NEW 17308) (T_NS_C 17309) (T_OBJECT_CAST 17310) (T_PRINT 17311) (T_READONLY 17312) (T_REQUIRE 17313) (T_REQUIRE_ONCE 17314) (T_START_HEREDOC 17315) (T_STATIC 17316) (T_STRING 17317) (T_STRING_CAST 17318) (T_THROW 17319) (T_TRAIT_C 17320) (T_UNSET_CAST 17321) (T_VARIABLE 17322) (T_YIELD 17323) (T_YIELD_FROM 17324) ("[" 17325) ("`" 17326) (array_object_dereferenceable 17327) (attribute 131) (attributes 17328) (callable_expr 17329) (callable_variable 17330) (class_constant 17331) (class_name 17332) (constant 17333) (dereferenceable_scalar 17334) (expr 17741) (fn 17336) (fully_dereferenceable 104) #'17337 (function_call 17338) (inline_function 17339) (internal_functions_in_yacc 17340) (match 17341) (name 17342) (new_expr 17343) (scalar 17344) (simple_variable 17345) (static_member 17346) (variable 17347) (variable_class_name 17348) ("~" 17349)) 7994 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 17743) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 7995 (("," 5258) (possible_comma 17744)) 7996 ((")" 17745)) 7997 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 17752) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 7998 ((")" 17753)) 7999 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 17755) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 8000 (("%" 292) (")" 17756) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 8001 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 17758) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 8002 (("%" 292) (")" 17759) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 8003 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 17766) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 8004 ((")" 17767)) 8005 (("%" 292) (")" 17772) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 8006 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 17775) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 8007 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 17776)) 8008 (("\"" 17778) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 8009 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 17788) (T_VARIABLE 2900) (encaps_var 2914)) 8010 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 17787) (T_VARIABLE 2900) (encaps_var 2905)) 8011 ((T_CLASS 17808)) 8012 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 17807) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 17795) (attribute 2980) (class_modifier 2945)) 8013 (("(" 17798) (argument_list 17799) (ctor_arguments 17800)) 8014 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 17801) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 17802) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 17803) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 8015 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 17806) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 8016 (("," 1469) (possible_comma 17804)) 8017 ((")" 17805)) 8018 (("(" 2982) (argument_list 2983) (ctor_arguments 17809)) 8019 ((T_EXTENDS 2985) (extends_from 17810)) 8020 ((T_IMPLEMENTS 2987) (implements_list 17811)) 8021 ((backup_doc_comment 17812)) 8022 (("{" 17813)) 8023 ((class_statement_list 17814)) 8024 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 17815)) 8025 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 17817) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 8026 (("%" 292) (")" 17818) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 8027 (("{" 17819)) 8028 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 17820) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 8029 (("}" 17821)) 8030 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 17823) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 8031 ((")" 17824)) 8032 (("=" 17825)) 8033 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 17826) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 8034 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 17828) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 8035 (("," 5258) (possible_comma 17829)) 8036 ((")" 17830)) 8037 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 17837) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 8038 ((")" 17838)) 8039 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 17840) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 8040 (("%" 292) (")" 17841) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 8041 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 17843) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 8042 (("%" 292) (")" 17844) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 8043 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 17851) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 8044 ((")" 17852)) 8045 (("%" 292) (")" 17857) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 8046 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 17860) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 8047 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 17861)) 8048 (("\"" 17863) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 8049 ((";" 17867)) 8050 ((";" 17869)) 8051 (("$" 17870) (T_VARIABLE 17871) (simple_variable 17878) ("{" 17879)) 8052 (("," 17875) (";" 17876)) 8053 (("$" 17870) (T_VARIABLE 17871) (global_var 17877) (simple_variable 17874)) 8054 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 17880) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 8055 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 17881)) 8056 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 17945) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8057 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 21540) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8058 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 21538) (encaps_var 5299)) 8059 (("$" 17885) (T_VARIABLE 17932) (simple_variable 21534) ("{" 21535)) 8060 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 21532) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 8061 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 21531) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8062 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 21530) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8063 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 21529) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8064 (("(" 21526)) 8065 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 21525) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8066 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 21524) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8067 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 21523) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8068 (("\"" 1509) ("$" 18188) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 18189) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 18190) ("[" 1529) (array_object_dereferenceable 18191) (callable_expr 18192) (callable_variable 18193) (class_constant 1533) (class_name 18194) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 18195) (name 18196) (simple_variable 18197) (static_member 18198) (variable 21522) (variable_class_name 18200)) 8069 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 21521) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8070 (("(" 21518)) 8071 (("(" 21515)) 8072 (("(" 21511) (exit_expr 21512)) 8073 (("\"" 1509) ("$" 18188) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 18189) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 18190) ("[" 1529) (array_object_dereferenceable 18191) (callable_expr 18192) (callable_variable 18193) (class_constant 1533) (class_name 18194) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 18195) (name 18196) (simple_variable 18197) (static_member 18198) (variable 21510) (variable_class_name 18200)) 8074 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 21509) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8075 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 21508) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8076 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 21507) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8077 (("(" 21503)) 8078 (("(" 21498)) 8079 (("(" 21492)) 8080 (("$" 18567) ("(" 19227) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 19228) (T_NAME_QUALIFIED 19229) (T_NAME_RELATIVE 19230) (T_READONLY 2936) (T_STATIC 19231) (T_STRING 19232) (T_VARIABLE 18569) (anonymous_class 21470) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 21471) (attribute 2943) (attributes 21472) (class_modifier 2945) (class_name 19236) (class_name_reference 21473) (name 19238) (new_variable 19239) (simple_variable 19240)) 8081 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 21469) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8082 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 21468) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8083 (("(" 18149) (argument_list 21467)) 8084 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 21466) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8085 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 21465) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8086 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 21460) (T_END_HEREDOC 21461) (T_VARIABLE 2900) (encaps_list 21462) (encaps_var 2902)) 8087 ((T_FN 35) (T_FUNCTION 127) (fn 17946) #'17947 (inline_function 21459)) 8088 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 21458) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8089 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 21457) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8090 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 21456) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8091 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21011) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 8092 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 20948) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8093 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 20944) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 8094 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 20942) (encaps_list 2805) (encaps_var 2806)) 8095 ((T_NULLSAFE_OBJECT_OPERATOR 20925) (T_OBJECT_OPERATOR 20926) ("[" 20927) ("{" 20928)) 8096 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 20922) (attribute 2728) (fn 17946) #'17947 (inline_function 20923)) 8097 (("(" 18149) (argument_list 20921)) 8098 ((T_PAAMAYIM_NEKUDOTAYIM 20913)) 8099 (("%" 17961) ("*" 17962) ("+" 17963) ("-" 17964) ("." 17965) ("/" 17966) ("<" 17967) (">" 17968) ("?" 17969) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 17970) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 17971) (T_AS 19324) (T_BOOLEAN_AND 17972) (T_BOOLEAN_OR 17973) (T_COALESCE 17974) (T_INSTANCEOF 17975) (T_IS_EQUAL 17976) (T_IS_GREATER_OR_EQUAL 17977) (T_IS_IDENTICAL 17978) (T_IS_NOT_EQUAL 17979) (T_IS_NOT_IDENTICAL 17980) (T_IS_SMALLER_OR_EQUAL 17981) (T_LOGICAL_AND 17982) (T_LOGICAL_OR 17983) (T_LOGICAL_XOR 17984) (T_POW 17985) (T_SL 17986) (T_SPACESHIP 17987) (T_SR 17988) ("^" 17989) ("|" 17990)) 8100 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 18253)) 8101 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 18241)) 8102 (("(" 18149) (argument_list 18240)) 8103 (("=" 18157) (T_AND_EQUAL 18158) (T_COALESCE_EQUAL 18159) (T_CONCAT_EQUAL 18160) (T_DEC 18161) (T_DIV_EQUAL 18162) (T_INC 18163) (T_MINUS_EQUAL 18164) (T_MOD_EQUAL 18165) (T_MUL_EQUAL 18166) (T_OR_EQUAL 18167) (T_PLUS_EQUAL 18168) (T_POW_EQUAL 18169) (T_SL_EQUAL 18170) (T_SR_EQUAL 18171) (T_XOR_EQUAL 18172)) 8104 ((T_PAAMAYIM_NEKUDOTAYIM 18062)) 8105 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 17960) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8106 (("%" 17961) ("*" 17962) ("+" 17963) ("-" 17964) ("." 17965) ("/" 17966) ("<" 17967) (">" 17968) ("?" 17969) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 17970) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 17971) (T_BOOLEAN_AND 17972) (T_BOOLEAN_OR 17973) (T_COALESCE 17974) (T_INSTANCEOF 17975) (T_IS_EQUAL 17976) (T_IS_GREATER_OR_EQUAL 17977) (T_IS_IDENTICAL 17978) (T_IS_NOT_EQUAL 17979) (T_IS_NOT_IDENTICAL 17980) (T_IS_SMALLER_OR_EQUAL 17981) (T_LOGICAL_AND 17982) (T_LOGICAL_OR 17983) (T_LOGICAL_XOR 17984) (T_POW 17985) (T_SL 17986) (T_SPACESHIP 17987) (T_SR 17988) ("^" 17989) ("|" 17990)) 8107 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18061) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8108 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18060) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8109 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18059) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8110 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18058) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8111 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18057) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8112 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18056) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8113 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18055) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8114 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18054) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8115 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 18049) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 18050) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 8116 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18048) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8117 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18047) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8118 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18046) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8119 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18045) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8120 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18044) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8121 (("$" 18006) ("(" 18007) (T_NAME_FULLY_QUALIFIED 18008) (T_NAME_QUALIFIED 18009) (T_NAME_RELATIVE 18010) (T_STATIC 18011) (T_STRING 18012) (T_VARIABLE 18013) (class_name 18014) (class_name_reference 18015) (name 18016) (new_variable 18017) (simple_variable 18018)) 8122 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18005) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8123 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18004) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8124 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18003) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8125 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18002) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8126 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18001) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8127 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18000) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8128 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 17999) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8129 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 17998) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8130 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 17997) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8131 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 17996) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8132 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 17995) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8133 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 17994) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8134 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 17993) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8135 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 17992) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8136 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 17991) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8137 (("$" 18006) (T_VARIABLE 18013) (simple_variable 18040) ("{" 18041)) 8138 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 18038) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 8139 ((T_PAAMAYIM_NEKUDOTAYIM 18036)) 8140 ((T_NULLSAFE_OBJECT_OPERATOR 18019) (T_OBJECT_OPERATOR 18020) (T_PAAMAYIM_NEKUDOTAYIM 18021) ("[" 18022) ("{" 18023)) 8141 (("$" 18006) (T_STRING 18029) (T_VARIABLE 18013) (property_name 18035) (simple_variable 18031) ("{" 18032)) 8142 (("$" 18006) (T_STRING 18029) (T_VARIABLE 18013) (property_name 18030) (simple_variable 18031) ("{" 18032)) 8143 (("$" 18006) (T_VARIABLE 18013) (simple_variable 18028)) 8144 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 18026) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 8145 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 18024) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 8146 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 18025)) 8147 (("]" 18027)) 8148 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 18033) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 8149 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 18034)) 8150 (("$" 18006) (T_VARIABLE 18013) (simple_variable 18037)) 8151 (("%" 292) (")" 18039) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 8152 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 18042) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 8153 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 18043)) 8154 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18053) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8155 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 18051) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 8156 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18052) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8157 (("$" 17885) (T_ABSTRACT 18063) (T_ARRAY 18064) (T_AS 18065) (T_BREAK 18066) (T_CALLABLE 18067) (T_CASE 18068) (T_CATCH 18069) (T_CLASS 18070) (T_CLASS_C 18071) (T_CLONE 18072) (T_CONST 18073) (T_CONTINUE 18074) (T_DECLARE 18075) (T_DEFAULT 18076) (T_DIR 18077) (T_DO 18078) (T_ECHO 18079) (T_ELSE 18080) (T_ELSEIF 18081) (T_EMPTY 18082) (T_ENDDECLARE 18083) (T_ENDFOR 18084) (T_ENDFOREACH 18085) (T_ENDIF 18086) (T_ENDSWITCH 18087) (T_ENDWHILE 18088) (T_ENUM 18089) (T_EVAL 18090) (T_EXIT 18091) (T_EXTENDS 18092) (T_FILE 18093) (T_FINAL 18094) (T_FINALLY 18095) (T_FN 18096) (T_FOR 18097) (T_FOREACH 18098) (T_FUNCTION 18099) (T_FUNC_C 18100) (T_GLOBAL 18101) (T_GOTO 18102) (T_IF 18103) (T_IMPLEMENTS 18104) (T_INCLUDE 18105) (T_INCLUDE_ONCE 18106) (T_INSTANCEOF 18107) (T_INSTEADOF 18108) (T_INTERFACE 18109) (T_ISSET 18110) (T_LINE 18111) (T_LIST 18112) (T_LOGICAL_AND 18113) (T_LOGICAL_OR 18114) (T_LOGICAL_XOR 18115) (T_MATCH 18116) (T_METHOD_C 18117) (T_NAMESPACE 18118) (T_NEW 18119) (T_NS_C 18120) (T_PRINT 18121) (T_PRIVATE 18122) (T_PROTECTED 18123) (T_PUBLIC 18124) (T_READONLY 18125) (T_REQUIRE 18126) (T_REQUIRE_ONCE 18127) (T_RETURN 18128) (T_STATIC 18129) (T_STRING 18130) (T_SWITCH 18131) (T_THROW 18132) (T_TRAIT 18133) (T_TRAIT_C 18134) (T_TRY 18135) (T_UNSET 18136) (T_USE 18137) (T_VAR 18138) (T_VARIABLE 17932) (T_WHILE 18139) (T_YIELD 18140) (identifier 18141) (member_name 18142) (reserved_non_modifiers 18143) (semi_reserved 18144) (simple_variable 18145) ("{" 18146)) 8158 (("(" 18149) (argument_list 18150)) 8159 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 18147) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 8160 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 18148)) 8161 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 18151) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 18152) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 18153) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 8162 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 18156) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 8163 (("," 1469) (possible_comma 18154)) 8164 ((")" 18155)) 8165 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (ampersand 18186) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18187) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8166 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18185) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8167 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18184) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8168 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18183) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8169 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18182) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8170 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18181) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8171 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18180) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8172 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18179) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8173 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18178) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8174 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18177) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8175 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18176) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8176 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18175) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8177 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18174) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8178 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 18173) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8179 (("\"" 1509) ("$" 18188) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 18189) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 18190) ("[" 1529) (array_object_dereferenceable 18191) (callable_expr 18192) (callable_variable 18193) (class_constant 1533) (class_name 18194) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 18195) (name 18196) (simple_variable 18197) (static_member 18198) (variable 18199) (variable_class_name 18200)) 8180 (("$" 18188) (T_VARIABLE 18190) (simple_variable 18236) ("{" 18237)) 8181 (("(" 18204) (argument_list 18235)) 8182 ((T_NULLSAFE_OBJECT_OPERATOR 18218) (T_OBJECT_OPERATOR 18219) ("[" 18220) ("{" 18221)) 8183 (("(" 18204) (argument_list 18217)) 8184 ((T_PAAMAYIM_NEKUDOTAYIM 18213)) 8185 (("(" 18204) (argument_list 18212)) 8186 ((T_PAAMAYIM_NEKUDOTAYIM 18201)) 8187 (("$" 18188) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 18190) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 18202) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 18203) ("{" 1627)) 8188 (("(" 18204) (argument_list 18205)) 8189 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 18206) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 18207) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 18208) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 8190 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 18211) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 8191 (("," 1469) (possible_comma 18209)) 8192 ((")" 18210)) 8193 (("$" 18188) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 18190) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 18214) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 18215) ("{" 1643)) 8194 (("(" 18204) (argument_list 18216)) 8195 (("$" 18188) (T_STRING 18226) (T_VARIABLE 18190) (property_name 18233) (simple_variable 18228) ("{" 18229)) 8196 (("$" 18188) (T_STRING 18226) (T_VARIABLE 18190) (property_name 18227) (simple_variable 18228) ("{" 18229)) 8197 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 18224) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 8198 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 18222) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 8199 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 18223)) 8200 (("]" 18225)) 8201 (("(" 18204) (argument_list 18232)) 8202 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 18230) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 8203 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 18231)) 8204 (("(" 18204) (argument_list 18234)) 8205 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 18238) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 8206 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 18239)) 8207 ((backup_doc_comment 18242)) 8208 (("(" 18243)) 8209 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 18244)) 8210 ((")" 18245)) 8211 ((T_USE 159) (lexical_vars 18246)) 8212 ((":" 161) (return_type 18247)) 8213 ((backup_fn_flags 18248)) 8214 (("{" 18249)) 8215 ((inner_statement_list 18250)) 8216 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 18251) ("~" 125)) 8217 ((backup_fn_flags 18252)) 8218 ((backup_doc_comment 18254)) 8219 (("(" 18255)) 8220 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 18256)) 8221 ((")" 18257)) 8222 ((":" 2241) (return_type 18258)) 8223 ((T_DOUBLE_ARROW 18259)) 8224 ((backup_fn_flags 18260)) 8225 ((backup_lex_pos 18261)) 8226 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18324) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8227 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 19323) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8228 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 19321) (encaps_var 5299)) 8229 (("$" 18264) (T_VARIABLE 18311) (simple_variable 19317) ("{" 19318)) 8230 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 19315) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 8231 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 19314) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8232 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 19313) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8233 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 19312) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8234 (("(" 19309)) 8235 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 19308) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8236 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 19307) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8237 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 19306) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8238 (("\"" 1509) ("$" 18567) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 18568) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 18569) ("[" 1529) (array_object_dereferenceable 18570) (callable_expr 18571) (callable_variable 18572) (class_constant 1533) (class_name 18573) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 18574) (name 18575) (simple_variable 18576) (static_member 18577) (variable 19305) (variable_class_name 18579)) 8239 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 19304) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8240 (("(" 19301)) 8241 (("(" 19298)) 8242 (("(" 19294) (exit_expr 19295)) 8243 (("\"" 1509) ("$" 18567) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 18568) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 18569) ("[" 1529) (array_object_dereferenceable 18570) (callable_expr 18571) (callable_variable 18572) (class_constant 1533) (class_name 18573) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 18574) (name 18575) (simple_variable 18576) (static_member 18577) (variable 19293) (variable_class_name 18579)) 8244 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 19292) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8245 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 19291) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8246 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 19290) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8247 (("(" 19286)) 8248 (("(" 19281)) 8249 (("(" 19275)) 8250 (("$" 18567) ("(" 19227) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 19228) (T_NAME_QUALIFIED 19229) (T_NAME_RELATIVE 19230) (T_READONLY 2936) (T_STATIC 19231) (T_STRING 19232) (T_VARIABLE 18569) (anonymous_class 19233) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 19234) (attribute 2943) (attributes 19235) (class_modifier 2945) (class_name 19236) (class_name_reference 19237) (name 19238) (new_variable 19239) (simple_variable 19240)) 8251 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 19226) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8252 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 19225) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8253 (("(" 18528) (argument_list 19224)) 8254 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 19223) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8255 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 19222) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8256 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 19217) (T_END_HEREDOC 19218) (T_VARIABLE 2900) (encaps_list 19219) (encaps_var 2902)) 8257 ((T_FN 35) (T_FUNCTION 127) (fn 18325) #'18326 (inline_function 19216)) 8258 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 19215) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8259 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 19214) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8260 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 19213) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8261 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18742) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8262 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18679) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8263 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 18675) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 8264 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 18673) (encaps_list 2805) (encaps_var 2806)) 8265 ((T_NULLSAFE_OBJECT_OPERATOR 18656) (T_OBJECT_OPERATOR 18657) ("[" 18658) ("{" 18659)) 8266 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 18653) (attribute 2728) (fn 18325) #'18326 (inline_function 18654)) 8267 (("(" 18528) (argument_list 18652)) 8268 ((T_PAAMAYIM_NEKUDOTAYIM 18644)) 8269 (("%" 18340) ("*" 18341) ("+" 18342) ("-" 18343) ("." 18344) ("/" 18345) ("<" 18346) (">" 18347) ("?" 18348) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 18349) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 18350) (T_BOOLEAN_AND 18351) (T_BOOLEAN_OR 18352) (T_COALESCE 18353) (T_INSTANCEOF 18354) (T_IS_EQUAL 18355) (T_IS_GREATER_OR_EQUAL 18356) (T_IS_IDENTICAL 18357) (T_IS_NOT_EQUAL 18358) (T_IS_NOT_IDENTICAL 18359) (T_IS_SMALLER_OR_EQUAL 18360) (T_LOGICAL_AND 18361) (T_LOGICAL_OR 18362) (T_LOGICAL_XOR 18363) (T_POW 18364) (T_SL 18365) (T_SPACESHIP 18366) (T_SR 18367) ("^" 18368) (backup_fn_flags 18643) ("|" 18369)) 8270 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 18632)) 8271 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 18620)) 8272 (("(" 18528) (argument_list 18619)) 8273 (("=" 18536) (T_AND_EQUAL 18537) (T_COALESCE_EQUAL 18538) (T_CONCAT_EQUAL 18539) (T_DEC 18540) (T_DIV_EQUAL 18541) (T_INC 18542) (T_MINUS_EQUAL 18543) (T_MOD_EQUAL 18544) (T_MUL_EQUAL 18545) (T_OR_EQUAL 18546) (T_PLUS_EQUAL 18547) (T_POW_EQUAL 18548) (T_SL_EQUAL 18549) (T_SR_EQUAL 18550) (T_XOR_EQUAL 18551)) 8274 ((T_PAAMAYIM_NEKUDOTAYIM 18441)) 8275 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18339) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8276 (("%" 18340) ("*" 18341) ("+" 18342) ("-" 18343) ("." 18344) ("/" 18345) ("<" 18346) (">" 18347) ("?" 18348) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 18349) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 18350) (T_BOOLEAN_AND 18351) (T_BOOLEAN_OR 18352) (T_COALESCE 18353) (T_INSTANCEOF 18354) (T_IS_EQUAL 18355) (T_IS_GREATER_OR_EQUAL 18356) (T_IS_IDENTICAL 18357) (T_IS_NOT_EQUAL 18358) (T_IS_NOT_IDENTICAL 18359) (T_IS_SMALLER_OR_EQUAL 18360) (T_LOGICAL_AND 18361) (T_LOGICAL_OR 18362) (T_LOGICAL_XOR 18363) (T_POW 18364) (T_SL 18365) (T_SPACESHIP 18366) (T_SR 18367) ("^" 18368) ("|" 18369)) 8277 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18440) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8278 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18439) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8279 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18438) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8280 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18437) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8281 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18436) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8282 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18435) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8283 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18434) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8284 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18433) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8285 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 18428) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 18429) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 8286 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18427) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8287 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18426) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8288 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18425) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8289 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18424) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8290 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18423) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8291 (("$" 18385) ("(" 18386) (T_NAME_FULLY_QUALIFIED 18387) (T_NAME_QUALIFIED 18388) (T_NAME_RELATIVE 18389) (T_STATIC 18390) (T_STRING 18391) (T_VARIABLE 18392) (class_name 18393) (class_name_reference 18394) (name 18395) (new_variable 18396) (simple_variable 18397)) 8292 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18384) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8293 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18383) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8294 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18382) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8295 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18381) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8296 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18380) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8297 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18379) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8298 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18378) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8299 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18377) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8300 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18376) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8301 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18375) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8302 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18374) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8303 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18373) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8304 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18372) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8305 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18371) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8306 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18370) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8307 (("$" 18385) (T_VARIABLE 18392) (simple_variable 18419) ("{" 18420)) 8308 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 18417) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 8309 ((T_PAAMAYIM_NEKUDOTAYIM 18415)) 8310 ((T_NULLSAFE_OBJECT_OPERATOR 18398) (T_OBJECT_OPERATOR 18399) (T_PAAMAYIM_NEKUDOTAYIM 18400) ("[" 18401) ("{" 18402)) 8311 (("$" 18385) (T_STRING 18408) (T_VARIABLE 18392) (property_name 18414) (simple_variable 18410) ("{" 18411)) 8312 (("$" 18385) (T_STRING 18408) (T_VARIABLE 18392) (property_name 18409) (simple_variable 18410) ("{" 18411)) 8313 (("$" 18385) (T_VARIABLE 18392) (simple_variable 18407)) 8314 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 18405) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 8315 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 18403) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 8316 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 18404)) 8317 (("]" 18406)) 8318 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 18412) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 8319 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 18413)) 8320 (("$" 18385) (T_VARIABLE 18392) (simple_variable 18416)) 8321 (("%" 292) (")" 18418) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 8322 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 18421) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 8323 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 18422)) 8324 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18432) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8325 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 18430) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 8326 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18431) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8327 (("$" 18264) (T_ABSTRACT 18442) (T_ARRAY 18443) (T_AS 18444) (T_BREAK 18445) (T_CALLABLE 18446) (T_CASE 18447) (T_CATCH 18448) (T_CLASS 18449) (T_CLASS_C 18450) (T_CLONE 18451) (T_CONST 18452) (T_CONTINUE 18453) (T_DECLARE 18454) (T_DEFAULT 18455) (T_DIR 18456) (T_DO 18457) (T_ECHO 18458) (T_ELSE 18459) (T_ELSEIF 18460) (T_EMPTY 18461) (T_ENDDECLARE 18462) (T_ENDFOR 18463) (T_ENDFOREACH 18464) (T_ENDIF 18465) (T_ENDSWITCH 18466) (T_ENDWHILE 18467) (T_ENUM 18468) (T_EVAL 18469) (T_EXIT 18470) (T_EXTENDS 18471) (T_FILE 18472) (T_FINAL 18473) (T_FINALLY 18474) (T_FN 18475) (T_FOR 18476) (T_FOREACH 18477) (T_FUNCTION 18478) (T_FUNC_C 18479) (T_GLOBAL 18480) (T_GOTO 18481) (T_IF 18482) (T_IMPLEMENTS 18483) (T_INCLUDE 18484) (T_INCLUDE_ONCE 18485) (T_INSTANCEOF 18486) (T_INSTEADOF 18487) (T_INTERFACE 18488) (T_ISSET 18489) (T_LINE 18490) (T_LIST 18491) (T_LOGICAL_AND 18492) (T_LOGICAL_OR 18493) (T_LOGICAL_XOR 18494) (T_MATCH 18495) (T_METHOD_C 18496) (T_NAMESPACE 18497) (T_NEW 18498) (T_NS_C 18499) (T_PRINT 18500) (T_PRIVATE 18501) (T_PROTECTED 18502) (T_PUBLIC 18503) (T_READONLY 18504) (T_REQUIRE 18505) (T_REQUIRE_ONCE 18506) (T_RETURN 18507) (T_STATIC 18508) (T_STRING 18509) (T_SWITCH 18510) (T_THROW 18511) (T_TRAIT 18512) (T_TRAIT_C 18513) (T_TRY 18514) (T_UNSET 18515) (T_USE 18516) (T_VAR 18517) (T_VARIABLE 18311) (T_WHILE 18518) (T_YIELD 18519) (identifier 18520) (member_name 18521) (reserved_non_modifiers 18522) (semi_reserved 18523) (simple_variable 18524) ("{" 18525)) 8328 (("(" 18528) (argument_list 18529)) 8329 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 18526) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 8330 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 18527)) 8331 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 18530) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 18531) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 18532) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 8332 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 18535) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 8333 (("," 1469) (possible_comma 18533)) 8334 ((")" 18534)) 8335 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (ampersand 18565) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18566) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8336 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18564) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8337 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18563) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8338 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18562) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8339 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18561) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8340 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18560) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8341 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18559) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8342 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18558) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8343 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18557) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8344 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18556) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8345 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18555) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8346 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18554) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8347 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18553) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8348 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18552) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8349 (("\"" 1509) ("$" 18567) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 18568) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 18569) ("[" 1529) (array_object_dereferenceable 18570) (callable_expr 18571) (callable_variable 18572) (class_constant 1533) (class_name 18573) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 18574) (name 18575) (simple_variable 18576) (static_member 18577) (variable 18578) (variable_class_name 18579)) 8350 (("$" 18567) (T_VARIABLE 18569) (simple_variable 18615) ("{" 18616)) 8351 (("(" 18583) (argument_list 18614)) 8352 ((T_NULLSAFE_OBJECT_OPERATOR 18597) (T_OBJECT_OPERATOR 18598) ("[" 18599) ("{" 18600)) 8353 (("(" 18583) (argument_list 18596)) 8354 ((T_PAAMAYIM_NEKUDOTAYIM 18592)) 8355 (("(" 18583) (argument_list 18591)) 8356 ((T_PAAMAYIM_NEKUDOTAYIM 18580)) 8357 (("$" 18567) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 18569) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 18581) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 18582) ("{" 1627)) 8358 (("(" 18583) (argument_list 18584)) 8359 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 18585) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 18586) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 18587) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 8360 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 18590) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 8361 (("," 1469) (possible_comma 18588)) 8362 ((")" 18589)) 8363 (("$" 18567) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 18569) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 18593) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 18594) ("{" 1643)) 8364 (("(" 18583) (argument_list 18595)) 8365 (("$" 18567) (T_STRING 18605) (T_VARIABLE 18569) (property_name 18612) (simple_variable 18607) ("{" 18608)) 8366 (("$" 18567) (T_STRING 18605) (T_VARIABLE 18569) (property_name 18606) (simple_variable 18607) ("{" 18608)) 8367 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 18603) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 8368 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 18601) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 8369 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 18602)) 8370 (("]" 18604)) 8371 (("(" 18583) (argument_list 18611)) 8372 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 18609) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 8373 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 18610)) 8374 (("(" 18583) (argument_list 18613)) 8375 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 18617) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 8376 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 18618)) 8377 ((backup_doc_comment 18621)) 8378 (("(" 18622)) 8379 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 18623)) 8380 ((")" 18624)) 8381 ((T_USE 159) (lexical_vars 18625)) 8382 ((":" 161) (return_type 18626)) 8383 ((backup_fn_flags 18627)) 8384 (("{" 18628)) 8385 ((inner_statement_list 18629)) 8386 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 18630) ("~" 125)) 8387 ((backup_fn_flags 18631)) 8388 ((backup_doc_comment 18633)) 8389 (("(" 18634)) 8390 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 18635)) 8391 ((")" 18636)) 8392 ((":" 2241) (return_type 18637)) 8393 ((T_DOUBLE_ARROW 18638)) 8394 ((backup_fn_flags 18639)) 8395 ((backup_lex_pos 18640)) 8396 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18641) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8397 (("%" 18340) ("*" 18341) ("+" 18342) ("-" 18343) ("." 18344) ("/" 18345) ("<" 18346) (">" 18347) ("?" 18348) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 18349) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 18350) (T_BOOLEAN_AND 18351) (T_BOOLEAN_OR 18352) (T_COALESCE 18353) (T_INSTANCEOF 18354) (T_IS_EQUAL 18355) (T_IS_GREATER_OR_EQUAL 18356) (T_IS_IDENTICAL 18357) (T_IS_NOT_EQUAL 18358) (T_IS_NOT_IDENTICAL 18359) (T_IS_SMALLER_OR_EQUAL 18360) (T_LOGICAL_AND 18361) (T_LOGICAL_OR 18362) (T_LOGICAL_XOR 18363) (T_POW 18364) (T_SL 18365) (T_SPACESHIP 18366) (T_SR 18367) ("^" 18368) (backup_fn_flags 18642) ("|" 18369)) 8398 (("$" 18264) (T_ABSTRACT 18442) (T_ARRAY 18443) (T_AS 18444) (T_BREAK 18445) (T_CALLABLE 18446) (T_CASE 18447) (T_CATCH 18448) (T_CLASS 18449) (T_CLASS_C 18450) (T_CLONE 18451) (T_CONST 18452) (T_CONTINUE 18453) (T_DECLARE 18454) (T_DEFAULT 18455) (T_DIR 18456) (T_DO 18457) (T_ECHO 18458) (T_ELSE 18459) (T_ELSEIF 18460) (T_EMPTY 18461) (T_ENDDECLARE 18462) (T_ENDFOR 18463) (T_ENDFOREACH 18464) (T_ENDIF 18465) (T_ENDSWITCH 18466) (T_ENDWHILE 18467) (T_ENUM 18468) (T_EVAL 18469) (T_EXIT 18470) (T_EXTENDS 18471) (T_FILE 18472) (T_FINAL 18473) (T_FINALLY 18474) (T_FN 18475) (T_FOR 18476) (T_FOREACH 18477) (T_FUNCTION 18478) (T_FUNC_C 18479) (T_GLOBAL 18480) (T_GOTO 18481) (T_IF 18482) (T_IMPLEMENTS 18483) (T_INCLUDE 18484) (T_INCLUDE_ONCE 18485) (T_INSTANCEOF 18486) (T_INSTEADOF 18487) (T_INTERFACE 18488) (T_ISSET 18489) (T_LINE 18490) (T_LIST 18491) (T_LOGICAL_AND 18492) (T_LOGICAL_OR 18493) (T_LOGICAL_XOR 18494) (T_MATCH 18495) (T_METHOD_C 18496) (T_NAMESPACE 18497) (T_NEW 18498) (T_NS_C 18499) (T_PRINT 18500) (T_PRIVATE 18501) (T_PROTECTED 18502) (T_PUBLIC 18503) (T_READONLY 18504) (T_REQUIRE 18505) (T_REQUIRE_ONCE 18506) (T_RETURN 18507) (T_STATIC 18508) (T_STRING 18509) (T_SWITCH 18510) (T_THROW 18511) (T_TRAIT 18512) (T_TRAIT_C 18513) (T_TRY 18514) (T_UNSET 18515) (T_USE 18516) (T_VAR 18517) (T_VARIABLE 18311) (T_WHILE 18518) (T_YIELD 18519) (identifier 18645) (member_name 18646) (reserved_non_modifiers 18522) (semi_reserved 18523) (simple_variable 18647) ("{" 18648)) 8399 (("(" 18528) (argument_list 18651)) 8400 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 18649) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 8401 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 18650)) 8402 ((T_FN 35) (T_FUNCTION 127) (fn 18325) #'18326 (inline_function 18655)) 8403 (("$" 18264) (T_STRING 18664) (T_VARIABLE 18311) (property_name 18671) (simple_variable 18666) ("{" 18667)) 8404 (("$" 18264) (T_STRING 18664) (T_VARIABLE 18311) (property_name 18665) (simple_variable 18666) ("{" 18667)) 8405 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 18662) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 8406 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 18660) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 8407 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 18661)) 8408 (("]" 18663)) 8409 (("(" 18528) (argument_list 18670)) 8410 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 18668) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 8411 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 18669)) 8412 (("(" 18528) (argument_list 18672)) 8413 (("`" 18674)) 8414 (("]" 18676)) 8415 (("=" 18677)) 8416 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 18678) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8417 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 19212) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8418 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 19210) (encaps_var 5299)) 8419 (("$" 18682) (T_VARIABLE 18729) (simple_variable 19206) ("{" 19207)) 8420 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 19204) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 8421 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 19203) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8422 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 19202) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8423 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 19201) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8424 (("(" 19198)) 8425 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 19197) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8426 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 19196) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8427 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 19195) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8428 (("\"" 1509) ("$" 18985) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 18986) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 18987) ("[" 1529) (array_object_dereferenceable 18988) (callable_expr 18989) (callable_variable 18990) (class_constant 1533) (class_name 18991) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 18992) (name 18993) (simple_variable 18994) (static_member 18995) (variable 19194) (variable_class_name 18997)) 8429 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 19193) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8430 (("(" 19190)) 8431 (("(" 19187)) 8432 (("(" 19183) (exit_expr 19184)) 8433 (("\"" 1509) ("$" 18985) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 18986) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 18987) ("[" 1529) (array_object_dereferenceable 18988) (callable_expr 18989) (callable_variable 18990) (class_constant 1533) (class_name 18991) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 18992) (name 18993) (simple_variable 18994) (static_member 18995) (variable 19182) (variable_class_name 18997)) 8434 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 19181) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8435 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 19180) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8436 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 19179) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8437 (("(" 19175)) 8438 (("(" 19170)) 8439 (("(" 19164)) 8440 (("$" 18985) ("(" 19116) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 19117) (T_NAME_QUALIFIED 19118) (T_NAME_RELATIVE 19119) (T_READONLY 2936) (T_STATIC 19120) (T_STRING 19121) (T_VARIABLE 18987) (anonymous_class 19122) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 19123) (attribute 2943) (attributes 19124) (class_modifier 2945) (class_name 19125) (class_name_reference 19126) (name 19127) (new_variable 19128) (simple_variable 19129)) 8441 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 19115) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8442 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 19114) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8443 (("(" 18946) (argument_list 19113)) 8444 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 19112) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8445 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 19111) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8446 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 19106) (T_END_HEREDOC 19107) (T_VARIABLE 2900) (encaps_list 19108) (encaps_var 2902)) 8447 ((T_FN 35) (T_FUNCTION 127) (fn 18743) #'18744 (inline_function 19105)) 8448 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 19104) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8449 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 19103) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8450 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 19102) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8451 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 19099) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8452 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 19098) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8453 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 19094) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 8454 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 19092) (encaps_list 2805) (encaps_var 2806)) 8455 ((T_NULLSAFE_OBJECT_OPERATOR 19075) (T_OBJECT_OPERATOR 19076) ("[" 19077) ("{" 19078)) 8456 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 19072) (attribute 2728) (fn 18743) #'18744 (inline_function 19073)) 8457 (("(" 18946) (argument_list 19071)) 8458 ((T_PAAMAYIM_NEKUDOTAYIM 19063)) 8459 (("%" 18758) ("*" 18759) ("+" 18760) ("-" 18761) ("." 18762) ("/" 18763) ("<" 18764) (">" 18765) ("?" 18766) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 18767) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 18768) (T_BOOLEAN_AND 18769) (T_BOOLEAN_OR 18770) (T_COALESCE 18771) (T_DOUBLE_ARROW 19061) (T_INSTANCEOF 18772) (T_IS_EQUAL 18773) (T_IS_GREATER_OR_EQUAL 18774) (T_IS_IDENTICAL 18775) (T_IS_NOT_EQUAL 18776) (T_IS_NOT_IDENTICAL 18777) (T_IS_SMALLER_OR_EQUAL 18778) (T_LOGICAL_AND 18779) (T_LOGICAL_OR 18780) (T_LOGICAL_XOR 18781) (T_POW 18782) (T_SL 18783) (T_SPACESHIP 18784) (T_SR 18785) ("^" 18786) ("|" 18787)) 8460 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 19050)) 8461 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 19038)) 8462 (("(" 18946) (argument_list 19037)) 8463 (("=" 18954) (T_AND_EQUAL 18955) (T_COALESCE_EQUAL 18956) (T_CONCAT_EQUAL 18957) (T_DEC 18958) (T_DIV_EQUAL 18959) (T_INC 18960) (T_MINUS_EQUAL 18961) (T_MOD_EQUAL 18962) (T_MUL_EQUAL 18963) (T_OR_EQUAL 18964) (T_PLUS_EQUAL 18965) (T_POW_EQUAL 18966) (T_SL_EQUAL 18967) (T_SR_EQUAL 18968) (T_XOR_EQUAL 18969)) 8464 ((T_PAAMAYIM_NEKUDOTAYIM 18859)) 8465 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18757) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8466 (("%" 18758) ("*" 18759) ("+" 18760) ("-" 18761) ("." 18762) ("/" 18763) ("<" 18764) (">" 18765) ("?" 18766) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 18767) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 18768) (T_BOOLEAN_AND 18769) (T_BOOLEAN_OR 18770) (T_COALESCE 18771) (T_INSTANCEOF 18772) (T_IS_EQUAL 18773) (T_IS_GREATER_OR_EQUAL 18774) (T_IS_IDENTICAL 18775) (T_IS_NOT_EQUAL 18776) (T_IS_NOT_IDENTICAL 18777) (T_IS_SMALLER_OR_EQUAL 18778) (T_LOGICAL_AND 18779) (T_LOGICAL_OR 18780) (T_LOGICAL_XOR 18781) (T_POW 18782) (T_SL 18783) (T_SPACESHIP 18784) (T_SR 18785) ("^" 18786) ("|" 18787)) 8467 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18858) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8468 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18857) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8469 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18856) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8470 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18855) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8471 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18854) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8472 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18853) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8473 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18852) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8474 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18851) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8475 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 18846) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 18847) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 8476 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18845) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8477 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18844) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8478 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18843) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8479 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18842) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8480 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18841) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8481 (("$" 18803) ("(" 18804) (T_NAME_FULLY_QUALIFIED 18805) (T_NAME_QUALIFIED 18806) (T_NAME_RELATIVE 18807) (T_STATIC 18808) (T_STRING 18809) (T_VARIABLE 18810) (class_name 18811) (class_name_reference 18812) (name 18813) (new_variable 18814) (simple_variable 18815)) 8482 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18802) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8483 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18801) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8484 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18800) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8485 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18799) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8486 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18798) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8487 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18797) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8488 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18796) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8489 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18795) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8490 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18794) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8491 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18793) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8492 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18792) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8493 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18791) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8494 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18790) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8495 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18789) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8496 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18788) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8497 (("$" 18803) (T_VARIABLE 18810) (simple_variable 18837) ("{" 18838)) 8498 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 18835) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 8499 ((T_PAAMAYIM_NEKUDOTAYIM 18833)) 8500 ((T_NULLSAFE_OBJECT_OPERATOR 18816) (T_OBJECT_OPERATOR 18817) (T_PAAMAYIM_NEKUDOTAYIM 18818) ("[" 18819) ("{" 18820)) 8501 (("$" 18803) (T_STRING 18826) (T_VARIABLE 18810) (property_name 18832) (simple_variable 18828) ("{" 18829)) 8502 (("$" 18803) (T_STRING 18826) (T_VARIABLE 18810) (property_name 18827) (simple_variable 18828) ("{" 18829)) 8503 (("$" 18803) (T_VARIABLE 18810) (simple_variable 18825)) 8504 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 18823) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 8505 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 18821) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 8506 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 18822)) 8507 (("]" 18824)) 8508 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 18830) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 8509 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 18831)) 8510 (("$" 18803) (T_VARIABLE 18810) (simple_variable 18834)) 8511 (("%" 292) (")" 18836) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 8512 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 18839) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 8513 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 18840)) 8514 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18850) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8515 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 18848) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 8516 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18849) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8517 (("$" 18682) (T_ABSTRACT 18860) (T_ARRAY 18861) (T_AS 18862) (T_BREAK 18863) (T_CALLABLE 18864) (T_CASE 18865) (T_CATCH 18866) (T_CLASS 18867) (T_CLASS_C 18868) (T_CLONE 18869) (T_CONST 18870) (T_CONTINUE 18871) (T_DECLARE 18872) (T_DEFAULT 18873) (T_DIR 18874) (T_DO 18875) (T_ECHO 18876) (T_ELSE 18877) (T_ELSEIF 18878) (T_EMPTY 18879) (T_ENDDECLARE 18880) (T_ENDFOR 18881) (T_ENDFOREACH 18882) (T_ENDIF 18883) (T_ENDSWITCH 18884) (T_ENDWHILE 18885) (T_ENUM 18886) (T_EVAL 18887) (T_EXIT 18888) (T_EXTENDS 18889) (T_FILE 18890) (T_FINAL 18891) (T_FINALLY 18892) (T_FN 18893) (T_FOR 18894) (T_FOREACH 18895) (T_FUNCTION 18896) (T_FUNC_C 18897) (T_GLOBAL 18898) (T_GOTO 18899) (T_IF 18900) (T_IMPLEMENTS 18901) (T_INCLUDE 18902) (T_INCLUDE_ONCE 18903) (T_INSTANCEOF 18904) (T_INSTEADOF 18905) (T_INTERFACE 18906) (T_ISSET 18907) (T_LINE 18908) (T_LIST 18909) (T_LOGICAL_AND 18910) (T_LOGICAL_OR 18911) (T_LOGICAL_XOR 18912) (T_MATCH 18913) (T_METHOD_C 18914) (T_NAMESPACE 18915) (T_NEW 18916) (T_NS_C 18917) (T_PRINT 18918) (T_PRIVATE 18919) (T_PROTECTED 18920) (T_PUBLIC 18921) (T_READONLY 18922) (T_REQUIRE 18923) (T_REQUIRE_ONCE 18924) (T_RETURN 18925) (T_STATIC 18926) (T_STRING 18927) (T_SWITCH 18928) (T_THROW 18929) (T_TRAIT 18930) (T_TRAIT_C 18931) (T_TRY 18932) (T_UNSET 18933) (T_USE 18934) (T_VAR 18935) (T_VARIABLE 18729) (T_WHILE 18936) (T_YIELD 18937) (identifier 18938) (member_name 18939) (reserved_non_modifiers 18940) (semi_reserved 18941) (simple_variable 18942) ("{" 18943)) 8518 (("(" 18946) (argument_list 18947)) 8519 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 18944) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 8520 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 18945)) 8521 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 18948) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 18949) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 18950) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 8522 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 18953) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 8523 (("," 1469) (possible_comma 18951)) 8524 ((")" 18952)) 8525 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (ampersand 18983) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18984) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8526 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18982) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8527 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18981) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8528 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18980) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8529 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18979) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8530 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18978) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8531 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18977) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8532 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18976) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8533 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18975) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8534 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18974) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8535 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18973) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8536 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18972) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8537 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18971) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8538 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 18970) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8539 (("\"" 1509) ("$" 18985) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 18986) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 18987) ("[" 1529) (array_object_dereferenceable 18988) (callable_expr 18989) (callable_variable 18990) (class_constant 1533) (class_name 18991) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 18992) (name 18993) (simple_variable 18994) (static_member 18995) (variable 18996) (variable_class_name 18997)) 8540 (("$" 18985) (T_VARIABLE 18987) (simple_variable 19033) ("{" 19034)) 8541 (("(" 19001) (argument_list 19032)) 8542 ((T_NULLSAFE_OBJECT_OPERATOR 19015) (T_OBJECT_OPERATOR 19016) ("[" 19017) ("{" 19018)) 8543 (("(" 19001) (argument_list 19014)) 8544 ((T_PAAMAYIM_NEKUDOTAYIM 19010)) 8545 (("(" 19001) (argument_list 19009)) 8546 ((T_PAAMAYIM_NEKUDOTAYIM 18998)) 8547 (("$" 18985) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 18987) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 18999) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 19000) ("{" 1627)) 8548 (("(" 19001) (argument_list 19002)) 8549 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 19003) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 19004) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 19005) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 8550 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 19008) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 8551 (("," 1469) (possible_comma 19006)) 8552 ((")" 19007)) 8553 (("$" 18985) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 18987) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 19011) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 19012) ("{" 1643)) 8554 (("(" 19001) (argument_list 19013)) 8555 (("$" 18985) (T_STRING 19023) (T_VARIABLE 18987) (property_name 19030) (simple_variable 19025) ("{" 19026)) 8556 (("$" 18985) (T_STRING 19023) (T_VARIABLE 18987) (property_name 19024) (simple_variable 19025) ("{" 19026)) 8557 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 19021) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 8558 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 19019) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 8559 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 19020)) 8560 (("]" 19022)) 8561 (("(" 19001) (argument_list 19029)) 8562 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 19027) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 8563 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 19028)) 8564 (("(" 19001) (argument_list 19031)) 8565 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 19035) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 8566 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 19036)) 8567 ((backup_doc_comment 19039)) 8568 (("(" 19040)) 8569 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 19041)) 8570 ((")" 19042)) 8571 ((T_USE 159) (lexical_vars 19043)) 8572 ((":" 161) (return_type 19044)) 8573 ((backup_fn_flags 19045)) 8574 (("{" 19046)) 8575 ((inner_statement_list 19047)) 8576 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 19048) ("~" 125)) 8577 ((backup_fn_flags 19049)) 8578 ((backup_doc_comment 19051)) 8579 (("(" 19052)) 8580 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 19053)) 8581 ((")" 19054)) 8582 ((":" 2241) (return_type 19055)) 8583 ((T_DOUBLE_ARROW 19056)) 8584 ((backup_fn_flags 19057)) 8585 ((backup_lex_pos 19058)) 8586 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 19059) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8587 (("%" 18758) ("*" 18759) ("+" 18760) ("-" 18761) ("." 18762) ("/" 18763) ("<" 18764) (">" 18765) ("?" 18766) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 18767) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 18768) (T_BOOLEAN_AND 18769) (T_BOOLEAN_OR 18770) (T_COALESCE 18771) (T_INSTANCEOF 18772) (T_IS_EQUAL 18773) (T_IS_GREATER_OR_EQUAL 18774) (T_IS_IDENTICAL 18775) (T_IS_NOT_EQUAL 18776) (T_IS_NOT_IDENTICAL 18777) (T_IS_SMALLER_OR_EQUAL 18778) (T_LOGICAL_AND 18779) (T_LOGICAL_OR 18780) (T_LOGICAL_XOR 18781) (T_POW 18782) (T_SL 18783) (T_SPACESHIP 18784) (T_SR 18785) ("^" 18786) (backup_fn_flags 19060) ("|" 18787)) 8588 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 19062) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8589 (("$" 18682) (T_ABSTRACT 18860) (T_ARRAY 18861) (T_AS 18862) (T_BREAK 18863) (T_CALLABLE 18864) (T_CASE 18865) (T_CATCH 18866) (T_CLASS 18867) (T_CLASS_C 18868) (T_CLONE 18869) (T_CONST 18870) (T_CONTINUE 18871) (T_DECLARE 18872) (T_DEFAULT 18873) (T_DIR 18874) (T_DO 18875) (T_ECHO 18876) (T_ELSE 18877) (T_ELSEIF 18878) (T_EMPTY 18879) (T_ENDDECLARE 18880) (T_ENDFOR 18881) (T_ENDFOREACH 18882) (T_ENDIF 18883) (T_ENDSWITCH 18884) (T_ENDWHILE 18885) (T_ENUM 18886) (T_EVAL 18887) (T_EXIT 18888) (T_EXTENDS 18889) (T_FILE 18890) (T_FINAL 18891) (T_FINALLY 18892) (T_FN 18893) (T_FOR 18894) (T_FOREACH 18895) (T_FUNCTION 18896) (T_FUNC_C 18897) (T_GLOBAL 18898) (T_GOTO 18899) (T_IF 18900) (T_IMPLEMENTS 18901) (T_INCLUDE 18902) (T_INCLUDE_ONCE 18903) (T_INSTANCEOF 18904) (T_INSTEADOF 18905) (T_INTERFACE 18906) (T_ISSET 18907) (T_LINE 18908) (T_LIST 18909) (T_LOGICAL_AND 18910) (T_LOGICAL_OR 18911) (T_LOGICAL_XOR 18912) (T_MATCH 18913) (T_METHOD_C 18914) (T_NAMESPACE 18915) (T_NEW 18916) (T_NS_C 18917) (T_PRINT 18918) (T_PRIVATE 18919) (T_PROTECTED 18920) (T_PUBLIC 18921) (T_READONLY 18922) (T_REQUIRE 18923) (T_REQUIRE_ONCE 18924) (T_RETURN 18925) (T_STATIC 18926) (T_STRING 18927) (T_SWITCH 18928) (T_THROW 18929) (T_TRAIT 18930) (T_TRAIT_C 18931) (T_TRY 18932) (T_UNSET 18933) (T_USE 18934) (T_VAR 18935) (T_VARIABLE 18729) (T_WHILE 18936) (T_YIELD 18937) (identifier 19064) (member_name 19065) (reserved_non_modifiers 18940) (semi_reserved 18941) (simple_variable 19066) ("{" 19067)) 8590 (("(" 18946) (argument_list 19070)) 8591 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 19068) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 8592 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 19069)) 8593 ((T_FN 35) (T_FUNCTION 127) (fn 18743) #'18744 (inline_function 19074)) 8594 (("$" 18682) (T_STRING 19083) (T_VARIABLE 18729) (property_name 19090) (simple_variable 19085) ("{" 19086)) 8595 (("$" 18682) (T_STRING 19083) (T_VARIABLE 18729) (property_name 19084) (simple_variable 19085) ("{" 19086)) 8596 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 19081) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 8597 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 19079) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 8598 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 19080)) 8599 (("]" 19082)) 8600 (("(" 18946) (argument_list 19089)) 8601 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 19087) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 8602 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 19088)) 8603 (("(" 18946) (argument_list 19091)) 8604 (("`" 19093)) 8605 (("]" 19095)) 8606 (("=" 19096)) 8607 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 19097) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8608 (("%" 18758) ("*" 18759) ("+" 18760) ("-" 18761) ("." 18762) ("/" 18763) ("<" 18764) (">" 18765) ("?" 18766) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 18767) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 18768) (T_BOOLEAN_AND 18769) (T_BOOLEAN_OR 18770) (T_COALESCE 18771) (T_DOUBLE_ARROW 19100) (T_INSTANCEOF 18772) (T_IS_EQUAL 18773) (T_IS_GREATER_OR_EQUAL 18774) (T_IS_IDENTICAL 18775) (T_IS_NOT_EQUAL 18776) (T_IS_NOT_IDENTICAL 18777) (T_IS_SMALLER_OR_EQUAL 18778) (T_LOGICAL_AND 18779) (T_LOGICAL_OR 18780) (T_LOGICAL_XOR 18781) (T_POW 18782) (T_SL 18783) (T_SPACESHIP 18784) (T_SR 18785) ("^" 18786) ("|" 18787)) 8609 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 19101) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8610 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 19110) (T_VARIABLE 2900) (encaps_var 2914)) 8611 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 19109) (T_VARIABLE 2900) (encaps_var 2905)) 8612 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 19162) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 8613 ((T_CLASS 19154)) 8614 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 19153) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 19123) (attribute 2980) (class_modifier 2945)) 8615 ((T_PAAMAYIM_NEKUDOTAYIM 19151)) 8616 (("(" 19142) (argument_list 19143) (ctor_arguments 19144)) 8617 ((T_NULLSAFE_OBJECT_OPERATOR 19130) (T_OBJECT_OPERATOR 19131) (T_PAAMAYIM_NEKUDOTAYIM 19132) ("[" 19133) ("{" 19134)) 8618 (("$" 18985) (T_STRING 19023) (T_VARIABLE 18987) (property_name 19141) (simple_variable 19025) ("{" 19026)) 8619 (("$" 18985) (T_STRING 19023) (T_VARIABLE 18987) (property_name 19140) (simple_variable 19025) ("{" 19026)) 8620 (("$" 18985) (T_VARIABLE 18987) (simple_variable 19139)) 8621 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 19137) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 8622 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 19135) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 8623 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 19136)) 8624 (("]" 19138)) 8625 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 19145) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 19146) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 19147) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 8626 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 19150) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 8627 (("," 1469) (possible_comma 19148)) 8628 ((")" 19149)) 8629 (("$" 18985) (T_VARIABLE 18987) (simple_variable 19152)) 8630 (("(" 2982) (argument_list 2983) (ctor_arguments 19155)) 8631 ((T_EXTENDS 2985) (extends_from 19156)) 8632 ((T_IMPLEMENTS 2987) (implements_list 19157)) 8633 ((backup_doc_comment 19158)) 8634 (("{" 19159)) 8635 ((class_statement_list 19160)) 8636 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 19161)) 8637 (("%" 292) (")" 19163) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 8638 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 19165) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 8639 (("%" 292) (")" 19166) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 8640 (("{" 19167)) 8641 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 19168) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 8642 (("}" 19169)) 8643 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 19171) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 8644 ((")" 19172)) 8645 (("=" 19173)) 8646 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 19174) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 8647 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 19176) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 8648 (("," 5258) (possible_comma 19177)) 8649 ((")" 19178)) 8650 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 19185) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 8651 ((")" 19186)) 8652 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 19188) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 8653 (("%" 292) (")" 19189) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 8654 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 19191) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 8655 (("%" 292) (")" 19192) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 8656 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 19199) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 8657 ((")" 19200)) 8658 (("%" 292) (")" 19205) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 8659 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 19208) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 8660 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 19209)) 8661 (("\"" 19211) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 8662 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 19221) (T_VARIABLE 2900) (encaps_var 2914)) 8663 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 19220) (T_VARIABLE 2900) (encaps_var 2905)) 8664 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 19273) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 8665 ((T_CLASS 19265)) 8666 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 19264) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 19234) (attribute 2980) (class_modifier 2945)) 8667 ((T_PAAMAYIM_NEKUDOTAYIM 19262)) 8668 (("(" 19253) (argument_list 19254) (ctor_arguments 19255)) 8669 ((T_NULLSAFE_OBJECT_OPERATOR 19241) (T_OBJECT_OPERATOR 19242) (T_PAAMAYIM_NEKUDOTAYIM 19243) ("[" 19244) ("{" 19245)) 8670 (("$" 18567) (T_STRING 18605) (T_VARIABLE 18569) (property_name 19252) (simple_variable 18607) ("{" 18608)) 8671 (("$" 18567) (T_STRING 18605) (T_VARIABLE 18569) (property_name 19251) (simple_variable 18607) ("{" 18608)) 8672 (("$" 18567) (T_VARIABLE 18569) (simple_variable 19250)) 8673 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 19248) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 8674 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 19246) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 8675 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 19247)) 8676 (("]" 19249)) 8677 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 19256) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 19257) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 19258) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 8678 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 19261) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 8679 (("," 1469) (possible_comma 19259)) 8680 ((")" 19260)) 8681 (("$" 18567) (T_VARIABLE 18569) (simple_variable 19263)) 8682 (("(" 2982) (argument_list 2983) (ctor_arguments 19266)) 8683 ((T_EXTENDS 2985) (extends_from 19267)) 8684 ((T_IMPLEMENTS 2987) (implements_list 19268)) 8685 ((backup_doc_comment 19269)) 8686 (("{" 19270)) 8687 ((class_statement_list 19271)) 8688 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 19272)) 8689 (("%" 292) (")" 19274) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 8690 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 19276) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 8691 (("%" 292) (")" 19277) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 8692 (("{" 19278)) 8693 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 19279) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 8694 (("}" 19280)) 8695 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 19282) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 8696 ((")" 19283)) 8697 (("=" 19284)) 8698 (("!" 18262) ("\"" 18263) ("$" 18264) ("(" 18265) ("+" 18266) ("-" 18267) ("@" 18268) (T_ARRAY 18269) (T_ARRAY_CAST 18270) (T_ATTRIBUTE 126) (T_BOOL_CAST 18271) (T_CLASS_C 18272) (T_CLONE 18273) (T_CONSTANT_ENCAPSED_STRING 18274) (T_DEC 18275) (T_DIR 18276) (T_DNUMBER 18277) (T_DOUBLE_CAST 18278) (T_EMPTY 18279) (T_EVAL 18280) (T_EXIT 18281) (T_FILE 18282) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18283) (T_INC 18284) (T_INCLUDE 18285) (T_INCLUDE_ONCE 18286) (T_INT_CAST 18287) (T_ISSET 18288) (T_LINE 18289) (T_LIST 18290) (T_LNUMBER 18291) (T_MATCH 18292) (T_METHOD_C 18293) (T_NAME_FULLY_QUALIFIED 18294) (T_NAME_QUALIFIED 18295) (T_NAME_RELATIVE 18296) (T_NEW 18297) (T_NS_C 18298) (T_OBJECT_CAST 18299) (T_PRINT 18300) (T_READONLY 18301) (T_REQUIRE 18302) (T_REQUIRE_ONCE 18303) (T_START_HEREDOC 18304) (T_STATIC 18305) (T_STRING 18306) (T_STRING_CAST 18307) (T_THROW 18308) (T_TRAIT_C 18309) (T_UNSET_CAST 18310) (T_VARIABLE 18311) (T_YIELD 18312) (T_YIELD_FROM 18313) ("[" 18314) ("`" 18315) (array_object_dereferenceable 18316) (attribute 131) (attributes 18317) (callable_expr 18318) (callable_variable 18319) (class_constant 18320) (class_name 18321) (constant 18322) (dereferenceable_scalar 18323) (expr 19285) (fn 18325) (fully_dereferenceable 104) #'18326 (function_call 18327) (inline_function 18328) (internal_functions_in_yacc 18329) (match 18330) (name 18331) (new_expr 18332) (scalar 18333) (simple_variable 18334) (static_member 18335) (variable 18336) (variable_class_name 18337) ("~" 18338)) 8699 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 19287) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 8700 (("," 5258) (possible_comma 19288)) 8701 ((")" 19289)) 8702 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 19296) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 8703 ((")" 19297)) 8704 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 19299) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 8705 (("%" 292) (")" 19300) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 8706 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 19302) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 8707 (("%" 292) (")" 19303) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 8708 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 19310) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 8709 ((")" 19311)) 8710 (("%" 292) (")" 19316) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 8711 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 19319) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 8712 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 19320)) 8713 (("\"" 19322) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 8714 (("\"" 1509) ("$" 19325) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19326) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19327) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19328) ("[" 19329) (ampersand 19330) (array_object_dereferenceable 19331) (callable_expr 19332) (callable_variable 19333) (class_constant 1533) (class_name 19334) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 19335) (fully_dereferenceable 104) (function_call 19336) (name 19337) (simple_variable 19338) (static_member 19339) (variable 19340) (variable_class_name 19341)) 8715 (("$" 19325) (T_VARIABLE 19328) (simple_variable 20909) ("{" 20910)) 8716 (("(" 20906)) 8717 (("(" 19345) (argument_list 20905)) 8718 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 20903) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 8719 (("\"" 1509) ("$" 19325) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19327) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19328) ("[" 1529) (array_object_dereferenceable 19331) (callable_expr 19332) (callable_variable 19333) (class_constant 1533) (class_name 19334) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 19336) (name 19337) (simple_variable 19338) (static_member 19339) (variable 20902) (variable_class_name 19341)) 8720 ((T_NULLSAFE_OBJECT_OPERATOR 20885) (T_OBJECT_OPERATOR 20886) ("[" 20887) ("{" 20888)) 8721 (("(" 19345) (argument_list 20884)) 8722 ((T_PAAMAYIM_NEKUDOTAYIM 20880)) 8723 ((")" 19354) (T_DOUBLE_ARROW 19355)) 8724 (("(" 19345) (argument_list 19353)) 8725 ((T_PAAMAYIM_NEKUDOTAYIM 19342)) 8726 (("$" 19325) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 19328) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 19343) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 19344) ("{" 1627)) 8727 (("(" 19345) (argument_list 19346)) 8728 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 19347) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 19348) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 19349) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 8729 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 19352) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 8730 (("," 1469) (possible_comma 19350)) 8731 ((")" 19351)) 8732 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 19386) (";" 16761) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16762) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16763) (T_DEC 22) (T_DECLARE 16764) (T_DIR 24) (T_DNUMBER 25) (T_DO 16765) (T_DOUBLE_CAST 27) (T_ECHO 16766) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16767) (T_FOREACH 16768) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16769) (T_GOTO 16770) (T_IF 16726) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16771) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16772) (T_START_HEREDOC 68) (T_STATIC 16773) (T_STRING 16774) (T_STRING_CAST 71) (T_SWITCH 16775) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16776) (T_UNSET 16777) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16778) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16779) (alt_if_stmt_without_else 16780) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16781) (fn 103) (foreach_statement 20879) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16782) (if_stmt_without_else 16783) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19388) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16785) ("~" 125)) 8733 (("\"" 1509) ("$" 19356) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19357) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19358) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19359) ("[" 19360) (ampersand 19361) (array_object_dereferenceable 19362) (callable_expr 19363) (callable_variable 19364) (class_constant 1533) (class_name 19365) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 19366) (fully_dereferenceable 104) (function_call 19367) (name 19368) (simple_variable 19369) (static_member 19370) (variable 19371) (variable_class_name 19372)) 8734 (("$" 19356) (T_VARIABLE 19359) (simple_variable 20875) ("{" 20876)) 8735 (("(" 20872)) 8736 (("(" 19376) (argument_list 20871)) 8737 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 20869) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 8738 (("\"" 1509) ("$" 19356) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19358) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19359) ("[" 1529) (array_object_dereferenceable 19362) (callable_expr 19363) (callable_variable 19364) (class_constant 1533) (class_name 19365) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 19367) (name 19368) (simple_variable 19369) (static_member 19370) (variable 20868) (variable_class_name 19372)) 8739 ((T_NULLSAFE_OBJECT_OPERATOR 20851) (T_OBJECT_OPERATOR 20852) ("[" 20853) ("{" 20854)) 8740 (("(" 19376) (argument_list 20850)) 8741 ((T_PAAMAYIM_NEKUDOTAYIM 20846)) 8742 ((")" 19385)) 8743 (("(" 19376) (argument_list 19384)) 8744 ((T_PAAMAYIM_NEKUDOTAYIM 19373)) 8745 (("$" 19356) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 19359) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 19374) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 19375) ("{" 1627)) 8746 (("(" 19376) (argument_list 19377)) 8747 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 19378) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 19379) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 19380) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 8748 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 19383) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 8749 (("," 1469) (possible_comma 19381)) 8750 ((")" 19382)) 8751 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 19386) (";" 16761) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16762) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16763) (T_DEC 22) (T_DECLARE 16764) (T_DIR 24) (T_DNUMBER 25) (T_DO 16765) (T_DOUBLE_CAST 27) (T_ECHO 16766) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16767) (T_FOREACH 16768) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16769) (T_GOTO 16770) (T_IF 16726) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16771) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16772) (T_START_HEREDOC 68) (T_STATIC 16773) (T_STRING 16774) (T_STRING_CAST 71) (T_SWITCH 16775) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16776) (T_UNSET 16777) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16778) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16779) (alt_if_stmt_without_else 16780) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16781) (fn 103) (foreach_statement 19387) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16782) (if_stmt_without_else 16783) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19388) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16785) ("~" 125)) 8752 ((inner_statement_list 19389)) 8753 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19390) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19391) (T_CLASS 19392) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19393) (T_DEC 22) (T_DECLARE 19394) (T_DIR 24) (T_DNUMBER 25) (T_DO 19395) (T_DOUBLE_CAST 27) (T_ECHO 19396) (T_EMPTY 29) (T_ENDFOREACH 19397) (T_ENUM 19398) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19399) (T_FOREACH 19400) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19401) (T_GOTO 19402) (T_HALT_COMPILER 19403) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19405) (T_INTERFACE 19406) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19407) (T_START_HEREDOC 68) (T_STATIC 19408) (T_STRING 19409) (T_STRING_CAST 71) (T_SWITCH 19410) (T_THROW 73) (T_TRAIT 19411) (T_TRAIT_C 75) (T_TRY 19412) (T_UNSET 19413) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19414) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19415) (alt_if_stmt_without_else 19416) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19417) (attributes 19418) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19419) (class_modifier 96) (class_modifiers 19420) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19421) (expr 19422) (fn 103) (fully_dereferenceable 104) #'19423 (function_call 106) (function_declaration_statement 19424) (if_stmt 19425) (if_stmt_without_else 19426) (inline_function 110) (inner_statement 19427) (interface_declaration_statement 19428) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19429) (static_member 119) (trait_declaration_statement 19430) (variable 122) (variable_class_name 123) ("{" 19431) ("~" 125)) 8754 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 20844) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 8755 ((T_STRING 20837)) 8756 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 20835) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 8757 (("(" 20826)) 8758 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19746) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19747) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19748) (T_DEC 22) (T_DECLARE 19749) (T_DIR 24) (T_DNUMBER 25) (T_DO 19750) (T_DOUBLE_CAST 27) (T_ECHO 19751) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19752) (T_FOREACH 19753) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19754) (T_GOTO 19755) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19757) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19758) (T_START_HEREDOC 68) (T_STATIC 19759) (T_STRING 19760) (T_STRING_CAST 71) (T_SWITCH 19761) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19762) (T_UNSET 19763) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19764) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19765) (alt_if_stmt_without_else 19766) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19767) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19768) (if_stmt_without_else 19769) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20820) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19771) ("~" 125)) 8759 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (echo_expr 19740) (echo_expr_list 20818) (expr 19742) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 8760 ((";" 20817)) 8761 ((T_STRING 20810)) 8762 (("(" 20797)) 8763 (("(" 20782)) 8764 (("$" 17870) (T_VARIABLE 17871) (global_var 17872) (global_var_list 20780) (simple_variable 17874)) 8765 ((T_STRING 20778)) 8766 (("(" 20775)) 8767 (("(" 20771)) 8768 ((T_STRING 20765)) 8769 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 20763) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 8770 ((T_FN 35) (T_FUNCTION 127) (T_VARIABLE 16848) (fn 103) #'134 (inline_function 16849) (static_var 16850) (static_var_list 20761)) 8771 ((":" 20760)) 8772 (("(" 20742)) 8773 ((T_STRING 20737)) 8774 (("{" 20720)) 8775 (("(" 20715)) 8776 (("(" 20706)) 8777 ((T_ELSE 20699) (T_ELSEIF 16203) (T_ENDIF 20700)) 8778 ((T_ABSTRACT 10) (T_ATTRIBUTE 13) (T_CLASS 19392) (T_ENUM 19398) (T_FINAL 34) (T_FN 35) (T_FUNCTION 38) (T_INTERFACE 19406) (T_READONLY 2936) (T_STATIC 16288) (T_TRAIT 19411) (attribute 16289) (attributed_statement 20698) (class_declaration_statement 19419) (class_modifier 96) (class_modifiers 19420) (enum_declaration_statement 19421) (fn 103) #'19423 (function_declaration_statement 19424) (inline_function 16291) (interface_declaration_statement 19428) (trait_declaration_statement 19430)) 8779 ((T_ABSTRACT 10) (T_CLASS 20690) (T_FINAL 34) (T_READONLY 2936) (class_modifier 16280)) 8780 (("%" 6465) ("*" 6466) ("+" 6467) ("-" 6468) ("." 6469) ("/" 6470) (";" 20689) ("<" 6471) (">" 6472) ("?" 6473) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 6474) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 6475) (T_BOOLEAN_AND 6476) (T_BOOLEAN_OR 6477) (T_COALESCE 6478) (T_INSTANCEOF 6479) (T_IS_EQUAL 6480) (T_IS_GREATER_OR_EQUAL 6481) (T_IS_IDENTICAL 6482) (T_IS_NOT_EQUAL 6483) (T_IS_NOT_IDENTICAL 6484) (T_IS_SMALLER_OR_EQUAL 6485) (T_LOGICAL_AND 6486) (T_LOGICAL_OR 6487) (T_LOGICAL_XOR 6488) (T_POW 6489) (T_SL 6490) (T_SPACESHIP 6491) (T_SR 6492) ("^" 6493) ("|" 6494)) 8781 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 16261) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 16262) (ampersand 16263) (returns_ref 20677)) 8782 ((T_ELSE 19434) (T_ELSEIF 19435)) 8783 ((inner_statement_list 19432)) 8784 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 19433) ("~" 125)) 8785 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19390) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19391) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19393) (T_DEC 22) (T_DECLARE 19394) (T_DIR 24) (T_DNUMBER 25) (T_DO 19395) (T_DOUBLE_CAST 27) (T_ECHO 19396) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19399) (T_FOREACH 19400) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19401) (T_GOTO 19402) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19405) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19407) (T_START_HEREDOC 68) (T_STATIC 19408) (T_STRING 19409) (T_STRING_CAST 71) (T_SWITCH 19410) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19412) (T_UNSET 19413) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19414) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19415) (alt_if_stmt_without_else 19416) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19422) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19425) (if_stmt_without_else 19426) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20676) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19431) ("~" 125)) 8786 (("(" 19436)) 8787 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 19437) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 8788 (("%" 292) (")" 19438) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 8789 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19439) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19440) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19441) (T_DEC 22) (T_DECLARE 19442) (T_DIR 24) (T_DNUMBER 25) (T_DO 19443) (T_DOUBLE_CAST 27) (T_ECHO 19444) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19445) (T_FOREACH 19446) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19447) (T_GOTO 19448) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19449) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19450) (T_START_HEREDOC 68) (T_STATIC 19451) (T_STRING 19452) (T_STRING_CAST 71) (T_SWITCH 19453) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19454) (T_UNSET 19455) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19456) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19457) (alt_if_stmt_without_else 19458) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19459) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19460) (if_stmt_without_else 19461) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19462) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19463) ("~" 125)) 8790 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 20674) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 8791 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 20672) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 8792 (("(" 20663)) 8793 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19746) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19747) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19748) (T_DEC 22) (T_DECLARE 19749) (T_DIR 24) (T_DNUMBER 25) (T_DO 19750) (T_DOUBLE_CAST 27) (T_ECHO 19751) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19752) (T_FOREACH 19753) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19754) (T_GOTO 19755) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19757) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19758) (T_START_HEREDOC 68) (T_STATIC 19759) (T_STRING 19760) (T_STRING_CAST 71) (T_SWITCH 19761) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19762) (T_UNSET 19763) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19764) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19765) (alt_if_stmt_without_else 19766) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19767) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19768) (if_stmt_without_else 19769) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20657) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19771) ("~" 125)) 8794 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (echo_expr 19740) (echo_expr_list 20655) (expr 19742) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 8795 (("(" 19549)) 8796 (("(" 19534)) 8797 (("$" 17870) (T_VARIABLE 17871) (global_var 17872) (global_var_list 19532) (simple_variable 17874)) 8798 ((T_STRING 19530)) 8799 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 19528) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 8800 ((T_FN 35) (T_FUNCTION 127) (T_VARIABLE 16848) (fn 103) #'134 (inline_function 16849) (static_var 16850) (static_var_list 19526)) 8801 ((":" 19525)) 8802 (("(" 19507)) 8803 (("{" 19490)) 8804 (("(" 19485)) 8805 (("(" 19476)) 8806 ((T_ELSE 19469) (T_ELSEIF 16203) (T_ENDIF 19470)) 8807 (("%" 6465) ("*" 6466) ("+" 6467) ("-" 6468) ("." 6469) ("/" 6470) (";" 19468) ("<" 6471) (">" 6472) ("?" 6473) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 6474) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 6475) (T_BOOLEAN_AND 6476) (T_BOOLEAN_OR 6477) (T_COALESCE 6478) (T_INSTANCEOF 6479) (T_IS_EQUAL 6480) (T_IS_GREATER_OR_EQUAL 6481) (T_IS_IDENTICAL 6482) (T_IS_NOT_EQUAL 6483) (T_IS_NOT_IDENTICAL 6484) (T_IS_SMALLER_OR_EQUAL 6485) (T_LOGICAL_AND 6486) (T_LOGICAL_OR 6487) (T_LOGICAL_XOR 6488) (T_POW 6489) (T_SL 6490) (T_SPACESHIP 6491) (T_SR 6492) ("^" 6493) ("|" 6494)) 8808 ((T_ELSE 19466) (T_ELSEIF 19435)) 8809 ((inner_statement_list 19464)) 8810 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 19465) ("~" 125)) 8811 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19439) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19440) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19441) (T_DEC 22) (T_DECLARE 19442) (T_DIR 24) (T_DNUMBER 25) (T_DO 19443) (T_DOUBLE_CAST 27) (T_ECHO 19444) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19445) (T_FOREACH 19446) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19447) (T_GOTO 19448) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19449) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19450) (T_START_HEREDOC 68) (T_STATIC 19451) (T_STRING 19452) (T_STRING_CAST 71) (T_SWITCH 19453) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19454) (T_UNSET 19455) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19456) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19457) (alt_if_stmt_without_else 19458) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19459) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19460) (if_stmt_without_else 19461) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19467) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19463) ("~" 125)) 8812 ((":" 19472)) 8813 ((";" 19471)) 8814 ((inner_statement_list 19473)) 8815 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16298) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16299) (T_CLASS 16300) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16301) (T_DEC 22) (T_DECLARE 16302) (T_DIR 24) (T_DNUMBER 25) (T_DO 16303) (T_DOUBLE_CAST 27) (T_ECHO 16304) (T_EMPTY 29) (T_ENDIF 19474) (T_ENUM 16306) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16307) (T_FOREACH 16308) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16309) (T_GOTO 16310) (T_HALT_COMPILER 16311) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16312) (T_INTERFACE 16313) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16314) (T_START_HEREDOC 68) (T_STATIC 16315) (T_STRING 16316) (T_STRING_CAST 71) (T_SWITCH 16317) (T_THROW 73) (T_TRAIT 16318) (T_TRAIT_C 75) (T_TRY 16319) (T_UNSET 16320) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16321) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16322) (alt_if_stmt_without_else 16323) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16324) (attributes 16325) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16326) (class_modifier 96) (class_modifiers 16327) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16328) (expr 16329) (fn 103) (fully_dereferenceable 104) #'16330 (function_call 106) (function_declaration_statement 16331) (if_stmt 16332) (if_stmt_without_else 16333) (inline_function 110) (inner_statement 16334) (interface_declaration_statement 16335) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16336) (static_member 119) (trait_declaration_statement 16337) (variable 122) (variable_class_name 123) ("{" 16338) ("~" 125)) 8816 ((";" 19475)) 8817 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 19477) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 8818 (("%" 292) (")" 19478) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 8819 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 19479) (";" 19439) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19440) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19441) (T_DEC 22) (T_DECLARE 19442) (T_DIR 24) (T_DNUMBER 25) (T_DO 19443) (T_DOUBLE_CAST 27) (T_ECHO 19444) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19445) (T_FOREACH 19446) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19447) (T_GOTO 19448) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19449) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19450) (T_START_HEREDOC 68) (T_STATIC 19451) (T_STRING 19452) (T_STRING_CAST 71) (T_SWITCH 19453) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19454) (T_UNSET 19455) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19456) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19457) (alt_if_stmt_without_else 19458) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19459) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19460) (if_stmt_without_else 19461) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19480) (static_member 119) (variable 122) (variable_class_name 123) (while_statement 19481) ("{" 19463) ("~" 125)) 8820 ((inner_statement_list 19482)) 8821 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16379) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16380) (T_CLASS 16381) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16382) (T_DEC 22) (T_DECLARE 16383) (T_DIR 24) (T_DNUMBER 25) (T_DO 16384) (T_DOUBLE_CAST 27) (T_ECHO 16385) (T_EMPTY 29) (T_ENDWHILE 19483) (T_ENUM 16387) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16388) (T_FOREACH 16389) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16390) (T_GOTO 16391) (T_HALT_COMPILER 16392) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16394) (T_INTERFACE 16395) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16396) (T_START_HEREDOC 68) (T_STATIC 16397) (T_STRING 16398) (T_STRING_CAST 71) (T_SWITCH 16399) (T_THROW 73) (T_TRAIT 16400) (T_TRAIT_C 75) (T_TRY 16401) (T_UNSET 16402) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16403) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16404) (alt_if_stmt_without_else 16405) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16406) (attributes 16407) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16408) (class_modifier 96) (class_modifiers 16409) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16410) (expr 16411) (fn 103) (fully_dereferenceable 104) #'16412 (function_call 106) (function_declaration_statement 16413) (if_stmt 16414) (if_stmt_without_else 16415) (inline_function 110) (inner_statement 16416) (interface_declaration_statement 16417) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16418) (static_member 119) (trait_declaration_statement 16419) (variable 122) (variable_class_name 123) ("{" 16420) ("~" 125)) 8822 ((";" 19484)) 8823 (("\"" 1509) ("$" 16475) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 16476) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 16477) ("[" 1529) (array_object_dereferenceable 16478) (callable_expr 16479) (callable_variable 16480) (class_constant 1533) (class_name 16481) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 16482) (name 16483) (simple_variable 16484) (static_member 16485) (unset_variable 16486) (unset_variables 19486) (variable 16488) (variable_class_name 16489)) 8824 (("," 16501) (possible_comma 19487)) 8825 ((")" 19488)) 8826 ((";" 19489)) 8827 ((inner_statement_list 19491)) 8828 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 19492) ("~" 125)) 8829 ((catch_list 19493)) 8830 ((T_CATCH 19494) (T_FINALLY 19495) (finally_statement 19496)) 8831 (("(" 19500)) 8832 (("{" 19497)) 8833 ((inner_statement_list 19498)) 8834 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 19499) ("~" 125)) 8835 ((T_NAME_FULLY_QUALIFIED 16545) (T_NAME_QUALIFIED 16546) (T_NAME_RELATIVE 16547) (T_STATIC 16548) (T_STRING 16549) (catch_name_list 19501) (class_name 16551) (name 16552)) 8836 ((T_VARIABLE 16553) (optional_variable 19502) ("|" 16555)) 8837 ((")" 19503)) 8838 (("{" 19504)) 8839 ((inner_statement_list 19505)) 8840 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 19506) ("~" 125)) 8841 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 19508) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 8842 (("%" 292) (")" 19509) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 8843 ((":" 19510) (switch_case_list 19511) ("{" 19512)) 8844 ((";" 19518) (case_list 19519)) 8845 ((";" 19513) (case_list 19514)) 8846 ((case_list 19516)) 8847 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 19515)) 8848 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 19517)) 8849 ((case_list 19522)) 8850 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 19520)) 8851 ((";" 19521)) 8852 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 19523)) 8853 ((";" 19524)) 8854 (("," 16852) (";" 19527)) 8855 ((";" 19529)) 8856 ((";" 19531)) 8857 (("," 17875) (";" 19533)) 8858 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 19535) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8859 (("%" 17961) ("*" 17962) ("+" 17963) ("-" 17964) ("." 17965) ("/" 17966) ("<" 17967) (">" 17968) ("?" 17969) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 17970) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 17971) (T_AS 19536) (T_BOOLEAN_AND 17972) (T_BOOLEAN_OR 17973) (T_COALESCE 17974) (T_INSTANCEOF 17975) (T_IS_EQUAL 17976) (T_IS_GREATER_OR_EQUAL 17977) (T_IS_IDENTICAL 17978) (T_IS_NOT_EQUAL 17979) (T_IS_NOT_IDENTICAL 17980) (T_IS_SMALLER_OR_EQUAL 17981) (T_LOGICAL_AND 17982) (T_LOGICAL_OR 17983) (T_LOGICAL_XOR 17984) (T_POW 17985) (T_SL 17986) (T_SPACESHIP 17987) (T_SR 17988) ("^" 17989) ("|" 17990)) 8860 (("\"" 1509) ("$" 19325) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19326) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19327) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19328) ("[" 19329) (ampersand 19330) (array_object_dereferenceable 19331) (callable_expr 19332) (callable_variable 19333) (class_constant 1533) (class_name 19334) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 19537) (fully_dereferenceable 104) (function_call 19336) (name 19337) (simple_variable 19338) (static_member 19339) (variable 19340) (variable_class_name 19341)) 8861 ((")" 19538) (T_DOUBLE_ARROW 19539)) 8862 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 19542) (";" 19439) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19440) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19441) (T_DEC 22) (T_DECLARE 19442) (T_DIR 24) (T_DNUMBER 25) (T_DO 19443) (T_DOUBLE_CAST 27) (T_ECHO 19444) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19445) (T_FOREACH 19446) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19447) (T_GOTO 19448) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19449) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19450) (T_START_HEREDOC 68) (T_STATIC 19451) (T_STRING 19452) (T_STRING_CAST 71) (T_SWITCH 19453) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19454) (T_UNSET 19455) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19456) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19457) (alt_if_stmt_without_else 19458) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19459) (fn 103) (foreach_statement 19548) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19460) (if_stmt_without_else 19461) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19544) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19463) ("~" 125)) 8863 (("\"" 1509) ("$" 19356) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19357) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19358) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19359) ("[" 19360) (ampersand 19361) (array_object_dereferenceable 19362) (callable_expr 19363) (callable_variable 19364) (class_constant 1533) (class_name 19365) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 19540) (fully_dereferenceable 104) (function_call 19367) (name 19368) (simple_variable 19369) (static_member 19370) (variable 19371) (variable_class_name 19372)) 8864 ((")" 19541)) 8865 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 19542) (";" 19439) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19440) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19441) (T_DEC 22) (T_DECLARE 19442) (T_DIR 24) (T_DNUMBER 25) (T_DO 19443) (T_DOUBLE_CAST 27) (T_ECHO 19444) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19445) (T_FOREACH 19446) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19447) (T_GOTO 19448) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19449) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19450) (T_START_HEREDOC 68) (T_STATIC 19451) (T_STRING 19452) (T_STRING_CAST 71) (T_SWITCH 19453) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19454) (T_UNSET 19455) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19456) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19457) (alt_if_stmt_without_else 19458) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19459) (fn 103) (foreach_statement 19543) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19460) (if_stmt_without_else 19461) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19544) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19463) ("~" 125)) 8866 ((inner_statement_list 19545)) 8867 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19390) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19391) (T_CLASS 19392) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19393) (T_DEC 22) (T_DECLARE 19394) (T_DIR 24) (T_DNUMBER 25) (T_DO 19395) (T_DOUBLE_CAST 27) (T_ECHO 19396) (T_EMPTY 29) (T_ENDFOREACH 19546) (T_ENUM 19398) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19399) (T_FOREACH 19400) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19401) (T_GOTO 19402) (T_HALT_COMPILER 19403) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19405) (T_INTERFACE 19406) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19407) (T_START_HEREDOC 68) (T_STATIC 19408) (T_STRING 19409) (T_STRING_CAST 71) (T_SWITCH 19410) (T_THROW 73) (T_TRAIT 19411) (T_TRAIT_C 75) (T_TRY 19412) (T_UNSET 19413) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19414) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19415) (alt_if_stmt_without_else 19416) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19417) (attributes 19418) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19419) (class_modifier 96) (class_modifiers 19420) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19421) (expr 19422) (fn 103) (fully_dereferenceable 104) #'19423 (function_call 106) (function_declaration_statement 19424) (if_stmt 19425) (if_stmt_without_else 19426) (inline_function 110) (inner_statement 19427) (interface_declaration_statement 19428) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19429) (static_member 119) (trait_declaration_statement 19430) (variable 122) (variable_class_name 123) ("{" 19431) ("~" 125)) 8868 ((";" 19547)) 8869 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 19551) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 8870 ((";" 19555)) 8871 (("," 19553)) 8872 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19554) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 8873 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 19556) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 8874 ((";" 19557)) 8875 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 19558) (fn 2394) (for_exprs 19559) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (non_empty_for_exprs 19560) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 8876 ((")" 19563)) 8877 (("," 19561)) 8878 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 19562) (fn 2394) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 8879 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 19564) (";" 19439) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19440) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19441) (T_DEC 22) (T_DECLARE 19442) (T_DIR 24) (T_DNUMBER 25) (T_DO 19443) (T_DOUBLE_CAST 27) (T_ECHO 19444) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19445) (T_FOREACH 19446) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19447) (T_GOTO 19448) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19449) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19450) (T_START_HEREDOC 68) (T_STATIC 19451) (T_STRING 19452) (T_STRING_CAST 71) (T_SWITCH 19453) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19454) (T_UNSET 19455) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19456) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19457) (alt_if_stmt_without_else 19458) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19459) (fn 103) (for_statement 19565) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19460) (if_stmt_without_else 19461) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19566) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19463) ("~" 125)) 8880 ((inner_statement_list 19567)) 8881 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19568) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19569) (T_CLASS 19570) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19571) (T_DEC 22) (T_DECLARE 19572) (T_DIR 24) (T_DNUMBER 25) (T_DO 19573) (T_DOUBLE_CAST 27) (T_ECHO 19574) (T_EMPTY 29) (T_ENDFOR 19575) (T_ENUM 19576) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19577) (T_FOREACH 19578) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19579) (T_GOTO 19580) (T_HALT_COMPILER 19581) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19583) (T_INTERFACE 19584) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19585) (T_START_HEREDOC 68) (T_STATIC 19586) (T_STRING 19587) (T_STRING_CAST 71) (T_SWITCH 19588) (T_THROW 73) (T_TRAIT 19589) (T_TRAIT_C 75) (T_TRY 19590) (T_UNSET 19591) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19592) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19593) (alt_if_stmt_without_else 19594) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19595) (attributes 19596) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19597) (class_modifier 96) (class_modifiers 19598) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19599) (expr 19600) (fn 103) (fully_dereferenceable 104) #'19601 (function_call 106) (function_declaration_statement 19602) (if_stmt 19603) (if_stmt_without_else 19604) (inline_function 110) (inner_statement 19605) (interface_declaration_statement 19606) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19607) (static_member 119) (trait_declaration_statement 19608) (variable 122) (variable_class_name 123) ("{" 19609) ("~" 125)) 8882 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 20653) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 8883 ((T_STRING 20646)) 8884 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 20644) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 8885 (("(" 20635)) 8886 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19746) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19747) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19748) (T_DEC 22) (T_DECLARE 19749) (T_DIR 24) (T_DNUMBER 25) (T_DO 19750) (T_DOUBLE_CAST 27) (T_ECHO 19751) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19752) (T_FOREACH 19753) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19754) (T_GOTO 19755) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19757) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19758) (T_START_HEREDOC 68) (T_STATIC 19759) (T_STRING 19760) (T_STRING_CAST 71) (T_SWITCH 19761) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19762) (T_UNSET 19763) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19764) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19765) (alt_if_stmt_without_else 19766) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19767) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19768) (if_stmt_without_else 19769) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20629) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19771) ("~" 125)) 8887 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (echo_expr 19740) (echo_expr_list 20627) (expr 19742) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 8888 ((";" 20626)) 8889 ((T_STRING 20619)) 8890 (("(" 20606)) 8891 (("(" 20591)) 8892 (("$" 17870) (T_VARIABLE 17871) (global_var 17872) (global_var_list 20589) (simple_variable 17874)) 8893 ((T_STRING 20587)) 8894 (("(" 20584)) 8895 (("(" 20580)) 8896 ((T_STRING 20574)) 8897 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 20572) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 8898 ((T_FN 35) (T_FUNCTION 127) (T_VARIABLE 16848) (fn 103) #'134 (inline_function 16849) (static_var 16850) (static_var_list 20570)) 8899 ((":" 20569)) 8900 (("(" 20551)) 8901 ((T_STRING 20546)) 8902 (("{" 20529)) 8903 (("(" 20524)) 8904 (("(" 20515)) 8905 ((T_ELSE 20508) (T_ELSEIF 16203) (T_ENDIF 20509)) 8906 ((T_ABSTRACT 10) (T_ATTRIBUTE 13) (T_CLASS 19570) (T_ENUM 19576) (T_FINAL 34) (T_FN 35) (T_FUNCTION 38) (T_INTERFACE 19584) (T_READONLY 2936) (T_STATIC 16288) (T_TRAIT 19589) (attribute 16289) (attributed_statement 20507) (class_declaration_statement 19597) (class_modifier 96) (class_modifiers 19598) (enum_declaration_statement 19599) (fn 103) #'19601 (function_declaration_statement 19602) (inline_function 16291) (interface_declaration_statement 19606) (trait_declaration_statement 19608)) 8907 ((T_ABSTRACT 10) (T_CLASS 20499) (T_FINAL 34) (T_READONLY 2936) (class_modifier 16280)) 8908 (("%" 6465) ("*" 6466) ("+" 6467) ("-" 6468) ("." 6469) ("/" 6470) (";" 20498) ("<" 6471) (">" 6472) ("?" 6473) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 6474) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 6475) (T_BOOLEAN_AND 6476) (T_BOOLEAN_OR 6477) (T_COALESCE 6478) (T_INSTANCEOF 6479) (T_IS_EQUAL 6480) (T_IS_GREATER_OR_EQUAL 6481) (T_IS_IDENTICAL 6482) (T_IS_NOT_EQUAL 6483) (T_IS_NOT_IDENTICAL 6484) (T_IS_SMALLER_OR_EQUAL 6485) (T_LOGICAL_AND 6486) (T_LOGICAL_OR 6487) (T_LOGICAL_XOR 6488) (T_POW 6489) (T_SL 6490) (T_SPACESHIP 6491) (T_SR 6492) ("^" 6493) ("|" 6494)) 8909 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 16261) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 16262) (ampersand 16263) (returns_ref 20486)) 8910 ((T_ELSE 19612) (T_ELSEIF 19613)) 8911 ((inner_statement_list 19610)) 8912 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 19611) ("~" 125)) 8913 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19568) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19569) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19571) (T_DEC 22) (T_DECLARE 19572) (T_DIR 24) (T_DNUMBER 25) (T_DO 19573) (T_DOUBLE_CAST 27) (T_ECHO 19574) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19577) (T_FOREACH 19578) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19579) (T_GOTO 19580) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19583) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19585) (T_START_HEREDOC 68) (T_STATIC 19586) (T_STRING 19587) (T_STRING_CAST 71) (T_SWITCH 19588) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19590) (T_UNSET 19591) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19592) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19593) (alt_if_stmt_without_else 19594) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19600) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19603) (if_stmt_without_else 19604) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20485) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19609) ("~" 125)) 8914 (("(" 19614)) 8915 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 19615) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 8916 (("%" 292) (")" 19616) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 8917 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19617) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19618) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19619) (T_DEC 22) (T_DECLARE 19620) (T_DIR 24) (T_DNUMBER 25) (T_DO 19621) (T_DOUBLE_CAST 27) (T_ECHO 19622) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19623) (T_FOREACH 19624) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19625) (T_GOTO 19626) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19627) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19628) (T_START_HEREDOC 68) (T_STATIC 19629) (T_STRING 19630) (T_STRING_CAST 71) (T_SWITCH 19631) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19632) (T_UNSET 19633) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19634) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19635) (alt_if_stmt_without_else 19636) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19637) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19638) (if_stmt_without_else 19639) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19640) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19641) ("~" 125)) 8918 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 20483) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 8919 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 20481) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 8920 (("(" 20472)) 8921 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19746) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19747) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19748) (T_DEC 22) (T_DECLARE 19749) (T_DIR 24) (T_DNUMBER 25) (T_DO 19750) (T_DOUBLE_CAST 27) (T_ECHO 19751) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19752) (T_FOREACH 19753) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19754) (T_GOTO 19755) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19757) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19758) (T_START_HEREDOC 68) (T_STATIC 19759) (T_STRING 19760) (T_STRING_CAST 71) (T_SWITCH 19761) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19762) (T_UNSET 19763) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19764) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19765) (alt_if_stmt_without_else 19766) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19767) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19768) (if_stmt_without_else 19769) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19770) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19771) ("~" 125)) 8922 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (echo_expr 19740) (echo_expr_list 19741) (expr 19742) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 8923 (("(" 19727)) 8924 (("(" 19712)) 8925 (("$" 17870) (T_VARIABLE 17871) (global_var 17872) (global_var_list 19710) (simple_variable 17874)) 8926 ((T_STRING 19708)) 8927 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 19706) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 8928 ((T_FN 35) (T_FUNCTION 127) (T_VARIABLE 16848) (fn 103) #'134 (inline_function 16849) (static_var 16850) (static_var_list 19704)) 8929 ((":" 19703)) 8930 (("(" 19685)) 8931 (("{" 19668)) 8932 (("(" 19663)) 8933 (("(" 19654)) 8934 ((T_ELSE 19647) (T_ELSEIF 16203) (T_ENDIF 19648)) 8935 (("%" 6465) ("*" 6466) ("+" 6467) ("-" 6468) ("." 6469) ("/" 6470) (";" 19646) ("<" 6471) (">" 6472) ("?" 6473) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 6474) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 6475) (T_BOOLEAN_AND 6476) (T_BOOLEAN_OR 6477) (T_COALESCE 6478) (T_INSTANCEOF 6479) (T_IS_EQUAL 6480) (T_IS_GREATER_OR_EQUAL 6481) (T_IS_IDENTICAL 6482) (T_IS_NOT_EQUAL 6483) (T_IS_NOT_IDENTICAL 6484) (T_IS_SMALLER_OR_EQUAL 6485) (T_LOGICAL_AND 6486) (T_LOGICAL_OR 6487) (T_LOGICAL_XOR 6488) (T_POW 6489) (T_SL 6490) (T_SPACESHIP 6491) (T_SR 6492) ("^" 6493) ("|" 6494)) 8936 ((T_ELSE 19644) (T_ELSEIF 19613)) 8937 ((inner_statement_list 19642)) 8938 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 19643) ("~" 125)) 8939 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19617) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19618) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19619) (T_DEC 22) (T_DECLARE 19620) (T_DIR 24) (T_DNUMBER 25) (T_DO 19621) (T_DOUBLE_CAST 27) (T_ECHO 19622) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19623) (T_FOREACH 19624) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19625) (T_GOTO 19626) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19627) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19628) (T_START_HEREDOC 68) (T_STATIC 19629) (T_STRING 19630) (T_STRING_CAST 71) (T_SWITCH 19631) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19632) (T_UNSET 19633) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19634) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19635) (alt_if_stmt_without_else 19636) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19637) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19638) (if_stmt_without_else 19639) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19645) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19641) ("~" 125)) 8940 ((":" 19650)) 8941 ((";" 19649)) 8942 ((inner_statement_list 19651)) 8943 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16298) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16299) (T_CLASS 16300) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16301) (T_DEC 22) (T_DECLARE 16302) (T_DIR 24) (T_DNUMBER 25) (T_DO 16303) (T_DOUBLE_CAST 27) (T_ECHO 16304) (T_EMPTY 29) (T_ENDIF 19652) (T_ENUM 16306) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16307) (T_FOREACH 16308) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16309) (T_GOTO 16310) (T_HALT_COMPILER 16311) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16312) (T_INTERFACE 16313) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16314) (T_START_HEREDOC 68) (T_STATIC 16315) (T_STRING 16316) (T_STRING_CAST 71) (T_SWITCH 16317) (T_THROW 73) (T_TRAIT 16318) (T_TRAIT_C 75) (T_TRY 16319) (T_UNSET 16320) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16321) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16322) (alt_if_stmt_without_else 16323) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16324) (attributes 16325) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16326) (class_modifier 96) (class_modifiers 16327) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16328) (expr 16329) (fn 103) (fully_dereferenceable 104) #'16330 (function_call 106) (function_declaration_statement 16331) (if_stmt 16332) (if_stmt_without_else 16333) (inline_function 110) (inner_statement 16334) (interface_declaration_statement 16335) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16336) (static_member 119) (trait_declaration_statement 16337) (variable 122) (variable_class_name 123) ("{" 16338) ("~" 125)) 8944 ((";" 19653)) 8945 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 19655) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 8946 (("%" 292) (")" 19656) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 8947 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 19657) (";" 19617) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19618) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19619) (T_DEC 22) (T_DECLARE 19620) (T_DIR 24) (T_DNUMBER 25) (T_DO 19621) (T_DOUBLE_CAST 27) (T_ECHO 19622) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19623) (T_FOREACH 19624) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19625) (T_GOTO 19626) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19627) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19628) (T_START_HEREDOC 68) (T_STATIC 19629) (T_STRING 19630) (T_STRING_CAST 71) (T_SWITCH 19631) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19632) (T_UNSET 19633) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19634) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19635) (alt_if_stmt_without_else 19636) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19637) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19638) (if_stmt_without_else 19639) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19658) (static_member 119) (variable 122) (variable_class_name 123) (while_statement 19659) ("{" 19641) ("~" 125)) 8948 ((inner_statement_list 19660)) 8949 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16379) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16380) (T_CLASS 16381) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16382) (T_DEC 22) (T_DECLARE 16383) (T_DIR 24) (T_DNUMBER 25) (T_DO 16384) (T_DOUBLE_CAST 27) (T_ECHO 16385) (T_EMPTY 29) (T_ENDWHILE 19661) (T_ENUM 16387) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16388) (T_FOREACH 16389) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16390) (T_GOTO 16391) (T_HALT_COMPILER 16392) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16394) (T_INTERFACE 16395) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16396) (T_START_HEREDOC 68) (T_STATIC 16397) (T_STRING 16398) (T_STRING_CAST 71) (T_SWITCH 16399) (T_THROW 73) (T_TRAIT 16400) (T_TRAIT_C 75) (T_TRY 16401) (T_UNSET 16402) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16403) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16404) (alt_if_stmt_without_else 16405) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16406) (attributes 16407) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16408) (class_modifier 96) (class_modifiers 16409) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16410) (expr 16411) (fn 103) (fully_dereferenceable 104) #'16412 (function_call 106) (function_declaration_statement 16413) (if_stmt 16414) (if_stmt_without_else 16415) (inline_function 110) (inner_statement 16416) (interface_declaration_statement 16417) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16418) (static_member 119) (trait_declaration_statement 16419) (variable 122) (variable_class_name 123) ("{" 16420) ("~" 125)) 8950 ((";" 19662)) 8951 (("\"" 1509) ("$" 16475) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 16476) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 16477) ("[" 1529) (array_object_dereferenceable 16478) (callable_expr 16479) (callable_variable 16480) (class_constant 1533) (class_name 16481) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 16482) (name 16483) (simple_variable 16484) (static_member 16485) (unset_variable 16486) (unset_variables 19664) (variable 16488) (variable_class_name 16489)) 8952 (("," 16501) (possible_comma 19665)) 8953 ((")" 19666)) 8954 ((";" 19667)) 8955 ((inner_statement_list 19669)) 8956 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 19670) ("~" 125)) 8957 ((catch_list 19671)) 8958 ((T_CATCH 19672) (T_FINALLY 19673) (finally_statement 19674)) 8959 (("(" 19678)) 8960 (("{" 19675)) 8961 ((inner_statement_list 19676)) 8962 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 19677) ("~" 125)) 8963 ((T_NAME_FULLY_QUALIFIED 16545) (T_NAME_QUALIFIED 16546) (T_NAME_RELATIVE 16547) (T_STATIC 16548) (T_STRING 16549) (catch_name_list 19679) (class_name 16551) (name 16552)) 8964 ((T_VARIABLE 16553) (optional_variable 19680) ("|" 16555)) 8965 ((")" 19681)) 8966 (("{" 19682)) 8967 ((inner_statement_list 19683)) 8968 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 19684) ("~" 125)) 8969 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 19686) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 8970 (("%" 292) (")" 19687) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 8971 ((":" 19688) (switch_case_list 19689) ("{" 19690)) 8972 ((";" 19696) (case_list 19697)) 8973 ((";" 19691) (case_list 19692)) 8974 ((case_list 19694)) 8975 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 19693)) 8976 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 19695)) 8977 ((case_list 19700)) 8978 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 19698)) 8979 ((";" 19699)) 8980 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 19701)) 8981 ((";" 19702)) 8982 (("," 16852) (";" 19705)) 8983 ((";" 19707)) 8984 ((";" 19709)) 8985 (("," 17875) (";" 19711)) 8986 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 19713) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 8987 (("%" 17961) ("*" 17962) ("+" 17963) ("-" 17964) ("." 17965) ("/" 17966) ("<" 17967) (">" 17968) ("?" 17969) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 17970) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 17971) (T_AS 19714) (T_BOOLEAN_AND 17972) (T_BOOLEAN_OR 17973) (T_COALESCE 17974) (T_INSTANCEOF 17975) (T_IS_EQUAL 17976) (T_IS_GREATER_OR_EQUAL 17977) (T_IS_IDENTICAL 17978) (T_IS_NOT_EQUAL 17979) (T_IS_NOT_IDENTICAL 17980) (T_IS_SMALLER_OR_EQUAL 17981) (T_LOGICAL_AND 17982) (T_LOGICAL_OR 17983) (T_LOGICAL_XOR 17984) (T_POW 17985) (T_SL 17986) (T_SPACESHIP 17987) (T_SR 17988) ("^" 17989) ("|" 17990)) 8988 (("\"" 1509) ("$" 19325) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19326) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19327) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19328) ("[" 19329) (ampersand 19330) (array_object_dereferenceable 19331) (callable_expr 19332) (callable_variable 19333) (class_constant 1533) (class_name 19334) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 19715) (fully_dereferenceable 104) (function_call 19336) (name 19337) (simple_variable 19338) (static_member 19339) (variable 19340) (variable_class_name 19341)) 8989 ((")" 19716) (T_DOUBLE_ARROW 19717)) 8990 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 19720) (";" 19617) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19618) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19619) (T_DEC 22) (T_DECLARE 19620) (T_DIR 24) (T_DNUMBER 25) (T_DO 19621) (T_DOUBLE_CAST 27) (T_ECHO 19622) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19623) (T_FOREACH 19624) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19625) (T_GOTO 19626) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19627) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19628) (T_START_HEREDOC 68) (T_STATIC 19629) (T_STRING 19630) (T_STRING_CAST 71) (T_SWITCH 19631) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19632) (T_UNSET 19633) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19634) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19635) (alt_if_stmt_without_else 19636) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19637) (fn 103) (foreach_statement 19726) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19638) (if_stmt_without_else 19639) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19722) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19641) ("~" 125)) 8991 (("\"" 1509) ("$" 19356) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19357) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19358) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19359) ("[" 19360) (ampersand 19361) (array_object_dereferenceable 19362) (callable_expr 19363) (callable_variable 19364) (class_constant 1533) (class_name 19365) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 19718) (fully_dereferenceable 104) (function_call 19367) (name 19368) (simple_variable 19369) (static_member 19370) (variable 19371) (variable_class_name 19372)) 8992 ((")" 19719)) 8993 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 19720) (";" 19617) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19618) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19619) (T_DEC 22) (T_DECLARE 19620) (T_DIR 24) (T_DNUMBER 25) (T_DO 19621) (T_DOUBLE_CAST 27) (T_ECHO 19622) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19623) (T_FOREACH 19624) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19625) (T_GOTO 19626) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19627) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19628) (T_START_HEREDOC 68) (T_STATIC 19629) (T_STRING 19630) (T_STRING_CAST 71) (T_SWITCH 19631) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19632) (T_UNSET 19633) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19634) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19635) (alt_if_stmt_without_else 19636) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19637) (fn 103) (foreach_statement 19721) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19638) (if_stmt_without_else 19639) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19722) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19641) ("~" 125)) 8994 ((inner_statement_list 19723)) 8995 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19390) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19391) (T_CLASS 19392) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19393) (T_DEC 22) (T_DECLARE 19394) (T_DIR 24) (T_DNUMBER 25) (T_DO 19395) (T_DOUBLE_CAST 27) (T_ECHO 19396) (T_EMPTY 29) (T_ENDFOREACH 19724) (T_ENUM 19398) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19399) (T_FOREACH 19400) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19401) (T_GOTO 19402) (T_HALT_COMPILER 19403) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19405) (T_INTERFACE 19406) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19407) (T_START_HEREDOC 68) (T_STATIC 19408) (T_STRING 19409) (T_STRING_CAST 71) (T_SWITCH 19410) (T_THROW 73) (T_TRAIT 19411) (T_TRAIT_C 75) (T_TRY 19412) (T_UNSET 19413) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19414) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19415) (alt_if_stmt_without_else 19416) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19417) (attributes 19418) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19419) (class_modifier 96) (class_modifiers 19420) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19421) (expr 19422) (fn 103) (fully_dereferenceable 104) #'19423 (function_call 106) (function_declaration_statement 19424) (if_stmt 19425) (if_stmt_without_else 19426) (inline_function 110) (inner_statement 19427) (interface_declaration_statement 19428) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19429) (static_member 119) (trait_declaration_statement 19430) (variable 122) (variable_class_name 123) ("{" 19431) ("~" 125)) 8996 ((";" 19725)) 8997 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 19728) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 8998 ((";" 19729)) 8999 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 19730) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 9000 ((";" 19731)) 9001 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 19558) (fn 2394) (for_exprs 19732) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (non_empty_for_exprs 19560) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 9002 ((")" 19733)) 9003 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 19734) (";" 19617) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19618) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19619) (T_DEC 22) (T_DECLARE 19620) (T_DIR 24) (T_DNUMBER 25) (T_DO 19621) (T_DOUBLE_CAST 27) (T_ECHO 19622) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19623) (T_FOREACH 19624) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19625) (T_GOTO 19626) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19627) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19628) (T_START_HEREDOC 68) (T_STATIC 19629) (T_STRING 19630) (T_STRING_CAST 71) (T_SWITCH 19631) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19632) (T_UNSET 19633) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19634) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19635) (alt_if_stmt_without_else 19636) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19637) (fn 103) (for_statement 19735) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19638) (if_stmt_without_else 19639) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19736) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19641) ("~" 125)) 9004 ((inner_statement_list 19737)) 9005 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19568) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19569) (T_CLASS 19570) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19571) (T_DEC 22) (T_DECLARE 19572) (T_DIR 24) (T_DNUMBER 25) (T_DO 19573) (T_DOUBLE_CAST 27) (T_ECHO 19574) (T_EMPTY 29) (T_ENDFOR 19738) (T_ENUM 19576) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19577) (T_FOREACH 19578) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19579) (T_GOTO 19580) (T_HALT_COMPILER 19581) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19583) (T_INTERFACE 19584) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19585) (T_START_HEREDOC 68) (T_STATIC 19586) (T_STRING 19587) (T_STRING_CAST 71) (T_SWITCH 19588) (T_THROW 73) (T_TRAIT 19589) (T_TRAIT_C 75) (T_TRY 19590) (T_UNSET 19591) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19592) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19593) (alt_if_stmt_without_else 19594) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19595) (attributes 19596) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19597) (class_modifier 96) (class_modifiers 19598) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19599) (expr 19600) (fn 103) (fully_dereferenceable 104) #'19601 (function_call 106) (function_declaration_statement 19602) (if_stmt 19603) (if_stmt_without_else 19604) (inline_function 110) (inner_statement 19605) (interface_declaration_statement 19606) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19607) (static_member 119) (trait_declaration_statement 19608) (variable 122) (variable_class_name 123) ("{" 19609) ("~" 125)) 9006 ((";" 19739)) 9007 (("," 19743) (";" 19744)) 9008 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (echo_expr 19745) (expr 19742) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 9009 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 20470) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 9010 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 20468) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 9011 (("(" 20459)) 9012 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19746) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19747) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19748) (T_DEC 22) (T_DECLARE 19749) (T_DIR 24) (T_DNUMBER 25) (T_DO 19750) (T_DOUBLE_CAST 27) (T_ECHO 19751) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19752) (T_FOREACH 19753) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19754) (T_GOTO 19755) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19757) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19758) (T_START_HEREDOC 68) (T_STATIC 19759) (T_STRING 19760) (T_STRING_CAST 71) (T_SWITCH 19761) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19762) (T_UNSET 19763) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19764) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19765) (alt_if_stmt_without_else 19766) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19767) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19768) (if_stmt_without_else 19769) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20453) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19771) ("~" 125)) 9013 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (echo_expr 19740) (echo_expr_list 20451) (expr 19742) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 9014 (("(" 20438)) 9015 (("(" 20423)) 9016 (("$" 17870) (T_VARIABLE 17871) (global_var 17872) (global_var_list 20421) (simple_variable 17874)) 9017 ((T_STRING 20419)) 9018 (("(" 20415)) 9019 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 20413) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 9020 ((T_FN 35) (T_FUNCTION 127) (T_VARIABLE 16848) (fn 103) #'134 (inline_function 16849) (static_var 16850) (static_var_list 20411)) 9021 ((":" 20410)) 9022 (("(" 20392)) 9023 (("{" 20375)) 9024 (("(" 20370)) 9025 (("(" 20361)) 9026 ((T_ELSE 20354) (T_ELSEIF 16203) (T_ENDIF 20355)) 9027 (("%" 6465) ("*" 6466) ("+" 6467) ("-" 6468) ("." 6469) ("/" 6470) (";" 20353) ("<" 6471) (">" 6472) ("?" 6473) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 6474) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 6475) (T_BOOLEAN_AND 6476) (T_BOOLEAN_OR 6477) (T_COALESCE 6478) (T_INSTANCEOF 6479) (T_IS_EQUAL 6480) (T_IS_GREATER_OR_EQUAL 6481) (T_IS_IDENTICAL 6482) (T_IS_NOT_EQUAL 6483) (T_IS_NOT_IDENTICAL 6484) (T_IS_SMALLER_OR_EQUAL 6485) (T_LOGICAL_AND 6486) (T_LOGICAL_OR 6487) (T_LOGICAL_XOR 6488) (T_POW 6489) (T_SL 6490) (T_SPACESHIP 6491) (T_SR 6492) ("^" 6493) ("|" 6494)) 9028 ((T_ELSE 19779) (T_ELSEIF 19780)) 9029 ((T_WHILE 19774)) 9030 ((inner_statement_list 19772)) 9031 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 19773) ("~" 125)) 9032 (("(" 19775)) 9033 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 19776) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 9034 (("%" 292) (")" 19777) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 9035 ((";" 19778)) 9036 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19746) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19747) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19748) (T_DEC 22) (T_DECLARE 19749) (T_DIR 24) (T_DNUMBER 25) (T_DO 19750) (T_DOUBLE_CAST 27) (T_ECHO 19751) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19752) (T_FOREACH 19753) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19754) (T_GOTO 19755) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19757) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19758) (T_START_HEREDOC 68) (T_STATIC 19759) (T_STRING 19760) (T_STRING_CAST 71) (T_SWITCH 19761) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19762) (T_UNSET 19763) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19764) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19765) (alt_if_stmt_without_else 19766) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19767) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19768) (if_stmt_without_else 19769) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20352) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19771) ("~" 125)) 9037 (("(" 19781)) 9038 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 19782) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 9039 (("%" 292) (")" 19783) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 9040 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19784) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19785) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19786) (T_DEC 22) (T_DECLARE 19787) (T_DIR 24) (T_DNUMBER 25) (T_DO 19788) (T_DOUBLE_CAST 27) (T_ECHO 19789) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19790) (T_FOREACH 19791) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19792) (T_GOTO 19793) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19794) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19795) (T_START_HEREDOC 68) (T_STATIC 19796) (T_STRING 19797) (T_STRING_CAST 71) (T_SWITCH 19798) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19799) (T_UNSET 19800) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19801) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19802) (alt_if_stmt_without_else 19803) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19804) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19805) (if_stmt_without_else 19806) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19807) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19808) ("~" 125)) 9041 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 20350) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 9042 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 20348) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 9043 (("(" 19915)) 9044 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19746) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19747) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19748) (T_DEC 22) (T_DECLARE 19749) (T_DIR 24) (T_DNUMBER 25) (T_DO 19750) (T_DOUBLE_CAST 27) (T_ECHO 19751) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19752) (T_FOREACH 19753) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19754) (T_GOTO 19755) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19757) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19758) (T_START_HEREDOC 68) (T_STATIC 19759) (T_STRING 19760) (T_STRING_CAST 71) (T_SWITCH 19761) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19762) (T_UNSET 19763) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19764) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19765) (alt_if_stmt_without_else 19766) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19767) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19768) (if_stmt_without_else 19769) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19909) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19771) ("~" 125)) 9045 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (echo_expr 19740) (echo_expr_list 19907) (expr 19742) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 9046 (("(" 19894)) 9047 (("(" 19879)) 9048 (("$" 17870) (T_VARIABLE 17871) (global_var 17872) (global_var_list 19877) (simple_variable 17874)) 9049 ((T_STRING 19875)) 9050 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 19873) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 9051 ((T_FN 35) (T_FUNCTION 127) (T_VARIABLE 16848) (fn 103) #'134 (inline_function 16849) (static_var 16850) (static_var_list 19871)) 9052 ((":" 19870)) 9053 (("(" 19852)) 9054 (("{" 19835)) 9055 (("(" 19830)) 9056 (("(" 19821)) 9057 ((T_ELSE 19814) (T_ELSEIF 16203) (T_ENDIF 19815)) 9058 (("%" 6465) ("*" 6466) ("+" 6467) ("-" 6468) ("." 6469) ("/" 6470) (";" 19813) ("<" 6471) (">" 6472) ("?" 6473) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 6474) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 6475) (T_BOOLEAN_AND 6476) (T_BOOLEAN_OR 6477) (T_COALESCE 6478) (T_INSTANCEOF 6479) (T_IS_EQUAL 6480) (T_IS_GREATER_OR_EQUAL 6481) (T_IS_IDENTICAL 6482) (T_IS_NOT_EQUAL 6483) (T_IS_NOT_IDENTICAL 6484) (T_IS_SMALLER_OR_EQUAL 6485) (T_LOGICAL_AND 6486) (T_LOGICAL_OR 6487) (T_LOGICAL_XOR 6488) (T_POW 6489) (T_SL 6490) (T_SPACESHIP 6491) (T_SR 6492) ("^" 6493) ("|" 6494)) 9059 ((T_ELSE 19811) (T_ELSEIF 19780)) 9060 ((inner_statement_list 19809)) 9061 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 19810) ("~" 125)) 9062 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19784) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19785) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19786) (T_DEC 22) (T_DECLARE 19787) (T_DIR 24) (T_DNUMBER 25) (T_DO 19788) (T_DOUBLE_CAST 27) (T_ECHO 19789) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19790) (T_FOREACH 19791) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19792) (T_GOTO 19793) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19794) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19795) (T_START_HEREDOC 68) (T_STATIC 19796) (T_STRING 19797) (T_STRING_CAST 71) (T_SWITCH 19798) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19799) (T_UNSET 19800) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19801) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19802) (alt_if_stmt_without_else 19803) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19804) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19805) (if_stmt_without_else 19806) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19812) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19808) ("~" 125)) 9063 ((":" 19817)) 9064 ((";" 19816)) 9065 ((inner_statement_list 19818)) 9066 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16298) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16299) (T_CLASS 16300) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16301) (T_DEC 22) (T_DECLARE 16302) (T_DIR 24) (T_DNUMBER 25) (T_DO 16303) (T_DOUBLE_CAST 27) (T_ECHO 16304) (T_EMPTY 29) (T_ENDIF 19819) (T_ENUM 16306) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16307) (T_FOREACH 16308) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16309) (T_GOTO 16310) (T_HALT_COMPILER 16311) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16312) (T_INTERFACE 16313) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16314) (T_START_HEREDOC 68) (T_STATIC 16315) (T_STRING 16316) (T_STRING_CAST 71) (T_SWITCH 16317) (T_THROW 73) (T_TRAIT 16318) (T_TRAIT_C 75) (T_TRY 16319) (T_UNSET 16320) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16321) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16322) (alt_if_stmt_without_else 16323) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16324) (attributes 16325) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16326) (class_modifier 96) (class_modifiers 16327) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16328) (expr 16329) (fn 103) (fully_dereferenceable 104) #'16330 (function_call 106) (function_declaration_statement 16331) (if_stmt 16332) (if_stmt_without_else 16333) (inline_function 110) (inner_statement 16334) (interface_declaration_statement 16335) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16336) (static_member 119) (trait_declaration_statement 16337) (variable 122) (variable_class_name 123) ("{" 16338) ("~" 125)) 9067 ((";" 19820)) 9068 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 19822) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 9069 (("%" 292) (")" 19823) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 9070 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 19824) (";" 19784) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19785) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19786) (T_DEC 22) (T_DECLARE 19787) (T_DIR 24) (T_DNUMBER 25) (T_DO 19788) (T_DOUBLE_CAST 27) (T_ECHO 19789) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19790) (T_FOREACH 19791) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19792) (T_GOTO 19793) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19794) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19795) (T_START_HEREDOC 68) (T_STATIC 19796) (T_STRING 19797) (T_STRING_CAST 71) (T_SWITCH 19798) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19799) (T_UNSET 19800) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19801) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19802) (alt_if_stmt_without_else 19803) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19804) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19805) (if_stmt_without_else 19806) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19825) (static_member 119) (variable 122) (variable_class_name 123) (while_statement 19826) ("{" 19808) ("~" 125)) 9071 ((inner_statement_list 19827)) 9072 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16379) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16380) (T_CLASS 16381) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16382) (T_DEC 22) (T_DECLARE 16383) (T_DIR 24) (T_DNUMBER 25) (T_DO 16384) (T_DOUBLE_CAST 27) (T_ECHO 16385) (T_EMPTY 29) (T_ENDWHILE 19828) (T_ENUM 16387) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16388) (T_FOREACH 16389) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16390) (T_GOTO 16391) (T_HALT_COMPILER 16392) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16394) (T_INTERFACE 16395) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16396) (T_START_HEREDOC 68) (T_STATIC 16397) (T_STRING 16398) (T_STRING_CAST 71) (T_SWITCH 16399) (T_THROW 73) (T_TRAIT 16400) (T_TRAIT_C 75) (T_TRY 16401) (T_UNSET 16402) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16403) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16404) (alt_if_stmt_without_else 16405) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16406) (attributes 16407) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16408) (class_modifier 96) (class_modifiers 16409) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16410) (expr 16411) (fn 103) (fully_dereferenceable 104) #'16412 (function_call 106) (function_declaration_statement 16413) (if_stmt 16414) (if_stmt_without_else 16415) (inline_function 110) (inner_statement 16416) (interface_declaration_statement 16417) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16418) (static_member 119) (trait_declaration_statement 16419) (variable 122) (variable_class_name 123) ("{" 16420) ("~" 125)) 9073 ((";" 19829)) 9074 (("\"" 1509) ("$" 16475) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 16476) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 16477) ("[" 1529) (array_object_dereferenceable 16478) (callable_expr 16479) (callable_variable 16480) (class_constant 1533) (class_name 16481) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 16482) (name 16483) (simple_variable 16484) (static_member 16485) (unset_variable 16486) (unset_variables 19831) (variable 16488) (variable_class_name 16489)) 9075 (("," 16501) (possible_comma 19832)) 9076 ((")" 19833)) 9077 ((";" 19834)) 9078 ((inner_statement_list 19836)) 9079 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 19837) ("~" 125)) 9080 ((catch_list 19838)) 9081 ((T_CATCH 19839) (T_FINALLY 19840) (finally_statement 19841)) 9082 (("(" 19845)) 9083 (("{" 19842)) 9084 ((inner_statement_list 19843)) 9085 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 19844) ("~" 125)) 9086 ((T_NAME_FULLY_QUALIFIED 16545) (T_NAME_QUALIFIED 16546) (T_NAME_RELATIVE 16547) (T_STATIC 16548) (T_STRING 16549) (catch_name_list 19846) (class_name 16551) (name 16552)) 9087 ((T_VARIABLE 16553) (optional_variable 19847) ("|" 16555)) 9088 ((")" 19848)) 9089 (("{" 19849)) 9090 ((inner_statement_list 19850)) 9091 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 19851) ("~" 125)) 9092 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 19853) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 9093 (("%" 292) (")" 19854) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 9094 ((":" 19855) (switch_case_list 19856) ("{" 19857)) 9095 ((";" 19863) (case_list 19864)) 9096 ((";" 19858) (case_list 19859)) 9097 ((case_list 19861)) 9098 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 19860)) 9099 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 19862)) 9100 ((case_list 19867)) 9101 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 19865)) 9102 ((";" 19866)) 9103 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 19868)) 9104 ((";" 19869)) 9105 (("," 16852) (";" 19872)) 9106 ((";" 19874)) 9107 ((";" 19876)) 9108 (("," 17875) (";" 19878)) 9109 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 19880) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 9110 (("%" 17961) ("*" 17962) ("+" 17963) ("-" 17964) ("." 17965) ("/" 17966) ("<" 17967) (">" 17968) ("?" 17969) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 17970) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 17971) (T_AS 19881) (T_BOOLEAN_AND 17972) (T_BOOLEAN_OR 17973) (T_COALESCE 17974) (T_INSTANCEOF 17975) (T_IS_EQUAL 17976) (T_IS_GREATER_OR_EQUAL 17977) (T_IS_IDENTICAL 17978) (T_IS_NOT_EQUAL 17979) (T_IS_NOT_IDENTICAL 17980) (T_IS_SMALLER_OR_EQUAL 17981) (T_LOGICAL_AND 17982) (T_LOGICAL_OR 17983) (T_LOGICAL_XOR 17984) (T_POW 17985) (T_SL 17986) (T_SPACESHIP 17987) (T_SR 17988) ("^" 17989) ("|" 17990)) 9111 (("\"" 1509) ("$" 19325) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19326) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19327) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19328) ("[" 19329) (ampersand 19330) (array_object_dereferenceable 19331) (callable_expr 19332) (callable_variable 19333) (class_constant 1533) (class_name 19334) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 19882) (fully_dereferenceable 104) (function_call 19336) (name 19337) (simple_variable 19338) (static_member 19339) (variable 19340) (variable_class_name 19341)) 9112 ((")" 19883) (T_DOUBLE_ARROW 19884)) 9113 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 19887) (";" 19784) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19785) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19786) (T_DEC 22) (T_DECLARE 19787) (T_DIR 24) (T_DNUMBER 25) (T_DO 19788) (T_DOUBLE_CAST 27) (T_ECHO 19789) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19790) (T_FOREACH 19791) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19792) (T_GOTO 19793) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19794) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19795) (T_START_HEREDOC 68) (T_STATIC 19796) (T_STRING 19797) (T_STRING_CAST 71) (T_SWITCH 19798) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19799) (T_UNSET 19800) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19801) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19802) (alt_if_stmt_without_else 19803) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19804) (fn 103) (foreach_statement 19893) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19805) (if_stmt_without_else 19806) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19889) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19808) ("~" 125)) 9114 (("\"" 1509) ("$" 19356) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19357) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19358) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19359) ("[" 19360) (ampersand 19361) (array_object_dereferenceable 19362) (callable_expr 19363) (callable_variable 19364) (class_constant 1533) (class_name 19365) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 19885) (fully_dereferenceable 104) (function_call 19367) (name 19368) (simple_variable 19369) (static_member 19370) (variable 19371) (variable_class_name 19372)) 9115 ((")" 19886)) 9116 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 19887) (";" 19784) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19785) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19786) (T_DEC 22) (T_DECLARE 19787) (T_DIR 24) (T_DNUMBER 25) (T_DO 19788) (T_DOUBLE_CAST 27) (T_ECHO 19789) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19790) (T_FOREACH 19791) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19792) (T_GOTO 19793) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19794) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19795) (T_START_HEREDOC 68) (T_STATIC 19796) (T_STRING 19797) (T_STRING_CAST 71) (T_SWITCH 19798) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19799) (T_UNSET 19800) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19801) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19802) (alt_if_stmt_without_else 19803) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19804) (fn 103) (foreach_statement 19888) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19805) (if_stmt_without_else 19806) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19889) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19808) ("~" 125)) 9117 ((inner_statement_list 19890)) 9118 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19390) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19391) (T_CLASS 19392) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19393) (T_DEC 22) (T_DECLARE 19394) (T_DIR 24) (T_DNUMBER 25) (T_DO 19395) (T_DOUBLE_CAST 27) (T_ECHO 19396) (T_EMPTY 29) (T_ENDFOREACH 19891) (T_ENUM 19398) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19399) (T_FOREACH 19400) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19401) (T_GOTO 19402) (T_HALT_COMPILER 19403) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19405) (T_INTERFACE 19406) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19407) (T_START_HEREDOC 68) (T_STATIC 19408) (T_STRING 19409) (T_STRING_CAST 71) (T_SWITCH 19410) (T_THROW 73) (T_TRAIT 19411) (T_TRAIT_C 75) (T_TRY 19412) (T_UNSET 19413) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19414) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19415) (alt_if_stmt_without_else 19416) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19417) (attributes 19418) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19419) (class_modifier 96) (class_modifiers 19420) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19421) (expr 19422) (fn 103) (fully_dereferenceable 104) #'19423 (function_call 106) (function_declaration_statement 19424) (if_stmt 19425) (if_stmt_without_else 19426) (inline_function 110) (inner_statement 19427) (interface_declaration_statement 19428) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19429) (static_member 119) (trait_declaration_statement 19430) (variable 122) (variable_class_name 123) ("{" 19431) ("~" 125)) 9119 ((";" 19892)) 9120 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 19895) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 9121 ((";" 19896)) 9122 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 19897) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 9123 ((";" 19898)) 9124 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 19558) (fn 2394) (for_exprs 19899) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (non_empty_for_exprs 19560) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 9125 ((")" 19900)) 9126 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 19901) (";" 19784) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19785) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19786) (T_DEC 22) (T_DECLARE 19787) (T_DIR 24) (T_DNUMBER 25) (T_DO 19788) (T_DOUBLE_CAST 27) (T_ECHO 19789) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19790) (T_FOREACH 19791) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19792) (T_GOTO 19793) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19794) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19795) (T_START_HEREDOC 68) (T_STATIC 19796) (T_STRING 19797) (T_STRING_CAST 71) (T_SWITCH 19798) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19799) (T_UNSET 19800) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19801) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19802) (alt_if_stmt_without_else 19803) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19804) (fn 103) (for_statement 19902) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19805) (if_stmt_without_else 19806) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19903) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19808) ("~" 125)) 9127 ((inner_statement_list 19904)) 9128 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19568) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19569) (T_CLASS 19570) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19571) (T_DEC 22) (T_DECLARE 19572) (T_DIR 24) (T_DNUMBER 25) (T_DO 19573) (T_DOUBLE_CAST 27) (T_ECHO 19574) (T_EMPTY 29) (T_ENDFOR 19905) (T_ENUM 19576) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19577) (T_FOREACH 19578) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19579) (T_GOTO 19580) (T_HALT_COMPILER 19581) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19583) (T_INTERFACE 19584) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19585) (T_START_HEREDOC 68) (T_STATIC 19586) (T_STRING 19587) (T_STRING_CAST 71) (T_SWITCH 19588) (T_THROW 73) (T_TRAIT 19589) (T_TRAIT_C 75) (T_TRY 19590) (T_UNSET 19591) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19592) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19593) (alt_if_stmt_without_else 19594) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19595) (attributes 19596) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19597) (class_modifier 96) (class_modifiers 19598) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19599) (expr 19600) (fn 103) (fully_dereferenceable 104) #'19601 (function_call 106) (function_declaration_statement 19602) (if_stmt 19603) (if_stmt_without_else 19604) (inline_function 110) (inner_statement 19605) (interface_declaration_statement 19606) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19607) (static_member 119) (trait_declaration_statement 19608) (variable 122) (variable_class_name 123) ("{" 19609) ("~" 125)) 9129 ((";" 19906)) 9130 (("," 19743) (";" 19908)) 9131 ((T_WHILE 19910)) 9132 (("(" 19911)) 9133 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 19912) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 9134 (("%" 292) (")" 19913) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 9135 ((";" 19914)) 9136 ((T_STRING 19916) (const_decl 19917) (const_list 19918)) 9137 (("=" 20345)) 9138 ((")" 19919) ("," 19920)) 9139 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 19922) (";" 19784) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19785) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19786) (T_DEC 22) (T_DECLARE 19787) (T_DIR 24) (T_DNUMBER 25) (T_DO 19788) (T_DOUBLE_CAST 27) (T_ECHO 19789) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19790) (T_FOREACH 19791) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19792) (T_GOTO 19793) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19794) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19795) (T_START_HEREDOC 68) (T_STATIC 19796) (T_STRING 19797) (T_STRING_CAST 71) (T_SWITCH 19798) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19799) (T_UNSET 19800) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19801) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19802) (alt_if_stmt_without_else 19803) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (declare_statement 19923) (dereferenceable_scalar 100) (expr 19804) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19805) (if_stmt_without_else 19806) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19924) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19808) ("~" 125)) 9140 ((T_STRING 19916) (const_decl 19921)) 9141 ((inner_statement_list 19925)) 9142 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19926) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19927) (T_CLASS 19928) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19929) (T_DEC 22) (T_DECLARE 19930) (T_DIR 24) (T_DNUMBER 25) (T_DO 19931) (T_DOUBLE_CAST 27) (T_ECHO 19932) (T_EMPTY 29) (T_ENDDECLARE 19933) (T_ENUM 19934) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19935) (T_FOREACH 19936) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19937) (T_GOTO 19938) (T_HALT_COMPILER 19939) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19941) (T_INTERFACE 19942) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19943) (T_START_HEREDOC 68) (T_STATIC 19944) (T_STRING 19945) (T_STRING_CAST 71) (T_SWITCH 19946) (T_THROW 73) (T_TRAIT 19947) (T_TRAIT_C 75) (T_TRY 19948) (T_UNSET 19949) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19950) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19951) (alt_if_stmt_without_else 19952) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19953) (attributes 19954) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19955) (class_modifier 96) (class_modifiers 19956) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19957) (expr 19958) (fn 103) (fully_dereferenceable 104) #'19959 (function_call 106) (function_declaration_statement 19960) (if_stmt 19961) (if_stmt_without_else 19962) (inline_function 110) (inner_statement 19963) (interface_declaration_statement 19964) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19965) (static_member 119) (trait_declaration_statement 19966) (variable 122) (variable_class_name 123) ("{" 19967) ("~" 125)) 9143 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 20343) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 9144 ((T_STRING 20336)) 9145 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 20334) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 9146 (("(" 20325)) 9147 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19746) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19747) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19748) (T_DEC 22) (T_DECLARE 19749) (T_DIR 24) (T_DNUMBER 25) (T_DO 19750) (T_DOUBLE_CAST 27) (T_ECHO 19751) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19752) (T_FOREACH 19753) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19754) (T_GOTO 19755) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19757) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19758) (T_START_HEREDOC 68) (T_STATIC 19759) (T_STRING 19760) (T_STRING_CAST 71) (T_SWITCH 19761) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19762) (T_UNSET 19763) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19764) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19765) (alt_if_stmt_without_else 19766) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19767) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19768) (if_stmt_without_else 19769) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20319) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19771) ("~" 125)) 9148 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (echo_expr 19740) (echo_expr_list 20317) (expr 19742) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 9149 ((";" 20316)) 9150 ((T_STRING 20257)) 9151 (("(" 20244)) 9152 (("(" 20229)) 9153 (("$" 17870) (T_VARIABLE 17871) (global_var 17872) (global_var_list 20227) (simple_variable 17874)) 9154 ((T_STRING 20225)) 9155 (("(" 20222)) 9156 (("(" 20216)) 9157 ((T_STRING 20208)) 9158 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 20206) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 9159 ((T_FN 35) (T_FUNCTION 127) (T_VARIABLE 16848) (fn 103) #'134 (inline_function 16849) (static_var 16850) (static_var_list 20204)) 9160 ((":" 20203)) 9161 (("(" 20185)) 9162 ((T_STRING 20180)) 9163 (("{" 20163)) 9164 (("(" 20158)) 9165 (("(" 20149)) 9166 ((T_ELSE 20142) (T_ELSEIF 16203) (T_ENDIF 20143)) 9167 ((T_ABSTRACT 10) (T_ATTRIBUTE 13) (T_CLASS 19928) (T_ENUM 19934) (T_FINAL 34) (T_FN 35) (T_FUNCTION 38) (T_INTERFACE 19942) (T_READONLY 2936) (T_STATIC 16288) (T_TRAIT 19947) (attribute 16289) (attributed_statement 20141) (class_declaration_statement 19955) (class_modifier 96) (class_modifiers 19956) (enum_declaration_statement 19957) (fn 103) #'19959 (function_declaration_statement 19960) (inline_function 16291) (interface_declaration_statement 19964) (trait_declaration_statement 19966)) 9168 ((T_ABSTRACT 10) (T_CLASS 20133) (T_FINAL 34) (T_READONLY 2936) (class_modifier 16280)) 9169 (("%" 6465) ("*" 6466) ("+" 6467) ("-" 6468) ("." 6469) ("/" 6470) (";" 20132) ("<" 6471) (">" 6472) ("?" 6473) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 6474) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 6475) (T_BOOLEAN_AND 6476) (T_BOOLEAN_OR 6477) (T_COALESCE 6478) (T_INSTANCEOF 6479) (T_IS_EQUAL 6480) (T_IS_GREATER_OR_EQUAL 6481) (T_IS_IDENTICAL 6482) (T_IS_NOT_EQUAL 6483) (T_IS_NOT_IDENTICAL 6484) (T_IS_SMALLER_OR_EQUAL 6485) (T_LOGICAL_AND 6486) (T_LOGICAL_OR 6487) (T_LOGICAL_XOR 6488) (T_POW 6489) (T_SL 6490) (T_SPACESHIP 6491) (T_SR 6492) ("^" 6493) ("|" 6494)) 9170 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 16261) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 16262) (ampersand 16263) (returns_ref 20120)) 9171 ((T_ELSE 19970) (T_ELSEIF 19971)) 9172 ((inner_statement_list 19968)) 9173 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 19969) ("~" 125)) 9174 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19926) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19927) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19929) (T_DEC 22) (T_DECLARE 19930) (T_DIR 24) (T_DNUMBER 25) (T_DO 19931) (T_DOUBLE_CAST 27) (T_ECHO 19932) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19935) (T_FOREACH 19936) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19937) (T_GOTO 19938) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19941) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19943) (T_START_HEREDOC 68) (T_STATIC 19944) (T_STRING 19945) (T_STRING_CAST 71) (T_SWITCH 19946) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19948) (T_UNSET 19949) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19950) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19951) (alt_if_stmt_without_else 19952) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19958) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19961) (if_stmt_without_else 19962) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20119) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19967) ("~" 125)) 9175 (("(" 19972)) 9176 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 19973) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 9177 (("%" 292) (")" 19974) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 9178 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19975) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19976) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19977) (T_DEC 22) (T_DECLARE 19978) (T_DIR 24) (T_DNUMBER 25) (T_DO 19979) (T_DOUBLE_CAST 27) (T_ECHO 19980) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19981) (T_FOREACH 19982) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19983) (T_GOTO 19984) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19985) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19986) (T_START_HEREDOC 68) (T_STATIC 19987) (T_STRING 19988) (T_STRING_CAST 71) (T_SWITCH 19989) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19990) (T_UNSET 19991) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19992) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19993) (alt_if_stmt_without_else 19994) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19995) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19996) (if_stmt_without_else 19997) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19998) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19999) ("~" 125)) 9179 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 20117) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 9180 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 20115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 9181 (("(" 20106)) 9182 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19746) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19747) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19748) (T_DEC 22) (T_DECLARE 19749) (T_DIR 24) (T_DNUMBER 25) (T_DO 19750) (T_DOUBLE_CAST 27) (T_ECHO 19751) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19752) (T_FOREACH 19753) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19754) (T_GOTO 19755) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19757) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19758) (T_START_HEREDOC 68) (T_STATIC 19759) (T_STRING 19760) (T_STRING_CAST 71) (T_SWITCH 19761) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19762) (T_UNSET 19763) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19764) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19765) (alt_if_stmt_without_else 19766) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19767) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19768) (if_stmt_without_else 19769) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20100) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19771) ("~" 125)) 9183 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (echo_expr 19740) (echo_expr_list 20098) (expr 19742) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 9184 (("(" 20085)) 9185 (("(" 20070)) 9186 (("$" 17870) (T_VARIABLE 17871) (global_var 17872) (global_var_list 20068) (simple_variable 17874)) 9187 ((T_STRING 20066)) 9188 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 20064) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 9189 ((T_FN 35) (T_FUNCTION 127) (T_VARIABLE 16848) (fn 103) #'134 (inline_function 16849) (static_var 16850) (static_var_list 20062)) 9190 ((":" 20061)) 9191 (("(" 20043)) 9192 (("{" 20026)) 9193 (("(" 20021)) 9194 (("(" 20012)) 9195 ((T_ELSE 20005) (T_ELSEIF 16203) (T_ENDIF 20006)) 9196 (("%" 6465) ("*" 6466) ("+" 6467) ("-" 6468) ("." 6469) ("/" 6470) (";" 20004) ("<" 6471) (">" 6472) ("?" 6473) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 6474) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 6475) (T_BOOLEAN_AND 6476) (T_BOOLEAN_OR 6477) (T_COALESCE 6478) (T_INSTANCEOF 6479) (T_IS_EQUAL 6480) (T_IS_GREATER_OR_EQUAL 6481) (T_IS_IDENTICAL 6482) (T_IS_NOT_EQUAL 6483) (T_IS_NOT_IDENTICAL 6484) (T_IS_SMALLER_OR_EQUAL 6485) (T_LOGICAL_AND 6486) (T_LOGICAL_OR 6487) (T_LOGICAL_XOR 6488) (T_POW 6489) (T_SL 6490) (T_SPACESHIP 6491) (T_SR 6492) ("^" 6493) ("|" 6494)) 9197 ((T_ELSE 20002) (T_ELSEIF 19971)) 9198 ((inner_statement_list 20000)) 9199 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 20001) ("~" 125)) 9200 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19975) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19976) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19977) (T_DEC 22) (T_DECLARE 19978) (T_DIR 24) (T_DNUMBER 25) (T_DO 19979) (T_DOUBLE_CAST 27) (T_ECHO 19980) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19981) (T_FOREACH 19982) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19983) (T_GOTO 19984) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19985) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19986) (T_START_HEREDOC 68) (T_STATIC 19987) (T_STRING 19988) (T_STRING_CAST 71) (T_SWITCH 19989) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19990) (T_UNSET 19991) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19992) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19993) (alt_if_stmt_without_else 19994) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19995) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19996) (if_stmt_without_else 19997) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20003) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19999) ("~" 125)) 9201 ((":" 20008)) 9202 ((";" 20007)) 9203 ((inner_statement_list 20009)) 9204 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16298) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16299) (T_CLASS 16300) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16301) (T_DEC 22) (T_DECLARE 16302) (T_DIR 24) (T_DNUMBER 25) (T_DO 16303) (T_DOUBLE_CAST 27) (T_ECHO 16304) (T_EMPTY 29) (T_ENDIF 20010) (T_ENUM 16306) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16307) (T_FOREACH 16308) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16309) (T_GOTO 16310) (T_HALT_COMPILER 16311) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16312) (T_INTERFACE 16313) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16314) (T_START_HEREDOC 68) (T_STATIC 16315) (T_STRING 16316) (T_STRING_CAST 71) (T_SWITCH 16317) (T_THROW 73) (T_TRAIT 16318) (T_TRAIT_C 75) (T_TRY 16319) (T_UNSET 16320) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16321) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16322) (alt_if_stmt_without_else 16323) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16324) (attributes 16325) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16326) (class_modifier 96) (class_modifiers 16327) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16328) (expr 16329) (fn 103) (fully_dereferenceable 104) #'16330 (function_call 106) (function_declaration_statement 16331) (if_stmt 16332) (if_stmt_without_else 16333) (inline_function 110) (inner_statement 16334) (interface_declaration_statement 16335) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16336) (static_member 119) (trait_declaration_statement 16337) (variable 122) (variable_class_name 123) ("{" 16338) ("~" 125)) 9205 ((";" 20011)) 9206 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 20013) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 9207 (("%" 292) (")" 20014) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 9208 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20015) (";" 19975) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19976) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19977) (T_DEC 22) (T_DECLARE 19978) (T_DIR 24) (T_DNUMBER 25) (T_DO 19979) (T_DOUBLE_CAST 27) (T_ECHO 19980) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19981) (T_FOREACH 19982) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19983) (T_GOTO 19984) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19985) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19986) (T_START_HEREDOC 68) (T_STATIC 19987) (T_STRING 19988) (T_STRING_CAST 71) (T_SWITCH 19989) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19990) (T_UNSET 19991) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19992) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19993) (alt_if_stmt_without_else 19994) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19995) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19996) (if_stmt_without_else 19997) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20016) (static_member 119) (variable 122) (variable_class_name 123) (while_statement 20017) ("{" 19999) ("~" 125)) 9209 ((inner_statement_list 20018)) 9210 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16379) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16380) (T_CLASS 16381) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16382) (T_DEC 22) (T_DECLARE 16383) (T_DIR 24) (T_DNUMBER 25) (T_DO 16384) (T_DOUBLE_CAST 27) (T_ECHO 16385) (T_EMPTY 29) (T_ENDWHILE 20019) (T_ENUM 16387) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16388) (T_FOREACH 16389) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16390) (T_GOTO 16391) (T_HALT_COMPILER 16392) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16394) (T_INTERFACE 16395) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16396) (T_START_HEREDOC 68) (T_STATIC 16397) (T_STRING 16398) (T_STRING_CAST 71) (T_SWITCH 16399) (T_THROW 73) (T_TRAIT 16400) (T_TRAIT_C 75) (T_TRY 16401) (T_UNSET 16402) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16403) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16404) (alt_if_stmt_without_else 16405) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16406) (attributes 16407) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16408) (class_modifier 96) (class_modifiers 16409) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16410) (expr 16411) (fn 103) (fully_dereferenceable 104) #'16412 (function_call 106) (function_declaration_statement 16413) (if_stmt 16414) (if_stmt_without_else 16415) (inline_function 110) (inner_statement 16416) (interface_declaration_statement 16417) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16418) (static_member 119) (trait_declaration_statement 16419) (variable 122) (variable_class_name 123) ("{" 16420) ("~" 125)) 9211 ((";" 20020)) 9212 (("\"" 1509) ("$" 16475) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 16476) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 16477) ("[" 1529) (array_object_dereferenceable 16478) (callable_expr 16479) (callable_variable 16480) (class_constant 1533) (class_name 16481) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 16482) (name 16483) (simple_variable 16484) (static_member 16485) (unset_variable 16486) (unset_variables 20022) (variable 16488) (variable_class_name 16489)) 9213 (("," 16501) (possible_comma 20023)) 9214 ((")" 20024)) 9215 ((";" 20025)) 9216 ((inner_statement_list 20027)) 9217 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 20028) ("~" 125)) 9218 ((catch_list 20029)) 9219 ((T_CATCH 20030) (T_FINALLY 20031) (finally_statement 20032)) 9220 (("(" 20036)) 9221 (("{" 20033)) 9222 ((inner_statement_list 20034)) 9223 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 20035) ("~" 125)) 9224 ((T_NAME_FULLY_QUALIFIED 16545) (T_NAME_QUALIFIED 16546) (T_NAME_RELATIVE 16547) (T_STATIC 16548) (T_STRING 16549) (catch_name_list 20037) (class_name 16551) (name 16552)) 9225 ((T_VARIABLE 16553) (optional_variable 20038) ("|" 16555)) 9226 ((")" 20039)) 9227 (("{" 20040)) 9228 ((inner_statement_list 20041)) 9229 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 20042) ("~" 125)) 9230 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 20044) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 9231 (("%" 292) (")" 20045) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 9232 ((":" 20046) (switch_case_list 20047) ("{" 20048)) 9233 ((";" 20054) (case_list 20055)) 9234 ((";" 20049) (case_list 20050)) 9235 ((case_list 20052)) 9236 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 20051)) 9237 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 20053)) 9238 ((case_list 20058)) 9239 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 20056)) 9240 ((";" 20057)) 9241 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 20059)) 9242 ((";" 20060)) 9243 (("," 16852) (";" 20063)) 9244 ((";" 20065)) 9245 ((";" 20067)) 9246 (("," 17875) (";" 20069)) 9247 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 20071) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 9248 (("%" 17961) ("*" 17962) ("+" 17963) ("-" 17964) ("." 17965) ("/" 17966) ("<" 17967) (">" 17968) ("?" 17969) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 17970) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 17971) (T_AS 20072) (T_BOOLEAN_AND 17972) (T_BOOLEAN_OR 17973) (T_COALESCE 17974) (T_INSTANCEOF 17975) (T_IS_EQUAL 17976) (T_IS_GREATER_OR_EQUAL 17977) (T_IS_IDENTICAL 17978) (T_IS_NOT_EQUAL 17979) (T_IS_NOT_IDENTICAL 17980) (T_IS_SMALLER_OR_EQUAL 17981) (T_LOGICAL_AND 17982) (T_LOGICAL_OR 17983) (T_LOGICAL_XOR 17984) (T_POW 17985) (T_SL 17986) (T_SPACESHIP 17987) (T_SR 17988) ("^" 17989) ("|" 17990)) 9249 (("\"" 1509) ("$" 19325) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19326) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19327) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19328) ("[" 19329) (ampersand 19330) (array_object_dereferenceable 19331) (callable_expr 19332) (callable_variable 19333) (class_constant 1533) (class_name 19334) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 20073) (fully_dereferenceable 104) (function_call 19336) (name 19337) (simple_variable 19338) (static_member 19339) (variable 19340) (variable_class_name 19341)) 9250 ((")" 20074) (T_DOUBLE_ARROW 20075)) 9251 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20078) (";" 19975) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19976) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19977) (T_DEC 22) (T_DECLARE 19978) (T_DIR 24) (T_DNUMBER 25) (T_DO 19979) (T_DOUBLE_CAST 27) (T_ECHO 19980) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19981) (T_FOREACH 19982) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19983) (T_GOTO 19984) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19985) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19986) (T_START_HEREDOC 68) (T_STATIC 19987) (T_STRING 19988) (T_STRING_CAST 71) (T_SWITCH 19989) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19990) (T_UNSET 19991) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19992) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19993) (alt_if_stmt_without_else 19994) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19995) (fn 103) (foreach_statement 20084) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19996) (if_stmt_without_else 19997) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20080) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19999) ("~" 125)) 9252 (("\"" 1509) ("$" 19356) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19357) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19358) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19359) ("[" 19360) (ampersand 19361) (array_object_dereferenceable 19362) (callable_expr 19363) (callable_variable 19364) (class_constant 1533) (class_name 19365) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 20076) (fully_dereferenceable 104) (function_call 19367) (name 19368) (simple_variable 19369) (static_member 19370) (variable 19371) (variable_class_name 19372)) 9253 ((")" 20077)) 9254 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20078) (";" 19975) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19976) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19977) (T_DEC 22) (T_DECLARE 19978) (T_DIR 24) (T_DNUMBER 25) (T_DO 19979) (T_DOUBLE_CAST 27) (T_ECHO 19980) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19981) (T_FOREACH 19982) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19983) (T_GOTO 19984) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19985) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19986) (T_START_HEREDOC 68) (T_STATIC 19987) (T_STRING 19988) (T_STRING_CAST 71) (T_SWITCH 19989) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19990) (T_UNSET 19991) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19992) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19993) (alt_if_stmt_without_else 19994) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19995) (fn 103) (foreach_statement 20079) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19996) (if_stmt_without_else 19997) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20080) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19999) ("~" 125)) 9255 ((inner_statement_list 20081)) 9256 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19390) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19391) (T_CLASS 19392) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19393) (T_DEC 22) (T_DECLARE 19394) (T_DIR 24) (T_DNUMBER 25) (T_DO 19395) (T_DOUBLE_CAST 27) (T_ECHO 19396) (T_EMPTY 29) (T_ENDFOREACH 20082) (T_ENUM 19398) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19399) (T_FOREACH 19400) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19401) (T_GOTO 19402) (T_HALT_COMPILER 19403) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19405) (T_INTERFACE 19406) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19407) (T_START_HEREDOC 68) (T_STATIC 19408) (T_STRING 19409) (T_STRING_CAST 71) (T_SWITCH 19410) (T_THROW 73) (T_TRAIT 19411) (T_TRAIT_C 75) (T_TRY 19412) (T_UNSET 19413) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19414) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19415) (alt_if_stmt_without_else 19416) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19417) (attributes 19418) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19419) (class_modifier 96) (class_modifiers 19420) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19421) (expr 19422) (fn 103) (fully_dereferenceable 104) #'19423 (function_call 106) (function_declaration_statement 19424) (if_stmt 19425) (if_stmt_without_else 19426) (inline_function 110) (inner_statement 19427) (interface_declaration_statement 19428) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19429) (static_member 119) (trait_declaration_statement 19430) (variable 122) (variable_class_name 123) ("{" 19431) ("~" 125)) 9257 ((";" 20083)) 9258 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 20086) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 9259 ((";" 20087)) 9260 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 20088) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 9261 ((";" 20089)) 9262 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 19558) (fn 2394) (for_exprs 20090) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (non_empty_for_exprs 19560) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 9263 ((")" 20091)) 9264 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20092) (";" 19975) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19976) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19977) (T_DEC 22) (T_DECLARE 19978) (T_DIR 24) (T_DNUMBER 25) (T_DO 19979) (T_DOUBLE_CAST 27) (T_ECHO 19980) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19981) (T_FOREACH 19982) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19983) (T_GOTO 19984) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19985) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19986) (T_START_HEREDOC 68) (T_STATIC 19987) (T_STRING 19988) (T_STRING_CAST 71) (T_SWITCH 19989) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19990) (T_UNSET 19991) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19992) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19993) (alt_if_stmt_without_else 19994) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19995) (fn 103) (for_statement 20093) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19996) (if_stmt_without_else 19997) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20094) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19999) ("~" 125)) 9265 ((inner_statement_list 20095)) 9266 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19568) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19569) (T_CLASS 19570) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19571) (T_DEC 22) (T_DECLARE 19572) (T_DIR 24) (T_DNUMBER 25) (T_DO 19573) (T_DOUBLE_CAST 27) (T_ECHO 19574) (T_EMPTY 29) (T_ENDFOR 20096) (T_ENUM 19576) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19577) (T_FOREACH 19578) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19579) (T_GOTO 19580) (T_HALT_COMPILER 19581) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19583) (T_INTERFACE 19584) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19585) (T_START_HEREDOC 68) (T_STATIC 19586) (T_STRING 19587) (T_STRING_CAST 71) (T_SWITCH 19588) (T_THROW 73) (T_TRAIT 19589) (T_TRAIT_C 75) (T_TRY 19590) (T_UNSET 19591) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19592) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19593) (alt_if_stmt_without_else 19594) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19595) (attributes 19596) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19597) (class_modifier 96) (class_modifiers 19598) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19599) (expr 19600) (fn 103) (fully_dereferenceable 104) #'19601 (function_call 106) (function_declaration_statement 19602) (if_stmt 19603) (if_stmt_without_else 19604) (inline_function 110) (inner_statement 19605) (interface_declaration_statement 19606) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19607) (static_member 119) (trait_declaration_statement 19608) (variable 122) (variable_class_name 123) ("{" 19609) ("~" 125)) 9267 ((";" 20097)) 9268 (("," 19743) (";" 20099)) 9269 ((T_WHILE 20101)) 9270 (("(" 20102)) 9271 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 20103) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 9272 (("%" 292) (")" 20104) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 9273 ((";" 20105)) 9274 ((T_STRING 19916) (const_decl 19917) (const_list 20107)) 9275 ((")" 20108) ("," 19920)) 9276 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20109) (";" 19975) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19976) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19977) (T_DEC 22) (T_DECLARE 19978) (T_DIR 24) (T_DNUMBER 25) (T_DO 19979) (T_DOUBLE_CAST 27) (T_ECHO 19980) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19981) (T_FOREACH 19982) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19983) (T_GOTO 19984) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19985) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19986) (T_START_HEREDOC 68) (T_STATIC 19987) (T_STRING 19988) (T_STRING_CAST 71) (T_SWITCH 19989) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19990) (T_UNSET 19991) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19992) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19993) (alt_if_stmt_without_else 19994) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (declare_statement 20110) (dereferenceable_scalar 100) (expr 19995) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19996) (if_stmt_without_else 19997) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20111) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19999) ("~" 125)) 9277 ((inner_statement_list 20112)) 9278 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19926) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19927) (T_CLASS 19928) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19929) (T_DEC 22) (T_DECLARE 19930) (T_DIR 24) (T_DNUMBER 25) (T_DO 19931) (T_DOUBLE_CAST 27) (T_ECHO 19932) (T_EMPTY 29) (T_ENDDECLARE 20113) (T_ENUM 19934) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19935) (T_FOREACH 19936) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19937) (T_GOTO 19938) (T_HALT_COMPILER 19939) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19941) (T_INTERFACE 19942) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19943) (T_START_HEREDOC 68) (T_STATIC 19944) (T_STRING 19945) (T_STRING_CAST 71) (T_SWITCH 19946) (T_THROW 73) (T_TRAIT 19947) (T_TRAIT_C 75) (T_TRY 19948) (T_UNSET 19949) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19950) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19951) (alt_if_stmt_without_else 19952) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19953) (attributes 19954) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19955) (class_modifier 96) (class_modifiers 19956) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19957) (expr 19958) (fn 103) (fully_dereferenceable 104) #'19959 (function_call 106) (function_declaration_statement 19960) (if_stmt 19961) (if_stmt_without_else 19962) (inline_function 110) (inner_statement 19963) (interface_declaration_statement 19964) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19965) (static_member 119) (trait_declaration_statement 19966) (variable 122) (variable_class_name 123) ("{" 19967) ("~" 125)) 9279 ((";" 20114)) 9280 ((";" 20116)) 9281 ((";" 20118)) 9282 ((T_READONLY 16265) (T_STRING 16266) (backup_doc_comment 139) (function_name 20121)) 9283 ((backup_doc_comment 20122)) 9284 (("(" 20123)) 9285 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 20124)) 9286 ((")" 20125)) 9287 ((":" 161) (return_type 20126)) 9288 ((backup_fn_flags 20127)) 9289 (("{" 20128)) 9290 ((inner_statement_list 20129)) 9291 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 20130) ("~" 125)) 9292 ((backup_fn_flags 20131)) 9293 ((T_STRING 20134)) 9294 ((T_EXTENDS 2985) (extends_from 20135)) 9295 ((T_IMPLEMENTS 2987) (implements_list 20136)) 9296 ((backup_doc_comment 20137)) 9297 (("{" 20138)) 9298 ((class_statement_list 20139)) 9299 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 20140)) 9300 ((":" 20145)) 9301 ((";" 20144)) 9302 ((inner_statement_list 20146)) 9303 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16298) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16299) (T_CLASS 16300) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16301) (T_DEC 22) (T_DECLARE 16302) (T_DIR 24) (T_DNUMBER 25) (T_DO 16303) (T_DOUBLE_CAST 27) (T_ECHO 16304) (T_EMPTY 29) (T_ENDIF 20147) (T_ENUM 16306) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16307) (T_FOREACH 16308) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16309) (T_GOTO 16310) (T_HALT_COMPILER 16311) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16312) (T_INTERFACE 16313) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16314) (T_START_HEREDOC 68) (T_STATIC 16315) (T_STRING 16316) (T_STRING_CAST 71) (T_SWITCH 16317) (T_THROW 73) (T_TRAIT 16318) (T_TRAIT_C 75) (T_TRY 16319) (T_UNSET 16320) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16321) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16322) (alt_if_stmt_without_else 16323) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16324) (attributes 16325) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16326) (class_modifier 96) (class_modifiers 16327) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16328) (expr 16329) (fn 103) (fully_dereferenceable 104) #'16330 (function_call 106) (function_declaration_statement 16331) (if_stmt 16332) (if_stmt_without_else 16333) (inline_function 110) (inner_statement 16334) (interface_declaration_statement 16335) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16336) (static_member 119) (trait_declaration_statement 16337) (variable 122) (variable_class_name 123) ("{" 16338) ("~" 125)) 9304 ((";" 20148)) 9305 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 20150) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 9306 (("%" 292) (")" 20151) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 9307 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20152) (";" 19926) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19927) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19929) (T_DEC 22) (T_DECLARE 19930) (T_DIR 24) (T_DNUMBER 25) (T_DO 19931) (T_DOUBLE_CAST 27) (T_ECHO 19932) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19935) (T_FOREACH 19936) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19937) (T_GOTO 19938) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19941) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19943) (T_START_HEREDOC 68) (T_STATIC 19944) (T_STRING 19945) (T_STRING_CAST 71) (T_SWITCH 19946) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19948) (T_UNSET 19949) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19950) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19951) (alt_if_stmt_without_else 19952) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19958) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19961) (if_stmt_without_else 19962) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20153) (static_member 119) (variable 122) (variable_class_name 123) (while_statement 20154) ("{" 19967) ("~" 125)) 9308 ((inner_statement_list 20155)) 9309 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16379) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16380) (T_CLASS 16381) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16382) (T_DEC 22) (T_DECLARE 16383) (T_DIR 24) (T_DNUMBER 25) (T_DO 16384) (T_DOUBLE_CAST 27) (T_ECHO 16385) (T_EMPTY 29) (T_ENDWHILE 20156) (T_ENUM 16387) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16388) (T_FOREACH 16389) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16390) (T_GOTO 16391) (T_HALT_COMPILER 16392) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16394) (T_INTERFACE 16395) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16396) (T_START_HEREDOC 68) (T_STATIC 16397) (T_STRING 16398) (T_STRING_CAST 71) (T_SWITCH 16399) (T_THROW 73) (T_TRAIT 16400) (T_TRAIT_C 75) (T_TRY 16401) (T_UNSET 16402) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16403) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16404) (alt_if_stmt_without_else 16405) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16406) (attributes 16407) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16408) (class_modifier 96) (class_modifiers 16409) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16410) (expr 16411) (fn 103) (fully_dereferenceable 104) #'16412 (function_call 106) (function_declaration_statement 16413) (if_stmt 16414) (if_stmt_without_else 16415) (inline_function 110) (inner_statement 16416) (interface_declaration_statement 16417) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16418) (static_member 119) (trait_declaration_statement 16419) (variable 122) (variable_class_name 123) ("{" 16420) ("~" 125)) 9310 ((";" 20157)) 9311 (("\"" 1509) ("$" 16475) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 16476) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 16477) ("[" 1529) (array_object_dereferenceable 16478) (callable_expr 16479) (callable_variable 16480) (class_constant 1533) (class_name 16481) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 16482) (name 16483) (simple_variable 16484) (static_member 16485) (unset_variable 16486) (unset_variables 20159) (variable 16488) (variable_class_name 16489)) 9312 (("," 16501) (possible_comma 20160)) 9313 ((")" 20161)) 9314 ((";" 20162)) 9315 ((inner_statement_list 20164)) 9316 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 20165) ("~" 125)) 9317 ((catch_list 20166)) 9318 ((T_CATCH 20167) (T_FINALLY 20168) (finally_statement 20169)) 9319 (("(" 20173)) 9320 (("{" 20170)) 9321 ((inner_statement_list 20171)) 9322 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 20172) ("~" 125)) 9323 ((T_NAME_FULLY_QUALIFIED 16545) (T_NAME_QUALIFIED 16546) (T_NAME_RELATIVE 16547) (T_STATIC 16548) (T_STRING 16549) (catch_name_list 20174) (class_name 16551) (name 16552)) 9324 ((T_VARIABLE 16553) (optional_variable 20175) ("|" 16555)) 9325 ((")" 20176)) 9326 (("{" 20177)) 9327 ((inner_statement_list 20178)) 9328 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 20179) ("~" 125)) 9329 ((backup_doc_comment 20181)) 9330 (("{" 20182)) 9331 ((class_statement_list 20183)) 9332 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 20184)) 9333 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 20186) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 9334 (("%" 292) (")" 20187) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 9335 ((":" 20188) (switch_case_list 20189) ("{" 20190)) 9336 ((";" 20196) (case_list 20197)) 9337 ((";" 20191) (case_list 20192)) 9338 ((case_list 20194)) 9339 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 20193)) 9340 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 20195)) 9341 ((case_list 20200)) 9342 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 20198)) 9343 ((";" 20199)) 9344 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 20201)) 9345 ((";" 20202)) 9346 (("," 16852) (";" 20205)) 9347 ((";" 20207)) 9348 ((T_EXTENDS 20209) (interface_extends_list 20210)) 9349 ((T_NAME_FULLY_QUALIFIED 6587) (T_NAME_QUALIFIED 6588) (T_NAME_RELATIVE 6589) (T_STATIC 6590) (T_STRING 6591) (class_name 6592) (class_name_list 20215) (name 6594)) 9350 ((backup_doc_comment 20211)) 9351 (("{" 20212)) 9352 ((class_statement_list 20213)) 9353 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 20214)) 9354 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 20217) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 9355 (("%" 292) (")" 20218) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 9356 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20219) (";" 19975) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19976) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19977) (T_DEC 22) (T_DECLARE 19978) (T_DIR 24) (T_DNUMBER 25) (T_DO 19979) (T_DOUBLE_CAST 27) (T_ECHO 19980) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19981) (T_FOREACH 19982) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19983) (T_GOTO 19984) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19985) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19986) (T_START_HEREDOC 68) (T_STATIC 19987) (T_STRING 19988) (T_STRING_CAST 71) (T_SWITCH 19989) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19990) (T_UNSET 19991) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19992) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19993) (alt_if_stmt_without_else 19994) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19995) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19996) (if_stmt_without_else 19997) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20220) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19999) ("~" 125)) 9357 ((inner_statement_list 20221)) 9358 ((")" 20223)) 9359 ((";" 20224)) 9360 ((";" 20226)) 9361 (("," 17875) (";" 20228)) 9362 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 20230) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 9363 (("%" 17961) ("*" 17962) ("+" 17963) ("-" 17964) ("." 17965) ("/" 17966) ("<" 17967) (">" 17968) ("?" 17969) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 17970) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 17971) (T_AS 20231) (T_BOOLEAN_AND 17972) (T_BOOLEAN_OR 17973) (T_COALESCE 17974) (T_INSTANCEOF 17975) (T_IS_EQUAL 17976) (T_IS_GREATER_OR_EQUAL 17977) (T_IS_IDENTICAL 17978) (T_IS_NOT_EQUAL 17979) (T_IS_NOT_IDENTICAL 17980) (T_IS_SMALLER_OR_EQUAL 17981) (T_LOGICAL_AND 17982) (T_LOGICAL_OR 17983) (T_LOGICAL_XOR 17984) (T_POW 17985) (T_SL 17986) (T_SPACESHIP 17987) (T_SR 17988) ("^" 17989) ("|" 17990)) 9364 (("\"" 1509) ("$" 19325) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19326) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19327) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19328) ("[" 19329) (ampersand 19330) (array_object_dereferenceable 19331) (callable_expr 19332) (callable_variable 19333) (class_constant 1533) (class_name 19334) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 20232) (fully_dereferenceable 104) (function_call 19336) (name 19337) (simple_variable 19338) (static_member 19339) (variable 19340) (variable_class_name 19341)) 9365 ((")" 20233) (T_DOUBLE_ARROW 20234)) 9366 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20237) (";" 19926) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19927) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19929) (T_DEC 22) (T_DECLARE 19930) (T_DIR 24) (T_DNUMBER 25) (T_DO 19931) (T_DOUBLE_CAST 27) (T_ECHO 19932) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19935) (T_FOREACH 19936) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19937) (T_GOTO 19938) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19941) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19943) (T_START_HEREDOC 68) (T_STATIC 19944) (T_STRING 19945) (T_STRING_CAST 71) (T_SWITCH 19946) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19948) (T_UNSET 19949) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19950) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19951) (alt_if_stmt_without_else 19952) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19958) (fn 103) (foreach_statement 20243) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19961) (if_stmt_without_else 19962) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20239) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19967) ("~" 125)) 9367 (("\"" 1509) ("$" 19356) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19357) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19358) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19359) ("[" 19360) (ampersand 19361) (array_object_dereferenceable 19362) (callable_expr 19363) (callable_variable 19364) (class_constant 1533) (class_name 19365) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 20235) (fully_dereferenceable 104) (function_call 19367) (name 19368) (simple_variable 19369) (static_member 19370) (variable 19371) (variable_class_name 19372)) 9368 ((")" 20236)) 9369 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20237) (";" 19926) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19927) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19929) (T_DEC 22) (T_DECLARE 19930) (T_DIR 24) (T_DNUMBER 25) (T_DO 19931) (T_DOUBLE_CAST 27) (T_ECHO 19932) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19935) (T_FOREACH 19936) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19937) (T_GOTO 19938) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19941) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19943) (T_START_HEREDOC 68) (T_STATIC 19944) (T_STRING 19945) (T_STRING_CAST 71) (T_SWITCH 19946) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19948) (T_UNSET 19949) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19950) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19951) (alt_if_stmt_without_else 19952) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19958) (fn 103) (foreach_statement 20238) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19961) (if_stmt_without_else 19962) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20239) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19967) ("~" 125)) 9370 ((inner_statement_list 20240)) 9371 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19390) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19391) (T_CLASS 19392) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19393) (T_DEC 22) (T_DECLARE 19394) (T_DIR 24) (T_DNUMBER 25) (T_DO 19395) (T_DOUBLE_CAST 27) (T_ECHO 19396) (T_EMPTY 29) (T_ENDFOREACH 20241) (T_ENUM 19398) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19399) (T_FOREACH 19400) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19401) (T_GOTO 19402) (T_HALT_COMPILER 19403) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19405) (T_INTERFACE 19406) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19407) (T_START_HEREDOC 68) (T_STATIC 19408) (T_STRING 19409) (T_STRING_CAST 71) (T_SWITCH 19410) (T_THROW 73) (T_TRAIT 19411) (T_TRAIT_C 75) (T_TRY 19412) (T_UNSET 19413) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19414) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19415) (alt_if_stmt_without_else 19416) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19417) (attributes 19418) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19419) (class_modifier 96) (class_modifiers 19420) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19421) (expr 19422) (fn 103) (fully_dereferenceable 104) #'19423 (function_call 106) (function_declaration_statement 19424) (if_stmt 19425) (if_stmt_without_else 19426) (inline_function 110) (inner_statement 19427) (interface_declaration_statement 19428) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19429) (static_member 119) (trait_declaration_statement 19430) (variable 122) (variable_class_name 123) ("{" 19431) ("~" 125)) 9372 ((";" 20242)) 9373 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 20245) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 9374 ((";" 20246)) 9375 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 20247) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 9376 ((";" 20248)) 9377 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 19558) (fn 2394) (for_exprs 20249) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (non_empty_for_exprs 19560) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 9378 ((")" 20250)) 9379 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20251) (";" 19926) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19927) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19929) (T_DEC 22) (T_DECLARE 19930) (T_DIR 24) (T_DNUMBER 25) (T_DO 19931) (T_DOUBLE_CAST 27) (T_ECHO 19932) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19935) (T_FOREACH 19936) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19937) (T_GOTO 19938) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19941) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19943) (T_START_HEREDOC 68) (T_STATIC 19944) (T_STRING 19945) (T_STRING_CAST 71) (T_SWITCH 19946) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19948) (T_UNSET 19949) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19950) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19951) (alt_if_stmt_without_else 19952) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19958) (fn 103) (for_statement 20252) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19961) (if_stmt_without_else 19962) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20253) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19967) ("~" 125)) 9380 ((inner_statement_list 20254)) 9381 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19568) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19569) (T_CLASS 19570) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19571) (T_DEC 22) (T_DECLARE 19572) (T_DIR 24) (T_DNUMBER 25) (T_DO 19573) (T_DOUBLE_CAST 27) (T_ECHO 19574) (T_EMPTY 29) (T_ENDFOR 20255) (T_ENUM 19576) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19577) (T_FOREACH 19578) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19579) (T_GOTO 19580) (T_HALT_COMPILER 19581) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19583) (T_INTERFACE 19584) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19585) (T_START_HEREDOC 68) (T_STATIC 19586) (T_STRING 19587) (T_STRING_CAST 71) (T_SWITCH 19588) (T_THROW 73) (T_TRAIT 19589) (T_TRAIT_C 75) (T_TRY 19590) (T_UNSET 19591) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19592) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19593) (alt_if_stmt_without_else 19594) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19595) (attributes 19596) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19597) (class_modifier 96) (class_modifiers 19598) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19599) (expr 19600) (fn 103) (fully_dereferenceable 104) #'19601 (function_call 106) (function_declaration_statement 19602) (if_stmt 19603) (if_stmt_without_else 19604) (inline_function 110) (inner_statement 19605) (interface_declaration_statement 19606) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19607) (static_member 119) (trait_declaration_statement 19608) (variable 122) (variable_class_name 123) ("{" 19609) ("~" 125)) 9382 ((";" 20256)) 9383 ((":" 20258) (enum_backing_type 20259)) 9384 (("(" 2248) ("?" 20265) (T_ARRAY 20266) (T_CALLABLE 20267) (T_NAME_FULLY_QUALIFIED 20268) (T_NAME_QUALIFIED 20269) (T_NAME_RELATIVE 20270) (T_STATIC 20271) (T_STRING 20272) (intersection_type 20273) (name 20274) (type 20275) (type_expr 20276) (type_without_static 20277) (union_type 20278) (union_type_element 20279)) 9385 ((T_IMPLEMENTS 2987) (implements_list 20260)) 9386 ((backup_doc_comment 20261)) 9387 (("{" 20262)) 9388 ((class_statement_list 20263)) 9389 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 20264)) 9390 ((T_ARRAY 20310) (T_CALLABLE 20311) (T_NAME_FULLY_QUALIFIED 6597) (T_NAME_QUALIFIED 6598) (T_NAME_RELATIVE 6599) (T_STATIC 20312) (T_STRING 6601) (name 20313) (type 20314) (type_without_static 20315)) 9391 ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 20308)) 9392 ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 20297)) 9393 (("|" 20295)) 9394 (("|" 20280)) 9395 (("(" 20281) (T_ARRAY 20282) (T_CALLABLE 20283) (T_NAME_FULLY_QUALIFIED 20284) (T_NAME_QUALIFIED 20285) (T_NAME_RELATIVE 20286) (T_STATIC 20287) (T_STRING 20288) (name 20289) (type 20290) (type_without_static 20291) (union_type_element 20292)) 9396 ((T_ARRAY 2277) (T_CALLABLE 2278) (T_NAME_FULLY_QUALIFIED 2279) (T_NAME_QUALIFIED 2280) (T_NAME_RELATIVE 2281) (T_STATIC 2282) (T_STRING 2283) (intersection_type 20293) (name 2285) (type 2286) (type_without_static 2287)) 9397 ((")" 20294) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 2300)) 9398 (("(" 20281) (T_ARRAY 20282) (T_CALLABLE 20283) (T_NAME_FULLY_QUALIFIED 20284) (T_NAME_QUALIFIED 20285) (T_NAME_RELATIVE 20286) (T_STATIC 20287) (T_STRING 20288) (name 20289) (type 20290) (type_without_static 20291) (union_type_element 20296)) 9399 ((T_ARRAY 20298) (T_CALLABLE 20299) (T_NAME_FULLY_QUALIFIED 20300) (T_NAME_QUALIFIED 20301) (T_NAME_RELATIVE 20302) (T_STATIC 20303) (T_STRING 20304) (name 20305) (type 20306) (type_without_static 20307)) 9400 ((T_ARRAY 20298) (T_CALLABLE 20299) (T_NAME_FULLY_QUALIFIED 20300) (T_NAME_QUALIFIED 20301) (T_NAME_RELATIVE 20302) (T_STATIC 20303) (T_STRING 20304) (name 20305) (type 20309) (type_without_static 20307)) 9401 (("," 19743) (";" 20318)) 9402 ((T_WHILE 20320)) 9403 (("(" 20321)) 9404 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 20322) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 9405 (("%" 292) (")" 20323) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 9406 ((";" 20324)) 9407 ((T_STRING 19916) (const_decl 19917) (const_list 20326)) 9408 ((")" 20327) ("," 19920)) 9409 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20328) (";" 19926) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19927) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19929) (T_DEC 22) (T_DECLARE 19930) (T_DIR 24) (T_DNUMBER 25) (T_DO 19931) (T_DOUBLE_CAST 27) (T_ECHO 19932) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19935) (T_FOREACH 19936) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19937) (T_GOTO 19938) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19941) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19943) (T_START_HEREDOC 68) (T_STATIC 19944) (T_STRING 19945) (T_STRING_CAST 71) (T_SWITCH 19946) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19948) (T_UNSET 19949) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19950) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19951) (alt_if_stmt_without_else 19952) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (declare_statement 20329) (dereferenceable_scalar 100) (expr 19958) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19961) (if_stmt_without_else 19962) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20330) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19967) ("~" 125)) 9410 ((inner_statement_list 20331)) 9411 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19926) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19927) (T_CLASS 19928) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19929) (T_DEC 22) (T_DECLARE 19930) (T_DIR 24) (T_DNUMBER 25) (T_DO 19931) (T_DOUBLE_CAST 27) (T_ECHO 19932) (T_EMPTY 29) (T_ENDDECLARE 20332) (T_ENUM 19934) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19935) (T_FOREACH 19936) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19937) (T_GOTO 19938) (T_HALT_COMPILER 19939) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19941) (T_INTERFACE 19942) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19943) (T_START_HEREDOC 68) (T_STATIC 19944) (T_STRING 19945) (T_STRING_CAST 71) (T_SWITCH 19946) (T_THROW 73) (T_TRAIT 19947) (T_TRAIT_C 75) (T_TRY 19948) (T_UNSET 19949) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19950) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19951) (alt_if_stmt_without_else 19952) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19953) (attributes 19954) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19955) (class_modifier 96) (class_modifiers 19956) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19957) (expr 19958) (fn 103) (fully_dereferenceable 104) #'19959 (function_call 106) (function_declaration_statement 19960) (if_stmt 19961) (if_stmt_without_else 19962) (inline_function 110) (inner_statement 19963) (interface_declaration_statement 19964) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19965) (static_member 119) (trait_declaration_statement 19966) (variable 122) (variable_class_name 123) ("{" 19967) ("~" 125)) 9412 ((";" 20333)) 9413 ((";" 20335)) 9414 ((T_EXTENDS 2985) (extends_from 20337)) 9415 ((T_IMPLEMENTS 2987) (implements_list 20338)) 9416 ((backup_doc_comment 20339)) 9417 (("{" 20340)) 9418 ((class_statement_list 20341)) 9419 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 20342)) 9420 ((";" 20344)) 9421 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 20346) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 9422 (("%" 1097) ("*" 1098) ("+" 1099) ("-" 1100) ("." 1101) ("/" 1102) ("<" 1103) (">" 1104) ("?" 1105) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1106) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1107) (T_BOOLEAN_AND 1108) (T_BOOLEAN_OR 1109) (T_COALESCE 1110) (T_INSTANCEOF 1111) (T_IS_EQUAL 1112) (T_IS_GREATER_OR_EQUAL 1113) (T_IS_IDENTICAL 1114) (T_IS_NOT_EQUAL 1115) (T_IS_NOT_IDENTICAL 1116) (T_IS_SMALLER_OR_EQUAL 1117) (T_LOGICAL_AND 1118) (T_LOGICAL_OR 1119) (T_LOGICAL_XOR 1120) (T_POW 1121) (T_SL 1122) (T_SPACESHIP 1123) (T_SR 1124) ("^" 1125) (backup_doc_comment 20347) ("|" 1126)) 9423 ((";" 20349)) 9424 ((";" 20351)) 9425 ((":" 20357)) 9426 ((";" 20356)) 9427 ((inner_statement_list 20358)) 9428 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16298) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16299) (T_CLASS 16300) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16301) (T_DEC 22) (T_DECLARE 16302) (T_DIR 24) (T_DNUMBER 25) (T_DO 16303) (T_DOUBLE_CAST 27) (T_ECHO 16304) (T_EMPTY 29) (T_ENDIF 20359) (T_ENUM 16306) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16307) (T_FOREACH 16308) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16309) (T_GOTO 16310) (T_HALT_COMPILER 16311) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16312) (T_INTERFACE 16313) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16314) (T_START_HEREDOC 68) (T_STATIC 16315) (T_STRING 16316) (T_STRING_CAST 71) (T_SWITCH 16317) (T_THROW 73) (T_TRAIT 16318) (T_TRAIT_C 75) (T_TRY 16319) (T_UNSET 16320) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16321) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16322) (alt_if_stmt_without_else 16323) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16324) (attributes 16325) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16326) (class_modifier 96) (class_modifiers 16327) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16328) (expr 16329) (fn 103) (fully_dereferenceable 104) #'16330 (function_call 106) (function_declaration_statement 16331) (if_stmt 16332) (if_stmt_without_else 16333) (inline_function 110) (inner_statement 16334) (interface_declaration_statement 16335) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16336) (static_member 119) (trait_declaration_statement 16337) (variable 122) (variable_class_name 123) ("{" 16338) ("~" 125)) 9429 ((";" 20360)) 9430 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 20362) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 9431 (("%" 292) (")" 20363) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 9432 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20364) (";" 19746) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19747) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19748) (T_DEC 22) (T_DECLARE 19749) (T_DIR 24) (T_DNUMBER 25) (T_DO 19750) (T_DOUBLE_CAST 27) (T_ECHO 19751) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19752) (T_FOREACH 19753) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19754) (T_GOTO 19755) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19757) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19758) (T_START_HEREDOC 68) (T_STATIC 19759) (T_STRING 19760) (T_STRING_CAST 71) (T_SWITCH 19761) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19762) (T_UNSET 19763) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19764) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19765) (alt_if_stmt_without_else 19766) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19767) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19768) (if_stmt_without_else 19769) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20365) (static_member 119) (variable 122) (variable_class_name 123) (while_statement 20366) ("{" 19771) ("~" 125)) 9433 ((inner_statement_list 20367)) 9434 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16379) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16380) (T_CLASS 16381) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16382) (T_DEC 22) (T_DECLARE 16383) (T_DIR 24) (T_DNUMBER 25) (T_DO 16384) (T_DOUBLE_CAST 27) (T_ECHO 16385) (T_EMPTY 29) (T_ENDWHILE 20368) (T_ENUM 16387) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16388) (T_FOREACH 16389) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16390) (T_GOTO 16391) (T_HALT_COMPILER 16392) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16394) (T_INTERFACE 16395) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16396) (T_START_HEREDOC 68) (T_STATIC 16397) (T_STRING 16398) (T_STRING_CAST 71) (T_SWITCH 16399) (T_THROW 73) (T_TRAIT 16400) (T_TRAIT_C 75) (T_TRY 16401) (T_UNSET 16402) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16403) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16404) (alt_if_stmt_without_else 16405) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16406) (attributes 16407) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16408) (class_modifier 96) (class_modifiers 16409) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16410) (expr 16411) (fn 103) (fully_dereferenceable 104) #'16412 (function_call 106) (function_declaration_statement 16413) (if_stmt 16414) (if_stmt_without_else 16415) (inline_function 110) (inner_statement 16416) (interface_declaration_statement 16417) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16418) (static_member 119) (trait_declaration_statement 16419) (variable 122) (variable_class_name 123) ("{" 16420) ("~" 125)) 9435 ((";" 20369)) 9436 (("\"" 1509) ("$" 16475) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 16476) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 16477) ("[" 1529) (array_object_dereferenceable 16478) (callable_expr 16479) (callable_variable 16480) (class_constant 1533) (class_name 16481) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 16482) (name 16483) (simple_variable 16484) (static_member 16485) (unset_variable 16486) (unset_variables 20371) (variable 16488) (variable_class_name 16489)) 9437 (("," 16501) (possible_comma 20372)) 9438 ((")" 20373)) 9439 ((";" 20374)) 9440 ((inner_statement_list 20376)) 9441 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 20377) ("~" 125)) 9442 ((catch_list 20378)) 9443 ((T_CATCH 20379) (T_FINALLY 20380) (finally_statement 20381)) 9444 (("(" 20385)) 9445 (("{" 20382)) 9446 ((inner_statement_list 20383)) 9447 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 20384) ("~" 125)) 9448 ((T_NAME_FULLY_QUALIFIED 16545) (T_NAME_QUALIFIED 16546) (T_NAME_RELATIVE 16547) (T_STATIC 16548) (T_STRING 16549) (catch_name_list 20386) (class_name 16551) (name 16552)) 9449 ((T_VARIABLE 16553) (optional_variable 20387) ("|" 16555)) 9450 ((")" 20388)) 9451 (("{" 20389)) 9452 ((inner_statement_list 20390)) 9453 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 20391) ("~" 125)) 9454 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 20393) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 9455 (("%" 292) (")" 20394) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 9456 ((":" 20395) (switch_case_list 20396) ("{" 20397)) 9457 ((";" 20403) (case_list 20404)) 9458 ((";" 20398) (case_list 20399)) 9459 ((case_list 20401)) 9460 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 20400)) 9461 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 20402)) 9462 ((case_list 20407)) 9463 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 20405)) 9464 ((";" 20406)) 9465 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 20408)) 9466 ((";" 20409)) 9467 (("," 16852) (";" 20412)) 9468 ((";" 20414)) 9469 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 20416) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 9470 (("%" 292) (")" 20417) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 9471 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20219) (";" 19784) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19785) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19786) (T_DEC 22) (T_DECLARE 19787) (T_DIR 24) (T_DNUMBER 25) (T_DO 19788) (T_DOUBLE_CAST 27) (T_ECHO 19789) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19790) (T_FOREACH 19791) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19792) (T_GOTO 19793) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19794) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19795) (T_START_HEREDOC 68) (T_STATIC 19796) (T_STRING 19797) (T_STRING_CAST 71) (T_SWITCH 19798) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19799) (T_UNSET 19800) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19801) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19802) (alt_if_stmt_without_else 19803) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19804) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19805) (if_stmt_without_else 19806) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20418) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19808) ("~" 125)) 9472 ((";" 20420)) 9473 (("," 17875) (";" 20422)) 9474 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 20424) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 9475 (("%" 17961) ("*" 17962) ("+" 17963) ("-" 17964) ("." 17965) ("/" 17966) ("<" 17967) (">" 17968) ("?" 17969) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 17970) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 17971) (T_AS 20425) (T_BOOLEAN_AND 17972) (T_BOOLEAN_OR 17973) (T_COALESCE 17974) (T_INSTANCEOF 17975) (T_IS_EQUAL 17976) (T_IS_GREATER_OR_EQUAL 17977) (T_IS_IDENTICAL 17978) (T_IS_NOT_EQUAL 17979) (T_IS_NOT_IDENTICAL 17980) (T_IS_SMALLER_OR_EQUAL 17981) (T_LOGICAL_AND 17982) (T_LOGICAL_OR 17983) (T_LOGICAL_XOR 17984) (T_POW 17985) (T_SL 17986) (T_SPACESHIP 17987) (T_SR 17988) ("^" 17989) ("|" 17990)) 9476 (("\"" 1509) ("$" 19325) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19326) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19327) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19328) ("[" 19329) (ampersand 19330) (array_object_dereferenceable 19331) (callable_expr 19332) (callable_variable 19333) (class_constant 1533) (class_name 19334) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 20426) (fully_dereferenceable 104) (function_call 19336) (name 19337) (simple_variable 19338) (static_member 19339) (variable 19340) (variable_class_name 19341)) 9477 ((")" 20427) (T_DOUBLE_ARROW 20428)) 9478 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20431) (";" 19746) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19747) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19748) (T_DEC 22) (T_DECLARE 19749) (T_DIR 24) (T_DNUMBER 25) (T_DO 19750) (T_DOUBLE_CAST 27) (T_ECHO 19751) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19752) (T_FOREACH 19753) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19754) (T_GOTO 19755) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19757) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19758) (T_START_HEREDOC 68) (T_STATIC 19759) (T_STRING 19760) (T_STRING_CAST 71) (T_SWITCH 19761) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19762) (T_UNSET 19763) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19764) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19765) (alt_if_stmt_without_else 19766) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19767) (fn 103) (foreach_statement 20437) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19768) (if_stmt_without_else 19769) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20433) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19771) ("~" 125)) 9479 (("\"" 1509) ("$" 19356) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19357) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19358) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19359) ("[" 19360) (ampersand 19361) (array_object_dereferenceable 19362) (callable_expr 19363) (callable_variable 19364) (class_constant 1533) (class_name 19365) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 20429) (fully_dereferenceable 104) (function_call 19367) (name 19368) (simple_variable 19369) (static_member 19370) (variable 19371) (variable_class_name 19372)) 9480 ((")" 20430)) 9481 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20431) (";" 19746) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19747) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19748) (T_DEC 22) (T_DECLARE 19749) (T_DIR 24) (T_DNUMBER 25) (T_DO 19750) (T_DOUBLE_CAST 27) (T_ECHO 19751) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19752) (T_FOREACH 19753) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19754) (T_GOTO 19755) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19757) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19758) (T_START_HEREDOC 68) (T_STATIC 19759) (T_STRING 19760) (T_STRING_CAST 71) (T_SWITCH 19761) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19762) (T_UNSET 19763) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19764) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19765) (alt_if_stmt_without_else 19766) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19767) (fn 103) (foreach_statement 20432) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19768) (if_stmt_without_else 19769) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20433) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19771) ("~" 125)) 9482 ((inner_statement_list 20434)) 9483 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19390) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19391) (T_CLASS 19392) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19393) (T_DEC 22) (T_DECLARE 19394) (T_DIR 24) (T_DNUMBER 25) (T_DO 19395) (T_DOUBLE_CAST 27) (T_ECHO 19396) (T_EMPTY 29) (T_ENDFOREACH 20435) (T_ENUM 19398) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19399) (T_FOREACH 19400) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19401) (T_GOTO 19402) (T_HALT_COMPILER 19403) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19405) (T_INTERFACE 19406) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19407) (T_START_HEREDOC 68) (T_STATIC 19408) (T_STRING 19409) (T_STRING_CAST 71) (T_SWITCH 19410) (T_THROW 73) (T_TRAIT 19411) (T_TRAIT_C 75) (T_TRY 19412) (T_UNSET 19413) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19414) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19415) (alt_if_stmt_without_else 19416) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19417) (attributes 19418) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19419) (class_modifier 96) (class_modifiers 19420) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19421) (expr 19422) (fn 103) (fully_dereferenceable 104) #'19423 (function_call 106) (function_declaration_statement 19424) (if_stmt 19425) (if_stmt_without_else 19426) (inline_function 110) (inner_statement 19427) (interface_declaration_statement 19428) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19429) (static_member 119) (trait_declaration_statement 19430) (variable 122) (variable_class_name 123) ("{" 19431) ("~" 125)) 9484 ((";" 20436)) 9485 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 20439) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 9486 ((";" 20440)) 9487 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 20441) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 9488 ((";" 20442)) 9489 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 19558) (fn 2394) (for_exprs 20443) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (non_empty_for_exprs 19560) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 9490 ((")" 20444)) 9491 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20445) (";" 19746) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19747) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19748) (T_DEC 22) (T_DECLARE 19749) (T_DIR 24) (T_DNUMBER 25) (T_DO 19750) (T_DOUBLE_CAST 27) (T_ECHO 19751) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19752) (T_FOREACH 19753) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19754) (T_GOTO 19755) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19757) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19758) (T_START_HEREDOC 68) (T_STATIC 19759) (T_STRING 19760) (T_STRING_CAST 71) (T_SWITCH 19761) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19762) (T_UNSET 19763) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19764) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19765) (alt_if_stmt_without_else 19766) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19767) (fn 103) (for_statement 20446) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19768) (if_stmt_without_else 19769) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20447) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19771) ("~" 125)) 9492 ((inner_statement_list 20448)) 9493 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19568) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19569) (T_CLASS 19570) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19571) (T_DEC 22) (T_DECLARE 19572) (T_DIR 24) (T_DNUMBER 25) (T_DO 19573) (T_DOUBLE_CAST 27) (T_ECHO 19574) (T_EMPTY 29) (T_ENDFOR 20449) (T_ENUM 19576) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19577) (T_FOREACH 19578) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19579) (T_GOTO 19580) (T_HALT_COMPILER 19581) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19583) (T_INTERFACE 19584) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19585) (T_START_HEREDOC 68) (T_STATIC 19586) (T_STRING 19587) (T_STRING_CAST 71) (T_SWITCH 19588) (T_THROW 73) (T_TRAIT 19589) (T_TRAIT_C 75) (T_TRY 19590) (T_UNSET 19591) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19592) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19593) (alt_if_stmt_without_else 19594) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19595) (attributes 19596) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19597) (class_modifier 96) (class_modifiers 19598) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19599) (expr 19600) (fn 103) (fully_dereferenceable 104) #'19601 (function_call 106) (function_declaration_statement 19602) (if_stmt 19603) (if_stmt_without_else 19604) (inline_function 110) (inner_statement 19605) (interface_declaration_statement 19606) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19607) (static_member 119) (trait_declaration_statement 19608) (variable 122) (variable_class_name 123) ("{" 19609) ("~" 125)) 9494 ((";" 20450)) 9495 (("," 19743) (";" 20452)) 9496 ((T_WHILE 20454)) 9497 (("(" 20455)) 9498 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 20456) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 9499 (("%" 292) (")" 20457) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 9500 ((";" 20458)) 9501 ((T_STRING 19916) (const_decl 19917) (const_list 20460)) 9502 ((")" 20461) ("," 19920)) 9503 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20462) (";" 19746) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19747) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19748) (T_DEC 22) (T_DECLARE 19749) (T_DIR 24) (T_DNUMBER 25) (T_DO 19750) (T_DOUBLE_CAST 27) (T_ECHO 19751) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19752) (T_FOREACH 19753) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19754) (T_GOTO 19755) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19757) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19758) (T_START_HEREDOC 68) (T_STATIC 19759) (T_STRING 19760) (T_STRING_CAST 71) (T_SWITCH 19761) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19762) (T_UNSET 19763) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19764) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19765) (alt_if_stmt_without_else 19766) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (declare_statement 20463) (dereferenceable_scalar 100) (expr 19767) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19768) (if_stmt_without_else 19769) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20464) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19771) ("~" 125)) 9504 ((inner_statement_list 20465)) 9505 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19926) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19927) (T_CLASS 19928) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19929) (T_DEC 22) (T_DECLARE 19930) (T_DIR 24) (T_DNUMBER 25) (T_DO 19931) (T_DOUBLE_CAST 27) (T_ECHO 19932) (T_EMPTY 29) (T_ENDDECLARE 20466) (T_ENUM 19934) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19935) (T_FOREACH 19936) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19937) (T_GOTO 19938) (T_HALT_COMPILER 19939) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19941) (T_INTERFACE 19942) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19943) (T_START_HEREDOC 68) (T_STATIC 19944) (T_STRING 19945) (T_STRING_CAST 71) (T_SWITCH 19946) (T_THROW 73) (T_TRAIT 19947) (T_TRAIT_C 75) (T_TRY 19948) (T_UNSET 19949) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19950) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19951) (alt_if_stmt_without_else 19952) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19953) (attributes 19954) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19955) (class_modifier 96) (class_modifiers 19956) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19957) (expr 19958) (fn 103) (fully_dereferenceable 104) #'19959 (function_call 106) (function_declaration_statement 19960) (if_stmt 19961) (if_stmt_without_else 19962) (inline_function 110) (inner_statement 19963) (interface_declaration_statement 19964) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19965) (static_member 119) (trait_declaration_statement 19966) (variable 122) (variable_class_name 123) ("{" 19967) ("~" 125)) 9506 ((";" 20467)) 9507 ((";" 20469)) 9508 ((";" 20471)) 9509 ((T_STRING 19916) (const_decl 19917) (const_list 20473)) 9510 ((")" 20474) ("," 19920)) 9511 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20475) (";" 19617) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19618) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19619) (T_DEC 22) (T_DECLARE 19620) (T_DIR 24) (T_DNUMBER 25) (T_DO 19621) (T_DOUBLE_CAST 27) (T_ECHO 19622) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19623) (T_FOREACH 19624) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19625) (T_GOTO 19626) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19627) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19628) (T_START_HEREDOC 68) (T_STATIC 19629) (T_STRING 19630) (T_STRING_CAST 71) (T_SWITCH 19631) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19632) (T_UNSET 19633) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19634) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19635) (alt_if_stmt_without_else 19636) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (declare_statement 20476) (dereferenceable_scalar 100) (expr 19637) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19638) (if_stmt_without_else 19639) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20477) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19641) ("~" 125)) 9512 ((inner_statement_list 20478)) 9513 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19926) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19927) (T_CLASS 19928) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19929) (T_DEC 22) (T_DECLARE 19930) (T_DIR 24) (T_DNUMBER 25) (T_DO 19931) (T_DOUBLE_CAST 27) (T_ECHO 19932) (T_EMPTY 29) (T_ENDDECLARE 20479) (T_ENUM 19934) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19935) (T_FOREACH 19936) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19937) (T_GOTO 19938) (T_HALT_COMPILER 19939) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19941) (T_INTERFACE 19942) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19943) (T_START_HEREDOC 68) (T_STATIC 19944) (T_STRING 19945) (T_STRING_CAST 71) (T_SWITCH 19946) (T_THROW 73) (T_TRAIT 19947) (T_TRAIT_C 75) (T_TRY 19948) (T_UNSET 19949) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19950) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19951) (alt_if_stmt_without_else 19952) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19953) (attributes 19954) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19955) (class_modifier 96) (class_modifiers 19956) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19957) (expr 19958) (fn 103) (fully_dereferenceable 104) #'19959 (function_call 106) (function_declaration_statement 19960) (if_stmt 19961) (if_stmt_without_else 19962) (inline_function 110) (inner_statement 19963) (interface_declaration_statement 19964) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19965) (static_member 119) (trait_declaration_statement 19966) (variable 122) (variable_class_name 123) ("{" 19967) ("~" 125)) 9514 ((";" 20480)) 9515 ((";" 20482)) 9516 ((";" 20484)) 9517 ((T_READONLY 16265) (T_STRING 16266) (backup_doc_comment 139) (function_name 20487)) 9518 ((backup_doc_comment 20488)) 9519 (("(" 20489)) 9520 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 20490)) 9521 ((")" 20491)) 9522 ((":" 161) (return_type 20492)) 9523 ((backup_fn_flags 20493)) 9524 (("{" 20494)) 9525 ((inner_statement_list 20495)) 9526 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 20496) ("~" 125)) 9527 ((backup_fn_flags 20497)) 9528 ((T_STRING 20500)) 9529 ((T_EXTENDS 2985) (extends_from 20501)) 9530 ((T_IMPLEMENTS 2987) (implements_list 20502)) 9531 ((backup_doc_comment 20503)) 9532 (("{" 20504)) 9533 ((class_statement_list 20505)) 9534 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 20506)) 9535 ((":" 20511)) 9536 ((";" 20510)) 9537 ((inner_statement_list 20512)) 9538 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16298) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16299) (T_CLASS 16300) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16301) (T_DEC 22) (T_DECLARE 16302) (T_DIR 24) (T_DNUMBER 25) (T_DO 16303) (T_DOUBLE_CAST 27) (T_ECHO 16304) (T_EMPTY 29) (T_ENDIF 20513) (T_ENUM 16306) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16307) (T_FOREACH 16308) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16309) (T_GOTO 16310) (T_HALT_COMPILER 16311) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16312) (T_INTERFACE 16313) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16314) (T_START_HEREDOC 68) (T_STATIC 16315) (T_STRING 16316) (T_STRING_CAST 71) (T_SWITCH 16317) (T_THROW 73) (T_TRAIT 16318) (T_TRAIT_C 75) (T_TRY 16319) (T_UNSET 16320) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16321) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16322) (alt_if_stmt_without_else 16323) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16324) (attributes 16325) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16326) (class_modifier 96) (class_modifiers 16327) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16328) (expr 16329) (fn 103) (fully_dereferenceable 104) #'16330 (function_call 106) (function_declaration_statement 16331) (if_stmt 16332) (if_stmt_without_else 16333) (inline_function 110) (inner_statement 16334) (interface_declaration_statement 16335) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16336) (static_member 119) (trait_declaration_statement 16337) (variable 122) (variable_class_name 123) ("{" 16338) ("~" 125)) 9539 ((";" 20514)) 9540 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 20516) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 9541 (("%" 292) (")" 20517) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 9542 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20518) (";" 19568) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19569) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19571) (T_DEC 22) (T_DECLARE 19572) (T_DIR 24) (T_DNUMBER 25) (T_DO 19573) (T_DOUBLE_CAST 27) (T_ECHO 19574) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19577) (T_FOREACH 19578) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19579) (T_GOTO 19580) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19583) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19585) (T_START_HEREDOC 68) (T_STATIC 19586) (T_STRING 19587) (T_STRING_CAST 71) (T_SWITCH 19588) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19590) (T_UNSET 19591) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19592) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19593) (alt_if_stmt_without_else 19594) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19600) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19603) (if_stmt_without_else 19604) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20519) (static_member 119) (variable 122) (variable_class_name 123) (while_statement 20520) ("{" 19609) ("~" 125)) 9543 ((inner_statement_list 20521)) 9544 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16379) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16380) (T_CLASS 16381) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16382) (T_DEC 22) (T_DECLARE 16383) (T_DIR 24) (T_DNUMBER 25) (T_DO 16384) (T_DOUBLE_CAST 27) (T_ECHO 16385) (T_EMPTY 29) (T_ENDWHILE 20522) (T_ENUM 16387) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16388) (T_FOREACH 16389) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16390) (T_GOTO 16391) (T_HALT_COMPILER 16392) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16394) (T_INTERFACE 16395) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16396) (T_START_HEREDOC 68) (T_STATIC 16397) (T_STRING 16398) (T_STRING_CAST 71) (T_SWITCH 16399) (T_THROW 73) (T_TRAIT 16400) (T_TRAIT_C 75) (T_TRY 16401) (T_UNSET 16402) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16403) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16404) (alt_if_stmt_without_else 16405) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16406) (attributes 16407) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16408) (class_modifier 96) (class_modifiers 16409) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16410) (expr 16411) (fn 103) (fully_dereferenceable 104) #'16412 (function_call 106) (function_declaration_statement 16413) (if_stmt 16414) (if_stmt_without_else 16415) (inline_function 110) (inner_statement 16416) (interface_declaration_statement 16417) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16418) (static_member 119) (trait_declaration_statement 16419) (variable 122) (variable_class_name 123) ("{" 16420) ("~" 125)) 9545 ((";" 20523)) 9546 (("\"" 1509) ("$" 16475) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 16476) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 16477) ("[" 1529) (array_object_dereferenceable 16478) (callable_expr 16479) (callable_variable 16480) (class_constant 1533) (class_name 16481) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 16482) (name 16483) (simple_variable 16484) (static_member 16485) (unset_variable 16486) (unset_variables 20525) (variable 16488) (variable_class_name 16489)) 9547 (("," 16501) (possible_comma 20526)) 9548 ((")" 20527)) 9549 ((";" 20528)) 9550 ((inner_statement_list 20530)) 9551 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 20531) ("~" 125)) 9552 ((catch_list 20532)) 9553 ((T_CATCH 20533) (T_FINALLY 20534) (finally_statement 20535)) 9554 (("(" 20539)) 9555 (("{" 20536)) 9556 ((inner_statement_list 20537)) 9557 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 20538) ("~" 125)) 9558 ((T_NAME_FULLY_QUALIFIED 16545) (T_NAME_QUALIFIED 16546) (T_NAME_RELATIVE 16547) (T_STATIC 16548) (T_STRING 16549) (catch_name_list 20540) (class_name 16551) (name 16552)) 9559 ((T_VARIABLE 16553) (optional_variable 20541) ("|" 16555)) 9560 ((")" 20542)) 9561 (("{" 20543)) 9562 ((inner_statement_list 20544)) 9563 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 20545) ("~" 125)) 9564 ((backup_doc_comment 20547)) 9565 (("{" 20548)) 9566 ((class_statement_list 20549)) 9567 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 20550)) 9568 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 20552) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 9569 (("%" 292) (")" 20553) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 9570 ((":" 20554) (switch_case_list 20555) ("{" 20556)) 9571 ((";" 20562) (case_list 20563)) 9572 ((";" 20557) (case_list 20558)) 9573 ((case_list 20560)) 9574 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 20559)) 9575 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 20561)) 9576 ((case_list 20566)) 9577 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 20564)) 9578 ((";" 20565)) 9579 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 20567)) 9580 ((";" 20568)) 9581 (("," 16852) (";" 20571)) 9582 ((";" 20573)) 9583 ((T_EXTENDS 20209) (interface_extends_list 20575)) 9584 ((backup_doc_comment 20576)) 9585 (("{" 20577)) 9586 ((class_statement_list 20578)) 9587 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 20579)) 9588 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 20581) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 9589 (("%" 292) (")" 20582) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 9590 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20219) (";" 19617) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19618) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19619) (T_DEC 22) (T_DECLARE 19620) (T_DIR 24) (T_DNUMBER 25) (T_DO 19621) (T_DOUBLE_CAST 27) (T_ECHO 19622) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19623) (T_FOREACH 19624) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19625) (T_GOTO 19626) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19627) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19628) (T_START_HEREDOC 68) (T_STATIC 19629) (T_STRING 19630) (T_STRING_CAST 71) (T_SWITCH 19631) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19632) (T_UNSET 19633) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19634) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19635) (alt_if_stmt_without_else 19636) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19637) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19638) (if_stmt_without_else 19639) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20583) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19641) ("~" 125)) 9591 ((")" 20585)) 9592 ((";" 20586)) 9593 ((";" 20588)) 9594 (("," 17875) (";" 20590)) 9595 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 20592) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 9596 (("%" 17961) ("*" 17962) ("+" 17963) ("-" 17964) ("." 17965) ("/" 17966) ("<" 17967) (">" 17968) ("?" 17969) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 17970) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 17971) (T_AS 20593) (T_BOOLEAN_AND 17972) (T_BOOLEAN_OR 17973) (T_COALESCE 17974) (T_INSTANCEOF 17975) (T_IS_EQUAL 17976) (T_IS_GREATER_OR_EQUAL 17977) (T_IS_IDENTICAL 17978) (T_IS_NOT_EQUAL 17979) (T_IS_NOT_IDENTICAL 17980) (T_IS_SMALLER_OR_EQUAL 17981) (T_LOGICAL_AND 17982) (T_LOGICAL_OR 17983) (T_LOGICAL_XOR 17984) (T_POW 17985) (T_SL 17986) (T_SPACESHIP 17987) (T_SR 17988) ("^" 17989) ("|" 17990)) 9597 (("\"" 1509) ("$" 19325) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19326) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19327) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19328) ("[" 19329) (ampersand 19330) (array_object_dereferenceable 19331) (callable_expr 19332) (callable_variable 19333) (class_constant 1533) (class_name 19334) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 20594) (fully_dereferenceable 104) (function_call 19336) (name 19337) (simple_variable 19338) (static_member 19339) (variable 19340) (variable_class_name 19341)) 9598 ((")" 20595) (T_DOUBLE_ARROW 20596)) 9599 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20599) (";" 19568) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19569) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19571) (T_DEC 22) (T_DECLARE 19572) (T_DIR 24) (T_DNUMBER 25) (T_DO 19573) (T_DOUBLE_CAST 27) (T_ECHO 19574) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19577) (T_FOREACH 19578) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19579) (T_GOTO 19580) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19583) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19585) (T_START_HEREDOC 68) (T_STATIC 19586) (T_STRING 19587) (T_STRING_CAST 71) (T_SWITCH 19588) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19590) (T_UNSET 19591) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19592) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19593) (alt_if_stmt_without_else 19594) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19600) (fn 103) (foreach_statement 20605) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19603) (if_stmt_without_else 19604) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20601) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19609) ("~" 125)) 9600 (("\"" 1509) ("$" 19356) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19357) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19358) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19359) ("[" 19360) (ampersand 19361) (array_object_dereferenceable 19362) (callable_expr 19363) (callable_variable 19364) (class_constant 1533) (class_name 19365) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 20597) (fully_dereferenceable 104) (function_call 19367) (name 19368) (simple_variable 19369) (static_member 19370) (variable 19371) (variable_class_name 19372)) 9601 ((")" 20598)) 9602 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20599) (";" 19568) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19569) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19571) (T_DEC 22) (T_DECLARE 19572) (T_DIR 24) (T_DNUMBER 25) (T_DO 19573) (T_DOUBLE_CAST 27) (T_ECHO 19574) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19577) (T_FOREACH 19578) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19579) (T_GOTO 19580) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19583) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19585) (T_START_HEREDOC 68) (T_STATIC 19586) (T_STRING 19587) (T_STRING_CAST 71) (T_SWITCH 19588) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19590) (T_UNSET 19591) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19592) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19593) (alt_if_stmt_without_else 19594) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19600) (fn 103) (foreach_statement 20600) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19603) (if_stmt_without_else 19604) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20601) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19609) ("~" 125)) 9603 ((inner_statement_list 20602)) 9604 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19390) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19391) (T_CLASS 19392) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19393) (T_DEC 22) (T_DECLARE 19394) (T_DIR 24) (T_DNUMBER 25) (T_DO 19395) (T_DOUBLE_CAST 27) (T_ECHO 19396) (T_EMPTY 29) (T_ENDFOREACH 20603) (T_ENUM 19398) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19399) (T_FOREACH 19400) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19401) (T_GOTO 19402) (T_HALT_COMPILER 19403) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19405) (T_INTERFACE 19406) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19407) (T_START_HEREDOC 68) (T_STATIC 19408) (T_STRING 19409) (T_STRING_CAST 71) (T_SWITCH 19410) (T_THROW 73) (T_TRAIT 19411) (T_TRAIT_C 75) (T_TRY 19412) (T_UNSET 19413) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19414) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19415) (alt_if_stmt_without_else 19416) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19417) (attributes 19418) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19419) (class_modifier 96) (class_modifiers 19420) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19421) (expr 19422) (fn 103) (fully_dereferenceable 104) #'19423 (function_call 106) (function_declaration_statement 19424) (if_stmt 19425) (if_stmt_without_else 19426) (inline_function 110) (inner_statement 19427) (interface_declaration_statement 19428) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19429) (static_member 119) (trait_declaration_statement 19430) (variable 122) (variable_class_name 123) ("{" 19431) ("~" 125)) 9605 ((";" 20604)) 9606 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 20607) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 9607 ((";" 20608)) 9608 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 20609) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 9609 ((";" 20610)) 9610 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 19558) (fn 2394) (for_exprs 20611) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (non_empty_for_exprs 19560) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 9611 ((")" 20612)) 9612 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20613) (";" 19568) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19569) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19571) (T_DEC 22) (T_DECLARE 19572) (T_DIR 24) (T_DNUMBER 25) (T_DO 19573) (T_DOUBLE_CAST 27) (T_ECHO 19574) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19577) (T_FOREACH 19578) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19579) (T_GOTO 19580) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19583) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19585) (T_START_HEREDOC 68) (T_STATIC 19586) (T_STRING 19587) (T_STRING_CAST 71) (T_SWITCH 19588) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19590) (T_UNSET 19591) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19592) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19593) (alt_if_stmt_without_else 19594) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19600) (fn 103) (for_statement 20614) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19603) (if_stmt_without_else 19604) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20615) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19609) ("~" 125)) 9613 ((inner_statement_list 20616)) 9614 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19568) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19569) (T_CLASS 19570) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19571) (T_DEC 22) (T_DECLARE 19572) (T_DIR 24) (T_DNUMBER 25) (T_DO 19573) (T_DOUBLE_CAST 27) (T_ECHO 19574) (T_EMPTY 29) (T_ENDFOR 20617) (T_ENUM 19576) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19577) (T_FOREACH 19578) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19579) (T_GOTO 19580) (T_HALT_COMPILER 19581) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19583) (T_INTERFACE 19584) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19585) (T_START_HEREDOC 68) (T_STATIC 19586) (T_STRING 19587) (T_STRING_CAST 71) (T_SWITCH 19588) (T_THROW 73) (T_TRAIT 19589) (T_TRAIT_C 75) (T_TRY 19590) (T_UNSET 19591) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19592) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19593) (alt_if_stmt_without_else 19594) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19595) (attributes 19596) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19597) (class_modifier 96) (class_modifiers 19598) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19599) (expr 19600) (fn 103) (fully_dereferenceable 104) #'19601 (function_call 106) (function_declaration_statement 19602) (if_stmt 19603) (if_stmt_without_else 19604) (inline_function 110) (inner_statement 19605) (interface_declaration_statement 19606) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19607) (static_member 119) (trait_declaration_statement 19608) (variable 122) (variable_class_name 123) ("{" 19609) ("~" 125)) 9615 ((";" 20618)) 9616 ((":" 20258) (enum_backing_type 20620)) 9617 ((T_IMPLEMENTS 2987) (implements_list 20621)) 9618 ((backup_doc_comment 20622)) 9619 (("{" 20623)) 9620 ((class_statement_list 20624)) 9621 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 20625)) 9622 (("," 19743) (";" 20628)) 9623 ((T_WHILE 20630)) 9624 (("(" 20631)) 9625 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 20632) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 9626 (("%" 292) (")" 20633) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 9627 ((";" 20634)) 9628 ((T_STRING 19916) (const_decl 19917) (const_list 20636)) 9629 ((")" 20637) ("," 19920)) 9630 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20638) (";" 19568) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19569) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19571) (T_DEC 22) (T_DECLARE 19572) (T_DIR 24) (T_DNUMBER 25) (T_DO 19573) (T_DOUBLE_CAST 27) (T_ECHO 19574) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19577) (T_FOREACH 19578) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19579) (T_GOTO 19580) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19583) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19585) (T_START_HEREDOC 68) (T_STATIC 19586) (T_STRING 19587) (T_STRING_CAST 71) (T_SWITCH 19588) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19590) (T_UNSET 19591) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19592) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19593) (alt_if_stmt_without_else 19594) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (declare_statement 20639) (dereferenceable_scalar 100) (expr 19600) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19603) (if_stmt_without_else 19604) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20640) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19609) ("~" 125)) 9631 ((inner_statement_list 20641)) 9632 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19926) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19927) (T_CLASS 19928) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19929) (T_DEC 22) (T_DECLARE 19930) (T_DIR 24) (T_DNUMBER 25) (T_DO 19931) (T_DOUBLE_CAST 27) (T_ECHO 19932) (T_EMPTY 29) (T_ENDDECLARE 20642) (T_ENUM 19934) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19935) (T_FOREACH 19936) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19937) (T_GOTO 19938) (T_HALT_COMPILER 19939) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19941) (T_INTERFACE 19942) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19943) (T_START_HEREDOC 68) (T_STATIC 19944) (T_STRING 19945) (T_STRING_CAST 71) (T_SWITCH 19946) (T_THROW 73) (T_TRAIT 19947) (T_TRAIT_C 75) (T_TRY 19948) (T_UNSET 19949) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19950) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19951) (alt_if_stmt_without_else 19952) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19953) (attributes 19954) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19955) (class_modifier 96) (class_modifiers 19956) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19957) (expr 19958) (fn 103) (fully_dereferenceable 104) #'19959 (function_call 106) (function_declaration_statement 19960) (if_stmt 19961) (if_stmt_without_else 19962) (inline_function 110) (inner_statement 19963) (interface_declaration_statement 19964) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19965) (static_member 119) (trait_declaration_statement 19966) (variable 122) (variable_class_name 123) ("{" 19967) ("~" 125)) 9633 ((";" 20643)) 9634 ((";" 20645)) 9635 ((T_EXTENDS 2985) (extends_from 20647)) 9636 ((T_IMPLEMENTS 2987) (implements_list 20648)) 9637 ((backup_doc_comment 20649)) 9638 (("{" 20650)) 9639 ((class_statement_list 20651)) 9640 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 20652)) 9641 ((";" 20654)) 9642 (("," 19743) (";" 20656)) 9643 ((T_WHILE 20658)) 9644 (("(" 20659)) 9645 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 20660) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 9646 (("%" 292) (")" 20661) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 9647 ((";" 20662)) 9648 ((T_STRING 19916) (const_decl 19917) (const_list 20664)) 9649 ((")" 20665) ("," 19920)) 9650 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20666) (";" 19439) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19440) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19441) (T_DEC 22) (T_DECLARE 19442) (T_DIR 24) (T_DNUMBER 25) (T_DO 19443) (T_DOUBLE_CAST 27) (T_ECHO 19444) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19445) (T_FOREACH 19446) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19447) (T_GOTO 19448) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19449) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19450) (T_START_HEREDOC 68) (T_STATIC 19451) (T_STRING 19452) (T_STRING_CAST 71) (T_SWITCH 19453) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19454) (T_UNSET 19455) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19456) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19457) (alt_if_stmt_without_else 19458) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (declare_statement 20667) (dereferenceable_scalar 100) (expr 19459) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19460) (if_stmt_without_else 19461) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20668) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19463) ("~" 125)) 9651 ((inner_statement_list 20669)) 9652 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19926) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19927) (T_CLASS 19928) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19929) (T_DEC 22) (T_DECLARE 19930) (T_DIR 24) (T_DNUMBER 25) (T_DO 19931) (T_DOUBLE_CAST 27) (T_ECHO 19932) (T_EMPTY 29) (T_ENDDECLARE 20670) (T_ENUM 19934) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19935) (T_FOREACH 19936) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19937) (T_GOTO 19938) (T_HALT_COMPILER 19939) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19941) (T_INTERFACE 19942) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19943) (T_START_HEREDOC 68) (T_STATIC 19944) (T_STRING 19945) (T_STRING_CAST 71) (T_SWITCH 19946) (T_THROW 73) (T_TRAIT 19947) (T_TRAIT_C 75) (T_TRY 19948) (T_UNSET 19949) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19950) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19951) (alt_if_stmt_without_else 19952) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19953) (attributes 19954) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19955) (class_modifier 96) (class_modifiers 19956) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19957) (expr 19958) (fn 103) (fully_dereferenceable 104) #'19959 (function_call 106) (function_declaration_statement 19960) (if_stmt 19961) (if_stmt_without_else 19962) (inline_function 110) (inner_statement 19963) (interface_declaration_statement 19964) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19965) (static_member 119) (trait_declaration_statement 19966) (variable 122) (variable_class_name 123) ("{" 19967) ("~" 125)) 9653 ((";" 20671)) 9654 ((";" 20673)) 9655 ((";" 20675)) 9656 ((T_READONLY 16265) (T_STRING 16266) (backup_doc_comment 139) (function_name 20678)) 9657 ((backup_doc_comment 20679)) 9658 (("(" 20680)) 9659 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 20681)) 9660 ((")" 20682)) 9661 ((":" 161) (return_type 20683)) 9662 ((backup_fn_flags 20684)) 9663 (("{" 20685)) 9664 ((inner_statement_list 20686)) 9665 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 20687) ("~" 125)) 9666 ((backup_fn_flags 20688)) 9667 ((T_STRING 20691)) 9668 ((T_EXTENDS 2985) (extends_from 20692)) 9669 ((T_IMPLEMENTS 2987) (implements_list 20693)) 9670 ((backup_doc_comment 20694)) 9671 (("{" 20695)) 9672 ((class_statement_list 20696)) 9673 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 20697)) 9674 ((":" 20702)) 9675 ((";" 20701)) 9676 ((inner_statement_list 20703)) 9677 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16298) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16299) (T_CLASS 16300) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16301) (T_DEC 22) (T_DECLARE 16302) (T_DIR 24) (T_DNUMBER 25) (T_DO 16303) (T_DOUBLE_CAST 27) (T_ECHO 16304) (T_EMPTY 29) (T_ENDIF 20704) (T_ENUM 16306) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16307) (T_FOREACH 16308) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16309) (T_GOTO 16310) (T_HALT_COMPILER 16311) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16312) (T_INTERFACE 16313) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16314) (T_START_HEREDOC 68) (T_STATIC 16315) (T_STRING 16316) (T_STRING_CAST 71) (T_SWITCH 16317) (T_THROW 73) (T_TRAIT 16318) (T_TRAIT_C 75) (T_TRY 16319) (T_UNSET 16320) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16321) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16322) (alt_if_stmt_without_else 16323) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16324) (attributes 16325) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16326) (class_modifier 96) (class_modifiers 16327) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16328) (expr 16329) (fn 103) (fully_dereferenceable 104) #'16330 (function_call 106) (function_declaration_statement 16331) (if_stmt 16332) (if_stmt_without_else 16333) (inline_function 110) (inner_statement 16334) (interface_declaration_statement 16335) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16336) (static_member 119) (trait_declaration_statement 16337) (variable 122) (variable_class_name 123) ("{" 16338) ("~" 125)) 9678 ((";" 20705)) 9679 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 20707) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 9680 (("%" 292) (")" 20708) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 9681 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20709) (";" 19390) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19391) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19393) (T_DEC 22) (T_DECLARE 19394) (T_DIR 24) (T_DNUMBER 25) (T_DO 19395) (T_DOUBLE_CAST 27) (T_ECHO 19396) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19399) (T_FOREACH 19400) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19401) (T_GOTO 19402) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19405) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19407) (T_START_HEREDOC 68) (T_STATIC 19408) (T_STRING 19409) (T_STRING_CAST 71) (T_SWITCH 19410) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19412) (T_UNSET 19413) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19414) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19415) (alt_if_stmt_without_else 19416) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19422) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19425) (if_stmt_without_else 19426) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20710) (static_member 119) (variable 122) (variable_class_name 123) (while_statement 20711) ("{" 19431) ("~" 125)) 9682 ((inner_statement_list 20712)) 9683 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16379) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16380) (T_CLASS 16381) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16382) (T_DEC 22) (T_DECLARE 16383) (T_DIR 24) (T_DNUMBER 25) (T_DO 16384) (T_DOUBLE_CAST 27) (T_ECHO 16385) (T_EMPTY 29) (T_ENDWHILE 20713) (T_ENUM 16387) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16388) (T_FOREACH 16389) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16390) (T_GOTO 16391) (T_HALT_COMPILER 16392) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16394) (T_INTERFACE 16395) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16396) (T_START_HEREDOC 68) (T_STATIC 16397) (T_STRING 16398) (T_STRING_CAST 71) (T_SWITCH 16399) (T_THROW 73) (T_TRAIT 16400) (T_TRAIT_C 75) (T_TRY 16401) (T_UNSET 16402) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16403) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16404) (alt_if_stmt_without_else 16405) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16406) (attributes 16407) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16408) (class_modifier 96) (class_modifiers 16409) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16410) (expr 16411) (fn 103) (fully_dereferenceable 104) #'16412 (function_call 106) (function_declaration_statement 16413) (if_stmt 16414) (if_stmt_without_else 16415) (inline_function 110) (inner_statement 16416) (interface_declaration_statement 16417) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16418) (static_member 119) (trait_declaration_statement 16419) (variable 122) (variable_class_name 123) ("{" 16420) ("~" 125)) 9684 ((";" 20714)) 9685 (("\"" 1509) ("$" 16475) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 16476) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 16477) ("[" 1529) (array_object_dereferenceable 16478) (callable_expr 16479) (callable_variable 16480) (class_constant 1533) (class_name 16481) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 16482) (name 16483) (simple_variable 16484) (static_member 16485) (unset_variable 16486) (unset_variables 20716) (variable 16488) (variable_class_name 16489)) 9686 (("," 16501) (possible_comma 20717)) 9687 ((")" 20718)) 9688 ((";" 20719)) 9689 ((inner_statement_list 20721)) 9690 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 20722) ("~" 125)) 9691 ((catch_list 20723)) 9692 ((T_CATCH 20724) (T_FINALLY 20725) (finally_statement 20726)) 9693 (("(" 20730)) 9694 (("{" 20727)) 9695 ((inner_statement_list 20728)) 9696 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 20729) ("~" 125)) 9697 ((T_NAME_FULLY_QUALIFIED 16545) (T_NAME_QUALIFIED 16546) (T_NAME_RELATIVE 16547) (T_STATIC 16548) (T_STRING 16549) (catch_name_list 20731) (class_name 16551) (name 16552)) 9698 ((T_VARIABLE 16553) (optional_variable 20732) ("|" 16555)) 9699 ((")" 20733)) 9700 (("{" 20734)) 9701 ((inner_statement_list 20735)) 9702 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 20736) ("~" 125)) 9703 ((backup_doc_comment 20738)) 9704 (("{" 20739)) 9705 ((class_statement_list 20740)) 9706 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 20741)) 9707 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 20743) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 9708 (("%" 292) (")" 20744) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 9709 ((":" 20745) (switch_case_list 20746) ("{" 20747)) 9710 ((";" 20753) (case_list 20754)) 9711 ((";" 20748) (case_list 20749)) 9712 ((case_list 20751)) 9713 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 20750)) 9714 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 20752)) 9715 ((case_list 20757)) 9716 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 20755)) 9717 ((";" 20756)) 9718 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 20758)) 9719 ((";" 20759)) 9720 (("," 16852) (";" 20762)) 9721 ((";" 20764)) 9722 ((T_EXTENDS 20209) (interface_extends_list 20766)) 9723 ((backup_doc_comment 20767)) 9724 (("{" 20768)) 9725 ((class_statement_list 20769)) 9726 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 20770)) 9727 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 20772) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 9728 (("%" 292) (")" 20773) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 9729 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20219) (";" 19439) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19440) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19441) (T_DEC 22) (T_DECLARE 19442) (T_DIR 24) (T_DNUMBER 25) (T_DO 19443) (T_DOUBLE_CAST 27) (T_ECHO 19444) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19445) (T_FOREACH 19446) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19447) (T_GOTO 19448) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19449) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19450) (T_START_HEREDOC 68) (T_STATIC 19451) (T_STRING 19452) (T_STRING_CAST 71) (T_SWITCH 19453) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19454) (T_UNSET 19455) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19456) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19457) (alt_if_stmt_without_else 19458) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19459) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19460) (if_stmt_without_else 19461) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20774) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19463) ("~" 125)) 9730 ((")" 20776)) 9731 ((";" 20777)) 9732 ((";" 20779)) 9733 (("," 17875) (";" 20781)) 9734 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 20783) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 9735 (("%" 17961) ("*" 17962) ("+" 17963) ("-" 17964) ("." 17965) ("/" 17966) ("<" 17967) (">" 17968) ("?" 17969) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 17970) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 17971) (T_AS 20784) (T_BOOLEAN_AND 17972) (T_BOOLEAN_OR 17973) (T_COALESCE 17974) (T_INSTANCEOF 17975) (T_IS_EQUAL 17976) (T_IS_GREATER_OR_EQUAL 17977) (T_IS_IDENTICAL 17978) (T_IS_NOT_EQUAL 17979) (T_IS_NOT_IDENTICAL 17980) (T_IS_SMALLER_OR_EQUAL 17981) (T_LOGICAL_AND 17982) (T_LOGICAL_OR 17983) (T_LOGICAL_XOR 17984) (T_POW 17985) (T_SL 17986) (T_SPACESHIP 17987) (T_SR 17988) ("^" 17989) ("|" 17990)) 9736 (("\"" 1509) ("$" 19325) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19326) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19327) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19328) ("[" 19329) (ampersand 19330) (array_object_dereferenceable 19331) (callable_expr 19332) (callable_variable 19333) (class_constant 1533) (class_name 19334) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 20785) (fully_dereferenceable 104) (function_call 19336) (name 19337) (simple_variable 19338) (static_member 19339) (variable 19340) (variable_class_name 19341)) 9737 ((")" 20786) (T_DOUBLE_ARROW 20787)) 9738 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20790) (";" 19390) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19391) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19393) (T_DEC 22) (T_DECLARE 19394) (T_DIR 24) (T_DNUMBER 25) (T_DO 19395) (T_DOUBLE_CAST 27) (T_ECHO 19396) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19399) (T_FOREACH 19400) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19401) (T_GOTO 19402) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19405) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19407) (T_START_HEREDOC 68) (T_STATIC 19408) (T_STRING 19409) (T_STRING_CAST 71) (T_SWITCH 19410) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19412) (T_UNSET 19413) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19414) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19415) (alt_if_stmt_without_else 19416) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19422) (fn 103) (foreach_statement 20796) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19425) (if_stmt_without_else 19426) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20792) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19431) ("~" 125)) 9739 (("\"" 1509) ("$" 19356) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19357) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19358) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19359) ("[" 19360) (ampersand 19361) (array_object_dereferenceable 19362) (callable_expr 19363) (callable_variable 19364) (class_constant 1533) (class_name 19365) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 20788) (fully_dereferenceable 104) (function_call 19367) (name 19368) (simple_variable 19369) (static_member 19370) (variable 19371) (variable_class_name 19372)) 9740 ((")" 20789)) 9741 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20790) (";" 19390) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19391) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19393) (T_DEC 22) (T_DECLARE 19394) (T_DIR 24) (T_DNUMBER 25) (T_DO 19395) (T_DOUBLE_CAST 27) (T_ECHO 19396) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19399) (T_FOREACH 19400) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19401) (T_GOTO 19402) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19405) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19407) (T_START_HEREDOC 68) (T_STATIC 19408) (T_STRING 19409) (T_STRING_CAST 71) (T_SWITCH 19410) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19412) (T_UNSET 19413) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19414) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19415) (alt_if_stmt_without_else 19416) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19422) (fn 103) (foreach_statement 20791) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19425) (if_stmt_without_else 19426) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20792) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19431) ("~" 125)) 9742 ((inner_statement_list 20793)) 9743 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19390) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19391) (T_CLASS 19392) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19393) (T_DEC 22) (T_DECLARE 19394) (T_DIR 24) (T_DNUMBER 25) (T_DO 19395) (T_DOUBLE_CAST 27) (T_ECHO 19396) (T_EMPTY 29) (T_ENDFOREACH 20794) (T_ENUM 19398) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19399) (T_FOREACH 19400) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19401) (T_GOTO 19402) (T_HALT_COMPILER 19403) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19405) (T_INTERFACE 19406) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19407) (T_START_HEREDOC 68) (T_STATIC 19408) (T_STRING 19409) (T_STRING_CAST 71) (T_SWITCH 19410) (T_THROW 73) (T_TRAIT 19411) (T_TRAIT_C 75) (T_TRY 19412) (T_UNSET 19413) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19414) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19415) (alt_if_stmt_without_else 19416) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19417) (attributes 19418) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19419) (class_modifier 96) (class_modifiers 19420) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19421) (expr 19422) (fn 103) (fully_dereferenceable 104) #'19423 (function_call 106) (function_declaration_statement 19424) (if_stmt 19425) (if_stmt_without_else 19426) (inline_function 110) (inner_statement 19427) (interface_declaration_statement 19428) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19429) (static_member 119) (trait_declaration_statement 19430) (variable 122) (variable_class_name 123) ("{" 19431) ("~" 125)) 9744 ((";" 20795)) 9745 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 20798) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 9746 ((";" 20799)) 9747 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 20800) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 9748 ((";" 20801)) 9749 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 19558) (fn 2394) (for_exprs 20802) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (non_empty_for_exprs 19560) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 9750 ((")" 20803)) 9751 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20804) (";" 19390) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19391) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19393) (T_DEC 22) (T_DECLARE 19394) (T_DIR 24) (T_DNUMBER 25) (T_DO 19395) (T_DOUBLE_CAST 27) (T_ECHO 19396) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19399) (T_FOREACH 19400) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19401) (T_GOTO 19402) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19405) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19407) (T_START_HEREDOC 68) (T_STATIC 19408) (T_STRING 19409) (T_STRING_CAST 71) (T_SWITCH 19410) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19412) (T_UNSET 19413) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19414) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19415) (alt_if_stmt_without_else 19416) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19422) (fn 103) (for_statement 20805) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19425) (if_stmt_without_else 19426) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20806) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19431) ("~" 125)) 9752 ((inner_statement_list 20807)) 9753 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19568) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19569) (T_CLASS 19570) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19571) (T_DEC 22) (T_DECLARE 19572) (T_DIR 24) (T_DNUMBER 25) (T_DO 19573) (T_DOUBLE_CAST 27) (T_ECHO 19574) (T_EMPTY 29) (T_ENDFOR 20808) (T_ENUM 19576) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19577) (T_FOREACH 19578) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19579) (T_GOTO 19580) (T_HALT_COMPILER 19581) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19583) (T_INTERFACE 19584) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19585) (T_START_HEREDOC 68) (T_STATIC 19586) (T_STRING 19587) (T_STRING_CAST 71) (T_SWITCH 19588) (T_THROW 73) (T_TRAIT 19589) (T_TRAIT_C 75) (T_TRY 19590) (T_UNSET 19591) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19592) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19593) (alt_if_stmt_without_else 19594) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19595) (attributes 19596) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19597) (class_modifier 96) (class_modifiers 19598) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19599) (expr 19600) (fn 103) (fully_dereferenceable 104) #'19601 (function_call 106) (function_declaration_statement 19602) (if_stmt 19603) (if_stmt_without_else 19604) (inline_function 110) (inner_statement 19605) (interface_declaration_statement 19606) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19607) (static_member 119) (trait_declaration_statement 19608) (variable 122) (variable_class_name 123) ("{" 19609) ("~" 125)) 9754 ((";" 20809)) 9755 ((":" 20258) (enum_backing_type 20811)) 9756 ((T_IMPLEMENTS 2987) (implements_list 20812)) 9757 ((backup_doc_comment 20813)) 9758 (("{" 20814)) 9759 ((class_statement_list 20815)) 9760 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 20816)) 9761 (("," 19743) (";" 20819)) 9762 ((T_WHILE 20821)) 9763 (("(" 20822)) 9764 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 20823) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 9765 (("%" 292) (")" 20824) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 9766 ((";" 20825)) 9767 ((T_STRING 19916) (const_decl 19917) (const_list 20827)) 9768 ((")" 20828) ("," 19920)) 9769 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20829) (";" 19390) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19391) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19393) (T_DEC 22) (T_DECLARE 19394) (T_DIR 24) (T_DNUMBER 25) (T_DO 19395) (T_DOUBLE_CAST 27) (T_ECHO 19396) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19399) (T_FOREACH 19400) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19401) (T_GOTO 19402) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19405) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19407) (T_START_HEREDOC 68) (T_STATIC 19408) (T_STRING 19409) (T_STRING_CAST 71) (T_SWITCH 19410) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19412) (T_UNSET 19413) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19414) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19415) (alt_if_stmt_without_else 19416) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (declare_statement 20830) (dereferenceable_scalar 100) (expr 19422) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19425) (if_stmt_without_else 19426) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 20831) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19431) ("~" 125)) 9770 ((inner_statement_list 20832)) 9771 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19926) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19927) (T_CLASS 19928) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19929) (T_DEC 22) (T_DECLARE 19930) (T_DIR 24) (T_DNUMBER 25) (T_DO 19931) (T_DOUBLE_CAST 27) (T_ECHO 19932) (T_EMPTY 29) (T_ENDDECLARE 20833) (T_ENUM 19934) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19935) (T_FOREACH 19936) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19937) (T_GOTO 19938) (T_HALT_COMPILER 19939) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19941) (T_INTERFACE 19942) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19943) (T_START_HEREDOC 68) (T_STATIC 19944) (T_STRING 19945) (T_STRING_CAST 71) (T_SWITCH 19946) (T_THROW 73) (T_TRAIT 19947) (T_TRAIT_C 75) (T_TRY 19948) (T_UNSET 19949) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19950) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19951) (alt_if_stmt_without_else 19952) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19953) (attributes 19954) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19955) (class_modifier 96) (class_modifiers 19956) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19957) (expr 19958) (fn 103) (fully_dereferenceable 104) #'19959 (function_call 106) (function_declaration_statement 19960) (if_stmt 19961) (if_stmt_without_else 19962) (inline_function 110) (inner_statement 19963) (interface_declaration_statement 19964) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19965) (static_member 119) (trait_declaration_statement 19966) (variable 122) (variable_class_name 123) ("{" 19967) ("~" 125)) 9772 ((";" 20834)) 9773 ((";" 20836)) 9774 ((T_EXTENDS 2985) (extends_from 20838)) 9775 ((T_IMPLEMENTS 2987) (implements_list 20839)) 9776 ((backup_doc_comment 20840)) 9777 (("{" 20841)) 9778 ((class_statement_list 20842)) 9779 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 20843)) 9780 ((";" 20845)) 9781 (("$" 19356) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 19359) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 20847) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 20848) ("{" 1643)) 9782 (("(" 19376) (argument_list 20849)) 9783 (("$" 19356) (T_STRING 20859) (T_VARIABLE 19359) (property_name 20866) (simple_variable 20861) ("{" 20862)) 9784 (("$" 19356) (T_STRING 20859) (T_VARIABLE 19359) (property_name 20860) (simple_variable 20861) ("{" 20862)) 9785 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 20857) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 9786 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 20855) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 9787 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 20856)) 9788 (("]" 20858)) 9789 (("(" 19376) (argument_list 20865)) 9790 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 20863) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 9791 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 20864)) 9792 (("(" 19376) (argument_list 20867)) 9793 (("]" 20870)) 9794 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 20873) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 9795 ((")" 20874)) 9796 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 20877) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 9797 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 20878)) 9798 (("$" 19325) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 19328) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 20881) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 20882) ("{" 1643)) 9799 (("(" 19345) (argument_list 20883)) 9800 (("$" 19325) (T_STRING 20893) (T_VARIABLE 19328) (property_name 20900) (simple_variable 20895) ("{" 20896)) 9801 (("$" 19325) (T_STRING 20893) (T_VARIABLE 19328) (property_name 20894) (simple_variable 20895) ("{" 20896)) 9802 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 20891) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 9803 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 20889) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 9804 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 20890)) 9805 (("]" 20892)) 9806 (("(" 19345) (argument_list 20899)) 9807 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 20897) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 9808 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 20898)) 9809 (("(" 19345) (argument_list 20901)) 9810 (("]" 20904)) 9811 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 20907) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 9812 ((")" 20908)) 9813 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 20911) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 9814 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 20912)) 9815 (("$" 17885) (T_ABSTRACT 18063) (T_ARRAY 18064) (T_AS 18065) (T_BREAK 18066) (T_CALLABLE 18067) (T_CASE 18068) (T_CATCH 18069) (T_CLASS 18070) (T_CLASS_C 18071) (T_CLONE 18072) (T_CONST 18073) (T_CONTINUE 18074) (T_DECLARE 18075) (T_DEFAULT 18076) (T_DIR 18077) (T_DO 18078) (T_ECHO 18079) (T_ELSE 18080) (T_ELSEIF 18081) (T_EMPTY 18082) (T_ENDDECLARE 18083) (T_ENDFOR 18084) (T_ENDFOREACH 18085) (T_ENDIF 18086) (T_ENDSWITCH 18087) (T_ENDWHILE 18088) (T_ENUM 18089) (T_EVAL 18090) (T_EXIT 18091) (T_EXTENDS 18092) (T_FILE 18093) (T_FINAL 18094) (T_FINALLY 18095) (T_FN 18096) (T_FOR 18097) (T_FOREACH 18098) (T_FUNCTION 18099) (T_FUNC_C 18100) (T_GLOBAL 18101) (T_GOTO 18102) (T_IF 18103) (T_IMPLEMENTS 18104) (T_INCLUDE 18105) (T_INCLUDE_ONCE 18106) (T_INSTANCEOF 18107) (T_INSTEADOF 18108) (T_INTERFACE 18109) (T_ISSET 18110) (T_LINE 18111) (T_LIST 18112) (T_LOGICAL_AND 18113) (T_LOGICAL_OR 18114) (T_LOGICAL_XOR 18115) (T_MATCH 18116) (T_METHOD_C 18117) (T_NAMESPACE 18118) (T_NEW 18119) (T_NS_C 18120) (T_PRINT 18121) (T_PRIVATE 18122) (T_PROTECTED 18123) (T_PUBLIC 18124) (T_READONLY 18125) (T_REQUIRE 18126) (T_REQUIRE_ONCE 18127) (T_RETURN 18128) (T_STATIC 18129) (T_STRING 18130) (T_SWITCH 18131) (T_THROW 18132) (T_TRAIT 18133) (T_TRAIT_C 18134) (T_TRY 18135) (T_UNSET 18136) (T_USE 18137) (T_VAR 18138) (T_VARIABLE 17932) (T_WHILE 18139) (T_YIELD 18140) (identifier 20914) (member_name 20915) (reserved_non_modifiers 18143) (semi_reserved 18144) (simple_variable 20916) ("{" 20917)) 9816 (("(" 18149) (argument_list 20920)) 9817 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 20918) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 9818 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 20919)) 9819 ((T_FN 35) (T_FUNCTION 127) (fn 17946) #'17947 (inline_function 20924)) 9820 (("$" 17885) (T_STRING 20933) (T_VARIABLE 17932) (property_name 20940) (simple_variable 20935) ("{" 20936)) 9821 (("$" 17885) (T_STRING 20933) (T_VARIABLE 17932) (property_name 20934) (simple_variable 20935) ("{" 20936)) 9822 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 20931) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 9823 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 20929) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 9824 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 20930)) 9825 (("]" 20932)) 9826 (("(" 18149) (argument_list 20939)) 9827 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 20937) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 9828 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 20938)) 9829 (("(" 18149) (argument_list 20941)) 9830 (("`" 20943)) 9831 (("]" 20945)) 9832 (("=" 20946)) 9833 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 20947) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 9834 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21455) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9835 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 21453) (encaps_var 5299)) 9836 (("$" 20951) (T_VARIABLE 20998) (simple_variable 21449) ("{" 21450)) 9837 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 21447) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 9838 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21446) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9839 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21445) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9840 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21444) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9841 (("(" 21441)) 9842 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21440) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9843 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21439) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9844 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21438) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9845 (("\"" 1509) ("$" 21254) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 21255) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 21256) ("[" 1529) (array_object_dereferenceable 21257) (callable_expr 21258) (callable_variable 21259) (class_constant 1533) (class_name 21260) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 21261) (name 21262) (simple_variable 21263) (static_member 21264) (variable 21437) (variable_class_name 21266)) 9846 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21436) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9847 (("(" 21433)) 9848 (("(" 21430)) 9849 (("(" 21426) (exit_expr 21427)) 9850 (("\"" 1509) ("$" 21254) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 21255) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 21256) ("[" 1529) (array_object_dereferenceable 21257) (callable_expr 21258) (callable_variable 21259) (class_constant 1533) (class_name 21260) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 21261) (name 21262) (simple_variable 21263) (static_member 21264) (variable 21425) (variable_class_name 21266)) 9851 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21424) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9852 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21423) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9853 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21422) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9854 (("(" 21418)) 9855 (("(" 21413)) 9856 (("(" 21407)) 9857 (("$" 18985) ("(" 19116) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 19117) (T_NAME_QUALIFIED 19118) (T_NAME_RELATIVE 19119) (T_READONLY 2936) (T_STATIC 19120) (T_STRING 19121) (T_VARIABLE 18987) (anonymous_class 21385) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 21386) (attribute 2943) (attributes 21387) (class_modifier 2945) (class_name 19125) (class_name_reference 21388) (name 19127) (new_variable 19128) (simple_variable 19129)) 9858 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21384) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9859 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21383) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9860 (("(" 21215) (argument_list 21382)) 9861 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21381) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9862 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21380) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9863 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 21375) (T_END_HEREDOC 21376) (T_VARIABLE 2900) (encaps_list 21377) (encaps_var 2902)) 9864 ((T_FN 35) (T_FUNCTION 127) (fn 21012) #'21013 (inline_function 21374)) 9865 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21373) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9866 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21372) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9867 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21371) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9868 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21368) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9869 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21367) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9870 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 21363) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 9871 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 21361) (encaps_list 2805) (encaps_var 2806)) 9872 ((T_NULLSAFE_OBJECT_OPERATOR 21344) (T_OBJECT_OPERATOR 21345) ("[" 21346) ("{" 21347)) 9873 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 21341) (attribute 2728) (fn 21012) #'21013 (inline_function 21342)) 9874 (("(" 21215) (argument_list 21340)) 9875 ((T_PAAMAYIM_NEKUDOTAYIM 21332)) 9876 (("%" 21027) ("*" 21028) ("+" 21029) ("-" 21030) ("." 21031) ("/" 21032) ("<" 21033) (">" 21034) ("?" 21035) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 21036) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 21037) (T_BOOLEAN_AND 21038) (T_BOOLEAN_OR 21039) (T_COALESCE 21040) (T_DOUBLE_ARROW 21330) (T_INSTANCEOF 21041) (T_IS_EQUAL 21042) (T_IS_GREATER_OR_EQUAL 21043) (T_IS_IDENTICAL 21044) (T_IS_NOT_EQUAL 21045) (T_IS_NOT_IDENTICAL 21046) (T_IS_SMALLER_OR_EQUAL 21047) (T_LOGICAL_AND 21048) (T_LOGICAL_OR 21049) (T_LOGICAL_XOR 21050) (T_POW 21051) (T_SL 21052) (T_SPACESHIP 21053) (T_SR 21054) ("^" 21055) ("|" 21056)) 9877 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 21319)) 9878 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 21307)) 9879 (("(" 21215) (argument_list 21306)) 9880 (("=" 21223) (T_AND_EQUAL 21224) (T_COALESCE_EQUAL 21225) (T_CONCAT_EQUAL 21226) (T_DEC 21227) (T_DIV_EQUAL 21228) (T_INC 21229) (T_MINUS_EQUAL 21230) (T_MOD_EQUAL 21231) (T_MUL_EQUAL 21232) (T_OR_EQUAL 21233) (T_PLUS_EQUAL 21234) (T_POW_EQUAL 21235) (T_SL_EQUAL 21236) (T_SR_EQUAL 21237) (T_XOR_EQUAL 21238)) 9881 ((T_PAAMAYIM_NEKUDOTAYIM 21128)) 9882 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21026) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9883 (("%" 21027) ("*" 21028) ("+" 21029) ("-" 21030) ("." 21031) ("/" 21032) ("<" 21033) (">" 21034) ("?" 21035) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 21036) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 21037) (T_BOOLEAN_AND 21038) (T_BOOLEAN_OR 21039) (T_COALESCE 21040) (T_INSTANCEOF 21041) (T_IS_EQUAL 21042) (T_IS_GREATER_OR_EQUAL 21043) (T_IS_IDENTICAL 21044) (T_IS_NOT_EQUAL 21045) (T_IS_NOT_IDENTICAL 21046) (T_IS_SMALLER_OR_EQUAL 21047) (T_LOGICAL_AND 21048) (T_LOGICAL_OR 21049) (T_LOGICAL_XOR 21050) (T_POW 21051) (T_SL 21052) (T_SPACESHIP 21053) (T_SR 21054) ("^" 21055) ("|" 21056)) 9884 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21127) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9885 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21126) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9886 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21125) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9887 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21124) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9888 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21123) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9889 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21122) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9890 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21121) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9891 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21120) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9892 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 21115) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 21116) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 9893 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21114) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9894 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21113) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9895 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21112) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9896 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21111) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9897 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21110) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9898 (("$" 21072) ("(" 21073) (T_NAME_FULLY_QUALIFIED 21074) (T_NAME_QUALIFIED 21075) (T_NAME_RELATIVE 21076) (T_STATIC 21077) (T_STRING 21078) (T_VARIABLE 21079) (class_name 21080) (class_name_reference 21081) (name 21082) (new_variable 21083) (simple_variable 21084)) 9899 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21071) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9900 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21070) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9901 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21069) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9902 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21068) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9903 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21067) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9904 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21066) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9905 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21065) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9906 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21064) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9907 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21063) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9908 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21062) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9909 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21061) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9910 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21060) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9911 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21059) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9912 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21058) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9913 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21057) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9914 (("$" 21072) (T_VARIABLE 21079) (simple_variable 21106) ("{" 21107)) 9915 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 21104) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 9916 ((T_PAAMAYIM_NEKUDOTAYIM 21102)) 9917 ((T_NULLSAFE_OBJECT_OPERATOR 21085) (T_OBJECT_OPERATOR 21086) (T_PAAMAYIM_NEKUDOTAYIM 21087) ("[" 21088) ("{" 21089)) 9918 (("$" 21072) (T_STRING 21095) (T_VARIABLE 21079) (property_name 21101) (simple_variable 21097) ("{" 21098)) 9919 (("$" 21072) (T_STRING 21095) (T_VARIABLE 21079) (property_name 21096) (simple_variable 21097) ("{" 21098)) 9920 (("$" 21072) (T_VARIABLE 21079) (simple_variable 21094)) 9921 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 21092) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 9922 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 21090) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 9923 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 21091)) 9924 (("]" 21093)) 9925 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 21099) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 9926 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 21100)) 9927 (("$" 21072) (T_VARIABLE 21079) (simple_variable 21103)) 9928 (("%" 292) (")" 21105) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 9929 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 21108) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 9930 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 21109)) 9931 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21119) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9932 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 21117) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 9933 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21118) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9934 (("$" 20951) (T_ABSTRACT 21129) (T_ARRAY 21130) (T_AS 21131) (T_BREAK 21132) (T_CALLABLE 21133) (T_CASE 21134) (T_CATCH 21135) (T_CLASS 21136) (T_CLASS_C 21137) (T_CLONE 21138) (T_CONST 21139) (T_CONTINUE 21140) (T_DECLARE 21141) (T_DEFAULT 21142) (T_DIR 21143) (T_DO 21144) (T_ECHO 21145) (T_ELSE 21146) (T_ELSEIF 21147) (T_EMPTY 21148) (T_ENDDECLARE 21149) (T_ENDFOR 21150) (T_ENDFOREACH 21151) (T_ENDIF 21152) (T_ENDSWITCH 21153) (T_ENDWHILE 21154) (T_ENUM 21155) (T_EVAL 21156) (T_EXIT 21157) (T_EXTENDS 21158) (T_FILE 21159) (T_FINAL 21160) (T_FINALLY 21161) (T_FN 21162) (T_FOR 21163) (T_FOREACH 21164) (T_FUNCTION 21165) (T_FUNC_C 21166) (T_GLOBAL 21167) (T_GOTO 21168) (T_IF 21169) (T_IMPLEMENTS 21170) (T_INCLUDE 21171) (T_INCLUDE_ONCE 21172) (T_INSTANCEOF 21173) (T_INSTEADOF 21174) (T_INTERFACE 21175) (T_ISSET 21176) (T_LINE 21177) (T_LIST 21178) (T_LOGICAL_AND 21179) (T_LOGICAL_OR 21180) (T_LOGICAL_XOR 21181) (T_MATCH 21182) (T_METHOD_C 21183) (T_NAMESPACE 21184) (T_NEW 21185) (T_NS_C 21186) (T_PRINT 21187) (T_PRIVATE 21188) (T_PROTECTED 21189) (T_PUBLIC 21190) (T_READONLY 21191) (T_REQUIRE 21192) (T_REQUIRE_ONCE 21193) (T_RETURN 21194) (T_STATIC 21195) (T_STRING 21196) (T_SWITCH 21197) (T_THROW 21198) (T_TRAIT 21199) (T_TRAIT_C 21200) (T_TRY 21201) (T_UNSET 21202) (T_USE 21203) (T_VAR 21204) (T_VARIABLE 20998) (T_WHILE 21205) (T_YIELD 21206) (identifier 21207) (member_name 21208) (reserved_non_modifiers 21209) (semi_reserved 21210) (simple_variable 21211) ("{" 21212)) 9935 (("(" 21215) (argument_list 21216)) 9936 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 21213) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 9937 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 21214)) 9938 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 21217) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 21218) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 21219) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 9939 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 21222) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 9940 (("," 1469) (possible_comma 21220)) 9941 ((")" 21221)) 9942 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (ampersand 21252) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21253) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9943 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21251) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9944 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21250) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9945 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21249) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9946 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21248) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9947 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21247) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9948 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21246) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9949 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21245) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9950 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21244) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9951 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21243) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9952 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21242) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9953 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21241) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9954 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21240) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9955 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21239) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 9956 (("\"" 1509) ("$" 21254) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 21255) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 21256) ("[" 1529) (array_object_dereferenceable 21257) (callable_expr 21258) (callable_variable 21259) (class_constant 1533) (class_name 21260) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 21261) (name 21262) (simple_variable 21263) (static_member 21264) (variable 21265) (variable_class_name 21266)) 9957 (("$" 21254) (T_VARIABLE 21256) (simple_variable 21302) ("{" 21303)) 9958 (("(" 21270) (argument_list 21301)) 9959 ((T_NULLSAFE_OBJECT_OPERATOR 21284) (T_OBJECT_OPERATOR 21285) ("[" 21286) ("{" 21287)) 9960 (("(" 21270) (argument_list 21283)) 9961 ((T_PAAMAYIM_NEKUDOTAYIM 21279)) 9962 (("(" 21270) (argument_list 21278)) 9963 ((T_PAAMAYIM_NEKUDOTAYIM 21267)) 9964 (("$" 21254) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 21256) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 21268) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 21269) ("{" 1627)) 9965 (("(" 21270) (argument_list 21271)) 9966 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 21272) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 21273) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 21274) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 9967 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 21277) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 9968 (("," 1469) (possible_comma 21275)) 9969 ((")" 21276)) 9970 (("$" 21254) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 21256) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 21280) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 21281) ("{" 1643)) 9971 (("(" 21270) (argument_list 21282)) 9972 (("$" 21254) (T_STRING 21292) (T_VARIABLE 21256) (property_name 21299) (simple_variable 21294) ("{" 21295)) 9973 (("$" 21254) (T_STRING 21292) (T_VARIABLE 21256) (property_name 21293) (simple_variable 21294) ("{" 21295)) 9974 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 21290) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 9975 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 21288) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 9976 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 21289)) 9977 (("]" 21291)) 9978 (("(" 21270) (argument_list 21298)) 9979 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 21296) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 9980 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 21297)) 9981 (("(" 21270) (argument_list 21300)) 9982 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 21304) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 9983 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 21305)) 9984 ((backup_doc_comment 21308)) 9985 (("(" 21309)) 9986 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 21310)) 9987 ((")" 21311)) 9988 ((T_USE 159) (lexical_vars 21312)) 9989 ((":" 161) (return_type 21313)) 9990 ((backup_fn_flags 21314)) 9991 (("{" 21315)) 9992 ((inner_statement_list 21316)) 9993 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 21317) ("~" 125)) 9994 ((backup_fn_flags 21318)) 9995 ((backup_doc_comment 21320)) 9996 (("(" 21321)) 9997 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 21322)) 9998 ((")" 21323)) 9999 ((":" 2241) (return_type 21324)) 10000 ((T_DOUBLE_ARROW 21325)) 10001 ((backup_fn_flags 21326)) 10002 ((backup_lex_pos 21327)) 10003 (("!" 18680) ("\"" 18681) ("$" 18682) ("(" 18683) ("+" 18684) ("-" 18685) ("@" 18686) (T_ARRAY 18687) (T_ARRAY_CAST 18688) (T_ATTRIBUTE 126) (T_BOOL_CAST 18689) (T_CLASS_C 18690) (T_CLONE 18691) (T_CONSTANT_ENCAPSED_STRING 18692) (T_DEC 18693) (T_DIR 18694) (T_DNUMBER 18695) (T_DOUBLE_CAST 18696) (T_EMPTY 18697) (T_EVAL 18698) (T_EXIT 18699) (T_FILE 18700) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 18701) (T_INC 18702) (T_INCLUDE 18703) (T_INCLUDE_ONCE 18704) (T_INT_CAST 18705) (T_ISSET 18706) (T_LINE 18707) (T_LIST 18708) (T_LNUMBER 18709) (T_MATCH 18710) (T_METHOD_C 18711) (T_NAME_FULLY_QUALIFIED 18712) (T_NAME_QUALIFIED 18713) (T_NAME_RELATIVE 18714) (T_NEW 18715) (T_NS_C 18716) (T_OBJECT_CAST 18717) (T_PRINT 18718) (T_READONLY 18719) (T_REQUIRE 18720) (T_REQUIRE_ONCE 18721) (T_START_HEREDOC 18722) (T_STATIC 18723) (T_STRING 18724) (T_STRING_CAST 18725) (T_THROW 18726) (T_TRAIT_C 18727) (T_UNSET_CAST 18728) (T_VARIABLE 18729) (T_YIELD 18730) (T_YIELD_FROM 18731) ("[" 18732) ("`" 18733) (array_object_dereferenceable 18734) (attribute 131) (attributes 18735) (callable_expr 18736) (callable_variable 18737) (class_constant 18738) (class_name 18739) (constant 18740) (dereferenceable_scalar 18741) (expr 21328) (fn 18743) (fully_dereferenceable 104) #'18744 (function_call 18745) (inline_function 18746) (internal_functions_in_yacc 18747) (match 18748) (name 18749) (new_expr 18750) (scalar 18751) (simple_variable 18752) (static_member 18753) (variable 18754) (variable_class_name 18755) ("~" 18756)) 10004 (("%" 18758) ("*" 18759) ("+" 18760) ("-" 18761) ("." 18762) ("/" 18763) ("<" 18764) (">" 18765) ("?" 18766) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 18767) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 18768) (T_BOOLEAN_AND 18769) (T_BOOLEAN_OR 18770) (T_COALESCE 18771) (T_INSTANCEOF 18772) (T_IS_EQUAL 18773) (T_IS_GREATER_OR_EQUAL 18774) (T_IS_IDENTICAL 18775) (T_IS_NOT_EQUAL 18776) (T_IS_NOT_IDENTICAL 18777) (T_IS_SMALLER_OR_EQUAL 18778) (T_LOGICAL_AND 18779) (T_LOGICAL_OR 18780) (T_LOGICAL_XOR 18781) (T_POW 18782) (T_SL 18783) (T_SPACESHIP 18784) (T_SR 18785) ("^" 18786) (backup_fn_flags 21329) ("|" 18787)) 10005 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 21331) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 10006 (("$" 20951) (T_ABSTRACT 21129) (T_ARRAY 21130) (T_AS 21131) (T_BREAK 21132) (T_CALLABLE 21133) (T_CASE 21134) (T_CATCH 21135) (T_CLASS 21136) (T_CLASS_C 21137) (T_CLONE 21138) (T_CONST 21139) (T_CONTINUE 21140) (T_DECLARE 21141) (T_DEFAULT 21142) (T_DIR 21143) (T_DO 21144) (T_ECHO 21145) (T_ELSE 21146) (T_ELSEIF 21147) (T_EMPTY 21148) (T_ENDDECLARE 21149) (T_ENDFOR 21150) (T_ENDFOREACH 21151) (T_ENDIF 21152) (T_ENDSWITCH 21153) (T_ENDWHILE 21154) (T_ENUM 21155) (T_EVAL 21156) (T_EXIT 21157) (T_EXTENDS 21158) (T_FILE 21159) (T_FINAL 21160) (T_FINALLY 21161) (T_FN 21162) (T_FOR 21163) (T_FOREACH 21164) (T_FUNCTION 21165) (T_FUNC_C 21166) (T_GLOBAL 21167) (T_GOTO 21168) (T_IF 21169) (T_IMPLEMENTS 21170) (T_INCLUDE 21171) (T_INCLUDE_ONCE 21172) (T_INSTANCEOF 21173) (T_INSTEADOF 21174) (T_INTERFACE 21175) (T_ISSET 21176) (T_LINE 21177) (T_LIST 21178) (T_LOGICAL_AND 21179) (T_LOGICAL_OR 21180) (T_LOGICAL_XOR 21181) (T_MATCH 21182) (T_METHOD_C 21183) (T_NAMESPACE 21184) (T_NEW 21185) (T_NS_C 21186) (T_PRINT 21187) (T_PRIVATE 21188) (T_PROTECTED 21189) (T_PUBLIC 21190) (T_READONLY 21191) (T_REQUIRE 21192) (T_REQUIRE_ONCE 21193) (T_RETURN 21194) (T_STATIC 21195) (T_STRING 21196) (T_SWITCH 21197) (T_THROW 21198) (T_TRAIT 21199) (T_TRAIT_C 21200) (T_TRY 21201) (T_UNSET 21202) (T_USE 21203) (T_VAR 21204) (T_VARIABLE 20998) (T_WHILE 21205) (T_YIELD 21206) (identifier 21333) (member_name 21334) (reserved_non_modifiers 21209) (semi_reserved 21210) (simple_variable 21335) ("{" 21336)) 10007 (("(" 21215) (argument_list 21339)) 10008 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 21337) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10009 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 21338)) 10010 ((T_FN 35) (T_FUNCTION 127) (fn 21012) #'21013 (inline_function 21343)) 10011 (("$" 20951) (T_STRING 21352) (T_VARIABLE 20998) (property_name 21359) (simple_variable 21354) ("{" 21355)) 10012 (("$" 20951) (T_STRING 21352) (T_VARIABLE 20998) (property_name 21353) (simple_variable 21354) ("{" 21355)) 10013 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 21350) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 10014 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 21348) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10015 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 21349)) 10016 (("]" 21351)) 10017 (("(" 21215) (argument_list 21358)) 10018 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 21356) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10019 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 21357)) 10020 (("(" 21215) (argument_list 21360)) 10021 (("`" 21362)) 10022 (("]" 21364)) 10023 (("=" 21365)) 10024 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21366) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 10025 (("%" 21027) ("*" 21028) ("+" 21029) ("-" 21030) ("." 21031) ("/" 21032) ("<" 21033) (">" 21034) ("?" 21035) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 21036) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 21037) (T_BOOLEAN_AND 21038) (T_BOOLEAN_OR 21039) (T_COALESCE 21040) (T_DOUBLE_ARROW 21369) (T_INSTANCEOF 21041) (T_IS_EQUAL 21042) (T_IS_GREATER_OR_EQUAL 21043) (T_IS_IDENTICAL 21044) (T_IS_NOT_EQUAL 21045) (T_IS_NOT_IDENTICAL 21046) (T_IS_SMALLER_OR_EQUAL 21047) (T_LOGICAL_AND 21048) (T_LOGICAL_OR 21049) (T_LOGICAL_XOR 21050) (T_POW 21051) (T_SL 21052) (T_SPACESHIP 21053) (T_SR 21054) ("^" 21055) ("|" 21056)) 10026 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21370) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 10027 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 21379) (T_VARIABLE 2900) (encaps_var 2914)) 10028 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 21378) (T_VARIABLE 2900) (encaps_var 2905)) 10029 ((T_CLASS 21399)) 10030 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 21398) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 21386) (attribute 2980) (class_modifier 2945)) 10031 (("(" 21389) (argument_list 21390) (ctor_arguments 21391)) 10032 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 21392) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 21393) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 21394) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 10033 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 21397) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 10034 (("," 1469) (possible_comma 21395)) 10035 ((")" 21396)) 10036 (("(" 2982) (argument_list 2983) (ctor_arguments 21400)) 10037 ((T_EXTENDS 2985) (extends_from 21401)) 10038 ((T_IMPLEMENTS 2987) (implements_list 21402)) 10039 ((backup_doc_comment 21403)) 10040 (("{" 21404)) 10041 ((class_statement_list 21405)) 10042 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 21406)) 10043 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 21408) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 10044 (("%" 292) (")" 21409) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 10045 (("{" 21410)) 10046 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 21411) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 10047 (("}" 21412)) 10048 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 21414) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 10049 ((")" 21415)) 10050 (("=" 21416)) 10051 (("!" 20949) ("\"" 20950) ("$" 20951) ("(" 20952) ("+" 20953) ("-" 20954) ("@" 20955) (T_ARRAY 20956) (T_ARRAY_CAST 20957) (T_ATTRIBUTE 126) (T_BOOL_CAST 20958) (T_CLASS_C 20959) (T_CLONE 20960) (T_CONSTANT_ENCAPSED_STRING 20961) (T_DEC 20962) (T_DIR 20963) (T_DNUMBER 20964) (T_DOUBLE_CAST 20965) (T_EMPTY 20966) (T_EVAL 20967) (T_EXIT 20968) (T_FILE 20969) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 20970) (T_INC 20971) (T_INCLUDE 20972) (T_INCLUDE_ONCE 20973) (T_INT_CAST 20974) (T_ISSET 20975) (T_LINE 20976) (T_LIST 20977) (T_LNUMBER 20978) (T_MATCH 20979) (T_METHOD_C 20980) (T_NAME_FULLY_QUALIFIED 20981) (T_NAME_QUALIFIED 20982) (T_NAME_RELATIVE 20983) (T_NEW 20984) (T_NS_C 20985) (T_OBJECT_CAST 20986) (T_PRINT 20987) (T_READONLY 20988) (T_REQUIRE 20989) (T_REQUIRE_ONCE 20990) (T_START_HEREDOC 20991) (T_STATIC 20992) (T_STRING 20993) (T_STRING_CAST 20994) (T_THROW 20995) (T_TRAIT_C 20996) (T_UNSET_CAST 20997) (T_VARIABLE 20998) (T_YIELD 20999) (T_YIELD_FROM 21000) ("[" 21001) ("`" 21002) (array_object_dereferenceable 21003) (attribute 131) (attributes 21004) (callable_expr 21005) (callable_variable 21006) (class_constant 21007) (class_name 21008) (constant 21009) (dereferenceable_scalar 21010) (expr 21417) (fn 21012) (fully_dereferenceable 104) #'21013 (function_call 21014) (inline_function 21015) (internal_functions_in_yacc 21016) (match 21017) (name 21018) (new_expr 21019) (scalar 21020) (simple_variable 21021) (static_member 21022) (variable 21023) (variable_class_name 21024) ("~" 21025)) 10052 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 21419) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 10053 (("," 5258) (possible_comma 21420)) 10054 ((")" 21421)) 10055 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 21428) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 10056 ((")" 21429)) 10057 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 21431) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 10058 (("%" 292) (")" 21432) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 10059 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 21434) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 10060 (("%" 292) (")" 21435) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 10061 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 21442) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 10062 ((")" 21443)) 10063 (("%" 292) (")" 21448) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 10064 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 21451) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10065 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 21452)) 10066 (("\"" 21454) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 10067 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 21464) (T_VARIABLE 2900) (encaps_var 2914)) 10068 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 21463) (T_VARIABLE 2900) (encaps_var 2905)) 10069 ((T_CLASS 21484)) 10070 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 21483) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 21471) (attribute 2980) (class_modifier 2945)) 10071 (("(" 21474) (argument_list 21475) (ctor_arguments 21476)) 10072 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 21477) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 21478) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 21479) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 10073 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 21482) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 10074 (("," 1469) (possible_comma 21480)) 10075 ((")" 21481)) 10076 (("(" 2982) (argument_list 2983) (ctor_arguments 21485)) 10077 ((T_EXTENDS 2985) (extends_from 21486)) 10078 ((T_IMPLEMENTS 2987) (implements_list 21487)) 10079 ((backup_doc_comment 21488)) 10080 (("{" 21489)) 10081 ((class_statement_list 21490)) 10082 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 21491)) 10083 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 21493) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 10084 (("%" 292) (")" 21494) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 10085 (("{" 21495)) 10086 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 21496) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 10087 (("}" 21497)) 10088 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 21499) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 10089 ((")" 21500)) 10090 (("=" 21501)) 10091 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 21502) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 10092 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 21504) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 10093 (("," 5258) (possible_comma 21505)) 10094 ((")" 21506)) 10095 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 21513) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 10096 ((")" 21514)) 10097 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 21516) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 10098 (("%" 292) (")" 21517) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 10099 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 21519) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 10100 (("%" 292) (")" 21520) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 10101 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 21527) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 10102 ((")" 21528)) 10103 (("%" 292) (")" 21533) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 10104 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 21536) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10105 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 21537)) 10106 (("\"" 21539) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 10107 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 21542) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 10108 ((";" 21543)) 10109 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 21544) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 10110 ((";" 21545)) 10111 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 19558) (fn 2394) (for_exprs 21546) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (non_empty_for_exprs 19560) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 10112 ((")" 21547)) 10113 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 21548) (";" 16761) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16762) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16763) (T_DEC 22) (T_DECLARE 16764) (T_DIR 24) (T_DNUMBER 25) (T_DO 16765) (T_DOUBLE_CAST 27) (T_ECHO 16766) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16767) (T_FOREACH 16768) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16769) (T_GOTO 16770) (T_IF 16726) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16771) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16772) (T_START_HEREDOC 68) (T_STATIC 16773) (T_STRING 16774) (T_STRING_CAST 71) (T_SWITCH 16775) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16776) (T_UNSET 16777) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16778) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16779) (alt_if_stmt_without_else 16780) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16781) (fn 103) (for_statement 21549) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16782) (if_stmt_without_else 16783) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 21550) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16785) ("~" 125)) 10114 ((inner_statement_list 21551)) 10115 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19568) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19569) (T_CLASS 19570) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19571) (T_DEC 22) (T_DECLARE 19572) (T_DIR 24) (T_DNUMBER 25) (T_DO 19573) (T_DOUBLE_CAST 27) (T_ECHO 19574) (T_EMPTY 29) (T_ENDFOR 21552) (T_ENUM 19576) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19577) (T_FOREACH 19578) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19579) (T_GOTO 19580) (T_HALT_COMPILER 19581) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19583) (T_INTERFACE 19584) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19585) (T_START_HEREDOC 68) (T_STATIC 19586) (T_STRING 19587) (T_STRING_CAST 71) (T_SWITCH 19588) (T_THROW 73) (T_TRAIT 19589) (T_TRAIT_C 75) (T_TRY 19590) (T_UNSET 19591) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19592) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19593) (alt_if_stmt_without_else 19594) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19595) (attributes 19596) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19597) (class_modifier 96) (class_modifiers 19598) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19599) (expr 19600) (fn 103) (fully_dereferenceable 104) #'19601 (function_call 106) (function_declaration_statement 19602) (if_stmt 19603) (if_stmt_without_else 19604) (inline_function 110) (inner_statement 19605) (interface_declaration_statement 19606) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19607) (static_member 119) (trait_declaration_statement 19608) (variable 122) (variable_class_name 123) ("{" 19609) ("~" 125)) 10116 ((";" 21553)) 10117 (("," 19743) (";" 21555)) 10118 ((T_WHILE 21557)) 10119 (("(" 21558)) 10120 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 21559) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 10121 (("%" 292) (")" 21560) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 10122 ((";" 21561)) 10123 ((T_STRING 19916) (const_decl 19917) (const_list 21563)) 10124 ((")" 21564) ("," 19920)) 10125 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 21565) (";" 16761) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16762) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16763) (T_DEC 22) (T_DECLARE 16764) (T_DIR 24) (T_DNUMBER 25) (T_DO 16765) (T_DOUBLE_CAST 27) (T_ECHO 16766) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16767) (T_FOREACH 16768) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16769) (T_GOTO 16770) (T_IF 16726) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16771) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16772) (T_START_HEREDOC 68) (T_STATIC 16773) (T_STRING 16774) (T_STRING_CAST 71) (T_SWITCH 16775) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16776) (T_UNSET 16777) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16778) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16779) (alt_if_stmt_without_else 16780) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (declare_statement 21566) (dereferenceable_scalar 100) (expr 16781) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16782) (if_stmt_without_else 16783) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 21567) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16785) ("~" 125)) 10126 ((inner_statement_list 21568)) 10127 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19926) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19927) (T_CLASS 19928) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19929) (T_DEC 22) (T_DECLARE 19930) (T_DIR 24) (T_DNUMBER 25) (T_DO 19931) (T_DOUBLE_CAST 27) (T_ECHO 19932) (T_EMPTY 29) (T_ENDDECLARE 21569) (T_ENUM 19934) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19935) (T_FOREACH 19936) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19937) (T_GOTO 19938) (T_HALT_COMPILER 19939) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19941) (T_INTERFACE 19942) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19943) (T_START_HEREDOC 68) (T_STATIC 19944) (T_STRING 19945) (T_STRING_CAST 71) (T_SWITCH 19946) (T_THROW 73) (T_TRAIT 19947) (T_TRAIT_C 75) (T_TRY 19948) (T_UNSET 19949) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19950) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19951) (alt_if_stmt_without_else 19952) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19953) (attributes 19954) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19955) (class_modifier 96) (class_modifiers 19956) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19957) (expr 19958) (fn 103) (fully_dereferenceable 104) #'19959 (function_call 106) (function_declaration_statement 19960) (if_stmt 19961) (if_stmt_without_else 19962) (inline_function 110) (inner_statement 19963) (interface_declaration_statement 19964) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19965) (static_member 119) (trait_declaration_statement 19966) (variable 122) (variable_class_name 123) ("{" 19967) ("~" 125)) 10128 ((";" 21570)) 10129 ((";" 21572)) 10130 ((";" 21574)) 10131 ((T_READONLY 16265) (T_STRING 16266) (backup_doc_comment 139) (function_name 21577)) 10132 ((backup_doc_comment 21578)) 10133 (("(" 21579)) 10134 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 21580)) 10135 ((")" 21581)) 10136 ((":" 161) (return_type 21582)) 10137 ((backup_fn_flags 21583)) 10138 (("{" 21584)) 10139 ((inner_statement_list 21585)) 10140 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 21586) ("~" 125)) 10141 ((backup_fn_flags 21587)) 10142 ((T_STRING 21590)) 10143 ((T_EXTENDS 2985) (extends_from 21591)) 10144 ((T_IMPLEMENTS 2987) (implements_list 21592)) 10145 ((backup_doc_comment 21593)) 10146 (("{" 21594)) 10147 ((class_statement_list 21595)) 10148 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 21596)) 10149 ((":" 21601)) 10150 ((";" 21600)) 10151 ((inner_statement_list 21602)) 10152 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16298) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16299) (T_CLASS 16300) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16301) (T_DEC 22) (T_DECLARE 16302) (T_DIR 24) (T_DNUMBER 25) (T_DO 16303) (T_DOUBLE_CAST 27) (T_ECHO 16304) (T_EMPTY 29) (T_ENDIF 21603) (T_ENUM 16306) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16307) (T_FOREACH 16308) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16309) (T_GOTO 16310) (T_HALT_COMPILER 16311) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16312) (T_INTERFACE 16313) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16314) (T_START_HEREDOC 68) (T_STATIC 16315) (T_STRING 16316) (T_STRING_CAST 71) (T_SWITCH 16317) (T_THROW 73) (T_TRAIT 16318) (T_TRAIT_C 75) (T_TRY 16319) (T_UNSET 16320) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16321) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16322) (alt_if_stmt_without_else 16323) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16324) (attributes 16325) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16326) (class_modifier 96) (class_modifiers 16327) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16328) (expr 16329) (fn 103) (fully_dereferenceable 104) #'16330 (function_call 106) (function_declaration_statement 16331) (if_stmt 16332) (if_stmt_without_else 16333) (inline_function 110) (inner_statement 16334) (interface_declaration_statement 16335) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16336) (static_member 119) (trait_declaration_statement 16337) (variable 122) (variable_class_name 123) ("{" 16338) ("~" 125)) 10153 ((";" 21604)) 10154 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 21606) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 10155 (("%" 292) (")" 21607) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 10156 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 21608) (";" 16713) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16714) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16716) (T_DEC 22) (T_DECLARE 16717) (T_DIR 24) (T_DNUMBER 25) (T_DO 16718) (T_DOUBLE_CAST 27) (T_ECHO 16719) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16721) (T_FOREACH 16722) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16723) (T_GOTO 16724) (T_IF 16726) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16727) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16729) (T_START_HEREDOC 68) (T_STATIC 16730) (T_STRING 16731) (T_STRING_CAST 71) (T_SWITCH 16732) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16734) (T_UNSET 16735) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16736) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16737) (alt_if_stmt_without_else 16738) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16744) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16747) (if_stmt_without_else 16748) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 21609) (static_member 119) (variable 122) (variable_class_name 123) (while_statement 21610) ("{" 16753) ("~" 125)) 10157 ((inner_statement_list 21611)) 10158 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16379) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16380) (T_CLASS 16381) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16382) (T_DEC 22) (T_DECLARE 16383) (T_DIR 24) (T_DNUMBER 25) (T_DO 16384) (T_DOUBLE_CAST 27) (T_ECHO 16385) (T_EMPTY 29) (T_ENDWHILE 21612) (T_ENUM 16387) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16388) (T_FOREACH 16389) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16390) (T_GOTO 16391) (T_HALT_COMPILER 16392) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16394) (T_INTERFACE 16395) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16396) (T_START_HEREDOC 68) (T_STATIC 16397) (T_STRING 16398) (T_STRING_CAST 71) (T_SWITCH 16399) (T_THROW 73) (T_TRAIT 16400) (T_TRAIT_C 75) (T_TRY 16401) (T_UNSET 16402) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16403) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16404) (alt_if_stmt_without_else 16405) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16406) (attributes 16407) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16408) (class_modifier 96) (class_modifiers 16409) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16410) (expr 16411) (fn 103) (fully_dereferenceable 104) #'16412 (function_call 106) (function_declaration_statement 16413) (if_stmt 16414) (if_stmt_without_else 16415) (inline_function 110) (inner_statement 16416) (interface_declaration_statement 16417) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16418) (static_member 119) (trait_declaration_statement 16419) (variable 122) (variable_class_name 123) ("{" 16420) ("~" 125)) 10159 ((";" 21613)) 10160 (("\"" 1509) ("$" 16475) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 16476) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 16477) ("[" 1529) (array_object_dereferenceable 16478) (callable_expr 16479) (callable_variable 16480) (class_constant 1533) (class_name 16481) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 16482) (name 16483) (simple_variable 16484) (static_member 16485) (unset_variable 16486) (unset_variables 21615) (variable 16488) (variable_class_name 16489)) 10161 (("," 16501) (possible_comma 21616)) 10162 ((")" 21617)) 10163 ((";" 21618)) 10164 ((inner_statement_list 21620)) 10165 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 21621) ("~" 125)) 10166 ((catch_list 21622)) 10167 ((T_CATCH 21623) (T_FINALLY 21624) (finally_statement 21625)) 10168 (("(" 21629)) 10169 (("{" 21626)) 10170 ((inner_statement_list 21627)) 10171 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 21628) ("~" 125)) 10172 ((T_NAME_FULLY_QUALIFIED 16545) (T_NAME_QUALIFIED 16546) (T_NAME_RELATIVE 16547) (T_STATIC 16548) (T_STRING 16549) (catch_name_list 21630) (class_name 16551) (name 16552)) 10173 ((T_VARIABLE 16553) (optional_variable 21631) ("|" 16555)) 10174 ((")" 21632)) 10175 (("{" 21633)) 10176 ((inner_statement_list 21634)) 10177 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 21635) ("~" 125)) 10178 ((backup_doc_comment 21637)) 10179 (("{" 21638)) 10180 ((class_statement_list 21639)) 10181 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 21640)) 10182 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 21642) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 10183 (("%" 292) (")" 21643) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 10184 ((":" 21644) (switch_case_list 21645) ("{" 21646)) 10185 ((";" 21652) (case_list 21653)) 10186 ((";" 21647) (case_list 21648)) 10187 ((case_list 21650)) 10188 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 21649)) 10189 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 21651)) 10190 ((case_list 21656)) 10191 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 21654)) 10192 ((";" 21655)) 10193 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 21657)) 10194 ((";" 21658)) 10195 (("," 16852) (";" 21661)) 10196 ((";" 21663)) 10197 ((T_EXTENDS 20209) (interface_extends_list 21665)) 10198 ((backup_doc_comment 21666)) 10199 (("{" 21667)) 10200 ((class_statement_list 21668)) 10201 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 21669)) 10202 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 21671) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 10203 (("%" 292) (")" 21672) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 10204 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20219) (";" 16761) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16762) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16763) (T_DEC 22) (T_DECLARE 16764) (T_DIR 24) (T_DNUMBER 25) (T_DO 16765) (T_DOUBLE_CAST 27) (T_ECHO 16766) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16767) (T_FOREACH 16768) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16769) (T_GOTO 16770) (T_IF 16726) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16771) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16772) (T_START_HEREDOC 68) (T_STATIC 16773) (T_STRING 16774) (T_STRING_CAST 71) (T_SWITCH 16775) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16776) (T_UNSET 16777) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16778) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16779) (alt_if_stmt_without_else 16780) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16781) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16782) (if_stmt_without_else 16783) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 21673) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16785) ("~" 125)) 10205 ((")" 21675)) 10206 ((";" 21676)) 10207 ((";" 21678)) 10208 (("," 17875) (";" 21680)) 10209 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 21682) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 10210 (("%" 17961) ("*" 17962) ("+" 17963) ("-" 17964) ("." 17965) ("/" 17966) ("<" 17967) (">" 17968) ("?" 17969) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 17970) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 17971) (T_AS 21683) (T_BOOLEAN_AND 17972) (T_BOOLEAN_OR 17973) (T_COALESCE 17974) (T_INSTANCEOF 17975) (T_IS_EQUAL 17976) (T_IS_GREATER_OR_EQUAL 17977) (T_IS_IDENTICAL 17978) (T_IS_NOT_EQUAL 17979) (T_IS_NOT_IDENTICAL 17980) (T_IS_SMALLER_OR_EQUAL 17981) (T_LOGICAL_AND 17982) (T_LOGICAL_OR 17983) (T_LOGICAL_XOR 17984) (T_POW 17985) (T_SL 17986) (T_SPACESHIP 17987) (T_SR 17988) ("^" 17989) ("|" 17990)) 10211 (("\"" 1509) ("$" 19325) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19326) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19327) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19328) ("[" 19329) (ampersand 19330) (array_object_dereferenceable 19331) (callable_expr 19332) (callable_variable 19333) (class_constant 1533) (class_name 19334) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 21684) (fully_dereferenceable 104) (function_call 19336) (name 19337) (simple_variable 19338) (static_member 19339) (variable 19340) (variable_class_name 19341)) 10212 ((")" 21685) (T_DOUBLE_ARROW 21686)) 10213 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 21689) (";" 16713) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16714) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16716) (T_DEC 22) (T_DECLARE 16717) (T_DIR 24) (T_DNUMBER 25) (T_DO 16718) (T_DOUBLE_CAST 27) (T_ECHO 16719) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16721) (T_FOREACH 16722) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16723) (T_GOTO 16724) (T_IF 16726) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16727) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16729) (T_START_HEREDOC 68) (T_STATIC 16730) (T_STRING 16731) (T_STRING_CAST 71) (T_SWITCH 16732) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16734) (T_UNSET 16735) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16736) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16737) (alt_if_stmt_without_else 16738) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16744) (fn 103) (foreach_statement 21695) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16747) (if_stmt_without_else 16748) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 21691) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16753) ("~" 125)) 10214 (("\"" 1509) ("$" 19356) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19357) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19358) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19359) ("[" 19360) (ampersand 19361) (array_object_dereferenceable 19362) (callable_expr 19363) (callable_variable 19364) (class_constant 1533) (class_name 19365) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 21687) (fully_dereferenceable 104) (function_call 19367) (name 19368) (simple_variable 19369) (static_member 19370) (variable 19371) (variable_class_name 19372)) 10215 ((")" 21688)) 10216 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 21689) (";" 16713) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16714) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16716) (T_DEC 22) (T_DECLARE 16717) (T_DIR 24) (T_DNUMBER 25) (T_DO 16718) (T_DOUBLE_CAST 27) (T_ECHO 16719) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16721) (T_FOREACH 16722) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16723) (T_GOTO 16724) (T_IF 16726) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16727) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16729) (T_START_HEREDOC 68) (T_STATIC 16730) (T_STRING 16731) (T_STRING_CAST 71) (T_SWITCH 16732) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16734) (T_UNSET 16735) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16736) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16737) (alt_if_stmt_without_else 16738) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16744) (fn 103) (foreach_statement 21690) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16747) (if_stmt_without_else 16748) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 21691) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16753) ("~" 125)) 10217 ((inner_statement_list 21692)) 10218 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19390) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19391) (T_CLASS 19392) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19393) (T_DEC 22) (T_DECLARE 19394) (T_DIR 24) (T_DNUMBER 25) (T_DO 19395) (T_DOUBLE_CAST 27) (T_ECHO 19396) (T_EMPTY 29) (T_ENDFOREACH 21693) (T_ENUM 19398) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19399) (T_FOREACH 19400) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19401) (T_GOTO 19402) (T_HALT_COMPILER 19403) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19405) (T_INTERFACE 19406) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19407) (T_START_HEREDOC 68) (T_STATIC 19408) (T_STRING 19409) (T_STRING_CAST 71) (T_SWITCH 19410) (T_THROW 73) (T_TRAIT 19411) (T_TRAIT_C 75) (T_TRY 19412) (T_UNSET 19413) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19414) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19415) (alt_if_stmt_without_else 19416) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19417) (attributes 19418) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19419) (class_modifier 96) (class_modifiers 19420) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19421) (expr 19422) (fn 103) (fully_dereferenceable 104) #'19423 (function_call 106) (function_declaration_statement 19424) (if_stmt 19425) (if_stmt_without_else 19426) (inline_function 110) (inner_statement 19427) (interface_declaration_statement 19428) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19429) (static_member 119) (trait_declaration_statement 19430) (variable 122) (variable_class_name 123) ("{" 19431) ("~" 125)) 10219 ((";" 21694)) 10220 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 21697) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 10221 ((";" 21698)) 10222 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 21699) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 10223 ((";" 21700)) 10224 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 19558) (fn 2394) (for_exprs 21701) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (non_empty_for_exprs 19560) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 10225 ((")" 21702)) 10226 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 21703) (";" 16713) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16714) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16716) (T_DEC 22) (T_DECLARE 16717) (T_DIR 24) (T_DNUMBER 25) (T_DO 16718) (T_DOUBLE_CAST 27) (T_ECHO 16719) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16721) (T_FOREACH 16722) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16723) (T_GOTO 16724) (T_IF 16726) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16727) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16729) (T_START_HEREDOC 68) (T_STATIC 16730) (T_STRING 16731) (T_STRING_CAST 71) (T_SWITCH 16732) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16734) (T_UNSET 16735) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16736) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16737) (alt_if_stmt_without_else 16738) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16744) (fn 103) (for_statement 21704) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16747) (if_stmt_without_else 16748) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 21705) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16753) ("~" 125)) 10227 ((inner_statement_list 21706)) 10228 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19568) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19569) (T_CLASS 19570) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19571) (T_DEC 22) (T_DECLARE 19572) (T_DIR 24) (T_DNUMBER 25) (T_DO 19573) (T_DOUBLE_CAST 27) (T_ECHO 19574) (T_EMPTY 29) (T_ENDFOR 21707) (T_ENUM 19576) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19577) (T_FOREACH 19578) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19579) (T_GOTO 19580) (T_HALT_COMPILER 19581) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19583) (T_INTERFACE 19584) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19585) (T_START_HEREDOC 68) (T_STATIC 19586) (T_STRING 19587) (T_STRING_CAST 71) (T_SWITCH 19588) (T_THROW 73) (T_TRAIT 19589) (T_TRAIT_C 75) (T_TRY 19590) (T_UNSET 19591) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19592) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19593) (alt_if_stmt_without_else 19594) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19595) (attributes 19596) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19597) (class_modifier 96) (class_modifiers 19598) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19599) (expr 19600) (fn 103) (fully_dereferenceable 104) #'19601 (function_call 106) (function_declaration_statement 19602) (if_stmt 19603) (if_stmt_without_else 19604) (inline_function 110) (inner_statement 19605) (interface_declaration_statement 19606) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19607) (static_member 119) (trait_declaration_statement 19608) (variable 122) (variable_class_name 123) ("{" 19609) ("~" 125)) 10229 ((";" 21708)) 10230 ((":" 20258) (enum_backing_type 21710)) 10231 ((T_IMPLEMENTS 2987) (implements_list 21711)) 10232 ((backup_doc_comment 21712)) 10233 (("{" 21713)) 10234 ((class_statement_list 21714)) 10235 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 21715)) 10236 (("," 19743) (";" 21717)) 10237 ((T_WHILE 21719)) 10238 (("(" 21720)) 10239 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 21721) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 10240 (("%" 292) (")" 21722) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 10241 ((";" 21723)) 10242 ((T_STRING 19916) (const_decl 19917) (const_list 21725)) 10243 ((")" 21726) ("," 19920)) 10244 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 21727) (";" 16713) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16714) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16716) (T_DEC 22) (T_DECLARE 16717) (T_DIR 24) (T_DNUMBER 25) (T_DO 16718) (T_DOUBLE_CAST 27) (T_ECHO 16719) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16721) (T_FOREACH 16722) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16723) (T_GOTO 16724) (T_IF 16726) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16727) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16729) (T_START_HEREDOC 68) (T_STATIC 16730) (T_STRING 16731) (T_STRING_CAST 71) (T_SWITCH 16732) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16734) (T_UNSET 16735) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16736) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16737) (alt_if_stmt_without_else 16738) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (declare_statement 21728) (dereferenceable_scalar 100) (expr 16744) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16747) (if_stmt_without_else 16748) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 21729) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16753) ("~" 125)) 10245 ((inner_statement_list 21730)) 10246 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19926) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19927) (T_CLASS 19928) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19929) (T_DEC 22) (T_DECLARE 19930) (T_DIR 24) (T_DNUMBER 25) (T_DO 19931) (T_DOUBLE_CAST 27) (T_ECHO 19932) (T_EMPTY 29) (T_ENDDECLARE 21731) (T_ENUM 19934) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19935) (T_FOREACH 19936) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19937) (T_GOTO 19938) (T_HALT_COMPILER 19939) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19941) (T_INTERFACE 19942) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19943) (T_START_HEREDOC 68) (T_STATIC 19944) (T_STRING 19945) (T_STRING_CAST 71) (T_SWITCH 19946) (T_THROW 73) (T_TRAIT 19947) (T_TRAIT_C 75) (T_TRY 19948) (T_UNSET 19949) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19950) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19951) (alt_if_stmt_without_else 19952) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19953) (attributes 19954) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19955) (class_modifier 96) (class_modifiers 19956) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19957) (expr 19958) (fn 103) (fully_dereferenceable 104) #'19959 (function_call 106) (function_declaration_statement 19960) (if_stmt 19961) (if_stmt_without_else 19962) (inline_function 110) (inner_statement 19963) (interface_declaration_statement 19964) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19965) (static_member 119) (trait_declaration_statement 19966) (variable 122) (variable_class_name 123) ("{" 19967) ("~" 125)) 10247 ((";" 21732)) 10248 ((";" 21734)) 10249 ((T_EXTENDS 2985) (extends_from 21736)) 10250 ((T_IMPLEMENTS 2987) (implements_list 21737)) 10251 ((backup_doc_comment 21738)) 10252 (("{" 21739)) 10253 ((class_statement_list 21740)) 10254 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 21741)) 10255 ((";" 21743)) 10256 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 23814) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10257 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 23812) (encaps_var 5299)) 10258 (("$" 21746) (T_VARIABLE 21793) (simple_variable 23808) ("{" 23809)) 10259 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 23806) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 10260 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 23805) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10261 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 23804) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10262 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 23803) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10263 (("(" 23800)) 10264 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 23799) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10265 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 23798) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10266 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 23797) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10267 (("\"" 1509) ("$" 22049) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 22050) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 22051) ("[" 1529) (array_object_dereferenceable 22052) (callable_expr 22053) (callable_variable 22054) (class_constant 1533) (class_name 22055) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 22056) (name 22057) (simple_variable 22058) (static_member 22059) (variable 23796) (variable_class_name 22061)) 10268 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 23795) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10269 (("(" 23792)) 10270 (("(" 23789)) 10271 (("(" 23785) (exit_expr 23786)) 10272 (("\"" 1509) ("$" 22049) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 22050) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 22051) ("[" 1529) (array_object_dereferenceable 22052) (callable_expr 22053) (callable_variable 22054) (class_constant 1533) (class_name 22055) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 22056) (name 22057) (simple_variable 22058) (static_member 22059) (variable 23784) (variable_class_name 22061)) 10273 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 23783) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10274 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 23782) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10275 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 23781) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10276 (("(" 23777)) 10277 (("(" 23772)) 10278 (("(" 23766)) 10279 (("$" 22428) ("(" 23088) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 23089) (T_NAME_QUALIFIED 23090) (T_NAME_RELATIVE 23091) (T_READONLY 2936) (T_STATIC 23092) (T_STRING 23093) (T_VARIABLE 22430) (anonymous_class 23744) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 23745) (attribute 2943) (attributes 23746) (class_modifier 2945) (class_name 23097) (class_name_reference 23747) (name 23099) (new_variable 23100) (simple_variable 23101)) 10280 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 23743) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10281 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 23742) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10282 (("(" 22010) (argument_list 23741)) 10283 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 23740) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10284 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 23739) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10285 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 23734) (T_END_HEREDOC 23735) (T_VARIABLE 2900) (encaps_list 23736) (encaps_var 2902)) 10286 ((T_FN 35) (T_FUNCTION 127) (fn 21807) #'21808 (inline_function 23733)) 10287 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 23732) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10288 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 23731) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10289 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 23730) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10290 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23285) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10291 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 23222) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10292 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 23218) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 10293 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 23216) (encaps_list 2805) (encaps_var 2806)) 10294 ((T_NULLSAFE_OBJECT_OPERATOR 23199) (T_OBJECT_OPERATOR 23200) ("[" 23201) ("{" 23202)) 10295 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 23196) (attribute 2728) (fn 21807) #'21808 (inline_function 23197)) 10296 (("(" 22010) (argument_list 23195)) 10297 ((T_PAAMAYIM_NEKUDOTAYIM 23187)) 10298 (("%" 21822) ("*" 21823) ("+" 21824) ("-" 21825) ("." 21826) ("/" 21827) (":" 16709) (";" 16710) ("<" 21828) (">" 21829) ("?" 21830) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 21831) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 21832) (T_BOOLEAN_AND 21833) (T_BOOLEAN_OR 21834) (T_COALESCE 21835) (T_INSTANCEOF 21836) (T_IS_EQUAL 21837) (T_IS_GREATER_OR_EQUAL 21838) (T_IS_IDENTICAL 21839) (T_IS_NOT_EQUAL 21840) (T_IS_NOT_IDENTICAL 21841) (T_IS_SMALLER_OR_EQUAL 21842) (T_LOGICAL_AND 21843) (T_LOGICAL_OR 21844) (T_LOGICAL_XOR 21845) (T_POW 21846) (T_SL 21847) (T_SPACESHIP 21848) (T_SR 21849) ("^" 21850) (case_separator 23185) ("|" 21851)) 10299 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 22114)) 10300 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 22102)) 10301 (("(" 22010) (argument_list 22101)) 10302 (("=" 22018) (T_AND_EQUAL 22019) (T_COALESCE_EQUAL 22020) (T_CONCAT_EQUAL 22021) (T_DEC 22022) (T_DIV_EQUAL 22023) (T_INC 22024) (T_MINUS_EQUAL 22025) (T_MOD_EQUAL 22026) (T_MUL_EQUAL 22027) (T_OR_EQUAL 22028) (T_PLUS_EQUAL 22029) (T_POW_EQUAL 22030) (T_SL_EQUAL 22031) (T_SR_EQUAL 22032) (T_XOR_EQUAL 22033)) 10303 ((T_PAAMAYIM_NEKUDOTAYIM 21923)) 10304 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 21821) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10305 (("%" 21822) ("*" 21823) ("+" 21824) ("-" 21825) ("." 21826) ("/" 21827) ("<" 21828) (">" 21829) ("?" 21830) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 21831) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 21832) (T_BOOLEAN_AND 21833) (T_BOOLEAN_OR 21834) (T_COALESCE 21835) (T_INSTANCEOF 21836) (T_IS_EQUAL 21837) (T_IS_GREATER_OR_EQUAL 21838) (T_IS_IDENTICAL 21839) (T_IS_NOT_EQUAL 21840) (T_IS_NOT_IDENTICAL 21841) (T_IS_SMALLER_OR_EQUAL 21842) (T_LOGICAL_AND 21843) (T_LOGICAL_OR 21844) (T_LOGICAL_XOR 21845) (T_POW 21846) (T_SL 21847) (T_SPACESHIP 21848) (T_SR 21849) ("^" 21850) ("|" 21851)) 10306 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 21922) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10307 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 21921) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10308 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 21920) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10309 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 21919) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10310 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 21918) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10311 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 21917) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10312 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 21916) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10313 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 21915) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10314 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 21910) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 21911) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 10315 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 21909) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10316 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 21908) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10317 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 21907) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10318 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 21906) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10319 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 21905) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10320 (("$" 21867) ("(" 21868) (T_NAME_FULLY_QUALIFIED 21869) (T_NAME_QUALIFIED 21870) (T_NAME_RELATIVE 21871) (T_STATIC 21872) (T_STRING 21873) (T_VARIABLE 21874) (class_name 21875) (class_name_reference 21876) (name 21877) (new_variable 21878) (simple_variable 21879)) 10321 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 21866) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10322 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 21865) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10323 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 21864) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10324 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 21863) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10325 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 21862) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10326 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 21861) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10327 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 21860) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10328 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 21859) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10329 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 21858) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10330 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 21857) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10331 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 21856) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10332 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 21855) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10333 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 21854) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10334 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 21853) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10335 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 21852) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10336 (("$" 21867) (T_VARIABLE 21874) (simple_variable 21901) ("{" 21902)) 10337 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 21899) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 10338 ((T_PAAMAYIM_NEKUDOTAYIM 21897)) 10339 ((T_NULLSAFE_OBJECT_OPERATOR 21880) (T_OBJECT_OPERATOR 21881) (T_PAAMAYIM_NEKUDOTAYIM 21882) ("[" 21883) ("{" 21884)) 10340 (("$" 21867) (T_STRING 21890) (T_VARIABLE 21874) (property_name 21896) (simple_variable 21892) ("{" 21893)) 10341 (("$" 21867) (T_STRING 21890) (T_VARIABLE 21874) (property_name 21891) (simple_variable 21892) ("{" 21893)) 10342 (("$" 21867) (T_VARIABLE 21874) (simple_variable 21889)) 10343 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 21887) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 10344 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 21885) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10345 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 21886)) 10346 (("]" 21888)) 10347 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 21894) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10348 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 21895)) 10349 (("$" 21867) (T_VARIABLE 21874) (simple_variable 21898)) 10350 (("%" 292) (")" 21900) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 10351 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 21903) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10352 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 21904)) 10353 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 21914) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10354 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 21912) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 10355 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 21913) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10356 (("$" 21746) (T_ABSTRACT 21924) (T_ARRAY 21925) (T_AS 21926) (T_BREAK 21927) (T_CALLABLE 21928) (T_CASE 21929) (T_CATCH 21930) (T_CLASS 21931) (T_CLASS_C 21932) (T_CLONE 21933) (T_CONST 21934) (T_CONTINUE 21935) (T_DECLARE 21936) (T_DEFAULT 21937) (T_DIR 21938) (T_DO 21939) (T_ECHO 21940) (T_ELSE 21941) (T_ELSEIF 21942) (T_EMPTY 21943) (T_ENDDECLARE 21944) (T_ENDFOR 21945) (T_ENDFOREACH 21946) (T_ENDIF 21947) (T_ENDSWITCH 21948) (T_ENDWHILE 21949) (T_ENUM 21950) (T_EVAL 21951) (T_EXIT 21952) (T_EXTENDS 21953) (T_FILE 21954) (T_FINAL 21955) (T_FINALLY 21956) (T_FN 21957) (T_FOR 21958) (T_FOREACH 21959) (T_FUNCTION 21960) (T_FUNC_C 21961) (T_GLOBAL 21962) (T_GOTO 21963) (T_IF 21964) (T_IMPLEMENTS 21965) (T_INCLUDE 21966) (T_INCLUDE_ONCE 21967) (T_INSTANCEOF 21968) (T_INSTEADOF 21969) (T_INTERFACE 21970) (T_ISSET 21971) (T_LINE 21972) (T_LIST 21973) (T_LOGICAL_AND 21974) (T_LOGICAL_OR 21975) (T_LOGICAL_XOR 21976) (T_MATCH 21977) (T_METHOD_C 21978) (T_NAMESPACE 21979) (T_NEW 21980) (T_NS_C 21981) (T_PRINT 21982) (T_PRIVATE 21983) (T_PROTECTED 21984) (T_PUBLIC 21985) (T_READONLY 21986) (T_REQUIRE 21987) (T_REQUIRE_ONCE 21988) (T_RETURN 21989) (T_STATIC 21990) (T_STRING 21991) (T_SWITCH 21992) (T_THROW 21993) (T_TRAIT 21994) (T_TRAIT_C 21995) (T_TRY 21996) (T_UNSET 21997) (T_USE 21998) (T_VAR 21999) (T_VARIABLE 21793) (T_WHILE 22000) (T_YIELD 22001) (identifier 22002) (member_name 22003) (reserved_non_modifiers 22004) (semi_reserved 22005) (simple_variable 22006) ("{" 22007)) 10357 (("(" 22010) (argument_list 22011)) 10358 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 22008) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10359 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 22009)) 10360 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 22012) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 22013) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 22014) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 10361 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 22017) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 10362 (("," 1469) (possible_comma 22015)) 10363 ((")" 22016)) 10364 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (ampersand 22047) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 22048) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10365 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 22046) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10366 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 22045) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10367 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 22044) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10368 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 22043) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10369 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 22042) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10370 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 22041) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10371 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 22040) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10372 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 22039) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10373 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 22038) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10374 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 22037) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10375 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 22036) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10376 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 22035) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10377 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 22034) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10378 (("\"" 1509) ("$" 22049) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 22050) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 22051) ("[" 1529) (array_object_dereferenceable 22052) (callable_expr 22053) (callable_variable 22054) (class_constant 1533) (class_name 22055) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 22056) (name 22057) (simple_variable 22058) (static_member 22059) (variable 22060) (variable_class_name 22061)) 10379 (("$" 22049) (T_VARIABLE 22051) (simple_variable 22097) ("{" 22098)) 10380 (("(" 22065) (argument_list 22096)) 10381 ((T_NULLSAFE_OBJECT_OPERATOR 22079) (T_OBJECT_OPERATOR 22080) ("[" 22081) ("{" 22082)) 10382 (("(" 22065) (argument_list 22078)) 10383 ((T_PAAMAYIM_NEKUDOTAYIM 22074)) 10384 (("(" 22065) (argument_list 22073)) 10385 ((T_PAAMAYIM_NEKUDOTAYIM 22062)) 10386 (("$" 22049) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 22051) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 22063) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 22064) ("{" 1627)) 10387 (("(" 22065) (argument_list 22066)) 10388 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 22067) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 22068) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 22069) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 10389 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 22072) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 10390 (("," 1469) (possible_comma 22070)) 10391 ((")" 22071)) 10392 (("$" 22049) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 22051) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 22075) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 22076) ("{" 1643)) 10393 (("(" 22065) (argument_list 22077)) 10394 (("$" 22049) (T_STRING 22087) (T_VARIABLE 22051) (property_name 22094) (simple_variable 22089) ("{" 22090)) 10395 (("$" 22049) (T_STRING 22087) (T_VARIABLE 22051) (property_name 22088) (simple_variable 22089) ("{" 22090)) 10396 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 22085) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 10397 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 22083) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10398 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 22084)) 10399 (("]" 22086)) 10400 (("(" 22065) (argument_list 22093)) 10401 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 22091) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10402 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 22092)) 10403 (("(" 22065) (argument_list 22095)) 10404 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 22099) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10405 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 22100)) 10406 ((backup_doc_comment 22103)) 10407 (("(" 22104)) 10408 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 22105)) 10409 ((")" 22106)) 10410 ((T_USE 159) (lexical_vars 22107)) 10411 ((":" 161) (return_type 22108)) 10412 ((backup_fn_flags 22109)) 10413 (("{" 22110)) 10414 ((inner_statement_list 22111)) 10415 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 22112) ("~" 125)) 10416 ((backup_fn_flags 22113)) 10417 ((backup_doc_comment 22115)) 10418 (("(" 22116)) 10419 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 22117)) 10420 ((")" 22118)) 10421 ((":" 2241) (return_type 22119)) 10422 ((T_DOUBLE_ARROW 22120)) 10423 ((backup_fn_flags 22121)) 10424 ((backup_lex_pos 22122)) 10425 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22185) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10426 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 23184) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10427 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 23182) (encaps_var 5299)) 10428 (("$" 22125) (T_VARIABLE 22172) (simple_variable 23178) ("{" 23179)) 10429 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 23176) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 10430 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 23175) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10431 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 23174) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10432 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 23173) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10433 (("(" 23170)) 10434 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 23169) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10435 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 23168) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10436 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 23167) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10437 (("\"" 1509) ("$" 22428) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 22429) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 22430) ("[" 1529) (array_object_dereferenceable 22431) (callable_expr 22432) (callable_variable 22433) (class_constant 1533) (class_name 22434) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 22435) (name 22436) (simple_variable 22437) (static_member 22438) (variable 23166) (variable_class_name 22440)) 10438 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 23165) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10439 (("(" 23162)) 10440 (("(" 23159)) 10441 (("(" 23155) (exit_expr 23156)) 10442 (("\"" 1509) ("$" 22428) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 22429) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 22430) ("[" 1529) (array_object_dereferenceable 22431) (callable_expr 22432) (callable_variable 22433) (class_constant 1533) (class_name 22434) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 22435) (name 22436) (simple_variable 22437) (static_member 22438) (variable 23154) (variable_class_name 22440)) 10443 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 23153) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10444 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 23152) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10445 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 23151) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10446 (("(" 23147)) 10447 (("(" 23142)) 10448 (("(" 23136)) 10449 (("$" 22428) ("(" 23088) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 23089) (T_NAME_QUALIFIED 23090) (T_NAME_RELATIVE 23091) (T_READONLY 2936) (T_STATIC 23092) (T_STRING 23093) (T_VARIABLE 22430) (anonymous_class 23094) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 23095) (attribute 2943) (attributes 23096) (class_modifier 2945) (class_name 23097) (class_name_reference 23098) (name 23099) (new_variable 23100) (simple_variable 23101)) 10450 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 23087) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10451 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 23086) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10452 (("(" 22389) (argument_list 23085)) 10453 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 23084) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10454 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 23083) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10455 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 23078) (T_END_HEREDOC 23079) (T_VARIABLE 2900) (encaps_list 23080) (encaps_var 2902)) 10456 ((T_FN 35) (T_FUNCTION 127) (fn 22186) #'22187 (inline_function 23077)) 10457 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 23076) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10458 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 23075) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10459 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 23074) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10460 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22603) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10461 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22540) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10462 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 22536) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 10463 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 22534) (encaps_list 2805) (encaps_var 2806)) 10464 ((T_NULLSAFE_OBJECT_OPERATOR 22517) (T_OBJECT_OPERATOR 22518) ("[" 22519) ("{" 22520)) 10465 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 22514) (attribute 2728) (fn 22186) #'22187 (inline_function 22515)) 10466 (("(" 22389) (argument_list 22513)) 10467 ((T_PAAMAYIM_NEKUDOTAYIM 22505)) 10468 (("%" 22201) ("*" 22202) ("+" 22203) ("-" 22204) ("." 22205) ("/" 22206) ("<" 22207) (">" 22208) ("?" 22209) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 22210) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 22211) (T_BOOLEAN_AND 22212) (T_BOOLEAN_OR 22213) (T_COALESCE 22214) (T_INSTANCEOF 22215) (T_IS_EQUAL 22216) (T_IS_GREATER_OR_EQUAL 22217) (T_IS_IDENTICAL 22218) (T_IS_NOT_EQUAL 22219) (T_IS_NOT_IDENTICAL 22220) (T_IS_SMALLER_OR_EQUAL 22221) (T_LOGICAL_AND 22222) (T_LOGICAL_OR 22223) (T_LOGICAL_XOR 22224) (T_POW 22225) (T_SL 22226) (T_SPACESHIP 22227) (T_SR 22228) ("^" 22229) (backup_fn_flags 22504) ("|" 22230)) 10469 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 22493)) 10470 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 22481)) 10471 (("(" 22389) (argument_list 22480)) 10472 (("=" 22397) (T_AND_EQUAL 22398) (T_COALESCE_EQUAL 22399) (T_CONCAT_EQUAL 22400) (T_DEC 22401) (T_DIV_EQUAL 22402) (T_INC 22403) (T_MINUS_EQUAL 22404) (T_MOD_EQUAL 22405) (T_MUL_EQUAL 22406) (T_OR_EQUAL 22407) (T_PLUS_EQUAL 22408) (T_POW_EQUAL 22409) (T_SL_EQUAL 22410) (T_SR_EQUAL 22411) (T_XOR_EQUAL 22412)) 10473 ((T_PAAMAYIM_NEKUDOTAYIM 22302)) 10474 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22200) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10475 (("%" 22201) ("*" 22202) ("+" 22203) ("-" 22204) ("." 22205) ("/" 22206) ("<" 22207) (">" 22208) ("?" 22209) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 22210) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 22211) (T_BOOLEAN_AND 22212) (T_BOOLEAN_OR 22213) (T_COALESCE 22214) (T_INSTANCEOF 22215) (T_IS_EQUAL 22216) (T_IS_GREATER_OR_EQUAL 22217) (T_IS_IDENTICAL 22218) (T_IS_NOT_EQUAL 22219) (T_IS_NOT_IDENTICAL 22220) (T_IS_SMALLER_OR_EQUAL 22221) (T_LOGICAL_AND 22222) (T_LOGICAL_OR 22223) (T_LOGICAL_XOR 22224) (T_POW 22225) (T_SL 22226) (T_SPACESHIP 22227) (T_SR 22228) ("^" 22229) ("|" 22230)) 10476 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22301) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10477 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22300) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10478 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22299) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10479 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22298) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10480 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22297) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10481 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22296) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10482 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22295) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10483 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22294) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10484 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 22289) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 22290) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 10485 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22288) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10486 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22287) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10487 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22286) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10488 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22285) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10489 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22284) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10490 (("$" 22246) ("(" 22247) (T_NAME_FULLY_QUALIFIED 22248) (T_NAME_QUALIFIED 22249) (T_NAME_RELATIVE 22250) (T_STATIC 22251) (T_STRING 22252) (T_VARIABLE 22253) (class_name 22254) (class_name_reference 22255) (name 22256) (new_variable 22257) (simple_variable 22258)) 10491 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22245) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10492 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22244) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10493 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22243) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10494 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22242) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10495 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22241) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10496 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22240) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10497 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22239) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10498 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22238) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10499 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22237) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10500 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22236) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10501 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22235) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10502 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22234) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10503 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22233) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10504 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22232) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10505 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22231) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10506 (("$" 22246) (T_VARIABLE 22253) (simple_variable 22280) ("{" 22281)) 10507 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 22278) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 10508 ((T_PAAMAYIM_NEKUDOTAYIM 22276)) 10509 ((T_NULLSAFE_OBJECT_OPERATOR 22259) (T_OBJECT_OPERATOR 22260) (T_PAAMAYIM_NEKUDOTAYIM 22261) ("[" 22262) ("{" 22263)) 10510 (("$" 22246) (T_STRING 22269) (T_VARIABLE 22253) (property_name 22275) (simple_variable 22271) ("{" 22272)) 10511 (("$" 22246) (T_STRING 22269) (T_VARIABLE 22253) (property_name 22270) (simple_variable 22271) ("{" 22272)) 10512 (("$" 22246) (T_VARIABLE 22253) (simple_variable 22268)) 10513 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 22266) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 10514 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 22264) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10515 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 22265)) 10516 (("]" 22267)) 10517 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 22273) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10518 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 22274)) 10519 (("$" 22246) (T_VARIABLE 22253) (simple_variable 22277)) 10520 (("%" 292) (")" 22279) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 10521 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 22282) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10522 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 22283)) 10523 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22293) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10524 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 22291) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 10525 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22292) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10526 (("$" 22125) (T_ABSTRACT 22303) (T_ARRAY 22304) (T_AS 22305) (T_BREAK 22306) (T_CALLABLE 22307) (T_CASE 22308) (T_CATCH 22309) (T_CLASS 22310) (T_CLASS_C 22311) (T_CLONE 22312) (T_CONST 22313) (T_CONTINUE 22314) (T_DECLARE 22315) (T_DEFAULT 22316) (T_DIR 22317) (T_DO 22318) (T_ECHO 22319) (T_ELSE 22320) (T_ELSEIF 22321) (T_EMPTY 22322) (T_ENDDECLARE 22323) (T_ENDFOR 22324) (T_ENDFOREACH 22325) (T_ENDIF 22326) (T_ENDSWITCH 22327) (T_ENDWHILE 22328) (T_ENUM 22329) (T_EVAL 22330) (T_EXIT 22331) (T_EXTENDS 22332) (T_FILE 22333) (T_FINAL 22334) (T_FINALLY 22335) (T_FN 22336) (T_FOR 22337) (T_FOREACH 22338) (T_FUNCTION 22339) (T_FUNC_C 22340) (T_GLOBAL 22341) (T_GOTO 22342) (T_IF 22343) (T_IMPLEMENTS 22344) (T_INCLUDE 22345) (T_INCLUDE_ONCE 22346) (T_INSTANCEOF 22347) (T_INSTEADOF 22348) (T_INTERFACE 22349) (T_ISSET 22350) (T_LINE 22351) (T_LIST 22352) (T_LOGICAL_AND 22353) (T_LOGICAL_OR 22354) (T_LOGICAL_XOR 22355) (T_MATCH 22356) (T_METHOD_C 22357) (T_NAMESPACE 22358) (T_NEW 22359) (T_NS_C 22360) (T_PRINT 22361) (T_PRIVATE 22362) (T_PROTECTED 22363) (T_PUBLIC 22364) (T_READONLY 22365) (T_REQUIRE 22366) (T_REQUIRE_ONCE 22367) (T_RETURN 22368) (T_STATIC 22369) (T_STRING 22370) (T_SWITCH 22371) (T_THROW 22372) (T_TRAIT 22373) (T_TRAIT_C 22374) (T_TRY 22375) (T_UNSET 22376) (T_USE 22377) (T_VAR 22378) (T_VARIABLE 22172) (T_WHILE 22379) (T_YIELD 22380) (identifier 22381) (member_name 22382) (reserved_non_modifiers 22383) (semi_reserved 22384) (simple_variable 22385) ("{" 22386)) 10527 (("(" 22389) (argument_list 22390)) 10528 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 22387) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10529 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 22388)) 10530 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 22391) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 22392) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 22393) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 10531 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 22396) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 10532 (("," 1469) (possible_comma 22394)) 10533 ((")" 22395)) 10534 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (ampersand 22426) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22427) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10535 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22425) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10536 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22424) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10537 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22423) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10538 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22422) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10539 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22421) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10540 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22420) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10541 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22419) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10542 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22418) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10543 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22417) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10544 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22416) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10545 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22415) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10546 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22414) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10547 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22413) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10548 (("\"" 1509) ("$" 22428) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 22429) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 22430) ("[" 1529) (array_object_dereferenceable 22431) (callable_expr 22432) (callable_variable 22433) (class_constant 1533) (class_name 22434) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 22435) (name 22436) (simple_variable 22437) (static_member 22438) (variable 22439) (variable_class_name 22440)) 10549 (("$" 22428) (T_VARIABLE 22430) (simple_variable 22476) ("{" 22477)) 10550 (("(" 22444) (argument_list 22475)) 10551 ((T_NULLSAFE_OBJECT_OPERATOR 22458) (T_OBJECT_OPERATOR 22459) ("[" 22460) ("{" 22461)) 10552 (("(" 22444) (argument_list 22457)) 10553 ((T_PAAMAYIM_NEKUDOTAYIM 22453)) 10554 (("(" 22444) (argument_list 22452)) 10555 ((T_PAAMAYIM_NEKUDOTAYIM 22441)) 10556 (("$" 22428) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 22430) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 22442) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 22443) ("{" 1627)) 10557 (("(" 22444) (argument_list 22445)) 10558 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 22446) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 22447) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 22448) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 10559 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 22451) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 10560 (("," 1469) (possible_comma 22449)) 10561 ((")" 22450)) 10562 (("$" 22428) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 22430) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 22454) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 22455) ("{" 1643)) 10563 (("(" 22444) (argument_list 22456)) 10564 (("$" 22428) (T_STRING 22466) (T_VARIABLE 22430) (property_name 22473) (simple_variable 22468) ("{" 22469)) 10565 (("$" 22428) (T_STRING 22466) (T_VARIABLE 22430) (property_name 22467) (simple_variable 22468) ("{" 22469)) 10566 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 22464) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 10567 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 22462) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10568 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 22463)) 10569 (("]" 22465)) 10570 (("(" 22444) (argument_list 22472)) 10571 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 22470) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10572 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 22471)) 10573 (("(" 22444) (argument_list 22474)) 10574 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 22478) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10575 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 22479)) 10576 ((backup_doc_comment 22482)) 10577 (("(" 22483)) 10578 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 22484)) 10579 ((")" 22485)) 10580 ((T_USE 159) (lexical_vars 22486)) 10581 ((":" 161) (return_type 22487)) 10582 ((backup_fn_flags 22488)) 10583 (("{" 22489)) 10584 ((inner_statement_list 22490)) 10585 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 22491) ("~" 125)) 10586 ((backup_fn_flags 22492)) 10587 ((backup_doc_comment 22494)) 10588 (("(" 22495)) 10589 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 22496)) 10590 ((")" 22497)) 10591 ((":" 2241) (return_type 22498)) 10592 ((T_DOUBLE_ARROW 22499)) 10593 ((backup_fn_flags 22500)) 10594 ((backup_lex_pos 22501)) 10595 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22502) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10596 (("%" 22201) ("*" 22202) ("+" 22203) ("-" 22204) ("." 22205) ("/" 22206) ("<" 22207) (">" 22208) ("?" 22209) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 22210) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 22211) (T_BOOLEAN_AND 22212) (T_BOOLEAN_OR 22213) (T_COALESCE 22214) (T_INSTANCEOF 22215) (T_IS_EQUAL 22216) (T_IS_GREATER_OR_EQUAL 22217) (T_IS_IDENTICAL 22218) (T_IS_NOT_EQUAL 22219) (T_IS_NOT_IDENTICAL 22220) (T_IS_SMALLER_OR_EQUAL 22221) (T_LOGICAL_AND 22222) (T_LOGICAL_OR 22223) (T_LOGICAL_XOR 22224) (T_POW 22225) (T_SL 22226) (T_SPACESHIP 22227) (T_SR 22228) ("^" 22229) (backup_fn_flags 22503) ("|" 22230)) 10597 (("$" 22125) (T_ABSTRACT 22303) (T_ARRAY 22304) (T_AS 22305) (T_BREAK 22306) (T_CALLABLE 22307) (T_CASE 22308) (T_CATCH 22309) (T_CLASS 22310) (T_CLASS_C 22311) (T_CLONE 22312) (T_CONST 22313) (T_CONTINUE 22314) (T_DECLARE 22315) (T_DEFAULT 22316) (T_DIR 22317) (T_DO 22318) (T_ECHO 22319) (T_ELSE 22320) (T_ELSEIF 22321) (T_EMPTY 22322) (T_ENDDECLARE 22323) (T_ENDFOR 22324) (T_ENDFOREACH 22325) (T_ENDIF 22326) (T_ENDSWITCH 22327) (T_ENDWHILE 22328) (T_ENUM 22329) (T_EVAL 22330) (T_EXIT 22331) (T_EXTENDS 22332) (T_FILE 22333) (T_FINAL 22334) (T_FINALLY 22335) (T_FN 22336) (T_FOR 22337) (T_FOREACH 22338) (T_FUNCTION 22339) (T_FUNC_C 22340) (T_GLOBAL 22341) (T_GOTO 22342) (T_IF 22343) (T_IMPLEMENTS 22344) (T_INCLUDE 22345) (T_INCLUDE_ONCE 22346) (T_INSTANCEOF 22347) (T_INSTEADOF 22348) (T_INTERFACE 22349) (T_ISSET 22350) (T_LINE 22351) (T_LIST 22352) (T_LOGICAL_AND 22353) (T_LOGICAL_OR 22354) (T_LOGICAL_XOR 22355) (T_MATCH 22356) (T_METHOD_C 22357) (T_NAMESPACE 22358) (T_NEW 22359) (T_NS_C 22360) (T_PRINT 22361) (T_PRIVATE 22362) (T_PROTECTED 22363) (T_PUBLIC 22364) (T_READONLY 22365) (T_REQUIRE 22366) (T_REQUIRE_ONCE 22367) (T_RETURN 22368) (T_STATIC 22369) (T_STRING 22370) (T_SWITCH 22371) (T_THROW 22372) (T_TRAIT 22373) (T_TRAIT_C 22374) (T_TRY 22375) (T_UNSET 22376) (T_USE 22377) (T_VAR 22378) (T_VARIABLE 22172) (T_WHILE 22379) (T_YIELD 22380) (identifier 22506) (member_name 22507) (reserved_non_modifiers 22383) (semi_reserved 22384) (simple_variable 22508) ("{" 22509)) 10598 (("(" 22389) (argument_list 22512)) 10599 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 22510) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10600 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 22511)) 10601 ((T_FN 35) (T_FUNCTION 127) (fn 22186) #'22187 (inline_function 22516)) 10602 (("$" 22125) (T_STRING 22525) (T_VARIABLE 22172) (property_name 22532) (simple_variable 22527) ("{" 22528)) 10603 (("$" 22125) (T_STRING 22525) (T_VARIABLE 22172) (property_name 22526) (simple_variable 22527) ("{" 22528)) 10604 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 22523) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 10605 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 22521) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10606 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 22522)) 10607 (("]" 22524)) 10608 (("(" 22389) (argument_list 22531)) 10609 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 22529) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10610 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 22530)) 10611 (("(" 22389) (argument_list 22533)) 10612 (("`" 22535)) 10613 (("]" 22537)) 10614 (("=" 22538)) 10615 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22539) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10616 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 23073) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10617 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 23071) (encaps_var 5299)) 10618 (("$" 22543) (T_VARIABLE 22590) (simple_variable 23067) ("{" 23068)) 10619 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 23065) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 10620 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 23064) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10621 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 23063) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10622 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 23062) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10623 (("(" 23059)) 10624 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 23058) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10625 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 23057) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10626 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 23056) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10627 (("\"" 1509) ("$" 22846) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 22847) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 22848) ("[" 1529) (array_object_dereferenceable 22849) (callable_expr 22850) (callable_variable 22851) (class_constant 1533) (class_name 22852) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 22853) (name 22854) (simple_variable 22855) (static_member 22856) (variable 23055) (variable_class_name 22858)) 10628 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 23054) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10629 (("(" 23051)) 10630 (("(" 23048)) 10631 (("(" 23044) (exit_expr 23045)) 10632 (("\"" 1509) ("$" 22846) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 22847) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 22848) ("[" 1529) (array_object_dereferenceable 22849) (callable_expr 22850) (callable_variable 22851) (class_constant 1533) (class_name 22852) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 22853) (name 22854) (simple_variable 22855) (static_member 22856) (variable 23043) (variable_class_name 22858)) 10633 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 23042) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10634 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 23041) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10635 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 23040) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10636 (("(" 23036)) 10637 (("(" 23031)) 10638 (("(" 23025)) 10639 (("$" 22846) ("(" 22977) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 22978) (T_NAME_QUALIFIED 22979) (T_NAME_RELATIVE 22980) (T_READONLY 2936) (T_STATIC 22981) (T_STRING 22982) (T_VARIABLE 22848) (anonymous_class 22983) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 22984) (attribute 2943) (attributes 22985) (class_modifier 2945) (class_name 22986) (class_name_reference 22987) (name 22988) (new_variable 22989) (simple_variable 22990)) 10640 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22976) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10641 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22975) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10642 (("(" 22807) (argument_list 22974)) 10643 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22973) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10644 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22972) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10645 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 22967) (T_END_HEREDOC 22968) (T_VARIABLE 2900) (encaps_list 22969) (encaps_var 2902)) 10646 ((T_FN 35) (T_FUNCTION 127) (fn 22604) #'22605 (inline_function 22966)) 10647 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22965) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10648 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22964) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10649 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22963) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10650 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22960) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10651 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22959) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10652 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 22955) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 10653 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 22953) (encaps_list 2805) (encaps_var 2806)) 10654 ((T_NULLSAFE_OBJECT_OPERATOR 22936) (T_OBJECT_OPERATOR 22937) ("[" 22938) ("{" 22939)) 10655 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 22933) (attribute 2728) (fn 22604) #'22605 (inline_function 22934)) 10656 (("(" 22807) (argument_list 22932)) 10657 ((T_PAAMAYIM_NEKUDOTAYIM 22924)) 10658 (("%" 22619) ("*" 22620) ("+" 22621) ("-" 22622) ("." 22623) ("/" 22624) ("<" 22625) (">" 22626) ("?" 22627) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 22628) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 22629) (T_BOOLEAN_AND 22630) (T_BOOLEAN_OR 22631) (T_COALESCE 22632) (T_DOUBLE_ARROW 22922) (T_INSTANCEOF 22633) (T_IS_EQUAL 22634) (T_IS_GREATER_OR_EQUAL 22635) (T_IS_IDENTICAL 22636) (T_IS_NOT_EQUAL 22637) (T_IS_NOT_IDENTICAL 22638) (T_IS_SMALLER_OR_EQUAL 22639) (T_LOGICAL_AND 22640) (T_LOGICAL_OR 22641) (T_LOGICAL_XOR 22642) (T_POW 22643) (T_SL 22644) (T_SPACESHIP 22645) (T_SR 22646) ("^" 22647) ("|" 22648)) 10659 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 22911)) 10660 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 22899)) 10661 (("(" 22807) (argument_list 22898)) 10662 (("=" 22815) (T_AND_EQUAL 22816) (T_COALESCE_EQUAL 22817) (T_CONCAT_EQUAL 22818) (T_DEC 22819) (T_DIV_EQUAL 22820) (T_INC 22821) (T_MINUS_EQUAL 22822) (T_MOD_EQUAL 22823) (T_MUL_EQUAL 22824) (T_OR_EQUAL 22825) (T_PLUS_EQUAL 22826) (T_POW_EQUAL 22827) (T_SL_EQUAL 22828) (T_SR_EQUAL 22829) (T_XOR_EQUAL 22830)) 10663 ((T_PAAMAYIM_NEKUDOTAYIM 22720)) 10664 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22618) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10665 (("%" 22619) ("*" 22620) ("+" 22621) ("-" 22622) ("." 22623) ("/" 22624) ("<" 22625) (">" 22626) ("?" 22627) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 22628) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 22629) (T_BOOLEAN_AND 22630) (T_BOOLEAN_OR 22631) (T_COALESCE 22632) (T_INSTANCEOF 22633) (T_IS_EQUAL 22634) (T_IS_GREATER_OR_EQUAL 22635) (T_IS_IDENTICAL 22636) (T_IS_NOT_EQUAL 22637) (T_IS_NOT_IDENTICAL 22638) (T_IS_SMALLER_OR_EQUAL 22639) (T_LOGICAL_AND 22640) (T_LOGICAL_OR 22641) (T_LOGICAL_XOR 22642) (T_POW 22643) (T_SL 22644) (T_SPACESHIP 22645) (T_SR 22646) ("^" 22647) ("|" 22648)) 10666 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22719) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10667 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22718) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10668 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22717) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10669 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22716) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10670 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22715) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10671 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22714) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10672 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22713) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10673 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22712) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10674 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 22707) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 22708) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 10675 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22706) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10676 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22705) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10677 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22704) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10678 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22703) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10679 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22702) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10680 (("$" 22664) ("(" 22665) (T_NAME_FULLY_QUALIFIED 22666) (T_NAME_QUALIFIED 22667) (T_NAME_RELATIVE 22668) (T_STATIC 22669) (T_STRING 22670) (T_VARIABLE 22671) (class_name 22672) (class_name_reference 22673) (name 22674) (new_variable 22675) (simple_variable 22676)) 10681 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22663) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10682 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22662) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10683 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22661) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10684 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22660) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10685 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22659) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10686 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22658) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10687 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22657) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10688 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22656) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10689 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22655) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10690 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22654) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10691 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22653) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10692 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22652) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10693 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22651) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10694 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22650) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10695 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22649) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10696 (("$" 22664) (T_VARIABLE 22671) (simple_variable 22698) ("{" 22699)) 10697 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 22696) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 10698 ((T_PAAMAYIM_NEKUDOTAYIM 22694)) 10699 ((T_NULLSAFE_OBJECT_OPERATOR 22677) (T_OBJECT_OPERATOR 22678) (T_PAAMAYIM_NEKUDOTAYIM 22679) ("[" 22680) ("{" 22681)) 10700 (("$" 22664) (T_STRING 22687) (T_VARIABLE 22671) (property_name 22693) (simple_variable 22689) ("{" 22690)) 10701 (("$" 22664) (T_STRING 22687) (T_VARIABLE 22671) (property_name 22688) (simple_variable 22689) ("{" 22690)) 10702 (("$" 22664) (T_VARIABLE 22671) (simple_variable 22686)) 10703 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 22684) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 10704 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 22682) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10705 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 22683)) 10706 (("]" 22685)) 10707 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 22691) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10708 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 22692)) 10709 (("$" 22664) (T_VARIABLE 22671) (simple_variable 22695)) 10710 (("%" 292) (")" 22697) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 10711 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 22700) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10712 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 22701)) 10713 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22711) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10714 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 22709) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 10715 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22710) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10716 (("$" 22543) (T_ABSTRACT 22721) (T_ARRAY 22722) (T_AS 22723) (T_BREAK 22724) (T_CALLABLE 22725) (T_CASE 22726) (T_CATCH 22727) (T_CLASS 22728) (T_CLASS_C 22729) (T_CLONE 22730) (T_CONST 22731) (T_CONTINUE 22732) (T_DECLARE 22733) (T_DEFAULT 22734) (T_DIR 22735) (T_DO 22736) (T_ECHO 22737) (T_ELSE 22738) (T_ELSEIF 22739) (T_EMPTY 22740) (T_ENDDECLARE 22741) (T_ENDFOR 22742) (T_ENDFOREACH 22743) (T_ENDIF 22744) (T_ENDSWITCH 22745) (T_ENDWHILE 22746) (T_ENUM 22747) (T_EVAL 22748) (T_EXIT 22749) (T_EXTENDS 22750) (T_FILE 22751) (T_FINAL 22752) (T_FINALLY 22753) (T_FN 22754) (T_FOR 22755) (T_FOREACH 22756) (T_FUNCTION 22757) (T_FUNC_C 22758) (T_GLOBAL 22759) (T_GOTO 22760) (T_IF 22761) (T_IMPLEMENTS 22762) (T_INCLUDE 22763) (T_INCLUDE_ONCE 22764) (T_INSTANCEOF 22765) (T_INSTEADOF 22766) (T_INTERFACE 22767) (T_ISSET 22768) (T_LINE 22769) (T_LIST 22770) (T_LOGICAL_AND 22771) (T_LOGICAL_OR 22772) (T_LOGICAL_XOR 22773) (T_MATCH 22774) (T_METHOD_C 22775) (T_NAMESPACE 22776) (T_NEW 22777) (T_NS_C 22778) (T_PRINT 22779) (T_PRIVATE 22780) (T_PROTECTED 22781) (T_PUBLIC 22782) (T_READONLY 22783) (T_REQUIRE 22784) (T_REQUIRE_ONCE 22785) (T_RETURN 22786) (T_STATIC 22787) (T_STRING 22788) (T_SWITCH 22789) (T_THROW 22790) (T_TRAIT 22791) (T_TRAIT_C 22792) (T_TRY 22793) (T_UNSET 22794) (T_USE 22795) (T_VAR 22796) (T_VARIABLE 22590) (T_WHILE 22797) (T_YIELD 22798) (identifier 22799) (member_name 22800) (reserved_non_modifiers 22801) (semi_reserved 22802) (simple_variable 22803) ("{" 22804)) 10717 (("(" 22807) (argument_list 22808)) 10718 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 22805) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10719 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 22806)) 10720 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 22809) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 22810) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 22811) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 10721 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 22814) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 10722 (("," 1469) (possible_comma 22812)) 10723 ((")" 22813)) 10724 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (ampersand 22844) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22845) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10725 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22843) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10726 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22842) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10727 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22841) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10728 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22840) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10729 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22839) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10730 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22838) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10731 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22837) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10732 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22836) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10733 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22835) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10734 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22834) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10735 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22833) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10736 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22832) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10737 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22831) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10738 (("\"" 1509) ("$" 22846) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 22847) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 22848) ("[" 1529) (array_object_dereferenceable 22849) (callable_expr 22850) (callable_variable 22851) (class_constant 1533) (class_name 22852) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 22853) (name 22854) (simple_variable 22855) (static_member 22856) (variable 22857) (variable_class_name 22858)) 10739 (("$" 22846) (T_VARIABLE 22848) (simple_variable 22894) ("{" 22895)) 10740 (("(" 22862) (argument_list 22893)) 10741 ((T_NULLSAFE_OBJECT_OPERATOR 22876) (T_OBJECT_OPERATOR 22877) ("[" 22878) ("{" 22879)) 10742 (("(" 22862) (argument_list 22875)) 10743 ((T_PAAMAYIM_NEKUDOTAYIM 22871)) 10744 (("(" 22862) (argument_list 22870)) 10745 ((T_PAAMAYIM_NEKUDOTAYIM 22859)) 10746 (("$" 22846) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 22848) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 22860) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 22861) ("{" 1627)) 10747 (("(" 22862) (argument_list 22863)) 10748 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 22864) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 22865) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 22866) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 10749 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 22869) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 10750 (("," 1469) (possible_comma 22867)) 10751 ((")" 22868)) 10752 (("$" 22846) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 22848) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 22872) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 22873) ("{" 1643)) 10753 (("(" 22862) (argument_list 22874)) 10754 (("$" 22846) (T_STRING 22884) (T_VARIABLE 22848) (property_name 22891) (simple_variable 22886) ("{" 22887)) 10755 (("$" 22846) (T_STRING 22884) (T_VARIABLE 22848) (property_name 22885) (simple_variable 22886) ("{" 22887)) 10756 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 22882) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 10757 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 22880) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10758 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 22881)) 10759 (("]" 22883)) 10760 (("(" 22862) (argument_list 22890)) 10761 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 22888) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10762 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 22889)) 10763 (("(" 22862) (argument_list 22892)) 10764 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 22896) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10765 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 22897)) 10766 ((backup_doc_comment 22900)) 10767 (("(" 22901)) 10768 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 22902)) 10769 ((")" 22903)) 10770 ((T_USE 159) (lexical_vars 22904)) 10771 ((":" 161) (return_type 22905)) 10772 ((backup_fn_flags 22906)) 10773 (("{" 22907)) 10774 ((inner_statement_list 22908)) 10775 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 22909) ("~" 125)) 10776 ((backup_fn_flags 22910)) 10777 ((backup_doc_comment 22912)) 10778 (("(" 22913)) 10779 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 22914)) 10780 ((")" 22915)) 10781 ((":" 2241) (return_type 22916)) 10782 ((T_DOUBLE_ARROW 22917)) 10783 ((backup_fn_flags 22918)) 10784 ((backup_lex_pos 22919)) 10785 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22920) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10786 (("%" 22619) ("*" 22620) ("+" 22621) ("-" 22622) ("." 22623) ("/" 22624) ("<" 22625) (">" 22626) ("?" 22627) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 22628) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 22629) (T_BOOLEAN_AND 22630) (T_BOOLEAN_OR 22631) (T_COALESCE 22632) (T_INSTANCEOF 22633) (T_IS_EQUAL 22634) (T_IS_GREATER_OR_EQUAL 22635) (T_IS_IDENTICAL 22636) (T_IS_NOT_EQUAL 22637) (T_IS_NOT_IDENTICAL 22638) (T_IS_SMALLER_OR_EQUAL 22639) (T_LOGICAL_AND 22640) (T_LOGICAL_OR 22641) (T_LOGICAL_XOR 22642) (T_POW 22643) (T_SL 22644) (T_SPACESHIP 22645) (T_SR 22646) ("^" 22647) (backup_fn_flags 22921) ("|" 22648)) 10787 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 22923) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10788 (("$" 22543) (T_ABSTRACT 22721) (T_ARRAY 22722) (T_AS 22723) (T_BREAK 22724) (T_CALLABLE 22725) (T_CASE 22726) (T_CATCH 22727) (T_CLASS 22728) (T_CLASS_C 22729) (T_CLONE 22730) (T_CONST 22731) (T_CONTINUE 22732) (T_DECLARE 22733) (T_DEFAULT 22734) (T_DIR 22735) (T_DO 22736) (T_ECHO 22737) (T_ELSE 22738) (T_ELSEIF 22739) (T_EMPTY 22740) (T_ENDDECLARE 22741) (T_ENDFOR 22742) (T_ENDFOREACH 22743) (T_ENDIF 22744) (T_ENDSWITCH 22745) (T_ENDWHILE 22746) (T_ENUM 22747) (T_EVAL 22748) (T_EXIT 22749) (T_EXTENDS 22750) (T_FILE 22751) (T_FINAL 22752) (T_FINALLY 22753) (T_FN 22754) (T_FOR 22755) (T_FOREACH 22756) (T_FUNCTION 22757) (T_FUNC_C 22758) (T_GLOBAL 22759) (T_GOTO 22760) (T_IF 22761) (T_IMPLEMENTS 22762) (T_INCLUDE 22763) (T_INCLUDE_ONCE 22764) (T_INSTANCEOF 22765) (T_INSTEADOF 22766) (T_INTERFACE 22767) (T_ISSET 22768) (T_LINE 22769) (T_LIST 22770) (T_LOGICAL_AND 22771) (T_LOGICAL_OR 22772) (T_LOGICAL_XOR 22773) (T_MATCH 22774) (T_METHOD_C 22775) (T_NAMESPACE 22776) (T_NEW 22777) (T_NS_C 22778) (T_PRINT 22779) (T_PRIVATE 22780) (T_PROTECTED 22781) (T_PUBLIC 22782) (T_READONLY 22783) (T_REQUIRE 22784) (T_REQUIRE_ONCE 22785) (T_RETURN 22786) (T_STATIC 22787) (T_STRING 22788) (T_SWITCH 22789) (T_THROW 22790) (T_TRAIT 22791) (T_TRAIT_C 22792) (T_TRY 22793) (T_UNSET 22794) (T_USE 22795) (T_VAR 22796) (T_VARIABLE 22590) (T_WHILE 22797) (T_YIELD 22798) (identifier 22925) (member_name 22926) (reserved_non_modifiers 22801) (semi_reserved 22802) (simple_variable 22927) ("{" 22928)) 10789 (("(" 22807) (argument_list 22931)) 10790 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 22929) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10791 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 22930)) 10792 ((T_FN 35) (T_FUNCTION 127) (fn 22604) #'22605 (inline_function 22935)) 10793 (("$" 22543) (T_STRING 22944) (T_VARIABLE 22590) (property_name 22951) (simple_variable 22946) ("{" 22947)) 10794 (("$" 22543) (T_STRING 22944) (T_VARIABLE 22590) (property_name 22945) (simple_variable 22946) ("{" 22947)) 10795 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 22942) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 10796 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 22940) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10797 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 22941)) 10798 (("]" 22943)) 10799 (("(" 22807) (argument_list 22950)) 10800 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 22948) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10801 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 22949)) 10802 (("(" 22807) (argument_list 22952)) 10803 (("`" 22954)) 10804 (("]" 22956)) 10805 (("=" 22957)) 10806 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22958) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10807 (("%" 22619) ("*" 22620) ("+" 22621) ("-" 22622) ("." 22623) ("/" 22624) ("<" 22625) (">" 22626) ("?" 22627) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 22628) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 22629) (T_BOOLEAN_AND 22630) (T_BOOLEAN_OR 22631) (T_COALESCE 22632) (T_DOUBLE_ARROW 22961) (T_INSTANCEOF 22633) (T_IS_EQUAL 22634) (T_IS_GREATER_OR_EQUAL 22635) (T_IS_IDENTICAL 22636) (T_IS_NOT_EQUAL 22637) (T_IS_NOT_IDENTICAL 22638) (T_IS_SMALLER_OR_EQUAL 22639) (T_LOGICAL_AND 22640) (T_LOGICAL_OR 22641) (T_LOGICAL_XOR 22642) (T_POW 22643) (T_SL 22644) (T_SPACESHIP 22645) (T_SR 22646) ("^" 22647) ("|" 22648)) 10808 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 22962) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10809 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 22971) (T_VARIABLE 2900) (encaps_var 2914)) 10810 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 22970) (T_VARIABLE 2900) (encaps_var 2905)) 10811 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 23023) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 10812 ((T_CLASS 23015)) 10813 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 23014) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 22984) (attribute 2980) (class_modifier 2945)) 10814 ((T_PAAMAYIM_NEKUDOTAYIM 23012)) 10815 (("(" 23003) (argument_list 23004) (ctor_arguments 23005)) 10816 ((T_NULLSAFE_OBJECT_OPERATOR 22991) (T_OBJECT_OPERATOR 22992) (T_PAAMAYIM_NEKUDOTAYIM 22993) ("[" 22994) ("{" 22995)) 10817 (("$" 22846) (T_STRING 22884) (T_VARIABLE 22848) (property_name 23002) (simple_variable 22886) ("{" 22887)) 10818 (("$" 22846) (T_STRING 22884) (T_VARIABLE 22848) (property_name 23001) (simple_variable 22886) ("{" 22887)) 10819 (("$" 22846) (T_VARIABLE 22848) (simple_variable 23000)) 10820 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 22998) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 10821 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 22996) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10822 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 22997)) 10823 (("]" 22999)) 10824 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 23006) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 23007) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 23008) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 10825 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 23011) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 10826 (("," 1469) (possible_comma 23009)) 10827 ((")" 23010)) 10828 (("$" 22846) (T_VARIABLE 22848) (simple_variable 23013)) 10829 (("(" 2982) (argument_list 2983) (ctor_arguments 23016)) 10830 ((T_EXTENDS 2985) (extends_from 23017)) 10831 ((T_IMPLEMENTS 2987) (implements_list 23018)) 10832 ((backup_doc_comment 23019)) 10833 (("{" 23020)) 10834 ((class_statement_list 23021)) 10835 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 23022)) 10836 (("%" 292) (")" 23024) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 10837 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 23026) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 10838 (("%" 292) (")" 23027) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 10839 (("{" 23028)) 10840 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 23029) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 10841 (("}" 23030)) 10842 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 23032) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 10843 ((")" 23033)) 10844 (("=" 23034)) 10845 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 23035) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 10846 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 23037) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 10847 (("," 5258) (possible_comma 23038)) 10848 ((")" 23039)) 10849 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 23046) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 10850 ((")" 23047)) 10851 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 23049) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 10852 (("%" 292) (")" 23050) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 10853 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 23052) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 10854 (("%" 292) (")" 23053) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 10855 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 23060) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 10856 ((")" 23061)) 10857 (("%" 292) (")" 23066) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 10858 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 23069) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10859 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 23070)) 10860 (("\"" 23072) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 10861 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 23082) (T_VARIABLE 2900) (encaps_var 2914)) 10862 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 23081) (T_VARIABLE 2900) (encaps_var 2905)) 10863 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 23134) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 10864 ((T_CLASS 23126)) 10865 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 23125) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 23095) (attribute 2980) (class_modifier 2945)) 10866 ((T_PAAMAYIM_NEKUDOTAYIM 23123)) 10867 (("(" 23114) (argument_list 23115) (ctor_arguments 23116)) 10868 ((T_NULLSAFE_OBJECT_OPERATOR 23102) (T_OBJECT_OPERATOR 23103) (T_PAAMAYIM_NEKUDOTAYIM 23104) ("[" 23105) ("{" 23106)) 10869 (("$" 22428) (T_STRING 22466) (T_VARIABLE 22430) (property_name 23113) (simple_variable 22468) ("{" 22469)) 10870 (("$" 22428) (T_STRING 22466) (T_VARIABLE 22430) (property_name 23112) (simple_variable 22468) ("{" 22469)) 10871 (("$" 22428) (T_VARIABLE 22430) (simple_variable 23111)) 10872 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 23109) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 10873 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 23107) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10874 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 23108)) 10875 (("]" 23110)) 10876 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 23117) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 23118) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 23119) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 10877 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 23122) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 10878 (("," 1469) (possible_comma 23120)) 10879 ((")" 23121)) 10880 (("$" 22428) (T_VARIABLE 22430) (simple_variable 23124)) 10881 (("(" 2982) (argument_list 2983) (ctor_arguments 23127)) 10882 ((T_EXTENDS 2985) (extends_from 23128)) 10883 ((T_IMPLEMENTS 2987) (implements_list 23129)) 10884 ((backup_doc_comment 23130)) 10885 (("{" 23131)) 10886 ((class_statement_list 23132)) 10887 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 23133)) 10888 (("%" 292) (")" 23135) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 10889 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 23137) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 10890 (("%" 292) (")" 23138) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 10891 (("{" 23139)) 10892 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 23140) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 10893 (("}" 23141)) 10894 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 23143) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 10895 ((")" 23144)) 10896 (("=" 23145)) 10897 (("!" 22123) ("\"" 22124) ("$" 22125) ("(" 22126) ("+" 22127) ("-" 22128) ("@" 22129) (T_ARRAY 22130) (T_ARRAY_CAST 22131) (T_ATTRIBUTE 126) (T_BOOL_CAST 22132) (T_CLASS_C 22133) (T_CLONE 22134) (T_CONSTANT_ENCAPSED_STRING 22135) (T_DEC 22136) (T_DIR 22137) (T_DNUMBER 22138) (T_DOUBLE_CAST 22139) (T_EMPTY 22140) (T_EVAL 22141) (T_EXIT 22142) (T_FILE 22143) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22144) (T_INC 22145) (T_INCLUDE 22146) (T_INCLUDE_ONCE 22147) (T_INT_CAST 22148) (T_ISSET 22149) (T_LINE 22150) (T_LIST 22151) (T_LNUMBER 22152) (T_MATCH 22153) (T_METHOD_C 22154) (T_NAME_FULLY_QUALIFIED 22155) (T_NAME_QUALIFIED 22156) (T_NAME_RELATIVE 22157) (T_NEW 22158) (T_NS_C 22159) (T_OBJECT_CAST 22160) (T_PRINT 22161) (T_READONLY 22162) (T_REQUIRE 22163) (T_REQUIRE_ONCE 22164) (T_START_HEREDOC 22165) (T_STATIC 22166) (T_STRING 22167) (T_STRING_CAST 22168) (T_THROW 22169) (T_TRAIT_C 22170) (T_UNSET_CAST 22171) (T_VARIABLE 22172) (T_YIELD 22173) (T_YIELD_FROM 22174) ("[" 22175) ("`" 22176) (array_object_dereferenceable 22177) (attribute 131) (attributes 22178) (callable_expr 22179) (callable_variable 22180) (class_constant 22181) (class_name 22182) (constant 22183) (dereferenceable_scalar 22184) (expr 23146) (fn 22186) (fully_dereferenceable 104) #'22187 (function_call 22188) (inline_function 22189) (internal_functions_in_yacc 22190) (match 22191) (name 22192) (new_expr 22193) (scalar 22194) (simple_variable 22195) (static_member 22196) (variable 22197) (variable_class_name 22198) ("~" 22199)) 10898 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 23148) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 10899 (("," 5258) (possible_comma 23149)) 10900 ((")" 23150)) 10901 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 23157) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 10902 ((")" 23158)) 10903 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 23160) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 10904 (("%" 292) (")" 23161) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 10905 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 23163) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 10906 (("%" 292) (")" 23164) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 10907 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 23171) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 10908 ((")" 23172)) 10909 (("%" 292) (")" 23177) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 10910 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 23180) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10911 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 23181)) 10912 (("\"" 23183) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 10913 ((inner_statement_list 23186)) 10914 (("$" 21746) (T_ABSTRACT 21924) (T_ARRAY 21925) (T_AS 21926) (T_BREAK 21927) (T_CALLABLE 21928) (T_CASE 21929) (T_CATCH 21930) (T_CLASS 21931) (T_CLASS_C 21932) (T_CLONE 21933) (T_CONST 21934) (T_CONTINUE 21935) (T_DECLARE 21936) (T_DEFAULT 21937) (T_DIR 21938) (T_DO 21939) (T_ECHO 21940) (T_ELSE 21941) (T_ELSEIF 21942) (T_EMPTY 21943) (T_ENDDECLARE 21944) (T_ENDFOR 21945) (T_ENDFOREACH 21946) (T_ENDIF 21947) (T_ENDSWITCH 21948) (T_ENDWHILE 21949) (T_ENUM 21950) (T_EVAL 21951) (T_EXIT 21952) (T_EXTENDS 21953) (T_FILE 21954) (T_FINAL 21955) (T_FINALLY 21956) (T_FN 21957) (T_FOR 21958) (T_FOREACH 21959) (T_FUNCTION 21960) (T_FUNC_C 21961) (T_GLOBAL 21962) (T_GOTO 21963) (T_IF 21964) (T_IMPLEMENTS 21965) (T_INCLUDE 21966) (T_INCLUDE_ONCE 21967) (T_INSTANCEOF 21968) (T_INSTEADOF 21969) (T_INTERFACE 21970) (T_ISSET 21971) (T_LINE 21972) (T_LIST 21973) (T_LOGICAL_AND 21974) (T_LOGICAL_OR 21975) (T_LOGICAL_XOR 21976) (T_MATCH 21977) (T_METHOD_C 21978) (T_NAMESPACE 21979) (T_NEW 21980) (T_NS_C 21981) (T_PRINT 21982) (T_PRIVATE 21983) (T_PROTECTED 21984) (T_PUBLIC 21985) (T_READONLY 21986) (T_REQUIRE 21987) (T_REQUIRE_ONCE 21988) (T_RETURN 21989) (T_STATIC 21990) (T_STRING 21991) (T_SWITCH 21992) (T_THROW 21993) (T_TRAIT 21994) (T_TRAIT_C 21995) (T_TRY 21996) (T_UNSET 21997) (T_USE 21998) (T_VAR 21999) (T_VARIABLE 21793) (T_WHILE 22000) (T_YIELD 22001) (identifier 23188) (member_name 23189) (reserved_non_modifiers 22004) (semi_reserved 22005) (simple_variable 23190) ("{" 23191)) 10915 (("(" 22010) (argument_list 23194)) 10916 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 23192) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10917 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 23193)) 10918 ((T_FN 35) (T_FUNCTION 127) (fn 21807) #'21808 (inline_function 23198)) 10919 (("$" 21746) (T_STRING 23207) (T_VARIABLE 21793) (property_name 23214) (simple_variable 23209) ("{" 23210)) 10920 (("$" 21746) (T_STRING 23207) (T_VARIABLE 21793) (property_name 23208) (simple_variable 23209) ("{" 23210)) 10921 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 23205) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 10922 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 23203) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10923 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 23204)) 10924 (("]" 23206)) 10925 (("(" 22010) (argument_list 23213)) 10926 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 23211) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 10927 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 23212)) 10928 (("(" 22010) (argument_list 23215)) 10929 (("`" 23217)) 10930 (("]" 23219)) 10931 (("=" 23220)) 10932 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 23221) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 10933 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23729) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10934 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 23727) (encaps_var 5299)) 10935 (("$" 23225) (T_VARIABLE 23272) (simple_variable 23723) ("{" 23724)) 10936 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 23721) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 10937 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23720) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10938 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23719) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10939 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23718) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10940 (("(" 23715)) 10941 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23714) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10942 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23713) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10943 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23712) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10944 (("\"" 1509) ("$" 23528) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 23529) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 23530) ("[" 1529) (array_object_dereferenceable 23531) (callable_expr 23532) (callable_variable 23533) (class_constant 1533) (class_name 23534) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 23535) (name 23536) (simple_variable 23537) (static_member 23538) (variable 23711) (variable_class_name 23540)) 10945 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23710) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10946 (("(" 23707)) 10947 (("(" 23704)) 10948 (("(" 23700) (exit_expr 23701)) 10949 (("\"" 1509) ("$" 23528) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 23529) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 23530) ("[" 1529) (array_object_dereferenceable 23531) (callable_expr 23532) (callable_variable 23533) (class_constant 1533) (class_name 23534) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 23535) (name 23536) (simple_variable 23537) (static_member 23538) (variable 23699) (variable_class_name 23540)) 10950 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23698) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10951 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23697) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10952 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23696) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10953 (("(" 23692)) 10954 (("(" 23687)) 10955 (("(" 23681)) 10956 (("$" 22846) ("(" 22977) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 22978) (T_NAME_QUALIFIED 22979) (T_NAME_RELATIVE 22980) (T_READONLY 2936) (T_STATIC 22981) (T_STRING 22982) (T_VARIABLE 22848) (anonymous_class 23659) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 23660) (attribute 2943) (attributes 23661) (class_modifier 2945) (class_name 22986) (class_name_reference 23662) (name 22988) (new_variable 22989) (simple_variable 22990)) 10957 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23658) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10958 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23657) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10959 (("(" 23489) (argument_list 23656)) 10960 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23655) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10961 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23654) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10962 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 23649) (T_END_HEREDOC 23650) (T_VARIABLE 2900) (encaps_list 23651) (encaps_var 2902)) 10963 ((T_FN 35) (T_FUNCTION 127) (fn 23286) #'23287 (inline_function 23648)) 10964 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23647) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10965 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23646) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10966 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23645) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10967 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23642) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10968 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23641) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10969 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 23637) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 10970 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 23635) (encaps_list 2805) (encaps_var 2806)) 10971 ((T_NULLSAFE_OBJECT_OPERATOR 23618) (T_OBJECT_OPERATOR 23619) ("[" 23620) ("{" 23621)) 10972 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 23615) (attribute 2728) (fn 23286) #'23287 (inline_function 23616)) 10973 (("(" 23489) (argument_list 23614)) 10974 ((T_PAAMAYIM_NEKUDOTAYIM 23606)) 10975 (("%" 23301) ("*" 23302) ("+" 23303) ("-" 23304) ("." 23305) ("/" 23306) ("<" 23307) (">" 23308) ("?" 23309) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 23310) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 23311) (T_BOOLEAN_AND 23312) (T_BOOLEAN_OR 23313) (T_COALESCE 23314) (T_DOUBLE_ARROW 23604) (T_INSTANCEOF 23315) (T_IS_EQUAL 23316) (T_IS_GREATER_OR_EQUAL 23317) (T_IS_IDENTICAL 23318) (T_IS_NOT_EQUAL 23319) (T_IS_NOT_IDENTICAL 23320) (T_IS_SMALLER_OR_EQUAL 23321) (T_LOGICAL_AND 23322) (T_LOGICAL_OR 23323) (T_LOGICAL_XOR 23324) (T_POW 23325) (T_SL 23326) (T_SPACESHIP 23327) (T_SR 23328) ("^" 23329) ("|" 23330)) 10976 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 23593)) 10977 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 23581)) 10978 (("(" 23489) (argument_list 23580)) 10979 (("=" 23497) (T_AND_EQUAL 23498) (T_COALESCE_EQUAL 23499) (T_CONCAT_EQUAL 23500) (T_DEC 23501) (T_DIV_EQUAL 23502) (T_INC 23503) (T_MINUS_EQUAL 23504) (T_MOD_EQUAL 23505) (T_MUL_EQUAL 23506) (T_OR_EQUAL 23507) (T_PLUS_EQUAL 23508) (T_POW_EQUAL 23509) (T_SL_EQUAL 23510) (T_SR_EQUAL 23511) (T_XOR_EQUAL 23512)) 10980 ((T_PAAMAYIM_NEKUDOTAYIM 23402)) 10981 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23300) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10982 (("%" 23301) ("*" 23302) ("+" 23303) ("-" 23304) ("." 23305) ("/" 23306) ("<" 23307) (">" 23308) ("?" 23309) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 23310) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 23311) (T_BOOLEAN_AND 23312) (T_BOOLEAN_OR 23313) (T_COALESCE 23314) (T_INSTANCEOF 23315) (T_IS_EQUAL 23316) (T_IS_GREATER_OR_EQUAL 23317) (T_IS_IDENTICAL 23318) (T_IS_NOT_EQUAL 23319) (T_IS_NOT_IDENTICAL 23320) (T_IS_SMALLER_OR_EQUAL 23321) (T_LOGICAL_AND 23322) (T_LOGICAL_OR 23323) (T_LOGICAL_XOR 23324) (T_POW 23325) (T_SL 23326) (T_SPACESHIP 23327) (T_SR 23328) ("^" 23329) ("|" 23330)) 10983 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23401) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10984 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23400) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10985 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23399) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10986 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23398) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10987 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23397) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10988 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23396) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10989 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23395) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10990 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23394) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10991 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 23389) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 23390) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 10992 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23388) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10993 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23387) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10994 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23386) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10995 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23385) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10996 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23384) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10997 (("$" 23346) ("(" 23347) (T_NAME_FULLY_QUALIFIED 23348) (T_NAME_QUALIFIED 23349) (T_NAME_RELATIVE 23350) (T_STATIC 23351) (T_STRING 23352) (T_VARIABLE 23353) (class_name 23354) (class_name_reference 23355) (name 23356) (new_variable 23357) (simple_variable 23358)) 10998 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23345) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 10999 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23344) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 11000 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23343) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 11001 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23342) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 11002 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23341) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 11003 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23340) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 11004 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23339) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 11005 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23338) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 11006 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23337) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 11007 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23336) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 11008 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23335) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 11009 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23334) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 11010 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23333) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 11011 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23332) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 11012 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23331) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 11013 (("$" 23346) (T_VARIABLE 23353) (simple_variable 23380) ("{" 23381)) 11014 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 23378) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 11015 ((T_PAAMAYIM_NEKUDOTAYIM 23376)) 11016 ((T_NULLSAFE_OBJECT_OPERATOR 23359) (T_OBJECT_OPERATOR 23360) (T_PAAMAYIM_NEKUDOTAYIM 23361) ("[" 23362) ("{" 23363)) 11017 (("$" 23346) (T_STRING 23369) (T_VARIABLE 23353) (property_name 23375) (simple_variable 23371) ("{" 23372)) 11018 (("$" 23346) (T_STRING 23369) (T_VARIABLE 23353) (property_name 23370) (simple_variable 23371) ("{" 23372)) 11019 (("$" 23346) (T_VARIABLE 23353) (simple_variable 23368)) 11020 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 23366) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 11021 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 23364) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 11022 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 23365)) 11023 (("]" 23367)) 11024 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 23373) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 11025 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 23374)) 11026 (("$" 23346) (T_VARIABLE 23353) (simple_variable 23377)) 11027 (("%" 292) (")" 23379) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 11028 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 23382) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 11029 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 23383)) 11030 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23393) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 11031 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 23391) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 11032 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23392) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 11033 (("$" 23225) (T_ABSTRACT 23403) (T_ARRAY 23404) (T_AS 23405) (T_BREAK 23406) (T_CALLABLE 23407) (T_CASE 23408) (T_CATCH 23409) (T_CLASS 23410) (T_CLASS_C 23411) (T_CLONE 23412) (T_CONST 23413) (T_CONTINUE 23414) (T_DECLARE 23415) (T_DEFAULT 23416) (T_DIR 23417) (T_DO 23418) (T_ECHO 23419) (T_ELSE 23420) (T_ELSEIF 23421) (T_EMPTY 23422) (T_ENDDECLARE 23423) (T_ENDFOR 23424) (T_ENDFOREACH 23425) (T_ENDIF 23426) (T_ENDSWITCH 23427) (T_ENDWHILE 23428) (T_ENUM 23429) (T_EVAL 23430) (T_EXIT 23431) (T_EXTENDS 23432) (T_FILE 23433) (T_FINAL 23434) (T_FINALLY 23435) (T_FN 23436) (T_FOR 23437) (T_FOREACH 23438) (T_FUNCTION 23439) (T_FUNC_C 23440) (T_GLOBAL 23441) (T_GOTO 23442) (T_IF 23443) (T_IMPLEMENTS 23444) (T_INCLUDE 23445) (T_INCLUDE_ONCE 23446) (T_INSTANCEOF 23447) (T_INSTEADOF 23448) (T_INTERFACE 23449) (T_ISSET 23450) (T_LINE 23451) (T_LIST 23452) (T_LOGICAL_AND 23453) (T_LOGICAL_OR 23454) (T_LOGICAL_XOR 23455) (T_MATCH 23456) (T_METHOD_C 23457) (T_NAMESPACE 23458) (T_NEW 23459) (T_NS_C 23460) (T_PRINT 23461) (T_PRIVATE 23462) (T_PROTECTED 23463) (T_PUBLIC 23464) (T_READONLY 23465) (T_REQUIRE 23466) (T_REQUIRE_ONCE 23467) (T_RETURN 23468) (T_STATIC 23469) (T_STRING 23470) (T_SWITCH 23471) (T_THROW 23472) (T_TRAIT 23473) (T_TRAIT_C 23474) (T_TRY 23475) (T_UNSET 23476) (T_USE 23477) (T_VAR 23478) (T_VARIABLE 23272) (T_WHILE 23479) (T_YIELD 23480) (identifier 23481) (member_name 23482) (reserved_non_modifiers 23483) (semi_reserved 23484) (simple_variable 23485) ("{" 23486)) 11034 (("(" 23489) (argument_list 23490)) 11035 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 23487) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 11036 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 23488)) 11037 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 23491) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 23492) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 23493) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 11038 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 23496) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 11039 (("," 1469) (possible_comma 23494)) 11040 ((")" 23495)) 11041 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (ampersand 23526) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23527) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 11042 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23525) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 11043 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23524) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 11044 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23523) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 11045 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23522) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 11046 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23521) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 11047 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23520) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 11048 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23519) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 11049 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23518) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 11050 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23517) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 11051 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23516) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 11052 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23515) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 11053 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23514) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 11054 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23513) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 11055 (("\"" 1509) ("$" 23528) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 23529) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 23530) ("[" 1529) (array_object_dereferenceable 23531) (callable_expr 23532) (callable_variable 23533) (class_constant 1533) (class_name 23534) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 23535) (name 23536) (simple_variable 23537) (static_member 23538) (variable 23539) (variable_class_name 23540)) 11056 (("$" 23528) (T_VARIABLE 23530) (simple_variable 23576) ("{" 23577)) 11057 (("(" 23544) (argument_list 23575)) 11058 ((T_NULLSAFE_OBJECT_OPERATOR 23558) (T_OBJECT_OPERATOR 23559) ("[" 23560) ("{" 23561)) 11059 (("(" 23544) (argument_list 23557)) 11060 ((T_PAAMAYIM_NEKUDOTAYIM 23553)) 11061 (("(" 23544) (argument_list 23552)) 11062 ((T_PAAMAYIM_NEKUDOTAYIM 23541)) 11063 (("$" 23528) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 23530) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 23542) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 23543) ("{" 1627)) 11064 (("(" 23544) (argument_list 23545)) 11065 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 23546) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 23547) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 23548) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 11066 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 23551) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 11067 (("," 1469) (possible_comma 23549)) 11068 ((")" 23550)) 11069 (("$" 23528) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 23530) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 23554) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 23555) ("{" 1643)) 11070 (("(" 23544) (argument_list 23556)) 11071 (("$" 23528) (T_STRING 23566) (T_VARIABLE 23530) (property_name 23573) (simple_variable 23568) ("{" 23569)) 11072 (("$" 23528) (T_STRING 23566) (T_VARIABLE 23530) (property_name 23567) (simple_variable 23568) ("{" 23569)) 11073 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 23564) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 11074 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 23562) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 11075 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 23563)) 11076 (("]" 23565)) 11077 (("(" 23544) (argument_list 23572)) 11078 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 23570) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 11079 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 23571)) 11080 (("(" 23544) (argument_list 23574)) 11081 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 23578) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 11082 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 23579)) 11083 ((backup_doc_comment 23582)) 11084 (("(" 23583)) 11085 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 23584)) 11086 ((")" 23585)) 11087 ((T_USE 159) (lexical_vars 23586)) 11088 ((":" 161) (return_type 23587)) 11089 ((backup_fn_flags 23588)) 11090 (("{" 23589)) 11091 ((inner_statement_list 23590)) 11092 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 23591) ("~" 125)) 11093 ((backup_fn_flags 23592)) 11094 ((backup_doc_comment 23594)) 11095 (("(" 23595)) 11096 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 23596)) 11097 ((")" 23597)) 11098 ((":" 2241) (return_type 23598)) 11099 ((T_DOUBLE_ARROW 23599)) 11100 ((backup_fn_flags 23600)) 11101 ((backup_lex_pos 23601)) 11102 (("!" 22541) ("\"" 22542) ("$" 22543) ("(" 22544) ("+" 22545) ("-" 22546) ("@" 22547) (T_ARRAY 22548) (T_ARRAY_CAST 22549) (T_ATTRIBUTE 126) (T_BOOL_CAST 22550) (T_CLASS_C 22551) (T_CLONE 22552) (T_CONSTANT_ENCAPSED_STRING 22553) (T_DEC 22554) (T_DIR 22555) (T_DNUMBER 22556) (T_DOUBLE_CAST 22557) (T_EMPTY 22558) (T_EVAL 22559) (T_EXIT 22560) (T_FILE 22561) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 22562) (T_INC 22563) (T_INCLUDE 22564) (T_INCLUDE_ONCE 22565) (T_INT_CAST 22566) (T_ISSET 22567) (T_LINE 22568) (T_LIST 22569) (T_LNUMBER 22570) (T_MATCH 22571) (T_METHOD_C 22572) (T_NAME_FULLY_QUALIFIED 22573) (T_NAME_QUALIFIED 22574) (T_NAME_RELATIVE 22575) (T_NEW 22576) (T_NS_C 22577) (T_OBJECT_CAST 22578) (T_PRINT 22579) (T_READONLY 22580) (T_REQUIRE 22581) (T_REQUIRE_ONCE 22582) (T_START_HEREDOC 22583) (T_STATIC 22584) (T_STRING 22585) (T_STRING_CAST 22586) (T_THROW 22587) (T_TRAIT_C 22588) (T_UNSET_CAST 22589) (T_VARIABLE 22590) (T_YIELD 22591) (T_YIELD_FROM 22592) ("[" 22593) ("`" 22594) (array_object_dereferenceable 22595) (attribute 131) (attributes 22596) (callable_expr 22597) (callable_variable 22598) (class_constant 22599) (class_name 22600) (constant 22601) (dereferenceable_scalar 22602) (expr 23602) (fn 22604) (fully_dereferenceable 104) #'22605 (function_call 22606) (inline_function 22607) (internal_functions_in_yacc 22608) (match 22609) (name 22610) (new_expr 22611) (scalar 22612) (simple_variable 22613) (static_member 22614) (variable 22615) (variable_class_name 22616) ("~" 22617)) 11103 (("%" 22619) ("*" 22620) ("+" 22621) ("-" 22622) ("." 22623) ("/" 22624) ("<" 22625) (">" 22626) ("?" 22627) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 22628) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 22629) (T_BOOLEAN_AND 22630) (T_BOOLEAN_OR 22631) (T_COALESCE 22632) (T_INSTANCEOF 22633) (T_IS_EQUAL 22634) (T_IS_GREATER_OR_EQUAL 22635) (T_IS_IDENTICAL 22636) (T_IS_NOT_EQUAL 22637) (T_IS_NOT_IDENTICAL 22638) (T_IS_SMALLER_OR_EQUAL 22639) (T_LOGICAL_AND 22640) (T_LOGICAL_OR 22641) (T_LOGICAL_XOR 22642) (T_POW 22643) (T_SL 22644) (T_SPACESHIP 22645) (T_SR 22646) ("^" 22647) (backup_fn_flags 23603) ("|" 22648)) 11104 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 23605) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 11105 (("$" 23225) (T_ABSTRACT 23403) (T_ARRAY 23404) (T_AS 23405) (T_BREAK 23406) (T_CALLABLE 23407) (T_CASE 23408) (T_CATCH 23409) (T_CLASS 23410) (T_CLASS_C 23411) (T_CLONE 23412) (T_CONST 23413) (T_CONTINUE 23414) (T_DECLARE 23415) (T_DEFAULT 23416) (T_DIR 23417) (T_DO 23418) (T_ECHO 23419) (T_ELSE 23420) (T_ELSEIF 23421) (T_EMPTY 23422) (T_ENDDECLARE 23423) (T_ENDFOR 23424) (T_ENDFOREACH 23425) (T_ENDIF 23426) (T_ENDSWITCH 23427) (T_ENDWHILE 23428) (T_ENUM 23429) (T_EVAL 23430) (T_EXIT 23431) (T_EXTENDS 23432) (T_FILE 23433) (T_FINAL 23434) (T_FINALLY 23435) (T_FN 23436) (T_FOR 23437) (T_FOREACH 23438) (T_FUNCTION 23439) (T_FUNC_C 23440) (T_GLOBAL 23441) (T_GOTO 23442) (T_IF 23443) (T_IMPLEMENTS 23444) (T_INCLUDE 23445) (T_INCLUDE_ONCE 23446) (T_INSTANCEOF 23447) (T_INSTEADOF 23448) (T_INTERFACE 23449) (T_ISSET 23450) (T_LINE 23451) (T_LIST 23452) (T_LOGICAL_AND 23453) (T_LOGICAL_OR 23454) (T_LOGICAL_XOR 23455) (T_MATCH 23456) (T_METHOD_C 23457) (T_NAMESPACE 23458) (T_NEW 23459) (T_NS_C 23460) (T_PRINT 23461) (T_PRIVATE 23462) (T_PROTECTED 23463) (T_PUBLIC 23464) (T_READONLY 23465) (T_REQUIRE 23466) (T_REQUIRE_ONCE 23467) (T_RETURN 23468) (T_STATIC 23469) (T_STRING 23470) (T_SWITCH 23471) (T_THROW 23472) (T_TRAIT 23473) (T_TRAIT_C 23474) (T_TRY 23475) (T_UNSET 23476) (T_USE 23477) (T_VAR 23478) (T_VARIABLE 23272) (T_WHILE 23479) (T_YIELD 23480) (identifier 23607) (member_name 23608) (reserved_non_modifiers 23483) (semi_reserved 23484) (simple_variable 23609) ("{" 23610)) 11106 (("(" 23489) (argument_list 23613)) 11107 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 23611) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 11108 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 23612)) 11109 ((T_FN 35) (T_FUNCTION 127) (fn 23286) #'23287 (inline_function 23617)) 11110 (("$" 23225) (T_STRING 23626) (T_VARIABLE 23272) (property_name 23633) (simple_variable 23628) ("{" 23629)) 11111 (("$" 23225) (T_STRING 23626) (T_VARIABLE 23272) (property_name 23627) (simple_variable 23628) ("{" 23629)) 11112 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 23624) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 11113 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 23622) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 11114 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 23623)) 11115 (("]" 23625)) 11116 (("(" 23489) (argument_list 23632)) 11117 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 23630) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 11118 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 23631)) 11119 (("(" 23489) (argument_list 23634)) 11120 (("`" 23636)) 11121 (("]" 23638)) 11122 (("=" 23639)) 11123 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23640) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 11124 (("%" 23301) ("*" 23302) ("+" 23303) ("-" 23304) ("." 23305) ("/" 23306) ("<" 23307) (">" 23308) ("?" 23309) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 23310) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 23311) (T_BOOLEAN_AND 23312) (T_BOOLEAN_OR 23313) (T_COALESCE 23314) (T_DOUBLE_ARROW 23643) (T_INSTANCEOF 23315) (T_IS_EQUAL 23316) (T_IS_GREATER_OR_EQUAL 23317) (T_IS_IDENTICAL 23318) (T_IS_NOT_EQUAL 23319) (T_IS_NOT_IDENTICAL 23320) (T_IS_SMALLER_OR_EQUAL 23321) (T_LOGICAL_AND 23322) (T_LOGICAL_OR 23323) (T_LOGICAL_XOR 23324) (T_POW 23325) (T_SL 23326) (T_SPACESHIP 23327) (T_SR 23328) ("^" 23329) ("|" 23330)) 11125 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23644) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 11126 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 23653) (T_VARIABLE 2900) (encaps_var 2914)) 11127 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 23652) (T_VARIABLE 2900) (encaps_var 2905)) 11128 ((T_CLASS 23673)) 11129 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 23672) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 23660) (attribute 2980) (class_modifier 2945)) 11130 (("(" 23663) (argument_list 23664) (ctor_arguments 23665)) 11131 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 23666) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 23667) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 23668) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 11132 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 23671) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 11133 (("," 1469) (possible_comma 23669)) 11134 ((")" 23670)) 11135 (("(" 2982) (argument_list 2983) (ctor_arguments 23674)) 11136 ((T_EXTENDS 2985) (extends_from 23675)) 11137 ((T_IMPLEMENTS 2987) (implements_list 23676)) 11138 ((backup_doc_comment 23677)) 11139 (("{" 23678)) 11140 ((class_statement_list 23679)) 11141 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 23680)) 11142 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 23682) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 11143 (("%" 292) (")" 23683) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 11144 (("{" 23684)) 11145 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 23685) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 11146 (("}" 23686)) 11147 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 23688) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 11148 ((")" 23689)) 11149 (("=" 23690)) 11150 (("!" 23223) ("\"" 23224) ("$" 23225) ("(" 23226) ("+" 23227) ("-" 23228) ("@" 23229) (T_ARRAY 23230) (T_ARRAY_CAST 23231) (T_ATTRIBUTE 126) (T_BOOL_CAST 23232) (T_CLASS_C 23233) (T_CLONE 23234) (T_CONSTANT_ENCAPSED_STRING 23235) (T_DEC 23236) (T_DIR 23237) (T_DNUMBER 23238) (T_DOUBLE_CAST 23239) (T_EMPTY 23240) (T_EVAL 23241) (T_EXIT 23242) (T_FILE 23243) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 23244) (T_INC 23245) (T_INCLUDE 23246) (T_INCLUDE_ONCE 23247) (T_INT_CAST 23248) (T_ISSET 23249) (T_LINE 23250) (T_LIST 23251) (T_LNUMBER 23252) (T_MATCH 23253) (T_METHOD_C 23254) (T_NAME_FULLY_QUALIFIED 23255) (T_NAME_QUALIFIED 23256) (T_NAME_RELATIVE 23257) (T_NEW 23258) (T_NS_C 23259) (T_OBJECT_CAST 23260) (T_PRINT 23261) (T_READONLY 23262) (T_REQUIRE 23263) (T_REQUIRE_ONCE 23264) (T_START_HEREDOC 23265) (T_STATIC 23266) (T_STRING 23267) (T_STRING_CAST 23268) (T_THROW 23269) (T_TRAIT_C 23270) (T_UNSET_CAST 23271) (T_VARIABLE 23272) (T_YIELD 23273) (T_YIELD_FROM 23274) ("[" 23275) ("`" 23276) (array_object_dereferenceable 23277) (attribute 131) (attributes 23278) (callable_expr 23279) (callable_variable 23280) (class_constant 23281) (class_name 23282) (constant 23283) (dereferenceable_scalar 23284) (expr 23691) (fn 23286) (fully_dereferenceable 104) #'23287 (function_call 23288) (inline_function 23289) (internal_functions_in_yacc 23290) (match 23291) (name 23292) (new_expr 23293) (scalar 23294) (simple_variable 23295) (static_member 23296) (variable 23297) (variable_class_name 23298) ("~" 23299)) 11151 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 23693) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 11152 (("," 5258) (possible_comma 23694)) 11153 ((")" 23695)) 11154 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 23702) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 11155 ((")" 23703)) 11156 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 23705) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 11157 (("%" 292) (")" 23706) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 11158 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 23708) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 11159 (("%" 292) (")" 23709) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 11160 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 23716) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 11161 ((")" 23717)) 11162 (("%" 292) (")" 23722) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 11163 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 23725) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 11164 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 23726)) 11165 (("\"" 23728) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 11166 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 23738) (T_VARIABLE 2900) (encaps_var 2914)) 11167 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 23737) (T_VARIABLE 2900) (encaps_var 2905)) 11168 ((T_CLASS 23758)) 11169 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 23757) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 23745) (attribute 2980) (class_modifier 2945)) 11170 (("(" 23748) (argument_list 23749) (ctor_arguments 23750)) 11171 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 23751) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 23752) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 23753) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 11172 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 23756) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 11173 (("," 1469) (possible_comma 23754)) 11174 ((")" 23755)) 11175 (("(" 2982) (argument_list 2983) (ctor_arguments 23759)) 11176 ((T_EXTENDS 2985) (extends_from 23760)) 11177 ((T_IMPLEMENTS 2987) (implements_list 23761)) 11178 ((backup_doc_comment 23762)) 11179 (("{" 23763)) 11180 ((class_statement_list 23764)) 11181 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 23765)) 11182 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 23767) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 11183 (("%" 292) (")" 23768) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 11184 (("{" 23769)) 11185 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 23770) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 11186 (("}" 23771)) 11187 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 23773) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 11188 ((")" 23774)) 11189 (("=" 23775)) 11190 (("!" 21744) ("\"" 21745) ("$" 21746) ("(" 21747) ("+" 21748) ("-" 21749) ("@" 21750) (T_ARRAY 21751) (T_ARRAY_CAST 21752) (T_ATTRIBUTE 126) (T_BOOL_CAST 21753) (T_CLASS_C 21754) (T_CLONE 21755) (T_CONSTANT_ENCAPSED_STRING 21756) (T_DEC 21757) (T_DIR 21758) (T_DNUMBER 21759) (T_DOUBLE_CAST 21760) (T_EMPTY 21761) (T_EVAL 21762) (T_EXIT 21763) (T_FILE 21764) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 21765) (T_INC 21766) (T_INCLUDE 21767) (T_INCLUDE_ONCE 21768) (T_INT_CAST 21769) (T_ISSET 21770) (T_LINE 21771) (T_LIST 21772) (T_LNUMBER 21773) (T_MATCH 21774) (T_METHOD_C 21775) (T_NAME_FULLY_QUALIFIED 21776) (T_NAME_QUALIFIED 21777) (T_NAME_RELATIVE 21778) (T_NEW 21779) (T_NS_C 21780) (T_OBJECT_CAST 21781) (T_PRINT 21782) (T_READONLY 21783) (T_REQUIRE 21784) (T_REQUIRE_ONCE 21785) (T_START_HEREDOC 21786) (T_STATIC 21787) (T_STRING 21788) (T_STRING_CAST 21789) (T_THROW 21790) (T_TRAIT_C 21791) (T_UNSET_CAST 21792) (T_VARIABLE 21793) (T_YIELD 21794) (T_YIELD_FROM 21795) ("[" 21796) ("`" 21797) (array_object_dereferenceable 21798) (attribute 131) (attributes 21799) (callable_expr 21800) (callable_variable 21801) (class_constant 21802) (class_name 21803) (constant 21804) (dereferenceable_scalar 21805) (expr 23776) (fn 21807) (fully_dereferenceable 104) #'21808 (function_call 21809) (inline_function 21810) (internal_functions_in_yacc 21811) (match 21812) (name 21813) (new_expr 21814) (scalar 21815) (simple_variable 21816) (static_member 21817) (variable 21818) (variable_class_name 21819) ("~" 21820)) 11191 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 23778) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 11192 (("," 5258) (possible_comma 23779)) 11193 ((")" 23780)) 11194 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 23787) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 11195 ((")" 23788)) 11196 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 23790) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 11197 (("%" 292) (")" 23791) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 11198 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 23793) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 11199 (("%" 292) (")" 23794) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 11200 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 23801) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 11201 ((")" 23802)) 11202 (("%" 292) (")" 23807) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 11203 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 23810) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 11204 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 23811)) 11205 (("\"" 23813) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 11206 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 23816)) 11207 ((";" 23817)) 11208 (("," 16852) (";" 23820)) 11209 ((";" 23822)) 11210 ((";" 23824)) 11211 (("," 17875) (";" 23826)) 11212 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 23828) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 11213 (("%" 17961) ("*" 17962) ("+" 17963) ("-" 17964) ("." 17965) ("/" 17966) ("<" 17967) (">" 17968) ("?" 17969) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 17970) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 17971) (T_AS 23829) (T_BOOLEAN_AND 17972) (T_BOOLEAN_OR 17973) (T_COALESCE 17974) (T_INSTANCEOF 17975) (T_IS_EQUAL 17976) (T_IS_GREATER_OR_EQUAL 17977) (T_IS_IDENTICAL 17978) (T_IS_NOT_EQUAL 17979) (T_IS_NOT_IDENTICAL 17980) (T_IS_SMALLER_OR_EQUAL 17981) (T_LOGICAL_AND 17982) (T_LOGICAL_OR 17983) (T_LOGICAL_XOR 17984) (T_POW 17985) (T_SL 17986) (T_SPACESHIP 17987) (T_SR 17988) ("^" 17989) ("|" 17990)) 11214 (("\"" 1509) ("$" 19325) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19326) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19327) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19328) ("[" 19329) (ampersand 19330) (array_object_dereferenceable 19331) (callable_expr 19332) (callable_variable 19333) (class_constant 1533) (class_name 19334) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 23830) (fully_dereferenceable 104) (function_call 19336) (name 19337) (simple_variable 19338) (static_member 19339) (variable 19340) (variable_class_name 19341)) 11215 ((")" 23831) (T_DOUBLE_ARROW 23832)) 11216 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 23835) (";" 16624) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16625) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16626) (T_DEC 22) (T_DECLARE 16627) (T_DIR 24) (T_DNUMBER 25) (T_DO 16628) (T_DOUBLE_CAST 27) (T_ECHO 16629) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16630) (T_FOREACH 16631) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16632) (T_GOTO 16633) (T_IF 16589) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16634) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16635) (T_START_HEREDOC 68) (T_STATIC 16636) (T_STRING 16637) (T_STRING_CAST 71) (T_SWITCH 16638) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16639) (T_UNSET 16640) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16641) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16642) (alt_if_stmt_without_else 16643) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16644) (fn 103) (foreach_statement 23841) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16645) (if_stmt_without_else 16646) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 23837) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16648) ("~" 125)) 11217 (("\"" 1509) ("$" 19356) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19357) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19358) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19359) ("[" 19360) (ampersand 19361) (array_object_dereferenceable 19362) (callable_expr 19363) (callable_variable 19364) (class_constant 1533) (class_name 19365) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 23833) (fully_dereferenceable 104) (function_call 19367) (name 19368) (simple_variable 19369) (static_member 19370) (variable 19371) (variable_class_name 19372)) 11218 ((")" 23834)) 11219 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 23835) (";" 16624) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16625) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16626) (T_DEC 22) (T_DECLARE 16627) (T_DIR 24) (T_DNUMBER 25) (T_DO 16628) (T_DOUBLE_CAST 27) (T_ECHO 16629) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16630) (T_FOREACH 16631) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16632) (T_GOTO 16633) (T_IF 16589) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16634) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16635) (T_START_HEREDOC 68) (T_STATIC 16636) (T_STRING 16637) (T_STRING_CAST 71) (T_SWITCH 16638) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16639) (T_UNSET 16640) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16641) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16642) (alt_if_stmt_without_else 16643) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16644) (fn 103) (foreach_statement 23836) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16645) (if_stmt_without_else 16646) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 23837) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16648) ("~" 125)) 11220 ((inner_statement_list 23838)) 11221 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19390) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19391) (T_CLASS 19392) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19393) (T_DEC 22) (T_DECLARE 19394) (T_DIR 24) (T_DNUMBER 25) (T_DO 19395) (T_DOUBLE_CAST 27) (T_ECHO 19396) (T_EMPTY 29) (T_ENDFOREACH 23839) (T_ENUM 19398) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19399) (T_FOREACH 19400) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19401) (T_GOTO 19402) (T_HALT_COMPILER 19403) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19405) (T_INTERFACE 19406) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19407) (T_START_HEREDOC 68) (T_STATIC 19408) (T_STRING 19409) (T_STRING_CAST 71) (T_SWITCH 19410) (T_THROW 73) (T_TRAIT 19411) (T_TRAIT_C 75) (T_TRY 19412) (T_UNSET 19413) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19414) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19415) (alt_if_stmt_without_else 19416) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19417) (attributes 19418) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19419) (class_modifier 96) (class_modifiers 19420) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19421) (expr 19422) (fn 103) (fully_dereferenceable 104) #'19423 (function_call 106) (function_declaration_statement 19424) (if_stmt 19425) (if_stmt_without_else 19426) (inline_function 110) (inner_statement 19427) (interface_declaration_statement 19428) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19429) (static_member 119) (trait_declaration_statement 19430) (variable 122) (variable_class_name 123) ("{" 19431) ("~" 125)) 11222 ((";" 23840)) 11223 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 23843) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 11224 ((";" 23844)) 11225 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 23845) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 11226 ((";" 23846)) 11227 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 19558) (fn 2394) (for_exprs 23847) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (non_empty_for_exprs 19560) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 11228 ((")" 23848)) 11229 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 23849) (";" 16624) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16625) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16626) (T_DEC 22) (T_DECLARE 16627) (T_DIR 24) (T_DNUMBER 25) (T_DO 16628) (T_DOUBLE_CAST 27) (T_ECHO 16629) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16630) (T_FOREACH 16631) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16632) (T_GOTO 16633) (T_IF 16589) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16634) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16635) (T_START_HEREDOC 68) (T_STATIC 16636) (T_STRING 16637) (T_STRING_CAST 71) (T_SWITCH 16638) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16639) (T_UNSET 16640) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16641) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16642) (alt_if_stmt_without_else 16643) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16644) (fn 103) (for_statement 23850) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16645) (if_stmt_without_else 16646) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 23851) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16648) ("~" 125)) 11230 ((inner_statement_list 23852)) 11231 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19568) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19569) (T_CLASS 19570) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19571) (T_DEC 22) (T_DECLARE 19572) (T_DIR 24) (T_DNUMBER 25) (T_DO 19573) (T_DOUBLE_CAST 27) (T_ECHO 19574) (T_EMPTY 29) (T_ENDFOR 23853) (T_ENUM 19576) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19577) (T_FOREACH 19578) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19579) (T_GOTO 19580) (T_HALT_COMPILER 19581) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19583) (T_INTERFACE 19584) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19585) (T_START_HEREDOC 68) (T_STATIC 19586) (T_STRING 19587) (T_STRING_CAST 71) (T_SWITCH 19588) (T_THROW 73) (T_TRAIT 19589) (T_TRAIT_C 75) (T_TRY 19590) (T_UNSET 19591) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19592) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19593) (alt_if_stmt_without_else 19594) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19595) (attributes 19596) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19597) (class_modifier 96) (class_modifiers 19598) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19599) (expr 19600) (fn 103) (fully_dereferenceable 104) #'19601 (function_call 106) (function_declaration_statement 19602) (if_stmt 19603) (if_stmt_without_else 19604) (inline_function 110) (inner_statement 19605) (interface_declaration_statement 19606) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19607) (static_member 119) (trait_declaration_statement 19608) (variable 122) (variable_class_name 123) ("{" 19609) ("~" 125)) 11232 ((";" 23854)) 11233 (("," 19743) (";" 23856)) 11234 ((T_WHILE 23858)) 11235 (("(" 23859)) 11236 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 23860) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 11237 (("%" 292) (")" 23861) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 11238 ((";" 23862)) 11239 ((T_STRING 19916) (const_decl 19917) (const_list 23864)) 11240 ((")" 23865) ("," 19920)) 11241 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 23866) (";" 16624) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16625) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16626) (T_DEC 22) (T_DECLARE 16627) (T_DIR 24) (T_DNUMBER 25) (T_DO 16628) (T_DOUBLE_CAST 27) (T_ECHO 16629) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16630) (T_FOREACH 16631) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16632) (T_GOTO 16633) (T_IF 16589) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16634) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16635) (T_START_HEREDOC 68) (T_STATIC 16636) (T_STRING 16637) (T_STRING_CAST 71) (T_SWITCH 16638) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16639) (T_UNSET 16640) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16641) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16642) (alt_if_stmt_without_else 16643) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (declare_statement 23867) (dereferenceable_scalar 100) (expr 16644) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16645) (if_stmt_without_else 16646) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 23868) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16648) ("~" 125)) 11242 ((inner_statement_list 23869)) 11243 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19926) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19927) (T_CLASS 19928) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19929) (T_DEC 22) (T_DECLARE 19930) (T_DIR 24) (T_DNUMBER 25) (T_DO 19931) (T_DOUBLE_CAST 27) (T_ECHO 19932) (T_EMPTY 29) (T_ENDDECLARE 23870) (T_ENUM 19934) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19935) (T_FOREACH 19936) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19937) (T_GOTO 19938) (T_HALT_COMPILER 19939) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19941) (T_INTERFACE 19942) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19943) (T_START_HEREDOC 68) (T_STATIC 19944) (T_STRING 19945) (T_STRING_CAST 71) (T_SWITCH 19946) (T_THROW 73) (T_TRAIT 19947) (T_TRAIT_C 75) (T_TRY 19948) (T_UNSET 19949) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19950) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19951) (alt_if_stmt_without_else 19952) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19953) (attributes 19954) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19955) (class_modifier 96) (class_modifiers 19956) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19957) (expr 19958) (fn 103) (fully_dereferenceable 104) #'19959 (function_call 106) (function_declaration_statement 19960) (if_stmt 19961) (if_stmt_without_else 19962) (inline_function 110) (inner_statement 19963) (interface_declaration_statement 19964) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19965) (static_member 119) (trait_declaration_statement 19966) (variable 122) (variable_class_name 123) ("{" 19967) ("~" 125)) 11244 ((";" 23871)) 11245 ((";" 23873)) 11246 ((";" 23875)) 11247 ((T_READONLY 16265) (T_STRING 16266) (backup_doc_comment 139) (function_name 23878)) 11248 ((backup_doc_comment 23879)) 11249 (("(" 23880)) 11250 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 23881)) 11251 ((")" 23882)) 11252 ((":" 161) (return_type 23883)) 11253 ((backup_fn_flags 23884)) 11254 (("{" 23885)) 11255 ((inner_statement_list 23886)) 11256 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 23887) ("~" 125)) 11257 ((backup_fn_flags 23888)) 11258 ((T_STRING 23891)) 11259 ((T_EXTENDS 2985) (extends_from 23892)) 11260 ((T_IMPLEMENTS 2987) (implements_list 23893)) 11261 ((backup_doc_comment 23894)) 11262 (("{" 23895)) 11263 ((class_statement_list 23896)) 11264 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 23897)) 11265 ((":" 23902)) 11266 ((";" 23901)) 11267 ((inner_statement_list 23903)) 11268 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16298) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16299) (T_CLASS 16300) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16301) (T_DEC 22) (T_DECLARE 16302) (T_DIR 24) (T_DNUMBER 25) (T_DO 16303) (T_DOUBLE_CAST 27) (T_ECHO 16304) (T_EMPTY 29) (T_ENDIF 23904) (T_ENUM 16306) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16307) (T_FOREACH 16308) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16309) (T_GOTO 16310) (T_HALT_COMPILER 16311) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16312) (T_INTERFACE 16313) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16314) (T_START_HEREDOC 68) (T_STATIC 16315) (T_STRING 16316) (T_STRING_CAST 71) (T_SWITCH 16317) (T_THROW 73) (T_TRAIT 16318) (T_TRAIT_C 75) (T_TRY 16319) (T_UNSET 16320) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16321) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16322) (alt_if_stmt_without_else 16323) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16324) (attributes 16325) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16326) (class_modifier 96) (class_modifiers 16327) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16328) (expr 16329) (fn 103) (fully_dereferenceable 104) #'16330 (function_call 106) (function_declaration_statement 16331) (if_stmt 16332) (if_stmt_without_else 16333) (inline_function 110) (inner_statement 16334) (interface_declaration_statement 16335) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16336) (static_member 119) (trait_declaration_statement 16337) (variable 122) (variable_class_name 123) ("{" 16338) ("~" 125)) 11269 ((";" 23905)) 11270 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 23907) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 11271 (("%" 292) (")" 23908) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 11272 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 23909) (";" 16576) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16577) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16579) (T_DEC 22) (T_DECLARE 16580) (T_DIR 24) (T_DNUMBER 25) (T_DO 16581) (T_DOUBLE_CAST 27) (T_ECHO 16582) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16584) (T_FOREACH 16585) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16586) (T_GOTO 16587) (T_IF 16589) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16590) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16592) (T_START_HEREDOC 68) (T_STATIC 16593) (T_STRING 16594) (T_STRING_CAST 71) (T_SWITCH 16595) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16597) (T_UNSET 16598) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16599) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16600) (alt_if_stmt_without_else 16601) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16607) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16610) (if_stmt_without_else 16611) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 23910) (static_member 119) (variable 122) (variable_class_name 123) (while_statement 23911) ("{" 16616) ("~" 125)) 11273 ((inner_statement_list 23912)) 11274 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16379) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16380) (T_CLASS 16381) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16382) (T_DEC 22) (T_DECLARE 16383) (T_DIR 24) (T_DNUMBER 25) (T_DO 16384) (T_DOUBLE_CAST 27) (T_ECHO 16385) (T_EMPTY 29) (T_ENDWHILE 23913) (T_ENUM 16387) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16388) (T_FOREACH 16389) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16390) (T_GOTO 16391) (T_HALT_COMPILER 16392) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16394) (T_INTERFACE 16395) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16396) (T_START_HEREDOC 68) (T_STATIC 16397) (T_STRING 16398) (T_STRING_CAST 71) (T_SWITCH 16399) (T_THROW 73) (T_TRAIT 16400) (T_TRAIT_C 75) (T_TRY 16401) (T_UNSET 16402) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16403) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16404) (alt_if_stmt_without_else 16405) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16406) (attributes 16407) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16408) (class_modifier 96) (class_modifiers 16409) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16410) (expr 16411) (fn 103) (fully_dereferenceable 104) #'16412 (function_call 106) (function_declaration_statement 16413) (if_stmt 16414) (if_stmt_without_else 16415) (inline_function 110) (inner_statement 16416) (interface_declaration_statement 16417) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16418) (static_member 119) (trait_declaration_statement 16419) (variable 122) (variable_class_name 123) ("{" 16420) ("~" 125)) 11275 ((";" 23914)) 11276 (("\"" 1509) ("$" 16475) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 16476) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 16477) ("[" 1529) (array_object_dereferenceable 16478) (callable_expr 16479) (callable_variable 16480) (class_constant 1533) (class_name 16481) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 16482) (name 16483) (simple_variable 16484) (static_member 16485) (unset_variable 16486) (unset_variables 23916) (variable 16488) (variable_class_name 16489)) 11277 (("," 16501) (possible_comma 23917)) 11278 ((")" 23918)) 11279 ((";" 23919)) 11280 ((inner_statement_list 23921)) 11281 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 23922) ("~" 125)) 11282 ((catch_list 23923)) 11283 ((T_CATCH 23924) (T_FINALLY 23925) (finally_statement 23926)) 11284 (("(" 23930)) 11285 (("{" 23927)) 11286 ((inner_statement_list 23928)) 11287 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 23929) ("~" 125)) 11288 ((T_NAME_FULLY_QUALIFIED 16545) (T_NAME_QUALIFIED 16546) (T_NAME_RELATIVE 16547) (T_STATIC 16548) (T_STRING 16549) (catch_name_list 23931) (class_name 16551) (name 16552)) 11289 ((T_VARIABLE 16553) (optional_variable 23932) ("|" 16555)) 11290 ((")" 23933)) 11291 (("{" 23934)) 11292 ((inner_statement_list 23935)) 11293 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 23936) ("~" 125)) 11294 ((backup_doc_comment 23938)) 11295 (("{" 23939)) 11296 ((class_statement_list 23940)) 11297 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 23941)) 11298 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 23943) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 11299 (("%" 292) (")" 23944) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 11300 ((":" 23945) (switch_case_list 23946) ("{" 23947)) 11301 ((";" 23953) (case_list 23954)) 11302 ((";" 23948) (case_list 23949)) 11303 ((case_list 23951)) 11304 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 23950)) 11305 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 23952)) 11306 ((case_list 23957)) 11307 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 23955)) 11308 ((";" 23956)) 11309 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 23958)) 11310 ((";" 23959)) 11311 (("," 16852) (";" 23962)) 11312 ((";" 23964)) 11313 ((T_EXTENDS 20209) (interface_extends_list 23966)) 11314 ((backup_doc_comment 23967)) 11315 (("{" 23968)) 11316 ((class_statement_list 23969)) 11317 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 23970)) 11318 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 23972) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 11319 (("%" 292) (")" 23973) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 11320 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20219) (";" 16624) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16625) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16626) (T_DEC 22) (T_DECLARE 16627) (T_DIR 24) (T_DNUMBER 25) (T_DO 16628) (T_DOUBLE_CAST 27) (T_ECHO 16629) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16630) (T_FOREACH 16631) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16632) (T_GOTO 16633) (T_IF 16589) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16634) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16635) (T_START_HEREDOC 68) (T_STATIC 16636) (T_STRING 16637) (T_STRING_CAST 71) (T_SWITCH 16638) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16639) (T_UNSET 16640) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16641) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16642) (alt_if_stmt_without_else 16643) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16644) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16645) (if_stmt_without_else 16646) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 23974) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16648) ("~" 125)) 11321 ((")" 23976)) 11322 ((";" 23977)) 11323 ((";" 23979)) 11324 (("," 17875) (";" 23981)) 11325 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 23983) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 11326 (("%" 17961) ("*" 17962) ("+" 17963) ("-" 17964) ("." 17965) ("/" 17966) ("<" 17967) (">" 17968) ("?" 17969) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 17970) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 17971) (T_AS 23984) (T_BOOLEAN_AND 17972) (T_BOOLEAN_OR 17973) (T_COALESCE 17974) (T_INSTANCEOF 17975) (T_IS_EQUAL 17976) (T_IS_GREATER_OR_EQUAL 17977) (T_IS_IDENTICAL 17978) (T_IS_NOT_EQUAL 17979) (T_IS_NOT_IDENTICAL 17980) (T_IS_SMALLER_OR_EQUAL 17981) (T_LOGICAL_AND 17982) (T_LOGICAL_OR 17983) (T_LOGICAL_XOR 17984) (T_POW 17985) (T_SL 17986) (T_SPACESHIP 17987) (T_SR 17988) ("^" 17989) ("|" 17990)) 11327 (("\"" 1509) ("$" 19325) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19326) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19327) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19328) ("[" 19329) (ampersand 19330) (array_object_dereferenceable 19331) (callable_expr 19332) (callable_variable 19333) (class_constant 1533) (class_name 19334) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 23985) (fully_dereferenceable 104) (function_call 19336) (name 19337) (simple_variable 19338) (static_member 19339) (variable 19340) (variable_class_name 19341)) 11328 ((")" 23986) (T_DOUBLE_ARROW 23987)) 11329 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 23990) (";" 16576) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16577) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16579) (T_DEC 22) (T_DECLARE 16580) (T_DIR 24) (T_DNUMBER 25) (T_DO 16581) (T_DOUBLE_CAST 27) (T_ECHO 16582) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16584) (T_FOREACH 16585) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16586) (T_GOTO 16587) (T_IF 16589) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16590) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16592) (T_START_HEREDOC 68) (T_STATIC 16593) (T_STRING 16594) (T_STRING_CAST 71) (T_SWITCH 16595) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16597) (T_UNSET 16598) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16599) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16600) (alt_if_stmt_without_else 16601) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16607) (fn 103) (foreach_statement 23996) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16610) (if_stmt_without_else 16611) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 23992) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16616) ("~" 125)) 11330 (("\"" 1509) ("$" 19356) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19357) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19358) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19359) ("[" 19360) (ampersand 19361) (array_object_dereferenceable 19362) (callable_expr 19363) (callable_variable 19364) (class_constant 1533) (class_name 19365) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 23988) (fully_dereferenceable 104) (function_call 19367) (name 19368) (simple_variable 19369) (static_member 19370) (variable 19371) (variable_class_name 19372)) 11331 ((")" 23989)) 11332 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 23990) (";" 16576) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16577) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16579) (T_DEC 22) (T_DECLARE 16580) (T_DIR 24) (T_DNUMBER 25) (T_DO 16581) (T_DOUBLE_CAST 27) (T_ECHO 16582) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16584) (T_FOREACH 16585) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16586) (T_GOTO 16587) (T_IF 16589) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16590) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16592) (T_START_HEREDOC 68) (T_STATIC 16593) (T_STRING 16594) (T_STRING_CAST 71) (T_SWITCH 16595) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16597) (T_UNSET 16598) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16599) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16600) (alt_if_stmt_without_else 16601) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16607) (fn 103) (foreach_statement 23991) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16610) (if_stmt_without_else 16611) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 23992) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16616) ("~" 125)) 11333 ((inner_statement_list 23993)) 11334 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19390) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19391) (T_CLASS 19392) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19393) (T_DEC 22) (T_DECLARE 19394) (T_DIR 24) (T_DNUMBER 25) (T_DO 19395) (T_DOUBLE_CAST 27) (T_ECHO 19396) (T_EMPTY 29) (T_ENDFOREACH 23994) (T_ENUM 19398) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19399) (T_FOREACH 19400) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19401) (T_GOTO 19402) (T_HALT_COMPILER 19403) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19405) (T_INTERFACE 19406) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19407) (T_START_HEREDOC 68) (T_STATIC 19408) (T_STRING 19409) (T_STRING_CAST 71) (T_SWITCH 19410) (T_THROW 73) (T_TRAIT 19411) (T_TRAIT_C 75) (T_TRY 19412) (T_UNSET 19413) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19414) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19415) (alt_if_stmt_without_else 19416) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19417) (attributes 19418) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19419) (class_modifier 96) (class_modifiers 19420) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19421) (expr 19422) (fn 103) (fully_dereferenceable 104) #'19423 (function_call 106) (function_declaration_statement 19424) (if_stmt 19425) (if_stmt_without_else 19426) (inline_function 110) (inner_statement 19427) (interface_declaration_statement 19428) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19429) (static_member 119) (trait_declaration_statement 19430) (variable 122) (variable_class_name 123) ("{" 19431) ("~" 125)) 11335 ((";" 23995)) 11336 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 23998) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 11337 ((";" 23999)) 11338 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 24000) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 11339 ((";" 24001)) 11340 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 19558) (fn 2394) (for_exprs 24002) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (non_empty_for_exprs 19560) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 11341 ((")" 24003)) 11342 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 24004) (";" 16576) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16577) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16579) (T_DEC 22) (T_DECLARE 16580) (T_DIR 24) (T_DNUMBER 25) (T_DO 16581) (T_DOUBLE_CAST 27) (T_ECHO 16582) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16584) (T_FOREACH 16585) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16586) (T_GOTO 16587) (T_IF 16589) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16590) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16592) (T_START_HEREDOC 68) (T_STATIC 16593) (T_STRING 16594) (T_STRING_CAST 71) (T_SWITCH 16595) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16597) (T_UNSET 16598) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16599) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16600) (alt_if_stmt_without_else 16601) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16607) (fn 103) (for_statement 24005) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16610) (if_stmt_without_else 16611) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 24006) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16616) ("~" 125)) 11343 ((inner_statement_list 24007)) 11344 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19568) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19569) (T_CLASS 19570) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19571) (T_DEC 22) (T_DECLARE 19572) (T_DIR 24) (T_DNUMBER 25) (T_DO 19573) (T_DOUBLE_CAST 27) (T_ECHO 19574) (T_EMPTY 29) (T_ENDFOR 24008) (T_ENUM 19576) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19577) (T_FOREACH 19578) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19579) (T_GOTO 19580) (T_HALT_COMPILER 19581) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19583) (T_INTERFACE 19584) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19585) (T_START_HEREDOC 68) (T_STATIC 19586) (T_STRING 19587) (T_STRING_CAST 71) (T_SWITCH 19588) (T_THROW 73) (T_TRAIT 19589) (T_TRAIT_C 75) (T_TRY 19590) (T_UNSET 19591) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19592) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19593) (alt_if_stmt_without_else 19594) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19595) (attributes 19596) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19597) (class_modifier 96) (class_modifiers 19598) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19599) (expr 19600) (fn 103) (fully_dereferenceable 104) #'19601 (function_call 106) (function_declaration_statement 19602) (if_stmt 19603) (if_stmt_without_else 19604) (inline_function 110) (inner_statement 19605) (interface_declaration_statement 19606) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19607) (static_member 119) (trait_declaration_statement 19608) (variable 122) (variable_class_name 123) ("{" 19609) ("~" 125)) 11345 ((";" 24009)) 11346 ((":" 20258) (enum_backing_type 24011)) 11347 ((T_IMPLEMENTS 2987) (implements_list 24012)) 11348 ((backup_doc_comment 24013)) 11349 (("{" 24014)) 11350 ((class_statement_list 24015)) 11351 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 24016)) 11352 (("," 19743) (";" 24018)) 11353 ((T_WHILE 24020)) 11354 (("(" 24021)) 11355 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 24022) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 11356 (("%" 292) (")" 24023) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 11357 ((";" 24024)) 11358 ((T_STRING 19916) (const_decl 19917) (const_list 24026)) 11359 ((")" 24027) ("," 19920)) 11360 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 24028) (";" 16576) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16577) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16579) (T_DEC 22) (T_DECLARE 16580) (T_DIR 24) (T_DNUMBER 25) (T_DO 16581) (T_DOUBLE_CAST 27) (T_ECHO 16582) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16584) (T_FOREACH 16585) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16586) (T_GOTO 16587) (T_IF 16589) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16590) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16592) (T_START_HEREDOC 68) (T_STATIC 16593) (T_STRING 16594) (T_STRING_CAST 71) (T_SWITCH 16595) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16597) (T_UNSET 16598) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16599) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16600) (alt_if_stmt_without_else 16601) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (declare_statement 24029) (dereferenceable_scalar 100) (expr 16607) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16610) (if_stmt_without_else 16611) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 24030) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16616) ("~" 125)) 11361 ((inner_statement_list 24031)) 11362 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19926) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19927) (T_CLASS 19928) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19929) (T_DEC 22) (T_DECLARE 19930) (T_DIR 24) (T_DNUMBER 25) (T_DO 19931) (T_DOUBLE_CAST 27) (T_ECHO 19932) (T_EMPTY 29) (T_ENDDECLARE 24032) (T_ENUM 19934) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19935) (T_FOREACH 19936) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19937) (T_GOTO 19938) (T_HALT_COMPILER 19939) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19941) (T_INTERFACE 19942) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19943) (T_START_HEREDOC 68) (T_STATIC 19944) (T_STRING 19945) (T_STRING_CAST 71) (T_SWITCH 19946) (T_THROW 73) (T_TRAIT 19947) (T_TRAIT_C 75) (T_TRY 19948) (T_UNSET 19949) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19950) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19951) (alt_if_stmt_without_else 19952) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19953) (attributes 19954) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19955) (class_modifier 96) (class_modifiers 19956) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19957) (expr 19958) (fn 103) (fully_dereferenceable 104) #'19959 (function_call 106) (function_declaration_statement 19960) (if_stmt 19961) (if_stmt_without_else 19962) (inline_function 110) (inner_statement 19963) (interface_declaration_statement 19964) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19965) (static_member 119) (trait_declaration_statement 19966) (variable 122) (variable_class_name 123) ("{" 19967) ("~" 125)) 11363 ((";" 24033)) 11364 ((";" 24035)) 11365 ((T_EXTENDS 2985) (extends_from 24037)) 11366 ((T_IMPLEMENTS 2987) (implements_list 24038)) 11367 ((backup_doc_comment 24039)) 11368 (("{" 24040)) 11369 ((class_statement_list 24041)) 11370 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 24042)) 11371 ((";" 24044)) 11372 (("%" 21822) ("*" 21823) ("+" 21824) ("-" 21825) ("." 21826) ("/" 21827) (":" 16572) (";" 16573) ("<" 21828) (">" 21829) ("?" 21830) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 21831) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 21832) (T_BOOLEAN_AND 21833) (T_BOOLEAN_OR 21834) (T_COALESCE 21835) (T_INSTANCEOF 21836) (T_IS_EQUAL 21837) (T_IS_GREATER_OR_EQUAL 21838) (T_IS_IDENTICAL 21839) (T_IS_NOT_EQUAL 21840) (T_IS_NOT_IDENTICAL 21841) (T_IS_SMALLER_OR_EQUAL 21842) (T_LOGICAL_AND 21843) (T_LOGICAL_OR 21844) (T_LOGICAL_XOR 21845) (T_POW 21846) (T_SL 21847) (T_SPACESHIP 21848) (T_SR 21849) ("^" 21850) (case_separator 24046) ("|" 21851)) 11373 ((inner_statement_list 24047)) 11374 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 24049)) 11375 ((case_list 24054)) 11376 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 24052)) 11377 ((";" 24053)) 11378 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 24055)) 11379 ((";" 24056)) 11380 (("," 16852) (";" 24059)) 11381 ((";" 24061)) 11382 ((";" 24063)) 11383 (("," 17875) (";" 24065)) 11384 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 24067) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 11385 (("%" 17961) ("*" 17962) ("+" 17963) ("-" 17964) ("." 17965) ("/" 17966) ("<" 17967) (">" 17968) ("?" 17969) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 17970) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 17971) (T_AS 24068) (T_BOOLEAN_AND 17972) (T_BOOLEAN_OR 17973) (T_COALESCE 17974) (T_INSTANCEOF 17975) (T_IS_EQUAL 17976) (T_IS_GREATER_OR_EQUAL 17977) (T_IS_IDENTICAL 17978) (T_IS_NOT_EQUAL 17979) (T_IS_NOT_IDENTICAL 17980) (T_IS_SMALLER_OR_EQUAL 17981) (T_LOGICAL_AND 17982) (T_LOGICAL_OR 17983) (T_LOGICAL_XOR 17984) (T_POW 17985) (T_SL 17986) (T_SPACESHIP 17987) (T_SR 17988) ("^" 17989) ("|" 17990)) 11386 (("\"" 1509) ("$" 19325) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19326) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19327) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19328) ("[" 19329) (ampersand 19330) (array_object_dereferenceable 19331) (callable_expr 19332) (callable_variable 19333) (class_constant 1533) (class_name 19334) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 24069) (fully_dereferenceable 104) (function_call 19336) (name 19337) (simple_variable 19338) (static_member 19339) (variable 19340) (variable_class_name 19341)) 11387 ((")" 24070) (T_DOUBLE_ARROW 24071)) 11388 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 24074) (";" 16428) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16429) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16430) (T_DEC 22) (T_DECLARE 16431) (T_DIR 24) (T_DNUMBER 25) (T_DO 16432) (T_DOUBLE_CAST 27) (T_ECHO 16433) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16434) (T_FOREACH 16435) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16436) (T_GOTO 16437) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16438) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16439) (T_START_HEREDOC 68) (T_STATIC 16440) (T_STRING 16441) (T_STRING_CAST 71) (T_SWITCH 16442) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16443) (T_UNSET 16444) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16445) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16446) (alt_if_stmt_without_else 16447) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16448) (fn 103) (foreach_statement 24080) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16449) (if_stmt_without_else 16450) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 24076) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16452) ("~" 125)) 11389 (("\"" 1509) ("$" 19356) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19357) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19358) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19359) ("[" 19360) (ampersand 19361) (array_object_dereferenceable 19362) (callable_expr 19363) (callable_variable 19364) (class_constant 1533) (class_name 19365) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 24072) (fully_dereferenceable 104) (function_call 19367) (name 19368) (simple_variable 19369) (static_member 19370) (variable 19371) (variable_class_name 19372)) 11390 ((")" 24073)) 11391 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 24074) (";" 16428) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16429) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16430) (T_DEC 22) (T_DECLARE 16431) (T_DIR 24) (T_DNUMBER 25) (T_DO 16432) (T_DOUBLE_CAST 27) (T_ECHO 16433) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16434) (T_FOREACH 16435) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16436) (T_GOTO 16437) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16438) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16439) (T_START_HEREDOC 68) (T_STATIC 16440) (T_STRING 16441) (T_STRING_CAST 71) (T_SWITCH 16442) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16443) (T_UNSET 16444) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16445) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16446) (alt_if_stmt_without_else 16447) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16448) (fn 103) (foreach_statement 24075) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16449) (if_stmt_without_else 16450) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 24076) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16452) ("~" 125)) 11392 ((inner_statement_list 24077)) 11393 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19390) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19391) (T_CLASS 19392) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19393) (T_DEC 22) (T_DECLARE 19394) (T_DIR 24) (T_DNUMBER 25) (T_DO 19395) (T_DOUBLE_CAST 27) (T_ECHO 19396) (T_EMPTY 29) (T_ENDFOREACH 24078) (T_ENUM 19398) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19399) (T_FOREACH 19400) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19401) (T_GOTO 19402) (T_HALT_COMPILER 19403) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19405) (T_INTERFACE 19406) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19407) (T_START_HEREDOC 68) (T_STATIC 19408) (T_STRING 19409) (T_STRING_CAST 71) (T_SWITCH 19410) (T_THROW 73) (T_TRAIT 19411) (T_TRAIT_C 75) (T_TRY 19412) (T_UNSET 19413) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19414) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19415) (alt_if_stmt_without_else 19416) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19417) (attributes 19418) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19419) (class_modifier 96) (class_modifiers 19420) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19421) (expr 19422) (fn 103) (fully_dereferenceable 104) #'19423 (function_call 106) (function_declaration_statement 19424) (if_stmt 19425) (if_stmt_without_else 19426) (inline_function 110) (inner_statement 19427) (interface_declaration_statement 19428) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19429) (static_member 119) (trait_declaration_statement 19430) (variable 122) (variable_class_name 123) ("{" 19431) ("~" 125)) 11394 ((";" 24079)) 11395 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 24082) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 11396 ((";" 24083)) 11397 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 24084) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 11398 ((";" 24085)) 11399 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 19558) (fn 2394) (for_exprs 24086) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (non_empty_for_exprs 19560) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 11400 ((")" 24087)) 11401 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 24088) (";" 16428) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16429) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16430) (T_DEC 22) (T_DECLARE 16431) (T_DIR 24) (T_DNUMBER 25) (T_DO 16432) (T_DOUBLE_CAST 27) (T_ECHO 16433) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16434) (T_FOREACH 16435) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16436) (T_GOTO 16437) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16438) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16439) (T_START_HEREDOC 68) (T_STATIC 16440) (T_STRING 16441) (T_STRING_CAST 71) (T_SWITCH 16442) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16443) (T_UNSET 16444) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16445) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16446) (alt_if_stmt_without_else 16447) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16448) (fn 103) (for_statement 24089) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16449) (if_stmt_without_else 16450) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 24090) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16452) ("~" 125)) 11402 ((inner_statement_list 24091)) 11403 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19568) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19569) (T_CLASS 19570) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19571) (T_DEC 22) (T_DECLARE 19572) (T_DIR 24) (T_DNUMBER 25) (T_DO 19573) (T_DOUBLE_CAST 27) (T_ECHO 19574) (T_EMPTY 29) (T_ENDFOR 24092) (T_ENUM 19576) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19577) (T_FOREACH 19578) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19579) (T_GOTO 19580) (T_HALT_COMPILER 19581) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19583) (T_INTERFACE 19584) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19585) (T_START_HEREDOC 68) (T_STATIC 19586) (T_STRING 19587) (T_STRING_CAST 71) (T_SWITCH 19588) (T_THROW 73) (T_TRAIT 19589) (T_TRAIT_C 75) (T_TRY 19590) (T_UNSET 19591) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19592) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19593) (alt_if_stmt_without_else 19594) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19595) (attributes 19596) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19597) (class_modifier 96) (class_modifiers 19598) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19599) (expr 19600) (fn 103) (fully_dereferenceable 104) #'19601 (function_call 106) (function_declaration_statement 19602) (if_stmt 19603) (if_stmt_without_else 19604) (inline_function 110) (inner_statement 19605) (interface_declaration_statement 19606) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19607) (static_member 119) (trait_declaration_statement 19608) (variable 122) (variable_class_name 123) ("{" 19609) ("~" 125)) 11404 ((";" 24093)) 11405 (("," 19743) (";" 24095)) 11406 ((T_WHILE 24097)) 11407 (("(" 24098)) 11408 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 24099) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 11409 (("%" 292) (")" 24100) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 11410 ((";" 24101)) 11411 ((T_STRING 19916) (const_decl 19917) (const_list 24103)) 11412 ((")" 24104) ("," 19920)) 11413 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 24105) (";" 16428) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16429) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16430) (T_DEC 22) (T_DECLARE 16431) (T_DIR 24) (T_DNUMBER 25) (T_DO 16432) (T_DOUBLE_CAST 27) (T_ECHO 16433) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16434) (T_FOREACH 16435) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16436) (T_GOTO 16437) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16438) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16439) (T_START_HEREDOC 68) (T_STATIC 16440) (T_STRING 16441) (T_STRING_CAST 71) (T_SWITCH 16442) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16443) (T_UNSET 16444) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16445) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16446) (alt_if_stmt_without_else 16447) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (declare_statement 24106) (dereferenceable_scalar 100) (expr 16448) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16449) (if_stmt_without_else 16450) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 24107) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16452) ("~" 125)) 11414 ((inner_statement_list 24108)) 11415 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19926) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19927) (T_CLASS 19928) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19929) (T_DEC 22) (T_DECLARE 19930) (T_DIR 24) (T_DNUMBER 25) (T_DO 19931) (T_DOUBLE_CAST 27) (T_ECHO 19932) (T_EMPTY 29) (T_ENDDECLARE 24109) (T_ENUM 19934) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19935) (T_FOREACH 19936) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19937) (T_GOTO 19938) (T_HALT_COMPILER 19939) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19941) (T_INTERFACE 19942) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19943) (T_START_HEREDOC 68) (T_STATIC 19944) (T_STRING 19945) (T_STRING_CAST 71) (T_SWITCH 19946) (T_THROW 73) (T_TRAIT 19947) (T_TRAIT_C 75) (T_TRY 19948) (T_UNSET 19949) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19950) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19951) (alt_if_stmt_without_else 19952) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19953) (attributes 19954) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19955) (class_modifier 96) (class_modifiers 19956) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19957) (expr 19958) (fn 103) (fully_dereferenceable 104) #'19959 (function_call 106) (function_declaration_statement 19960) (if_stmt 19961) (if_stmt_without_else 19962) (inline_function 110) (inner_statement 19963) (interface_declaration_statement 19964) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19965) (static_member 119) (trait_declaration_statement 19966) (variable 122) (variable_class_name 123) ("{" 19967) ("~" 125)) 11416 ((";" 24110)) 11417 ((";" 24112)) 11418 ((";" 24114)) 11419 ((T_READONLY 16265) (T_STRING 16266) (backup_doc_comment 139) (function_name 24117)) 11420 ((backup_doc_comment 24118)) 11421 (("(" 24119)) 11422 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 24120)) 11423 ((")" 24121)) 11424 ((":" 161) (return_type 24122)) 11425 ((backup_fn_flags 24123)) 11426 (("{" 24124)) 11427 ((inner_statement_list 24125)) 11428 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 24126) ("~" 125)) 11429 ((backup_fn_flags 24127)) 11430 ((T_STRING 24130)) 11431 ((T_EXTENDS 2985) (extends_from 24131)) 11432 ((T_IMPLEMENTS 2987) (implements_list 24132)) 11433 ((backup_doc_comment 24133)) 11434 (("{" 24134)) 11435 ((class_statement_list 24135)) 11436 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 24136)) 11437 ((":" 24141)) 11438 ((";" 24140)) 11439 ((inner_statement_list 24142)) 11440 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16298) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16299) (T_CLASS 16300) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16301) (T_DEC 22) (T_DECLARE 16302) (T_DIR 24) (T_DNUMBER 25) (T_DO 16303) (T_DOUBLE_CAST 27) (T_ECHO 16304) (T_EMPTY 29) (T_ENDIF 24143) (T_ENUM 16306) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16307) (T_FOREACH 16308) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16309) (T_GOTO 16310) (T_HALT_COMPILER 16311) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16312) (T_INTERFACE 16313) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16314) (T_START_HEREDOC 68) (T_STATIC 16315) (T_STRING 16316) (T_STRING_CAST 71) (T_SWITCH 16317) (T_THROW 73) (T_TRAIT 16318) (T_TRAIT_C 75) (T_TRY 16319) (T_UNSET 16320) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16321) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16322) (alt_if_stmt_without_else 16323) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16324) (attributes 16325) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16326) (class_modifier 96) (class_modifiers 16327) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16328) (expr 16329) (fn 103) (fully_dereferenceable 104) #'16330 (function_call 106) (function_declaration_statement 16331) (if_stmt 16332) (if_stmt_without_else 16333) (inline_function 110) (inner_statement 16334) (interface_declaration_statement 16335) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16336) (static_member 119) (trait_declaration_statement 16337) (variable 122) (variable_class_name 123) ("{" 16338) ("~" 125)) 11441 ((";" 24144)) 11442 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 24146) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 11443 (("%" 292) (")" 24147) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 11444 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 24148) (";" 16379) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16380) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16382) (T_DEC 22) (T_DECLARE 16383) (T_DIR 24) (T_DNUMBER 25) (T_DO 16384) (T_DOUBLE_CAST 27) (T_ECHO 16385) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16388) (T_FOREACH 16389) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16390) (T_GOTO 16391) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16394) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16396) (T_START_HEREDOC 68) (T_STATIC 16397) (T_STRING 16398) (T_STRING_CAST 71) (T_SWITCH 16399) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16401) (T_UNSET 16402) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16403) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16404) (alt_if_stmt_without_else 16405) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16411) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16414) (if_stmt_without_else 16415) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 24149) (static_member 119) (variable 122) (variable_class_name 123) (while_statement 24150) ("{" 16420) ("~" 125)) 11445 ((inner_statement_list 24151)) 11446 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16379) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16380) (T_CLASS 16381) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16382) (T_DEC 22) (T_DECLARE 16383) (T_DIR 24) (T_DNUMBER 25) (T_DO 16384) (T_DOUBLE_CAST 27) (T_ECHO 16385) (T_EMPTY 29) (T_ENDWHILE 24152) (T_ENUM 16387) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16388) (T_FOREACH 16389) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16390) (T_GOTO 16391) (T_HALT_COMPILER 16392) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16394) (T_INTERFACE 16395) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16396) (T_START_HEREDOC 68) (T_STATIC 16397) (T_STRING 16398) (T_STRING_CAST 71) (T_SWITCH 16399) (T_THROW 73) (T_TRAIT 16400) (T_TRAIT_C 75) (T_TRY 16401) (T_UNSET 16402) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16403) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16404) (alt_if_stmt_without_else 16405) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16406) (attributes 16407) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16408) (class_modifier 96) (class_modifiers 16409) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16410) (expr 16411) (fn 103) (fully_dereferenceable 104) #'16412 (function_call 106) (function_declaration_statement 16413) (if_stmt 16414) (if_stmt_without_else 16415) (inline_function 110) (inner_statement 16416) (interface_declaration_statement 16417) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16418) (static_member 119) (trait_declaration_statement 16419) (variable 122) (variable_class_name 123) ("{" 16420) ("~" 125)) 11447 ((";" 24153)) 11448 (("\"" 1509) ("$" 16475) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 16476) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 16477) ("[" 1529) (array_object_dereferenceable 16478) (callable_expr 16479) (callable_variable 16480) (class_constant 1533) (class_name 16481) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 16482) (name 16483) (simple_variable 16484) (static_member 16485) (unset_variable 16486) (unset_variables 24155) (variable 16488) (variable_class_name 16489)) 11449 (("," 16501) (possible_comma 24156)) 11450 ((")" 24157)) 11451 ((";" 24158)) 11452 ((inner_statement_list 24160)) 11453 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 24161) ("~" 125)) 11454 ((catch_list 24162)) 11455 ((T_CATCH 24163) (T_FINALLY 24164) (finally_statement 24165)) 11456 (("(" 24169)) 11457 (("{" 24166)) 11458 ((inner_statement_list 24167)) 11459 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 24168) ("~" 125)) 11460 ((T_NAME_FULLY_QUALIFIED 16545) (T_NAME_QUALIFIED 16546) (T_NAME_RELATIVE 16547) (T_STATIC 16548) (T_STRING 16549) (catch_name_list 24170) (class_name 16551) (name 16552)) 11461 ((T_VARIABLE 16553) (optional_variable 24171) ("|" 16555)) 11462 ((")" 24172)) 11463 (("{" 24173)) 11464 ((inner_statement_list 24174)) 11465 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 24175) ("~" 125)) 11466 ((backup_doc_comment 24177)) 11467 (("{" 24178)) 11468 ((class_statement_list 24179)) 11469 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 24180)) 11470 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 24182) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 11471 (("%" 292) (")" 24183) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 11472 ((":" 24184) (switch_case_list 24185) ("{" 24186)) 11473 ((";" 24192) (case_list 24193)) 11474 ((";" 24187) (case_list 24188)) 11475 ((case_list 24190)) 11476 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 24189)) 11477 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 24191)) 11478 ((case_list 24196)) 11479 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 24194)) 11480 ((";" 24195)) 11481 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 24197)) 11482 ((";" 24198)) 11483 (("," 16852) (";" 24201)) 11484 ((";" 24203)) 11485 ((T_EXTENDS 20209) (interface_extends_list 24205)) 11486 ((backup_doc_comment 24206)) 11487 (("{" 24207)) 11488 ((class_statement_list 24208)) 11489 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 24209)) 11490 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 24211) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 11491 (("%" 292) (")" 24212) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 11492 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20219) (";" 16428) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16429) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16430) (T_DEC 22) (T_DECLARE 16431) (T_DIR 24) (T_DNUMBER 25) (T_DO 16432) (T_DOUBLE_CAST 27) (T_ECHO 16433) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16434) (T_FOREACH 16435) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16436) (T_GOTO 16437) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16438) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16439) (T_START_HEREDOC 68) (T_STATIC 16440) (T_STRING 16441) (T_STRING_CAST 71) (T_SWITCH 16442) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16443) (T_UNSET 16444) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16445) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16446) (alt_if_stmt_without_else 16447) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16448) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16449) (if_stmt_without_else 16450) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 24213) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16452) ("~" 125)) 11493 ((")" 24215)) 11494 ((";" 24216)) 11495 ((";" 24218)) 11496 (("," 17875) (";" 24220)) 11497 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 24222) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 11498 (("%" 17961) ("*" 17962) ("+" 17963) ("-" 17964) ("." 17965) ("/" 17966) ("<" 17967) (">" 17968) ("?" 17969) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 17970) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 17971) (T_AS 24223) (T_BOOLEAN_AND 17972) (T_BOOLEAN_OR 17973) (T_COALESCE 17974) (T_INSTANCEOF 17975) (T_IS_EQUAL 17976) (T_IS_GREATER_OR_EQUAL 17977) (T_IS_IDENTICAL 17978) (T_IS_NOT_EQUAL 17979) (T_IS_NOT_IDENTICAL 17980) (T_IS_SMALLER_OR_EQUAL 17981) (T_LOGICAL_AND 17982) (T_LOGICAL_OR 17983) (T_LOGICAL_XOR 17984) (T_POW 17985) (T_SL 17986) (T_SPACESHIP 17987) (T_SR 17988) ("^" 17989) ("|" 17990)) 11499 (("\"" 1509) ("$" 19325) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19326) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19327) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19328) ("[" 19329) (ampersand 19330) (array_object_dereferenceable 19331) (callable_expr 19332) (callable_variable 19333) (class_constant 1533) (class_name 19334) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 24224) (fully_dereferenceable 104) (function_call 19336) (name 19337) (simple_variable 19338) (static_member 19339) (variable 19340) (variable_class_name 19341)) 11500 ((")" 24225) (T_DOUBLE_ARROW 24226)) 11501 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 24229) (";" 16379) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16380) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16382) (T_DEC 22) (T_DECLARE 16383) (T_DIR 24) (T_DNUMBER 25) (T_DO 16384) (T_DOUBLE_CAST 27) (T_ECHO 16385) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16388) (T_FOREACH 16389) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16390) (T_GOTO 16391) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16394) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16396) (T_START_HEREDOC 68) (T_STATIC 16397) (T_STRING 16398) (T_STRING_CAST 71) (T_SWITCH 16399) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16401) (T_UNSET 16402) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16403) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16404) (alt_if_stmt_without_else 16405) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16411) (fn 103) (foreach_statement 24235) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16414) (if_stmt_without_else 16415) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 24231) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16420) ("~" 125)) 11502 (("\"" 1509) ("$" 19356) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19357) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19358) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19359) ("[" 19360) (ampersand 19361) (array_object_dereferenceable 19362) (callable_expr 19363) (callable_variable 19364) (class_constant 1533) (class_name 19365) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 24227) (fully_dereferenceable 104) (function_call 19367) (name 19368) (simple_variable 19369) (static_member 19370) (variable 19371) (variable_class_name 19372)) 11503 ((")" 24228)) 11504 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 24229) (";" 16379) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16380) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16382) (T_DEC 22) (T_DECLARE 16383) (T_DIR 24) (T_DNUMBER 25) (T_DO 16384) (T_DOUBLE_CAST 27) (T_ECHO 16385) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16388) (T_FOREACH 16389) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16390) (T_GOTO 16391) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16394) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16396) (T_START_HEREDOC 68) (T_STATIC 16397) (T_STRING 16398) (T_STRING_CAST 71) (T_SWITCH 16399) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16401) (T_UNSET 16402) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16403) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16404) (alt_if_stmt_without_else 16405) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16411) (fn 103) (foreach_statement 24230) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16414) (if_stmt_without_else 16415) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 24231) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16420) ("~" 125)) 11505 ((inner_statement_list 24232)) 11506 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19390) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19391) (T_CLASS 19392) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19393) (T_DEC 22) (T_DECLARE 19394) (T_DIR 24) (T_DNUMBER 25) (T_DO 19395) (T_DOUBLE_CAST 27) (T_ECHO 19396) (T_EMPTY 29) (T_ENDFOREACH 24233) (T_ENUM 19398) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19399) (T_FOREACH 19400) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19401) (T_GOTO 19402) (T_HALT_COMPILER 19403) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19405) (T_INTERFACE 19406) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19407) (T_START_HEREDOC 68) (T_STATIC 19408) (T_STRING 19409) (T_STRING_CAST 71) (T_SWITCH 19410) (T_THROW 73) (T_TRAIT 19411) (T_TRAIT_C 75) (T_TRY 19412) (T_UNSET 19413) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19414) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19415) (alt_if_stmt_without_else 19416) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19417) (attributes 19418) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19419) (class_modifier 96) (class_modifiers 19420) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19421) (expr 19422) (fn 103) (fully_dereferenceable 104) #'19423 (function_call 106) (function_declaration_statement 19424) (if_stmt 19425) (if_stmt_without_else 19426) (inline_function 110) (inner_statement 19427) (interface_declaration_statement 19428) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19429) (static_member 119) (trait_declaration_statement 19430) (variable 122) (variable_class_name 123) ("{" 19431) ("~" 125)) 11507 ((";" 24234)) 11508 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 24237) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 11509 ((";" 24238)) 11510 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 24239) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 11511 ((";" 24240)) 11512 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 19558) (fn 2394) (for_exprs 24241) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (non_empty_for_exprs 19560) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 11513 ((")" 24242)) 11514 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 24243) (";" 16379) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16380) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16382) (T_DEC 22) (T_DECLARE 16383) (T_DIR 24) (T_DNUMBER 25) (T_DO 16384) (T_DOUBLE_CAST 27) (T_ECHO 16385) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16388) (T_FOREACH 16389) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16390) (T_GOTO 16391) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16394) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16396) (T_START_HEREDOC 68) (T_STATIC 16397) (T_STRING 16398) (T_STRING_CAST 71) (T_SWITCH 16399) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16401) (T_UNSET 16402) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16403) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16404) (alt_if_stmt_without_else 16405) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16411) (fn 103) (for_statement 24244) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16414) (if_stmt_without_else 16415) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 24245) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16420) ("~" 125)) 11515 ((inner_statement_list 24246)) 11516 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19568) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19569) (T_CLASS 19570) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19571) (T_DEC 22) (T_DECLARE 19572) (T_DIR 24) (T_DNUMBER 25) (T_DO 19573) (T_DOUBLE_CAST 27) (T_ECHO 19574) (T_EMPTY 29) (T_ENDFOR 24247) (T_ENUM 19576) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19577) (T_FOREACH 19578) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19579) (T_GOTO 19580) (T_HALT_COMPILER 19581) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19583) (T_INTERFACE 19584) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19585) (T_START_HEREDOC 68) (T_STATIC 19586) (T_STRING 19587) (T_STRING_CAST 71) (T_SWITCH 19588) (T_THROW 73) (T_TRAIT 19589) (T_TRAIT_C 75) (T_TRY 19590) (T_UNSET 19591) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19592) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19593) (alt_if_stmt_without_else 19594) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19595) (attributes 19596) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19597) (class_modifier 96) (class_modifiers 19598) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19599) (expr 19600) (fn 103) (fully_dereferenceable 104) #'19601 (function_call 106) (function_declaration_statement 19602) (if_stmt 19603) (if_stmt_without_else 19604) (inline_function 110) (inner_statement 19605) (interface_declaration_statement 19606) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19607) (static_member 119) (trait_declaration_statement 19608) (variable 122) (variable_class_name 123) ("{" 19609) ("~" 125)) 11517 ((";" 24248)) 11518 ((":" 20258) (enum_backing_type 24250)) 11519 ((T_IMPLEMENTS 2987) (implements_list 24251)) 11520 ((backup_doc_comment 24252)) 11521 (("{" 24253)) 11522 ((class_statement_list 24254)) 11523 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 24255)) 11524 (("," 19743) (";" 24258)) 11525 ((T_WHILE 24260)) 11526 (("(" 24261)) 11527 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 24262) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 11528 (("%" 292) (")" 24263) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 11529 ((";" 24264)) 11530 ((T_STRING 19916) (const_decl 19917) (const_list 24266)) 11531 ((")" 24267) ("," 19920)) 11532 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 24268) (";" 16379) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16380) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16382) (T_DEC 22) (T_DECLARE 16383) (T_DIR 24) (T_DNUMBER 25) (T_DO 16384) (T_DOUBLE_CAST 27) (T_ECHO 16385) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16388) (T_FOREACH 16389) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16390) (T_GOTO 16391) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16394) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16396) (T_START_HEREDOC 68) (T_STATIC 16397) (T_STRING 16398) (T_STRING_CAST 71) (T_SWITCH 16399) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16401) (T_UNSET 16402) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16403) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16404) (alt_if_stmt_without_else 16405) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (declare_statement 24269) (dereferenceable_scalar 100) (expr 16411) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16414) (if_stmt_without_else 16415) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 24270) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16420) ("~" 125)) 11533 ((inner_statement_list 24271)) 11534 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19926) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19927) (T_CLASS 19928) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19929) (T_DEC 22) (T_DECLARE 19930) (T_DIR 24) (T_DNUMBER 25) (T_DO 19931) (T_DOUBLE_CAST 27) (T_ECHO 19932) (T_EMPTY 29) (T_ENDDECLARE 24272) (T_ENUM 19934) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19935) (T_FOREACH 19936) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19937) (T_GOTO 19938) (T_HALT_COMPILER 19939) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19941) (T_INTERFACE 19942) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19943) (T_START_HEREDOC 68) (T_STATIC 19944) (T_STRING 19945) (T_STRING_CAST 71) (T_SWITCH 19946) (T_THROW 73) (T_TRAIT 19947) (T_TRAIT_C 75) (T_TRY 19948) (T_UNSET 19949) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19950) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19951) (alt_if_stmt_without_else 19952) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19953) (attributes 19954) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19955) (class_modifier 96) (class_modifiers 19956) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19957) (expr 19958) (fn 103) (fully_dereferenceable 104) #'19959 (function_call 106) (function_declaration_statement 19960) (if_stmt 19961) (if_stmt_without_else 19962) (inline_function 110) (inner_statement 19963) (interface_declaration_statement 19964) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19965) (static_member 119) (trait_declaration_statement 19966) (variable 122) (variable_class_name 123) ("{" 19967) ("~" 125)) 11535 ((";" 24273)) 11536 ((";" 24275)) 11537 ((T_EXTENDS 2985) (extends_from 24277)) 11538 ((T_IMPLEMENTS 2987) (implements_list 24278)) 11539 ((backup_doc_comment 24279)) 11540 (("{" 24280)) 11541 ((class_statement_list 24281)) 11542 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 24282)) 11543 ((";" 24284)) 11544 (("\"" 1509) ("$" 16475) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 16476) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 16477) ("[" 1529) (array_object_dereferenceable 16478) (callable_expr 16479) (callable_variable 16480) (class_constant 1533) (class_name 16481) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 16482) (name 16483) (simple_variable 16484) (static_member 16485) (unset_variable 16486) (unset_variables 24286) (variable 16488) (variable_class_name 16489)) 11545 (("," 16501) (possible_comma 24287)) 11546 ((")" 24288)) 11547 ((";" 24289)) 11548 ((inner_statement_list 24291)) 11549 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 24292) ("~" 125)) 11550 ((catch_list 24293)) 11551 ((T_CATCH 24294) (T_FINALLY 24295) (finally_statement 24296)) 11552 (("(" 24300)) 11553 (("{" 24297)) 11554 ((inner_statement_list 24298)) 11555 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 24299) ("~" 125)) 11556 ((T_NAME_FULLY_QUALIFIED 16545) (T_NAME_QUALIFIED 16546) (T_NAME_RELATIVE 16547) (T_STATIC 16548) (T_STRING 16549) (catch_name_list 24301) (class_name 16551) (name 16552)) 11557 ((T_VARIABLE 16553) (optional_variable 24302) ("|" 16555)) 11558 ((")" 24303)) 11559 (("{" 24304)) 11560 ((inner_statement_list 24305)) 11561 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 24306) ("~" 125)) 11562 ((backup_doc_comment 24308)) 11563 (("{" 24309)) 11564 ((class_statement_list 24310)) 11565 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 24311)) 11566 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 24313) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 11567 (("%" 292) (")" 24314) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 11568 ((":" 24315) (switch_case_list 24316) ("{" 24317)) 11569 ((";" 24323) (case_list 24324)) 11570 ((";" 24318) (case_list 24319)) 11571 ((case_list 24321)) 11572 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 24320)) 11573 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 24322)) 11574 ((case_list 24327)) 11575 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 24325)) 11576 ((";" 24326)) 11577 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 24328)) 11578 ((";" 24329)) 11579 (("," 16852) (";" 24332)) 11580 ((";" 24334)) 11581 ((T_EXTENDS 20209) (interface_extends_list 24336)) 11582 ((backup_doc_comment 24337)) 11583 (("{" 24338)) 11584 ((class_statement_list 24339)) 11585 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 24340)) 11586 ((")" 24342)) 11587 ((";" 24343)) 11588 ((";" 24345)) 11589 (("," 17875) (";" 24347)) 11590 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 24349) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 11591 (("%" 17961) ("*" 17962) ("+" 17963) ("-" 17964) ("." 17965) ("/" 17966) ("<" 17967) (">" 17968) ("?" 17969) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 17970) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 17971) (T_AS 24350) (T_BOOLEAN_AND 17972) (T_BOOLEAN_OR 17973) (T_COALESCE 17974) (T_INSTANCEOF 17975) (T_IS_EQUAL 17976) (T_IS_GREATER_OR_EQUAL 17977) (T_IS_IDENTICAL 17978) (T_IS_NOT_EQUAL 17979) (T_IS_NOT_IDENTICAL 17980) (T_IS_SMALLER_OR_EQUAL 17981) (T_LOGICAL_AND 17982) (T_LOGICAL_OR 17983) (T_LOGICAL_XOR 17984) (T_POW 17985) (T_SL 17986) (T_SPACESHIP 17987) (T_SR 17988) ("^" 17989) ("|" 17990)) 11592 (("\"" 1509) ("$" 19325) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19326) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19327) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19328) ("[" 19329) (ampersand 19330) (array_object_dereferenceable 19331) (callable_expr 19332) (callable_variable 19333) (class_constant 1533) (class_name 19334) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 24351) (fully_dereferenceable 104) (function_call 19336) (name 19337) (simple_variable 19338) (static_member 19339) (variable 19340) (variable_class_name 19341)) 11593 ((")" 24352) (T_DOUBLE_ARROW 24353)) 11594 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 24356) (";" 16298) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16299) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16301) (T_DEC 22) (T_DECLARE 16302) (T_DIR 24) (T_DNUMBER 25) (T_DO 16303) (T_DOUBLE_CAST 27) (T_ECHO 16304) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16307) (T_FOREACH 16308) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16309) (T_GOTO 16310) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16312) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16314) (T_START_HEREDOC 68) (T_STATIC 16315) (T_STRING 16316) (T_STRING_CAST 71) (T_SWITCH 16317) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16319) (T_UNSET 16320) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16321) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16322) (alt_if_stmt_without_else 16323) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16329) (fn 103) (foreach_statement 24362) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16332) (if_stmt_without_else 16333) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 24358) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16338) ("~" 125)) 11595 (("\"" 1509) ("$" 19356) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19357) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19358) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19359) ("[" 19360) (ampersand 19361) (array_object_dereferenceable 19362) (callable_expr 19363) (callable_variable 19364) (class_constant 1533) (class_name 19365) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 24354) (fully_dereferenceable 104) (function_call 19367) (name 19368) (simple_variable 19369) (static_member 19370) (variable 19371) (variable_class_name 19372)) 11596 ((")" 24355)) 11597 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 24356) (";" 16298) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16299) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16301) (T_DEC 22) (T_DECLARE 16302) (T_DIR 24) (T_DNUMBER 25) (T_DO 16303) (T_DOUBLE_CAST 27) (T_ECHO 16304) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16307) (T_FOREACH 16308) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16309) (T_GOTO 16310) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16312) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16314) (T_START_HEREDOC 68) (T_STATIC 16315) (T_STRING 16316) (T_STRING_CAST 71) (T_SWITCH 16317) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16319) (T_UNSET 16320) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16321) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16322) (alt_if_stmt_without_else 16323) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16329) (fn 103) (foreach_statement 24357) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16332) (if_stmt_without_else 16333) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 24358) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16338) ("~" 125)) 11598 ((inner_statement_list 24359)) 11599 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19390) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19391) (T_CLASS 19392) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19393) (T_DEC 22) (T_DECLARE 19394) (T_DIR 24) (T_DNUMBER 25) (T_DO 19395) (T_DOUBLE_CAST 27) (T_ECHO 19396) (T_EMPTY 29) (T_ENDFOREACH 24360) (T_ENUM 19398) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19399) (T_FOREACH 19400) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19401) (T_GOTO 19402) (T_HALT_COMPILER 19403) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19405) (T_INTERFACE 19406) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19407) (T_START_HEREDOC 68) (T_STATIC 19408) (T_STRING 19409) (T_STRING_CAST 71) (T_SWITCH 19410) (T_THROW 73) (T_TRAIT 19411) (T_TRAIT_C 75) (T_TRY 19412) (T_UNSET 19413) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19414) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19415) (alt_if_stmt_without_else 19416) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19417) (attributes 19418) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19419) (class_modifier 96) (class_modifiers 19420) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19421) (expr 19422) (fn 103) (fully_dereferenceable 104) #'19423 (function_call 106) (function_declaration_statement 19424) (if_stmt 19425) (if_stmt_without_else 19426) (inline_function 110) (inner_statement 19427) (interface_declaration_statement 19428) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19429) (static_member 119) (trait_declaration_statement 19430) (variable 122) (variable_class_name 123) ("{" 19431) ("~" 125)) 11600 ((";" 24361)) 11601 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 24364) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 11602 ((";" 24365)) 11603 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 24366) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 11604 ((";" 24367)) 11605 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 19558) (fn 2394) (for_exprs 24368) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (non_empty_for_exprs 19560) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 11606 ((")" 24369)) 11607 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 24370) (";" 16298) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16299) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16301) (T_DEC 22) (T_DECLARE 16302) (T_DIR 24) (T_DNUMBER 25) (T_DO 16303) (T_DOUBLE_CAST 27) (T_ECHO 16304) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16307) (T_FOREACH 16308) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16309) (T_GOTO 16310) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16312) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16314) (T_START_HEREDOC 68) (T_STATIC 16315) (T_STRING 16316) (T_STRING_CAST 71) (T_SWITCH 16317) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16319) (T_UNSET 16320) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16321) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16322) (alt_if_stmt_without_else 16323) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16329) (fn 103) (for_statement 24371) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16332) (if_stmt_without_else 16333) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 24372) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16338) ("~" 125)) 11608 ((inner_statement_list 24373)) 11609 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19568) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19569) (T_CLASS 19570) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19571) (T_DEC 22) (T_DECLARE 19572) (T_DIR 24) (T_DNUMBER 25) (T_DO 19573) (T_DOUBLE_CAST 27) (T_ECHO 19574) (T_EMPTY 29) (T_ENDFOR 24374) (T_ENUM 19576) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19577) (T_FOREACH 19578) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19579) (T_GOTO 19580) (T_HALT_COMPILER 19581) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19583) (T_INTERFACE 19584) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19585) (T_START_HEREDOC 68) (T_STATIC 19586) (T_STRING 19587) (T_STRING_CAST 71) (T_SWITCH 19588) (T_THROW 73) (T_TRAIT 19589) (T_TRAIT_C 75) (T_TRY 19590) (T_UNSET 19591) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19592) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19593) (alt_if_stmt_without_else 19594) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19595) (attributes 19596) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19597) (class_modifier 96) (class_modifiers 19598) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19599) (expr 19600) (fn 103) (fully_dereferenceable 104) #'19601 (function_call 106) (function_declaration_statement 19602) (if_stmt 19603) (if_stmt_without_else 19604) (inline_function 110) (inner_statement 19605) (interface_declaration_statement 19606) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19607) (static_member 119) (trait_declaration_statement 19608) (variable 122) (variable_class_name 123) ("{" 19609) ("~" 125)) 11610 ((";" 24375)) 11611 ((":" 20258) (enum_backing_type 24377)) 11612 ((T_IMPLEMENTS 2987) (implements_list 24378)) 11613 ((backup_doc_comment 24379)) 11614 (("{" 24380)) 11615 ((class_statement_list 24381)) 11616 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 24382)) 11617 (("," 19743) (";" 24385)) 11618 ((T_WHILE 24387)) 11619 (("(" 24388)) 11620 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 24389) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 11621 (("%" 292) (")" 24390) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 11622 ((";" 24391)) 11623 ((T_STRING 19916) (const_decl 19917) (const_list 24393)) 11624 ((")" 24394) ("," 19920)) 11625 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 24395) (";" 16298) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16299) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16301) (T_DEC 22) (T_DECLARE 16302) (T_DIR 24) (T_DNUMBER 25) (T_DO 16303) (T_DOUBLE_CAST 27) (T_ECHO 16304) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16307) (T_FOREACH 16308) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16309) (T_GOTO 16310) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16312) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16314) (T_START_HEREDOC 68) (T_STATIC 16315) (T_STRING 16316) (T_STRING_CAST 71) (T_SWITCH 16317) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16319) (T_UNSET 16320) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16321) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16322) (alt_if_stmt_without_else 16323) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (declare_statement 24396) (dereferenceable_scalar 100) (expr 16329) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16332) (if_stmt_without_else 16333) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 24397) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16338) ("~" 125)) 11626 ((inner_statement_list 24398)) 11627 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19926) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19927) (T_CLASS 19928) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19929) (T_DEC 22) (T_DECLARE 19930) (T_DIR 24) (T_DNUMBER 25) (T_DO 19931) (T_DOUBLE_CAST 27) (T_ECHO 19932) (T_EMPTY 29) (T_ENDDECLARE 24399) (T_ENUM 19934) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19935) (T_FOREACH 19936) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19937) (T_GOTO 19938) (T_HALT_COMPILER 19939) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19941) (T_INTERFACE 19942) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19943) (T_START_HEREDOC 68) (T_STATIC 19944) (T_STRING 19945) (T_STRING_CAST 71) (T_SWITCH 19946) (T_THROW 73) (T_TRAIT 19947) (T_TRAIT_C 75) (T_TRY 19948) (T_UNSET 19949) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19950) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19951) (alt_if_stmt_without_else 19952) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19953) (attributes 19954) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19955) (class_modifier 96) (class_modifiers 19956) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19957) (expr 19958) (fn 103) (fully_dereferenceable 104) #'19959 (function_call 106) (function_declaration_statement 19960) (if_stmt 19961) (if_stmt_without_else 19962) (inline_function 110) (inner_statement 19963) (interface_declaration_statement 19964) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19965) (static_member 119) (trait_declaration_statement 19966) (variable 122) (variable_class_name 123) ("{" 19967) ("~" 125)) 11628 ((";" 24400)) 11629 ((";" 24402)) 11630 ((T_EXTENDS 2985) (extends_from 24404)) 11631 ((T_IMPLEMENTS 2987) (implements_list 24405)) 11632 ((backup_doc_comment 24406)) 11633 (("{" 24407)) 11634 ((class_statement_list 24408)) 11635 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 24409)) 11636 ((";" 24411)) 11637 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 24413) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 11638 (("%" 292) (")" 24414) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 11639 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 24415) (";" 16211) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16212) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16214) (T_DEC 22) (T_DECLARE 16215) (T_DIR 24) (T_DNUMBER 25) (T_DO 16216) (T_DOUBLE_CAST 27) (T_ECHO 16217) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16219) (T_FOREACH 16220) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16221) (T_GOTO 16222) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16225) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16227) (T_START_HEREDOC 68) (T_STATIC 16228) (T_STRING 16229) (T_STRING_CAST 71) (T_SWITCH 16230) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16232) (T_UNSET 16233) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16234) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16235) (alt_if_stmt_without_else 16236) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16242) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16245) (if_stmt_without_else 16246) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 24416) (static_member 119) (variable 122) (variable_class_name 123) (while_statement 24417) ("{" 16251) ("~" 125)) 11640 ((inner_statement_list 24418)) 11641 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16379) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16380) (T_CLASS 16381) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16382) (T_DEC 22) (T_DECLARE 16383) (T_DIR 24) (T_DNUMBER 25) (T_DO 16384) (T_DOUBLE_CAST 27) (T_ECHO 16385) (T_EMPTY 29) (T_ENDWHILE 24419) (T_ENUM 16387) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16388) (T_FOREACH 16389) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16390) (T_GOTO 16391) (T_HALT_COMPILER 16392) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16394) (T_INTERFACE 16395) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16396) (T_START_HEREDOC 68) (T_STATIC 16397) (T_STRING 16398) (T_STRING_CAST 71) (T_SWITCH 16399) (T_THROW 73) (T_TRAIT 16400) (T_TRAIT_C 75) (T_TRY 16401) (T_UNSET 16402) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16403) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16404) (alt_if_stmt_without_else 16405) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16406) (attributes 16407) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16408) (class_modifier 96) (class_modifiers 16409) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16410) (expr 16411) (fn 103) (fully_dereferenceable 104) #'16412 (function_call 106) (function_declaration_statement 16413) (if_stmt 16414) (if_stmt_without_else 16415) (inline_function 110) (inner_statement 16416) (interface_declaration_statement 16417) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16418) (static_member 119) (trait_declaration_statement 16419) (variable 122) (variable_class_name 123) ("{" 16420) ("~" 125)) 11642 ((";" 24420)) 11643 (("\"" 1509) ("$" 16475) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 16476) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 16477) ("[" 1529) (array_object_dereferenceable 16478) (callable_expr 16479) (callable_variable 16480) (class_constant 1533) (class_name 16481) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 16482) (name 16483) (simple_variable 16484) (static_member 16485) (unset_variable 16486) (unset_variables 24422) (variable 16488) (variable_class_name 16489)) 11644 (("," 16501) (possible_comma 24423)) 11645 ((")" 24424)) 11646 ((";" 24425)) 11647 ((inner_statement_list 24427)) 11648 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 24428) ("~" 125)) 11649 ((catch_list 24429)) 11650 ((T_CATCH 24430) (T_FINALLY 24431) (finally_statement 24432)) 11651 (("(" 24436)) 11652 (("{" 24433)) 11653 ((inner_statement_list 24434)) 11654 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 24435) ("~" 125)) 11655 ((T_NAME_FULLY_QUALIFIED 16545) (T_NAME_QUALIFIED 16546) (T_NAME_RELATIVE 16547) (T_STATIC 16548) (T_STRING 16549) (catch_name_list 24437) (class_name 16551) (name 16552)) 11656 ((T_VARIABLE 16553) (optional_variable 24438) ("|" 16555)) 11657 ((")" 24439)) 11658 (("{" 24440)) 11659 ((inner_statement_list 24441)) 11660 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 24442) ("~" 125)) 11661 ((backup_doc_comment 24444)) 11662 (("{" 24445)) 11663 ((class_statement_list 24446)) 11664 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 24447)) 11665 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 24449) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 11666 (("%" 292) (")" 24450) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 11667 ((":" 24451) (switch_case_list 24452) ("{" 24453)) 11668 ((";" 24459) (case_list 24460)) 11669 ((";" 24454) (case_list 24455)) 11670 ((case_list 24457)) 11671 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 24456)) 11672 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 24458)) 11673 ((case_list 24463)) 11674 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 24461)) 11675 ((";" 24462)) 11676 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 24464)) 11677 ((";" 24465)) 11678 (("," 16852) (";" 24468)) 11679 ((";" 24470)) 11680 ((T_EXTENDS 20209) (interface_extends_list 24472)) 11681 ((backup_doc_comment 24473)) 11682 (("{" 24474)) 11683 ((class_statement_list 24475)) 11684 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 24476)) 11685 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 24478) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 11686 (("%" 292) (")" 24479) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 11687 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20219) (";" 16211) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16212) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16214) (T_DEC 22) (T_DECLARE 16215) (T_DIR 24) (T_DNUMBER 25) (T_DO 16216) (T_DOUBLE_CAST 27) (T_ECHO 16217) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16219) (T_FOREACH 16220) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16221) (T_GOTO 16222) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16225) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16227) (T_START_HEREDOC 68) (T_STATIC 16228) (T_STRING 16229) (T_STRING_CAST 71) (T_SWITCH 16230) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16232) (T_UNSET 16233) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16234) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16235) (alt_if_stmt_without_else 16236) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16242) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16245) (if_stmt_without_else 16246) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 24480) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16251) ("~" 125)) 11688 ((")" 24482)) 11689 ((";" 24483)) 11690 ((";" 24485)) 11691 (("," 17875) (";" 24487)) 11692 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 24489) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 11693 (("%" 17961) ("*" 17962) ("+" 17963) ("-" 17964) ("." 17965) ("/" 17966) ("<" 17967) (">" 17968) ("?" 17969) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 17970) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 17971) (T_AS 24490) (T_BOOLEAN_AND 17972) (T_BOOLEAN_OR 17973) (T_COALESCE 17974) (T_INSTANCEOF 17975) (T_IS_EQUAL 17976) (T_IS_GREATER_OR_EQUAL 17977) (T_IS_IDENTICAL 17978) (T_IS_NOT_EQUAL 17979) (T_IS_NOT_IDENTICAL 17980) (T_IS_SMALLER_OR_EQUAL 17981) (T_LOGICAL_AND 17982) (T_LOGICAL_OR 17983) (T_LOGICAL_XOR 17984) (T_POW 17985) (T_SL 17986) (T_SPACESHIP 17987) (T_SR 17988) ("^" 17989) ("|" 17990)) 11694 (("\"" 1509) ("$" 19325) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19326) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19327) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19328) ("[" 19329) (ampersand 19330) (array_object_dereferenceable 19331) (callable_expr 19332) (callable_variable 19333) (class_constant 1533) (class_name 19334) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 24491) (fully_dereferenceable 104) (function_call 19336) (name 19337) (simple_variable 19338) (static_member 19339) (variable 19340) (variable_class_name 19341)) 11695 ((")" 24492) (T_DOUBLE_ARROW 24493)) 11696 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 24496) (";" 16211) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16212) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16214) (T_DEC 22) (T_DECLARE 16215) (T_DIR 24) (T_DNUMBER 25) (T_DO 16216) (T_DOUBLE_CAST 27) (T_ECHO 16217) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16219) (T_FOREACH 16220) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16221) (T_GOTO 16222) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16225) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16227) (T_START_HEREDOC 68) (T_STATIC 16228) (T_STRING 16229) (T_STRING_CAST 71) (T_SWITCH 16230) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16232) (T_UNSET 16233) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16234) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16235) (alt_if_stmt_without_else 16236) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16242) (fn 103) (foreach_statement 24502) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16245) (if_stmt_without_else 16246) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 24498) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16251) ("~" 125)) 11697 (("\"" 1509) ("$" 19356) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19357) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19358) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19359) ("[" 19360) (ampersand 19361) (array_object_dereferenceable 19362) (callable_expr 19363) (callable_variable 19364) (class_constant 1533) (class_name 19365) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 24494) (fully_dereferenceable 104) (function_call 19367) (name 19368) (simple_variable 19369) (static_member 19370) (variable 19371) (variable_class_name 19372)) 11698 ((")" 24495)) 11699 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 24496) (";" 16211) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16212) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16214) (T_DEC 22) (T_DECLARE 16215) (T_DIR 24) (T_DNUMBER 25) (T_DO 16216) (T_DOUBLE_CAST 27) (T_ECHO 16217) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16219) (T_FOREACH 16220) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16221) (T_GOTO 16222) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16225) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16227) (T_START_HEREDOC 68) (T_STATIC 16228) (T_STRING 16229) (T_STRING_CAST 71) (T_SWITCH 16230) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16232) (T_UNSET 16233) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16234) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16235) (alt_if_stmt_without_else 16236) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16242) (fn 103) (foreach_statement 24497) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16245) (if_stmt_without_else 16246) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 24498) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16251) ("~" 125)) 11700 ((inner_statement_list 24499)) 11701 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19390) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19391) (T_CLASS 19392) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19393) (T_DEC 22) (T_DECLARE 19394) (T_DIR 24) (T_DNUMBER 25) (T_DO 19395) (T_DOUBLE_CAST 27) (T_ECHO 19396) (T_EMPTY 29) (T_ENDFOREACH 24500) (T_ENUM 19398) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19399) (T_FOREACH 19400) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19401) (T_GOTO 19402) (T_HALT_COMPILER 19403) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19405) (T_INTERFACE 19406) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19407) (T_START_HEREDOC 68) (T_STATIC 19408) (T_STRING 19409) (T_STRING_CAST 71) (T_SWITCH 19410) (T_THROW 73) (T_TRAIT 19411) (T_TRAIT_C 75) (T_TRY 19412) (T_UNSET 19413) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19414) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19415) (alt_if_stmt_without_else 19416) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19417) (attributes 19418) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19419) (class_modifier 96) (class_modifiers 19420) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19421) (expr 19422) (fn 103) (fully_dereferenceable 104) #'19423 (function_call 106) (function_declaration_statement 19424) (if_stmt 19425) (if_stmt_without_else 19426) (inline_function 110) (inner_statement 19427) (interface_declaration_statement 19428) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19429) (static_member 119) (trait_declaration_statement 19430) (variable 122) (variable_class_name 123) ("{" 19431) ("~" 125)) 11702 ((";" 24501)) 11703 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 24504) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 11704 ((";" 24505)) 11705 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 24506) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 11706 ((";" 24507)) 11707 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 19558) (fn 2394) (for_exprs 24508) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (non_empty_for_exprs 19560) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 11708 ((")" 24509)) 11709 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 24510) (";" 16211) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16212) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16214) (T_DEC 22) (T_DECLARE 16215) (T_DIR 24) (T_DNUMBER 25) (T_DO 16216) (T_DOUBLE_CAST 27) (T_ECHO 16217) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16219) (T_FOREACH 16220) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16221) (T_GOTO 16222) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16225) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16227) (T_START_HEREDOC 68) (T_STATIC 16228) (T_STRING 16229) (T_STRING_CAST 71) (T_SWITCH 16230) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16232) (T_UNSET 16233) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16234) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16235) (alt_if_stmt_without_else 16236) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16242) (fn 103) (for_statement 24511) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16245) (if_stmt_without_else 16246) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 24512) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16251) ("~" 125)) 11710 ((inner_statement_list 24513)) 11711 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19568) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19569) (T_CLASS 19570) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19571) (T_DEC 22) (T_DECLARE 19572) (T_DIR 24) (T_DNUMBER 25) (T_DO 19573) (T_DOUBLE_CAST 27) (T_ECHO 19574) (T_EMPTY 29) (T_ENDFOR 24514) (T_ENUM 19576) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19577) (T_FOREACH 19578) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19579) (T_GOTO 19580) (T_HALT_COMPILER 19581) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19583) (T_INTERFACE 19584) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19585) (T_START_HEREDOC 68) (T_STATIC 19586) (T_STRING 19587) (T_STRING_CAST 71) (T_SWITCH 19588) (T_THROW 73) (T_TRAIT 19589) (T_TRAIT_C 75) (T_TRY 19590) (T_UNSET 19591) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19592) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19593) (alt_if_stmt_without_else 19594) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19595) (attributes 19596) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19597) (class_modifier 96) (class_modifiers 19598) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19599) (expr 19600) (fn 103) (fully_dereferenceable 104) #'19601 (function_call 106) (function_declaration_statement 19602) (if_stmt 19603) (if_stmt_without_else 19604) (inline_function 110) (inner_statement 19605) (interface_declaration_statement 19606) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19607) (static_member 119) (trait_declaration_statement 19608) (variable 122) (variable_class_name 123) ("{" 19609) ("~" 125)) 11712 ((";" 24515)) 11713 ((":" 20258) (enum_backing_type 24517)) 11714 ((T_IMPLEMENTS 2987) (implements_list 24518)) 11715 ((backup_doc_comment 24519)) 11716 (("{" 24520)) 11717 ((class_statement_list 24521)) 11718 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 24522)) 11719 (("," 19743) (";" 24524)) 11720 ((T_WHILE 24526)) 11721 (("(" 24527)) 11722 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 24528) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 11723 (("%" 292) (")" 24529) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 11724 ((";" 24530)) 11725 ((T_STRING 19916) (const_decl 19917) (const_list 24532)) 11726 ((")" 24533) ("," 19920)) 11727 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 24534) (";" 16211) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16212) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16214) (T_DEC 22) (T_DECLARE 16215) (T_DIR 24) (T_DNUMBER 25) (T_DO 16216) (T_DOUBLE_CAST 27) (T_ECHO 16217) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16219) (T_FOREACH 16220) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16221) (T_GOTO 16222) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16225) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16227) (T_START_HEREDOC 68) (T_STATIC 16228) (T_STRING 16229) (T_STRING_CAST 71) (T_SWITCH 16230) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16232) (T_UNSET 16233) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16234) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16235) (alt_if_stmt_without_else 16236) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (declare_statement 24535) (dereferenceable_scalar 100) (expr 16242) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16245) (if_stmt_without_else 16246) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 24536) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16251) ("~" 125)) 11728 ((inner_statement_list 24537)) 11729 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19926) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19927) (T_CLASS 19928) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19929) (T_DEC 22) (T_DECLARE 19930) (T_DIR 24) (T_DNUMBER 25) (T_DO 19931) (T_DOUBLE_CAST 27) (T_ECHO 19932) (T_EMPTY 29) (T_ENDDECLARE 24538) (T_ENUM 19934) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19935) (T_FOREACH 19936) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19937) (T_GOTO 19938) (T_HALT_COMPILER 19939) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19941) (T_INTERFACE 19942) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19943) (T_START_HEREDOC 68) (T_STATIC 19944) (T_STRING 19945) (T_STRING_CAST 71) (T_SWITCH 19946) (T_THROW 73) (T_TRAIT 19947) (T_TRAIT_C 75) (T_TRY 19948) (T_UNSET 19949) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19950) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19951) (alt_if_stmt_without_else 19952) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19953) (attributes 19954) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19955) (class_modifier 96) (class_modifiers 19956) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19957) (expr 19958) (fn 103) (fully_dereferenceable 104) #'19959 (function_call 106) (function_declaration_statement 19960) (if_stmt 19961) (if_stmt_without_else 19962) (inline_function 110) (inner_statement 19963) (interface_declaration_statement 19964) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19965) (static_member 119) (trait_declaration_statement 19966) (variable 122) (variable_class_name 123) ("{" 19967) ("~" 125)) 11730 ((";" 24539)) 11731 ((";" 24541)) 11732 ((T_EXTENDS 2985) (extends_from 24543)) 11733 ((T_IMPLEMENTS 2987) (implements_list 24544)) 11734 ((backup_doc_comment 24545)) 11735 (("{" 24546)) 11736 ((class_statement_list 24547)) 11737 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 24548)) 11738 ((";" 24550)) 11739 ((inner_statement_list 24552)) 11740 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16298) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16299) (T_CLASS 16300) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16301) (T_DEC 22) (T_DECLARE 16302) (T_DIR 24) (T_DNUMBER 25) (T_DO 16303) (T_DOUBLE_CAST 27) (T_ECHO 16304) (T_EMPTY 29) (T_ENDIF 24553) (T_ENUM 16306) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16307) (T_FOREACH 16308) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16309) (T_GOTO 16310) (T_HALT_COMPILER 16311) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16312) (T_INTERFACE 16313) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16314) (T_START_HEREDOC 68) (T_STATIC 16315) (T_STRING 16316) (T_STRING_CAST 71) (T_SWITCH 16317) (T_THROW 73) (T_TRAIT 16318) (T_TRAIT_C 75) (T_TRY 16319) (T_UNSET 16320) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16321) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16322) (alt_if_stmt_without_else 16323) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16324) (attributes 16325) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16326) (class_modifier 96) (class_modifiers 16327) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16328) (expr 16329) (fn 103) (fully_dereferenceable 104) #'16330 (function_call 106) (function_declaration_statement 16331) (if_stmt 16332) (if_stmt_without_else 16333) (inline_function 110) (inner_statement 16334) (interface_declaration_statement 16335) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16336) (static_member 119) (trait_declaration_statement 16337) (variable 122) (variable_class_name 123) ("{" 16338) ("~" 125)) 11741 ((";" 24554)) 11742 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 24556) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 11743 (("%" 292) (")" 24557) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 11744 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 24558) (";" 16172) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16173) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16174) (T_DEC 22) (T_DECLARE 16175) (T_DIR 24) (T_DNUMBER 25) (T_DO 16176) (T_DOUBLE_CAST 27) (T_ECHO 16177) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16178) (T_FOREACH 16179) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16180) (T_GOTO 16181) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16182) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16183) (T_START_HEREDOC 68) (T_STATIC 16184) (T_STRING 16185) (T_STRING_CAST 71) (T_SWITCH 16186) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16187) (T_UNSET 16188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16190) (alt_if_stmt_without_else 16191) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16192) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16193) (if_stmt_without_else 16194) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 24559) (static_member 119) (variable 122) (variable_class_name 123) (while_statement 24560) ("{" 16196) ("~" 125)) 11745 ((inner_statement_list 24561)) 11746 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16379) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16380) (T_CLASS 16381) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16382) (T_DEC 22) (T_DECLARE 16383) (T_DIR 24) (T_DNUMBER 25) (T_DO 16384) (T_DOUBLE_CAST 27) (T_ECHO 16385) (T_EMPTY 29) (T_ENDWHILE 24562) (T_ENUM 16387) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16388) (T_FOREACH 16389) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16390) (T_GOTO 16391) (T_HALT_COMPILER 16392) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16394) (T_INTERFACE 16395) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16396) (T_START_HEREDOC 68) (T_STATIC 16397) (T_STRING 16398) (T_STRING_CAST 71) (T_SWITCH 16399) (T_THROW 73) (T_TRAIT 16400) (T_TRAIT_C 75) (T_TRY 16401) (T_UNSET 16402) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16403) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16404) (alt_if_stmt_without_else 16405) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16406) (attributes 16407) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16408) (class_modifier 96) (class_modifiers 16409) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16410) (expr 16411) (fn 103) (fully_dereferenceable 104) #'16412 (function_call 106) (function_declaration_statement 16413) (if_stmt 16414) (if_stmt_without_else 16415) (inline_function 110) (inner_statement 16416) (interface_declaration_statement 16417) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16418) (static_member 119) (trait_declaration_statement 16419) (variable 122) (variable_class_name 123) ("{" 16420) ("~" 125)) 11747 ((";" 24563)) 11748 (("\"" 1509) ("$" 16475) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 16476) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 16477) ("[" 1529) (array_object_dereferenceable 16478) (callable_expr 16479) (callable_variable 16480) (class_constant 1533) (class_name 16481) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 16482) (name 16483) (simple_variable 16484) (static_member 16485) (unset_variable 16486) (unset_variables 24565) (variable 16488) (variable_class_name 16489)) 11749 (("," 16501) (possible_comma 24566)) 11750 ((")" 24567)) 11751 ((";" 24568)) 11752 ((inner_statement_list 24570)) 11753 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 24571) ("~" 125)) 11754 ((catch_list 24572)) 11755 ((T_CATCH 24573) (T_FINALLY 24574) (finally_statement 24575)) 11756 (("(" 24579)) 11757 (("{" 24576)) 11758 ((inner_statement_list 24577)) 11759 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 24578) ("~" 125)) 11760 ((T_NAME_FULLY_QUALIFIED 16545) (T_NAME_QUALIFIED 16546) (T_NAME_RELATIVE 16547) (T_STATIC 16548) (T_STRING 16549) (catch_name_list 24580) (class_name 16551) (name 16552)) 11761 ((T_VARIABLE 16553) (optional_variable 24581) ("|" 16555)) 11762 ((")" 24582)) 11763 (("{" 24583)) 11764 ((inner_statement_list 24584)) 11765 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 24585) ("~" 125)) 11766 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 24587) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 11767 (("%" 292) (")" 24588) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 11768 ((":" 24589) (switch_case_list 24590) ("{" 24591)) 11769 ((";" 24597) (case_list 24598)) 11770 ((";" 24592) (case_list 24593)) 11771 ((case_list 24595)) 11772 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 24594)) 11773 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 24596)) 11774 ((case_list 24601)) 11775 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 24599)) 11776 ((";" 24600)) 11777 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 24602)) 11778 ((";" 24603)) 11779 (("," 16852) (";" 24606)) 11780 ((";" 24608)) 11781 ((";" 24610)) 11782 (("," 17875) (";" 24612)) 11783 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 24614) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 11784 (("%" 17961) ("*" 17962) ("+" 17963) ("-" 17964) ("." 17965) ("/" 17966) ("<" 17967) (">" 17968) ("?" 17969) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 17970) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 17971) (T_AS 24615) (T_BOOLEAN_AND 17972) (T_BOOLEAN_OR 17973) (T_COALESCE 17974) (T_INSTANCEOF 17975) (T_IS_EQUAL 17976) (T_IS_GREATER_OR_EQUAL 17977) (T_IS_IDENTICAL 17978) (T_IS_NOT_EQUAL 17979) (T_IS_NOT_IDENTICAL 17980) (T_IS_SMALLER_OR_EQUAL 17981) (T_LOGICAL_AND 17982) (T_LOGICAL_OR 17983) (T_LOGICAL_XOR 17984) (T_POW 17985) (T_SL 17986) (T_SPACESHIP 17987) (T_SR 17988) ("^" 17989) ("|" 17990)) 11785 (("\"" 1509) ("$" 19325) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19326) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19327) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19328) ("[" 19329) (ampersand 19330) (array_object_dereferenceable 19331) (callable_expr 19332) (callable_variable 19333) (class_constant 1533) (class_name 19334) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 24616) (fully_dereferenceable 104) (function_call 19336) (name 19337) (simple_variable 19338) (static_member 19339) (variable 19340) (variable_class_name 19341)) 11786 ((")" 24617) (T_DOUBLE_ARROW 24618)) 11787 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 24621) (";" 16172) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16173) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16174) (T_DEC 22) (T_DECLARE 16175) (T_DIR 24) (T_DNUMBER 25) (T_DO 16176) (T_DOUBLE_CAST 27) (T_ECHO 16177) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16178) (T_FOREACH 16179) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16180) (T_GOTO 16181) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16182) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16183) (T_START_HEREDOC 68) (T_STATIC 16184) (T_STRING 16185) (T_STRING_CAST 71) (T_SWITCH 16186) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16187) (T_UNSET 16188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16190) (alt_if_stmt_without_else 16191) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16192) (fn 103) (foreach_statement 24627) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16193) (if_stmt_without_else 16194) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 24623) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16196) ("~" 125)) 11788 (("\"" 1509) ("$" 19356) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19357) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19358) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19359) ("[" 19360) (ampersand 19361) (array_object_dereferenceable 19362) (callable_expr 19363) (callable_variable 19364) (class_constant 1533) (class_name 19365) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 24619) (fully_dereferenceable 104) (function_call 19367) (name 19368) (simple_variable 19369) (static_member 19370) (variable 19371) (variable_class_name 19372)) 11789 ((")" 24620)) 11790 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 24621) (";" 16172) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16173) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16174) (T_DEC 22) (T_DECLARE 16175) (T_DIR 24) (T_DNUMBER 25) (T_DO 16176) (T_DOUBLE_CAST 27) (T_ECHO 16177) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16178) (T_FOREACH 16179) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16180) (T_GOTO 16181) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16182) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16183) (T_START_HEREDOC 68) (T_STATIC 16184) (T_STRING 16185) (T_STRING_CAST 71) (T_SWITCH 16186) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16187) (T_UNSET 16188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16190) (alt_if_stmt_without_else 16191) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16192) (fn 103) (foreach_statement 24622) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16193) (if_stmt_without_else 16194) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 24623) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16196) ("~" 125)) 11791 ((inner_statement_list 24624)) 11792 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19390) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19391) (T_CLASS 19392) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19393) (T_DEC 22) (T_DECLARE 19394) (T_DIR 24) (T_DNUMBER 25) (T_DO 19395) (T_DOUBLE_CAST 27) (T_ECHO 19396) (T_EMPTY 29) (T_ENDFOREACH 24625) (T_ENUM 19398) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19399) (T_FOREACH 19400) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19401) (T_GOTO 19402) (T_HALT_COMPILER 19403) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19405) (T_INTERFACE 19406) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19407) (T_START_HEREDOC 68) (T_STATIC 19408) (T_STRING 19409) (T_STRING_CAST 71) (T_SWITCH 19410) (T_THROW 73) (T_TRAIT 19411) (T_TRAIT_C 75) (T_TRY 19412) (T_UNSET 19413) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19414) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19415) (alt_if_stmt_without_else 19416) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19417) (attributes 19418) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19419) (class_modifier 96) (class_modifiers 19420) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19421) (expr 19422) (fn 103) (fully_dereferenceable 104) #'19423 (function_call 106) (function_declaration_statement 19424) (if_stmt 19425) (if_stmt_without_else 19426) (inline_function 110) (inner_statement 19427) (interface_declaration_statement 19428) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19429) (static_member 119) (trait_declaration_statement 19430) (variable 122) (variable_class_name 123) ("{" 19431) ("~" 125)) 11793 ((";" 24626)) 11794 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 24629) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 11795 ((";" 24630)) 11796 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 24631) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 11797 ((";" 24632)) 11798 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 19558) (fn 2394) (for_exprs 24633) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (non_empty_for_exprs 19560) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 11799 ((")" 24634)) 11800 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 24635) (";" 16172) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16173) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16174) (T_DEC 22) (T_DECLARE 16175) (T_DIR 24) (T_DNUMBER 25) (T_DO 16176) (T_DOUBLE_CAST 27) (T_ECHO 16177) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16178) (T_FOREACH 16179) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16180) (T_GOTO 16181) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16182) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16183) (T_START_HEREDOC 68) (T_STATIC 16184) (T_STRING 16185) (T_STRING_CAST 71) (T_SWITCH 16186) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16187) (T_UNSET 16188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16190) (alt_if_stmt_without_else 16191) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16192) (fn 103) (for_statement 24636) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16193) (if_stmt_without_else 16194) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 24637) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16196) ("~" 125)) 11801 ((inner_statement_list 24638)) 11802 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19568) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19569) (T_CLASS 19570) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19571) (T_DEC 22) (T_DECLARE 19572) (T_DIR 24) (T_DNUMBER 25) (T_DO 19573) (T_DOUBLE_CAST 27) (T_ECHO 19574) (T_EMPTY 29) (T_ENDFOR 24639) (T_ENUM 19576) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19577) (T_FOREACH 19578) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19579) (T_GOTO 19580) (T_HALT_COMPILER 19581) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19583) (T_INTERFACE 19584) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19585) (T_START_HEREDOC 68) (T_STATIC 19586) (T_STRING 19587) (T_STRING_CAST 71) (T_SWITCH 19588) (T_THROW 73) (T_TRAIT 19589) (T_TRAIT_C 75) (T_TRY 19590) (T_UNSET 19591) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19592) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19593) (alt_if_stmt_without_else 19594) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19595) (attributes 19596) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19597) (class_modifier 96) (class_modifiers 19598) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19599) (expr 19600) (fn 103) (fully_dereferenceable 104) #'19601 (function_call 106) (function_declaration_statement 19602) (if_stmt 19603) (if_stmt_without_else 19604) (inline_function 110) (inner_statement 19605) (interface_declaration_statement 19606) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19607) (static_member 119) (trait_declaration_statement 19608) (variable 122) (variable_class_name 123) ("{" 19609) ("~" 125)) 11803 ((";" 24640)) 11804 (("," 19743) (";" 24642)) 11805 ((T_WHILE 24644)) 11806 (("(" 24645)) 11807 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 24646) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 11808 (("%" 292) (")" 24647) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 11809 ((";" 24648)) 11810 ((T_STRING 19916) (const_decl 19917) (const_list 24650)) 11811 ((")" 24651) ("," 19920)) 11812 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 24652) (";" 16172) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16173) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16174) (T_DEC 22) (T_DECLARE 16175) (T_DIR 24) (T_DNUMBER 25) (T_DO 16176) (T_DOUBLE_CAST 27) (T_ECHO 16177) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16178) (T_FOREACH 16179) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16180) (T_GOTO 16181) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16182) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16183) (T_START_HEREDOC 68) (T_STATIC 16184) (T_STRING 16185) (T_STRING_CAST 71) (T_SWITCH 16186) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16187) (T_UNSET 16188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16190) (alt_if_stmt_without_else 16191) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (declare_statement 24653) (dereferenceable_scalar 100) (expr 16192) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16193) (if_stmt_without_else 16194) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 24654) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16196) ("~" 125)) 11813 ((inner_statement_list 24655)) 11814 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19926) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19927) (T_CLASS 19928) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19929) (T_DEC 22) (T_DECLARE 19930) (T_DIR 24) (T_DNUMBER 25) (T_DO 19931) (T_DOUBLE_CAST 27) (T_ECHO 19932) (T_EMPTY 29) (T_ENDDECLARE 24656) (T_ENUM 19934) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19935) (T_FOREACH 19936) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19937) (T_GOTO 19938) (T_HALT_COMPILER 19939) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19941) (T_INTERFACE 19942) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19943) (T_START_HEREDOC 68) (T_STATIC 19944) (T_STRING 19945) (T_STRING_CAST 71) (T_SWITCH 19946) (T_THROW 73) (T_TRAIT 19947) (T_TRAIT_C 75) (T_TRY 19948) (T_UNSET 19949) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19950) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19951) (alt_if_stmt_without_else 19952) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19953) (attributes 19954) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19955) (class_modifier 96) (class_modifiers 19956) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19957) (expr 19958) (fn 103) (fully_dereferenceable 104) #'19959 (function_call 106) (function_declaration_statement 19960) (if_stmt 19961) (if_stmt_without_else 19962) (inline_function 110) (inner_statement 19963) (interface_declaration_statement 19964) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19965) (static_member 119) (trait_declaration_statement 19966) (variable 122) (variable_class_name 123) ("{" 19967) ("~" 125)) 11815 ((";" 24657)) 11816 ((";" 24659)) 11817 ((";" 24661)) 11818 (("$" 216) (T_ABSTRACT 14910) (T_ARRAY 14911) (T_AS 14912) (T_BREAK 14913) (T_CALLABLE 14914) (T_CASE 14915) (T_CATCH 14916) (T_CLASS 14917) (T_CLASS_C 14918) (T_CLONE 14919) (T_CONST 14920) (T_CONTINUE 14921) (T_DECLARE 14922) (T_DEFAULT 14923) (T_DIR 14924) (T_DO 14925) (T_ECHO 14926) (T_ELSE 14927) (T_ELSEIF 14928) (T_EMPTY 14929) (T_ENDDECLARE 14930) (T_ENDFOR 14931) (T_ENDFOREACH 14932) (T_ENDIF 14933) (T_ENDSWITCH 14934) (T_ENDWHILE 14935) (T_ENUM 14936) (T_EVAL 14937) (T_EXIT 14938) (T_EXTENDS 14939) (T_FILE 14940) (T_FINAL 14941) (T_FINALLY 14942) (T_FN 14943) (T_FOR 14944) (T_FOREACH 14945) (T_FUNCTION 14946) (T_FUNC_C 14947) (T_GLOBAL 14948) (T_GOTO 14949) (T_IF 14950) (T_IMPLEMENTS 14951) (T_INCLUDE 14952) (T_INCLUDE_ONCE 14953) (T_INSTANCEOF 14954) (T_INSTEADOF 14955) (T_INTERFACE 14956) (T_ISSET 14957) (T_LINE 14958) (T_LIST 14959) (T_LOGICAL_AND 14960) (T_LOGICAL_OR 14961) (T_LOGICAL_XOR 14962) (T_MATCH 14963) (T_METHOD_C 14964) (T_NAMESPACE 14965) (T_NEW 14966) (T_NS_C 14967) (T_PRINT 14968) (T_PRIVATE 14969) (T_PROTECTED 14970) (T_PUBLIC 14971) (T_READONLY 14972) (T_REQUIRE 14973) (T_REQUIRE_ONCE 14974) (T_RETURN 14975) (T_STATIC 14976) (T_STRING 14977) (T_SWITCH 14978) (T_THROW 14979) (T_TRAIT 14980) (T_TRAIT_C 14981) (T_TRY 14982) (T_UNSET 14983) (T_USE 14984) (T_VAR 14985) (T_VARIABLE 263) (T_WHILE 14986) (T_YIELD 14987) (identifier 24663) (member_name 24664) (reserved_non_modifiers 14990) (semi_reserved 14991) (simple_variable 24665) ("{" 24666)) 11819 (("(" 14996) (argument_list 24669)) 11820 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 24667) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 11821 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 24668)) 11822 ((T_FN 35) (T_FUNCTION 127) (fn 277) #'278 (inline_function 24673)) 11823 (("$" 216) (T_STRING 24682) (T_VARIABLE 263) (property_name 24689) (simple_variable 24684) ("{" 24685)) 11824 (("$" 216) (T_STRING 24682) (T_VARIABLE 263) (property_name 24683) (simple_variable 24684) ("{" 24685)) 11825 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 24680) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 11826 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 24678) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 11827 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 24679)) 11828 (("]" 24681)) 11829 (("(" 14996) (argument_list 24688)) 11830 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 24686) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 11831 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 24687)) 11832 (("(" 14996) (argument_list 24690)) 11833 (("`" 24692)) 11834 (("]" 24694)) 11835 (("=" 24695)) 11836 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 24696) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 11837 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 25204) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11838 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 25202) (encaps_var 5299)) 11839 (("$" 24700) (T_VARIABLE 24747) (simple_variable 25198) ("{" 25199)) 11840 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25196) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 11841 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 25195) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11842 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 25194) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11843 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 25193) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11844 (("(" 25190)) 11845 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 25189) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11846 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 25188) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11847 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 25187) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11848 (("\"" 1509) ("$" 25003) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 25004) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 25005) ("[" 1529) (array_object_dereferenceable 25006) (callable_expr 25007) (callable_variable 25008) (class_constant 1533) (class_name 25009) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 25010) (name 25011) (simple_variable 25012) (static_member 25013) (variable 25186) (variable_class_name 25015)) 11849 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 25185) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11850 (("(" 25182)) 11851 (("(" 25179)) 11852 (("(" 25175) (exit_expr 25176)) 11853 (("\"" 1509) ("$" 25003) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 25004) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 25005) ("[" 1529) (array_object_dereferenceable 25006) (callable_expr 25007) (callable_variable 25008) (class_constant 1533) (class_name 25009) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 25010) (name 25011) (simple_variable 25012) (static_member 25013) (variable 25174) (variable_class_name 25015)) 11854 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 25173) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11855 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 25172) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11856 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 25171) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11857 (("(" 25167)) 11858 (("(" 25162)) 11859 (("(" 25156)) 11860 (("$" 15832) ("(" 15963) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 15964) (T_NAME_QUALIFIED 15965) (T_NAME_RELATIVE 15966) (T_READONLY 2936) (T_STATIC 15967) (T_STRING 15968) (T_VARIABLE 15834) (anonymous_class 25134) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 25135) (attribute 2943) (attributes 25136) (class_modifier 2945) (class_name 15972) (class_name_reference 25137) (name 15974) (new_variable 15975) (simple_variable 15976)) 11861 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 25133) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11862 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 25132) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11863 (("(" 24964) (argument_list 25131)) 11864 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 25130) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11865 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 25129) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11866 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 25124) (T_END_HEREDOC 25125) (T_VARIABLE 2900) (encaps_list 25126) (encaps_var 2902)) 11867 ((T_FN 35) (T_FUNCTION 127) (fn 24761) #'24762 (inline_function 25123)) 11868 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 25122) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11869 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 25121) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11870 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 25120) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11871 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 25117) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11872 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 25116) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11873 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 25112) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 11874 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 25110) (encaps_list 2805) (encaps_var 2806)) 11875 ((T_NULLSAFE_OBJECT_OPERATOR 25093) (T_OBJECT_OPERATOR 25094) ("[" 25095) ("{" 25096)) 11876 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 25090) (attribute 2728) (fn 24761) #'24762 (inline_function 25091)) 11877 (("(" 24964) (argument_list 25089)) 11878 ((T_PAAMAYIM_NEKUDOTAYIM 25081)) 11879 (("%" 24776) ("*" 24777) ("+" 24778) ("-" 24779) ("." 24780) ("/" 24781) ("<" 24782) (">" 24783) ("?" 24784) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 24785) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 24786) (T_BOOLEAN_AND 24787) (T_BOOLEAN_OR 24788) (T_COALESCE 24789) (T_DOUBLE_ARROW 25079) (T_INSTANCEOF 24790) (T_IS_EQUAL 24791) (T_IS_GREATER_OR_EQUAL 24792) (T_IS_IDENTICAL 24793) (T_IS_NOT_EQUAL 24794) (T_IS_NOT_IDENTICAL 24795) (T_IS_SMALLER_OR_EQUAL 24796) (T_LOGICAL_AND 24797) (T_LOGICAL_OR 24798) (T_LOGICAL_XOR 24799) (T_POW 24800) (T_SL 24801) (T_SPACESHIP 24802) (T_SR 24803) ("^" 24804) ("|" 24805)) 11880 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 25068)) 11881 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 25056)) 11882 (("(" 24964) (argument_list 25055)) 11883 (("=" 24972) (T_AND_EQUAL 24973) (T_COALESCE_EQUAL 24974) (T_CONCAT_EQUAL 24975) (T_DEC 24976) (T_DIV_EQUAL 24977) (T_INC 24978) (T_MINUS_EQUAL 24979) (T_MOD_EQUAL 24980) (T_MUL_EQUAL 24981) (T_OR_EQUAL 24982) (T_PLUS_EQUAL 24983) (T_POW_EQUAL 24984) (T_SL_EQUAL 24985) (T_SR_EQUAL 24986) (T_XOR_EQUAL 24987)) 11884 ((T_PAAMAYIM_NEKUDOTAYIM 24877)) 11885 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24775) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11886 (("%" 24776) ("*" 24777) ("+" 24778) ("-" 24779) ("." 24780) ("/" 24781) ("<" 24782) (">" 24783) ("?" 24784) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 24785) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 24786) (T_BOOLEAN_AND 24787) (T_BOOLEAN_OR 24788) (T_COALESCE 24789) (T_INSTANCEOF 24790) (T_IS_EQUAL 24791) (T_IS_GREATER_OR_EQUAL 24792) (T_IS_IDENTICAL 24793) (T_IS_NOT_EQUAL 24794) (T_IS_NOT_IDENTICAL 24795) (T_IS_SMALLER_OR_EQUAL 24796) (T_LOGICAL_AND 24797) (T_LOGICAL_OR 24798) (T_LOGICAL_XOR 24799) (T_POW 24800) (T_SL 24801) (T_SPACESHIP 24802) (T_SR 24803) ("^" 24804) ("|" 24805)) 11887 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24876) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11888 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24875) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11889 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24874) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11890 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24873) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11891 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24872) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11892 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24871) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11893 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24870) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11894 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24869) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11895 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 24864) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 24865) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 11896 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24863) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11897 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24862) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11898 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24861) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11899 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24860) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11900 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24859) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11901 (("$" 24821) ("(" 24822) (T_NAME_FULLY_QUALIFIED 24823) (T_NAME_QUALIFIED 24824) (T_NAME_RELATIVE 24825) (T_STATIC 24826) (T_STRING 24827) (T_VARIABLE 24828) (class_name 24829) (class_name_reference 24830) (name 24831) (new_variable 24832) (simple_variable 24833)) 11902 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24820) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11903 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24819) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11904 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24818) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11905 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24817) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11906 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24816) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11907 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24815) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11908 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24814) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11909 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24813) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11910 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24812) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11911 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24811) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11912 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24810) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11913 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24809) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11914 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24808) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11915 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24807) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11916 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24806) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11917 (("$" 24821) (T_VARIABLE 24828) (simple_variable 24855) ("{" 24856)) 11918 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 24853) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 11919 ((T_PAAMAYIM_NEKUDOTAYIM 24851)) 11920 ((T_NULLSAFE_OBJECT_OPERATOR 24834) (T_OBJECT_OPERATOR 24835) (T_PAAMAYIM_NEKUDOTAYIM 24836) ("[" 24837) ("{" 24838)) 11921 (("$" 24821) (T_STRING 24844) (T_VARIABLE 24828) (property_name 24850) (simple_variable 24846) ("{" 24847)) 11922 (("$" 24821) (T_STRING 24844) (T_VARIABLE 24828) (property_name 24845) (simple_variable 24846) ("{" 24847)) 11923 (("$" 24821) (T_VARIABLE 24828) (simple_variable 24843)) 11924 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 24841) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 11925 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 24839) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 11926 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 24840)) 11927 (("]" 24842)) 11928 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 24848) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 11929 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 24849)) 11930 (("$" 24821) (T_VARIABLE 24828) (simple_variable 24852)) 11931 (("%" 292) (")" 24854) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 11932 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 24857) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 11933 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 24858)) 11934 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24868) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11935 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 24866) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 11936 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24867) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11937 (("$" 24700) (T_ABSTRACT 24878) (T_ARRAY 24879) (T_AS 24880) (T_BREAK 24881) (T_CALLABLE 24882) (T_CASE 24883) (T_CATCH 24884) (T_CLASS 24885) (T_CLASS_C 24886) (T_CLONE 24887) (T_CONST 24888) (T_CONTINUE 24889) (T_DECLARE 24890) (T_DEFAULT 24891) (T_DIR 24892) (T_DO 24893) (T_ECHO 24894) (T_ELSE 24895) (T_ELSEIF 24896) (T_EMPTY 24897) (T_ENDDECLARE 24898) (T_ENDFOR 24899) (T_ENDFOREACH 24900) (T_ENDIF 24901) (T_ENDSWITCH 24902) (T_ENDWHILE 24903) (T_ENUM 24904) (T_EVAL 24905) (T_EXIT 24906) (T_EXTENDS 24907) (T_FILE 24908) (T_FINAL 24909) (T_FINALLY 24910) (T_FN 24911) (T_FOR 24912) (T_FOREACH 24913) (T_FUNCTION 24914) (T_FUNC_C 24915) (T_GLOBAL 24916) (T_GOTO 24917) (T_IF 24918) (T_IMPLEMENTS 24919) (T_INCLUDE 24920) (T_INCLUDE_ONCE 24921) (T_INSTANCEOF 24922) (T_INSTEADOF 24923) (T_INTERFACE 24924) (T_ISSET 24925) (T_LINE 24926) (T_LIST 24927) (T_LOGICAL_AND 24928) (T_LOGICAL_OR 24929) (T_LOGICAL_XOR 24930) (T_MATCH 24931) (T_METHOD_C 24932) (T_NAMESPACE 24933) (T_NEW 24934) (T_NS_C 24935) (T_PRINT 24936) (T_PRIVATE 24937) (T_PROTECTED 24938) (T_PUBLIC 24939) (T_READONLY 24940) (T_REQUIRE 24941) (T_REQUIRE_ONCE 24942) (T_RETURN 24943) (T_STATIC 24944) (T_STRING 24945) (T_SWITCH 24946) (T_THROW 24947) (T_TRAIT 24948) (T_TRAIT_C 24949) (T_TRY 24950) (T_UNSET 24951) (T_USE 24952) (T_VAR 24953) (T_VARIABLE 24747) (T_WHILE 24954) (T_YIELD 24955) (identifier 24956) (member_name 24957) (reserved_non_modifiers 24958) (semi_reserved 24959) (simple_variable 24960) ("{" 24961)) 11938 (("(" 24964) (argument_list 24965)) 11939 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 24962) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 11940 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 24963)) 11941 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 24966) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 24967) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 24968) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 11942 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 24971) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 11943 (("," 1469) (possible_comma 24969)) 11944 ((")" 24970)) 11945 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (ampersand 25001) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 25002) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11946 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 25000) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11947 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24999) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11948 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24998) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11949 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24997) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11950 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24996) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11951 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24995) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11952 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24994) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11953 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24993) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11954 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24992) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11955 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24991) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11956 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24990) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11957 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24989) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11958 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 24988) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 11959 (("\"" 1509) ("$" 25003) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 25004) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 25005) ("[" 1529) (array_object_dereferenceable 25006) (callable_expr 25007) (callable_variable 25008) (class_constant 1533) (class_name 25009) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 25010) (name 25011) (simple_variable 25012) (static_member 25013) (variable 25014) (variable_class_name 25015)) 11960 (("$" 25003) (T_VARIABLE 25005) (simple_variable 25051) ("{" 25052)) 11961 (("(" 25019) (argument_list 25050)) 11962 ((T_NULLSAFE_OBJECT_OPERATOR 25033) (T_OBJECT_OPERATOR 25034) ("[" 25035) ("{" 25036)) 11963 (("(" 25019) (argument_list 25032)) 11964 ((T_PAAMAYIM_NEKUDOTAYIM 25028)) 11965 (("(" 25019) (argument_list 25027)) 11966 ((T_PAAMAYIM_NEKUDOTAYIM 25016)) 11967 (("$" 25003) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 25005) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 25017) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 25018) ("{" 1627)) 11968 (("(" 25019) (argument_list 25020)) 11969 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 25021) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 25022) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 25023) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 11970 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 25026) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 11971 (("," 1469) (possible_comma 25024)) 11972 ((")" 25025)) 11973 (("$" 25003) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 25005) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 25029) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 25030) ("{" 1643)) 11974 (("(" 25019) (argument_list 25031)) 11975 (("$" 25003) (T_STRING 25041) (T_VARIABLE 25005) (property_name 25048) (simple_variable 25043) ("{" 25044)) 11976 (("$" 25003) (T_STRING 25041) (T_VARIABLE 25005) (property_name 25042) (simple_variable 25043) ("{" 25044)) 11977 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 25039) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 11978 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 25037) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 11979 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 25038)) 11980 (("]" 25040)) 11981 (("(" 25019) (argument_list 25047)) 11982 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 25045) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 11983 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 25046)) 11984 (("(" 25019) (argument_list 25049)) 11985 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 25053) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 11986 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 25054)) 11987 ((backup_doc_comment 25057)) 11988 (("(" 25058)) 11989 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 25059)) 11990 ((")" 25060)) 11991 ((T_USE 159) (lexical_vars 25061)) 11992 ((":" 161) (return_type 25062)) 11993 ((backup_fn_flags 25063)) 11994 (("{" 25064)) 11995 ((inner_statement_list 25065)) 11996 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 25066) ("~" 125)) 11997 ((backup_fn_flags 25067)) 11998 ((backup_doc_comment 25069)) 11999 (("(" 25070)) 12000 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 25071)) 12001 ((")" 25072)) 12002 ((":" 2241) (return_type 25073)) 12003 ((T_DOUBLE_ARROW 25074)) 12004 ((backup_fn_flags 25075)) 12005 ((backup_lex_pos 25076)) 12006 (("!" 15527) ("\"" 15528) ("$" 15529) ("(" 15530) ("+" 15531) ("-" 15532) ("@" 15533) (T_ARRAY 15534) (T_ARRAY_CAST 15535) (T_ATTRIBUTE 126) (T_BOOL_CAST 15536) (T_CLASS_C 15537) (T_CLONE 15538) (T_CONSTANT_ENCAPSED_STRING 15539) (T_DEC 15540) (T_DIR 15541) (T_DNUMBER 15542) (T_DOUBLE_CAST 15543) (T_EMPTY 15544) (T_EVAL 15545) (T_EXIT 15546) (T_FILE 15547) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 15548) (T_INC 15549) (T_INCLUDE 15550) (T_INCLUDE_ONCE 15551) (T_INT_CAST 15552) (T_ISSET 15553) (T_LINE 15554) (T_LIST 15555) (T_LNUMBER 15556) (T_MATCH 15557) (T_METHOD_C 15558) (T_NAME_FULLY_QUALIFIED 15559) (T_NAME_QUALIFIED 15560) (T_NAME_RELATIVE 15561) (T_NEW 15562) (T_NS_C 15563) (T_OBJECT_CAST 15564) (T_PRINT 15565) (T_READONLY 15566) (T_REQUIRE 15567) (T_REQUIRE_ONCE 15568) (T_START_HEREDOC 15569) (T_STATIC 15570) (T_STRING 15571) (T_STRING_CAST 15572) (T_THROW 15573) (T_TRAIT_C 15574) (T_UNSET_CAST 15575) (T_VARIABLE 15576) (T_YIELD 15577) (T_YIELD_FROM 15578) ("[" 15579) ("`" 15580) (array_object_dereferenceable 15581) (attribute 131) (attributes 15582) (callable_expr 15583) (callable_variable 15584) (class_constant 15585) (class_name 15586) (constant 15587) (dereferenceable_scalar 15588) (expr 25077) (fn 15590) (fully_dereferenceable 104) #'15591 (function_call 15592) (inline_function 15593) (internal_functions_in_yacc 15594) (match 15595) (name 15596) (new_expr 15597) (scalar 15598) (simple_variable 15599) (static_member 15600) (variable 15601) (variable_class_name 15602) ("~" 15603)) 12007 (("%" 15605) ("*" 15606) ("+" 15607) ("-" 15608) ("." 15609) ("/" 15610) ("<" 15611) (">" 15612) ("?" 15613) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 15614) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 15615) (T_BOOLEAN_AND 15616) (T_BOOLEAN_OR 15617) (T_COALESCE 15618) (T_INSTANCEOF 15619) (T_IS_EQUAL 15620) (T_IS_GREATER_OR_EQUAL 15621) (T_IS_IDENTICAL 15622) (T_IS_NOT_EQUAL 15623) (T_IS_NOT_IDENTICAL 15624) (T_IS_SMALLER_OR_EQUAL 15625) (T_LOGICAL_AND 15626) (T_LOGICAL_OR 15627) (T_LOGICAL_XOR 15628) (T_POW 15629) (T_SL 15630) (T_SPACESHIP 15631) (T_SR 15632) ("^" 15633) (backup_fn_flags 25078) ("|" 15634)) 12008 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25080) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 12009 (("$" 24700) (T_ABSTRACT 24878) (T_ARRAY 24879) (T_AS 24880) (T_BREAK 24881) (T_CALLABLE 24882) (T_CASE 24883) (T_CATCH 24884) (T_CLASS 24885) (T_CLASS_C 24886) (T_CLONE 24887) (T_CONST 24888) (T_CONTINUE 24889) (T_DECLARE 24890) (T_DEFAULT 24891) (T_DIR 24892) (T_DO 24893) (T_ECHO 24894) (T_ELSE 24895) (T_ELSEIF 24896) (T_EMPTY 24897) (T_ENDDECLARE 24898) (T_ENDFOR 24899) (T_ENDFOREACH 24900) (T_ENDIF 24901) (T_ENDSWITCH 24902) (T_ENDWHILE 24903) (T_ENUM 24904) (T_EVAL 24905) (T_EXIT 24906) (T_EXTENDS 24907) (T_FILE 24908) (T_FINAL 24909) (T_FINALLY 24910) (T_FN 24911) (T_FOR 24912) (T_FOREACH 24913) (T_FUNCTION 24914) (T_FUNC_C 24915) (T_GLOBAL 24916) (T_GOTO 24917) (T_IF 24918) (T_IMPLEMENTS 24919) (T_INCLUDE 24920) (T_INCLUDE_ONCE 24921) (T_INSTANCEOF 24922) (T_INSTEADOF 24923) (T_INTERFACE 24924) (T_ISSET 24925) (T_LINE 24926) (T_LIST 24927) (T_LOGICAL_AND 24928) (T_LOGICAL_OR 24929) (T_LOGICAL_XOR 24930) (T_MATCH 24931) (T_METHOD_C 24932) (T_NAMESPACE 24933) (T_NEW 24934) (T_NS_C 24935) (T_PRINT 24936) (T_PRIVATE 24937) (T_PROTECTED 24938) (T_PUBLIC 24939) (T_READONLY 24940) (T_REQUIRE 24941) (T_REQUIRE_ONCE 24942) (T_RETURN 24943) (T_STATIC 24944) (T_STRING 24945) (T_SWITCH 24946) (T_THROW 24947) (T_TRAIT 24948) (T_TRAIT_C 24949) (T_TRY 24950) (T_UNSET 24951) (T_USE 24952) (T_VAR 24953) (T_VARIABLE 24747) (T_WHILE 24954) (T_YIELD 24955) (identifier 25082) (member_name 25083) (reserved_non_modifiers 24958) (semi_reserved 24959) (simple_variable 25084) ("{" 25085)) 12010 (("(" 24964) (argument_list 25088)) 12011 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 25086) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12012 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 25087)) 12013 ((T_FN 35) (T_FUNCTION 127) (fn 24761) #'24762 (inline_function 25092)) 12014 (("$" 24700) (T_STRING 25101) (T_VARIABLE 24747) (property_name 25108) (simple_variable 25103) ("{" 25104)) 12015 (("$" 24700) (T_STRING 25101) (T_VARIABLE 24747) (property_name 25102) (simple_variable 25103) ("{" 25104)) 12016 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 25099) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 12017 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 25097) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12018 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 25098)) 12019 (("]" 25100)) 12020 (("(" 24964) (argument_list 25107)) 12021 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 25105) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12022 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 25106)) 12023 (("(" 24964) (argument_list 25109)) 12024 (("`" 25111)) 12025 (("]" 25113)) 12026 (("=" 25114)) 12027 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 25115) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 12028 (("%" 24776) ("*" 24777) ("+" 24778) ("-" 24779) ("." 24780) ("/" 24781) ("<" 24782) (">" 24783) ("?" 24784) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 24785) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 24786) (T_BOOLEAN_AND 24787) (T_BOOLEAN_OR 24788) (T_COALESCE 24789) (T_DOUBLE_ARROW 25118) (T_INSTANCEOF 24790) (T_IS_EQUAL 24791) (T_IS_GREATER_OR_EQUAL 24792) (T_IS_IDENTICAL 24793) (T_IS_NOT_EQUAL 24794) (T_IS_NOT_IDENTICAL 24795) (T_IS_SMALLER_OR_EQUAL 24796) (T_LOGICAL_AND 24797) (T_LOGICAL_OR 24798) (T_LOGICAL_XOR 24799) (T_POW 24800) (T_SL 24801) (T_SPACESHIP 24802) (T_SR 24803) ("^" 24804) ("|" 24805)) 12029 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 25119) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 12030 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 25128) (T_VARIABLE 2900) (encaps_var 2914)) 12031 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 25127) (T_VARIABLE 2900) (encaps_var 2905)) 12032 ((T_CLASS 25148)) 12033 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 25147) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 25135) (attribute 2980) (class_modifier 2945)) 12034 (("(" 25138) (argument_list 25139) (ctor_arguments 25140)) 12035 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 25141) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 25142) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 25143) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 12036 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 25146) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 12037 (("," 1469) (possible_comma 25144)) 12038 ((")" 25145)) 12039 (("(" 2982) (argument_list 2983) (ctor_arguments 25149)) 12040 ((T_EXTENDS 2985) (extends_from 25150)) 12041 ((T_IMPLEMENTS 2987) (implements_list 25151)) 12042 ((backup_doc_comment 25152)) 12043 (("{" 25153)) 12044 ((class_statement_list 25154)) 12045 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 25155)) 12046 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25157) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 12047 (("%" 292) (")" 25158) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 12048 (("{" 25159)) 12049 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 25160) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 12050 (("}" 25161)) 12051 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 25163) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 12052 ((")" 25164)) 12053 (("=" 25165)) 12054 (("!" 24698) ("\"" 24699) ("$" 24700) ("(" 24701) ("+" 24702) ("-" 24703) ("@" 24704) (T_ARRAY 24705) (T_ARRAY_CAST 24706) (T_ATTRIBUTE 126) (T_BOOL_CAST 24707) (T_CLASS_C 24708) (T_CLONE 24709) (T_CONSTANT_ENCAPSED_STRING 24710) (T_DEC 24711) (T_DIR 24712) (T_DNUMBER 24713) (T_DOUBLE_CAST 24714) (T_EMPTY 24715) (T_EVAL 24716) (T_EXIT 24717) (T_FILE 24718) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 24719) (T_INC 24720) (T_INCLUDE 24721) (T_INCLUDE_ONCE 24722) (T_INT_CAST 24723) (T_ISSET 24724) (T_LINE 24725) (T_LIST 24726) (T_LNUMBER 24727) (T_MATCH 24728) (T_METHOD_C 24729) (T_NAME_FULLY_QUALIFIED 24730) (T_NAME_QUALIFIED 24731) (T_NAME_RELATIVE 24732) (T_NEW 24733) (T_NS_C 24734) (T_OBJECT_CAST 24735) (T_PRINT 24736) (T_READONLY 24737) (T_REQUIRE 24738) (T_REQUIRE_ONCE 24739) (T_START_HEREDOC 24740) (T_STATIC 24741) (T_STRING 24742) (T_STRING_CAST 24743) (T_THROW 24744) (T_TRAIT_C 24745) (T_UNSET_CAST 24746) (T_VARIABLE 24747) (T_YIELD 24748) (T_YIELD_FROM 24749) ("[" 24750) ("`" 24751) (array_object_dereferenceable 24752) (attribute 131) (attributes 24753) (callable_expr 24754) (callable_variable 24755) (class_constant 24756) (class_name 24757) (constant 24758) (dereferenceable_scalar 24759) (expr 25166) (fn 24761) (fully_dereferenceable 104) #'24762 (function_call 24763) (inline_function 24764) (internal_functions_in_yacc 24765) (match 24766) (name 24767) (new_expr 24768) (scalar 24769) (simple_variable 24770) (static_member 24771) (variable 24772) (variable_class_name 24773) ("~" 24774)) 12055 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 25168) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 12056 (("," 5258) (possible_comma 25169)) 12057 ((")" 25170)) 12058 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 25177) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 12059 ((")" 25178)) 12060 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25180) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 12061 (("%" 292) (")" 25181) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 12062 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25183) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 12063 (("%" 292) (")" 25184) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 12064 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 25191) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 12065 ((")" 25192)) 12066 (("%" 292) (")" 25197) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 12067 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 25200) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12068 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 25201)) 12069 (("\"" 25203) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 12070 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 25213) (T_VARIABLE 2900) (encaps_var 2914)) 12071 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 25212) (T_VARIABLE 2900) (encaps_var 2905)) 12072 ((T_CLASS 25233)) 12073 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 25232) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 25220) (attribute 2980) (class_modifier 2945)) 12074 (("(" 25223) (argument_list 25224) (ctor_arguments 25225)) 12075 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 25226) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 25227) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 25228) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 12076 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 25231) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 12077 (("," 1469) (possible_comma 25229)) 12078 ((")" 25230)) 12079 (("(" 2982) (argument_list 2983) (ctor_arguments 25234)) 12080 ((T_EXTENDS 2985) (extends_from 25235)) 12081 ((T_IMPLEMENTS 2987) (implements_list 25236)) 12082 ((backup_doc_comment 25237)) 12083 (("{" 25238)) 12084 ((class_statement_list 25239)) 12085 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 25240)) 12086 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25242) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 12087 (("%" 292) (")" 25243) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 12088 (("{" 25244)) 12089 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 25245) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 12090 (("}" 25246)) 12091 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 25248) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 12092 ((")" 25249)) 12093 (("=" 25250)) 12094 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25251) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 12095 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 25253) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 12096 (("," 5258) (possible_comma 25254)) 12097 ((")" 25255)) 12098 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 25262) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 12099 ((")" 25263)) 12100 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25265) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 12101 (("%" 292) (")" 25266) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 12102 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 12103 (("%" 292) (")" 25269) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 12104 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 25276) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 12105 ((")" 25277)) 12106 (("%" 292) (")" 25282) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 12107 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 25285) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12108 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 25286)) 12109 (("\"" 25288) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 12110 ((T_READONLY 16265) (T_STRING 16266) (backup_doc_comment 139) (function_name 25292)) 12111 ((backup_doc_comment 25293)) 12112 (("(" 25294)) 12113 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 25295)) 12114 ((")" 25296)) 12115 ((":" 161) (return_type 25297)) 12116 ((backup_fn_flags 25298)) 12117 (("{" 25299)) 12118 ((inner_statement_list 25300)) 12119 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 25301) ("~" 125)) 12120 ((backup_fn_flags 25302)) 12121 ((T_STRING 25305)) 12122 ((T_EXTENDS 2985) (extends_from 25306)) 12123 ((T_IMPLEMENTS 2987) (implements_list 25307)) 12124 ((backup_doc_comment 25308)) 12125 (("{" 25309)) 12126 ((class_statement_list 25310)) 12127 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 25311)) 12128 ((":" 25316)) 12129 ((";" 25315)) 12130 ((inner_statement_list 25317)) 12131 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16298) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16299) (T_CLASS 16300) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16301) (T_DEC 22) (T_DECLARE 16302) (T_DIR 24) (T_DNUMBER 25) (T_DO 16303) (T_DOUBLE_CAST 27) (T_ECHO 16304) (T_EMPTY 29) (T_ENDIF 25318) (T_ENUM 16306) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16307) (T_FOREACH 16308) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16309) (T_GOTO 16310) (T_HALT_COMPILER 16311) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16312) (T_INTERFACE 16313) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16314) (T_START_HEREDOC 68) (T_STATIC 16315) (T_STRING 16316) (T_STRING_CAST 71) (T_SWITCH 16317) (T_THROW 73) (T_TRAIT 16318) (T_TRAIT_C 75) (T_TRY 16319) (T_UNSET 16320) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16321) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16322) (alt_if_stmt_without_else 16323) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16324) (attributes 16325) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16326) (class_modifier 96) (class_modifiers 16327) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16328) (expr 16329) (fn 103) (fully_dereferenceable 104) #'16330 (function_call 106) (function_declaration_statement 16331) (if_stmt 16332) (if_stmt_without_else 16333) (inline_function 110) (inner_statement 16334) (interface_declaration_statement 16335) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16336) (static_member 119) (trait_declaration_statement 16337) (variable 122) (variable_class_name 123) ("{" 16338) ("~" 125)) 12132 ((";" 25319)) 12133 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25321) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 12134 (("%" 292) (")" 25322) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 12135 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 25323) (";" 166) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 197) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 25324) (static_member 119) (variable 122) (variable_class_name 123) (while_statement 25325) ("{" 206) ("~" 125)) 12136 ((inner_statement_list 25326)) 12137 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16379) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16380) (T_CLASS 16381) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16382) (T_DEC 22) (T_DECLARE 16383) (T_DIR 24) (T_DNUMBER 25) (T_DO 16384) (T_DOUBLE_CAST 27) (T_ECHO 16385) (T_EMPTY 29) (T_ENDWHILE 25327) (T_ENUM 16387) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16388) (T_FOREACH 16389) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16390) (T_GOTO 16391) (T_HALT_COMPILER 16392) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16394) (T_INTERFACE 16395) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16396) (T_START_HEREDOC 68) (T_STATIC 16397) (T_STRING 16398) (T_STRING_CAST 71) (T_SWITCH 16399) (T_THROW 73) (T_TRAIT 16400) (T_TRAIT_C 75) (T_TRY 16401) (T_UNSET 16402) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16403) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16404) (alt_if_stmt_without_else 16405) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16406) (attributes 16407) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16408) (class_modifier 96) (class_modifiers 16409) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16410) (expr 16411) (fn 103) (fully_dereferenceable 104) #'16412 (function_call 106) (function_declaration_statement 16413) (if_stmt 16414) (if_stmt_without_else 16415) (inline_function 110) (inner_statement 16416) (interface_declaration_statement 16417) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16418) (static_member 119) (trait_declaration_statement 16419) (variable 122) (variable_class_name 123) ("{" 16420) ("~" 125)) 12138 ((";" 25328)) 12139 (("\"" 1509) ("$" 16475) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 16476) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 16477) ("[" 1529) (array_object_dereferenceable 16478) (callable_expr 16479) (callable_variable 16480) (class_constant 1533) (class_name 16481) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 16482) (name 16483) (simple_variable 16484) (static_member 16485) (unset_variable 16486) (unset_variables 25330) (variable 16488) (variable_class_name 16489)) 12140 (("," 16501) (possible_comma 25331)) 12141 ((")" 25332)) 12142 ((";" 25333)) 12143 ((inner_statement_list 25335)) 12144 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 25336) ("~" 125)) 12145 ((catch_list 25337)) 12146 ((T_CATCH 25338) (T_FINALLY 25339) (finally_statement 25340)) 12147 (("(" 25344)) 12148 (("{" 25341)) 12149 ((inner_statement_list 25342)) 12150 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 25343) ("~" 125)) 12151 ((T_NAME_FULLY_QUALIFIED 16545) (T_NAME_QUALIFIED 16546) (T_NAME_RELATIVE 16547) (T_STATIC 16548) (T_STRING 16549) (catch_name_list 25345) (class_name 16551) (name 16552)) 12152 ((T_VARIABLE 16553) (optional_variable 25346) ("|" 16555)) 12153 ((")" 25347)) 12154 (("{" 25348)) 12155 ((inner_statement_list 25349)) 12156 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 25350) ("~" 125)) 12157 ((backup_doc_comment 25352)) 12158 (("{" 25353)) 12159 ((class_statement_list 25354)) 12160 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 25355)) 12161 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25357) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 12162 (("%" 292) (")" 25358) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 12163 ((":" 25359) (switch_case_list 25360) ("{" 25361)) 12164 ((";" 25367) (case_list 25368)) 12165 ((";" 25362) (case_list 25363)) 12166 ((case_list 25365)) 12167 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 25364)) 12168 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 25366)) 12169 ((case_list 25371)) 12170 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 25369)) 12171 ((";" 25370)) 12172 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 25372)) 12173 ((";" 25373)) 12174 (("," 16852) (";" 25376)) 12175 ((";" 25378)) 12176 ((T_EXTENDS 20209) (interface_extends_list 25380)) 12177 ((backup_doc_comment 25381)) 12178 (("{" 25382)) 12179 ((class_statement_list 25383)) 12180 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 25384)) 12181 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25386) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 12182 (("%" 292) (")" 25387) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 12183 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20219) (";" 16172) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 16173) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16174) (T_DEC 22) (T_DECLARE 16175) (T_DIR 24) (T_DNUMBER 25) (T_DO 16176) (T_DOUBLE_CAST 27) (T_ECHO 16177) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 16178) (T_FOREACH 16179) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 16180) (T_GOTO 16181) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16182) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16183) (T_START_HEREDOC 68) (T_STATIC 16184) (T_STRING 16185) (T_STRING_CAST 71) (T_SWITCH 16186) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 16187) (T_UNSET 16188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16190) (alt_if_stmt_without_else 16191) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 16192) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 16193) (if_stmt_without_else 16194) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 25388) (static_member 119) (variable 122) (variable_class_name 123) ("{" 16196) ("~" 125)) 12184 ((")" 25390)) 12185 ((";" 25391)) 12186 ((";" 25393)) 12187 (("," 17875) (";" 25395)) 12188 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 25397) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 12189 (("%" 17961) ("*" 17962) ("+" 17963) ("-" 17964) ("." 17965) ("/" 17966) ("<" 17967) (">" 17968) ("?" 17969) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 17970) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 17971) (T_AS 25398) (T_BOOLEAN_AND 17972) (T_BOOLEAN_OR 17973) (T_COALESCE 17974) (T_INSTANCEOF 17975) (T_IS_EQUAL 17976) (T_IS_GREATER_OR_EQUAL 17977) (T_IS_IDENTICAL 17978) (T_IS_NOT_EQUAL 17979) (T_IS_NOT_IDENTICAL 17980) (T_IS_SMALLER_OR_EQUAL 17981) (T_LOGICAL_AND 17982) (T_LOGICAL_OR 17983) (T_LOGICAL_XOR 17984) (T_POW 17985) (T_SL 17986) (T_SPACESHIP 17987) (T_SR 17988) ("^" 17989) ("|" 17990)) 12190 (("\"" 1509) ("$" 19325) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19326) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19327) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19328) ("[" 19329) (ampersand 19330) (array_object_dereferenceable 19331) (callable_expr 19332) (callable_variable 19333) (class_constant 1533) (class_name 19334) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 25399) (fully_dereferenceable 104) (function_call 19336) (name 19337) (simple_variable 19338) (static_member 19339) (variable 19340) (variable_class_name 19341)) 12191 ((")" 25400) (T_DOUBLE_ARROW 25401)) 12192 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 25404) (";" 166) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 197) (fn 103) (foreach_statement 25410) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 25406) (static_member 119) (variable 122) (variable_class_name 123) ("{" 206) ("~" 125)) 12193 (("\"" 1509) ("$" 19356) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19357) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19358) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19359) ("[" 19360) (ampersand 19361) (array_object_dereferenceable 19362) (callable_expr 19363) (callable_variable 19364) (class_constant 1533) (class_name 19365) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 25402) (fully_dereferenceable 104) (function_call 19367) (name 19368) (simple_variable 19369) (static_member 19370) (variable 19371) (variable_class_name 19372)) 12194 ((")" 25403)) 12195 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 25404) (";" 166) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 197) (fn 103) (foreach_statement 25405) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 25406) (static_member 119) (variable 122) (variable_class_name 123) ("{" 206) ("~" 125)) 12196 ((inner_statement_list 25407)) 12197 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19390) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19391) (T_CLASS 19392) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19393) (T_DEC 22) (T_DECLARE 19394) (T_DIR 24) (T_DNUMBER 25) (T_DO 19395) (T_DOUBLE_CAST 27) (T_ECHO 19396) (T_EMPTY 29) (T_ENDFOREACH 25408) (T_ENUM 19398) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19399) (T_FOREACH 19400) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19401) (T_GOTO 19402) (T_HALT_COMPILER 19403) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19405) (T_INTERFACE 19406) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19407) (T_START_HEREDOC 68) (T_STATIC 19408) (T_STRING 19409) (T_STRING_CAST 71) (T_SWITCH 19410) (T_THROW 73) (T_TRAIT 19411) (T_TRAIT_C 75) (T_TRY 19412) (T_UNSET 19413) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19414) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19415) (alt_if_stmt_without_else 19416) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19417) (attributes 19418) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19419) (class_modifier 96) (class_modifiers 19420) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19421) (expr 19422) (fn 103) (fully_dereferenceable 104) #'19423 (function_call 106) (function_declaration_statement 19424) (if_stmt 19425) (if_stmt_without_else 19426) (inline_function 110) (inner_statement 19427) (interface_declaration_statement 19428) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19429) (static_member 119) (trait_declaration_statement 19430) (variable 122) (variable_class_name 123) ("{" 19431) ("~" 125)) 12198 ((";" 25409)) 12199 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 25412) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 12200 ((";" 25413)) 12201 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 25414) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 12202 ((";" 25415)) 12203 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 19558) (fn 2394) (for_exprs 25416) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (non_empty_for_exprs 19560) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 12204 ((")" 25417)) 12205 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 25418) (";" 166) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 197) (fn 103) (for_statement 25419) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 25420) (static_member 119) (variable 122) (variable_class_name 123) ("{" 206) ("~" 125)) 12206 ((inner_statement_list 25421)) 12207 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19568) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19569) (T_CLASS 19570) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19571) (T_DEC 22) (T_DECLARE 19572) (T_DIR 24) (T_DNUMBER 25) (T_DO 19573) (T_DOUBLE_CAST 27) (T_ECHO 19574) (T_EMPTY 29) (T_ENDFOR 25422) (T_ENUM 19576) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19577) (T_FOREACH 19578) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19579) (T_GOTO 19580) (T_HALT_COMPILER 19581) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19583) (T_INTERFACE 19584) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19585) (T_START_HEREDOC 68) (T_STATIC 19586) (T_STRING 19587) (T_STRING_CAST 71) (T_SWITCH 19588) (T_THROW 73) (T_TRAIT 19589) (T_TRAIT_C 75) (T_TRY 19590) (T_UNSET 19591) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19592) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19593) (alt_if_stmt_without_else 19594) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19595) (attributes 19596) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19597) (class_modifier 96) (class_modifiers 19598) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19599) (expr 19600) (fn 103) (fully_dereferenceable 104) #'19601 (function_call 106) (function_declaration_statement 19602) (if_stmt 19603) (if_stmt_without_else 19604) (inline_function 110) (inner_statement 19605) (interface_declaration_statement 19606) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19607) (static_member 119) (trait_declaration_statement 19608) (variable 122) (variable_class_name 123) ("{" 19609) ("~" 125)) 12208 ((";" 25423)) 12209 ((":" 20258) (enum_backing_type 25425)) 12210 ((T_IMPLEMENTS 2987) (implements_list 25426)) 12211 ((backup_doc_comment 25427)) 12212 (("{" 25428)) 12213 ((class_statement_list 25429)) 12214 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 25430)) 12215 (("," 19743) (";" 25432)) 12216 ((T_WHILE 25434)) 12217 (("(" 25435)) 12218 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25436) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 12219 (("%" 292) (")" 25437) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 12220 ((";" 25438)) 12221 ((T_STRING 19916) (const_decl 19917) (const_list 25440)) 12222 ((")" 25441) ("," 19920)) 12223 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 25442) (";" 166) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (declare_statement 25443) (dereferenceable_scalar 100) (expr 197) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 25444) (static_member 119) (variable 122) (variable_class_name 123) ("{" 206) ("~" 125)) 12224 ((inner_statement_list 25445)) 12225 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19926) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19927) (T_CLASS 19928) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19929) (T_DEC 22) (T_DECLARE 19930) (T_DIR 24) (T_DNUMBER 25) (T_DO 19931) (T_DOUBLE_CAST 27) (T_ECHO 19932) (T_EMPTY 29) (T_ENDDECLARE 25446) (T_ENUM 19934) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19935) (T_FOREACH 19936) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19937) (T_GOTO 19938) (T_HALT_COMPILER 19939) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19941) (T_INTERFACE 19942) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19943) (T_START_HEREDOC 68) (T_STATIC 19944) (T_STRING 19945) (T_STRING_CAST 71) (T_SWITCH 19946) (T_THROW 73) (T_TRAIT 19947) (T_TRAIT_C 75) (T_TRY 19948) (T_UNSET 19949) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19950) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19951) (alt_if_stmt_without_else 19952) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19953) (attributes 19954) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19955) (class_modifier 96) (class_modifiers 19956) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19957) (expr 19958) (fn 103) (fully_dereferenceable 104) #'19959 (function_call 106) (function_declaration_statement 19960) (if_stmt 19961) (if_stmt_without_else 19962) (inline_function 110) (inner_statement 19963) (interface_declaration_statement 19964) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19965) (static_member 119) (trait_declaration_statement 19966) (variable 122) (variable_class_name 123) ("{" 19967) ("~" 125)) 12226 ((";" 25447)) 12227 ((";" 25449)) 12228 ((T_EXTENDS 2985) (extends_from 25451)) 12229 ((T_IMPLEMENTS 2987) (implements_list 25452)) 12230 ((backup_doc_comment 25453)) 12231 (("{" 25454)) 12232 ((class_statement_list 25455)) 12233 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 25456)) 12234 ((";" 25458)) 12235 ((T_ARRAY 25504) (T_CALLABLE 25505) (T_NAME_FULLY_QUALIFIED 25506) (T_NAME_QUALIFIED 25507) (T_NAME_RELATIVE 25508) (T_STATIC 25509) (T_STRING 25510) (name 25511) (type 25512) (type_without_static 25513)) 12236 ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 25502)) 12237 ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 25491)) 12238 (("|" 25489)) 12239 (("|" 25474)) 12240 (("(" 25475) (T_ARRAY 25476) (T_CALLABLE 25477) (T_NAME_FULLY_QUALIFIED 25478) (T_NAME_QUALIFIED 25479) (T_NAME_RELATIVE 25480) (T_STATIC 25481) (T_STRING 25482) (name 25483) (type 25484) (type_without_static 25485) (union_type_element 25486)) 12241 ((T_ARRAY 2277) (T_CALLABLE 2278) (T_NAME_FULLY_QUALIFIED 2279) (T_NAME_QUALIFIED 2280) (T_NAME_RELATIVE 2281) (T_STATIC 2282) (T_STRING 2283) (intersection_type 25487) (name 2285) (type 2286) (type_without_static 2287)) 12242 ((")" 25488) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 2300)) 12243 (("(" 25475) (T_ARRAY 25476) (T_CALLABLE 25477) (T_NAME_FULLY_QUALIFIED 25478) (T_NAME_QUALIFIED 25479) (T_NAME_RELATIVE 25480) (T_STATIC 25481) (T_STRING 25482) (name 25483) (type 25484) (type_without_static 25485) (union_type_element 25490)) 12244 ((T_ARRAY 25492) (T_CALLABLE 25493) (T_NAME_FULLY_QUALIFIED 25494) (T_NAME_QUALIFIED 25495) (T_NAME_RELATIVE 25496) (T_STATIC 25497) (T_STRING 25498) (name 25499) (type 25500) (type_without_static 25501)) 12245 ((T_ARRAY 25492) (T_CALLABLE 25493) (T_NAME_FULLY_QUALIFIED 25494) (T_NAME_QUALIFIED 25495) (T_NAME_RELATIVE 25496) (T_STATIC 25497) (T_STRING 25498) (name 25499) (type 25503) (type_without_static 25501)) 12246 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 25515) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 25516) (T_VARIABLE 25517) (ampersand 25518) (lexical_var 25519) (lexical_var_list 25520)) 12247 ((T_VARIABLE 25525)) 12248 (("," 25521) (possible_comma 25522)) 12249 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 25515) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 25516) (T_VARIABLE 25517) (ampersand 25518) (lexical_var 25524)) 12250 ((")" 25523)) 12251 ((T_ARRAY 25574) (T_CALLABLE 25575) (T_NAME_FULLY_QUALIFIED 25576) (T_NAME_QUALIFIED 25577) (T_NAME_RELATIVE 25578) (T_STRING 25579) (name 25580) (type_without_static 25581)) 12252 ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 25572)) 12253 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 25564) (is_reference 25565)) 12254 ((T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 25555)) 12255 (("|" 25553)) 12256 (("|" 25540)) 12257 (("(" 25541) (T_ARRAY 25542) (T_CALLABLE 25543) (T_NAME_FULLY_QUALIFIED 25544) (T_NAME_QUALIFIED 25545) (T_NAME_RELATIVE 25546) (T_STRING 25547) (name 25548) (type_without_static 25549) (union_type_without_static_element 25550)) 12258 ((T_ARRAY 2277) (T_CALLABLE 2278) (T_NAME_FULLY_QUALIFIED 2279) (T_NAME_QUALIFIED 2280) (T_NAME_RELATIVE 2281) (T_STRING 2283) (intersection_type_without_static 25551) (name 2285) (type_without_static 3041)) 12259 ((")" 25552) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 3045)) 12260 (("(" 25541) (T_ARRAY 25542) (T_CALLABLE 25543) (T_NAME_FULLY_QUALIFIED 25544) (T_NAME_QUALIFIED 25545) (T_NAME_RELATIVE 25546) (T_STRING 25547) (name 25548) (type_without_static 25549) (union_type_without_static_element 25554)) 12261 ((T_ARRAY 25556) (T_CALLABLE 25557) (T_NAME_FULLY_QUALIFIED 25558) (T_NAME_QUALIFIED 25559) (T_NAME_RELATIVE 25560) (T_STRING 25561) (name 25562) (type_without_static 25563)) 12262 ((T_ELLIPSIS 25566) (is_variadic 25567)) 12263 ((T_VARIABLE 25568)) 12264 ((backup_doc_comment 25569)) 12265 (("=" 25570)) 12266 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 25571) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 12267 ((T_ARRAY 25556) (T_CALLABLE 25557) (T_NAME_FULLY_QUALIFIED 25558) (T_NAME_QUALIFIED 25559) (T_NAME_RELATIVE 25560) (T_STRING 25561) (name 25562) (type_without_static 25573)) 12268 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 25584) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (optional_cpp_modifiers 155) (parameter 156)) 12269 (("," 6583) (possible_comma 25589)) 12270 (("]" 25590)) 12271 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 25593) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 25594) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 25595) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 12272 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 25598) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 12273 (("," 1469) (possible_comma 25596)) 12274 ((")" 25597)) 12275 (("," 6583) (possible_comma 25600)) 12276 (("]" 25601)) 12277 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 25603) ("~" 125)) 12278 (("$" 4) (T_ABSTRACT 25605) (T_ARRAY 25606) (T_AS 25607) (T_BREAK 25608) (T_CALLABLE 25609) (T_CASE 25610) (T_CATCH 25611) (T_CLASS 25612) (T_CLASS_C 25613) (T_CLONE 25614) (T_CONST 25615) (T_CONTINUE 25616) (T_DECLARE 25617) (T_DEFAULT 25618) (T_DIR 25619) (T_DO 25620) (T_ECHO 25621) (T_ELSE 25622) (T_ELSEIF 25623) (T_EMPTY 25624) (T_ENDDECLARE 25625) (T_ENDFOR 25626) (T_ENDFOREACH 25627) (T_ENDIF 25628) (T_ENDSWITCH 25629) (T_ENDWHILE 25630) (T_ENUM 25631) (T_EVAL 25632) (T_EXIT 25633) (T_EXTENDS 25634) (T_FILE 25635) (T_FINAL 25636) (T_FINALLY 25637) (T_FN 25638) (T_FOR 25639) (T_FOREACH 25640) (T_FUNCTION 25641) (T_FUNC_C 25642) (T_GLOBAL 25643) (T_GOTO 25644) (T_IF 25645) (T_IMPLEMENTS 25646) (T_INCLUDE 25647) (T_INCLUDE_ONCE 25648) (T_INSTANCEOF 25649) (T_INSTEADOF 25650) (T_INTERFACE 25651) (T_ISSET 25652) (T_LINE 25653) (T_LIST 25654) (T_LOGICAL_AND 25655) (T_LOGICAL_OR 25656) (T_LOGICAL_XOR 25657) (T_MATCH 25658) (T_METHOD_C 25659) (T_NAMESPACE 25660) (T_NEW 25661) (T_NS_C 25662) (T_PRINT 25663) (T_PRIVATE 25664) (T_PROTECTED 25665) (T_PUBLIC 25666) (T_READONLY 25667) (T_REQUIRE 25668) (T_REQUIRE_ONCE 25669) (T_RETURN 25670) (T_STATIC 25671) (T_STRING 25672) (T_SWITCH 25673) (T_THROW 25674) (T_TRAIT 25675) (T_TRAIT_C 25676) (T_TRY 25677) (T_UNSET 25678) (T_USE 25679) (T_VAR 25680) (T_VARIABLE 80) (T_WHILE 25681) (T_YIELD 25682) (identifier 25683) (member_name 25684) (reserved_non_modifiers 25685) (semi_reserved 25686) (simple_variable 25687) ("{" 25688)) 12279 (("(" 25591) (argument_list 25691)) 12280 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 25689) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12281 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 25690)) 12282 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (ampersand 25721) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 25722) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 12283 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 25720) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 12284 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 25719) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 12285 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 25718) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 12286 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 25717) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 12287 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 25716) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 12288 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 25715) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 12289 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 25714) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 12290 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 25713) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 12291 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 25712) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 12292 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 25711) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 12293 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 25710) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 12294 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 25709) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 12295 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 25708) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 12296 (("\"" 1509) ("$" 25723) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 25724) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 25725) ("[" 1529) (array_object_dereferenceable 25726) (callable_expr 25727) (callable_variable 25728) (class_constant 1533) (class_name 25729) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 25730) (name 25731) (simple_variable 25732) (static_member 25733) (variable 25734) (variable_class_name 25735)) 12297 (("$" 25723) (T_VARIABLE 25725) (simple_variable 25771) ("{" 25772)) 12298 (("(" 25739) (argument_list 25770)) 12299 ((T_NULLSAFE_OBJECT_OPERATOR 25753) (T_OBJECT_OPERATOR 25754) ("[" 25755) ("{" 25756)) 12300 (("(" 25739) (argument_list 25752)) 12301 ((T_PAAMAYIM_NEKUDOTAYIM 25748)) 12302 (("(" 25739) (argument_list 25747)) 12303 ((T_PAAMAYIM_NEKUDOTAYIM 25736)) 12304 (("$" 25723) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 25725) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 25737) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 25738) ("{" 1627)) 12305 (("(" 25739) (argument_list 25740)) 12306 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 25741) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 25742) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 25743) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 12307 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 25746) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 12308 (("," 1469) (possible_comma 25744)) 12309 ((")" 25745)) 12310 (("$" 25723) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 25725) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 25749) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 25750) ("{" 1643)) 12311 (("(" 25739) (argument_list 25751)) 12312 (("$" 25723) (T_STRING 25761) (T_VARIABLE 25725) (property_name 25768) (simple_variable 25763) ("{" 25764)) 12313 (("$" 25723) (T_STRING 25761) (T_VARIABLE 25725) (property_name 25762) (simple_variable 25763) ("{" 25764)) 12314 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 25759) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 12315 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 25757) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12316 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 25758)) 12317 (("]" 25760)) 12318 (("(" 25739) (argument_list 25767)) 12319 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 25765) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12320 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 25766)) 12321 (("(" 25739) (argument_list 25769)) 12322 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 25773) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12323 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 25774)) 12324 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 8) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 15) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 21) (T_DEC 22) (T_DECLARE 23) (T_DIR 24) (T_DNUMBER 25) (T_DO 26) (T_DOUBLE_CAST 27) (T_ECHO 28) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 36) (T_FOREACH 37) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 40) (T_GOTO 41) (T_IF 43) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 47) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 67) (T_START_HEREDOC 68) (T_STATIC 69) (T_STRING 70) (T_STRING_CAST 71) (T_SWITCH 72) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 76) (T_UNSET 77) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 81) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 86) (alt_if_stmt_without_else 87) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 102) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 108) (if_stmt_without_else 109) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 25925) (static_member 119) (variable 122) (variable_class_name 123) ("{" 124) ("~" 125)) 12325 (("(" 25778)) 12326 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25779) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 12327 (("%" 292) (")" 25780) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 12328 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 25781) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 25782) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 25783) (T_DEC 22) (T_DECLARE 25784) (T_DIR 24) (T_DNUMBER 25) (T_DO 25785) (T_DOUBLE_CAST 27) (T_ECHO 25786) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 25787) (T_FOREACH 25788) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 25789) (T_GOTO 25790) (T_IF 43) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 25791) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 25792) (T_START_HEREDOC 68) (T_STATIC 25793) (T_STRING 25794) (T_STRING_CAST 71) (T_SWITCH 25795) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 25796) (T_UNSET 25797) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 25798) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 25799) (alt_if_stmt_without_else 25800) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 25801) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 25802) (if_stmt_without_else 25803) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 25804) (static_member 119) (variable 122) (variable_class_name 123) ("{" 25805) ("~" 125)) 12329 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 25923) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 12330 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 25921) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 12331 (("(" 25912)) 12332 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19746) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19747) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19748) (T_DEC 22) (T_DECLARE 19749) (T_DIR 24) (T_DNUMBER 25) (T_DO 19750) (T_DOUBLE_CAST 27) (T_ECHO 19751) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19752) (T_FOREACH 19753) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19754) (T_GOTO 19755) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19757) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19758) (T_START_HEREDOC 68) (T_STATIC 19759) (T_STRING 19760) (T_STRING_CAST 71) (T_SWITCH 19761) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19762) (T_UNSET 19763) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19764) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19765) (alt_if_stmt_without_else 19766) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19767) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19768) (if_stmt_without_else 19769) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 25906) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19771) ("~" 125)) 12333 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (echo_expr 19740) (echo_expr_list 25904) (expr 19742) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 12334 (("(" 25891)) 12335 (("(" 25876)) 12336 (("$" 17870) (T_VARIABLE 17871) (global_var 17872) (global_var_list 25874) (simple_variable 17874)) 12337 ((T_STRING 25872)) 12338 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 25870) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 12339 ((T_FN 35) (T_FUNCTION 127) (T_VARIABLE 16848) (fn 103) #'134 (inline_function 16849) (static_var 16850) (static_var_list 25868)) 12340 ((":" 25867)) 12341 (("(" 25849)) 12342 (("{" 25832)) 12343 (("(" 25827)) 12344 (("(" 25818)) 12345 ((T_ELSE 25811) (T_ELSEIF 16203) (T_ENDIF 25812)) 12346 (("%" 6465) ("*" 6466) ("+" 6467) ("-" 6468) ("." 6469) ("/" 6470) (";" 25810) ("<" 6471) (">" 6472) ("?" 6473) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 6474) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 6475) (T_BOOLEAN_AND 6476) (T_BOOLEAN_OR 6477) (T_COALESCE 6478) (T_INSTANCEOF 6479) (T_IS_EQUAL 6480) (T_IS_GREATER_OR_EQUAL 6481) (T_IS_IDENTICAL 6482) (T_IS_NOT_EQUAL 6483) (T_IS_NOT_IDENTICAL 6484) (T_IS_SMALLER_OR_EQUAL 6485) (T_LOGICAL_AND 6486) (T_LOGICAL_OR 6487) (T_LOGICAL_XOR 6488) (T_POW 6489) (T_SL 6490) (T_SPACESHIP 6491) (T_SR 6492) ("^" 6493) ("|" 6494)) 12347 ((T_ELSE 25808) (T_ELSEIF 25777)) 12348 ((inner_statement_list 25806)) 12349 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 25807) ("~" 125)) 12350 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 25781) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 25782) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 25783) (T_DEC 22) (T_DECLARE 25784) (T_DIR 24) (T_DNUMBER 25) (T_DO 25785) (T_DOUBLE_CAST 27) (T_ECHO 25786) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 25787) (T_FOREACH 25788) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 25789) (T_GOTO 25790) (T_IF 43) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 25791) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 25792) (T_START_HEREDOC 68) (T_STATIC 25793) (T_STRING 25794) (T_STRING_CAST 71) (T_SWITCH 25795) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 25796) (T_UNSET 25797) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 25798) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 25799) (alt_if_stmt_without_else 25800) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 25801) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 25802) (if_stmt_without_else 25803) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 25809) (static_member 119) (variable 122) (variable_class_name 123) ("{" 25805) ("~" 125)) 12351 ((":" 25814)) 12352 ((";" 25813)) 12353 ((inner_statement_list 25815)) 12354 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16298) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16299) (T_CLASS 16300) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16301) (T_DEC 22) (T_DECLARE 16302) (T_DIR 24) (T_DNUMBER 25) (T_DO 16303) (T_DOUBLE_CAST 27) (T_ECHO 16304) (T_EMPTY 29) (T_ENDIF 25816) (T_ENUM 16306) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16307) (T_FOREACH 16308) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16309) (T_GOTO 16310) (T_HALT_COMPILER 16311) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16312) (T_INTERFACE 16313) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16314) (T_START_HEREDOC 68) (T_STATIC 16315) (T_STRING 16316) (T_STRING_CAST 71) (T_SWITCH 16317) (T_THROW 73) (T_TRAIT 16318) (T_TRAIT_C 75) (T_TRY 16319) (T_UNSET 16320) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16321) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16322) (alt_if_stmt_without_else 16323) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16324) (attributes 16325) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16326) (class_modifier 96) (class_modifiers 16327) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16328) (expr 16329) (fn 103) (fully_dereferenceable 104) #'16330 (function_call 106) (function_declaration_statement 16331) (if_stmt 16332) (if_stmt_without_else 16333) (inline_function 110) (inner_statement 16334) (interface_declaration_statement 16335) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16336) (static_member 119) (trait_declaration_statement 16337) (variable 122) (variable_class_name 123) ("{" 16338) ("~" 125)) 12355 ((";" 25817)) 12356 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25819) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 12357 (("%" 292) (")" 25820) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 12358 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 25821) (";" 25781) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 25782) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 25783) (T_DEC 22) (T_DECLARE 25784) (T_DIR 24) (T_DNUMBER 25) (T_DO 25785) (T_DOUBLE_CAST 27) (T_ECHO 25786) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 25787) (T_FOREACH 25788) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 25789) (T_GOTO 25790) (T_IF 43) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 25791) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 25792) (T_START_HEREDOC 68) (T_STATIC 25793) (T_STRING 25794) (T_STRING_CAST 71) (T_SWITCH 25795) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 25796) (T_UNSET 25797) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 25798) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 25799) (alt_if_stmt_without_else 25800) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 25801) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 25802) (if_stmt_without_else 25803) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 25822) (static_member 119) (variable 122) (variable_class_name 123) (while_statement 25823) ("{" 25805) ("~" 125)) 12359 ((inner_statement_list 25824)) 12360 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16379) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16380) (T_CLASS 16381) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16382) (T_DEC 22) (T_DECLARE 16383) (T_DIR 24) (T_DNUMBER 25) (T_DO 16384) (T_DOUBLE_CAST 27) (T_ECHO 16385) (T_EMPTY 29) (T_ENDWHILE 25825) (T_ENUM 16387) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16388) (T_FOREACH 16389) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16390) (T_GOTO 16391) (T_HALT_COMPILER 16392) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16394) (T_INTERFACE 16395) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16396) (T_START_HEREDOC 68) (T_STATIC 16397) (T_STRING 16398) (T_STRING_CAST 71) (T_SWITCH 16399) (T_THROW 73) (T_TRAIT 16400) (T_TRAIT_C 75) (T_TRY 16401) (T_UNSET 16402) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16403) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16404) (alt_if_stmt_without_else 16405) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16406) (attributes 16407) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16408) (class_modifier 96) (class_modifiers 16409) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16410) (expr 16411) (fn 103) (fully_dereferenceable 104) #'16412 (function_call 106) (function_declaration_statement 16413) (if_stmt 16414) (if_stmt_without_else 16415) (inline_function 110) (inner_statement 16416) (interface_declaration_statement 16417) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16418) (static_member 119) (trait_declaration_statement 16419) (variable 122) (variable_class_name 123) ("{" 16420) ("~" 125)) 12361 ((";" 25826)) 12362 (("\"" 1509) ("$" 16475) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 16476) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 16477) ("[" 1529) (array_object_dereferenceable 16478) (callable_expr 16479) (callable_variable 16480) (class_constant 1533) (class_name 16481) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 16482) (name 16483) (simple_variable 16484) (static_member 16485) (unset_variable 16486) (unset_variables 25828) (variable 16488) (variable_class_name 16489)) 12363 (("," 16501) (possible_comma 25829)) 12364 ((")" 25830)) 12365 ((";" 25831)) 12366 ((inner_statement_list 25833)) 12367 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 25834) ("~" 125)) 12368 ((catch_list 25835)) 12369 ((T_CATCH 25836) (T_FINALLY 25837) (finally_statement 25838)) 12370 (("(" 25842)) 12371 (("{" 25839)) 12372 ((inner_statement_list 25840)) 12373 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 25841) ("~" 125)) 12374 ((T_NAME_FULLY_QUALIFIED 16545) (T_NAME_QUALIFIED 16546) (T_NAME_RELATIVE 16547) (T_STATIC 16548) (T_STRING 16549) (catch_name_list 25843) (class_name 16551) (name 16552)) 12375 ((T_VARIABLE 16553) (optional_variable 25844) ("|" 16555)) 12376 ((")" 25845)) 12377 (("{" 25846)) 12378 ((inner_statement_list 25847)) 12379 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 25848) ("~" 125)) 12380 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25850) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 12381 (("%" 292) (")" 25851) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 12382 ((":" 25852) (switch_case_list 25853) ("{" 25854)) 12383 ((";" 25860) (case_list 25861)) 12384 ((";" 25855) (case_list 25856)) 12385 ((case_list 25858)) 12386 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 25857)) 12387 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 25859)) 12388 ((case_list 25864)) 12389 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 25862)) 12390 ((";" 25863)) 12391 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 25865)) 12392 ((";" 25866)) 12393 (("," 16852) (";" 25869)) 12394 ((";" 25871)) 12395 ((";" 25873)) 12396 (("," 17875) (";" 25875)) 12397 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 25877) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 12398 (("%" 17961) ("*" 17962) ("+" 17963) ("-" 17964) ("." 17965) ("/" 17966) ("<" 17967) (">" 17968) ("?" 17969) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 17970) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 17971) (T_AS 25878) (T_BOOLEAN_AND 17972) (T_BOOLEAN_OR 17973) (T_COALESCE 17974) (T_INSTANCEOF 17975) (T_IS_EQUAL 17976) (T_IS_GREATER_OR_EQUAL 17977) (T_IS_IDENTICAL 17978) (T_IS_NOT_EQUAL 17979) (T_IS_NOT_IDENTICAL 17980) (T_IS_SMALLER_OR_EQUAL 17981) (T_LOGICAL_AND 17982) (T_LOGICAL_OR 17983) (T_LOGICAL_XOR 17984) (T_POW 17985) (T_SL 17986) (T_SPACESHIP 17987) (T_SR 17988) ("^" 17989) ("|" 17990)) 12399 (("\"" 1509) ("$" 19325) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19326) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19327) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19328) ("[" 19329) (ampersand 19330) (array_object_dereferenceable 19331) (callable_expr 19332) (callable_variable 19333) (class_constant 1533) (class_name 19334) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 25879) (fully_dereferenceable 104) (function_call 19336) (name 19337) (simple_variable 19338) (static_member 19339) (variable 19340) (variable_class_name 19341)) 12400 ((")" 25880) (T_DOUBLE_ARROW 25881)) 12401 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 25884) (";" 25781) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 25782) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 25783) (T_DEC 22) (T_DECLARE 25784) (T_DIR 24) (T_DNUMBER 25) (T_DO 25785) (T_DOUBLE_CAST 27) (T_ECHO 25786) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 25787) (T_FOREACH 25788) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 25789) (T_GOTO 25790) (T_IF 43) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 25791) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 25792) (T_START_HEREDOC 68) (T_STATIC 25793) (T_STRING 25794) (T_STRING_CAST 71) (T_SWITCH 25795) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 25796) (T_UNSET 25797) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 25798) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 25799) (alt_if_stmt_without_else 25800) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 25801) (fn 103) (foreach_statement 25890) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 25802) (if_stmt_without_else 25803) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 25886) (static_member 119) (variable 122) (variable_class_name 123) ("{" 25805) ("~" 125)) 12402 (("\"" 1509) ("$" 19356) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19357) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19358) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19359) ("[" 19360) (ampersand 19361) (array_object_dereferenceable 19362) (callable_expr 19363) (callable_variable 19364) (class_constant 1533) (class_name 19365) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 25882) (fully_dereferenceable 104) (function_call 19367) (name 19368) (simple_variable 19369) (static_member 19370) (variable 19371) (variable_class_name 19372)) 12403 ((")" 25883)) 12404 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 25884) (";" 25781) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 25782) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 25783) (T_DEC 22) (T_DECLARE 25784) (T_DIR 24) (T_DNUMBER 25) (T_DO 25785) (T_DOUBLE_CAST 27) (T_ECHO 25786) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 25787) (T_FOREACH 25788) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 25789) (T_GOTO 25790) (T_IF 43) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 25791) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 25792) (T_START_HEREDOC 68) (T_STATIC 25793) (T_STRING 25794) (T_STRING_CAST 71) (T_SWITCH 25795) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 25796) (T_UNSET 25797) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 25798) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 25799) (alt_if_stmt_without_else 25800) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 25801) (fn 103) (foreach_statement 25885) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 25802) (if_stmt_without_else 25803) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 25886) (static_member 119) (variable 122) (variable_class_name 123) ("{" 25805) ("~" 125)) 12405 ((inner_statement_list 25887)) 12406 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19390) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19391) (T_CLASS 19392) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19393) (T_DEC 22) (T_DECLARE 19394) (T_DIR 24) (T_DNUMBER 25) (T_DO 19395) (T_DOUBLE_CAST 27) (T_ECHO 19396) (T_EMPTY 29) (T_ENDFOREACH 25888) (T_ENUM 19398) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19399) (T_FOREACH 19400) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19401) (T_GOTO 19402) (T_HALT_COMPILER 19403) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19405) (T_INTERFACE 19406) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19407) (T_START_HEREDOC 68) (T_STATIC 19408) (T_STRING 19409) (T_STRING_CAST 71) (T_SWITCH 19410) (T_THROW 73) (T_TRAIT 19411) (T_TRAIT_C 75) (T_TRY 19412) (T_UNSET 19413) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19414) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19415) (alt_if_stmt_without_else 19416) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19417) (attributes 19418) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19419) (class_modifier 96) (class_modifiers 19420) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19421) (expr 19422) (fn 103) (fully_dereferenceable 104) #'19423 (function_call 106) (function_declaration_statement 19424) (if_stmt 19425) (if_stmt_without_else 19426) (inline_function 110) (inner_statement 19427) (interface_declaration_statement 19428) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19429) (static_member 119) (trait_declaration_statement 19430) (variable 122) (variable_class_name 123) ("{" 19431) ("~" 125)) 12407 ((";" 25889)) 12408 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 25892) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 12409 ((";" 25893)) 12410 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 25894) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 12411 ((";" 25895)) 12412 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 19558) (fn 2394) (for_exprs 25896) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (non_empty_for_exprs 19560) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 12413 ((")" 25897)) 12414 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 25898) (";" 25781) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 25782) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 25783) (T_DEC 22) (T_DECLARE 25784) (T_DIR 24) (T_DNUMBER 25) (T_DO 25785) (T_DOUBLE_CAST 27) (T_ECHO 25786) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 25787) (T_FOREACH 25788) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 25789) (T_GOTO 25790) (T_IF 43) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 25791) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 25792) (T_START_HEREDOC 68) (T_STATIC 25793) (T_STRING 25794) (T_STRING_CAST 71) (T_SWITCH 25795) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 25796) (T_UNSET 25797) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 25798) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 25799) (alt_if_stmt_without_else 25800) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 25801) (fn 103) (for_statement 25899) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 25802) (if_stmt_without_else 25803) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 25900) (static_member 119) (variable 122) (variable_class_name 123) ("{" 25805) ("~" 125)) 12415 ((inner_statement_list 25901)) 12416 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19568) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19569) (T_CLASS 19570) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19571) (T_DEC 22) (T_DECLARE 19572) (T_DIR 24) (T_DNUMBER 25) (T_DO 19573) (T_DOUBLE_CAST 27) (T_ECHO 19574) (T_EMPTY 29) (T_ENDFOR 25902) (T_ENUM 19576) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19577) (T_FOREACH 19578) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19579) (T_GOTO 19580) (T_HALT_COMPILER 19581) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19583) (T_INTERFACE 19584) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19585) (T_START_HEREDOC 68) (T_STATIC 19586) (T_STRING 19587) (T_STRING_CAST 71) (T_SWITCH 19588) (T_THROW 73) (T_TRAIT 19589) (T_TRAIT_C 75) (T_TRY 19590) (T_UNSET 19591) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19592) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19593) (alt_if_stmt_without_else 19594) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19595) (attributes 19596) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19597) (class_modifier 96) (class_modifiers 19598) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19599) (expr 19600) (fn 103) (fully_dereferenceable 104) #'19601 (function_call 106) (function_declaration_statement 19602) (if_stmt 19603) (if_stmt_without_else 19604) (inline_function 110) (inner_statement 19605) (interface_declaration_statement 19606) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19607) (static_member 119) (trait_declaration_statement 19608) (variable 122) (variable_class_name 123) ("{" 19609) ("~" 125)) 12417 ((";" 25903)) 12418 (("," 19743) (";" 25905)) 12419 ((T_WHILE 25907)) 12420 (("(" 25908)) 12421 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 25909) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 12422 (("%" 292) (")" 25910) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 12423 ((";" 25911)) 12424 ((T_STRING 19916) (const_decl 19917) (const_list 25913)) 12425 ((")" 25914) ("," 19920)) 12426 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 25915) (";" 25781) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 25782) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 25783) (T_DEC 22) (T_DECLARE 25784) (T_DIR 24) (T_DNUMBER 25) (T_DO 25785) (T_DOUBLE_CAST 27) (T_ECHO 25786) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 25787) (T_FOREACH 25788) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 25789) (T_GOTO 25790) (T_IF 43) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 25791) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 25792) (T_START_HEREDOC 68) (T_STATIC 25793) (T_STRING 25794) (T_STRING_CAST 71) (T_SWITCH 25795) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 25796) (T_UNSET 25797) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 25798) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 25799) (alt_if_stmt_without_else 25800) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (declare_statement 25916) (dereferenceable_scalar 100) (expr 25801) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 25802) (if_stmt_without_else 25803) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 25917) (static_member 119) (variable 122) (variable_class_name 123) ("{" 25805) ("~" 125)) 12427 ((inner_statement_list 25918)) 12428 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19926) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19927) (T_CLASS 19928) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19929) (T_DEC 22) (T_DECLARE 19930) (T_DIR 24) (T_DNUMBER 25) (T_DO 19931) (T_DOUBLE_CAST 27) (T_ECHO 19932) (T_EMPTY 29) (T_ENDDECLARE 25919) (T_ENUM 19934) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19935) (T_FOREACH 19936) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19937) (T_GOTO 19938) (T_HALT_COMPILER 19939) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19941) (T_INTERFACE 19942) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19943) (T_START_HEREDOC 68) (T_STATIC 19944) (T_STRING 19945) (T_STRING_CAST 71) (T_SWITCH 19946) (T_THROW 73) (T_TRAIT 19947) (T_TRAIT_C 75) (T_TRY 19948) (T_UNSET 19949) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19950) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19951) (alt_if_stmt_without_else 19952) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19953) (attributes 19954) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19955) (class_modifier 96) (class_modifiers 19956) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19957) (expr 19958) (fn 103) (fully_dereferenceable 104) #'19959 (function_call 106) (function_declaration_statement 19960) (if_stmt 19961) (if_stmt_without_else 19962) (inline_function 110) (inner_statement 19963) (interface_declaration_statement 19964) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19965) (static_member 119) (trait_declaration_statement 19966) (variable 122) (variable_class_name 123) ("{" 19967) ("~" 125)) 12429 ((";" 25920)) 12430 ((";" 25922)) 12431 ((";" 25924)) 12432 ((T_READONLY 16265) (T_STRING 16266) (backup_doc_comment 139) (function_name 25927)) 12433 ((backup_doc_comment 25928)) 12434 (("(" 25929)) 12435 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 25930)) 12436 ((")" 25931)) 12437 ((":" 161) (return_type 25932)) 12438 ((backup_fn_flags 25933)) 12439 (("{" 25934)) 12440 ((inner_statement_list 25935)) 12441 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 25936) ("~" 125)) 12442 ((backup_fn_flags 25937)) 12443 ((backup_doc_comment 25939)) 12444 (("(" 25940)) 12445 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 25941)) 12446 ((")" 25942)) 12447 ((":" 2241) (return_type 25943)) 12448 ((T_DOUBLE_ARROW 25944)) 12449 ((backup_fn_flags 25945)) 12450 ((backup_lex_pos 25946)) 12451 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26009) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12452 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 27008) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12453 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 27006) (encaps_var 5299)) 12454 (("$" 25949) (T_VARIABLE 25996) (simple_variable 27002) ("{" 27003)) 12455 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 27000) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 12456 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26999) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12457 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26998) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12458 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26997) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12459 (("(" 26994)) 12460 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26993) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12461 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26992) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12462 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26991) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12463 (("\"" 1509) ("$" 26252) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 26253) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 26254) ("[" 1529) (array_object_dereferenceable 26255) (callable_expr 26256) (callable_variable 26257) (class_constant 1533) (class_name 26258) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 26259) (name 26260) (simple_variable 26261) (static_member 26262) (variable 26990) (variable_class_name 26264)) 12464 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26989) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12465 (("(" 26986)) 12466 (("(" 26983)) 12467 (("(" 26979) (exit_expr 26980)) 12468 (("\"" 1509) ("$" 26252) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 26253) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 26254) ("[" 1529) (array_object_dereferenceable 26255) (callable_expr 26256) (callable_variable 26257) (class_constant 1533) (class_name 26258) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 26259) (name 26260) (simple_variable 26261) (static_member 26262) (variable 26978) (variable_class_name 26264)) 12469 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26977) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12470 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26976) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12471 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26975) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12472 (("(" 26971)) 12473 (("(" 26966)) 12474 (("(" 26960)) 12475 (("$" 26252) ("(" 26912) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 26913) (T_NAME_QUALIFIED 26914) (T_NAME_RELATIVE 26915) (T_READONLY 2936) (T_STATIC 26916) (T_STRING 26917) (T_VARIABLE 26254) (anonymous_class 26918) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 26919) (attribute 2943) (attributes 26920) (class_modifier 2945) (class_name 26921) (class_name_reference 26922) (name 26923) (new_variable 26924) (simple_variable 26925)) 12476 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26911) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12477 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26910) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12478 (("(" 26213) (argument_list 26909)) 12479 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26908) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12480 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26907) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12481 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 26902) (T_END_HEREDOC 26903) (T_VARIABLE 2900) (encaps_list 26904) (encaps_var 2902)) 12482 ((T_FN 35) (T_FUNCTION 127) (fn 26010) #'26011 (inline_function 26901)) 12483 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26900) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12484 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26899) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12485 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26898) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12486 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26427) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12487 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26364) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12488 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 26360) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 12489 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 26358) (encaps_list 2805) (encaps_var 2806)) 12490 ((T_NULLSAFE_OBJECT_OPERATOR 26341) (T_OBJECT_OPERATOR 26342) ("[" 26343) ("{" 26344)) 12491 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 26338) (attribute 2728) (fn 26010) #'26011 (inline_function 26339)) 12492 (("(" 26213) (argument_list 26337)) 12493 ((T_PAAMAYIM_NEKUDOTAYIM 26329)) 12494 (("%" 26025) ("*" 26026) ("+" 26027) ("-" 26028) ("." 26029) ("/" 26030) ("<" 26031) (">" 26032) ("?" 26033) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 26034) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 26035) (T_BOOLEAN_AND 26036) (T_BOOLEAN_OR 26037) (T_COALESCE 26038) (T_INSTANCEOF 26039) (T_IS_EQUAL 26040) (T_IS_GREATER_OR_EQUAL 26041) (T_IS_IDENTICAL 26042) (T_IS_NOT_EQUAL 26043) (T_IS_NOT_IDENTICAL 26044) (T_IS_SMALLER_OR_EQUAL 26045) (T_LOGICAL_AND 26046) (T_LOGICAL_OR 26047) (T_LOGICAL_XOR 26048) (T_POW 26049) (T_SL 26050) (T_SPACESHIP 26051) (T_SR 26052) ("^" 26053) (backup_fn_flags 26328) ("|" 26054)) 12495 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 26317)) 12496 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 26305)) 12497 (("(" 26213) (argument_list 26304)) 12498 (("=" 26221) (T_AND_EQUAL 26222) (T_COALESCE_EQUAL 26223) (T_CONCAT_EQUAL 26224) (T_DEC 26225) (T_DIV_EQUAL 26226) (T_INC 26227) (T_MINUS_EQUAL 26228) (T_MOD_EQUAL 26229) (T_MUL_EQUAL 26230) (T_OR_EQUAL 26231) (T_PLUS_EQUAL 26232) (T_POW_EQUAL 26233) (T_SL_EQUAL 26234) (T_SR_EQUAL 26235) (T_XOR_EQUAL 26236)) 12499 ((T_PAAMAYIM_NEKUDOTAYIM 26126)) 12500 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26024) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12501 (("%" 26025) ("*" 26026) ("+" 26027) ("-" 26028) ("." 26029) ("/" 26030) ("<" 26031) (">" 26032) ("?" 26033) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 26034) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 26035) (T_BOOLEAN_AND 26036) (T_BOOLEAN_OR 26037) (T_COALESCE 26038) (T_INSTANCEOF 26039) (T_IS_EQUAL 26040) (T_IS_GREATER_OR_EQUAL 26041) (T_IS_IDENTICAL 26042) (T_IS_NOT_EQUAL 26043) (T_IS_NOT_IDENTICAL 26044) (T_IS_SMALLER_OR_EQUAL 26045) (T_LOGICAL_AND 26046) (T_LOGICAL_OR 26047) (T_LOGICAL_XOR 26048) (T_POW 26049) (T_SL 26050) (T_SPACESHIP 26051) (T_SR 26052) ("^" 26053) ("|" 26054)) 12502 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26125) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12503 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26124) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12504 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26123) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12505 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26122) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12506 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26121) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12507 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26120) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12508 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26119) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12509 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26118) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12510 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 26113) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 26114) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 12511 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26112) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12512 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26111) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12513 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26110) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12514 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26109) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12515 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26108) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12516 (("$" 26070) ("(" 26071) (T_NAME_FULLY_QUALIFIED 26072) (T_NAME_QUALIFIED 26073) (T_NAME_RELATIVE 26074) (T_STATIC 26075) (T_STRING 26076) (T_VARIABLE 26077) (class_name 26078) (class_name_reference 26079) (name 26080) (new_variable 26081) (simple_variable 26082)) 12517 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26069) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12518 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26068) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12519 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26067) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12520 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26066) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12521 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26065) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12522 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26064) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12523 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26063) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12524 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26062) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12525 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26061) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12526 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26060) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12527 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26059) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12528 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26058) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12529 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26057) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12530 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26056) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12531 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26055) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12532 (("$" 26070) (T_VARIABLE 26077) (simple_variable 26104) ("{" 26105)) 12533 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 26102) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 12534 ((T_PAAMAYIM_NEKUDOTAYIM 26100)) 12535 ((T_NULLSAFE_OBJECT_OPERATOR 26083) (T_OBJECT_OPERATOR 26084) (T_PAAMAYIM_NEKUDOTAYIM 26085) ("[" 26086) ("{" 26087)) 12536 (("$" 26070) (T_STRING 26093) (T_VARIABLE 26077) (property_name 26099) (simple_variable 26095) ("{" 26096)) 12537 (("$" 26070) (T_STRING 26093) (T_VARIABLE 26077) (property_name 26094) (simple_variable 26095) ("{" 26096)) 12538 (("$" 26070) (T_VARIABLE 26077) (simple_variable 26092)) 12539 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 26090) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 12540 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 26088) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12541 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 26089)) 12542 (("]" 26091)) 12543 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 26097) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12544 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 26098)) 12545 (("$" 26070) (T_VARIABLE 26077) (simple_variable 26101)) 12546 (("%" 292) (")" 26103) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 12547 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 26106) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12548 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 26107)) 12549 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26117) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12550 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 26115) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 12551 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26116) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12552 (("$" 25949) (T_ABSTRACT 26127) (T_ARRAY 26128) (T_AS 26129) (T_BREAK 26130) (T_CALLABLE 26131) (T_CASE 26132) (T_CATCH 26133) (T_CLASS 26134) (T_CLASS_C 26135) (T_CLONE 26136) (T_CONST 26137) (T_CONTINUE 26138) (T_DECLARE 26139) (T_DEFAULT 26140) (T_DIR 26141) (T_DO 26142) (T_ECHO 26143) (T_ELSE 26144) (T_ELSEIF 26145) (T_EMPTY 26146) (T_ENDDECLARE 26147) (T_ENDFOR 26148) (T_ENDFOREACH 26149) (T_ENDIF 26150) (T_ENDSWITCH 26151) (T_ENDWHILE 26152) (T_ENUM 26153) (T_EVAL 26154) (T_EXIT 26155) (T_EXTENDS 26156) (T_FILE 26157) (T_FINAL 26158) (T_FINALLY 26159) (T_FN 26160) (T_FOR 26161) (T_FOREACH 26162) (T_FUNCTION 26163) (T_FUNC_C 26164) (T_GLOBAL 26165) (T_GOTO 26166) (T_IF 26167) (T_IMPLEMENTS 26168) (T_INCLUDE 26169) (T_INCLUDE_ONCE 26170) (T_INSTANCEOF 26171) (T_INSTEADOF 26172) (T_INTERFACE 26173) (T_ISSET 26174) (T_LINE 26175) (T_LIST 26176) (T_LOGICAL_AND 26177) (T_LOGICAL_OR 26178) (T_LOGICAL_XOR 26179) (T_MATCH 26180) (T_METHOD_C 26181) (T_NAMESPACE 26182) (T_NEW 26183) (T_NS_C 26184) (T_PRINT 26185) (T_PRIVATE 26186) (T_PROTECTED 26187) (T_PUBLIC 26188) (T_READONLY 26189) (T_REQUIRE 26190) (T_REQUIRE_ONCE 26191) (T_RETURN 26192) (T_STATIC 26193) (T_STRING 26194) (T_SWITCH 26195) (T_THROW 26196) (T_TRAIT 26197) (T_TRAIT_C 26198) (T_TRY 26199) (T_UNSET 26200) (T_USE 26201) (T_VAR 26202) (T_VARIABLE 25996) (T_WHILE 26203) (T_YIELD 26204) (identifier 26205) (member_name 26206) (reserved_non_modifiers 26207) (semi_reserved 26208) (simple_variable 26209) ("{" 26210)) 12553 (("(" 26213) (argument_list 26214)) 12554 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 26211) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12555 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 26212)) 12556 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 26215) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 26216) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 26217) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 12557 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 26220) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 12558 (("," 1469) (possible_comma 26218)) 12559 ((")" 26219)) 12560 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (ampersand 26250) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26251) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12561 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26249) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12562 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26248) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12563 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26247) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12564 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26246) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12565 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26245) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12566 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26244) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12567 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26243) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12568 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26242) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12569 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26241) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12570 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26240) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12571 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26239) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12572 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26238) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12573 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26237) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12574 (("\"" 1509) ("$" 26252) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 26253) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 26254) ("[" 1529) (array_object_dereferenceable 26255) (callable_expr 26256) (callable_variable 26257) (class_constant 1533) (class_name 26258) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 26259) (name 26260) (simple_variable 26261) (static_member 26262) (variable 26263) (variable_class_name 26264)) 12575 (("$" 26252) (T_VARIABLE 26254) (simple_variable 26300) ("{" 26301)) 12576 (("(" 26268) (argument_list 26299)) 12577 ((T_NULLSAFE_OBJECT_OPERATOR 26282) (T_OBJECT_OPERATOR 26283) ("[" 26284) ("{" 26285)) 12578 (("(" 26268) (argument_list 26281)) 12579 ((T_PAAMAYIM_NEKUDOTAYIM 26277)) 12580 (("(" 26268) (argument_list 26276)) 12581 ((T_PAAMAYIM_NEKUDOTAYIM 26265)) 12582 (("$" 26252) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 26254) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 26266) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 26267) ("{" 1627)) 12583 (("(" 26268) (argument_list 26269)) 12584 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 26270) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 26271) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 26272) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 12585 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 26275) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 12586 (("," 1469) (possible_comma 26273)) 12587 ((")" 26274)) 12588 (("$" 26252) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 26254) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 26278) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 26279) ("{" 1643)) 12589 (("(" 26268) (argument_list 26280)) 12590 (("$" 26252) (T_STRING 26290) (T_VARIABLE 26254) (property_name 26297) (simple_variable 26292) ("{" 26293)) 12591 (("$" 26252) (T_STRING 26290) (T_VARIABLE 26254) (property_name 26291) (simple_variable 26292) ("{" 26293)) 12592 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 26288) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 12593 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 26286) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12594 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 26287)) 12595 (("]" 26289)) 12596 (("(" 26268) (argument_list 26296)) 12597 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 26294) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12598 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 26295)) 12599 (("(" 26268) (argument_list 26298)) 12600 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 26302) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12601 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 26303)) 12602 ((backup_doc_comment 26306)) 12603 (("(" 26307)) 12604 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 26308)) 12605 ((")" 26309)) 12606 ((T_USE 159) (lexical_vars 26310)) 12607 ((":" 161) (return_type 26311)) 12608 ((backup_fn_flags 26312)) 12609 (("{" 26313)) 12610 ((inner_statement_list 26314)) 12611 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 26315) ("~" 125)) 12612 ((backup_fn_flags 26316)) 12613 ((backup_doc_comment 26318)) 12614 (("(" 26319)) 12615 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 26320)) 12616 ((")" 26321)) 12617 ((":" 2241) (return_type 26322)) 12618 ((T_DOUBLE_ARROW 26323)) 12619 ((backup_fn_flags 26324)) 12620 ((backup_lex_pos 26325)) 12621 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26326) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12622 (("%" 26025) ("*" 26026) ("+" 26027) ("-" 26028) ("." 26029) ("/" 26030) ("<" 26031) (">" 26032) ("?" 26033) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 26034) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 26035) (T_BOOLEAN_AND 26036) (T_BOOLEAN_OR 26037) (T_COALESCE 26038) (T_INSTANCEOF 26039) (T_IS_EQUAL 26040) (T_IS_GREATER_OR_EQUAL 26041) (T_IS_IDENTICAL 26042) (T_IS_NOT_EQUAL 26043) (T_IS_NOT_IDENTICAL 26044) (T_IS_SMALLER_OR_EQUAL 26045) (T_LOGICAL_AND 26046) (T_LOGICAL_OR 26047) (T_LOGICAL_XOR 26048) (T_POW 26049) (T_SL 26050) (T_SPACESHIP 26051) (T_SR 26052) ("^" 26053) (backup_fn_flags 26327) ("|" 26054)) 12623 (("$" 25949) (T_ABSTRACT 26127) (T_ARRAY 26128) (T_AS 26129) (T_BREAK 26130) (T_CALLABLE 26131) (T_CASE 26132) (T_CATCH 26133) (T_CLASS 26134) (T_CLASS_C 26135) (T_CLONE 26136) (T_CONST 26137) (T_CONTINUE 26138) (T_DECLARE 26139) (T_DEFAULT 26140) (T_DIR 26141) (T_DO 26142) (T_ECHO 26143) (T_ELSE 26144) (T_ELSEIF 26145) (T_EMPTY 26146) (T_ENDDECLARE 26147) (T_ENDFOR 26148) (T_ENDFOREACH 26149) (T_ENDIF 26150) (T_ENDSWITCH 26151) (T_ENDWHILE 26152) (T_ENUM 26153) (T_EVAL 26154) (T_EXIT 26155) (T_EXTENDS 26156) (T_FILE 26157) (T_FINAL 26158) (T_FINALLY 26159) (T_FN 26160) (T_FOR 26161) (T_FOREACH 26162) (T_FUNCTION 26163) (T_FUNC_C 26164) (T_GLOBAL 26165) (T_GOTO 26166) (T_IF 26167) (T_IMPLEMENTS 26168) (T_INCLUDE 26169) (T_INCLUDE_ONCE 26170) (T_INSTANCEOF 26171) (T_INSTEADOF 26172) (T_INTERFACE 26173) (T_ISSET 26174) (T_LINE 26175) (T_LIST 26176) (T_LOGICAL_AND 26177) (T_LOGICAL_OR 26178) (T_LOGICAL_XOR 26179) (T_MATCH 26180) (T_METHOD_C 26181) (T_NAMESPACE 26182) (T_NEW 26183) (T_NS_C 26184) (T_PRINT 26185) (T_PRIVATE 26186) (T_PROTECTED 26187) (T_PUBLIC 26188) (T_READONLY 26189) (T_REQUIRE 26190) (T_REQUIRE_ONCE 26191) (T_RETURN 26192) (T_STATIC 26193) (T_STRING 26194) (T_SWITCH 26195) (T_THROW 26196) (T_TRAIT 26197) (T_TRAIT_C 26198) (T_TRY 26199) (T_UNSET 26200) (T_USE 26201) (T_VAR 26202) (T_VARIABLE 25996) (T_WHILE 26203) (T_YIELD 26204) (identifier 26330) (member_name 26331) (reserved_non_modifiers 26207) (semi_reserved 26208) (simple_variable 26332) ("{" 26333)) 12624 (("(" 26213) (argument_list 26336)) 12625 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 26334) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12626 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 26335)) 12627 ((T_FN 35) (T_FUNCTION 127) (fn 26010) #'26011 (inline_function 26340)) 12628 (("$" 25949) (T_STRING 26349) (T_VARIABLE 25996) (property_name 26356) (simple_variable 26351) ("{" 26352)) 12629 (("$" 25949) (T_STRING 26349) (T_VARIABLE 25996) (property_name 26350) (simple_variable 26351) ("{" 26352)) 12630 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 26347) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 12631 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 26345) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12632 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 26346)) 12633 (("]" 26348)) 12634 (("(" 26213) (argument_list 26355)) 12635 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 26353) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12636 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 26354)) 12637 (("(" 26213) (argument_list 26357)) 12638 (("`" 26359)) 12639 (("]" 26361)) 12640 (("=" 26362)) 12641 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26363) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12642 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26897) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12643 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 26895) (encaps_var 5299)) 12644 (("$" 26367) (T_VARIABLE 26414) (simple_variable 26891) ("{" 26892)) 12645 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 26889) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 12646 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26888) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12647 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26887) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12648 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26886) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12649 (("(" 26883)) 12650 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26882) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12651 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26881) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12652 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26880) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12653 (("\"" 1509) ("$" 26670) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 26671) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 26672) ("[" 1529) (array_object_dereferenceable 26673) (callable_expr 26674) (callable_variable 26675) (class_constant 1533) (class_name 26676) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 26677) (name 26678) (simple_variable 26679) (static_member 26680) (variable 26879) (variable_class_name 26682)) 12654 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26878) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12655 (("(" 26875)) 12656 (("(" 26872)) 12657 (("(" 26868) (exit_expr 26869)) 12658 (("\"" 1509) ("$" 26670) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 26671) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 26672) ("[" 1529) (array_object_dereferenceable 26673) (callable_expr 26674) (callable_variable 26675) (class_constant 1533) (class_name 26676) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 26677) (name 26678) (simple_variable 26679) (static_member 26680) (variable 26867) (variable_class_name 26682)) 12659 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26866) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12660 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26865) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12661 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26864) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12662 (("(" 26860)) 12663 (("(" 26855)) 12664 (("(" 26849)) 12665 (("$" 26670) ("(" 26801) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 26802) (T_NAME_QUALIFIED 26803) (T_NAME_RELATIVE 26804) (T_READONLY 2936) (T_STATIC 26805) (T_STRING 26806) (T_VARIABLE 26672) (anonymous_class 26807) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 26808) (attribute 2943) (attributes 26809) (class_modifier 2945) (class_name 26810) (class_name_reference 26811) (name 26812) (new_variable 26813) (simple_variable 26814)) 12666 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26800) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12667 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26799) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12668 (("(" 26631) (argument_list 26798)) 12669 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26797) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12670 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26796) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12671 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 26791) (T_END_HEREDOC 26792) (T_VARIABLE 2900) (encaps_list 26793) (encaps_var 2902)) 12672 ((T_FN 35) (T_FUNCTION 127) (fn 26428) #'26429 (inline_function 26790)) 12673 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26789) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12674 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26788) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12675 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26787) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12676 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26784) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12677 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26783) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12678 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 26779) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 12679 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 26777) (encaps_list 2805) (encaps_var 2806)) 12680 ((T_NULLSAFE_OBJECT_OPERATOR 26760) (T_OBJECT_OPERATOR 26761) ("[" 26762) ("{" 26763)) 12681 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 26757) (attribute 2728) (fn 26428) #'26429 (inline_function 26758)) 12682 (("(" 26631) (argument_list 26756)) 12683 ((T_PAAMAYIM_NEKUDOTAYIM 26748)) 12684 (("%" 26443) ("*" 26444) ("+" 26445) ("-" 26446) ("." 26447) ("/" 26448) ("<" 26449) (">" 26450) ("?" 26451) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 26452) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 26453) (T_BOOLEAN_AND 26454) (T_BOOLEAN_OR 26455) (T_COALESCE 26456) (T_DOUBLE_ARROW 26746) (T_INSTANCEOF 26457) (T_IS_EQUAL 26458) (T_IS_GREATER_OR_EQUAL 26459) (T_IS_IDENTICAL 26460) (T_IS_NOT_EQUAL 26461) (T_IS_NOT_IDENTICAL 26462) (T_IS_SMALLER_OR_EQUAL 26463) (T_LOGICAL_AND 26464) (T_LOGICAL_OR 26465) (T_LOGICAL_XOR 26466) (T_POW 26467) (T_SL 26468) (T_SPACESHIP 26469) (T_SR 26470) ("^" 26471) ("|" 26472)) 12685 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 26735)) 12686 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 26723)) 12687 (("(" 26631) (argument_list 26722)) 12688 (("=" 26639) (T_AND_EQUAL 26640) (T_COALESCE_EQUAL 26641) (T_CONCAT_EQUAL 26642) (T_DEC 26643) (T_DIV_EQUAL 26644) (T_INC 26645) (T_MINUS_EQUAL 26646) (T_MOD_EQUAL 26647) (T_MUL_EQUAL 26648) (T_OR_EQUAL 26649) (T_PLUS_EQUAL 26650) (T_POW_EQUAL 26651) (T_SL_EQUAL 26652) (T_SR_EQUAL 26653) (T_XOR_EQUAL 26654)) 12689 ((T_PAAMAYIM_NEKUDOTAYIM 26544)) 12690 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26442) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12691 (("%" 26443) ("*" 26444) ("+" 26445) ("-" 26446) ("." 26447) ("/" 26448) ("<" 26449) (">" 26450) ("?" 26451) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 26452) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 26453) (T_BOOLEAN_AND 26454) (T_BOOLEAN_OR 26455) (T_COALESCE 26456) (T_INSTANCEOF 26457) (T_IS_EQUAL 26458) (T_IS_GREATER_OR_EQUAL 26459) (T_IS_IDENTICAL 26460) (T_IS_NOT_EQUAL 26461) (T_IS_NOT_IDENTICAL 26462) (T_IS_SMALLER_OR_EQUAL 26463) (T_LOGICAL_AND 26464) (T_LOGICAL_OR 26465) (T_LOGICAL_XOR 26466) (T_POW 26467) (T_SL 26468) (T_SPACESHIP 26469) (T_SR 26470) ("^" 26471) ("|" 26472)) 12692 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26543) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12693 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26542) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12694 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26541) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12695 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26540) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12696 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26539) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12697 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26538) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12698 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26537) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12699 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26536) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12700 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 26531) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 26532) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 12701 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26530) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12702 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26529) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12703 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26528) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12704 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26527) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12705 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26526) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12706 (("$" 26488) ("(" 26489) (T_NAME_FULLY_QUALIFIED 26490) (T_NAME_QUALIFIED 26491) (T_NAME_RELATIVE 26492) (T_STATIC 26493) (T_STRING 26494) (T_VARIABLE 26495) (class_name 26496) (class_name_reference 26497) (name 26498) (new_variable 26499) (simple_variable 26500)) 12707 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26487) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12708 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26486) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12709 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26485) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12710 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26484) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12711 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26483) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12712 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26482) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12713 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26481) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12714 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26480) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12715 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26479) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12716 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26478) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12717 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26477) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12718 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26476) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12719 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26475) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12720 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26474) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12721 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26473) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12722 (("$" 26488) (T_VARIABLE 26495) (simple_variable 26522) ("{" 26523)) 12723 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 26520) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 12724 ((T_PAAMAYIM_NEKUDOTAYIM 26518)) 12725 ((T_NULLSAFE_OBJECT_OPERATOR 26501) (T_OBJECT_OPERATOR 26502) (T_PAAMAYIM_NEKUDOTAYIM 26503) ("[" 26504) ("{" 26505)) 12726 (("$" 26488) (T_STRING 26511) (T_VARIABLE 26495) (property_name 26517) (simple_variable 26513) ("{" 26514)) 12727 (("$" 26488) (T_STRING 26511) (T_VARIABLE 26495) (property_name 26512) (simple_variable 26513) ("{" 26514)) 12728 (("$" 26488) (T_VARIABLE 26495) (simple_variable 26510)) 12729 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 26508) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 12730 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 26506) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12731 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 26507)) 12732 (("]" 26509)) 12733 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 26515) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12734 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 26516)) 12735 (("$" 26488) (T_VARIABLE 26495) (simple_variable 26519)) 12736 (("%" 292) (")" 26521) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 12737 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 26524) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12738 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 26525)) 12739 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26535) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12740 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 26533) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 12741 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26534) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12742 (("$" 26367) (T_ABSTRACT 26545) (T_ARRAY 26546) (T_AS 26547) (T_BREAK 26548) (T_CALLABLE 26549) (T_CASE 26550) (T_CATCH 26551) (T_CLASS 26552) (T_CLASS_C 26553) (T_CLONE 26554) (T_CONST 26555) (T_CONTINUE 26556) (T_DECLARE 26557) (T_DEFAULT 26558) (T_DIR 26559) (T_DO 26560) (T_ECHO 26561) (T_ELSE 26562) (T_ELSEIF 26563) (T_EMPTY 26564) (T_ENDDECLARE 26565) (T_ENDFOR 26566) (T_ENDFOREACH 26567) (T_ENDIF 26568) (T_ENDSWITCH 26569) (T_ENDWHILE 26570) (T_ENUM 26571) (T_EVAL 26572) (T_EXIT 26573) (T_EXTENDS 26574) (T_FILE 26575) (T_FINAL 26576) (T_FINALLY 26577) (T_FN 26578) (T_FOR 26579) (T_FOREACH 26580) (T_FUNCTION 26581) (T_FUNC_C 26582) (T_GLOBAL 26583) (T_GOTO 26584) (T_IF 26585) (T_IMPLEMENTS 26586) (T_INCLUDE 26587) (T_INCLUDE_ONCE 26588) (T_INSTANCEOF 26589) (T_INSTEADOF 26590) (T_INTERFACE 26591) (T_ISSET 26592) (T_LINE 26593) (T_LIST 26594) (T_LOGICAL_AND 26595) (T_LOGICAL_OR 26596) (T_LOGICAL_XOR 26597) (T_MATCH 26598) (T_METHOD_C 26599) (T_NAMESPACE 26600) (T_NEW 26601) (T_NS_C 26602) (T_PRINT 26603) (T_PRIVATE 26604) (T_PROTECTED 26605) (T_PUBLIC 26606) (T_READONLY 26607) (T_REQUIRE 26608) (T_REQUIRE_ONCE 26609) (T_RETURN 26610) (T_STATIC 26611) (T_STRING 26612) (T_SWITCH 26613) (T_THROW 26614) (T_TRAIT 26615) (T_TRAIT_C 26616) (T_TRY 26617) (T_UNSET 26618) (T_USE 26619) (T_VAR 26620) (T_VARIABLE 26414) (T_WHILE 26621) (T_YIELD 26622) (identifier 26623) (member_name 26624) (reserved_non_modifiers 26625) (semi_reserved 26626) (simple_variable 26627) ("{" 26628)) 12743 (("(" 26631) (argument_list 26632)) 12744 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 26629) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12745 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 26630)) 12746 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 26633) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 26634) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 26635) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 12747 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 26638) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 12748 (("," 1469) (possible_comma 26636)) 12749 ((")" 26637)) 12750 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (ampersand 26668) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26669) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12751 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26667) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12752 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26666) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12753 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26665) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12754 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26664) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12755 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26663) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12756 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26662) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12757 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26661) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12758 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26660) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12759 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26659) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12760 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26658) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12761 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26657) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12762 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26656) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12763 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26655) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12764 (("\"" 1509) ("$" 26670) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 26671) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 26672) ("[" 1529) (array_object_dereferenceable 26673) (callable_expr 26674) (callable_variable 26675) (class_constant 1533) (class_name 26676) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 26677) (name 26678) (simple_variable 26679) (static_member 26680) (variable 26681) (variable_class_name 26682)) 12765 (("$" 26670) (T_VARIABLE 26672) (simple_variable 26718) ("{" 26719)) 12766 (("(" 26686) (argument_list 26717)) 12767 ((T_NULLSAFE_OBJECT_OPERATOR 26700) (T_OBJECT_OPERATOR 26701) ("[" 26702) ("{" 26703)) 12768 (("(" 26686) (argument_list 26699)) 12769 ((T_PAAMAYIM_NEKUDOTAYIM 26695)) 12770 (("(" 26686) (argument_list 26694)) 12771 ((T_PAAMAYIM_NEKUDOTAYIM 26683)) 12772 (("$" 26670) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 26672) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 26684) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 26685) ("{" 1627)) 12773 (("(" 26686) (argument_list 26687)) 12774 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 26688) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 26689) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 26690) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 12775 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 26693) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 12776 (("," 1469) (possible_comma 26691)) 12777 ((")" 26692)) 12778 (("$" 26670) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 26672) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 26696) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 26697) ("{" 1643)) 12779 (("(" 26686) (argument_list 26698)) 12780 (("$" 26670) (T_STRING 26708) (T_VARIABLE 26672) (property_name 26715) (simple_variable 26710) ("{" 26711)) 12781 (("$" 26670) (T_STRING 26708) (T_VARIABLE 26672) (property_name 26709) (simple_variable 26710) ("{" 26711)) 12782 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 26706) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 12783 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 26704) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12784 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 26705)) 12785 (("]" 26707)) 12786 (("(" 26686) (argument_list 26714)) 12787 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 26712) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12788 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 26713)) 12789 (("(" 26686) (argument_list 26716)) 12790 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 26720) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12791 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 26721)) 12792 ((backup_doc_comment 26724)) 12793 (("(" 26725)) 12794 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 26726)) 12795 ((")" 26727)) 12796 ((T_USE 159) (lexical_vars 26728)) 12797 ((":" 161) (return_type 26729)) 12798 ((backup_fn_flags 26730)) 12799 (("{" 26731)) 12800 ((inner_statement_list 26732)) 12801 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 26733) ("~" 125)) 12802 ((backup_fn_flags 26734)) 12803 ((backup_doc_comment 26736)) 12804 (("(" 26737)) 12805 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 26738)) 12806 ((")" 26739)) 12807 ((":" 2241) (return_type 26740)) 12808 ((T_DOUBLE_ARROW 26741)) 12809 ((backup_fn_flags 26742)) 12810 ((backup_lex_pos 26743)) 12811 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26744) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12812 (("%" 26443) ("*" 26444) ("+" 26445) ("-" 26446) ("." 26447) ("/" 26448) ("<" 26449) (">" 26450) ("?" 26451) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 26452) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 26453) (T_BOOLEAN_AND 26454) (T_BOOLEAN_OR 26455) (T_COALESCE 26456) (T_INSTANCEOF 26457) (T_IS_EQUAL 26458) (T_IS_GREATER_OR_EQUAL 26459) (T_IS_IDENTICAL 26460) (T_IS_NOT_EQUAL 26461) (T_IS_NOT_IDENTICAL 26462) (T_IS_SMALLER_OR_EQUAL 26463) (T_LOGICAL_AND 26464) (T_LOGICAL_OR 26465) (T_LOGICAL_XOR 26466) (T_POW 26467) (T_SL 26468) (T_SPACESHIP 26469) (T_SR 26470) ("^" 26471) (backup_fn_flags 26745) ("|" 26472)) 12813 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26747) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12814 (("$" 26367) (T_ABSTRACT 26545) (T_ARRAY 26546) (T_AS 26547) (T_BREAK 26548) (T_CALLABLE 26549) (T_CASE 26550) (T_CATCH 26551) (T_CLASS 26552) (T_CLASS_C 26553) (T_CLONE 26554) (T_CONST 26555) (T_CONTINUE 26556) (T_DECLARE 26557) (T_DEFAULT 26558) (T_DIR 26559) (T_DO 26560) (T_ECHO 26561) (T_ELSE 26562) (T_ELSEIF 26563) (T_EMPTY 26564) (T_ENDDECLARE 26565) (T_ENDFOR 26566) (T_ENDFOREACH 26567) (T_ENDIF 26568) (T_ENDSWITCH 26569) (T_ENDWHILE 26570) (T_ENUM 26571) (T_EVAL 26572) (T_EXIT 26573) (T_EXTENDS 26574) (T_FILE 26575) (T_FINAL 26576) (T_FINALLY 26577) (T_FN 26578) (T_FOR 26579) (T_FOREACH 26580) (T_FUNCTION 26581) (T_FUNC_C 26582) (T_GLOBAL 26583) (T_GOTO 26584) (T_IF 26585) (T_IMPLEMENTS 26586) (T_INCLUDE 26587) (T_INCLUDE_ONCE 26588) (T_INSTANCEOF 26589) (T_INSTEADOF 26590) (T_INTERFACE 26591) (T_ISSET 26592) (T_LINE 26593) (T_LIST 26594) (T_LOGICAL_AND 26595) (T_LOGICAL_OR 26596) (T_LOGICAL_XOR 26597) (T_MATCH 26598) (T_METHOD_C 26599) (T_NAMESPACE 26600) (T_NEW 26601) (T_NS_C 26602) (T_PRINT 26603) (T_PRIVATE 26604) (T_PROTECTED 26605) (T_PUBLIC 26606) (T_READONLY 26607) (T_REQUIRE 26608) (T_REQUIRE_ONCE 26609) (T_RETURN 26610) (T_STATIC 26611) (T_STRING 26612) (T_SWITCH 26613) (T_THROW 26614) (T_TRAIT 26615) (T_TRAIT_C 26616) (T_TRY 26617) (T_UNSET 26618) (T_USE 26619) (T_VAR 26620) (T_VARIABLE 26414) (T_WHILE 26621) (T_YIELD 26622) (identifier 26749) (member_name 26750) (reserved_non_modifiers 26625) (semi_reserved 26626) (simple_variable 26751) ("{" 26752)) 12815 (("(" 26631) (argument_list 26755)) 12816 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 26753) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12817 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 26754)) 12818 ((T_FN 35) (T_FUNCTION 127) (fn 26428) #'26429 (inline_function 26759)) 12819 (("$" 26367) (T_STRING 26768) (T_VARIABLE 26414) (property_name 26775) (simple_variable 26770) ("{" 26771)) 12820 (("$" 26367) (T_STRING 26768) (T_VARIABLE 26414) (property_name 26769) (simple_variable 26770) ("{" 26771)) 12821 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 26766) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 12822 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 26764) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12823 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 26765)) 12824 (("]" 26767)) 12825 (("(" 26631) (argument_list 26774)) 12826 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 26772) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12827 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 26773)) 12828 (("(" 26631) (argument_list 26776)) 12829 (("`" 26778)) 12830 (("]" 26780)) 12831 (("=" 26781)) 12832 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26782) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12833 (("%" 26443) ("*" 26444) ("+" 26445) ("-" 26446) ("." 26447) ("/" 26448) ("<" 26449) (">" 26450) ("?" 26451) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 26452) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 26453) (T_BOOLEAN_AND 26454) (T_BOOLEAN_OR 26455) (T_COALESCE 26456) (T_DOUBLE_ARROW 26785) (T_INSTANCEOF 26457) (T_IS_EQUAL 26458) (T_IS_GREATER_OR_EQUAL 26459) (T_IS_IDENTICAL 26460) (T_IS_NOT_EQUAL 26461) (T_IS_NOT_IDENTICAL 26462) (T_IS_SMALLER_OR_EQUAL 26463) (T_LOGICAL_AND 26464) (T_LOGICAL_OR 26465) (T_LOGICAL_XOR 26466) (T_POW 26467) (T_SL 26468) (T_SPACESHIP 26469) (T_SR 26470) ("^" 26471) ("|" 26472)) 12834 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26786) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12835 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 26795) (T_VARIABLE 2900) (encaps_var 2914)) 12836 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 26794) (T_VARIABLE 2900) (encaps_var 2905)) 12837 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 26847) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 12838 ((T_CLASS 26839)) 12839 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 26838) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 26808) (attribute 2980) (class_modifier 2945)) 12840 ((T_PAAMAYIM_NEKUDOTAYIM 26836)) 12841 (("(" 26827) (argument_list 26828) (ctor_arguments 26829)) 12842 ((T_NULLSAFE_OBJECT_OPERATOR 26815) (T_OBJECT_OPERATOR 26816) (T_PAAMAYIM_NEKUDOTAYIM 26817) ("[" 26818) ("{" 26819)) 12843 (("$" 26670) (T_STRING 26708) (T_VARIABLE 26672) (property_name 26826) (simple_variable 26710) ("{" 26711)) 12844 (("$" 26670) (T_STRING 26708) (T_VARIABLE 26672) (property_name 26825) (simple_variable 26710) ("{" 26711)) 12845 (("$" 26670) (T_VARIABLE 26672) (simple_variable 26824)) 12846 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 26822) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 12847 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 26820) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12848 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 26821)) 12849 (("]" 26823)) 12850 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 26830) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 26831) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 26832) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 12851 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 26835) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 12852 (("," 1469) (possible_comma 26833)) 12853 ((")" 26834)) 12854 (("$" 26670) (T_VARIABLE 26672) (simple_variable 26837)) 12855 (("(" 2982) (argument_list 2983) (ctor_arguments 26840)) 12856 ((T_EXTENDS 2985) (extends_from 26841)) 12857 ((T_IMPLEMENTS 2987) (implements_list 26842)) 12858 ((backup_doc_comment 26843)) 12859 (("{" 26844)) 12860 ((class_statement_list 26845)) 12861 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 26846)) 12862 (("%" 292) (")" 26848) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 12863 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 26850) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 12864 (("%" 292) (")" 26851) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 12865 (("{" 26852)) 12866 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 26853) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 12867 (("}" 26854)) 12868 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 26856) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 12869 ((")" 26857)) 12870 (("=" 26858)) 12871 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 26859) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 12872 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 26861) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 12873 (("," 5258) (possible_comma 26862)) 12874 ((")" 26863)) 12875 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 26870) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 12876 ((")" 26871)) 12877 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 26873) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 12878 (("%" 292) (")" 26874) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 12879 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 26876) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 12880 (("%" 292) (")" 26877) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 12881 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 26884) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 12882 ((")" 26885)) 12883 (("%" 292) (")" 26890) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 12884 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 26893) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12885 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 26894)) 12886 (("\"" 26896) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 12887 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 26906) (T_VARIABLE 2900) (encaps_var 2914)) 12888 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 26905) (T_VARIABLE 2900) (encaps_var 2905)) 12889 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 26958) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 12890 ((T_CLASS 26950)) 12891 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 26949) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 26919) (attribute 2980) (class_modifier 2945)) 12892 ((T_PAAMAYIM_NEKUDOTAYIM 26947)) 12893 (("(" 26938) (argument_list 26939) (ctor_arguments 26940)) 12894 ((T_NULLSAFE_OBJECT_OPERATOR 26926) (T_OBJECT_OPERATOR 26927) (T_PAAMAYIM_NEKUDOTAYIM 26928) ("[" 26929) ("{" 26930)) 12895 (("$" 26252) (T_STRING 26290) (T_VARIABLE 26254) (property_name 26937) (simple_variable 26292) ("{" 26293)) 12896 (("$" 26252) (T_STRING 26290) (T_VARIABLE 26254) (property_name 26936) (simple_variable 26292) ("{" 26293)) 12897 (("$" 26252) (T_VARIABLE 26254) (simple_variable 26935)) 12898 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 26933) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 12899 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 26931) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12900 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 26932)) 12901 (("]" 26934)) 12902 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 26941) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 26942) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 26943) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 12903 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 26946) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 12904 (("," 1469) (possible_comma 26944)) 12905 ((")" 26945)) 12906 (("$" 26252) (T_VARIABLE 26254) (simple_variable 26948)) 12907 (("(" 2982) (argument_list 2983) (ctor_arguments 26951)) 12908 ((T_EXTENDS 2985) (extends_from 26952)) 12909 ((T_IMPLEMENTS 2987) (implements_list 26953)) 12910 ((backup_doc_comment 26954)) 12911 (("{" 26955)) 12912 ((class_statement_list 26956)) 12913 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 26957)) 12914 (("%" 292) (")" 26959) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 12915 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 26961) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 12916 (("%" 292) (")" 26962) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 12917 (("{" 26963)) 12918 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 26964) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 12919 (("}" 26965)) 12920 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 26967) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 12921 ((")" 26968)) 12922 (("=" 26969)) 12923 (("!" 25947) ("\"" 25948) ("$" 25949) ("(" 25950) ("+" 25951) ("-" 25952) ("@" 25953) (T_ARRAY 25954) (T_ARRAY_CAST 25955) (T_ATTRIBUTE 126) (T_BOOL_CAST 25956) (T_CLASS_C 25957) (T_CLONE 25958) (T_CONSTANT_ENCAPSED_STRING 25959) (T_DEC 25960) (T_DIR 25961) (T_DNUMBER 25962) (T_DOUBLE_CAST 25963) (T_EMPTY 25964) (T_EVAL 25965) (T_EXIT 25966) (T_FILE 25967) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 25968) (T_INC 25969) (T_INCLUDE 25970) (T_INCLUDE_ONCE 25971) (T_INT_CAST 25972) (T_ISSET 25973) (T_LINE 25974) (T_LIST 25975) (T_LNUMBER 25976) (T_MATCH 25977) (T_METHOD_C 25978) (T_NAME_FULLY_QUALIFIED 25979) (T_NAME_QUALIFIED 25980) (T_NAME_RELATIVE 25981) (T_NEW 25982) (T_NS_C 25983) (T_OBJECT_CAST 25984) (T_PRINT 25985) (T_READONLY 25986) (T_REQUIRE 25987) (T_REQUIRE_ONCE 25988) (T_START_HEREDOC 25989) (T_STATIC 25990) (T_STRING 25991) (T_STRING_CAST 25992) (T_THROW 25993) (T_TRAIT_C 25994) (T_UNSET_CAST 25995) (T_VARIABLE 25996) (T_YIELD 25997) (T_YIELD_FROM 25998) ("[" 25999) ("`" 26000) (array_object_dereferenceable 26001) (attribute 131) (attributes 26002) (callable_expr 26003) (callable_variable 26004) (class_constant 26005) (class_name 26006) (constant 26007) (dereferenceable_scalar 26008) (expr 26970) (fn 26010) (fully_dereferenceable 104) #'26011 (function_call 26012) (inline_function 26013) (internal_functions_in_yacc 26014) (match 26015) (name 26016) (new_expr 26017) (scalar 26018) (simple_variable 26019) (static_member 26020) (variable 26021) (variable_class_name 26022) ("~" 26023)) 12924 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 26972) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 12925 (("," 5258) (possible_comma 26973)) 12926 ((")" 26974)) 12927 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 26981) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 12928 ((")" 26982)) 12929 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 26984) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 12930 (("%" 292) (")" 26985) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 12931 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 26987) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 12932 (("%" 292) (")" 26988) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 12933 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 26995) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 12934 ((")" 26996)) 12935 (("%" 292) (")" 27001) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 12936 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 27004) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12937 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 27005)) 12938 (("\"" 27007) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 12939 (("$" 4) (T_ABSTRACT 25605) (T_ARRAY 25606) (T_AS 25607) (T_BREAK 25608) (T_CALLABLE 25609) (T_CASE 25610) (T_CATCH 25611) (T_CLASS 25612) (T_CLASS_C 25613) (T_CLONE 25614) (T_CONST 25615) (T_CONTINUE 25616) (T_DECLARE 25617) (T_DEFAULT 25618) (T_DIR 25619) (T_DO 25620) (T_ECHO 25621) (T_ELSE 25622) (T_ELSEIF 25623) (T_EMPTY 25624) (T_ENDDECLARE 25625) (T_ENDFOR 25626) (T_ENDFOREACH 25627) (T_ENDIF 25628) (T_ENDSWITCH 25629) (T_ENDWHILE 25630) (T_ENUM 25631) (T_EVAL 25632) (T_EXIT 25633) (T_EXTENDS 25634) (T_FILE 25635) (T_FINAL 25636) (T_FINALLY 25637) (T_FN 25638) (T_FOR 25639) (T_FOREACH 25640) (T_FUNCTION 25641) (T_FUNC_C 25642) (T_GLOBAL 25643) (T_GOTO 25644) (T_IF 25645) (T_IMPLEMENTS 25646) (T_INCLUDE 25647) (T_INCLUDE_ONCE 25648) (T_INSTANCEOF 25649) (T_INSTEADOF 25650) (T_INTERFACE 25651) (T_ISSET 25652) (T_LINE 25653) (T_LIST 25654) (T_LOGICAL_AND 25655) (T_LOGICAL_OR 25656) (T_LOGICAL_XOR 25657) (T_MATCH 25658) (T_METHOD_C 25659) (T_NAMESPACE 25660) (T_NEW 25661) (T_NS_C 25662) (T_PRINT 25663) (T_PRIVATE 25664) (T_PROTECTED 25665) (T_PUBLIC 25666) (T_READONLY 25667) (T_REQUIRE 25668) (T_REQUIRE_ONCE 25669) (T_RETURN 25670) (T_STATIC 25671) (T_STRING 25672) (T_SWITCH 25673) (T_THROW 25674) (T_TRAIT 25675) (T_TRAIT_C 25676) (T_TRY 25677) (T_UNSET 25678) (T_USE 25679) (T_VAR 25680) (T_VARIABLE 80) (T_WHILE 25681) (T_YIELD 25682) (identifier 27011) (member_name 27012) (reserved_non_modifiers 25685) (semi_reserved 25686) (simple_variable 27013) ("{" 27014)) 12940 (("(" 25591) (argument_list 27017)) 12941 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 27015) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12942 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 27016)) 12943 ((T_STRING 27019)) 12944 ((T_EXTENDS 2985) (extends_from 27020)) 12945 ((T_IMPLEMENTS 2987) (implements_list 27021)) 12946 ((backup_doc_comment 27022)) 12947 (("{" 27023)) 12948 ((class_statement_list 27024)) 12949 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 27025)) 12950 ((T_STRING 27077)) 12951 ((T_STRING 27070)) 12952 ((T_STRING 27064)) 12953 ((T_STRING 27059)) 12954 ((T_ABSTRACT 10) (T_CLASS 27051) (T_FINAL 34) (T_READONLY 2936) (class_modifier 16280)) 12955 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 16261) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 16262) (ampersand 16263) (returns_ref 27039)) 12956 ((T_READONLY 16265) (T_STRING 16266) (backup_doc_comment 139) (function_name 27040)) 12957 ((backup_doc_comment 27041)) 12958 (("(" 27042)) 12959 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 27043)) 12960 ((")" 27044)) 12961 ((":" 161) (return_type 27045)) 12962 ((backup_fn_flags 27046)) 12963 (("{" 27047)) 12964 ((inner_statement_list 27048)) 12965 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 27049) ("~" 125)) 12966 ((backup_fn_flags 27050)) 12967 ((T_STRING 27052)) 12968 ((T_EXTENDS 2985) (extends_from 27053)) 12969 ((T_IMPLEMENTS 2987) (implements_list 27054)) 12970 ((backup_doc_comment 27055)) 12971 (("{" 27056)) 12972 ((class_statement_list 27057)) 12973 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 27058)) 12974 ((backup_doc_comment 27060)) 12975 (("{" 27061)) 12976 ((class_statement_list 27062)) 12977 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 27063)) 12978 ((T_EXTENDS 20209) (interface_extends_list 27065)) 12979 ((backup_doc_comment 27066)) 12980 (("{" 27067)) 12981 ((class_statement_list 27068)) 12982 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 27069)) 12983 ((":" 20258) (enum_backing_type 27071)) 12984 ((T_IMPLEMENTS 2987) (implements_list 27072)) 12985 ((backup_doc_comment 27073)) 12986 (("{" 27074)) 12987 ((class_statement_list 27075)) 12988 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 27076)) 12989 ((T_EXTENDS 2985) (extends_from 27078)) 12990 ((T_IMPLEMENTS 2987) (implements_list 27079)) 12991 ((backup_doc_comment 27080)) 12992 (("{" 27081)) 12993 ((class_statement_list 27082)) 12994 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 27083)) 12995 (("$" 4) (T_STRING 27092) (T_VARIABLE 80) (property_name 27099) (simple_variable 27094) ("{" 27095)) 12996 (("$" 4) (T_STRING 27092) (T_VARIABLE 80) (property_name 27093) (simple_variable 27094) ("{" 27095)) 12997 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 27090) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 12998 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 27088) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 12999 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 27089)) 13000 (("]" 27091)) 13001 (("(" 25591) (argument_list 27098)) 13002 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 27096) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 13003 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 27097)) 13004 (("(" 25591) (argument_list 27100)) 13005 ((":" 27104)) 13006 ((";" 27103)) 13007 ((inner_statement_list 27105)) 13008 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16298) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16299) (T_CLASS 16300) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16301) (T_DEC 22) (T_DECLARE 16302) (T_DIR 24) (T_DNUMBER 25) (T_DO 16303) (T_DOUBLE_CAST 27) (T_ECHO 16304) (T_EMPTY 29) (T_ENDIF 27106) (T_ENUM 16306) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16307) (T_FOREACH 16308) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16309) (T_GOTO 16310) (T_HALT_COMPILER 16311) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16312) (T_INTERFACE 16313) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16314) (T_START_HEREDOC 68) (T_STATIC 16315) (T_STRING 16316) (T_STRING_CAST 71) (T_SWITCH 16317) (T_THROW 73) (T_TRAIT 16318) (T_TRAIT_C 75) (T_TRY 16319) (T_UNSET 16320) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16321) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16322) (alt_if_stmt_without_else 16323) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16324) (attributes 16325) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16326) (class_modifier 96) (class_modifiers 16327) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16328) (expr 16329) (fn 103) (fully_dereferenceable 104) #'16330 (function_call 106) (function_declaration_statement 16331) (if_stmt 16332) (if_stmt_without_else 16333) (inline_function 110) (inner_statement 16334) (interface_declaration_statement 16335) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16336) (static_member 119) (trait_declaration_statement 16337) (variable 122) (variable_class_name 123) ("{" 16338) ("~" 125)) 13009 ((";" 27107)) 13010 (("`" 27109)) 13011 (("]" 27111)) 13012 (("=" 27112)) 13013 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 27113) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 13014 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27621) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13015 ((T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5296) (T_VARIABLE 5297) (encaps_list 27619) (encaps_var 5299)) 13016 (("$" 27117) (T_VARIABLE 27164) (simple_variable 27615) ("{" 27616)) 13017 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 27613) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 13018 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27612) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13019 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27611) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13020 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27610) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13021 (("(" 27607)) 13022 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27606) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13023 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27605) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13024 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27604) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13025 (("\"" 1509) ("$" 27420) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 27421) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 27422) ("[" 1529) (array_object_dereferenceable 27423) (callable_expr 27424) (callable_variable 27425) (class_constant 1533) (class_name 27426) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 27427) (name 27428) (simple_variable 27429) (static_member 27430) (variable 27603) (variable_class_name 27432)) 13026 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27602) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13027 (("(" 27599)) 13028 (("(" 27596)) 13029 (("(" 27592) (exit_expr 27593)) 13030 (("\"" 1509) ("$" 27420) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 27421) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 27422) ("[" 1529) (array_object_dereferenceable 27423) (callable_expr 27424) (callable_variable 27425) (class_constant 1533) (class_name 27426) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 27427) (name 27428) (simple_variable 27429) (static_member 27430) (variable 27591) (variable_class_name 27432)) 13031 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27590) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13032 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27589) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13033 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27588) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13034 (("(" 27584)) 13035 (("(" 27579)) 13036 (("(" 27573)) 13037 (("$" 26670) ("(" 26801) (T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_NAME_FULLY_QUALIFIED 26802) (T_NAME_QUALIFIED 26803) (T_NAME_RELATIVE 26804) (T_READONLY 2936) (T_STATIC 26805) (T_STRING 26806) (T_VARIABLE 26672) (anonymous_class 27551) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 27552) (attribute 2943) (attributes 27553) (class_modifier 2945) (class_name 26810) (class_name_reference 27554) (name 26812) (new_variable 26813) (simple_variable 26814)) 13038 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27550) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13039 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27549) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13040 (("(" 27381) (argument_list 27548)) 13041 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27547) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13042 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27546) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13043 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 27541) (T_END_HEREDOC 27542) (T_VARIABLE 2900) (encaps_list 27543) (encaps_var 2902)) 13044 ((T_FN 35) (T_FUNCTION 127) (fn 27178) #'27179 (inline_function 27540)) 13045 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27539) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13046 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27538) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13047 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27537) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13048 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27534) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13049 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27533) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13050 (("!" 1665) ("\"" 1666) ("$" 1667) ("(" 1668) ("+" 1669) ("-" 1670) ("@" 1671) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1672) (T_ARRAY_CAST 1673) (T_ATTRIBUTE 126) (T_BOOL_CAST 1674) (T_CLASS_C 1675) (T_CLONE 1676) (T_CONSTANT_ENCAPSED_STRING 1677) (T_DEC 1678) (T_DIR 1679) (T_DNUMBER 1680) (T_DOUBLE_CAST 1681) (T_ELLIPSIS 1682) (T_EMPTY 1683) (T_EVAL 1684) (T_EXIT 1685) (T_FILE 1686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1687) (T_INC 1688) (T_INCLUDE 1689) (T_INCLUDE_ONCE 1690) (T_INT_CAST 1691) (T_ISSET 1692) (T_LINE 1693) (T_LIST 1694) (T_LNUMBER 1695) (T_MATCH 1696) (T_METHOD_C 1697) (T_NAME_FULLY_QUALIFIED 1698) (T_NAME_QUALIFIED 1699) (T_NAME_RELATIVE 1700) (T_NEW 1701) (T_NS_C 1702) (T_OBJECT_CAST 1703) (T_PRINT 1704) (T_READONLY 1705) (T_REQUIRE 1706) (T_REQUIRE_ONCE 1707) (T_START_HEREDOC 1708) (T_STATIC 1709) (T_STRING 1710) (T_STRING_CAST 1711) (T_THROW 1712) (T_TRAIT_C 1713) (T_UNSET_CAST 1714) (T_VARIABLE 1715) (T_YIELD 1716) (T_YIELD_FROM 1717) ("[" 1718) ("`" 1719) (ampersand 1720) (array_object_dereferenceable 1721) (array_pair 1722) (array_pair_list 27529) (attribute 131) (attributes 1724) (callable_expr 1725) (callable_variable 1726) (class_constant 1727) (class_name 1728) (constant 1729) (dereferenceable_scalar 1730) (expr 1731) (fn 1732) (fully_dereferenceable 104) #'1733 (function_call 1734) (inline_function 1735) (internal_functions_in_yacc 1736) (match 1737) (name 1738) (new_expr 1739) (non_empty_array_pair_list 1740) (possible_array_pair 1741) (scalar 1742) (simple_variable 1743) (static_member 1744) (variable 1745) (variable_class_name 1746) ("~" 1747)) 13051 ((T_CURLY_OPEN 2800) (T_DOLLAR_OPEN_CURLY_BRACES 2801) (T_ENCAPSED_AND_WHITESPACE 2802) (T_VARIABLE 2803) (backticks_expr 27527) (encaps_list 2805) (encaps_var 2806)) 13052 ((T_NULLSAFE_OBJECT_OPERATOR 27510) (T_OBJECT_OPERATOR 27511) ("[" 27512) ("{" 27513)) 13053 ((T_ATTRIBUTE 126) (T_FN 35) (T_FUNCTION 127) (T_STATIC 27507) (attribute 2728) (fn 27178) #'27179 (inline_function 27508)) 13054 (("(" 27381) (argument_list 27506)) 13055 ((T_PAAMAYIM_NEKUDOTAYIM 27498)) 13056 (("%" 27193) ("*" 27194) ("+" 27195) ("-" 27196) ("." 27197) ("/" 27198) ("<" 27199) (">" 27200) ("?" 27201) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 27202) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 27203) (T_BOOLEAN_AND 27204) (T_BOOLEAN_OR 27205) (T_COALESCE 27206) (T_DOUBLE_ARROW 27496) (T_INSTANCEOF 27207) (T_IS_EQUAL 27208) (T_IS_GREATER_OR_EQUAL 27209) (T_IS_IDENTICAL 27210) (T_IS_NOT_EQUAL 27211) (T_IS_NOT_IDENTICAL 27212) (T_IS_SMALLER_OR_EQUAL 27213) (T_LOGICAL_AND 27214) (T_LOGICAL_OR 27215) (T_LOGICAL_XOR 27216) (T_POW 27217) (T_SL 27218) (T_SPACESHIP 27219) (T_SR 27220) ("^" 27221) ("|" 27222)) 13057 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 27485)) 13058 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 135) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 136) (ampersand 137) (returns_ref 27473)) 13059 (("(" 27381) (argument_list 27472)) 13060 (("=" 27389) (T_AND_EQUAL 27390) (T_COALESCE_EQUAL 27391) (T_CONCAT_EQUAL 27392) (T_DEC 27393) (T_DIV_EQUAL 27394) (T_INC 27395) (T_MINUS_EQUAL 27396) (T_MOD_EQUAL 27397) (T_MUL_EQUAL 27398) (T_OR_EQUAL 27399) (T_PLUS_EQUAL 27400) (T_POW_EQUAL 27401) (T_SL_EQUAL 27402) (T_SR_EQUAL 27403) (T_XOR_EQUAL 27404)) 13061 ((T_PAAMAYIM_NEKUDOTAYIM 27294)) 13062 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27192) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13063 (("%" 27193) ("*" 27194) ("+" 27195) ("-" 27196) ("." 27197) ("/" 27198) ("<" 27199) (">" 27200) ("?" 27201) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 27202) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 27203) (T_BOOLEAN_AND 27204) (T_BOOLEAN_OR 27205) (T_COALESCE 27206) (T_INSTANCEOF 27207) (T_IS_EQUAL 27208) (T_IS_GREATER_OR_EQUAL 27209) (T_IS_IDENTICAL 27210) (T_IS_NOT_EQUAL 27211) (T_IS_NOT_IDENTICAL 27212) (T_IS_SMALLER_OR_EQUAL 27213) (T_LOGICAL_AND 27214) (T_LOGICAL_OR 27215) (T_LOGICAL_XOR 27216) (T_POW 27217) (T_SL 27218) (T_SPACESHIP 27219) (T_SR 27220) ("^" 27221) ("|" 27222)) 13064 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27293) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13065 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27292) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13066 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27291) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13067 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27290) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13068 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27289) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13069 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27288) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13070 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27287) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13071 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27286) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13072 (("!" 665) ("\"" 666) ("$" 667) ("(" 668) ("+" 669) ("-" 670) (":" 27281) ("@" 672) (T_ARRAY 673) (T_ARRAY_CAST 674) (T_ATTRIBUTE 126) (T_BOOL_CAST 675) (T_CLASS_C 676) (T_CLONE 677) (T_CONSTANT_ENCAPSED_STRING 678) (T_DEC 679) (T_DIR 680) (T_DNUMBER 681) (T_DOUBLE_CAST 682) (T_EMPTY 683) (T_EVAL 684) (T_EXIT 685) (T_FILE 686) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 687) (T_INC 688) (T_INCLUDE 689) (T_INCLUDE_ONCE 690) (T_INT_CAST 691) (T_ISSET 692) (T_LINE 693) (T_LIST 694) (T_LNUMBER 695) (T_MATCH 696) (T_METHOD_C 697) (T_NAME_FULLY_QUALIFIED 698) (T_NAME_QUALIFIED 699) (T_NAME_RELATIVE 700) (T_NEW 701) (T_NS_C 702) (T_OBJECT_CAST 703) (T_PRINT 704) (T_READONLY 705) (T_REQUIRE 706) (T_REQUIRE_ONCE 707) (T_START_HEREDOC 708) (T_STATIC 709) (T_STRING 710) (T_STRING_CAST 711) (T_THROW 712) (T_TRAIT_C 713) (T_UNSET_CAST 714) (T_VARIABLE 715) (T_YIELD 716) (T_YIELD_FROM 717) ("[" 718) ("`" 719) (array_object_dereferenceable 720) (attribute 131) (attributes 721) (callable_expr 722) (callable_variable 723) (class_constant 724) (class_name 725) (constant 726) (dereferenceable_scalar 727) (expr 27282) (fn 729) (fully_dereferenceable 104) #'730 (function_call 731) (inline_function 732) (internal_functions_in_yacc 733) (match 734) (name 735) (new_expr 736) (scalar 737) (simple_variable 738) (static_member 739) (variable 740) (variable_class_name 741) ("~" 742)) 13073 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27280) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13074 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27279) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13075 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27278) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13076 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27277) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13077 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27276) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13078 (("$" 27238) ("(" 27239) (T_NAME_FULLY_QUALIFIED 27240) (T_NAME_QUALIFIED 27241) (T_NAME_RELATIVE 27242) (T_STATIC 27243) (T_STRING 27244) (T_VARIABLE 27245) (class_name 27246) (class_name_reference 27247) (name 27248) (new_variable 27249) (simple_variable 27250)) 13079 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27237) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13080 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27236) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13081 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27235) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13082 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27234) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13083 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27233) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13084 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27232) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13085 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27231) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13086 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27230) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13087 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27229) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13088 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27228) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13089 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27227) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13090 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27226) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13091 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27225) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13092 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27224) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13093 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27223) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13094 (("$" 27238) (T_VARIABLE 27245) (simple_variable 27272) ("{" 27273)) 13095 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 27270) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 13096 ((T_PAAMAYIM_NEKUDOTAYIM 27268)) 13097 ((T_NULLSAFE_OBJECT_OPERATOR 27251) (T_OBJECT_OPERATOR 27252) (T_PAAMAYIM_NEKUDOTAYIM 27253) ("[" 27254) ("{" 27255)) 13098 (("$" 27238) (T_STRING 27261) (T_VARIABLE 27245) (property_name 27267) (simple_variable 27263) ("{" 27264)) 13099 (("$" 27238) (T_STRING 27261) (T_VARIABLE 27245) (property_name 27262) (simple_variable 27263) ("{" 27264)) 13100 (("$" 27238) (T_VARIABLE 27245) (simple_variable 27260)) 13101 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 27258) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 13102 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 27256) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 13103 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 27257)) 13104 (("]" 27259)) 13105 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 27265) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 13106 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 27266)) 13107 (("$" 27238) (T_VARIABLE 27245) (simple_variable 27269)) 13108 (("%" 292) (")" 27271) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 13109 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 27274) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 13110 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 27275)) 13111 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27285) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13112 (("%" 744) ("*" 745) ("+" 746) ("-" 747) ("." 748) ("/" 749) (":" 27283) ("<" 750) (">" 751) ("?" 752) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 753) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 754) (T_BOOLEAN_AND 755) (T_BOOLEAN_OR 756) (T_COALESCE 757) (T_INSTANCEOF 758) (T_IS_EQUAL 759) (T_IS_GREATER_OR_EQUAL 760) (T_IS_IDENTICAL 761) (T_IS_NOT_EQUAL 762) (T_IS_NOT_IDENTICAL 763) (T_IS_SMALLER_OR_EQUAL 764) (T_LOGICAL_AND 765) (T_LOGICAL_OR 766) (T_LOGICAL_XOR 767) (T_POW 768) (T_SL 769) (T_SPACESHIP 770) (T_SR 771) ("^" 772) ("|" 773)) 13113 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27284) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13114 (("$" 27117) (T_ABSTRACT 27295) (T_ARRAY 27296) (T_AS 27297) (T_BREAK 27298) (T_CALLABLE 27299) (T_CASE 27300) (T_CATCH 27301) (T_CLASS 27302) (T_CLASS_C 27303) (T_CLONE 27304) (T_CONST 27305) (T_CONTINUE 27306) (T_DECLARE 27307) (T_DEFAULT 27308) (T_DIR 27309) (T_DO 27310) (T_ECHO 27311) (T_ELSE 27312) (T_ELSEIF 27313) (T_EMPTY 27314) (T_ENDDECLARE 27315) (T_ENDFOR 27316) (T_ENDFOREACH 27317) (T_ENDIF 27318) (T_ENDSWITCH 27319) (T_ENDWHILE 27320) (T_ENUM 27321) (T_EVAL 27322) (T_EXIT 27323) (T_EXTENDS 27324) (T_FILE 27325) (T_FINAL 27326) (T_FINALLY 27327) (T_FN 27328) (T_FOR 27329) (T_FOREACH 27330) (T_FUNCTION 27331) (T_FUNC_C 27332) (T_GLOBAL 27333) (T_GOTO 27334) (T_IF 27335) (T_IMPLEMENTS 27336) (T_INCLUDE 27337) (T_INCLUDE_ONCE 27338) (T_INSTANCEOF 27339) (T_INSTEADOF 27340) (T_INTERFACE 27341) (T_ISSET 27342) (T_LINE 27343) (T_LIST 27344) (T_LOGICAL_AND 27345) (T_LOGICAL_OR 27346) (T_LOGICAL_XOR 27347) (T_MATCH 27348) (T_METHOD_C 27349) (T_NAMESPACE 27350) (T_NEW 27351) (T_NS_C 27352) (T_PRINT 27353) (T_PRIVATE 27354) (T_PROTECTED 27355) (T_PUBLIC 27356) (T_READONLY 27357) (T_REQUIRE 27358) (T_REQUIRE_ONCE 27359) (T_RETURN 27360) (T_STATIC 27361) (T_STRING 27362) (T_SWITCH 27363) (T_THROW 27364) (T_TRAIT 27365) (T_TRAIT_C 27366) (T_TRY 27367) (T_UNSET 27368) (T_USE 27369) (T_VAR 27370) (T_VARIABLE 27164) (T_WHILE 27371) (T_YIELD 27372) (identifier 27373) (member_name 27374) (reserved_non_modifiers 27375) (semi_reserved 27376) (simple_variable 27377) ("{" 27378)) 13115 (("(" 27381) (argument_list 27382)) 13116 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 27379) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 13117 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 27380)) 13118 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 27383) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 27384) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 27385) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 13119 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 27388) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 13120 (("," 1469) (possible_comma 27386)) 13121 ((")" 27387)) 13122 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (ampersand 27418) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27419) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13123 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27417) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13124 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27416) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13125 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27415) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13126 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27414) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13127 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27413) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13128 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27412) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13129 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27411) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13130 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27410) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13131 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27409) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13132 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27408) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13133 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27407) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13134 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27406) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13135 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27405) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13136 (("\"" 1509) ("$" 27420) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 27421) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 27422) ("[" 1529) (array_object_dereferenceable 27423) (callable_expr 27424) (callable_variable 27425) (class_constant 1533) (class_name 27426) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 27427) (name 27428) (simple_variable 27429) (static_member 27430) (variable 27431) (variable_class_name 27432)) 13137 (("$" 27420) (T_VARIABLE 27422) (simple_variable 27468) ("{" 27469)) 13138 (("(" 27436) (argument_list 27467)) 13139 ((T_NULLSAFE_OBJECT_OPERATOR 27450) (T_OBJECT_OPERATOR 27451) ("[" 27452) ("{" 27453)) 13140 (("(" 27436) (argument_list 27449)) 13141 ((T_PAAMAYIM_NEKUDOTAYIM 27445)) 13142 (("(" 27436) (argument_list 27444)) 13143 ((T_PAAMAYIM_NEKUDOTAYIM 27433)) 13144 (("$" 27420) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 27422) (T_WHILE 1620) (T_YIELD 1621) (identifier 1622) (member_name 27434) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 27435) ("{" 1627)) 13145 (("(" 27436) (argument_list 27437)) 13146 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 27438) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 27439) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 27440) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 13147 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 27443) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 13148 (("," 1469) (possible_comma 27441)) 13149 ((")" 27442)) 13150 (("$" 27420) (T_ABSTRACT 1544) (T_ARRAY 1545) (T_AS 1546) (T_BREAK 1547) (T_CALLABLE 1548) (T_CASE 1549) (T_CATCH 1550) (T_CLASS 1551) (T_CLASS_C 1552) (T_CLONE 1553) (T_CONST 1554) (T_CONTINUE 1555) (T_DECLARE 1556) (T_DEFAULT 1557) (T_DIR 1558) (T_DO 1559) (T_ECHO 1560) (T_ELSE 1561) (T_ELSEIF 1562) (T_EMPTY 1563) (T_ENDDECLARE 1564) (T_ENDFOR 1565) (T_ENDFOREACH 1566) (T_ENDIF 1567) (T_ENDSWITCH 1568) (T_ENDWHILE 1569) (T_ENUM 1570) (T_EVAL 1571) (T_EXIT 1572) (T_EXTENDS 1573) (T_FILE 1574) (T_FINAL 1575) (T_FINALLY 1576) (T_FN 1577) (T_FOR 1578) (T_FOREACH 1579) (T_FUNCTION 1580) (T_FUNC_C 1581) (T_GLOBAL 1582) (T_GOTO 1583) (T_IF 1584) (T_IMPLEMENTS 1585) (T_INCLUDE 1586) (T_INCLUDE_ONCE 1587) (T_INSTANCEOF 1588) (T_INSTEADOF 1589) (T_INTERFACE 1590) (T_ISSET 1591) (T_LINE 1592) (T_LIST 1593) (T_LOGICAL_AND 1594) (T_LOGICAL_OR 1595) (T_LOGICAL_XOR 1596) (T_MATCH 1597) (T_METHOD_C 1598) (T_NAMESPACE 1599) (T_NEW 1600) (T_NS_C 1601) (T_PRINT 1602) (T_PRIVATE 1603) (T_PROTECTED 1604) (T_PUBLIC 1605) (T_READONLY 1606) (T_REQUIRE 1607) (T_REQUIRE_ONCE 1608) (T_RETURN 1609) (T_STATIC 1610) (T_STRING 1611) (T_SWITCH 1612) (T_THROW 1613) (T_TRAIT 1614) (T_TRAIT_C 1615) (T_TRY 1616) (T_UNSET 1617) (T_USE 1618) (T_VAR 1619) (T_VARIABLE 27422) (T_WHILE 1620) (T_YIELD 1621) (identifier 1640) (member_name 27446) (reserved_non_modifiers 1624) (semi_reserved 1625) (simple_variable 27447) ("{" 1643)) 13151 (("(" 27436) (argument_list 27448)) 13152 (("$" 27420) (T_STRING 27458) (T_VARIABLE 27422) (property_name 27465) (simple_variable 27460) ("{" 27461)) 13153 (("$" 27420) (T_STRING 27458) (T_VARIABLE 27422) (property_name 27459) (simple_variable 27460) ("{" 27461)) 13154 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 27456) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 13155 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 27454) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 13156 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 27455)) 13157 (("]" 27457)) 13158 (("(" 27436) (argument_list 27464)) 13159 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 27462) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 13160 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 27463)) 13161 (("(" 27436) (argument_list 27466)) 13162 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 27470) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 13163 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 27471)) 13164 ((backup_doc_comment 27474)) 13165 (("(" 27475)) 13166 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 27476)) 13167 ((")" 27477)) 13168 ((T_USE 159) (lexical_vars 27478)) 13169 ((":" 161) (return_type 27479)) 13170 ((backup_fn_flags 27480)) 13171 (("{" 27481)) 13172 ((inner_statement_list 27482)) 13173 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 27483) ("~" 125)) 13174 ((backup_fn_flags 27484)) 13175 ((backup_doc_comment 27486)) 13176 (("(" 27487)) 13177 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 27488)) 13178 ((")" 27489)) 13179 ((":" 2241) (return_type 27490)) 13180 ((T_DOUBLE_ARROW 27491)) 13181 ((backup_fn_flags 27492)) 13182 ((backup_lex_pos 27493)) 13183 (("!" 26365) ("\"" 26366) ("$" 26367) ("(" 26368) ("+" 26369) ("-" 26370) ("@" 26371) (T_ARRAY 26372) (T_ARRAY_CAST 26373) (T_ATTRIBUTE 126) (T_BOOL_CAST 26374) (T_CLASS_C 26375) (T_CLONE 26376) (T_CONSTANT_ENCAPSED_STRING 26377) (T_DEC 26378) (T_DIR 26379) (T_DNUMBER 26380) (T_DOUBLE_CAST 26381) (T_EMPTY 26382) (T_EVAL 26383) (T_EXIT 26384) (T_FILE 26385) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 26386) (T_INC 26387) (T_INCLUDE 26388) (T_INCLUDE_ONCE 26389) (T_INT_CAST 26390) (T_ISSET 26391) (T_LINE 26392) (T_LIST 26393) (T_LNUMBER 26394) (T_MATCH 26395) (T_METHOD_C 26396) (T_NAME_FULLY_QUALIFIED 26397) (T_NAME_QUALIFIED 26398) (T_NAME_RELATIVE 26399) (T_NEW 26400) (T_NS_C 26401) (T_OBJECT_CAST 26402) (T_PRINT 26403) (T_READONLY 26404) (T_REQUIRE 26405) (T_REQUIRE_ONCE 26406) (T_START_HEREDOC 26407) (T_STATIC 26408) (T_STRING 26409) (T_STRING_CAST 26410) (T_THROW 26411) (T_TRAIT_C 26412) (T_UNSET_CAST 26413) (T_VARIABLE 26414) (T_YIELD 26415) (T_YIELD_FROM 26416) ("[" 26417) ("`" 26418) (array_object_dereferenceable 26419) (attribute 131) (attributes 26420) (callable_expr 26421) (callable_variable 26422) (class_constant 26423) (class_name 26424) (constant 26425) (dereferenceable_scalar 26426) (expr 27494) (fn 26428) (fully_dereferenceable 104) #'26429 (function_call 26430) (inline_function 26431) (internal_functions_in_yacc 26432) (match 26433) (name 26434) (new_expr 26435) (scalar 26436) (simple_variable 26437) (static_member 26438) (variable 26439) (variable_class_name 26440) ("~" 26441)) 13184 (("%" 26443) ("*" 26444) ("+" 26445) ("-" 26446) ("." 26447) ("/" 26448) ("<" 26449) (">" 26450) ("?" 26451) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 26452) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 26453) (T_BOOLEAN_AND 26454) (T_BOOLEAN_OR 26455) (T_COALESCE 26456) (T_INSTANCEOF 26457) (T_IS_EQUAL 26458) (T_IS_GREATER_OR_EQUAL 26459) (T_IS_IDENTICAL 26460) (T_IS_NOT_EQUAL 26461) (T_IS_NOT_IDENTICAL 26462) (T_IS_SMALLER_OR_EQUAL 26463) (T_LOGICAL_AND 26464) (T_LOGICAL_OR 26465) (T_LOGICAL_XOR 26466) (T_POW 26467) (T_SL 26468) (T_SPACESHIP 26469) (T_SR 26470) ("^" 26471) (backup_fn_flags 27495) ("|" 26472)) 13185 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 27497) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 13186 (("$" 27117) (T_ABSTRACT 27295) (T_ARRAY 27296) (T_AS 27297) (T_BREAK 27298) (T_CALLABLE 27299) (T_CASE 27300) (T_CATCH 27301) (T_CLASS 27302) (T_CLASS_C 27303) (T_CLONE 27304) (T_CONST 27305) (T_CONTINUE 27306) (T_DECLARE 27307) (T_DEFAULT 27308) (T_DIR 27309) (T_DO 27310) (T_ECHO 27311) (T_ELSE 27312) (T_ELSEIF 27313) (T_EMPTY 27314) (T_ENDDECLARE 27315) (T_ENDFOR 27316) (T_ENDFOREACH 27317) (T_ENDIF 27318) (T_ENDSWITCH 27319) (T_ENDWHILE 27320) (T_ENUM 27321) (T_EVAL 27322) (T_EXIT 27323) (T_EXTENDS 27324) (T_FILE 27325) (T_FINAL 27326) (T_FINALLY 27327) (T_FN 27328) (T_FOR 27329) (T_FOREACH 27330) (T_FUNCTION 27331) (T_FUNC_C 27332) (T_GLOBAL 27333) (T_GOTO 27334) (T_IF 27335) (T_IMPLEMENTS 27336) (T_INCLUDE 27337) (T_INCLUDE_ONCE 27338) (T_INSTANCEOF 27339) (T_INSTEADOF 27340) (T_INTERFACE 27341) (T_ISSET 27342) (T_LINE 27343) (T_LIST 27344) (T_LOGICAL_AND 27345) (T_LOGICAL_OR 27346) (T_LOGICAL_XOR 27347) (T_MATCH 27348) (T_METHOD_C 27349) (T_NAMESPACE 27350) (T_NEW 27351) (T_NS_C 27352) (T_PRINT 27353) (T_PRIVATE 27354) (T_PROTECTED 27355) (T_PUBLIC 27356) (T_READONLY 27357) (T_REQUIRE 27358) (T_REQUIRE_ONCE 27359) (T_RETURN 27360) (T_STATIC 27361) (T_STRING 27362) (T_SWITCH 27363) (T_THROW 27364) (T_TRAIT 27365) (T_TRAIT_C 27366) (T_TRY 27367) (T_UNSET 27368) (T_USE 27369) (T_VAR 27370) (T_VARIABLE 27164) (T_WHILE 27371) (T_YIELD 27372) (identifier 27499) (member_name 27500) (reserved_non_modifiers 27375) (semi_reserved 27376) (simple_variable 27501) ("{" 27502)) 13187 (("(" 27381) (argument_list 27505)) 13188 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 27503) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 13189 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 27504)) 13190 ((T_FN 35) (T_FUNCTION 127) (fn 27178) #'27179 (inline_function 27509)) 13191 (("$" 27117) (T_STRING 27518) (T_VARIABLE 27164) (property_name 27525) (simple_variable 27520) ("{" 27521)) 13192 (("$" 27117) (T_STRING 27518) (T_VARIABLE 27164) (property_name 27519) (simple_variable 27520) ("{" 27521)) 13193 (("!" 498) ("\"" 499) ("$" 500) ("(" 501) ("+" 502) ("-" 503) ("@" 504) (T_ARRAY 505) (T_ARRAY_CAST 506) (T_ATTRIBUTE 126) (T_BOOL_CAST 507) (T_CLASS_C 508) (T_CLONE 509) (T_CONSTANT_ENCAPSED_STRING 510) (T_DEC 511) (T_DIR 512) (T_DNUMBER 513) (T_DOUBLE_CAST 514) (T_EMPTY 515) (T_EVAL 516) (T_EXIT 517) (T_FILE 518) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 519) (T_INC 520) (T_INCLUDE 521) (T_INCLUDE_ONCE 522) (T_INT_CAST 523) (T_ISSET 524) (T_LINE 525) (T_LIST 526) (T_LNUMBER 527) (T_MATCH 528) (T_METHOD_C 529) (T_NAME_FULLY_QUALIFIED 530) (T_NAME_QUALIFIED 531) (T_NAME_RELATIVE 532) (T_NEW 533) (T_NS_C 534) (T_OBJECT_CAST 535) (T_PRINT 536) (T_READONLY 537) (T_REQUIRE 538) (T_REQUIRE_ONCE 539) (T_START_HEREDOC 540) (T_STATIC 541) (T_STRING 542) (T_STRING_CAST 543) (T_THROW 544) (T_TRAIT_C 545) (T_UNSET_CAST 546) (T_VARIABLE 547) (T_YIELD 548) (T_YIELD_FROM 549) ("[" 550) ("`" 551) (array_object_dereferenceable 552) (attribute 131) (attributes 553) (callable_expr 554) (callable_variable 555) (class_constant 556) (class_name 557) (constant 558) (dereferenceable_scalar 559) (expr 560) (fn 561) (fully_dereferenceable 104) #'562 (function_call 563) (inline_function 564) (internal_functions_in_yacc 565) (match 566) (name 567) (new_expr 568) (optional_expr 27516) (scalar 570) (simple_variable 571) (static_member 572) (variable 573) (variable_class_name 574) ("~" 575)) 13194 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 27514) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 13195 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 27515)) 13196 (("]" 27517)) 13197 (("(" 27381) (argument_list 27524)) 13198 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 27522) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 13199 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 27523)) 13200 (("(" 27381) (argument_list 27526)) 13201 (("`" 27528)) 13202 (("]" 27530)) 13203 (("=" 27531)) 13204 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27532) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13205 (("%" 27193) ("*" 27194) ("+" 27195) ("-" 27196) ("." 27197) ("/" 27198) ("<" 27199) (">" 27200) ("?" 27201) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 27202) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 27203) (T_BOOLEAN_AND 27204) (T_BOOLEAN_OR 27205) (T_COALESCE 27206) (T_DOUBLE_ARROW 27535) (T_INSTANCEOF 27207) (T_IS_EQUAL 27208) (T_IS_GREATER_OR_EQUAL 27209) (T_IS_IDENTICAL 27210) (T_IS_NOT_EQUAL 27211) (T_IS_NOT_IDENTICAL 27212) (T_IS_SMALLER_OR_EQUAL 27213) (T_LOGICAL_AND 27214) (T_LOGICAL_OR 27215) (T_LOGICAL_XOR 27216) (T_POW 27217) (T_SL 27218) (T_SPACESHIP 27219) (T_SR 27220) ("^" 27221) ("|" 27222)) 13206 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27536) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13207 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 27545) (T_VARIABLE 2900) (encaps_var 2914)) 13208 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 27544) (T_VARIABLE 2900) (encaps_var 2905)) 13209 ((T_CLASS 27565)) 13210 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 27564) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 27552) (attribute 2980) (class_modifier 2945)) 13211 (("(" 27555) (argument_list 27556) (ctor_arguments 27557)) 13212 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 27558) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 27559) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 27560) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 13213 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 27563) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 13214 (("," 1469) (possible_comma 27561)) 13215 ((")" 27562)) 13216 (("(" 2982) (argument_list 2983) (ctor_arguments 27566)) 13217 ((T_EXTENDS 2985) (extends_from 27567)) 13218 ((T_IMPLEMENTS 2987) (implements_list 27568)) 13219 ((backup_doc_comment 27569)) 13220 (("{" 27570)) 13221 ((class_statement_list 27571)) 13222 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 27572)) 13223 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 27574) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 13224 (("%" 292) (")" 27575) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 13225 (("{" 27576)) 13226 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 27577) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 13227 (("}" 27578)) 13228 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 27580) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 13229 ((")" 27581)) 13230 (("=" 27582)) 13231 (("!" 27115) ("\"" 27116) ("$" 27117) ("(" 27118) ("+" 27119) ("-" 27120) ("@" 27121) (T_ARRAY 27122) (T_ARRAY_CAST 27123) (T_ATTRIBUTE 126) (T_BOOL_CAST 27124) (T_CLASS_C 27125) (T_CLONE 27126) (T_CONSTANT_ENCAPSED_STRING 27127) (T_DEC 27128) (T_DIR 27129) (T_DNUMBER 27130) (T_DOUBLE_CAST 27131) (T_EMPTY 27132) (T_EVAL 27133) (T_EXIT 27134) (T_FILE 27135) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 27136) (T_INC 27137) (T_INCLUDE 27138) (T_INCLUDE_ONCE 27139) (T_INT_CAST 27140) (T_ISSET 27141) (T_LINE 27142) (T_LIST 27143) (T_LNUMBER 27144) (T_MATCH 27145) (T_METHOD_C 27146) (T_NAME_FULLY_QUALIFIED 27147) (T_NAME_QUALIFIED 27148) (T_NAME_RELATIVE 27149) (T_NEW 27150) (T_NS_C 27151) (T_OBJECT_CAST 27152) (T_PRINT 27153) (T_READONLY 27154) (T_REQUIRE 27155) (T_REQUIRE_ONCE 27156) (T_START_HEREDOC 27157) (T_STATIC 27158) (T_STRING 27159) (T_STRING_CAST 27160) (T_THROW 27161) (T_TRAIT_C 27162) (T_UNSET_CAST 27163) (T_VARIABLE 27164) (T_YIELD 27165) (T_YIELD_FROM 27166) ("[" 27167) ("`" 27168) (array_object_dereferenceable 27169) (attribute 131) (attributes 27170) (callable_expr 27171) (callable_variable 27172) (class_constant 27173) (class_name 27174) (constant 27175) (dereferenceable_scalar 27176) (expr 27583) (fn 27178) (fully_dereferenceable 104) #'27179 (function_call 27180) (inline_function 27181) (internal_functions_in_yacc 27182) (match 27183) (name 27184) (new_expr 27185) (scalar 27186) (simple_variable 27187) (static_member 27188) (variable 27189) (variable_class_name 27190) ("~" 27191)) 13232 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 27585) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 13233 (("," 5258) (possible_comma 27586)) 13234 ((")" 27587)) 13235 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 27594) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 13236 ((")" 27595)) 13237 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 27597) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 13238 (("%" 292) (")" 27598) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 13239 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 27600) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 13240 (("%" 292) (")" 27601) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 13241 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 27608) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 13242 ((")" 27609)) 13243 (("%" 292) (")" 27614) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 13244 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 27617) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 13245 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 27618)) 13246 (("\"" 27620) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302)) 13247 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 27623) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 13248 (("%" 292) (")" 27624) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 13249 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 27625) (";" 8) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 15) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 21) (T_DEC 22) (T_DECLARE 23) (T_DIR 24) (T_DNUMBER 25) (T_DO 26) (T_DOUBLE_CAST 27) (T_ECHO 28) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 36) (T_FOREACH 37) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 40) (T_GOTO 41) (T_IF 43) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 47) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 67) (T_START_HEREDOC 68) (T_STATIC 69) (T_STRING 70) (T_STRING_CAST 71) (T_SWITCH 72) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 76) (T_UNSET 77) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 81) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 86) (alt_if_stmt_without_else 87) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 102) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 108) (if_stmt_without_else 109) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 27626) (static_member 119) (variable 122) (variable_class_name 123) (while_statement 27627) ("{" 124) ("~" 125)) 13250 ((inner_statement_list 27628)) 13251 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16379) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16380) (T_CLASS 16381) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16382) (T_DEC 22) (T_DECLARE 16383) (T_DIR 24) (T_DNUMBER 25) (T_DO 16384) (T_DOUBLE_CAST 27) (T_ECHO 16385) (T_EMPTY 29) (T_ENDWHILE 27629) (T_ENUM 16387) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16388) (T_FOREACH 16389) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16390) (T_GOTO 16391) (T_HALT_COMPILER 16392) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16394) (T_INTERFACE 16395) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16396) (T_START_HEREDOC 68) (T_STATIC 16397) (T_STRING 16398) (T_STRING_CAST 71) (T_SWITCH 16399) (T_THROW 73) (T_TRAIT 16400) (T_TRAIT_C 75) (T_TRY 16401) (T_UNSET 16402) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16403) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16404) (alt_if_stmt_without_else 16405) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16406) (attributes 16407) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16408) (class_modifier 96) (class_modifiers 16409) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16410) (expr 16411) (fn 103) (fully_dereferenceable 104) #'16412 (function_call 106) (function_declaration_statement 16413) (if_stmt 16414) (if_stmt_without_else 16415) (inline_function 110) (inner_statement 16416) (interface_declaration_statement 16417) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16418) (static_member 119) (trait_declaration_statement 16419) (variable 122) (variable_class_name 123) ("{" 16420) ("~" 125)) 13252 ((";" 27630)) 13253 ((T_AS 27653) (T_NS_SEPARATOR 27671)) 13254 ((";" 27670)) 13255 (("," 27645) (";" 27669)) 13256 ((T_NAME_FULLY_QUALIFIED 27633) (T_NAME_QUALIFIED 27634) (T_STRING 27635) (group_use_declaration 27642) (legacy_namespace_name 27643) (namespace_name 27638) (use_declaration 27639) (use_declarations 27644)) 13257 ((";" 27668)) 13258 ((T_AS 27653) (T_NS_SEPARATOR 27655)) 13259 (("," 27645) (";" 27646)) 13260 ((T_NAME_FULLY_QUALIFIED 27647) (T_NAME_QUALIFIED 27648) (T_STRING 27649) (legacy_namespace_name 27650) (namespace_name 27651) (use_declaration 27652)) 13261 ((T_AS 27653)) 13262 ((T_STRING 27654)) 13263 (("{" 27656)) 13264 ((T_NAME_QUALIFIED 27657) (T_STRING 27658) (namespace_name 27659) (unprefixed_use_declaration 27660) (unprefixed_use_declarations 27661)) 13265 ((T_AS 27666)) 13266 (("," 27662) (possible_comma 27663)) 13267 ((T_NAME_QUALIFIED 27657) (T_STRING 27658) (namespace_name 27659) (unprefixed_use_declaration 27665)) 13268 (("}" 27664)) 13269 ((T_STRING 27667)) 13270 (("{" 27672)) 13271 ((T_CONST 27673) (T_FUNCTION 27674) (T_NAME_QUALIFIED 27657) (T_STRING 27658) (inline_use_declaration 27675) (inline_use_declarations 27676) (namespace_name 27659) (unprefixed_use_declaration 27677) (use_type 27678)) 13272 (("," 27680) (possible_comma 27681)) 13273 ((T_NAME_QUALIFIED 27657) (T_STRING 27658) (namespace_name 27659) (unprefixed_use_declaration 27679)) 13274 ((T_CONST 27673) (T_FUNCTION 27674) (T_NAME_QUALIFIED 27657) (T_STRING 27658) (inline_use_declaration 27683) (namespace_name 27659) (unprefixed_use_declaration 27677) (use_type 27678)) 13275 (("}" 27682)) 13276 (("\"" 1509) ("$" 16475) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 16476) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 16477) ("[" 1529) (array_object_dereferenceable 16478) (callable_expr 16479) (callable_variable 16480) (class_constant 1533) (class_name 16481) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 16482) (name 16483) (simple_variable 16484) (static_member 16485) (unset_variable 16486) (unset_variables 27686) (variable 16488) (variable_class_name 16489)) 13277 (("," 16501) (possible_comma 27687)) 13278 ((")" 27688)) 13279 ((";" 27689)) 13280 ((inner_statement_list 27691)) 13281 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 27692) ("~" 125)) 13282 ((catch_list 27693)) 13283 ((T_CATCH 27694) (T_FINALLY 27695) (finally_statement 27696)) 13284 (("(" 27700)) 13285 (("{" 27697)) 13286 ((inner_statement_list 27698)) 13287 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 27699) ("~" 125)) 13288 ((T_NAME_FULLY_QUALIFIED 16545) (T_NAME_QUALIFIED 16546) (T_NAME_RELATIVE 16547) (T_STATIC 16548) (T_STRING 16549) (catch_name_list 27701) (class_name 16551) (name 16552)) 13289 ((T_VARIABLE 16553) (optional_variable 27702) ("|" 16555)) 13290 ((")" 27703)) 13291 (("{" 27704)) 13292 ((inner_statement_list 27705)) 13293 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 27706) ("~" 125)) 13294 ((backup_doc_comment 27708)) 13295 (("{" 27709)) 13296 ((class_statement_list 27710)) 13297 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 27711)) 13298 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 27714) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 13299 (("%" 292) (")" 27715) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 13300 ((":" 27716) (switch_case_list 27717) ("{" 27718)) 13301 ((";" 27724) (case_list 27725)) 13302 ((";" 27719) (case_list 27720)) 13303 ((case_list 27722)) 13304 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 27721)) 13305 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 27723)) 13306 ((case_list 27728)) 13307 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 27726)) 13308 ((";" 27727)) 13309 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 27729)) 13310 ((";" 27730)) 13311 (("," 16852) (";" 27734)) 13312 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_END_HEREDOC 27739) (T_VARIABLE 2900) (encaps_var 2914)) 13313 ((T_CURLY_OPEN 2896) (T_DOLLAR_OPEN_CURLY_BRACES 2897) (T_ENCAPSED_AND_WHITESPACE 2903) (T_END_HEREDOC 27738) (T_VARIABLE 2900) (encaps_var 2905)) 13314 ((";" 27741)) 13315 ((T_CLASS 27760)) 13316 ((T_ABSTRACT 10) (T_ATTRIBUTE 2932) (T_FINAL 34) (T_READONLY 2936) (anonymous_class 27759) (anonymous_class_modifiers 2941) (anonymous_class_modifiers_optional 27747) (attribute 2980) (class_modifier 2945)) 13317 (("(" 27750) (argument_list 27751) (ctor_arguments 27752)) 13318 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 27753) ("+" 939) ("-" 940) ("@" 941) (T_ABSTRACT 942) (T_ARRAY 943) (T_ARRAY_CAST 944) (T_AS 945) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_BREAK 947) (T_CALLABLE 948) (T_CASE 949) (T_CATCH 950) (T_CLASS 951) (T_CLASS_C 952) (T_CLONE 953) (T_CONST 954) (T_CONSTANT_ENCAPSED_STRING 955) (T_CONTINUE 956) (T_DEC 957) (T_DECLARE 958) (T_DEFAULT 959) (T_DIR 960) (T_DNUMBER 961) (T_DO 962) (T_DOUBLE_CAST 963) (T_ECHO 964) (T_ELLIPSIS 27754) (T_ELSE 966) (T_ELSEIF 967) (T_EMPTY 968) (T_ENDDECLARE 969) (T_ENDFOR 970) (T_ENDFOREACH 971) (T_ENDIF 972) (T_ENDSWITCH 973) (T_ENDWHILE 974) (T_ENUM 975) (T_EVAL 976) (T_EXIT 977) (T_EXTENDS 978) (T_FILE 979) (T_FINAL 980) (T_FINALLY 981) (T_FN 982) (T_FOR 983) (T_FOREACH 984) (T_FUNCTION 985) (T_FUNC_C 986) (T_GLOBAL 987) (T_GOTO 988) (T_IF 989) (T_IMPLEMENTS 990) (T_INC 991) (T_INCLUDE 992) (T_INCLUDE_ONCE 993) (T_INSTANCEOF 994) (T_INSTEADOF 995) (T_INTERFACE 996) (T_INT_CAST 997) (T_ISSET 998) (T_LINE 999) (T_LIST 1000) (T_LNUMBER 1001) (T_LOGICAL_AND 1002) (T_LOGICAL_OR 1003) (T_LOGICAL_XOR 1004) (T_MATCH 1005) (T_METHOD_C 1006) (T_NAMESPACE 1007) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1011) (T_NS_C 1012) (T_OBJECT_CAST 1013) (T_PRINT 1014) (T_PRIVATE 1015) (T_PROTECTED 1016) (T_PUBLIC 1017) (T_READONLY 1018) (T_REQUIRE 1019) (T_REQUIRE_ONCE 1020) (T_RETURN 1021) (T_START_HEREDOC 1022) (T_STATIC 1023) (T_STRING 1024) (T_STRING_CAST 1025) (T_SWITCH 1026) (T_THROW 1027) (T_TRAIT 1028) (T_TRAIT_C 1029) (T_TRY 1030) (T_UNSET 1031) (T_UNSET_CAST 1032) (T_USE 1033) (T_VAR 1034) (T_VARIABLE 1035) (T_WHILE 1036) (T_YIELD 1037) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (argument 1041) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1050) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (identifier 1054) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (non_empty_argument_list 27755) (reserved_non_modifiers 1061) (scalar 1062) (semi_reserved 1063) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 13319 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) (")" 27758) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 1474) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 13320 (("," 1469) (possible_comma 27756)) 13321 ((")" 27757)) 13322 (("(" 2982) (argument_list 2983) (ctor_arguments 27761)) 13323 ((T_EXTENDS 2985) (extends_from 27762)) 13324 ((T_IMPLEMENTS 2987) (implements_list 27763)) 13325 ((backup_doc_comment 27764)) 13326 (("{" 27765)) 13327 ((class_statement_list 27766)) 13328 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 27767)) 13329 ((";" 28244) ("{" 28245)) 13330 ((top_statement_list 27852)) 13331 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 27853) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 27854) (T_CLASS 27855) (T_CLASS_C 17) (T_CLONE 18) (T_CONST 27856) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 27857) (T_DEC 22) (T_DECLARE 27858) (T_DIR 24) (T_DNUMBER 25) (T_DO 27859) (T_DOUBLE_CAST 27) (T_ECHO 27860) (T_EMPTY 29) (T_ENUM 27861) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 27862) (T_FOREACH 27863) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 27864) (T_GOTO 27865) (T_HALT_COMPILER 27866) (T_IF 27867) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 27868) (T_INTERFACE 27869) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAMESPACE 27870) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 27871) (T_START_HEREDOC 68) (T_STATIC 27872) (T_STRING 27873) (T_STRING_CAST 71) (T_SWITCH 27874) (T_THROW 73) (T_TRAIT 27875) (T_TRAIT_C 75) (T_TRY 27876) (T_UNSET 27877) (T_UNSET_CAST 78) (T_USE 27878) (T_VARIABLE 80) (T_WHILE 27879) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 27880) (alt_if_stmt_without_else 27881) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 27882) (attributes 27883) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 27884) (class_modifier 96) (class_modifiers 27885) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 27886) (expr 27887) (fn 103) (fully_dereferenceable 104) #'27888 (function_call 106) (function_declaration_statement 27889) (if_stmt 27890) (if_stmt_without_else 27891) (inline_function 110) (interface_declaration_statement 27892) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 27893) (static_member 119) (top_statement 27894) (trait_declaration_statement 27895) (variable 122) (variable_class_name 123) ("{" 27896) ("}" 27897) ("~" 125)) 13332 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 28242) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 13333 ((T_STRING 28235)) 13334 ((T_STRING 28226) (const_decl 28227) (const_list 28228)) 13335 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 28224) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 13336 (("(" 28215)) 13337 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19746) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19747) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19748) (T_DEC 22) (T_DECLARE 19749) (T_DIR 24) (T_DNUMBER 25) (T_DO 19750) (T_DOUBLE_CAST 27) (T_ECHO 19751) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19752) (T_FOREACH 19753) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19754) (T_GOTO 19755) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19757) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19758) (T_START_HEREDOC 68) (T_STATIC 19759) (T_STRING 19760) (T_STRING_CAST 71) (T_SWITCH 19761) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19762) (T_UNSET 19763) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19764) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19765) (alt_if_stmt_without_else 19766) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19767) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19768) (if_stmt_without_else 19769) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 28209) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19771) ("~" 125)) 13338 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (echo_expr 19740) (echo_expr_list 28207) (expr 19742) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 13339 ((T_STRING 28200)) 13340 (("(" 28187)) 13341 (("(" 28172)) 13342 (("$" 17870) (T_VARIABLE 17871) (global_var 17872) (global_var_list 28170) (simple_variable 17874)) 13343 ((T_STRING 28168)) 13344 (("(" 28165)) 13345 (("(" 28161)) 13346 ((T_STRING 28155)) 13347 ((T_ABSTRACT 27768) (T_ARRAY 27769) (T_AS 27770) (T_BREAK 27771) (T_CALLABLE 27772) (T_CASE 27773) (T_CATCH 27774) (T_CLASS 27775) (T_CLASS_C 27776) (T_CLONE 27777) (T_CONST 27778) (T_CONTINUE 27779) (T_DECLARE 27780) (T_DEFAULT 27781) (T_DIR 27782) (T_DO 27783) (T_ECHO 27784) (T_ELSE 27785) (T_ELSEIF 27786) (T_EMPTY 27787) (T_ENDDECLARE 27788) (T_ENDFOR 27789) (T_ENDFOREACH 27790) (T_ENDIF 27791) (T_ENDSWITCH 27792) (T_ENDWHILE 27793) (T_ENUM 27794) (T_EVAL 27795) (T_EXIT 27796) (T_EXTENDS 27797) (T_FILE 27798) (T_FINAL 27799) (T_FINALLY 27800) (T_FN 27801) (T_FOR 27802) (T_FOREACH 27803) (T_FUNCTION 27804) (T_FUNC_C 27805) (T_GLOBAL 27806) (T_GOTO 27807) (T_IF 27808) (T_IMPLEMENTS 27809) (T_INCLUDE 27810) (T_INCLUDE_ONCE 27811) (T_INSTANCEOF 27812) (T_INSTEADOF 27813) (T_INTERFACE 27814) (T_ISSET 27815) (T_LINE 27816) (T_LIST 27817) (T_LOGICAL_AND 27818) (T_LOGICAL_OR 27819) (T_LOGICAL_XOR 27820) (T_MATCH 27821) (T_METHOD_C 27822) (T_NAMESPACE 27823) (T_NAME_QUALIFIED 27824) (T_NEW 27825) (T_NS_C 27826) (T_PRINT 27827) (T_PRIVATE 27828) (T_PROTECTED 27829) (T_PUBLIC 27830) (T_READONLY 27831) (T_REQUIRE 27832) (T_REQUIRE_ONCE 27833) (T_RETURN 27834) (T_STATIC 27835) (T_STRING 27836) (T_SWITCH 27837) (T_THROW 27838) (T_TRAIT 27839) (T_TRAIT_C 27840) (T_TRY 27841) (T_UNSET 27842) (T_USE 27843) (T_VAR 27844) (T_WHILE 27845) (T_YIELD 27846) (identifier 27847) (namespace_declaration_name 28147) (reserved_non_modifiers 27849) (semi_reserved 27850) ("{" 28148)) 13348 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 28145) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 13349 ((T_FN 35) (T_FUNCTION 127) (T_VARIABLE 16848) (fn 103) #'134 (inline_function 16849) (static_var 16850) (static_var_list 28143)) 13350 ((":" 28142)) 13351 (("(" 28124)) 13352 ((T_STRING 28119)) 13353 (("{" 28102)) 13354 (("(" 28097)) 13355 ((T_CONST 27631) (T_FUNCTION 27632) (T_NAME_FULLY_QUALIFIED 27633) (T_NAME_QUALIFIED 27634) (T_STRING 27635) (legacy_namespace_name 27636) (mixed_group_use_declaration 28088) (namespace_name 27638) (use_declaration 27639) (use_declarations 28089) (use_type 28090)) 13356 (("(" 28079)) 13357 ((T_ELSE 28072) (T_ELSEIF 16203) (T_ENDIF 28073)) 13358 ((T_ABSTRACT 10) (T_ATTRIBUTE 13) (T_CLASS 27855) (T_ENUM 27861) (T_FINAL 34) (T_FN 35) (T_FUNCTION 38) (T_INTERFACE 27869) (T_READONLY 2936) (T_STATIC 16288) (T_TRAIT 27875) (attribute 16289) (attributed_statement 28071) (class_declaration_statement 27884) (class_modifier 96) (class_modifiers 27885) (enum_declaration_statement 27886) (fn 103) #'27888 (function_declaration_statement 27889) (inline_function 16291) (interface_declaration_statement 27892) (trait_declaration_statement 27895)) 13359 ((T_ABSTRACT 10) (T_CLASS 28063) (T_FINAL 34) (T_READONLY 2936) (class_modifier 16280)) 13360 (("%" 6465) ("*" 6466) ("+" 6467) ("-" 6468) ("." 6469) ("/" 6470) (";" 28062) ("<" 6471) (">" 6472) ("?" 6473) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 6474) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 6475) (T_BOOLEAN_AND 6476) (T_BOOLEAN_OR 6477) (T_COALESCE 6478) (T_INSTANCEOF 6479) (T_IS_EQUAL 6480) (T_IS_GREATER_OR_EQUAL 6481) (T_IS_IDENTICAL 6482) (T_IS_NOT_EQUAL 6483) (T_IS_NOT_IDENTICAL 6484) (T_IS_SMALLER_OR_EQUAL 6485) (T_LOGICAL_AND 6486) (T_LOGICAL_OR 6487) (T_LOGICAL_XOR 6488) (T_POW 6489) (T_SL 6490) (T_SPACESHIP 6491) (T_SR 6492) ("^" 6493) ("|" 6494)) 13361 ((T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 16261) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 16262) (ampersand 16263) (returns_ref 28050)) 13362 ((T_ELSE 27900) (T_ELSEIF 27901)) 13363 ((inner_statement_list 27898)) 13364 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 27899) ("~" 125)) 13365 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 27853) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 27854) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 27857) (T_DEC 22) (T_DECLARE 27858) (T_DIR 24) (T_DNUMBER 25) (T_DO 27859) (T_DOUBLE_CAST 27) (T_ECHO 27860) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 27862) (T_FOREACH 27863) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 27864) (T_GOTO 27865) (T_IF 27867) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 27868) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 27871) (T_START_HEREDOC 68) (T_STATIC 27872) (T_STRING 27873) (T_STRING_CAST 71) (T_SWITCH 27874) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 27876) (T_UNSET 27877) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 27879) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 27880) (alt_if_stmt_without_else 27881) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 27887) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 27890) (if_stmt_without_else 27891) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 28049) (static_member 119) (variable 122) (variable_class_name 123) ("{" 27896) ("~" 125)) 13366 (("(" 27902)) 13367 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 27903) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 13368 (("%" 292) (")" 27904) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 13369 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 27905) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 27906) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 27907) (T_DEC 22) (T_DECLARE 27908) (T_DIR 24) (T_DNUMBER 25) (T_DO 27909) (T_DOUBLE_CAST 27) (T_ECHO 27910) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 27911) (T_FOREACH 27912) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 27913) (T_GOTO 27914) (T_IF 27867) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 27915) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 27916) (T_START_HEREDOC 68) (T_STATIC 27917) (T_STRING 27918) (T_STRING_CAST 71) (T_SWITCH 27919) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 27920) (T_UNSET 27921) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 27922) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 27923) (alt_if_stmt_without_else 27924) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 27925) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 27926) (if_stmt_without_else 27927) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 27928) (static_member 119) (variable 122) (variable_class_name 123) ("{" 27929) ("~" 125)) 13370 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 28047) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 13371 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 28045) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 13372 (("(" 28036)) 13373 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19746) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19747) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19748) (T_DEC 22) (T_DECLARE 19749) (T_DIR 24) (T_DNUMBER 25) (T_DO 19750) (T_DOUBLE_CAST 27) (T_ECHO 19751) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19752) (T_FOREACH 19753) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19754) (T_GOTO 19755) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19757) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19758) (T_START_HEREDOC 68) (T_STATIC 19759) (T_STRING 19760) (T_STRING_CAST 71) (T_SWITCH 19761) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19762) (T_UNSET 19763) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19764) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19765) (alt_if_stmt_without_else 19766) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19767) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19768) (if_stmt_without_else 19769) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 28030) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19771) ("~" 125)) 13374 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (echo_expr 19740) (echo_expr_list 28028) (expr 19742) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 13375 (("(" 28015)) 13376 (("(" 28000)) 13377 (("$" 17870) (T_VARIABLE 17871) (global_var 17872) (global_var_list 27998) (simple_variable 17874)) 13378 ((T_STRING 27996)) 13379 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 27994) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 13380 ((T_FN 35) (T_FUNCTION 127) (T_VARIABLE 16848) (fn 103) #'134 (inline_function 16849) (static_var 16850) (static_var_list 27992)) 13381 ((":" 27991)) 13382 (("(" 27973)) 13383 (("{" 27956)) 13384 (("(" 27951)) 13385 (("(" 27942)) 13386 ((T_ELSE 27935) (T_ELSEIF 16203) (T_ENDIF 27936)) 13387 (("%" 6465) ("*" 6466) ("+" 6467) ("-" 6468) ("." 6469) ("/" 6470) (";" 27934) ("<" 6471) (">" 6472) ("?" 6473) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 6474) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 6475) (T_BOOLEAN_AND 6476) (T_BOOLEAN_OR 6477) (T_COALESCE 6478) (T_INSTANCEOF 6479) (T_IS_EQUAL 6480) (T_IS_GREATER_OR_EQUAL 6481) (T_IS_IDENTICAL 6482) (T_IS_NOT_EQUAL 6483) (T_IS_NOT_IDENTICAL 6484) (T_IS_SMALLER_OR_EQUAL 6485) (T_LOGICAL_AND 6486) (T_LOGICAL_OR 6487) (T_LOGICAL_XOR 6488) (T_POW 6489) (T_SL 6490) (T_SPACESHIP 6491) (T_SR 6492) ("^" 6493) ("|" 6494)) 13388 ((T_ELSE 27932) (T_ELSEIF 27901)) 13389 ((inner_statement_list 27930)) 13390 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 27931) ("~" 125)) 13391 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 27905) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 27906) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 27907) (T_DEC 22) (T_DECLARE 27908) (T_DIR 24) (T_DNUMBER 25) (T_DO 27909) (T_DOUBLE_CAST 27) (T_ECHO 27910) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 27911) (T_FOREACH 27912) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 27913) (T_GOTO 27914) (T_IF 27867) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 27915) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 27916) (T_START_HEREDOC 68) (T_STATIC 27917) (T_STRING 27918) (T_STRING_CAST 71) (T_SWITCH 27919) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 27920) (T_UNSET 27921) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 27922) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 27923) (alt_if_stmt_without_else 27924) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 27925) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 27926) (if_stmt_without_else 27927) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 27933) (static_member 119) (variable 122) (variable_class_name 123) ("{" 27929) ("~" 125)) 13392 ((":" 27938)) 13393 ((";" 27937)) 13394 ((inner_statement_list 27939)) 13395 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16298) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16299) (T_CLASS 16300) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16301) (T_DEC 22) (T_DECLARE 16302) (T_DIR 24) (T_DNUMBER 25) (T_DO 16303) (T_DOUBLE_CAST 27) (T_ECHO 16304) (T_EMPTY 29) (T_ENDIF 27940) (T_ENUM 16306) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16307) (T_FOREACH 16308) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16309) (T_GOTO 16310) (T_HALT_COMPILER 16311) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16312) (T_INTERFACE 16313) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16314) (T_START_HEREDOC 68) (T_STATIC 16315) (T_STRING 16316) (T_STRING_CAST 71) (T_SWITCH 16317) (T_THROW 73) (T_TRAIT 16318) (T_TRAIT_C 75) (T_TRY 16319) (T_UNSET 16320) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16321) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16322) (alt_if_stmt_without_else 16323) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16324) (attributes 16325) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16326) (class_modifier 96) (class_modifiers 16327) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16328) (expr 16329) (fn 103) (fully_dereferenceable 104) #'16330 (function_call 106) (function_declaration_statement 16331) (if_stmt 16332) (if_stmt_without_else 16333) (inline_function 110) (inner_statement 16334) (interface_declaration_statement 16335) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16336) (static_member 119) (trait_declaration_statement 16337) (variable 122) (variable_class_name 123) ("{" 16338) ("~" 125)) 13396 ((";" 27941)) 13397 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 27943) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 13398 (("%" 292) (")" 27944) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 13399 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 27945) (";" 27905) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 27906) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 27907) (T_DEC 22) (T_DECLARE 27908) (T_DIR 24) (T_DNUMBER 25) (T_DO 27909) (T_DOUBLE_CAST 27) (T_ECHO 27910) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 27911) (T_FOREACH 27912) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 27913) (T_GOTO 27914) (T_IF 27867) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 27915) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 27916) (T_START_HEREDOC 68) (T_STATIC 27917) (T_STRING 27918) (T_STRING_CAST 71) (T_SWITCH 27919) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 27920) (T_UNSET 27921) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 27922) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 27923) (alt_if_stmt_without_else 27924) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 27925) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 27926) (if_stmt_without_else 27927) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 27946) (static_member 119) (variable 122) (variable_class_name 123) (while_statement 27947) ("{" 27929) ("~" 125)) 13400 ((inner_statement_list 27948)) 13401 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16379) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16380) (T_CLASS 16381) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16382) (T_DEC 22) (T_DECLARE 16383) (T_DIR 24) (T_DNUMBER 25) (T_DO 16384) (T_DOUBLE_CAST 27) (T_ECHO 16385) (T_EMPTY 29) (T_ENDWHILE 27949) (T_ENUM 16387) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16388) (T_FOREACH 16389) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16390) (T_GOTO 16391) (T_HALT_COMPILER 16392) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16394) (T_INTERFACE 16395) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16396) (T_START_HEREDOC 68) (T_STATIC 16397) (T_STRING 16398) (T_STRING_CAST 71) (T_SWITCH 16399) (T_THROW 73) (T_TRAIT 16400) (T_TRAIT_C 75) (T_TRY 16401) (T_UNSET 16402) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16403) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16404) (alt_if_stmt_without_else 16405) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16406) (attributes 16407) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16408) (class_modifier 96) (class_modifiers 16409) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16410) (expr 16411) (fn 103) (fully_dereferenceable 104) #'16412 (function_call 106) (function_declaration_statement 16413) (if_stmt 16414) (if_stmt_without_else 16415) (inline_function 110) (inner_statement 16416) (interface_declaration_statement 16417) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16418) (static_member 119) (trait_declaration_statement 16419) (variable 122) (variable_class_name 123) ("{" 16420) ("~" 125)) 13402 ((";" 27950)) 13403 (("\"" 1509) ("$" 16475) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 16476) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 16477) ("[" 1529) (array_object_dereferenceable 16478) (callable_expr 16479) (callable_variable 16480) (class_constant 1533) (class_name 16481) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 16482) (name 16483) (simple_variable 16484) (static_member 16485) (unset_variable 16486) (unset_variables 27952) (variable 16488) (variable_class_name 16489)) 13404 (("," 16501) (possible_comma 27953)) 13405 ((")" 27954)) 13406 ((";" 27955)) 13407 ((inner_statement_list 27957)) 13408 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 27958) ("~" 125)) 13409 ((catch_list 27959)) 13410 ((T_CATCH 27960) (T_FINALLY 27961) (finally_statement 27962)) 13411 (("(" 27966)) 13412 (("{" 27963)) 13413 ((inner_statement_list 27964)) 13414 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 27965) ("~" 125)) 13415 ((T_NAME_FULLY_QUALIFIED 16545) (T_NAME_QUALIFIED 16546) (T_NAME_RELATIVE 16547) (T_STATIC 16548) (T_STRING 16549) (catch_name_list 27967) (class_name 16551) (name 16552)) 13416 ((T_VARIABLE 16553) (optional_variable 27968) ("|" 16555)) 13417 ((")" 27969)) 13418 (("{" 27970)) 13419 ((inner_statement_list 27971)) 13420 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 27972) ("~" 125)) 13421 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 27974) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 13422 (("%" 292) (")" 27975) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 13423 ((":" 27976) (switch_case_list 27977) ("{" 27978)) 13424 ((";" 27984) (case_list 27985)) 13425 ((";" 27979) (case_list 27980)) 13426 ((case_list 27982)) 13427 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 27981)) 13428 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 27983)) 13429 ((case_list 27988)) 13430 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 27986)) 13431 ((";" 27987)) 13432 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 27989)) 13433 ((";" 27990)) 13434 (("," 16852) (";" 27993)) 13435 ((";" 27995)) 13436 ((";" 27997)) 13437 (("," 17875) (";" 27999)) 13438 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 28001) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 13439 (("%" 17961) ("*" 17962) ("+" 17963) ("-" 17964) ("." 17965) ("/" 17966) ("<" 17967) (">" 17968) ("?" 17969) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 17970) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 17971) (T_AS 28002) (T_BOOLEAN_AND 17972) (T_BOOLEAN_OR 17973) (T_COALESCE 17974) (T_INSTANCEOF 17975) (T_IS_EQUAL 17976) (T_IS_GREATER_OR_EQUAL 17977) (T_IS_IDENTICAL 17978) (T_IS_NOT_EQUAL 17979) (T_IS_NOT_IDENTICAL 17980) (T_IS_SMALLER_OR_EQUAL 17981) (T_LOGICAL_AND 17982) (T_LOGICAL_OR 17983) (T_LOGICAL_XOR 17984) (T_POW 17985) (T_SL 17986) (T_SPACESHIP 17987) (T_SR 17988) ("^" 17989) ("|" 17990)) 13440 (("\"" 1509) ("$" 19325) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19326) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19327) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19328) ("[" 19329) (ampersand 19330) (array_object_dereferenceable 19331) (callable_expr 19332) (callable_variable 19333) (class_constant 1533) (class_name 19334) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 28003) (fully_dereferenceable 104) (function_call 19336) (name 19337) (simple_variable 19338) (static_member 19339) (variable 19340) (variable_class_name 19341)) 13441 ((")" 28004) (T_DOUBLE_ARROW 28005)) 13442 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 28008) (";" 27905) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 27906) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 27907) (T_DEC 22) (T_DECLARE 27908) (T_DIR 24) (T_DNUMBER 25) (T_DO 27909) (T_DOUBLE_CAST 27) (T_ECHO 27910) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 27911) (T_FOREACH 27912) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 27913) (T_GOTO 27914) (T_IF 27867) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 27915) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 27916) (T_START_HEREDOC 68) (T_STATIC 27917) (T_STRING 27918) (T_STRING_CAST 71) (T_SWITCH 27919) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 27920) (T_UNSET 27921) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 27922) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 27923) (alt_if_stmt_without_else 27924) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 27925) (fn 103) (foreach_statement 28014) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 27926) (if_stmt_without_else 27927) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 28010) (static_member 119) (variable 122) (variable_class_name 123) ("{" 27929) ("~" 125)) 13443 (("\"" 1509) ("$" 19356) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19357) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19358) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19359) ("[" 19360) (ampersand 19361) (array_object_dereferenceable 19362) (callable_expr 19363) (callable_variable 19364) (class_constant 1533) (class_name 19365) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 28006) (fully_dereferenceable 104) (function_call 19367) (name 19368) (simple_variable 19369) (static_member 19370) (variable 19371) (variable_class_name 19372)) 13444 ((")" 28007)) 13445 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 28008) (";" 27905) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 27906) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 27907) (T_DEC 22) (T_DECLARE 27908) (T_DIR 24) (T_DNUMBER 25) (T_DO 27909) (T_DOUBLE_CAST 27) (T_ECHO 27910) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 27911) (T_FOREACH 27912) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 27913) (T_GOTO 27914) (T_IF 27867) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 27915) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 27916) (T_START_HEREDOC 68) (T_STATIC 27917) (T_STRING 27918) (T_STRING_CAST 71) (T_SWITCH 27919) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 27920) (T_UNSET 27921) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 27922) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 27923) (alt_if_stmt_without_else 27924) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 27925) (fn 103) (foreach_statement 28009) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 27926) (if_stmt_without_else 27927) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 28010) (static_member 119) (variable 122) (variable_class_name 123) ("{" 27929) ("~" 125)) 13446 ((inner_statement_list 28011)) 13447 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19390) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19391) (T_CLASS 19392) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19393) (T_DEC 22) (T_DECLARE 19394) (T_DIR 24) (T_DNUMBER 25) (T_DO 19395) (T_DOUBLE_CAST 27) (T_ECHO 19396) (T_EMPTY 29) (T_ENDFOREACH 28012) (T_ENUM 19398) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19399) (T_FOREACH 19400) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19401) (T_GOTO 19402) (T_HALT_COMPILER 19403) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19405) (T_INTERFACE 19406) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19407) (T_START_HEREDOC 68) (T_STATIC 19408) (T_STRING 19409) (T_STRING_CAST 71) (T_SWITCH 19410) (T_THROW 73) (T_TRAIT 19411) (T_TRAIT_C 75) (T_TRY 19412) (T_UNSET 19413) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19414) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19415) (alt_if_stmt_without_else 19416) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19417) (attributes 19418) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19419) (class_modifier 96) (class_modifiers 19420) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19421) (expr 19422) (fn 103) (fully_dereferenceable 104) #'19423 (function_call 106) (function_declaration_statement 19424) (if_stmt 19425) (if_stmt_without_else 19426) (inline_function 110) (inner_statement 19427) (interface_declaration_statement 19428) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19429) (static_member 119) (trait_declaration_statement 19430) (variable 122) (variable_class_name 123) ("{" 19431) ("~" 125)) 13448 ((";" 28013)) 13449 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 28016) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 13450 ((";" 28017)) 13451 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 28018) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 13452 ((";" 28019)) 13453 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 19558) (fn 2394) (for_exprs 28020) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (non_empty_for_exprs 19560) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 13454 ((")" 28021)) 13455 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 28022) (";" 27905) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 27906) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 27907) (T_DEC 22) (T_DECLARE 27908) (T_DIR 24) (T_DNUMBER 25) (T_DO 27909) (T_DOUBLE_CAST 27) (T_ECHO 27910) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 27911) (T_FOREACH 27912) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 27913) (T_GOTO 27914) (T_IF 27867) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 27915) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 27916) (T_START_HEREDOC 68) (T_STATIC 27917) (T_STRING 27918) (T_STRING_CAST 71) (T_SWITCH 27919) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 27920) (T_UNSET 27921) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 27922) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 27923) (alt_if_stmt_without_else 27924) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 27925) (fn 103) (for_statement 28023) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 27926) (if_stmt_without_else 27927) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 28024) (static_member 119) (variable 122) (variable_class_name 123) ("{" 27929) ("~" 125)) 13456 ((inner_statement_list 28025)) 13457 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19568) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19569) (T_CLASS 19570) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19571) (T_DEC 22) (T_DECLARE 19572) (T_DIR 24) (T_DNUMBER 25) (T_DO 19573) (T_DOUBLE_CAST 27) (T_ECHO 19574) (T_EMPTY 29) (T_ENDFOR 28026) (T_ENUM 19576) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19577) (T_FOREACH 19578) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19579) (T_GOTO 19580) (T_HALT_COMPILER 19581) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19583) (T_INTERFACE 19584) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19585) (T_START_HEREDOC 68) (T_STATIC 19586) (T_STRING 19587) (T_STRING_CAST 71) (T_SWITCH 19588) (T_THROW 73) (T_TRAIT 19589) (T_TRAIT_C 75) (T_TRY 19590) (T_UNSET 19591) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19592) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19593) (alt_if_stmt_without_else 19594) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19595) (attributes 19596) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19597) (class_modifier 96) (class_modifiers 19598) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19599) (expr 19600) (fn 103) (fully_dereferenceable 104) #'19601 (function_call 106) (function_declaration_statement 19602) (if_stmt 19603) (if_stmt_without_else 19604) (inline_function 110) (inner_statement 19605) (interface_declaration_statement 19606) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19607) (static_member 119) (trait_declaration_statement 19608) (variable 122) (variable_class_name 123) ("{" 19609) ("~" 125)) 13458 ((";" 28027)) 13459 (("," 19743) (";" 28029)) 13460 ((T_WHILE 28031)) 13461 (("(" 28032)) 13462 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 28033) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 13463 (("%" 292) (")" 28034) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 13464 ((";" 28035)) 13465 ((T_STRING 19916) (const_decl 19917) (const_list 28037)) 13466 ((")" 28038) ("," 19920)) 13467 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 28039) (";" 27905) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 27906) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 27907) (T_DEC 22) (T_DECLARE 27908) (T_DIR 24) (T_DNUMBER 25) (T_DO 27909) (T_DOUBLE_CAST 27) (T_ECHO 27910) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 27911) (T_FOREACH 27912) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 27913) (T_GOTO 27914) (T_IF 27867) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 27915) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 27916) (T_START_HEREDOC 68) (T_STATIC 27917) (T_STRING 27918) (T_STRING_CAST 71) (T_SWITCH 27919) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 27920) (T_UNSET 27921) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 27922) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 27923) (alt_if_stmt_without_else 27924) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (declare_statement 28040) (dereferenceable_scalar 100) (expr 27925) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 27926) (if_stmt_without_else 27927) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 28041) (static_member 119) (variable 122) (variable_class_name 123) ("{" 27929) ("~" 125)) 13468 ((inner_statement_list 28042)) 13469 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19926) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19927) (T_CLASS 19928) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19929) (T_DEC 22) (T_DECLARE 19930) (T_DIR 24) (T_DNUMBER 25) (T_DO 19931) (T_DOUBLE_CAST 27) (T_ECHO 19932) (T_EMPTY 29) (T_ENDDECLARE 28043) (T_ENUM 19934) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19935) (T_FOREACH 19936) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19937) (T_GOTO 19938) (T_HALT_COMPILER 19939) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19941) (T_INTERFACE 19942) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19943) (T_START_HEREDOC 68) (T_STATIC 19944) (T_STRING 19945) (T_STRING_CAST 71) (T_SWITCH 19946) (T_THROW 73) (T_TRAIT 19947) (T_TRAIT_C 75) (T_TRY 19948) (T_UNSET 19949) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19950) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19951) (alt_if_stmt_without_else 19952) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19953) (attributes 19954) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19955) (class_modifier 96) (class_modifiers 19956) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19957) (expr 19958) (fn 103) (fully_dereferenceable 104) #'19959 (function_call 106) (function_declaration_statement 19960) (if_stmt 19961) (if_stmt_without_else 19962) (inline_function 110) (inner_statement 19963) (interface_declaration_statement 19964) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19965) (static_member 119) (trait_declaration_statement 19966) (variable 122) (variable_class_name 123) ("{" 19967) ("~" 125)) 13470 ((";" 28044)) 13471 ((";" 28046)) 13472 ((";" 28048)) 13473 ((T_READONLY 16265) (T_STRING 16266) (backup_doc_comment 139) (function_name 28051)) 13474 ((backup_doc_comment 28052)) 13475 (("(" 28053)) 13476 ((T_ABSTRACT 141) (T_ATTRIBUTE 142) (T_FINAL 143) (T_PRIVATE 144) (T_PROTECTED 145) (T_PUBLIC 146) (T_READONLY 147) (T_STATIC 148) (attribute 149) (attributed_parameter 150) (attributes 151) (member_modifier 152) (non_empty_member_modifiers 153) (non_empty_parameter_list 154) (optional_cpp_modifiers 155) (parameter 156) (parameter_list 28054)) 13477 ((")" 28055)) 13478 ((":" 161) (return_type 28056)) 13479 ((backup_fn_flags 28057)) 13480 (("{" 28058)) 13481 ((inner_statement_list 28059)) 13482 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 28060) ("~" 125)) 13483 ((backup_fn_flags 28061)) 13484 ((T_STRING 28064)) 13485 ((T_EXTENDS 2985) (extends_from 28065)) 13486 ((T_IMPLEMENTS 2987) (implements_list 28066)) 13487 ((backup_doc_comment 28067)) 13488 (("{" 28068)) 13489 ((class_statement_list 28069)) 13490 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 28070)) 13491 ((":" 28075)) 13492 ((";" 28074)) 13493 ((inner_statement_list 28076)) 13494 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16298) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16299) (T_CLASS 16300) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16301) (T_DEC 22) (T_DECLARE 16302) (T_DIR 24) (T_DNUMBER 25) (T_DO 16303) (T_DOUBLE_CAST 27) (T_ECHO 16304) (T_EMPTY 29) (T_ENDIF 28077) (T_ENUM 16306) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16307) (T_FOREACH 16308) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16309) (T_GOTO 16310) (T_HALT_COMPILER 16311) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16312) (T_INTERFACE 16313) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16314) (T_START_HEREDOC 68) (T_STATIC 16315) (T_STRING 16316) (T_STRING_CAST 71) (T_SWITCH 16317) (T_THROW 73) (T_TRAIT 16318) (T_TRAIT_C 75) (T_TRY 16319) (T_UNSET 16320) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16321) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16322) (alt_if_stmt_without_else 16323) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16324) (attributes 16325) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16326) (class_modifier 96) (class_modifiers 16327) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16328) (expr 16329) (fn 103) (fully_dereferenceable 104) #'16330 (function_call 106) (function_declaration_statement 16331) (if_stmt 16332) (if_stmt_without_else 16333) (inline_function 110) (inner_statement 16334) (interface_declaration_statement 16335) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16336) (static_member 119) (trait_declaration_statement 16337) (variable 122) (variable_class_name 123) ("{" 16338) ("~" 125)) 13495 ((";" 28078)) 13496 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 28080) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 13497 (("%" 292) (")" 28081) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 13498 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 28082) (";" 27853) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 27854) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 27857) (T_DEC 22) (T_DECLARE 27858) (T_DIR 24) (T_DNUMBER 25) (T_DO 27859) (T_DOUBLE_CAST 27) (T_ECHO 27860) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 27862) (T_FOREACH 27863) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 27864) (T_GOTO 27865) (T_IF 27867) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 27868) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 27871) (T_START_HEREDOC 68) (T_STATIC 27872) (T_STRING 27873) (T_STRING_CAST 71) (T_SWITCH 27874) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 27876) (T_UNSET 27877) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 27879) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 27880) (alt_if_stmt_without_else 27881) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 27887) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 27890) (if_stmt_without_else 27891) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 28083) (static_member 119) (variable 122) (variable_class_name 123) (while_statement 28084) ("{" 27896) ("~" 125)) 13499 ((inner_statement_list 28085)) 13500 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16379) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16380) (T_CLASS 16381) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16382) (T_DEC 22) (T_DECLARE 16383) (T_DIR 24) (T_DNUMBER 25) (T_DO 16384) (T_DOUBLE_CAST 27) (T_ECHO 16385) (T_EMPTY 29) (T_ENDWHILE 28086) (T_ENUM 16387) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16388) (T_FOREACH 16389) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16390) (T_GOTO 16391) (T_HALT_COMPILER 16392) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16394) (T_INTERFACE 16395) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16396) (T_START_HEREDOC 68) (T_STATIC 16397) (T_STRING 16398) (T_STRING_CAST 71) (T_SWITCH 16399) (T_THROW 73) (T_TRAIT 16400) (T_TRAIT_C 75) (T_TRY 16401) (T_UNSET 16402) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16403) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16404) (alt_if_stmt_without_else 16405) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16406) (attributes 16407) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16408) (class_modifier 96) (class_modifiers 16409) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16410) (expr 16411) (fn 103) (fully_dereferenceable 104) #'16412 (function_call 106) (function_declaration_statement 16413) (if_stmt 16414) (if_stmt_without_else 16415) (inline_function 110) (inner_statement 16416) (interface_declaration_statement 16417) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16418) (static_member 119) (trait_declaration_statement 16419) (variable 122) (variable_class_name 123) ("{" 16420) ("~" 125)) 13501 ((";" 28087)) 13502 ((";" 28096)) 13503 (("," 27645) (";" 28095)) 13504 ((T_NAME_FULLY_QUALIFIED 27633) (T_NAME_QUALIFIED 27634) (T_STRING 27635) (group_use_declaration 28091) (legacy_namespace_name 27643) (namespace_name 27638) (use_declaration 27639) (use_declarations 28092)) 13505 ((";" 28094)) 13506 (("," 27645) (";" 28093)) 13507 (("\"" 1509) ("$" 16475) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 16476) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 16477) ("[" 1529) (array_object_dereferenceable 16478) (callable_expr 16479) (callable_variable 16480) (class_constant 1533) (class_name 16481) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 16482) (name 16483) (simple_variable 16484) (static_member 16485) (unset_variable 16486) (unset_variables 28098) (variable 16488) (variable_class_name 16489)) 13508 (("," 16501) (possible_comma 28099)) 13509 ((")" 28100)) 13510 ((";" 28101)) 13511 ((inner_statement_list 28103)) 13512 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 28104) ("~" 125)) 13513 ((catch_list 28105)) 13514 ((T_CATCH 28106) (T_FINALLY 28107) (finally_statement 28108)) 13515 (("(" 28112)) 13516 (("{" 28109)) 13517 ((inner_statement_list 28110)) 13518 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 28111) ("~" 125)) 13519 ((T_NAME_FULLY_QUALIFIED 16545) (T_NAME_QUALIFIED 16546) (T_NAME_RELATIVE 16547) (T_STATIC 16548) (T_STRING 16549) (catch_name_list 28113) (class_name 16551) (name 16552)) 13520 ((T_VARIABLE 16553) (optional_variable 28114) ("|" 16555)) 13521 ((")" 28115)) 13522 (("{" 28116)) 13523 ((inner_statement_list 28117)) 13524 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 28118) ("~" 125)) 13525 ((backup_doc_comment 28120)) 13526 (("{" 28121)) 13527 ((class_statement_list 28122)) 13528 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 28123)) 13529 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 28125) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 13530 (("%" 292) (")" 28126) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 13531 ((":" 28127) (switch_case_list 28128) ("{" 28129)) 13532 ((";" 28135) (case_list 28136)) 13533 ((";" 28130) (case_list 28131)) 13534 ((case_list 28133)) 13535 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 28132)) 13536 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 28134)) 13537 ((case_list 28139)) 13538 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 28137)) 13539 ((";" 28138)) 13540 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 28140)) 13541 ((";" 28141)) 13542 (("," 16852) (";" 28144)) 13543 ((";" 28146)) 13544 ((";" 28151) ("{" 28152)) 13545 ((top_statement_list 28149)) 13546 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 27853) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 27854) (T_CLASS 27855) (T_CLASS_C 17) (T_CLONE 18) (T_CONST 27856) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 27857) (T_DEC 22) (T_DECLARE 27858) (T_DIR 24) (T_DNUMBER 25) (T_DO 27859) (T_DOUBLE_CAST 27) (T_ECHO 27860) (T_EMPTY 29) (T_ENUM 27861) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 27862) (T_FOREACH 27863) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 27864) (T_GOTO 27865) (T_HALT_COMPILER 27866) (T_IF 27867) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 27868) (T_INTERFACE 27869) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAMESPACE 27870) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 27871) (T_START_HEREDOC 68) (T_STATIC 27872) (T_STRING 27873) (T_STRING_CAST 71) (T_SWITCH 27874) (T_THROW 73) (T_TRAIT 27875) (T_TRAIT_C 75) (T_TRY 27876) (T_UNSET 27877) (T_UNSET_CAST 78) (T_USE 27878) (T_VARIABLE 80) (T_WHILE 27879) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 27880) (alt_if_stmt_without_else 27881) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 27882) (attributes 27883) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 27884) (class_modifier 96) (class_modifiers 27885) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 27886) (expr 27887) (fn 103) (fully_dereferenceable 104) #'27888 (function_call 106) (function_declaration_statement 27889) (if_stmt 27890) (if_stmt_without_else 27891) (inline_function 110) (interface_declaration_statement 27892) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 27893) (static_member 119) (top_statement 27894) (trait_declaration_statement 27895) (variable 122) (variable_class_name 123) ("{" 27896) ("}" 28150) ("~" 125)) 13547 ((top_statement_list 28153)) 13548 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 27853) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 27854) (T_CLASS 27855) (T_CLASS_C 17) (T_CLONE 18) (T_CONST 27856) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 27857) (T_DEC 22) (T_DECLARE 27858) (T_DIR 24) (T_DNUMBER 25) (T_DO 27859) (T_DOUBLE_CAST 27) (T_ECHO 27860) (T_EMPTY 29) (T_ENUM 27861) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 27862) (T_FOREACH 27863) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 27864) (T_GOTO 27865) (T_HALT_COMPILER 27866) (T_IF 27867) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 27868) (T_INTERFACE 27869) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAMESPACE 27870) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 27871) (T_START_HEREDOC 68) (T_STATIC 27872) (T_STRING 27873) (T_STRING_CAST 71) (T_SWITCH 27874) (T_THROW 73) (T_TRAIT 27875) (T_TRAIT_C 75) (T_TRY 27876) (T_UNSET 27877) (T_UNSET_CAST 78) (T_USE 27878) (T_VARIABLE 80) (T_WHILE 27879) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 27880) (alt_if_stmt_without_else 27881) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 27882) (attributes 27883) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 27884) (class_modifier 96) (class_modifiers 27885) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 27886) (expr 27887) (fn 103) (fully_dereferenceable 104) #'27888 (function_call 106) (function_declaration_statement 27889) (if_stmt 27890) (if_stmt_without_else 27891) (inline_function 110) (interface_declaration_statement 27892) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 27893) (static_member 119) (top_statement 27894) (trait_declaration_statement 27895) (variable 122) (variable_class_name 123) ("{" 27896) ("}" 28154) ("~" 125)) 13549 ((T_EXTENDS 20209) (interface_extends_list 28156)) 13550 ((backup_doc_comment 28157)) 13551 (("{" 28158)) 13552 ((class_statement_list 28159)) 13553 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 28160)) 13554 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 28162) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 13555 (("%" 292) (")" 28163) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 13556 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20219) (";" 27905) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 27906) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 27907) (T_DEC 22) (T_DECLARE 27908) (T_DIR 24) (T_DNUMBER 25) (T_DO 27909) (T_DOUBLE_CAST 27) (T_ECHO 27910) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 27911) (T_FOREACH 27912) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 27913) (T_GOTO 27914) (T_IF 27867) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 27915) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 27916) (T_START_HEREDOC 68) (T_STATIC 27917) (T_STRING 27918) (T_STRING_CAST 71) (T_SWITCH 27919) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 27920) (T_UNSET 27921) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 27922) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 27923) (alt_if_stmt_without_else 27924) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 27925) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 27926) (if_stmt_without_else 27927) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 28164) (static_member 119) (variable 122) (variable_class_name 123) ("{" 27929) ("~" 125)) 13557 ((")" 28166)) 13558 ((";" 28167)) 13559 ((";" 28169)) 13560 (("," 17875) (";" 28171)) 13561 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 28173) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 13562 (("%" 17961) ("*" 17962) ("+" 17963) ("-" 17964) ("." 17965) ("/" 17966) ("<" 17967) (">" 17968) ("?" 17969) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 17970) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 17971) (T_AS 28174) (T_BOOLEAN_AND 17972) (T_BOOLEAN_OR 17973) (T_COALESCE 17974) (T_INSTANCEOF 17975) (T_IS_EQUAL 17976) (T_IS_GREATER_OR_EQUAL 17977) (T_IS_IDENTICAL 17978) (T_IS_NOT_EQUAL 17979) (T_IS_NOT_IDENTICAL 17980) (T_IS_SMALLER_OR_EQUAL 17981) (T_LOGICAL_AND 17982) (T_LOGICAL_OR 17983) (T_LOGICAL_XOR 17984) (T_POW 17985) (T_SL 17986) (T_SPACESHIP 17987) (T_SR 17988) ("^" 17989) ("|" 17990)) 13563 (("\"" 1509) ("$" 19325) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19326) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19327) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19328) ("[" 19329) (ampersand 19330) (array_object_dereferenceable 19331) (callable_expr 19332) (callable_variable 19333) (class_constant 1533) (class_name 19334) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 28175) (fully_dereferenceable 104) (function_call 19336) (name 19337) (simple_variable 19338) (static_member 19339) (variable 19340) (variable_class_name 19341)) 13564 ((")" 28176) (T_DOUBLE_ARROW 28177)) 13565 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 28180) (";" 27853) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 27854) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 27857) (T_DEC 22) (T_DECLARE 27858) (T_DIR 24) (T_DNUMBER 25) (T_DO 27859) (T_DOUBLE_CAST 27) (T_ECHO 27860) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 27862) (T_FOREACH 27863) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 27864) (T_GOTO 27865) (T_IF 27867) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 27868) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 27871) (T_START_HEREDOC 68) (T_STATIC 27872) (T_STRING 27873) (T_STRING_CAST 71) (T_SWITCH 27874) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 27876) (T_UNSET 27877) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 27879) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 27880) (alt_if_stmt_without_else 27881) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 27887) (fn 103) (foreach_statement 28186) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 27890) (if_stmt_without_else 27891) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 28182) (static_member 119) (variable 122) (variable_class_name 123) ("{" 27896) ("~" 125)) 13566 (("\"" 1509) ("$" 19356) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19357) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19358) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19359) ("[" 19360) (ampersand 19361) (array_object_dereferenceable 19362) (callable_expr 19363) (callable_variable 19364) (class_constant 1533) (class_name 19365) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 28178) (fully_dereferenceable 104) (function_call 19367) (name 19368) (simple_variable 19369) (static_member 19370) (variable 19371) (variable_class_name 19372)) 13567 ((")" 28179)) 13568 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 28180) (";" 27853) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 27854) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 27857) (T_DEC 22) (T_DECLARE 27858) (T_DIR 24) (T_DNUMBER 25) (T_DO 27859) (T_DOUBLE_CAST 27) (T_ECHO 27860) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 27862) (T_FOREACH 27863) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 27864) (T_GOTO 27865) (T_IF 27867) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 27868) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 27871) (T_START_HEREDOC 68) (T_STATIC 27872) (T_STRING 27873) (T_STRING_CAST 71) (T_SWITCH 27874) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 27876) (T_UNSET 27877) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 27879) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 27880) (alt_if_stmt_without_else 27881) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 27887) (fn 103) (foreach_statement 28181) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 27890) (if_stmt_without_else 27891) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 28182) (static_member 119) (variable 122) (variable_class_name 123) ("{" 27896) ("~" 125)) 13569 ((inner_statement_list 28183)) 13570 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19390) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19391) (T_CLASS 19392) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19393) (T_DEC 22) (T_DECLARE 19394) (T_DIR 24) (T_DNUMBER 25) (T_DO 19395) (T_DOUBLE_CAST 27) (T_ECHO 19396) (T_EMPTY 29) (T_ENDFOREACH 28184) (T_ENUM 19398) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19399) (T_FOREACH 19400) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19401) (T_GOTO 19402) (T_HALT_COMPILER 19403) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19405) (T_INTERFACE 19406) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19407) (T_START_HEREDOC 68) (T_STATIC 19408) (T_STRING 19409) (T_STRING_CAST 71) (T_SWITCH 19410) (T_THROW 73) (T_TRAIT 19411) (T_TRAIT_C 75) (T_TRY 19412) (T_UNSET 19413) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19414) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19415) (alt_if_stmt_without_else 19416) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19417) (attributes 19418) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19419) (class_modifier 96) (class_modifiers 19420) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19421) (expr 19422) (fn 103) (fully_dereferenceable 104) #'19423 (function_call 106) (function_declaration_statement 19424) (if_stmt 19425) (if_stmt_without_else 19426) (inline_function 110) (inner_statement 19427) (interface_declaration_statement 19428) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19429) (static_member 119) (trait_declaration_statement 19430) (variable 122) (variable_class_name 123) ("{" 19431) ("~" 125)) 13571 ((";" 28185)) 13572 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 28188) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 13573 ((";" 28189)) 13574 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 28190) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 13575 ((";" 28191)) 13576 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 19558) (fn 2394) (for_exprs 28192) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (non_empty_for_exprs 19560) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 13577 ((")" 28193)) 13578 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 28194) (";" 27853) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 27854) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 27857) (T_DEC 22) (T_DECLARE 27858) (T_DIR 24) (T_DNUMBER 25) (T_DO 27859) (T_DOUBLE_CAST 27) (T_ECHO 27860) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 27862) (T_FOREACH 27863) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 27864) (T_GOTO 27865) (T_IF 27867) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 27868) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 27871) (T_START_HEREDOC 68) (T_STATIC 27872) (T_STRING 27873) (T_STRING_CAST 71) (T_SWITCH 27874) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 27876) (T_UNSET 27877) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 27879) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 27880) (alt_if_stmt_without_else 27881) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 27887) (fn 103) (for_statement 28195) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 27890) (if_stmt_without_else 27891) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 28196) (static_member 119) (variable 122) (variable_class_name 123) ("{" 27896) ("~" 125)) 13579 ((inner_statement_list 28197)) 13580 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19568) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19569) (T_CLASS 19570) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19571) (T_DEC 22) (T_DECLARE 19572) (T_DIR 24) (T_DNUMBER 25) (T_DO 19573) (T_DOUBLE_CAST 27) (T_ECHO 19574) (T_EMPTY 29) (T_ENDFOR 28198) (T_ENUM 19576) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19577) (T_FOREACH 19578) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19579) (T_GOTO 19580) (T_HALT_COMPILER 19581) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19583) (T_INTERFACE 19584) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19585) (T_START_HEREDOC 68) (T_STATIC 19586) (T_STRING 19587) (T_STRING_CAST 71) (T_SWITCH 19588) (T_THROW 73) (T_TRAIT 19589) (T_TRAIT_C 75) (T_TRY 19590) (T_UNSET 19591) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19592) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19593) (alt_if_stmt_without_else 19594) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19595) (attributes 19596) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19597) (class_modifier 96) (class_modifiers 19598) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19599) (expr 19600) (fn 103) (fully_dereferenceable 104) #'19601 (function_call 106) (function_declaration_statement 19602) (if_stmt 19603) (if_stmt_without_else 19604) (inline_function 110) (inner_statement 19605) (interface_declaration_statement 19606) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19607) (static_member 119) (trait_declaration_statement 19608) (variable 122) (variable_class_name 123) ("{" 19609) ("~" 125)) 13581 ((";" 28199)) 13582 ((":" 20258) (enum_backing_type 28201)) 13583 ((T_IMPLEMENTS 2987) (implements_list 28202)) 13584 ((backup_doc_comment 28203)) 13585 (("{" 28204)) 13586 ((class_statement_list 28205)) 13587 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 28206)) 13588 (("," 19743) (";" 28208)) 13589 ((T_WHILE 28210)) 13590 (("(" 28211)) 13591 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 28212) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 13592 (("%" 292) (")" 28213) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 13593 ((";" 28214)) 13594 ((T_STRING 19916) (const_decl 19917) (const_list 28216)) 13595 ((")" 28217) ("," 19920)) 13596 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 28218) (";" 27853) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 27854) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 27857) (T_DEC 22) (T_DECLARE 27858) (T_DIR 24) (T_DNUMBER 25) (T_DO 27859) (T_DOUBLE_CAST 27) (T_ECHO 27860) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 27862) (T_FOREACH 27863) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 27864) (T_GOTO 27865) (T_IF 27867) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 27868) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 27871) (T_START_HEREDOC 68) (T_STATIC 27872) (T_STRING 27873) (T_STRING_CAST 71) (T_SWITCH 27874) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 27876) (T_UNSET 27877) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 27879) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 27880) (alt_if_stmt_without_else 27881) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (declare_statement 28219) (dereferenceable_scalar 100) (expr 27887) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 27890) (if_stmt_without_else 27891) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 28220) (static_member 119) (variable 122) (variable_class_name 123) ("{" 27896) ("~" 125)) 13597 ((inner_statement_list 28221)) 13598 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19926) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19927) (T_CLASS 19928) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19929) (T_DEC 22) (T_DECLARE 19930) (T_DIR 24) (T_DNUMBER 25) (T_DO 19931) (T_DOUBLE_CAST 27) (T_ECHO 19932) (T_EMPTY 29) (T_ENDDECLARE 28222) (T_ENUM 19934) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19935) (T_FOREACH 19936) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19937) (T_GOTO 19938) (T_HALT_COMPILER 19939) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19941) (T_INTERFACE 19942) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19943) (T_START_HEREDOC 68) (T_STATIC 19944) (T_STRING 19945) (T_STRING_CAST 71) (T_SWITCH 19946) (T_THROW 73) (T_TRAIT 19947) (T_TRAIT_C 75) (T_TRY 19948) (T_UNSET 19949) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19950) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19951) (alt_if_stmt_without_else 19952) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19953) (attributes 19954) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19955) (class_modifier 96) (class_modifiers 19956) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19957) (expr 19958) (fn 103) (fully_dereferenceable 104) #'19959 (function_call 106) (function_declaration_statement 19960) (if_stmt 19961) (if_stmt_without_else 19962) (inline_function 110) (inner_statement 19963) (interface_declaration_statement 19964) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19965) (static_member 119) (trait_declaration_statement 19966) (variable 122) (variable_class_name 123) ("{" 19967) ("~" 125)) 13599 ((";" 28223)) 13600 ((";" 28225)) 13601 (("=" 28232)) 13602 (("," 28229) (";" 28230)) 13603 ((T_STRING 28226) (const_decl 28231)) 13604 (("!" 3066) ("\"" 3067) ("$" 3068) ("(" 3069) ("+" 3070) ("-" 3071) ("@" 3072) (T_ARRAY 3073) (T_ARRAY_CAST 3074) (T_ATTRIBUTE 126) (T_BOOL_CAST 3075) (T_CLASS_C 3076) (T_CLONE 3077) (T_CONSTANT_ENCAPSED_STRING 3078) (T_DEC 3079) (T_DIR 3080) (T_DNUMBER 3081) (T_DOUBLE_CAST 3082) (T_EMPTY 3083) (T_EVAL 3084) (T_EXIT 3085) (T_FILE 3086) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3087) (T_INC 3088) (T_INCLUDE 3089) (T_INCLUDE_ONCE 3090) (T_INT_CAST 3091) (T_ISSET 3092) (T_LINE 3093) (T_LIST 3094) (T_LNUMBER 3095) (T_MATCH 3096) (T_METHOD_C 3097) (T_NAME_FULLY_QUALIFIED 3098) (T_NAME_QUALIFIED 3099) (T_NAME_RELATIVE 3100) (T_NEW 3101) (T_NS_C 3102) (T_OBJECT_CAST 3103) (T_PRINT 3104) (T_READONLY 3105) (T_REQUIRE 3106) (T_REQUIRE_ONCE 3107) (T_START_HEREDOC 3108) (T_STATIC 3109) (T_STRING 3110) (T_STRING_CAST 3111) (T_THROW 3112) (T_TRAIT_C 3113) (T_UNSET_CAST 3114) (T_VARIABLE 3115) (T_YIELD 3116) (T_YIELD_FROM 3117) ("[" 3118) ("`" 3119) (array_object_dereferenceable 3120) (attribute 131) (attributes 3121) (callable_expr 3122) (callable_variable 3123) (class_constant 3124) (class_name 3125) (constant 3126) (dereferenceable_scalar 3127) (expr 28233) (fn 3129) (fully_dereferenceable 104) #'3130 (function_call 3131) (inline_function 3132) (internal_functions_in_yacc 3133) (match 3134) (name 3135) (new_expr 3136) (scalar 3137) (simple_variable 3138) (static_member 3139) (variable 3140) (variable_class_name 3141) ("~" 3142)) 13605 (("%" 3144) ("*" 3145) ("+" 3146) ("-" 3147) ("." 3148) ("/" 3149) ("<" 3150) (">" 3151) ("?" 3152) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 3153) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 3154) (T_BOOLEAN_AND 3155) (T_BOOLEAN_OR 3156) (T_COALESCE 3157) (T_INSTANCEOF 3158) (T_IS_EQUAL 3159) (T_IS_GREATER_OR_EQUAL 3160) (T_IS_IDENTICAL 3161) (T_IS_NOT_EQUAL 3162) (T_IS_NOT_IDENTICAL 3163) (T_IS_SMALLER_OR_EQUAL 3164) (T_LOGICAL_AND 3165) (T_LOGICAL_OR 3166) (T_LOGICAL_XOR 3167) (T_POW 3168) (T_SL 3169) (T_SPACESHIP 3170) (T_SR 3171) ("^" 3172) (backup_doc_comment 28234) ("|" 3173)) 13606 ((T_EXTENDS 2985) (extends_from 28236)) 13607 ((T_IMPLEMENTS 2987) (implements_list 28237)) 13608 ((backup_doc_comment 28238)) 13609 (("{" 28239)) 13610 ((class_statement_list 28240)) 13611 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 28241)) 13612 ((";" 28243)) 13613 ((top_statement_list 28246)) 13614 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 27853) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 27854) (T_CLASS 27855) (T_CLASS_C 17) (T_CLONE 18) (T_CONST 27856) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 27857) (T_DEC 22) (T_DECLARE 27858) (T_DIR 24) (T_DNUMBER 25) (T_DO 27859) (T_DOUBLE_CAST 27) (T_ECHO 27860) (T_EMPTY 29) (T_ENUM 27861) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 27862) (T_FOREACH 27863) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 27864) (T_GOTO 27865) (T_HALT_COMPILER 27866) (T_IF 27867) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 27868) (T_INTERFACE 27869) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAMESPACE 27870) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 27871) (T_START_HEREDOC 68) (T_STATIC 27872) (T_STRING 27873) (T_STRING_CAST 71) (T_SWITCH 27874) (T_THROW 73) (T_TRAIT 27875) (T_TRAIT_C 75) (T_TRY 27876) (T_UNSET 27877) (T_UNSET_CAST 78) (T_USE 27878) (T_VARIABLE 80) (T_WHILE 27879) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 27880) (alt_if_stmt_without_else 27881) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 27882) (attributes 27883) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 27884) (class_modifier 96) (class_modifiers 27885) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 27886) (expr 27887) (fn 103) (fully_dereferenceable 104) #'27888 (function_call 106) (function_declaration_statement 27889) (if_stmt 27890) (if_stmt_without_else 27891) (inline_function 110) (interface_declaration_statement 27892) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 27893) (static_member 119) (top_statement 27894) (trait_declaration_statement 27895) (variable 122) (variable_class_name 123) ("{" 27896) ("}" 28247) ("~" 125)) 13615 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 28249) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 13616 (("%" 292) (")" 28250) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 13617 (("{" 28251)) 13618 (("!" 3972) ("\"" 3973) ("$" 3974) ("(" 3975) ("+" 3976) ("-" 3977) ("@" 3978) (T_ARRAY 3979) (T_ARRAY_CAST 3980) (T_ATTRIBUTE 126) (T_BOOL_CAST 3981) (T_CLASS_C 3982) (T_CLONE 3983) (T_CONSTANT_ENCAPSED_STRING 3984) (T_DEC 3985) (T_DEFAULT 3986) (T_DIR 3987) (T_DNUMBER 3988) (T_DOUBLE_CAST 3989) (T_EMPTY 3990) (T_EVAL 3991) (T_EXIT 3992) (T_FILE 3993) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 3994) (T_INC 3995) (T_INCLUDE 3996) (T_INCLUDE_ONCE 3997) (T_INT_CAST 3998) (T_ISSET 3999) (T_LINE 4000) (T_LIST 4001) (T_LNUMBER 4002) (T_MATCH 4003) (T_METHOD_C 4004) (T_NAME_FULLY_QUALIFIED 4005) (T_NAME_QUALIFIED 4006) (T_NAME_RELATIVE 4007) (T_NEW 4008) (T_NS_C 4009) (T_OBJECT_CAST 4010) (T_PRINT 4011) (T_READONLY 4012) (T_REQUIRE 4013) (T_REQUIRE_ONCE 4014) (T_START_HEREDOC 4015) (T_STATIC 4016) (T_STRING 4017) (T_STRING_CAST 4018) (T_THROW 4019) (T_TRAIT_C 4020) (T_UNSET_CAST 4021) (T_VARIABLE 4022) (T_YIELD 4023) (T_YIELD_FROM 4024) ("[" 4025) ("`" 4026) (array_object_dereferenceable 4027) (attribute 131) (attributes 4028) (callable_expr 4029) (callable_variable 4030) (class_constant 4031) (class_name 4032) (constant 4033) (dereferenceable_scalar 4034) (expr 4035) (fn 4036) (fully_dereferenceable 104) #'4037 (function_call 4038) (inline_function 4039) (internal_functions_in_yacc 4040) (match 4041) (match_arm 4042) (match_arm_cond_list 4043) (match_arm_list 28252) (name 4045) (new_expr 4046) (non_empty_match_arm_list 4047) (scalar 4048) (simple_variable 4049) (static_member 4050) (variable 4051) (variable_class_name 4052) ("~" 4053)) 13619 (("}" 28253)) 13620 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 28255) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 13621 ((")" 28256)) 13622 (("=" 28257)) 13623 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 28258) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 13624 (("!" 934) ("\"" 935) ("$" 936) ("(" 937) ("+" 939) ("-" 940) ("@" 941) (T_ARRAY 1069) (T_ARRAY_CAST 944) (T_ATTRIBUTE 126) (T_BOOL_CAST 946) (T_CLASS_C 1070) (T_CLONE 1071) (T_CONSTANT_ENCAPSED_STRING 955) (T_DEC 957) (T_DIR 1072) (T_DNUMBER 961) (T_DOUBLE_CAST 963) (T_EMPTY 1073) (T_EVAL 1074) (T_EXIT 1075) (T_FILE 1076) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1077) (T_INC 991) (T_INCLUDE 1078) (T_INCLUDE_ONCE 1079) (T_INT_CAST 997) (T_ISSET 1080) (T_LINE 1081) (T_LIST 1082) (T_LNUMBER 1001) (T_MATCH 1083) (T_METHOD_C 1084) (T_NAME_FULLY_QUALIFIED 1008) (T_NAME_QUALIFIED 1009) (T_NAME_RELATIVE 1010) (T_NEW 1085) (T_NS_C 1086) (T_OBJECT_CAST 1013) (T_PRINT 1087) (T_READONLY 1088) (T_REQUIRE 1089) (T_REQUIRE_ONCE 1090) (T_START_HEREDOC 1022) (T_STATIC 1091) (T_STRING 1092) (T_STRING_CAST 1025) (T_THROW 1093) (T_TRAIT_C 1094) (T_UNSET_CAST 1032) (T_VARIABLE 1035) (T_YIELD 1095) (T_YIELD_FROM 1038) ("[" 1039) ("`" 1040) (array_object_dereferenceable 1042) (attribute 131) (attributes 1043) (callable_expr 1044) (callable_variable 1045) (class_constant 1046) (class_name 1047) (constant 1048) (dereferenceable_scalar 1049) (expr 5255) (fn 1051) (fully_dereferenceable 104) #'1052 (function_call 1053) (inline_function 1055) (internal_functions_in_yacc 1056) (isset_variable 5256) (isset_variables 28260) (match 1057) (name 1058) (new_expr 1059) (scalar 1062) (simple_variable 1064) (static_member 1065) (variable 1066) (variable_class_name 1067) ("~" 1068)) 13625 (("," 5258) (possible_comma 28261)) 13626 ((")" 28262)) 13627 ((T_EXTENDS 20209) (interface_extends_list 28265)) 13628 ((backup_doc_comment 28266)) 13629 (("{" 28267)) 13630 ((class_statement_list 28268)) 13631 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 28269)) 13632 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 28274) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 13633 (("%" 292) (")" 28275) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 13634 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20219) (";" 28276) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 28277) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 28278) (T_DEC 22) (T_DECLARE 28279) (T_DIR 24) (T_DNUMBER 25) (T_DO 28280) (T_DOUBLE_CAST 27) (T_ECHO 28281) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 28282) (T_FOREACH 28283) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 28284) (T_GOTO 28285) (T_IF 28286) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 28287) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 28288) (T_START_HEREDOC 68) (T_STATIC 28289) (T_STRING 28290) (T_STRING_CAST 71) (T_SWITCH 28291) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 28292) (T_UNSET 28293) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 28294) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 28295) (alt_if_stmt_without_else 28296) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 28297) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 28298) (if_stmt_without_else 28299) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 28300) (static_member 119) (variable 122) (variable_class_name 123) ("{" 28301) ("~" 125)) 13635 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 28428) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 13636 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 28426) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 13637 (("(" 28417)) 13638 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19746) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 19747) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19748) (T_DEC 22) (T_DECLARE 19749) (T_DIR 24) (T_DNUMBER 25) (T_DO 19750) (T_DOUBLE_CAST 27) (T_ECHO 19751) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 19752) (T_FOREACH 19753) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 19754) (T_GOTO 19755) (T_IF 19756) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19757) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19758) (T_START_HEREDOC 68) (T_STATIC 19759) (T_STRING 19760) (T_STRING_CAST 71) (T_SWITCH 19761) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 19762) (T_UNSET 19763) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19764) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19765) (alt_if_stmt_without_else 19766) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 19767) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 19768) (if_stmt_without_else 19769) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 28411) (static_member 119) (variable 122) (variable_class_name 123) ("{" 19771) ("~" 125)) 13639 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (echo_expr 19740) (echo_expr_list 28409) (expr 19742) (fn 16919) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 13640 (("(" 28396)) 13641 (("(" 28381)) 13642 (("$" 17870) (T_VARIABLE 17871) (global_var 17872) (global_var_list 28379) (simple_variable 17874)) 13643 ((T_STRING 28377)) 13644 (("(" 28373)) 13645 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_DEC 22) (T_DIR 24) (T_DNUMBER 25) (T_DOUBLE_CAST 27) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 39) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_START_HEREDOC 68) (T_STATIC 129) (T_STRING 130) (T_STRING_CAST 71) (T_THROW 73) (T_TRAIT_C 75) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 17865) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (optional_expr 28371) (scalar 116) (simple_variable 117) (static_member 119) (variable 122) (variable_class_name 123) ("~" 125)) 13646 ((T_FN 35) (T_FUNCTION 127) (T_VARIABLE 16848) (fn 103) #'134 (inline_function 16849) (static_var 16850) (static_var_list 28369)) 13647 ((":" 28368)) 13648 (("(" 28350)) 13649 (("{" 28333)) 13650 (("(" 28328)) 13651 (("(" 28319)) 13652 ((T_ELSE 28312) (T_ELSEIF 16203) (T_ENDIF 28313)) 13653 (("%" 6465) ("*" 6466) ("+" 6467) ("-" 6468) ("." 6469) ("/" 6470) (";" 28311) ("<" 6471) (">" 6472) ("?" 6473) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 6474) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 6475) (T_BOOLEAN_AND 6476) (T_BOOLEAN_OR 6477) (T_COALESCE 6478) (T_INSTANCEOF 6479) (T_IS_EQUAL 6480) (T_IS_GREATER_OR_EQUAL 6481) (T_IS_IDENTICAL 6482) (T_IS_NOT_EQUAL 6483) (T_IS_NOT_IDENTICAL 6484) (T_IS_SMALLER_OR_EQUAL 6485) (T_LOGICAL_AND 6486) (T_LOGICAL_OR 6487) (T_LOGICAL_XOR 6488) (T_POW 6489) (T_SL 6490) (T_SPACESHIP 6491) (T_SR 6492) ("^" 6493) ("|" 6494)) 13654 ((T_ELSE 28304) (T_ELSEIF 28305)) 13655 ((inner_statement_list 28302)) 13656 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 28303) ("~" 125)) 13657 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 28276) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 28277) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 28278) (T_DEC 22) (T_DECLARE 28279) (T_DIR 24) (T_DNUMBER 25) (T_DO 28280) (T_DOUBLE_CAST 27) (T_ECHO 28281) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 28282) (T_FOREACH 28283) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 28284) (T_GOTO 28285) (T_IF 28286) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 28287) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 28288) (T_START_HEREDOC 68) (T_STATIC 28289) (T_STRING 28290) (T_STRING_CAST 71) (T_SWITCH 28291) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 28292) (T_UNSET 28293) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 28294) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 28295) (alt_if_stmt_without_else 28296) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 28297) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 28298) (if_stmt_without_else 28299) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 28310) (static_member 119) (variable 122) (variable_class_name 123) ("{" 28301) ("~" 125)) 13658 (("(" 28306)) 13659 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 28307) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 13660 (("%" 292) (")" 28308) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 13661 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 28276) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 28277) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 28278) (T_DEC 22) (T_DECLARE 28279) (T_DIR 24) (T_DNUMBER 25) (T_DO 28280) (T_DOUBLE_CAST 27) (T_ECHO 28281) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 28282) (T_FOREACH 28283) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 28284) (T_GOTO 28285) (T_IF 28286) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 28287) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 28288) (T_START_HEREDOC 68) (T_STATIC 28289) (T_STRING 28290) (T_STRING_CAST 71) (T_SWITCH 28291) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 28292) (T_UNSET 28293) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 28294) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 28295) (alt_if_stmt_without_else 28296) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 28297) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 28298) (if_stmt_without_else 28299) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 28309) (static_member 119) (variable 122) (variable_class_name 123) ("{" 28301) ("~" 125)) 13662 ((":" 28315)) 13663 ((";" 28314)) 13664 ((inner_statement_list 28316)) 13665 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16298) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16299) (T_CLASS 16300) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16301) (T_DEC 22) (T_DECLARE 16302) (T_DIR 24) (T_DNUMBER 25) (T_DO 16303) (T_DOUBLE_CAST 27) (T_ECHO 16304) (T_EMPTY 29) (T_ENDIF 28317) (T_ENUM 16306) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16307) (T_FOREACH 16308) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16309) (T_GOTO 16310) (T_HALT_COMPILER 16311) (T_IF 16224) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16312) (T_INTERFACE 16313) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16314) (T_START_HEREDOC 68) (T_STATIC 16315) (T_STRING 16316) (T_STRING_CAST 71) (T_SWITCH 16317) (T_THROW 73) (T_TRAIT 16318) (T_TRAIT_C 75) (T_TRY 16319) (T_UNSET 16320) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16321) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16322) (alt_if_stmt_without_else 16323) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16324) (attributes 16325) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16326) (class_modifier 96) (class_modifiers 16327) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16328) (expr 16329) (fn 103) (fully_dereferenceable 104) #'16330 (function_call 106) (function_declaration_statement 16331) (if_stmt 16332) (if_stmt_without_else 16333) (inline_function 110) (inner_statement 16334) (interface_declaration_statement 16335) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16336) (static_member 119) (trait_declaration_statement 16337) (variable 122) (variable_class_name 123) ("{" 16338) ("~" 125)) 13666 ((";" 28318)) 13667 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 28320) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 13668 (("%" 292) (")" 28321) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 13669 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 28322) (";" 28276) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 28277) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 28278) (T_DEC 22) (T_DECLARE 28279) (T_DIR 24) (T_DNUMBER 25) (T_DO 28280) (T_DOUBLE_CAST 27) (T_ECHO 28281) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 28282) (T_FOREACH 28283) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 28284) (T_GOTO 28285) (T_IF 28286) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 28287) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 28288) (T_START_HEREDOC 68) (T_STATIC 28289) (T_STRING 28290) (T_STRING_CAST 71) (T_SWITCH 28291) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 28292) (T_UNSET 28293) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 28294) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 28295) (alt_if_stmt_without_else 28296) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 28297) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 28298) (if_stmt_without_else 28299) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 28323) (static_member 119) (variable 122) (variable_class_name 123) (while_statement 28324) ("{" 28301) ("~" 125)) 13670 ((inner_statement_list 28325)) 13671 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 16379) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 16380) (T_CLASS 16381) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 16382) (T_DEC 22) (T_DECLARE 16383) (T_DIR 24) (T_DNUMBER 25) (T_DO 16384) (T_DOUBLE_CAST 27) (T_ECHO 16385) (T_EMPTY 29) (T_ENDWHILE 28326) (T_ENUM 16387) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 16388) (T_FOREACH 16389) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 16390) (T_GOTO 16391) (T_HALT_COMPILER 16392) (T_IF 16393) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 16394) (T_INTERFACE 16395) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 16396) (T_START_HEREDOC 68) (T_STATIC 16397) (T_STRING 16398) (T_STRING_CAST 71) (T_SWITCH 16399) (T_THROW 73) (T_TRAIT 16400) (T_TRAIT_C 75) (T_TRY 16401) (T_UNSET 16402) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 16403) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 16404) (alt_if_stmt_without_else 16405) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 16406) (attributes 16407) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 16408) (class_modifier 96) (class_modifiers 16409) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 16410) (expr 16411) (fn 103) (fully_dereferenceable 104) #'16412 (function_call 106) (function_declaration_statement 16413) (if_stmt 16414) (if_stmt_without_else 16415) (inline_function 110) (inner_statement 16416) (interface_declaration_statement 16417) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 16418) (static_member 119) (trait_declaration_statement 16419) (variable 122) (variable_class_name 123) ("{" 16420) ("~" 125)) 13672 ((";" 28327)) 13673 (("\"" 1509) ("$" 16475) ("(" 1511) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 16476) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 16477) ("[" 1529) (array_object_dereferenceable 16478) (callable_expr 16479) (callable_variable 16480) (class_constant 1533) (class_name 16481) (constant 1535) (dereferenceable_scalar 1536) (fully_dereferenceable 104) (function_call 16482) (name 16483) (simple_variable 16484) (static_member 16485) (unset_variable 16486) (unset_variables 28329) (variable 16488) (variable_class_name 16489)) 13674 (("," 16501) (possible_comma 28330)) 13675 ((")" 28331)) 13676 ((";" 28332)) 13677 ((inner_statement_list 28334)) 13678 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 28335) ("~" 125)) 13679 ((catch_list 28336)) 13680 ((T_CATCH 28337) (T_FINALLY 28338) (finally_statement 28339)) 13681 (("(" 28343)) 13682 (("{" 28340)) 13683 ((inner_statement_list 28341)) 13684 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 28342) ("~" 125)) 13685 ((T_NAME_FULLY_QUALIFIED 16545) (T_NAME_QUALIFIED 16546) (T_NAME_RELATIVE 16547) (T_STATIC 16548) (T_STRING 16549) (catch_name_list 28344) (class_name 16551) (name 16552)) 13686 ((T_VARIABLE 16553) (optional_variable 28345) ("|" 16555)) 13687 ((")" 28346)) 13688 (("{" 28347)) 13689 ((inner_statement_list 28348)) 13690 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 166) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 167) (T_CLASS 168) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 169) (T_DEC 22) (T_DECLARE 170) (T_DIR 24) (T_DNUMBER 25) (T_DO 171) (T_DOUBLE_CAST 27) (T_ECHO 172) (T_EMPTY 29) (T_ENUM 173) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 174) (T_FOREACH 175) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 176) (T_GOTO 177) (T_HALT_COMPILER 178) (T_IF 179) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 180) (T_INTERFACE 181) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 182) (T_START_HEREDOC 68) (T_STATIC 183) (T_STRING 184) (T_STRING_CAST 71) (T_SWITCH 185) (T_THROW 73) (T_TRAIT 186) (T_TRAIT_C 75) (T_TRY 187) (T_UNSET 188) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 189) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 190) (alt_if_stmt_without_else 191) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 192) (attributes 193) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 194) (class_modifier 96) (class_modifiers 195) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 196) (expr 197) (fn 103) (fully_dereferenceable 104) #'198 (function_call 106) (function_declaration_statement 199) (if_stmt 200) (if_stmt_without_else 201) (inline_function 110) (inner_statement 202) (interface_declaration_statement 203) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 204) (static_member 119) (trait_declaration_statement 205) (variable 122) (variable_class_name 123) ("{" 206) ("}" 28349) ("~" 125)) 13691 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 28351) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 13692 (("%" 292) (")" 28352) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 13693 ((":" 28353) (switch_case_list 28354) ("{" 28355)) 13694 ((";" 28361) (case_list 28362)) 13695 ((";" 28356) (case_list 28357)) 13696 ((case_list 28359)) 13697 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 28358)) 13698 ((T_CASE 16569) (T_DEFAULT 16570) ("}" 28360)) 13699 ((case_list 28365)) 13700 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 28363)) 13701 ((";" 28364)) 13702 ((T_CASE 16705) (T_DEFAULT 16706) (T_ENDSWITCH 28366)) 13703 ((";" 28367)) 13704 (("," 16852) (";" 28370)) 13705 ((";" 28372)) 13706 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 28374) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 13707 (("%" 292) (")" 28375) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 13708 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 20219) (";" 25781) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 25782) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 25783) (T_DEC 22) (T_DECLARE 25784) (T_DIR 24) (T_DNUMBER 25) (T_DO 25785) (T_DOUBLE_CAST 27) (T_ECHO 25786) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 25787) (T_FOREACH 25788) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 25789) (T_GOTO 25790) (T_IF 43) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 25791) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 25792) (T_START_HEREDOC 68) (T_STATIC 25793) (T_STRING 25794) (T_STRING_CAST 71) (T_SWITCH 25795) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 25796) (T_UNSET 25797) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 25798) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 25799) (alt_if_stmt_without_else 25800) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 25801) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 25802) (if_stmt_without_else 25803) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 28376) (static_member 119) (variable 122) (variable_class_name 123) ("{" 25805) ("~" 125)) 13709 ((";" 28378)) 13710 (("," 17875) (";" 28380)) 13711 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 28382) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 13712 (("%" 17961) ("*" 17962) ("+" 17963) ("-" 17964) ("." 17965) ("/" 17966) ("<" 17967) (">" 17968) ("?" 17969) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 17970) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 17971) (T_AS 28383) (T_BOOLEAN_AND 17972) (T_BOOLEAN_OR 17973) (T_COALESCE 17974) (T_INSTANCEOF 17975) (T_IS_EQUAL 17976) (T_IS_GREATER_OR_EQUAL 17977) (T_IS_IDENTICAL 17978) (T_IS_NOT_EQUAL 17979) (T_IS_NOT_IDENTICAL 17980) (T_IS_SMALLER_OR_EQUAL 17981) (T_LOGICAL_AND 17982) (T_LOGICAL_OR 17983) (T_LOGICAL_XOR 17984) (T_POW 17985) (T_SL 17986) (T_SPACESHIP 17987) (T_SR 17988) ("^" 17989) ("|" 17990)) 13713 (("\"" 1509) ("$" 19325) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19326) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19327) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19328) ("[" 19329) (ampersand 19330) (array_object_dereferenceable 19331) (callable_expr 19332) (callable_variable 19333) (class_constant 1533) (class_name 19334) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 28384) (fully_dereferenceable 104) (function_call 19336) (name 19337) (simple_variable 19338) (static_member 19339) (variable 19340) (variable_class_name 19341)) 13714 ((")" 28385) (T_DOUBLE_ARROW 28386)) 13715 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 28389) (";" 28276) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 28277) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 28278) (T_DEC 22) (T_DECLARE 28279) (T_DIR 24) (T_DNUMBER 25) (T_DO 28280) (T_DOUBLE_CAST 27) (T_ECHO 28281) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 28282) (T_FOREACH 28283) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 28284) (T_GOTO 28285) (T_IF 28286) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 28287) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 28288) (T_START_HEREDOC 68) (T_STATIC 28289) (T_STRING 28290) (T_STRING_CAST 71) (T_SWITCH 28291) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 28292) (T_UNSET 28293) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 28294) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 28295) (alt_if_stmt_without_else 28296) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 28297) (fn 103) (foreach_statement 28395) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 28298) (if_stmt_without_else 28299) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 28391) (static_member 119) (variable 122) (variable_class_name 123) ("{" 28301) ("~" 125)) 13716 (("\"" 1509) ("$" 19356) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19357) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19358) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19359) ("[" 19360) (ampersand 19361) (array_object_dereferenceable 19362) (callable_expr 19363) (callable_variable 19364) (class_constant 1533) (class_name 19365) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 28387) (fully_dereferenceable 104) (function_call 19367) (name 19368) (simple_variable 19369) (static_member 19370) (variable 19371) (variable_class_name 19372)) 13717 ((")" 28388)) 13718 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 28389) (";" 28276) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 28277) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 28278) (T_DEC 22) (T_DECLARE 28279) (T_DIR 24) (T_DNUMBER 25) (T_DO 28280) (T_DOUBLE_CAST 27) (T_ECHO 28281) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 28282) (T_FOREACH 28283) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 28284) (T_GOTO 28285) (T_IF 28286) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 28287) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 28288) (T_START_HEREDOC 68) (T_STATIC 28289) (T_STRING 28290) (T_STRING_CAST 71) (T_SWITCH 28291) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 28292) (T_UNSET 28293) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 28294) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 28295) (alt_if_stmt_without_else 28296) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 28297) (fn 103) (foreach_statement 28390) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 28298) (if_stmt_without_else 28299) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 28391) (static_member 119) (variable 122) (variable_class_name 123) ("{" 28301) ("~" 125)) 13719 ((inner_statement_list 28392)) 13720 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19390) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19391) (T_CLASS 19392) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19393) (T_DEC 22) (T_DECLARE 19394) (T_DIR 24) (T_DNUMBER 25) (T_DO 19395) (T_DOUBLE_CAST 27) (T_ECHO 19396) (T_EMPTY 29) (T_ENDFOREACH 28393) (T_ENUM 19398) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19399) (T_FOREACH 19400) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19401) (T_GOTO 19402) (T_HALT_COMPILER 19403) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19405) (T_INTERFACE 19406) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19407) (T_START_HEREDOC 68) (T_STATIC 19408) (T_STRING 19409) (T_STRING_CAST 71) (T_SWITCH 19410) (T_THROW 73) (T_TRAIT 19411) (T_TRAIT_C 75) (T_TRY 19412) (T_UNSET 19413) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19414) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19415) (alt_if_stmt_without_else 19416) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19417) (attributes 19418) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19419) (class_modifier 96) (class_modifiers 19420) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19421) (expr 19422) (fn 103) (fully_dereferenceable 104) #'19423 (function_call 106) (function_declaration_statement 19424) (if_stmt 19425) (if_stmt_without_else 19426) (inline_function 110) (inner_statement 19427) (interface_declaration_statement 19428) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19429) (static_member 119) (trait_declaration_statement 19430) (variable 122) (variable_class_name 123) ("{" 19431) ("~" 125)) 13721 ((";" 28394)) 13722 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 28397) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 13723 ((";" 28398)) 13724 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 28399) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 13725 ((";" 28400)) 13726 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 19558) (fn 2394) (for_exprs 28401) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (non_empty_for_exprs 19560) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 13727 ((")" 28402)) 13728 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 28403) (";" 28276) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 28277) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 28278) (T_DEC 22) (T_DECLARE 28279) (T_DIR 24) (T_DNUMBER 25) (T_DO 28280) (T_DOUBLE_CAST 27) (T_ECHO 28281) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 28282) (T_FOREACH 28283) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 28284) (T_GOTO 28285) (T_IF 28286) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 28287) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 28288) (T_START_HEREDOC 68) (T_STATIC 28289) (T_STRING 28290) (T_STRING_CAST 71) (T_SWITCH 28291) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 28292) (T_UNSET 28293) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 28294) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 28295) (alt_if_stmt_without_else 28296) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 28297) (fn 103) (for_statement 28404) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 28298) (if_stmt_without_else 28299) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 28405) (static_member 119) (variable 122) (variable_class_name 123) ("{" 28301) ("~" 125)) 13729 ((inner_statement_list 28406)) 13730 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19568) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19569) (T_CLASS 19570) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19571) (T_DEC 22) (T_DECLARE 19572) (T_DIR 24) (T_DNUMBER 25) (T_DO 19573) (T_DOUBLE_CAST 27) (T_ECHO 19574) (T_EMPTY 29) (T_ENDFOR 28407) (T_ENUM 19576) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19577) (T_FOREACH 19578) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19579) (T_GOTO 19580) (T_HALT_COMPILER 19581) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19583) (T_INTERFACE 19584) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19585) (T_START_HEREDOC 68) (T_STATIC 19586) (T_STRING 19587) (T_STRING_CAST 71) (T_SWITCH 19588) (T_THROW 73) (T_TRAIT 19589) (T_TRAIT_C 75) (T_TRY 19590) (T_UNSET 19591) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19592) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19593) (alt_if_stmt_without_else 19594) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19595) (attributes 19596) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19597) (class_modifier 96) (class_modifiers 19598) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19599) (expr 19600) (fn 103) (fully_dereferenceable 104) #'19601 (function_call 106) (function_declaration_statement 19602) (if_stmt 19603) (if_stmt_without_else 19604) (inline_function 110) (inner_statement 19605) (interface_declaration_statement 19606) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19607) (static_member 119) (trait_declaration_statement 19608) (variable 122) (variable_class_name 123) ("{" 19609) ("~" 125)) 13731 ((";" 28408)) 13732 (("," 19743) (";" 28410)) 13733 ((T_WHILE 28412)) 13734 (("(" 28413)) 13735 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 28414) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 13736 (("%" 292) (")" 28415) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 13737 ((";" 28416)) 13738 ((T_STRING 19916) (const_decl 19917) (const_list 28418)) 13739 ((")" 28419) ("," 19920)) 13740 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 28420) (";" 28276) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 28277) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 28278) (T_DEC 22) (T_DECLARE 28279) (T_DIR 24) (T_DNUMBER 25) (T_DO 28280) (T_DOUBLE_CAST 27) (T_ECHO 28281) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 28282) (T_FOREACH 28283) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 28284) (T_GOTO 28285) (T_IF 28286) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 28287) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 28288) (T_START_HEREDOC 68) (T_STATIC 28289) (T_STRING 28290) (T_STRING_CAST 71) (T_SWITCH 28291) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 28292) (T_UNSET 28293) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 28294) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 28295) (alt_if_stmt_without_else 28296) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (declare_statement 28421) (dereferenceable_scalar 100) (expr 28297) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 28298) (if_stmt_without_else 28299) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 28422) (static_member 119) (variable 122) (variable_class_name 123) ("{" 28301) ("~" 125)) 13741 ((inner_statement_list 28423)) 13742 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19926) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19927) (T_CLASS 19928) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19929) (T_DEC 22) (T_DECLARE 19930) (T_DIR 24) (T_DNUMBER 25) (T_DO 19931) (T_DOUBLE_CAST 27) (T_ECHO 19932) (T_EMPTY 29) (T_ENDDECLARE 28424) (T_ENUM 19934) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19935) (T_FOREACH 19936) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19937) (T_GOTO 19938) (T_HALT_COMPILER 19939) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19941) (T_INTERFACE 19942) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19943) (T_START_HEREDOC 68) (T_STATIC 19944) (T_STRING 19945) (T_STRING_CAST 71) (T_SWITCH 19946) (T_THROW 73) (T_TRAIT 19947) (T_TRAIT_C 75) (T_TRY 19948) (T_UNSET 19949) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19950) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19951) (alt_if_stmt_without_else 19952) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19953) (attributes 19954) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19955) (class_modifier 96) (class_modifiers 19956) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19957) (expr 19958) (fn 103) (fully_dereferenceable 104) #'19959 (function_call 106) (function_declaration_statement 19960) (if_stmt 19961) (if_stmt_without_else 19962) (inline_function 110) (inner_statement 19963) (interface_declaration_statement 19964) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19965) (static_member 119) (trait_declaration_statement 19966) (variable 122) (variable_class_name 123) ("{" 19967) ("~" 125)) 13743 ((";" 28425)) 13744 ((";" 28427)) 13745 ((";" 28429)) 13746 ((")" 28431)) 13747 ((";" 28432)) 13748 ((";" 28434)) 13749 (("," 17875) (";" 28436)) 13750 (("!" 17883) ("\"" 17884) ("$" 17885) ("(" 17886) ("+" 17887) ("-" 17888) ("@" 17889) (T_ARRAY 17890) (T_ARRAY_CAST 17891) (T_ATTRIBUTE 126) (T_BOOL_CAST 17892) (T_CLASS_C 17893) (T_CLONE 17894) (T_CONSTANT_ENCAPSED_STRING 17895) (T_DEC 17896) (T_DIR 17897) (T_DNUMBER 17898) (T_DOUBLE_CAST 17899) (T_EMPTY 17900) (T_EVAL 17901) (T_EXIT 17902) (T_FILE 17903) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 17904) (T_INC 17905) (T_INCLUDE 17906) (T_INCLUDE_ONCE 17907) (T_INT_CAST 17908) (T_ISSET 17909) (T_LINE 17910) (T_LIST 17911) (T_LNUMBER 17912) (T_MATCH 17913) (T_METHOD_C 17914) (T_NAME_FULLY_QUALIFIED 17915) (T_NAME_QUALIFIED 17916) (T_NAME_RELATIVE 17917) (T_NEW 17918) (T_NS_C 17919) (T_OBJECT_CAST 17920) (T_PRINT 17921) (T_READONLY 17922) (T_REQUIRE 17923) (T_REQUIRE_ONCE 17924) (T_START_HEREDOC 17925) (T_STATIC 17926) (T_STRING 17927) (T_STRING_CAST 17928) (T_THROW 17929) (T_TRAIT_C 17930) (T_UNSET_CAST 17931) (T_VARIABLE 17932) (T_YIELD 17933) (T_YIELD_FROM 17934) ("[" 17935) ("`" 17936) (array_object_dereferenceable 17937) (attribute 131) (attributes 17938) (callable_expr 17939) (callable_variable 17940) (class_constant 17941) (class_name 17942) (constant 17943) (dereferenceable_scalar 17944) (expr 28438) (fn 17946) (fully_dereferenceable 104) #'17947 (function_call 17948) (inline_function 17949) (internal_functions_in_yacc 17950) (match 17951) (name 17952) (new_expr 17953) (scalar 17954) (simple_variable 17955) (static_member 17956) (variable 17957) (variable_class_name 17958) ("~" 17959)) 13751 (("%" 17961) ("*" 17962) ("+" 17963) ("-" 17964) ("." 17965) ("/" 17966) ("<" 17967) (">" 17968) ("?" 17969) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 17970) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 17971) (T_AS 28439) (T_BOOLEAN_AND 17972) (T_BOOLEAN_OR 17973) (T_COALESCE 17974) (T_INSTANCEOF 17975) (T_IS_EQUAL 17976) (T_IS_GREATER_OR_EQUAL 17977) (T_IS_IDENTICAL 17978) (T_IS_NOT_EQUAL 17979) (T_IS_NOT_IDENTICAL 17980) (T_IS_SMALLER_OR_EQUAL 17981) (T_LOGICAL_AND 17982) (T_LOGICAL_OR 17983) (T_LOGICAL_XOR 17984) (T_POW 17985) (T_SL 17986) (T_SPACESHIP 17987) (T_SR 17988) ("^" 17989) ("|" 17990)) 13752 (("\"" 1509) ("$" 19325) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19326) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19327) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19328) ("[" 19329) (ampersand 19330) (array_object_dereferenceable 19331) (callable_expr 19332) (callable_variable 19333) (class_constant 1533) (class_name 19334) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 28440) (fully_dereferenceable 104) (function_call 19336) (name 19337) (simple_variable 19338) (static_member 19339) (variable 19340) (variable_class_name 19341)) 13753 ((")" 28441) (T_DOUBLE_ARROW 28442)) 13754 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 28445) (";" 8) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 15) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 21) (T_DEC 22) (T_DECLARE 23) (T_DIR 24) (T_DNUMBER 25) (T_DO 26) (T_DOUBLE_CAST 27) (T_ECHO 28) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 36) (T_FOREACH 37) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 40) (T_GOTO 41) (T_IF 43) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 47) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 67) (T_START_HEREDOC 68) (T_STATIC 69) (T_STRING 70) (T_STRING_CAST 71) (T_SWITCH 72) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 76) (T_UNSET 77) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 81) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 86) (alt_if_stmt_without_else 87) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 102) (fn 103) (foreach_statement 28451) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 108) (if_stmt_without_else 109) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 28447) (static_member 119) (variable 122) (variable_class_name 123) ("{" 124) ("~" 125)) 13755 (("\"" 1509) ("$" 19356) ("(" 1511) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1512) (T_CLASS_C 1513) (T_CONSTANT_ENCAPSED_STRING 1514) (T_DIR 1515) (T_FILE 1516) (T_FUNC_C 1517) (T_LINE 1518) (T_LIST 19357) (T_METHOD_C 1519) (T_NAME_FULLY_QUALIFIED 1520) (T_NAME_QUALIFIED 1521) (T_NAME_RELATIVE 1522) (T_NS_C 1523) (T_READONLY 19358) (T_STATIC 1525) (T_STRING 1526) (T_TRAIT_C 1527) (T_VARIABLE 19359) ("[" 19360) (ampersand 19361) (array_object_dereferenceable 19362) (callable_expr 19363) (callable_variable 19364) (class_constant 1533) (class_name 19365) (constant 1535) (dereferenceable_scalar 1536) (foreach_variable 28443) (fully_dereferenceable 104) (function_call 19367) (name 19368) (simple_variable 19369) (static_member 19370) (variable 19371) (variable_class_name 19372)) 13756 ((")" 28444)) 13757 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 28445) (";" 8) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 15) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 21) (T_DEC 22) (T_DECLARE 23) (T_DIR 24) (T_DNUMBER 25) (T_DO 26) (T_DOUBLE_CAST 27) (T_ECHO 28) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 36) (T_FOREACH 37) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 40) (T_GOTO 41) (T_IF 43) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 47) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 67) (T_START_HEREDOC 68) (T_STATIC 69) (T_STRING 70) (T_STRING_CAST 71) (T_SWITCH 72) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 76) (T_UNSET 77) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 81) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 86) (alt_if_stmt_without_else 87) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 102) (fn 103) (foreach_statement 28446) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 108) (if_stmt_without_else 109) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 28447) (static_member 119) (variable 122) (variable_class_name 123) ("{" 124) ("~" 125)) 13758 ((inner_statement_list 28448)) 13759 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19390) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19391) (T_CLASS 19392) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19393) (T_DEC 22) (T_DECLARE 19394) (T_DIR 24) (T_DNUMBER 25) (T_DO 19395) (T_DOUBLE_CAST 27) (T_ECHO 19396) (T_EMPTY 29) (T_ENDFOREACH 28449) (T_ENUM 19398) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19399) (T_FOREACH 19400) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19401) (T_GOTO 19402) (T_HALT_COMPILER 19403) (T_IF 19404) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19405) (T_INTERFACE 19406) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19407) (T_START_HEREDOC 68) (T_STATIC 19408) (T_STRING 19409) (T_STRING_CAST 71) (T_SWITCH 19410) (T_THROW 73) (T_TRAIT 19411) (T_TRAIT_C 75) (T_TRY 19412) (T_UNSET 19413) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19414) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19415) (alt_if_stmt_without_else 19416) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19417) (attributes 19418) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19419) (class_modifier 96) (class_modifiers 19420) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19421) (expr 19422) (fn 103) (fully_dereferenceable 104) #'19423 (function_call 106) (function_declaration_statement 19424) (if_stmt 19425) (if_stmt_without_else 19426) (inline_function 110) (inner_statement 19427) (interface_declaration_statement 19428) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19429) (static_member 119) (trait_declaration_statement 19430) (variable 122) (variable_class_name 123) ("{" 19431) ("~" 125)) 13760 ((";" 28450)) 13761 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 28453) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 13762 ((";" 28454)) 13763 (("!" 16856) ("\"" 16857) ("$" 16858) ("(" 16859) ("+" 16860) ("-" 16861) ("@" 16862) (T_ARRAY 16863) (T_ARRAY_CAST 16864) (T_ATTRIBUTE 126) (T_BOOL_CAST 16865) (T_CLASS_C 16866) (T_CLONE 16867) (T_CONSTANT_ENCAPSED_STRING 16868) (T_DEC 16869) (T_DIR 16870) (T_DNUMBER 16871) (T_DOUBLE_CAST 16872) (T_EMPTY 16873) (T_EVAL 16874) (T_EXIT 16875) (T_FILE 16876) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 16877) (T_INC 16878) (T_INCLUDE 16879) (T_INCLUDE_ONCE 16880) (T_INT_CAST 16881) (T_ISSET 16882) (T_LINE 16883) (T_LIST 16884) (T_LNUMBER 16885) (T_MATCH 16886) (T_METHOD_C 16887) (T_NAME_FULLY_QUALIFIED 16888) (T_NAME_QUALIFIED 16889) (T_NAME_RELATIVE 16890) (T_NEW 16891) (T_NS_C 16892) (T_OBJECT_CAST 16893) (T_PRINT 16894) (T_READONLY 16895) (T_REQUIRE 16896) (T_REQUIRE_ONCE 16897) (T_START_HEREDOC 16898) (T_STATIC 16899) (T_STRING 16900) (T_STRING_CAST 16901) (T_THROW 16902) (T_TRAIT_C 16903) (T_UNSET_CAST 16904) (T_VARIABLE 16905) (T_YIELD 16906) (T_YIELD_FROM 16907) ("[" 16908) ("`" 16909) (array_object_dereferenceable 16910) (attribute 131) (attributes 16911) (callable_expr 16912) (callable_variable 16913) (class_constant 16914) (class_name 16915) (constant 16916) (dereferenceable_scalar 16917) (expr 19550) (fn 16919) (for_exprs 28455) (fully_dereferenceable 104) #'16920 (function_call 16921) (inline_function 16922) (internal_functions_in_yacc 16923) (match 16924) (name 16925) (new_expr 16926) (non_empty_for_exprs 19552) (scalar 16927) (simple_variable 16928) (static_member 16929) (variable 16930) (variable_class_name 16931) ("~" 16932)) 13764 ((";" 28456)) 13765 (("!" 2330) ("\"" 2331) ("$" 2332) ("(" 2333) ("+" 2334) ("-" 2335) ("@" 2336) (T_ARRAY 2337) (T_ARRAY_CAST 2338) (T_ATTRIBUTE 126) (T_BOOL_CAST 2339) (T_CLASS_C 2340) (T_CLONE 2341) (T_CONSTANT_ENCAPSED_STRING 2342) (T_DEC 2343) (T_DIR 2344) (T_DNUMBER 2345) (T_DOUBLE_CAST 2346) (T_EMPTY 2347) (T_EVAL 2348) (T_EXIT 2349) (T_FILE 2350) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 2351) (T_INC 2352) (T_INCLUDE 2353) (T_INCLUDE_ONCE 2354) (T_INT_CAST 2355) (T_ISSET 2356) (T_LINE 2357) (T_LIST 2408) (T_LNUMBER 2359) (T_MATCH 2360) (T_METHOD_C 2361) (T_NAME_FULLY_QUALIFIED 2362) (T_NAME_QUALIFIED 2363) (T_NAME_RELATIVE 2364) (T_NEW 2365) (T_NS_C 2366) (T_OBJECT_CAST 2367) (T_PRINT 2368) (T_READONLY 2369) (T_REQUIRE 2370) (T_REQUIRE_ONCE 2371) (T_START_HEREDOC 2372) (T_STATIC 2373) (T_STRING 2374) (T_STRING_CAST 2375) (T_THROW 2376) (T_TRAIT_C 2377) (T_UNSET_CAST 2378) (T_VARIABLE 2379) (T_YIELD 2380) (T_YIELD_FROM 2381) ("[" 2382) ("`" 2383) (array_object_dereferenceable 2385) (attribute 131) (attributes 2386) (callable_expr 2387) (callable_variable 2388) (class_constant 2389) (class_name 2390) (constant 2391) (dereferenceable_scalar 2392) (expr 19558) (fn 2394) (for_exprs 28457) (fully_dereferenceable 104) #'2395 (function_call 2396) (inline_function 2397) (internal_functions_in_yacc 2398) (match 2399) (name 2400) (new_expr 2401) (non_empty_for_exprs 19560) (scalar 2402) (simple_variable 2403) (static_member 2404) (variable 2405) (variable_class_name 2406) ("~" 2407)) 13766 ((")" 28458)) 13767 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 28459) (";" 8) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 15) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 21) (T_DEC 22) (T_DECLARE 23) (T_DIR 24) (T_DNUMBER 25) (T_DO 26) (T_DOUBLE_CAST 27) (T_ECHO 28) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 36) (T_FOREACH 37) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 40) (T_GOTO 41) (T_IF 43) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 47) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 67) (T_START_HEREDOC 68) (T_STATIC 69) (T_STRING 70) (T_STRING_CAST 71) (T_SWITCH 72) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 76) (T_UNSET 77) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 81) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 86) (alt_if_stmt_without_else 87) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (dereferenceable_scalar 100) (expr 102) (fn 103) (for_statement 28460) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 108) (if_stmt_without_else 109) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 28461) (static_member 119) (variable 122) (variable_class_name 123) ("{" 124) ("~" 125)) 13768 ((inner_statement_list 28462)) 13769 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19568) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19569) (T_CLASS 19570) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19571) (T_DEC 22) (T_DECLARE 19572) (T_DIR 24) (T_DNUMBER 25) (T_DO 19573) (T_DOUBLE_CAST 27) (T_ECHO 19574) (T_EMPTY 29) (T_ENDFOR 28463) (T_ENUM 19576) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19577) (T_FOREACH 19578) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19579) (T_GOTO 19580) (T_HALT_COMPILER 19581) (T_IF 19582) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19583) (T_INTERFACE 19584) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19585) (T_START_HEREDOC 68) (T_STATIC 19586) (T_STRING 19587) (T_STRING_CAST 71) (T_SWITCH 19588) (T_THROW 73) (T_TRAIT 19589) (T_TRAIT_C 75) (T_TRY 19590) (T_UNSET 19591) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19592) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19593) (alt_if_stmt_without_else 19594) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19595) (attributes 19596) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19597) (class_modifier 96) (class_modifiers 19598) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19599) (expr 19600) (fn 103) (fully_dereferenceable 104) #'19601 (function_call 106) (function_declaration_statement 19602) (if_stmt 19603) (if_stmt_without_else 19604) (inline_function 110) (inner_statement 19605) (interface_declaration_statement 19606) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19607) (static_member 119) (trait_declaration_statement 19608) (variable 122) (variable_class_name 123) ("{" 19609) ("~" 125)) 13770 ((";" 28464)) 13771 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 5268) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (optional_expr 28467) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 13772 ((")" 28468)) 13773 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 28470) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 13774 (("%" 292) (")" 28471) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 13775 ((":" 20258) (enum_backing_type 28473)) 13776 ((T_IMPLEMENTS 2987) (implements_list 28474)) 13777 ((backup_doc_comment 28475)) 13778 (("{" 28476)) 13779 ((class_statement_list 28477)) 13780 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 28478)) 13781 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 28480) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 13782 (("%" 292) (")" 28481) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 13783 (("," 19743) (";" 28483)) 13784 ((T_WHILE 28486)) 13785 (("(" 28487)) 13786 (("!" 214) ("\"" 215) ("$" 216) ("(" 217) ("+" 218) ("-" 219) ("@" 220) (T_ARRAY 221) (T_ARRAY_CAST 222) (T_ATTRIBUTE 126) (T_BOOL_CAST 223) (T_CLASS_C 224) (T_CLONE 225) (T_CONSTANT_ENCAPSED_STRING 226) (T_DEC 227) (T_DIR 228) (T_DNUMBER 229) (T_DOUBLE_CAST 230) (T_EMPTY 231) (T_EVAL 232) (T_EXIT 233) (T_FILE 234) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 235) (T_INC 236) (T_INCLUDE 237) (T_INCLUDE_ONCE 238) (T_INT_CAST 239) (T_ISSET 240) (T_LINE 241) (T_LIST 242) (T_LNUMBER 243) (T_MATCH 244) (T_METHOD_C 245) (T_NAME_FULLY_QUALIFIED 246) (T_NAME_QUALIFIED 247) (T_NAME_RELATIVE 248) (T_NEW 249) (T_NS_C 250) (T_OBJECT_CAST 251) (T_PRINT 252) (T_READONLY 253) (T_REQUIRE 254) (T_REQUIRE_ONCE 255) (T_START_HEREDOC 256) (T_STATIC 257) (T_STRING 258) (T_STRING_CAST 259) (T_THROW 260) (T_TRAIT_C 261) (T_UNSET_CAST 262) (T_VARIABLE 263) (T_YIELD 264) (T_YIELD_FROM 265) ("[" 266) ("`" 267) (array_object_dereferenceable 268) (attribute 131) (attributes 269) (callable_expr 270) (callable_variable 271) (class_constant 272) (class_name 273) (constant 274) (dereferenceable_scalar 275) (expr 28488) (fn 277) (fully_dereferenceable 104) #'278 (function_call 279) (inline_function 280) (internal_functions_in_yacc 281) (match 282) (name 283) (new_expr 284) (scalar 285) (simple_variable 286) (static_member 287) (variable 288) (variable_class_name 289) ("~" 290)) 13787 (("%" 292) (")" 28489) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 13788 ((";" 28490)) 13789 ((T_STRING 19916) (const_decl 19917) (const_list 28492)) 13790 ((")" 28493) ("," 19920)) 13791 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (":" 28494) (";" 8) ("@" 9) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 126) (T_BOOL_CAST 14) (T_BREAK 15) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 21) (T_DEC 22) (T_DECLARE 23) (T_DIR 24) (T_DNUMBER 25) (T_DO 26) (T_DOUBLE_CAST 27) (T_ECHO 28) (T_EMPTY 29) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FN 35) (T_FOR 36) (T_FOREACH 37) (T_FUNCTION 127) (T_FUNC_C 39) (T_GLOBAL 40) (T_GOTO 41) (T_IF 43) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 47) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 128) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 67) (T_START_HEREDOC 68) (T_STATIC 69) (T_STRING 70) (T_STRING_CAST 71) (T_SWITCH 72) (T_THROW 73) (T_TRAIT_C 75) (T_TRY 76) (T_UNSET 77) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 81) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 86) (alt_if_stmt_without_else 87) (array_object_dereferenceable 88) (attribute 131) (attributes 132) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_name 98) (constant 99) (declare_statement 28495) (dereferenceable_scalar 100) (expr 102) (fn 103) (fully_dereferenceable 104) #'134 (function_call 106) (if_stmt 108) (if_stmt_without_else 109) (inline_function 110) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 28496) (static_member 119) (variable 122) (variable_class_name 123) ("{" 124) ("~" 125)) 13792 ((inner_statement_list 28497)) 13793 (("!" 2) ("\"" 3) ("$" 4) ("(" 5) ("+" 6) ("-" 7) (";" 19926) ("@" 9) (T_ABSTRACT 10) (T_ARRAY 11) (T_ARRAY_CAST 12) (T_ATTRIBUTE 13) (T_BOOL_CAST 14) (T_BREAK 19927) (T_CLASS 19928) (T_CLASS_C 17) (T_CLONE 18) (T_CONSTANT_ENCAPSED_STRING 20) (T_CONTINUE 19929) (T_DEC 22) (T_DECLARE 19930) (T_DIR 24) (T_DNUMBER 25) (T_DO 19931) (T_DOUBLE_CAST 27) (T_ECHO 19932) (T_EMPTY 29) (T_ENDDECLARE 28498) (T_ENUM 19934) (T_EVAL 31) (T_EXIT 32) (T_FILE 33) (T_FINAL 34) (T_FN 35) (T_FOR 19935) (T_FOREACH 19936) (T_FUNCTION 38) (T_FUNC_C 39) (T_GLOBAL 19937) (T_GOTO 19938) (T_HALT_COMPILER 19939) (T_IF 19940) (T_INC 44) (T_INCLUDE 45) (T_INCLUDE_ONCE 46) (T_INLINE_HTML 19941) (T_INTERFACE 19942) (T_INT_CAST 49) (T_ISSET 50) (T_LINE 51) (T_LIST 52) (T_LNUMBER 53) (T_MATCH 54) (T_METHOD_C 55) (T_NAME_FULLY_QUALIFIED 57) (T_NAME_QUALIFIED 58) (T_NAME_RELATIVE 59) (T_NEW 60) (T_NS_C 61) (T_OBJECT_CAST 62) (T_PRINT 63) (T_READONLY 64) (T_REQUIRE 65) (T_REQUIRE_ONCE 66) (T_RETURN 19943) (T_START_HEREDOC 68) (T_STATIC 19944) (T_STRING 19945) (T_STRING_CAST 71) (T_SWITCH 19946) (T_THROW 73) (T_TRAIT 19947) (T_TRAIT_C 75) (T_TRY 19948) (T_UNSET 19949) (T_UNSET_CAST 78) (T_VARIABLE 80) (T_WHILE 19950) (T_YIELD 82) (T_YIELD_FROM 83) ("[" 84) ("`" 85) (alt_if_stmt 19951) (alt_if_stmt_without_else 19952) (array_object_dereferenceable 88) (attribute 89) (attributed_statement 19953) (attributes 19954) (callable_expr 92) (callable_variable 93) (class_constant 94) (class_declaration_statement 19955) (class_modifier 96) (class_modifiers 19956) (class_name 98) (constant 99) (dereferenceable_scalar 100) (enum_declaration_statement 19957) (expr 19958) (fn 103) (fully_dereferenceable 104) #'19959 (function_call 106) (function_declaration_statement 19960) (if_stmt 19961) (if_stmt_without_else 19962) (inline_function 110) (inner_statement 19963) (interface_declaration_statement 19964) (internal_functions_in_yacc 112) (match 113) (name 114) (new_expr 115) (scalar 116) (simple_variable 117) (statement 19965) (static_member 119) (trait_declaration_statement 19966) (variable 122) (variable_class_name 123) ("{" 19967) ("~" 125)) 13794 ((";" 28499)) 13795 ((";" 28502)) 13796 (("," 28229) (";" 28504)) 13797 ((T_EXTENDS 2985) (extends_from 28507)) 13798 ((T_IMPLEMENTS 2987) (implements_list 28508)) 13799 ((backup_doc_comment 28509)) 13800 (("{" 28510)) 13801 ((class_statement_list 28511)) 13802 ((T_ABSTRACT 2992) (T_ATTRIBUTE 2993) (T_CASE 2994) (T_FINAL 2995) (T_PRIVATE 2996) (T_PROTECTED 2997) (T_PUBLIC 2998) (T_READONLY 2999) (T_STATIC 3000) (T_USE 3001) (T_VAR 3002) (attribute 3003) (attributed_class_statement 3004) (attributes 3005) (class_const_modifiers 3006) (class_statement 3007) (enum_case 3008) (member_modifier 3009) (method_modifiers 3010) (non_empty_member_modifiers 3011) (property_modifiers 3012) ("}" 28512)) 13803 ((";" 28514)) 13804 (("," 6583) (possible_comma 28517)) 13805 (("]" 28518)) 13806 (("!" 1852) ("\"" 1853) ("$" 1854) ("(" 1855) ("+" 1856) ("-" 1857) ("@" 1858) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 1505) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 1506) (T_ARRAY 1859) (T_ARRAY_CAST 1860) (T_ATTRIBUTE 126) (T_BOOL_CAST 1861) (T_CLASS_C 1862) (T_CLONE 1863) (T_CONSTANT_ENCAPSED_STRING 1864) (T_DEC 1865) (T_DIR 1866) (T_DNUMBER 1867) (T_DOUBLE_CAST 1868) (T_ELLIPSIS 1869) (T_EMPTY 1870) (T_EVAL 1871) (T_EXIT 1872) (T_FILE 1873) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 1874) (T_INC 1875) (T_INCLUDE 1876) (T_INCLUDE_ONCE 1877) (T_INT_CAST 1878) (T_ISSET 1879) (T_LINE 1880) (T_LIST 1881) (T_LNUMBER 1882) (T_MATCH 1883) (T_METHOD_C 1884) (T_NAME_FULLY_QUALIFIED 1885) (T_NAME_QUALIFIED 1886) (T_NAME_RELATIVE 1887) (T_NEW 1888) (T_NS_C 1889) (T_OBJECT_CAST 1890) (T_PRINT 1891) (T_READONLY 1892) (T_REQUIRE 1893) (T_REQUIRE_ONCE 1894) (T_START_HEREDOC 1895) (T_STATIC 1896) (T_STRING 1897) (T_STRING_CAST 1898) (T_THROW 1899) (T_TRAIT_C 1900) (T_UNSET_CAST 1901) (T_VARIABLE 1902) (T_YIELD 1903) (T_YIELD_FROM 1904) ("[" 1905) ("`" 1906) (ampersand 1907) (array_object_dereferenceable 1908) (array_pair 1909) (array_pair_list 28521) (attribute 131) (attributes 1911) (callable_expr 1912) (callable_variable 1913) (class_constant 1914) (class_name 1915) (constant 1916) (dereferenceable_scalar 1917) (expr 1918) (fn 1919) (fully_dereferenceable 104) #'1920 (function_call 1921) (inline_function 1922) (internal_functions_in_yacc 1923) (match 1924) (name 1925) (new_expr 1926) (non_empty_array_pair_list 1927) (possible_array_pair 1928) (scalar 1929) (simple_variable 1930) (static_member 1931) (variable 1932) (variable_class_name 1933) ("~" 1934)) 13807 ((")" 28522)) 13808 (("%" 292) (")" 28527) ("*" 293) ("+" 294) ("-" 295) ("." 296) ("/" 297) ("<" 298) (">" 299) ("?" 300) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 301) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 302) (T_BOOLEAN_AND 303) (T_BOOLEAN_OR 304) (T_COALESCE 305) (T_INSTANCEOF 306) (T_IS_EQUAL 307) (T_IS_GREATER_OR_EQUAL 308) (T_IS_IDENTICAL 309) (T_IS_NOT_EQUAL 310) (T_IS_NOT_IDENTICAL 311) (T_IS_SMALLER_OR_EQUAL 312) (T_LOGICAL_AND 313) (T_LOGICAL_OR 314) (T_LOGICAL_XOR 315) (T_POW 316) (T_SL 317) (T_SPACESHIP 318) (T_SR 319) ("^" 320) ("|" 321)) 13809 (("!" 355) ("\"" 356) ("$" 357) ("(" 358) ("+" 359) ("-" 360) ("@" 361) (T_ARRAY 362) (T_ARRAY_CAST 363) (T_ATTRIBUTE 126) (T_BOOL_CAST 364) (T_CLASS_C 365) (T_CLONE 366) (T_CONSTANT_ENCAPSED_STRING 367) (T_DEC 368) (T_DIR 369) (T_DNUMBER 370) (T_DOUBLE_CAST 371) (T_EMPTY 372) (T_EVAL 373) (T_EXIT 374) (T_FILE 375) (T_FN 35) (T_FUNCTION 127) (T_FUNC_C 376) (T_INC 377) (T_INCLUDE 378) (T_INCLUDE_ONCE 379) (T_INT_CAST 380) (T_ISSET 381) (T_LINE 382) (T_LIST 383) (T_LNUMBER 384) (T_MATCH 385) (T_METHOD_C 386) (T_NAME_FULLY_QUALIFIED 387) (T_NAME_QUALIFIED 388) (T_NAME_RELATIVE 389) (T_NEW 390) (T_NS_C 391) (T_OBJECT_CAST 392) (T_PRINT 393) (T_READONLY 394) (T_REQUIRE 395) (T_REQUIRE_ONCE 396) (T_START_HEREDOC 397) (T_STATIC 398) (T_STRING 399) (T_STRING_CAST 400) (T_THROW 401) (T_TRAIT_C 402) (T_UNSET_CAST 403) (T_VARIABLE 404) (T_YIELD 405) (T_YIELD_FROM 406) ("[" 407) ("`" 408) (array_object_dereferenceable 409) (attribute 131) (attributes 410) (callable_expr 411) (callable_variable 412) (class_constant 413) (class_name 414) (constant 415) (dereferenceable_scalar 416) (expr 28530) (fn 418) (fully_dereferenceable 104) #'419 (function_call 420) (inline_function 421) (internal_functions_in_yacc 422) (match 423) (name 424) (new_expr 425) (scalar 426) (simple_variable 427) (static_member 428) (variable 429) (variable_class_name 430) ("~" 431)) 13810 (("%" 433) ("*" 434) ("+" 435) ("-" 436) ("." 437) ("/" 438) ("<" 439) (">" 440) ("?" 441) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG 442) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG 443) (T_BOOLEAN_AND 444) (T_BOOLEAN_OR 445) (T_COALESCE 446) (T_INSTANCEOF 447) (T_IS_EQUAL 448) (T_IS_GREATER_OR_EQUAL 449) (T_IS_IDENTICAL 450) (T_IS_NOT_EQUAL 451) (T_IS_NOT_IDENTICAL 452) (T_IS_SMALLER_OR_EQUAL 453) (T_LOGICAL_AND 454) (T_LOGICAL_OR 455) (T_LOGICAL_XOR 456) (T_POW 457) (T_SL 458) (T_SPACESHIP 459) (T_SR 460) ("^" 461) ("|" 462) ("}" 28531)) 13811 (("\"" 28533) (T_CURLY_OPEN 5294) (T_DOLLAR_OPEN_CURLY_BRACES 5295) (T_ENCAPSED_AND_WHITESPACE 5301) (T_VARIABLE 5297) (encaps_var 5302))))
  "The generated distinct goto-tables.")

(defvar
  phps-mode-parser--table-productions-number-reverse
  #s(hash-table size 730 test equal rehash-size 1.5 rehash-threshold 0.8125 data (0 ((start) (top_statement_list)) 1 ((reserved_non_modifiers) (T_INCLUDE)) 2 ((reserved_non_modifiers) (T_INCLUDE_ONCE)) 3 ((reserved_non_modifiers) (T_EVAL)) 4 ((reserved_non_modifiers) (T_REQUIRE)) 5 ((reserved_non_modifiers) (T_REQUIRE_ONCE)) 6 ((reserved_non_modifiers) (T_LOGICAL_OR)) 7 ((reserved_non_modifiers) (T_LOGICAL_XOR)) 8 ((reserved_non_modifiers) (T_LOGICAL_AND)) 9 ((reserved_non_modifiers) (T_INSTANCEOF)) 10 ((reserved_non_modifiers) (T_NEW)) 11 ((reserved_non_modifiers) (T_CLONE)) 12 ((reserved_non_modifiers) (T_EXIT)) 13 ((reserved_non_modifiers) (T_IF)) 14 ((reserved_non_modifiers) (T_ELSEIF)) 15 ((reserved_non_modifiers) (T_ELSE)) 16 ((reserved_non_modifiers) (T_ENDIF)) 17 ((reserved_non_modifiers) (T_ECHO)) 18 ((reserved_non_modifiers) (T_DO)) 19 ((reserved_non_modifiers) (T_WHILE)) 20 ((reserved_non_modifiers) (T_ENDWHILE)) 21 ((reserved_non_modifiers) (T_FOR)) 22 ((reserved_non_modifiers) (T_ENDFOR)) 23 ((reserved_non_modifiers) (T_FOREACH)) 24 ((reserved_non_modifiers) (T_ENDFOREACH)) 25 ((reserved_non_modifiers) (T_DECLARE)) 26 ((reserved_non_modifiers) (T_ENDDECLARE)) 27 ((reserved_non_modifiers) (T_AS)) 28 ((reserved_non_modifiers) (T_TRY)) 29 ((reserved_non_modifiers) (T_CATCH)) 30 ((reserved_non_modifiers) (T_FINALLY)) 31 ((reserved_non_modifiers) (T_THROW)) 32 ((reserved_non_modifiers) (T_USE)) 33 ((reserved_non_modifiers) (T_INSTEADOF)) 34 ((reserved_non_modifiers) (T_GLOBAL)) 35 ((reserved_non_modifiers) (T_VAR)) 36 ((reserved_non_modifiers) (T_UNSET)) 37 ((reserved_non_modifiers) (T_ISSET)) 38 ((reserved_non_modifiers) (T_EMPTY)) 39 ((reserved_non_modifiers) (T_CONTINUE)) 40 ((reserved_non_modifiers) (T_GOTO)) 41 ((reserved_non_modifiers) (T_FUNCTION)) 42 ((reserved_non_modifiers) (T_CONST)) 43 ((reserved_non_modifiers) (T_RETURN)) 44 ((reserved_non_modifiers) (T_PRINT)) 45 ((reserved_non_modifiers) (T_YIELD)) 46 ((reserved_non_modifiers) (T_LIST)) 47 ((reserved_non_modifiers) (T_SWITCH)) 48 ((reserved_non_modifiers) (T_ENDSWITCH)) 49 ((reserved_non_modifiers) (T_CASE)) 50 ((reserved_non_modifiers) (T_DEFAULT)) 51 ((reserved_non_modifiers) (T_BREAK)) 52 ((reserved_non_modifiers) (T_ARRAY)) 53 ((reserved_non_modifiers) (T_CALLABLE)) 54 ((reserved_non_modifiers) (T_EXTENDS)) 55 ((reserved_non_modifiers) (T_IMPLEMENTS)) 56 ((reserved_non_modifiers) (T_NAMESPACE)) 57 ((reserved_non_modifiers) (T_TRAIT)) 58 ((reserved_non_modifiers) (T_INTERFACE)) 59 ((reserved_non_modifiers) (T_CLASS)) 60 ((reserved_non_modifiers) (T_CLASS_C)) 61 ((reserved_non_modifiers) (T_TRAIT_C)) 62 ((reserved_non_modifiers) (T_FUNC_C)) 63 ((reserved_non_modifiers) (T_METHOD_C)) 64 ((reserved_non_modifiers) (T_LINE)) 65 ((reserved_non_modifiers) (T_FILE)) 66 ((reserved_non_modifiers) (T_DIR)) 67 ((reserved_non_modifiers) (T_NS_C)) 68 ((reserved_non_modifiers) (T_FN)) 69 ((reserved_non_modifiers) (T_MATCH)) 70 ((reserved_non_modifiers) (T_ENUM)) 71 ((semi_reserved) (reserved_non_modifiers)) 72 ((semi_reserved) (T_STATIC)) 73 ((semi_reserved) (T_ABSTRACT)) 74 ((semi_reserved) (T_FINAL)) 75 ((semi_reserved) (T_PRIVATE)) 76 ((semi_reserved) (T_PROTECTED)) 77 ((semi_reserved) (T_PUBLIC)) 78 ((semi_reserved) (T_READONLY)) 79 ((ampersand) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG)) 80 ((ampersand) (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG)) 81 ((identifier) (T_STRING)) 82 ((identifier) (semi_reserved)) 83 ((top_statement_list) (top_statement_list top_statement)) 84 ((top_statement_list) (%empty)) 85 ((namespace_declaration_name) (identifier)) 86 ((namespace_declaration_name) (T_NAME_QUALIFIED)) 87 ((namespace_name) (T_STRING)) 88 ((namespace_name) (T_NAME_QUALIFIED)) 89 ((legacy_namespace_name) (namespace_name)) 90 ((legacy_namespace_name) (T_NAME_FULLY_QUALIFIED)) 91 ((name) (T_STRING)) 92 ((name) (T_NAME_QUALIFIED)) 93 ((name) (T_NAME_FULLY_QUALIFIED)) 94 ((name) (T_NAME_RELATIVE)) 95 ((attribute_decl) (class_name)) 96 ((attribute_decl) (class_name argument_list)) 97 ((attribute_group) (attribute_decl)) 98 ((attribute_group) (attribute_group "," attribute_decl)) 99 ((attribute) (T_ATTRIBUTE attribute_group possible_comma "]")) 100 ((attributes) (attribute)) 101 ((attributes) (attributes attribute)) 102 ((attributed_statement) (function_declaration_statement)) 103 ((attributed_statement) (class_declaration_statement)) 104 ((attributed_statement) (trait_declaration_statement)) 105 ((attributed_statement) (interface_declaration_statement)) 106 ((attributed_statement) (enum_declaration_statement)) 107 ((top_statement) (statement)) 108 ((top_statement) (attributed_statement)) 109 ((top_statement) (attributes attributed_statement)) 110 ((top_statement) (T_HALT_COMPILER "(" ")" ";")) 111 ((top_statement) (T_NAMESPACE namespace_declaration_name ";")) 112 ((top_statement) (T_NAMESPACE namespace_declaration_name "{" top_statement_list "}")) 113 ((top_statement) (T_NAMESPACE "{" top_statement_list "}")) 114 ((top_statement) (T_USE mixed_group_use_declaration ";")) 115 ((top_statement) (T_USE use_type group_use_declaration ";")) 116 ((top_statement) (T_USE use_declarations ";")) 117 ((top_statement) (T_USE use_type use_declarations ";")) 118 ((top_statement) (T_CONST const_list ";")) 119 ((use_type) (T_FUNCTION)) 120 ((use_type) (T_CONST)) 121 ((group_use_declaration) (legacy_namespace_name T_NS_SEPARATOR "{" unprefixed_use_declarations possible_comma "}")) 122 ((mixed_group_use_declaration) (legacy_namespace_name T_NS_SEPARATOR "{" inline_use_declarations possible_comma "}")) 123 ((possible_comma) (%empty)) 124 ((possible_comma) (",")) 125 ((inline_use_declarations) (inline_use_declarations "," inline_use_declaration)) 126 ((inline_use_declarations) (inline_use_declaration)) 127 ((unprefixed_use_declarations) (unprefixed_use_declarations "," unprefixed_use_declaration)) 128 ((unprefixed_use_declarations) (unprefixed_use_declaration)) 129 ((use_declarations) (use_declarations "," use_declaration)) 130 ((use_declarations) (use_declaration)) 131 ((inline_use_declaration) (unprefixed_use_declaration)) 132 ((inline_use_declaration) (use_type unprefixed_use_declaration)) 133 ((unprefixed_use_declaration) (namespace_name)) 134 ((unprefixed_use_declaration) (namespace_name T_AS T_STRING)) 135 ((use_declaration) (legacy_namespace_name)) 136 ((use_declaration) (legacy_namespace_name T_AS T_STRING)) 137 ((const_list) (const_list "," const_decl)) 138 ((const_list) (const_decl)) 139 ((inner_statement_list) (inner_statement_list inner_statement)) 140 ((inner_statement_list) (%empty)) 141 ((inner_statement) (statement)) 142 ((inner_statement) (attributed_statement)) 143 ((inner_statement) (attributes attributed_statement)) 144 ((inner_statement) (T_HALT_COMPILER "(" ")" ";")) 145 ((statement) ("{" inner_statement_list "}")) 146 ((statement) (if_stmt)) 147 ((statement) (alt_if_stmt)) 148 ((statement) (T_WHILE "(" expr ")" while_statement)) 149 ((statement) (T_DO statement T_WHILE "(" expr ")" ";")) 150 ((statement) (T_FOR "(" for_exprs ";" for_exprs ";" for_exprs ")" for_statement)) 151 ((statement) (T_SWITCH "(" expr ")" switch_case_list)) 152 ((statement) (T_BREAK optional_expr ";")) 153 ((statement) (T_CONTINUE optional_expr ";")) 154 ((statement) (T_RETURN optional_expr ";")) 155 ((statement) (T_GLOBAL global_var_list ";")) 156 ((statement) (T_STATIC static_var_list ";")) 157 ((statement) (T_ECHO echo_expr_list ";")) 158 ((statement) (T_INLINE_HTML)) 159 ((statement) (expr ";")) 160 ((statement) (T_UNSET "(" unset_variables possible_comma ")" ";")) 161 ((statement) (T_FOREACH "(" expr T_AS foreach_variable ")" foreach_statement)) 162 ((statement) (T_FOREACH "(" expr T_AS foreach_variable T_DOUBLE_ARROW foreach_variable ")" foreach_statement)) 163 ((statement) (T_DECLARE "(" const_list ")" declare_statement)) 164 ((statement) (";")) 165 ((statement) (T_TRY "{" inner_statement_list "}" catch_list finally_statement)) 166 ((statement) (T_GOTO T_STRING ";")) 167 ((statement) (T_STRING ":")) 168 ((catch_list) (%empty)) 169 ((catch_list) (catch_list T_CATCH "(" catch_name_list optional_variable ")" "{" inner_statement_list "}")) 170 ((catch_name_list) (class_name)) 171 ((catch_name_list) (catch_name_list "|" class_name)) 172 ((optional_variable) (%empty)) 173 ((optional_variable) (T_VARIABLE)) 174 ((finally_statement) (%empty)) 175 ((finally_statement) (T_FINALLY "{" inner_statement_list "}")) 176 ((unset_variables) (unset_variable)) 177 ((unset_variables) (unset_variables "," unset_variable)) 178 ((unset_variable) (variable)) 179 ((function_name) (T_STRING)) 180 ((function_name) (T_READONLY)) 181 ((function_declaration_statement) (function returns_ref function_name backup_doc_comment "(" parameter_list ")" return_type backup_fn_flags "{" inner_statement_list "}" backup_fn_flags)) 182 ((is_reference) (%empty)) 183 ((is_reference) (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG)) 184 ((is_variadic) (%empty)) 185 ((is_variadic) (T_ELLIPSIS)) 186 ((class_declaration_statement) (class_modifiers T_CLASS T_STRING extends_from implements_list backup_doc_comment "{" class_statement_list "}")) 187 ((class_declaration_statement) (T_CLASS T_STRING extends_from implements_list backup_doc_comment "{" class_statement_list "}")) 188 ((class_modifiers) (class_modifier)) 189 ((class_modifiers) (class_modifiers class_modifier)) 190 ((anonymous_class_modifiers) (class_modifier)) 191 ((anonymous_class_modifiers) (anonymous_class_modifiers class_modifier)) 192 ((anonymous_class_modifiers_optional) (%empty)) 193 ((anonymous_class_modifiers_optional) (anonymous_class_modifiers)) 194 ((class_modifier) (T_ABSTRACT)) 195 ((class_modifier) (T_FINAL)) 196 ((class_modifier) (T_READONLY)) 197 ((trait_declaration_statement) (T_TRAIT T_STRING backup_doc_comment "{" class_statement_list "}")) 198 ((interface_declaration_statement) (T_INTERFACE T_STRING interface_extends_list backup_doc_comment "{" class_statement_list "}")) 199 ((enum_declaration_statement) (T_ENUM T_STRING enum_backing_type implements_list backup_doc_comment "{" class_statement_list "}")) 200 ((enum_backing_type) (%empty)) 201 ((enum_backing_type) (":" type_expr)) 202 ((enum_case) (T_CASE backup_doc_comment identifier enum_case_expr ";")) 203 ((enum_case_expr) (%empty)) 204 ((enum_case_expr) ("=" expr)) 205 ((extends_from) (%empty)) 206 ((extends_from) (T_EXTENDS class_name)) 207 ((interface_extends_list) (%empty)) 208 ((interface_extends_list) (T_EXTENDS class_name_list)) 209 ((implements_list) (%empty)) 210 ((implements_list) (T_IMPLEMENTS class_name_list)) 211 ((foreach_variable) (variable)) 212 ((foreach_variable) (ampersand variable)) 213 ((foreach_variable) (T_LIST "(" array_pair_list ")")) 214 ((foreach_variable) ("[" array_pair_list "]")) 215 ((for_statement) (statement)) 216 ((for_statement) (":" inner_statement_list T_ENDFOR ";")) 217 ((foreach_statement) (statement)) 218 ((foreach_statement) (":" inner_statement_list T_ENDFOREACH ";")) 219 ((declare_statement) (statement)) 220 ((declare_statement) (":" inner_statement_list T_ENDDECLARE ";")) 221 ((switch_case_list) ("{" case_list "}")) 222 ((switch_case_list) ("{" ";" case_list "}")) 223 ((switch_case_list) (":" case_list T_ENDSWITCH ";")) 224 ((switch_case_list) (":" ";" case_list T_ENDSWITCH ";")) 225 ((case_list) (%empty)) 226 ((case_list) (case_list T_CASE expr case_separator inner_statement_list)) 227 ((case_list) (case_list T_DEFAULT case_separator inner_statement_list)) 228 ((case_separator) (":")) 229 ((case_separator) (";")) 230 ((match) (T_MATCH "(" expr ")" "{" match_arm_list "}")) 231 ((match_arm_list) (%empty)) 232 ((match_arm_list) (non_empty_match_arm_list possible_comma)) 233 ((non_empty_match_arm_list) (match_arm)) 234 ((non_empty_match_arm_list) (non_empty_match_arm_list "," match_arm)) 235 ((match_arm) (match_arm_cond_list possible_comma T_DOUBLE_ARROW expr)) 236 ((match_arm) (T_DEFAULT possible_comma T_DOUBLE_ARROW expr)) 237 ((match_arm_cond_list) (expr)) 238 ((match_arm_cond_list) (match_arm_cond_list "," expr)) 239 ((while_statement) (statement)) 240 ((while_statement) (":" inner_statement_list T_ENDWHILE ";")) 241 ((if_stmt_without_else) (T_IF "(" expr ")" statement)) 242 ((if_stmt_without_else) (if_stmt_without_else T_ELSEIF "(" expr ")" statement)) 243 ((if_stmt) (if_stmt_without_else)) 244 ((if_stmt) (if_stmt_without_else T_ELSE statement)) 245 ((alt_if_stmt_without_else) (T_IF "(" expr ")" ":" inner_statement_list)) 246 ((alt_if_stmt_without_else) (alt_if_stmt_without_else T_ELSEIF "(" expr ")" ":" inner_statement_list)) 247 ((alt_if_stmt) (alt_if_stmt_without_else T_ENDIF ";")) 248 ((alt_if_stmt) (alt_if_stmt_without_else T_ELSE ":" inner_statement_list T_ENDIF ";")) 249 ((parameter_list) (non_empty_parameter_list possible_comma)) 250 ((parameter_list) (%empty)) 251 ((non_empty_parameter_list) (attributed_parameter)) 252 ((non_empty_parameter_list) (non_empty_parameter_list "," attributed_parameter)) 253 ((attributed_parameter) (attributes parameter)) 254 ((attributed_parameter) (parameter)) 255 ((optional_cpp_modifiers) (%empty)) 256 ((optional_cpp_modifiers) (non_empty_member_modifiers)) 257 ((parameter) (optional_cpp_modifiers optional_type_without_static is_reference is_variadic T_VARIABLE backup_doc_comment)) 258 ((parameter) (optional_cpp_modifiers optional_type_without_static is_reference is_variadic T_VARIABLE backup_doc_comment "=" expr)) 259 ((optional_type_without_static) (%empty)) 260 ((optional_type_without_static) (type_expr_without_static)) 261 ((type_expr) (type)) 262 ((type_expr) ("?" type)) 263 ((type_expr) (union_type)) 264 ((type_expr) (intersection_type)) 265 ((type) (type_without_static)) 266 ((type) (T_STATIC)) 267 ((union_type_element) (type)) 268 ((union_type_element) ("(" intersection_type ")")) 269 ((union_type) (union_type_element "|" union_type_element)) 270 ((union_type) (union_type "|" union_type_element)) 271 ((intersection_type) (type T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG type)) 272 ((intersection_type) (intersection_type T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG type)) 273 ((type_expr_without_static) (type_without_static)) 274 ((type_expr_without_static) ("?" type_without_static)) 275 ((type_expr_without_static) (union_type_without_static)) 276 ((type_expr_without_static) (intersection_type_without_static)) 277 ((type_without_static) (T_ARRAY)) 278 ((type_without_static) (T_CALLABLE)) 279 ((type_without_static) (name)) 280 ((union_type_without_static_element) (type_without_static)) 281 ((union_type_without_static_element) ("(" intersection_type_without_static ")")) 282 ((union_type_without_static) (union_type_without_static_element "|" union_type_without_static_element)) 283 ((union_type_without_static) (union_type_without_static "|" union_type_without_static_element)) 284 ((intersection_type_without_static) (type_without_static T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG type_without_static)) 285 ((intersection_type_without_static) (intersection_type_without_static T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG type_without_static)) 286 ((return_type) (%empty)) 287 ((return_type) (":" type_expr)) 288 ((argument_list) ("(" ")")) 289 ((argument_list) ("(" non_empty_argument_list possible_comma ")")) 290 ((argument_list) ("(" T_ELLIPSIS ")")) 291 ((non_empty_argument_list) (argument)) 292 ((non_empty_argument_list) (non_empty_argument_list "," argument)) 293 ((argument) (expr)) 294 ((argument) (identifier ":" expr)) 295 ((argument) (T_ELLIPSIS expr)) 296 ((global_var_list) (global_var_list "," global_var)) 297 ((global_var_list) (global_var)) 298 ((global_var) (simple_variable)) 299 ((static_var_list) (static_var_list "," static_var)) 300 ((static_var_list) (static_var)) 301 ((static_var) (T_VARIABLE)) 302 ((static_var) (T_VARIABLE "=" expr)) 303 ((class_statement_list) (class_statement_list class_statement)) 304 ((class_statement_list) (%empty)) 305 ((attributed_class_statement) (property_modifiers optional_type_without_static property_list ";")) 306 ((attributed_class_statement) (class_const_modifiers T_CONST class_const_list ";")) 307 ((attributed_class_statement) (class_const_modifiers T_CONST type_expr class_const_list ";")) 308 ((attributed_class_statement) (method_modifiers function returns_ref identifier backup_doc_comment "(" parameter_list ")" return_type backup_fn_flags method_body backup_fn_flags)) 309 ((attributed_class_statement) (enum_case)) 310 ((class_statement) (attributed_class_statement)) 311 ((class_statement) (attributes attributed_class_statement)) 312 ((class_statement) (T_USE class_name_list trait_adaptations)) 313 ((class_name_list) (class_name)) 314 ((class_name_list) (class_name_list "," class_name)) 315 ((trait_adaptations) (";")) 316 ((trait_adaptations) ("{" "}")) 317 ((trait_adaptations) ("{" trait_adaptation_list "}")) 318 ((trait_adaptation_list) (trait_adaptation)) 319 ((trait_adaptation_list) (trait_adaptation_list trait_adaptation)) 320 ((trait_adaptation) (trait_precedence ";")) 321 ((trait_adaptation) (trait_alias ";")) 322 ((trait_precedence) (absolute_trait_method_reference T_INSTEADOF class_name_list)) 323 ((trait_alias) (trait_method_reference T_AS T_STRING)) 324 ((trait_alias) (trait_method_reference T_AS reserved_non_modifiers)) 325 ((trait_alias) (trait_method_reference T_AS member_modifier identifier)) 326 ((trait_alias) (trait_method_reference T_AS member_modifier)) 327 ((trait_method_reference) (identifier)) 328 ((trait_method_reference) (absolute_trait_method_reference)) 329 ((absolute_trait_method_reference) (class_name T_PAAMAYIM_NEKUDOTAYIM identifier)) 330 ((method_body) (";")) 331 ((method_body) ("{" inner_statement_list "}")) 332 ((property_modifiers) (non_empty_member_modifiers)) 333 ((property_modifiers) (T_VAR)) 334 ((method_modifiers) (%empty)) 335 ((method_modifiers) (non_empty_member_modifiers)) 336 ((class_const_modifiers) (%empty)) 337 ((class_const_modifiers) (non_empty_member_modifiers)) 338 ((non_empty_member_modifiers) (member_modifier)) 339 ((non_empty_member_modifiers) (non_empty_member_modifiers member_modifier)) 340 ((member_modifier) (T_PUBLIC)) 341 ((member_modifier) (T_PROTECTED)) 342 ((member_modifier) (T_PRIVATE)) 343 ((member_modifier) (T_STATIC)) 344 ((member_modifier) (T_ABSTRACT)) 345 ((member_modifier) (T_FINAL)) 346 ((member_modifier) (T_READONLY)) 347 ((property_list) (property_list "," property)) 348 ((property_list) (property)) 349 ((property) (T_VARIABLE backup_doc_comment)) 350 ((property) (T_VARIABLE "=" expr backup_doc_comment)) 351 ((class_const_list) (class_const_list "," class_const_decl)) 352 ((class_const_list) (class_const_decl)) 353 ((class_const_decl) (T_STRING "=" expr backup_doc_comment)) 354 ((class_const_decl) (semi_reserved "=" expr backup_doc_comment)) 355 ((const_decl) (T_STRING "=" expr backup_doc_comment)) 356 ((echo_expr_list) (echo_expr_list "," echo_expr)) 357 ((echo_expr_list) (echo_expr)) 358 ((echo_expr) (expr)) 359 ((for_exprs) (%empty)) 360 ((for_exprs) (non_empty_for_exprs)) 361 ((non_empty_for_exprs) (non_empty_for_exprs "," expr)) 362 ((non_empty_for_exprs) (expr)) 363 ((anonymous_class) (anonymous_class_modifiers_optional T_CLASS ctor_arguments extends_from implements_list backup_doc_comment "{" class_statement_list "}")) 364 ((new_expr) (T_NEW class_name_reference ctor_arguments)) 365 ((new_expr) (T_NEW anonymous_class)) 366 ((new_expr) (T_NEW attributes anonymous_class)) 367 ((expr) (variable)) 368 ((expr) (T_LIST "(" array_pair_list ")" "=" expr)) 369 ((expr) ("[" array_pair_list "]" "=" expr)) 370 ((expr) (variable "=" expr)) 371 ((expr) (variable "=" ampersand variable)) 372 ((expr) (T_CLONE expr)) 373 ((expr) (variable T_PLUS_EQUAL expr)) 374 ((expr) (variable T_MINUS_EQUAL expr)) 375 ((expr) (variable T_MUL_EQUAL expr)) 376 ((expr) (variable T_POW_EQUAL expr)) 377 ((expr) (variable T_DIV_EQUAL expr)) 378 ((expr) (variable T_CONCAT_EQUAL expr)) 379 ((expr) (variable T_MOD_EQUAL expr)) 380 ((expr) (variable T_AND_EQUAL expr)) 381 ((expr) (variable T_OR_EQUAL expr)) 382 ((expr) (variable T_XOR_EQUAL expr)) 383 ((expr) (variable T_SL_EQUAL expr)) 384 ((expr) (variable T_SR_EQUAL expr)) 385 ((expr) (variable T_COALESCE_EQUAL expr)) 386 ((expr) (variable T_INC)) 387 ((expr) (T_INC variable)) 388 ((expr) (variable T_DEC)) 389 ((expr) (T_DEC variable)) 390 ((expr) (expr T_BOOLEAN_OR expr)) 391 ((expr) (expr T_BOOLEAN_AND expr)) 392 ((expr) (expr T_LOGICAL_OR expr)) 393 ((expr) (expr T_LOGICAL_AND expr)) 394 ((expr) (expr T_LOGICAL_XOR expr)) 395 ((expr) (expr "|" expr)) 396 ((expr) (expr T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG expr)) 397 ((expr) (expr T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG expr)) 398 ((expr) (expr "^" expr)) 399 ((expr) (expr "." expr)) 400 ((expr) (expr "+" expr)) 401 ((expr) (expr "-" expr)) 402 ((expr) (expr "*" expr)) 403 ((expr) (expr T_POW expr)) 404 ((expr) (expr "/" expr)) 405 ((expr) (expr "%" expr)) 406 ((expr) (expr T_SL expr)) 407 ((expr) (expr T_SR expr)) 408 ((expr) ("+" expr)) 409 ((expr) ("-" expr)) 410 ((expr) ("!" expr)) 411 ((expr) ("~" expr)) 412 ((expr) (expr T_IS_IDENTICAL expr)) 413 ((expr) (expr T_IS_NOT_IDENTICAL expr)) 414 ((expr) (expr T_IS_EQUAL expr)) 415 ((expr) (expr T_IS_NOT_EQUAL expr)) 416 ((expr) (expr "<" expr)) 417 ((expr) (expr T_IS_SMALLER_OR_EQUAL expr)) 418 ((expr) (expr ">" expr)) 419 ((expr) (expr T_IS_GREATER_OR_EQUAL expr)) 420 ((expr) (expr T_SPACESHIP expr)) 421 ((expr) (expr T_INSTANCEOF class_name_reference)) 422 ((expr) ("(" expr ")")) 423 ((expr) (new_expr)) 424 ((expr) (expr "?" expr ":" expr)) 425 ((expr) (expr "?" ":" expr)) 426 ((expr) (expr T_COALESCE expr)) 427 ((expr) (internal_functions_in_yacc)) 428 ((expr) (T_INT_CAST expr)) 429 ((expr) (T_DOUBLE_CAST expr)) 430 ((expr) (T_STRING_CAST expr)) 431 ((expr) (T_ARRAY_CAST expr)) 432 ((expr) (T_OBJECT_CAST expr)) 433 ((expr) (T_BOOL_CAST expr)) 434 ((expr) (T_UNSET_CAST expr)) 435 ((expr) (T_EXIT exit_expr)) 436 ((expr) ("@" expr)) 437 ((expr) (scalar)) 438 ((expr) ("`" backticks_expr "`")) 439 ((expr) (T_PRINT expr)) 440 ((expr) (T_YIELD)) 441 ((expr) (T_YIELD expr)) 442 ((expr) (T_YIELD expr T_DOUBLE_ARROW expr)) 443 ((expr) (T_YIELD_FROM expr)) 444 ((expr) (T_THROW expr)) 445 ((expr) (inline_function)) 446 ((expr) (attributes inline_function)) 447 ((expr) (T_STATIC inline_function)) 448 ((expr) (attributes T_STATIC inline_function)) 449 ((expr) (match)) 450 ((inline_function) (function returns_ref backup_doc_comment "(" parameter_list ")" lexical_vars return_type backup_fn_flags "{" inner_statement_list "}" backup_fn_flags)) 451 ((inline_function) (fn returns_ref backup_doc_comment "(" parameter_list ")" return_type T_DOUBLE_ARROW backup_fn_flags backup_lex_pos expr backup_fn_flags)) 452 ((fn) (T_FN)) 453 ((function) (T_FUNCTION)) 454 ((backup_doc_comment) (%empty)) 455 ((backup_fn_flags) (%empty)) 456 ((backup_lex_pos) (%empty)) 457 ((returns_ref) (%empty)) 458 ((returns_ref) (ampersand)) 459 ((lexical_vars) (%empty)) 460 ((lexical_vars) (T_USE "(" lexical_var_list possible_comma ")")) 461 ((lexical_var_list) (lexical_var_list "," lexical_var)) 462 ((lexical_var_list) (lexical_var)) 463 ((lexical_var) (T_VARIABLE)) 464 ((lexical_var) (ampersand T_VARIABLE)) 465 ((function_call) (name argument_list)) 466 ((function_call) (T_READONLY argument_list)) 467 ((function_call) (class_name T_PAAMAYIM_NEKUDOTAYIM member_name argument_list)) 468 ((function_call) (variable_class_name T_PAAMAYIM_NEKUDOTAYIM member_name argument_list)) 469 ((function_call) (callable_expr argument_list)) 470 ((class_name) (T_STATIC)) 471 ((class_name) (name)) 472 ((class_name_reference) (class_name)) 473 ((class_name_reference) (new_variable)) 474 ((class_name_reference) ("(" expr ")")) 475 ((exit_expr) (%empty)) 476 ((exit_expr) ("(" optional_expr ")")) 477 ((backticks_expr) (%empty)) 478 ((backticks_expr) (T_ENCAPSED_AND_WHITESPACE)) 479 ((backticks_expr) (encaps_list)) 480 ((ctor_arguments) (%empty)) 481 ((ctor_arguments) (argument_list)) 482 ((dereferenceable_scalar) (T_ARRAY "(" array_pair_list ")")) 483 ((dereferenceable_scalar) ("[" array_pair_list "]")) 484 ((dereferenceable_scalar) (T_CONSTANT_ENCAPSED_STRING)) 485 ((dereferenceable_scalar) ("\"" encaps_list "\"")) 486 ((scalar) (T_LNUMBER)) 487 ((scalar) (T_DNUMBER)) 488 ((scalar) (T_START_HEREDOC T_ENCAPSED_AND_WHITESPACE T_END_HEREDOC)) 489 ((scalar) (T_START_HEREDOC T_END_HEREDOC)) 490 ((scalar) (T_START_HEREDOC encaps_list T_END_HEREDOC)) 491 ((scalar) (dereferenceable_scalar)) 492 ((scalar) (constant)) 493 ((scalar) (class_constant)) 494 ((constant) (name)) 495 ((constant) (T_LINE)) 496 ((constant) (T_FILE)) 497 ((constant) (T_DIR)) 498 ((constant) (T_TRAIT_C)) 499 ((constant) (T_METHOD_C)) 500 ((constant) (T_FUNC_C)) 501 ((constant) (T_NS_C)) 502 ((constant) (T_CLASS_C)) 503 ((class_constant) (class_name T_PAAMAYIM_NEKUDOTAYIM identifier)) 504 ((class_constant) (variable_class_name T_PAAMAYIM_NEKUDOTAYIM identifier)) 505 ((class_constant) (class_name T_PAAMAYIM_NEKUDOTAYIM "{" expr "}")) 506 ((class_constant) (variable_class_name T_PAAMAYIM_NEKUDOTAYIM "{" expr "}")) 507 ((optional_expr) (%empty)) 508 ((optional_expr) (expr)) 509 ((variable_class_name) (fully_dereferenceable)) 510 ((fully_dereferenceable) (variable)) 511 ((fully_dereferenceable) ("(" expr ")")) 512 ((fully_dereferenceable) (dereferenceable_scalar)) 513 ((fully_dereferenceable) (class_constant)) 514 ((array_object_dereferenceable) (fully_dereferenceable)) 515 ((array_object_dereferenceable) (constant)) 516 ((callable_expr) (callable_variable)) 517 ((callable_expr) ("(" expr ")")) 518 ((callable_expr) (dereferenceable_scalar)) 519 ((callable_variable) (simple_variable)) 520 ((callable_variable) (array_object_dereferenceable "[" optional_expr "]")) 521 ((callable_variable) (array_object_dereferenceable "{" expr "}")) 522 ((callable_variable) (array_object_dereferenceable T_OBJECT_OPERATOR property_name argument_list)) 523 ((callable_variable) (array_object_dereferenceable T_NULLSAFE_OBJECT_OPERATOR property_name argument_list)) 524 ((callable_variable) (function_call)) 525 ((variable) (callable_variable)) 526 ((variable) (static_member)) 527 ((variable) (array_object_dereferenceable T_OBJECT_OPERATOR property_name)) 528 ((variable) (array_object_dereferenceable T_NULLSAFE_OBJECT_OPERATOR property_name)) 529 ((simple_variable) (T_VARIABLE)) 530 ((simple_variable) ("$" "{" expr "}")) 531 ((simple_variable) ("$" simple_variable)) 532 ((static_member) (class_name T_PAAMAYIM_NEKUDOTAYIM simple_variable)) 533 ((static_member) (variable_class_name T_PAAMAYIM_NEKUDOTAYIM simple_variable)) 534 ((new_variable) (simple_variable)) 535 ((new_variable) (new_variable "[" optional_expr "]")) 536 ((new_variable) (new_variable "{" expr "}")) 537 ((new_variable) (new_variable T_OBJECT_OPERATOR property_name)) 538 ((new_variable) (new_variable T_NULLSAFE_OBJECT_OPERATOR property_name)) 539 ((new_variable) (class_name T_PAAMAYIM_NEKUDOTAYIM simple_variable)) 540 ((new_variable) (new_variable T_PAAMAYIM_NEKUDOTAYIM simple_variable)) 541 ((member_name) (identifier)) 542 ((member_name) ("{" expr "}")) 543 ((member_name) (simple_variable)) 544 ((property_name) (T_STRING)) 545 ((property_name) ("{" expr "}")) 546 ((property_name) (simple_variable)) 547 ((array_pair_list) (non_empty_array_pair_list)) 548 ((possible_array_pair) (%empty)) 549 ((possible_array_pair) (array_pair)) 550 ((non_empty_array_pair_list) (non_empty_array_pair_list "," possible_array_pair)) 551 ((non_empty_array_pair_list) (possible_array_pair)) 552 ((array_pair) (expr T_DOUBLE_ARROW expr)) 553 ((array_pair) (expr)) 554 ((array_pair) (expr T_DOUBLE_ARROW ampersand variable)) 555 ((array_pair) (ampersand variable)) 556 ((array_pair) (T_ELLIPSIS expr)) 557 ((array_pair) (expr T_DOUBLE_ARROW T_LIST "(" array_pair_list ")")) 558 ((array_pair) (T_LIST "(" array_pair_list ")")) 559 ((encaps_list) (encaps_list encaps_var)) 560 ((encaps_list) (encaps_list T_ENCAPSED_AND_WHITESPACE)) 561 ((encaps_list) (encaps_var)) 562 ((encaps_list) (T_ENCAPSED_AND_WHITESPACE encaps_var)) 563 ((encaps_var) (T_VARIABLE)) 564 ((encaps_var) (T_VARIABLE "[" encaps_var_offset "]")) 565 ((encaps_var) (T_VARIABLE T_OBJECT_OPERATOR T_STRING)) 566 ((encaps_var) (T_VARIABLE T_NULLSAFE_OBJECT_OPERATOR T_STRING)) 567 ((encaps_var) (T_DOLLAR_OPEN_CURLY_BRACES expr "}")) 568 ((encaps_var) (T_DOLLAR_OPEN_CURLY_BRACES T_STRING_VARNAME "}")) 569 ((encaps_var) (T_DOLLAR_OPEN_CURLY_BRACES T_STRING_VARNAME "[" expr "]" "}")) 570 ((encaps_var) (T_CURLY_OPEN variable "}")) 571 ((encaps_var_offset) (T_STRING)) 572 ((encaps_var_offset) (T_NUM_STRING)) 573 ((encaps_var_offset) ("-" T_NUM_STRING)) 574 ((encaps_var_offset) (T_VARIABLE)) 575 ((internal_functions_in_yacc) (T_ISSET "(" isset_variables possible_comma ")")) 576 ((internal_functions_in_yacc) (T_EMPTY "(" expr ")")) 577 ((internal_functions_in_yacc) (T_INCLUDE expr)) 578 ((internal_functions_in_yacc) (T_INCLUDE_ONCE expr)) 579 ((internal_functions_in_yacc) (T_EVAL "(" expr ")")) 580 ((internal_functions_in_yacc) (T_REQUIRE expr)) 581 ((internal_functions_in_yacc) (T_REQUIRE_ONCE expr)) 582 ((isset_variables) (isset_variable)) 583 ((isset_variables) (isset_variables "," isset_variable)) 584 ((isset_variable) (expr))))
  "The hash-table indexed by production-number and value is production.")

(defvar
  phps-mode-parser--table-look-aheads
  #s(hash-table size 217 test equal rehash-size 1.5 rehash-threshold 0.8125 data (("!") t ("\"") t ($) t ("$") t ("%") t ("(") t (")") t ("*") t ("+") t (",") t ("-") t (".") t ("/") t (":") t (";") t ("<") t ("=") t (">") t ("?") t ("@") t (PREC_ARROW_FUNCTION) t (T_ABSTRACT) t (T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG) t (T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG) t (T_AND_EQUAL) t (T_ARRAY) t (T_ARRAY_CAST) t (T_AS) t (T_ATTRIBUTE) t (T_BOOLEAN_AND) t (T_BOOLEAN_OR) t (T_BOOL_CAST) t (T_BREAK) t (T_CALLABLE) t (T_CASE) t (T_CATCH) t (T_CLASS) t (T_CLASS_C) t (T_CLONE) t (T_COALESCE) t (T_COALESCE_EQUAL) t (T_CONCAT_EQUAL) t (T_CONST) t (T_CONSTANT_ENCAPSED_STRING) t (T_CONTINUE) t (T_CURLY_OPEN) t (T_DEC) t (T_DECLARE) t (T_DEFAULT) t (T_DIR) t (T_DIV_EQUAL) t (T_DNUMBER) t (T_DO) t (T_DOLLAR_OPEN_CURLY_BRACES) t (T_DOUBLE_ARROW) t (T_DOUBLE_CAST) t (T_ECHO) t (T_ELLIPSIS) t (T_ELSE) t (T_ELSEIF) t (T_EMPTY) t (T_ENCAPSED_AND_WHITESPACE) t (T_ENDDECLARE) t (T_ENDFOR) t (T_ENDFOREACH) t (T_ENDIF) t (T_ENDSWITCH) t (T_ENDWHILE) t (T_END_HEREDOC) t (T_ENUM) t (T_EVAL) t (T_EXIT) t (T_EXTENDS) t (T_FILE) t (T_FINAL) t (T_FINALLY) t (T_FN) t (T_FOR) t (T_FOREACH) t (T_FUNCTION) t (T_FUNC_C) t (T_GLOBAL) t (T_GOTO) t (T_HALT_COMPILER) t (T_IF) t (T_IMPLEMENTS) t (T_INC) t (T_INCLUDE) t (T_INCLUDE_ONCE) t (T_INLINE_HTML) t (T_INSTANCEOF) t (T_INSTEADOF) t (T_INTERFACE) t (T_INT_CAST) t (T_ISSET) t (T_IS_EQUAL) t (T_IS_GREATER_OR_EQUAL) t (T_IS_IDENTICAL) t (T_IS_NOT_EQUAL) t (T_IS_NOT_IDENTICAL) t (T_IS_SMALLER_OR_EQUAL) t (T_LINE) t (T_LIST) t (T_LNUMBER) t (T_LOGICAL_AND) t (T_LOGICAL_OR) t (T_LOGICAL_XOR) t (T_MATCH) t (T_METHOD_C) t (T_MINUS_EQUAL) t (T_MOD_EQUAL) t (T_MUL_EQUAL) t (T_NAMESPACE) t (T_NAME_FULLY_QUALIFIED) t (T_NAME_QUALIFIED) t (T_NAME_RELATIVE) t (T_NEW) t (T_NOELSE) t (T_NS_C) t (T_NS_SEPARATOR) t (T_NULLSAFE_OBJECT_OPERATOR) t (T_NUM_STRING) t (T_OBJECT_CAST) t (T_OBJECT_OPERATOR) t (T_OR_EQUAL) t (T_PAAMAYIM_NEKUDOTAYIM) t (T_PLUS_EQUAL) t (T_POW) t (T_POW_EQUAL) t (T_PRINT) t (T_PRIVATE) t (T_PROTECTED) t (T_PUBLIC) t (T_READONLY) t (T_REQUIRE) t (T_REQUIRE_ONCE) t (T_RETURN) t (T_SL) t (T_SL_EQUAL) t (T_SPACESHIP) t (T_SR) t (T_SR_EQUAL) t (T_START_HEREDOC) t (T_STATIC) t (T_STRING) t (T_STRING_CAST) t (T_STRING_VARNAME) t (T_SWITCH) t (T_THROW) t (T_TRAIT) t (T_TRAIT_C) t (T_TRY) t (T_UNSET) t (T_UNSET_CAST) t (T_USE) t (T_VAR) t (T_VARIABLE) t (T_WHILE) t (T_XOR_EQUAL) t (T_YIELD) t (T_YIELD_FROM) t ("[") t ("]") t ("^") t ("`") t ("{") t ("|") t ("}") t ("~") t))
  "The hash-table of valid look-aheads.")

(defvar
  phps-mode-parser--table-terminal-p
  #s(hash-table size 217 test equal rehash-size 1.5 rehash-threshold 0.8125 data (T_NUM_STRING t T_CURLY_OPEN t T_STRING_VARNAME t T_DOLLAR_OPEN_CURLY_BRACES t "$" t T_NULLSAFE_OBJECT_OPERATOR t T_OBJECT_OPERATOR t T_END_HEREDOC t T_START_HEREDOC t T_DNUMBER t T_LNUMBER t "\"" t T_CONSTANT_ENCAPSED_STRING t T_ENCAPSED_AND_WHITESPACE t PREC_ARROW_FUNCTION t T_YIELD_FROM t "`" t "@" t T_UNSET_CAST t T_BOOL_CAST t T_OBJECT_CAST t T_ARRAY_CAST t T_STRING_CAST t T_DOUBLE_CAST t T_INT_CAST t T_COALESCE t T_SPACESHIP t T_IS_GREATER_OR_EQUAL t ">" t T_IS_SMALLER_OR_EQUAL t "<" t T_IS_NOT_EQUAL t T_IS_EQUAL t T_IS_NOT_IDENTICAL t T_IS_IDENTICAL t "!" t "~" t T_SR t T_SL t "%" t "/" t T_POW t "*" t "-" t "+" t "." t "^" t T_BOOLEAN_AND t T_BOOLEAN_OR t T_DEC t T_INC t T_COALESCE_EQUAL t T_SR_EQUAL t T_SL_EQUAL t T_XOR_EQUAL t T_OR_EQUAL t T_AND_EQUAL t T_MOD_EQUAL t T_CONCAT_EQUAL t T_DIV_EQUAL t T_POW_EQUAL t T_MUL_EQUAL t T_MINUS_EQUAL t T_PLUS_EQUAL t T_PAAMAYIM_NEKUDOTAYIM t "?" t T_NOELSE t "[" t "=" t T_ELLIPSIS t T_VARIABLE t "|" t ":" t T_DOUBLE_ARROW t T_INLINE_HTML t T_NS_SEPARATOR t "}" t "{" t ";" t ")" t "(" t T_HALT_COMPILER t "]" t T_ATTRIBUTE t "," t T_NAME_RELATIVE t T_NAME_FULLY_QUALIFIED t T_NAME_QUALIFIED t T_STRING t T_AMPERSAND_NOT_FOLLOWED_BY_VAR_OR_VARARG t T_AMPERSAND_FOLLOWED_BY_VAR_OR_VARARG t T_READONLY t T_PUBLIC t T_PROTECTED t T_PRIVATE t T_FINAL t T_ABSTRACT t T_STATIC t T_ENUM t T_MATCH t T_FN t T_NS_C t T_DIR t T_FILE t T_LINE t T_METHOD_C t T_FUNC_C t T_TRAIT_C t T_CLASS_C t T_CLASS t T_INTERFACE t T_TRAIT t T_NAMESPACE t T_IMPLEMENTS t T_EXTENDS t T_CALLABLE t T_ARRAY t T_BREAK t T_DEFAULT t T_CASE t T_ENDSWITCH t T_SWITCH t T_LIST t T_YIELD t T_PRINT t T_RETURN t T_CONST t T_FUNCTION t T_GOTO t T_CONTINUE t T_EMPTY t T_ISSET t T_UNSET t T_VAR t T_GLOBAL t T_INSTEADOF t T_USE t T_THROW t T_FINALLY t T_CATCH t T_TRY t T_AS t T_ENDDECLARE t T_DECLARE t T_ENDFOREACH t T_FOREACH t T_ENDFOR t T_FOR t T_ENDWHILE t T_WHILE t T_DO t T_ECHO t T_ENDIF t T_ELSE t T_ELSEIF t T_IF t T_EXIT t T_CLONE t T_NEW t T_INSTANCEOF t T_LOGICAL_AND t T_LOGICAL_XOR t T_LOGICAL_OR t T_REQUIRE_ONCE t T_REQUIRE t T_EVAL t T_INCLUDE_ONCE t T_INCLUDE t))
  "The hash-table of valid terminals.")

(defvar
  phps-mode-parser--table-non-terminal-p
  #s(hash-table size 217 test equal rehash-size 1.5 rehash-threshold 0.8125 data (isset_variable t isset_variables t encaps_var_offset t encaps_var t possible_array_pair t array_pair t non_empty_array_pair_list t static_member t function_call t property_name t array_object_dereferenceable t callable_variable t fully_dereferenceable t class_constant t constant t dereferenceable_scalar t encaps_list t new_variable t callable_expr t variable_class_name t member_name t lexical_var t lexical_var_list t backup_lex_pos t fn t lexical_vars t match t inline_function t backticks_expr t scalar t exit_expr t internal_functions_in_yacc t new_expr t anonymous_class t class_name_reference t ctor_arguments t anonymous_class_modifiers_optional t non_empty_for_exprs t echo_expr t class_const_decl t property t member_modifier t trait_method_reference t absolute_trait_method_reference t trait_alias t trait_precedence t trait_adaptation t trait_adaptation_list t trait_adaptations t attributed_class_statement t enum_case t method_body t method_modifiers t class_const_list t class_const_modifiers t property_list t property_modifiers t class_statement t static_var t simple_variable t global_var t argument t non_empty_argument_list t union_type_without_static_element t name t intersection_type_without_static t union_type_without_static t union_type_element t type_without_static t intersection_type t union_type t type t type_expr_without_static t is_variadic t is_reference t optional_type_without_static t optional_cpp_modifiers t non_empty_member_modifiers t parameter t attributed_parameter t non_empty_parameter_list t alt_if_stmt_without_else t if_stmt_without_else t match_arm_cond_list t match_arm t non_empty_match_arm_list t match_arm_list t case_separator t case_list t array_pair_list t ampersand t class_name_list t enum_case_expr t type_expr t enum_backing_type t interface_extends_list t anonymous_class_modifiers t class_modifier t class_statement_list t implements_list t extends_from t class_modifiers t backup_fn_flags t return_type t parameter_list t backup_doc_comment t function_name t returns_ref t function t variable t unset_variable t optional_variable t catch_name_list t finally_statement t catch_list t declare_statement t foreach_statement t foreach_variable t unset_variables t echo_expr_list t static_var_list t global_var_list t optional_expr t switch_case_list t for_statement t for_exprs t while_statement t expr t alt_if_stmt t if_stmt t inner_statement t inner_statement_list t const_decl t use_declaration t unprefixed_use_declaration t inline_use_declaration t inline_use_declarations t unprefixed_use_declarations t legacy_namespace_name t const_list t use_declarations t group_use_declaration t use_type t mixed_group_use_declaration t namespace_declaration_name t attributed_statement t statement t enum_declaration_statement t interface_declaration_statement t trait_declaration_statement t class_declaration_statement t function_declaration_statement t attributes t attribute t possible_comma t attribute_group t attribute_decl t argument_list t class_name t namespace_name t identifier t top_statement t semi_reserved t reserved_non_modifiers t top_statement_list t))
  "The hash-table of valid non-terminals.")

(defvar
  phps-mode-parser--table-translations
  #s(hash-table size 65 test equal rehash-size 1.5 rehash-threshold 0.8125 data ())
  "The hash-table of translations.")

(defvar
  phps-mode-parser--e-identifier
  '%empty
  "The e-identifier.")

(defvar
  phps-mode-parser--eof-identifier
  '$
  "The end-of-file-identifier.")

(defvar
  phps-mode-parser--look-ahead-number
  1
  "The look-ahead number.")

(defvar
  phps-mode-parser-lex-analyzer--index-init
  1
  "Initial value of index.")

(defvar
  phps-mode-parser-lex-analyzer--state-init
  (list 'ST_INITIAL)
  "Initial value of state.")


;;; Buffer-Local Variables:


(defvar-local
  phps-mode-parser-lex-analyzer--buffered-response
  nil
  "Buffered tokens of lex-analyzer.")

(defvar-local
  phps-mode-parser-lex-analyzer--index
  0
  "The current index of the lex-analyzer.")

(defvar-local
  phps-mode-parser-lex-analyzer--state
  nil
  "The current state of the lex-analyzer.")


;;; Variable Functions:


(defvar
  phps-mode-parser-lex-analyzer--get-function
  (lambda (token) (let ((start (car (cdr token))) (end (cdr (cdr token)))) (if (<= end (point-max)) (progn (buffer-substring-no-properties start end)))))
  "The lex-analyzer get function.")

(defvar
  phps-mode-parser-lex-analyzer--function
  (lambda (index old-state)
    (let* ((lexer-response
            (phps-mode-lexer--re2c index old-state))
          (tokens
            (nth 0 lexer-response))
          (move-to-index
            (nth 1 lexer-response))
          (new-state
            (nth 2 lexer-response)))


        (unless move-to-index
          (let ((token-type (car (car tokens))))
            (cond

              ((or
                (equal token-type 'T_OPEN_TAG)
                (equal token-type 'T_COMMENT)
                (equal token-type 'T_DOC_COMMENT)
              )
                (setq
                  move-to-index
                  (cdr (cdr (car tokens)))))

              ((equal token-type 'T_OPEN_TAG_WITH_ECHO)
                (setf (car (car tokens)) 'T_ECHO))

              ((equal token-type 'T_CLOSE_TAG)
                (setf (car (car tokens)) ";"))

              )

            ))

      (list tokens move-to-index new-state)))
  "The lex-analyzer function.")

(defvar
  phps-mode-parser-lex-analyzer--reset-function
  (lambda nil (progn))
  "The lex-analyzer reset function.")


;;; Functions:


;;; Functions for Lex-Analyzer:


(defun
  phps-mode-parser-lex-analyzer--get-function (token)
  "Get information about TOKEN."
  (let ((meta-information))
    (condition-case
      error
      (progn
        (setq
          meta-information
          (funcall
            phps-mode-parser-lex-analyzer--get-function
            token)))
      (error (error
        "Lex-analyze failed to get token meta-data of %s, error: %s"
        token
        (car (cdr error)))))
    (unless meta-information
      (error "Could not find any token meta-information for: %s" token))
    meta-information))

(defun
  phps-mode-parser-lex-analyzer--reset
  ()
  "Reset Lex-Analyzer."
  (setq
    phps-mode-parser-lex-analyzer--buffered-response
    (make-hash-table :test 'equal))
  (setq
    phps-mode-parser-lex-analyzer--index
    phps-mode-parser-lex-analyzer--index-init)
  (setq
    phps-mode-parser-lex-analyzer--state
    phps-mode-parser-lex-analyzer--state-init)
  (when
    phps-mode-parser-lex-analyzer--reset-function
    (funcall
      phps-mode-parser-lex-analyzer--reset-function)))

(defun
  phps-mode-parser-lex-analyzer--peek-next-look-ahead
  ()
  "Peek next look-ahead number of tokens via lex-analyzer."
  (let ((look-ahead)
        (look-ahead-length
          0)
        (index
          phps-mode-parser-lex-analyzer--index)
        (state
          phps-mode-parser-lex-analyzer--state)
        (k (max
            1
            phps-mode-parser--look-ahead-number)))
    (while (<
            look-ahead-length
            k)
      (let* ((result-list
              (phps-mode-parser-lex-analyzer--get-buffered-lex
               index
               state))
             (token
              (nth 0 result-list))
             (new-index
              (nth 2 result-list))
             (new-state
              (nth 3 result-list)))
        (push
         token
         look-ahead)
        (setq
         look-ahead-length
         (1+ look-ahead-length))
        (setq
         index
         new-index)
        (setq
         state
         new-state)))

    (nreverse look-ahead)))

(defun
  phps-mode-parser-lex-analyzer--pop-token ()
  "Pop next token via lex-analyzer."
  (let* ((result-list
          (phps-mode-parser-lex-analyzer--get-buffered-lex
           phps-mode-parser-lex-analyzer--index
           phps-mode-parser-lex-analyzer--state))
         (token
          (nth 0 result-list))
         (new-index
          (nth 2 result-list))
         (new-state
          (nth 3 result-list)))
    (setq-local
     phps-mode-parser-lex-analyzer--index
     new-index)
    (setq-local
     phps-mode-parser-lex-analyzer--state
     new-state)
    (list token)))

(defun phps-mode-parser-lex-analyzer--get-buffered-lex (index state)
  "Get next token in stream, use buffer to only call function when needed."
  (unless (gethash
           index
           phps-mode-parser-lex-analyzer--buffered-response)
    (let ((continue t)
          (tmp-index index)
          (tmp-state state))
      (while continue
        (condition-case error
            (progn
              (let* ((result-list
                      (funcall
                       phps-mode-parser-lex-analyzer--function
                       tmp-index
                       tmp-state))
                     (tokens
                      (nth 0 result-list))
                     (move-to-index-flag
                      (nth 1 result-list))
                     (new-state
                      (nth 2 result-list)))
                (if move-to-index-flag
                    (progn
                      (setq
                       tmp-index
                       move-to-index-flag)
                      (setq
                       tmp-state
                       new-state))

                  (if tokens

                      (progn
                        (unless (listp (car tokens))
                          (setq tokens (list tokens)))

                        (let* ((first-token (car tokens))
                               (first-token-start (car (cdr first-token)))
                               (first-token-end (cdr (cdr first-token))))
                          (when (< index first-token-start)
                            (let ((token-start index))
                              (while (< token-start first-token-start)
                                (puthash
                                 token-start
                                 (list
                                  first-token
                                  nil
                                  first-token-end
                                  new-state)
                                 phps-mode-parser-lex-analyzer--buffered-response)
                                (setq
                                 token-start
                                 (1+ token-start))))))

                        (dolist (token tokens)
                          (let ((token-start (car (cdr token)))
                                (token-end (cdr (cdr token))))
                            (puthash
                             token-start
                             (list token nil token-end new-state)
                             phps-mode-parser-lex-analyzer--buffered-response))))

                    ;; Fill up look-ahead with EOF-identifier if we found nothing
                    (puthash
                     index
                     (list (list phps-mode-parser--eof-identifier) nil (1+ index) nil)
                     phps-mode-parser-lex-analyzer--buffered-response))

                  (setq
                   continue
                   nil))))
          (error
           (error
            "Lex-analyze failed to get next token at: %s in state: %s, error: %s"
            index
            state
            error))))))
  (gethash
   index
   phps-mode-parser-lex-analyzer--buffered-response))


;;; Functions for Syntax-Analyzer / Parser:


(defun
  phps-mode-parser--get-grammar-production-by-number
  (production-number)
  "If PRODUCTION-NUMBER exist, return it's production."
  (gethash
   production-number
   phps-mode-parser--table-productions-number-reverse))

(defun
  phps-mode-parser--valid-symbol-p
  (symbol)
  "Return whether SYMBOL is valid or not."
  (let ((is-valid t))
    (unless (or
             (phps-mode-parser--valid-e-p symbol)
             (phps-mode-parser--valid-eof-p symbol)
             (phps-mode-parser--valid-non-terminal-p symbol)
             (phps-mode-parser--valid-terminal-p symbol))
      (setq is-valid nil))
    is-valid))

(defun
  phps-mode-parser--valid-e-p
  (symbol)
  "Return whether SYMBOL is the e identifier or not."
  (eq
   symbol
   phps-mode-parser--e-identifier))

(defun
  phps-mode-parser--valid-eof-p
  (symbol)
  "Return whether SYMBOL is the EOF identifier or not."
  (eq
    symbol
    phps-mode-parser--eof-identifier))

(defun
  phps-mode-parser--valid-non-terminal-p (symbol)
  "Return whether SYMBOL is a non-terminal in grammar or not."
  (gethash
   symbol
   phps-mode-parser--table-non-terminal-p))

(defun
  phps-mode-parser--valid-terminal-p (symbol)
  "Return whether SYMBOL is a terminal in grammar or not."
  (gethash
   symbol
   phps-mode-parser--table-terminal-p))

(defun
  phps-mode-parser--get-grammar-translation-by-number
  (production-number)
  "If translation for PRODUCTION-NUMBER exist, return it."
  (gethash
    production-number
    phps-mode-parser--table-translations))

(defun
  phps-mode-parser--parse
  (&optional
    perform-sdt
    input-tape-index
    pushdown-list
    output
    translation
    translation-symbol-table-list
    history)
  "Perform a LR-parse via lex-analyzer, optionally PERFORM-SDT means to perform
  syntax-directed translation and optioanlly start at INPUT-TAPE-INDEX with
  PUSHDOWN-LIST, OUTPUT, TRANSLATION, TRANSLATION-SYMBOL-TABLE-LIST and HISTORY."
  (unless input-tape-index
    (setq input-tape-index 1))
  (unless pushdown-list
    (push 0 pushdown-list))
  (let ((translation-symbol-table
         (make-hash-table :test 'equal)))
    (when translation-symbol-table-list
      (dolist
          (item translation-symbol-table-list)
        (puthash
         (nth 0 item)
         (nth 1 item)
         translation-symbol-table)))

    (if (and
         input-tape-index
         (> input-tape-index 1))
        (setq
         phps-mode-parser-lex-analyzer--index
         input-tape-index)
      (phps-mode-parser-lex-analyzer--reset))

    ;; Make sure tables exists
    (unless phps-mode-parser--action-tables
      (error "Missing action-tables for grammar!"))
    (unless phps-mode-parser--distinct-action-tables
      (error "Missing distinct GOTO-tables for grammar!"))
    (unless phps-mode-parser--goto-tables
      (error "Missing GOTO-tables for grammar!"))
    (unless phps-mode-parser--distinct-goto-tables
      (error "Missing distinct GOTO-tables for grammar!"))

    (let ((accept))
      (while (not accept)

        ;; (1) The look-ahead string u, consisting of the next k input symbols, is determined.
        (let ((look-ahead
               (phps-mode-parser-lex-analyzer--peek-next-look-ahead))
              (look-ahead-full))

          ;; Save token stream indexes in separate variable if needed later
          (setq look-ahead-full look-ahead)

          ;; Create simplified look-ahead for logic below
          (setq look-ahead nil)
          (dolist (look-ahead-item look-ahead-full)
            (if (listp look-ahead-item)
                (push (car look-ahead-item) look-ahead)
              (push look-ahead-item look-ahead)))
          (setq look-ahead (nreverse look-ahead))

          (let ((table-index
                 (car pushdown-list)))
            (let ((action-table-distinct-index
                   (gethash
                    table-index
                    phps-mode-parser--action-tables)))
              (let ((action-table
                     (gethash
                      action-table-distinct-index
                      phps-mode-parser--distinct-action-tables)))
              (unless action-table
                (error
                 "Action-table with index %s is empty! Push-down-list: %s"
                 table-index
                 pushdown-list))
              (let ((action-match nil)
                    (action-table-length (length action-table))
                    (action-index 0)
                    (possible-look-aheads))

                ;; (2) The parsing action f of the table on top of the pushdown list is applied to the lookahead string u.
                (while (and
                        (not action-match)
                        (< action-index action-table-length))
                  (let ((action (nth action-index action-table)))
                    (let ((action-look-ahead (car action)))
                      (push
                       action-look-ahead
                       possible-look-aheads)
                      (when
                          (equal
                           action-look-ahead
                           look-ahead)
                        (setq
                         action-match
                         (cdr action)))
                      (when
                          (and
                           (=
                            phps-mode-parser--look-ahead-number
                            0)
                           (not
                            action-look-ahead))
                        ;; LR(0) reduce actions occupy entire row
                        ;; and is applied regardless of look-ahead
                        (setq
                         action-match
                         (cdr action))))
                    (setq
                     action-index
                     (1+ action-index))))

                (unless action-match
                  ;; (c) If f(u) = error, we halt parsing (and, in practice
                  ;; transfer to an error recovery routine).
                  (signal
                    'error
                    (list
                      (format
                        "Invalid syntax! Expected one of %s found %s at %s"

                   possible-look-aheads
                   look-ahead
                   phps-mode-parser-lex-analyzer--index)
                   possible-look-aheads
                   look-ahead
                   phps-mode-parser-lex-analyzer--index)))

                (cond

                 ((equal action-match '(shift))
                  ;; (a) If f(u) = shift, then the next input symbol, say a
                  ;; is removed from the input and shifted onto the pushdown list.
                  ;; The goto function g of the table on top of the pushdown list
                  ;; is applied to a to determine the new table to be placed on
                  ;; top of the pushdown list. We then return to step(1). If
                  ;; there is no next input symbol or g(a) is undefined, halt
                  ;; and declare error.

                  (let ((a (list (car look-ahead)))
                        (a-full (list (car look-ahead-full))))
                      (let ((goto-table-distinct-index
                             (gethash
                              table-index
                              phps-mode-parser--goto-tables)))
                        (let ((goto-table
                               (gethash
                                goto-table-distinct-index
                                phps-mode-parser--distinct-goto-tables)))
                      (let ((goto-table-length (length goto-table))
                            (goto-index 0)
                            (searching-match t)
                            (next-index)
                            (possible-look-aheads))

                        (while (and
                                searching-match
                                (< goto-index goto-table-length))
                          (let ((goto-item (nth goto-index goto-table)))
                            (let ((goto-item-symbol (list (car goto-item)))
                                  (goto-item-next-index (car (cdr goto-item))))
                              (push goto-item-symbol possible-look-aheads)

                              (when (equal
                                     goto-item-symbol
                                     a)
                                (setq next-index goto-item-next-index)
                                (setq searching-match nil))))

                          (setq goto-index (1+ goto-index)))
                        (unless next-index
                          (error
                           "In shift, found no GOTO-item for %s at %s, expected one of %s"
                           a
                           phps-mode-parser-lex-analyzer--index
                           possible-look-aheads))

                        (push (car a-full) pushdown-list)
                        (push next-index pushdown-list)
                        (phps-mode-parser-lex-analyzer--pop-token))))))

                 ((equal (car action-match) 'reduce)
                  ;; (b) If f(u) = reduce i and production i is A -> a,
                  ;; then 2|a| symbols are removed from the top of the pushdown
                  ;; list, and production number i is placed in the output
                  ;; buffer. A new table T' is then exposed as the top table
                  ;; of the pushdown list, and the goto function of T' is applied
                  ;; to A to determine the next table to be placed on top of the
                  ;; pushdown list. We place A and this new table on top of the
                  ;; the pushdown list and return to step (1)

                  (let ((production-number (car (cdr action-match))))

                    (let ((production
                           (phps-mode-parser--get-grammar-production-by-number
                            production-number)))
                      (let ((production-lhs (car production))
                            (production-rhs (car (cdr production)))
                            (popped-items-contents))
                        (unless (equal
                                 production-rhs
                                 (list phps-mode-parser--e-identifier))
                          (let ((pop-items (* 2 (length production-rhs)))
                                (popped-items 0)
                                (popped-item))
                            (while (< popped-items pop-items)
                              (setq popped-item (pop pushdown-list))
                              (when (and
                                     (listp popped-item)
                                     (phps-mode-parser--valid-symbol-p
                                      (car popped-item)))
                                (push
                                 popped-item
                                 popped-items-contents))
                              (setq popped-items (1+ popped-items)))))
                        (push production-number output)

                        (when perform-sdt
                          (let ((popped-items-meta-contents)
                                (popped-items-terminals))
                            (setq
                             popped-items-contents
                             (reverse popped-items-contents))
                            ;; Collect arguments for translation
                            (dolist (popped-item popped-items-contents)
                              (if (and
                                   (listp popped-item)
                                   (cdr popped-item))
                                  ;; If item is a terminal, use it's literal value
                                  (progn
                                    (push
                                      (phps-mode-parser-lex-analyzer--get-function
                                       popped-item)
                                       popped-items-meta-contents)
                                      (push
                                       popped-item
                                       popped-items-terminals))

                                ;; If item is a non-terminal
                                (let ((temp-hash-key
                                       (format
                                        "%S"
                                         popped-item)))

                                ;; If we have a translation for symbol, pop one
                                ;; otherwise push nil on translation argument stack
                                (if (gethash
                                         temp-hash-key
                                         translation-symbol-table)
                                        (let ((symbol-translations
                                               (gethash
                                                temp-hash-key
                                                translation-symbol-table)))
                                          (let ((symbol-translation
                                                 (pop symbol-translations)))
                                            (push
                                             (car symbol-translation)
                                             popped-items-meta-contents)
                                            (push
                                             (car (cdr symbol-translation))
                                             popped-items-terminals)
                                            (puthash
                                             temp-hash-key
                                             symbol-translations
                                             translation-symbol-table)))
                                      (push
                                       nil
                                       popped-items-meta-contents)
                                      (push
                                       nil
                                       popped-items-terminals)))))

                              ;; If we just have one argument, pass it as a instead of a list
                              (when (= (length popped-items-meta-contents) 1)
                                (setq
                                 popped-items-meta-contents
                                 (car popped-items-meta-contents))
                                (setq
                                 popped-items-terminals
                                 (car popped-items-terminals)))

                              ;; Perform translation at reduction if specified
                              (if
                                  (phps-mode-parser--get-grammar-translation-by-number
                                   production-number)
                                   (progn
                                  ;; (message "Translation: %s" production-number)
                                  ;; (message "args: %S" popped-items-meta-contents)
                                  ;; (message "terminals: %S" popped-items-terminals)
                                  (let ((partial-translation
                                         (funcall
                                          (phps-mode-parser--get-grammar-translation-by-number
                                           production-number)
                                          popped-items-meta-contents
                                          popped-items-terminals)))
                                    (let ((temp-hash-key
                                           (format
                                            "%S"
                                            production-lhs)))
                                      (let ((symbol-translations
                                             (gethash
                                              temp-hash-key
                                              translation-symbol-table)))
                                        (push
                                          (list
                                           partial-translation
                                           popped-items-terminals)
                                           symbol-translations)
                                        (puthash
                                         temp-hash-key
                                         symbol-translations
                                         translation-symbol-table)
                                        (setq
                                         translation
                                         partial-translation)))))

                                ;; When no translation is specified just use popped contents as translation
                                (let ((partial-translation
                                       (list
                                        popped-items-meta-contents
                                        popped-items-terminals)))
                                  (let ((temp-hash-key
                                         (format
                                          "%S"
                                          production-lhs)))
                                    (let ((symbol-translations
                                           (gethash
                                            temp-hash-key
                                            translation-symbol-table)))
                                      (push
                                       partial-translation
                                       symbol-translations)
                                      (puthash
                                       temp-hash-key
                                       symbol-translations
                                       translation-symbol-table)
                                      (setq
                                       translation
                                       (car partial-translation))))))))

                          (let ((new-table-index (car pushdown-list)))
                            (let ((goto-table-distinct-index
                                   (gethash
                                    new-table-index
                                    phps-mode-parser--goto-tables)))
                              (let ((goto-table
                                     (gethash
                                      goto-table-distinct-index
                                      phps-mode-parser--distinct-goto-tables)))
                                (let ((goto-table-length
                                       (length goto-table))
                                      (goto-index 0)
                                      (searching-match t)
                                      (next-index))

                                  (while (and
                                          searching-match
                                          (< goto-index goto-table-length))
                                    (let ((goto-item (nth goto-index goto-table)))
                                      (let ((goto-item-symbol (list (car goto-item)))
                                            (goto-item-next-index (car (cdr goto-item))))

                                        (when (equal
                                               goto-item-symbol
                                               production-lhs)
                                          (setq next-index goto-item-next-index)
                                          (setq searching-match nil))))

                                    (setq goto-index (1+ goto-index)))

                                  (when next-index
                                    (push production-lhs pushdown-list)
                                    (push next-index pushdown-list))))))))))

                   ((equal action-match '(accept))
                    ;;    (d) If f(u) = accept, we halt and declare the string
                    ;;    in the output buffer to be the right parse of the original
                    ;;    input string.

                    (setq accept t))
                   (t (error
                       "Invalid action-match: %s!"
                       action-match)))))))))
      (unless accept
        (error
         "Parsed entire string without getting accepting! Output: %s"
         (reverse output)))
      (when history
        (setq history (reverse history)))
      (when output
        (setq output (reverse output)))
      (let ((translation-symbol-table-list))
        (when translation-symbol-table
          (maphash
           (lambda (key value)
             (push
              `(,key ,value)
              translation-symbol-table-list))
           translation-symbol-table))
        (list
         output
         translation
         translation-symbol-table-list
         history)))))

(defun phps-mode-parser-parse
    (&optional
     input-tape-index
     pushdown-list
     output
     translation
     history)
  "Perform a LR-parse via lex-analyzer, optionally at INPUT-TAPE-INDEX
  with PUSHDOWN-LIST, OUTPUT, TRANSLATION and HISTORY."
  (let ((result
         (phps-mode-parser--parse
          nil
          input-tape-index
          pushdown-list
          output
          translation
          history)))
    (nth 0 result)))

(defun phps-mode-parser-translate
    (&optional
     input-tape-index
     pushdown-list
     output
     translation
     history)
  "Perform a LR-parse via lex-analyzer, optionally at INPUT-TAPE-INDEX with
  PUSHDOWN-LIST, OUTPUT, TRANSLATION and HISTORY."
  (let ((result
         (phps-mode-parser--parse
          t
          input-tape-index
          pushdown-list
          output
          translation
          history)))
    (nth 1 result)))

(provide 'phps-mode-parser)

;;; phps-mode-parser.el ends here
